<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'چمي: بالغ، بالغ، گوري رنگت, وچولي گوري رنگت',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'چمي: بالغ، بالغ، گوري رنگت, پڪو رنگ',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'چمي: بالغ، بالغ، گوري رنگت, وچولو ڪارو رنگ',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'چمي: بالغ، بالغ، گوري رنگت, ڪارو رنگ',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'چمي: بالغ، بالغ، وچولي گوري رنگت, گوري رنگت',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'چمي: بالغ، بالغ، وچولي گوري رنگت, پڪو رنگ',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'چمي: بالغ، بالغ، وچولي گوري رنگت, وچولو ڪارو رنگ',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'چمي: بالغ، بالغ، وچولي گوري رنگت, ڪارو رنگ',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'چمي: بالغ، بالغ، پڪو رنگ, گوري رنگت',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'چمي: بالغ، بالغ، پڪو رنگ, وچولي گوري رنگت',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'چمي: بالغ، بالغ، پڪو رنگ, وچولو ڪارو رنگ',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'چمي: بالغ، بالغ، پڪو رنگ, ڪارو رنگ',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'چمي: بالغ، بالغ، وچولو ڪارو رنگ, گوري رنگت',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'چمي: بالغ، بالغ، وچولو ڪارو رنگ, وچولي گوري رنگت',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'چمي: بالغ، بالغ، وچولو ڪارو رنگ, پڪو رنگ',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'چمي: بالغ، بالغ، وچولو ڪارو رنگ, ڪارو رنگ',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'چمي: بالغ، بالغ، ڪارو رنگ, گوري رنگت',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'چمي: بالغ، بالغ، ڪارو رنگ, وچولي گوري رنگت',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'چمي: بالغ، بالغ، ڪارو رنگ, پڪو رنگ',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'چمي: بالغ، بالغ، ڪارو رنگ, وچولو ڪارو رنگ',
    '👨🏻‍❤‍💋‍👨🏻' => 'چمي: ماڻهو، ماڻهو, گوري رنگت',
    '👨🏻‍❤‍💋‍👨🏼' => 'چمي: ماڻهو، ماڻهو، گوري رنگت, وچولي گوري رنگت',
    '👨🏻‍❤‍💋‍👨🏽' => 'چمي: ماڻهو، ماڻهو، گوري رنگت, پڪو رنگ',
    '👨🏻‍❤‍💋‍👨🏾' => 'چمي: ماڻهو، ماڻهو، گوري رنگت, وچولو ڪارو رنگ',
    '👨🏻‍❤‍💋‍👨🏿' => 'چمي: ماڻهو، ماڻهو، گوري رنگت, ڪارو رنگ',
    '👨🏼‍❤‍💋‍👨🏻' => 'چمي: ماڻهو، ماڻهو، وچولي گوري رنگت, گوري رنگت',
    '👨🏼‍❤‍💋‍👨🏼' => 'چمي: ماڻهو، ماڻهو, وچولي گوري رنگت',
    '👨🏼‍❤‍💋‍👨🏽' => 'چمي: ماڻهو، ماڻهو، وچولي گوري رنگت, پڪو رنگ',
    '👨🏼‍❤‍💋‍👨🏾' => 'چمي: ماڻهو، ماڻهو، وچولي گوري رنگت, وچولو ڪارو رنگ',
    '👨🏼‍❤‍💋‍👨🏿' => 'چمي: ماڻهو، ماڻهو، وچولي گوري رنگت, ڪارو رنگ',
    '👨🏽‍❤‍💋‍👨🏻' => 'چمي: ماڻهو، ماڻهو، پڪو رنگ, گوري رنگت',
    '👨🏽‍❤‍💋‍👨🏼' => 'چمي: ماڻهو، ماڻهو، پڪو رنگ, وچولي گوري رنگت',
    '👨🏽‍❤‍💋‍👨🏽' => 'چمي: ماڻهو، ماڻهو, پڪو رنگ',
    '👨🏽‍❤‍💋‍👨🏾' => 'چمي: ماڻهو، ماڻهو، پڪو رنگ, وچولو ڪارو رنگ',
    '👨🏽‍❤‍💋‍👨🏿' => 'چمي: ماڻهو، ماڻهو، پڪو رنگ, ڪارو رنگ',
    '👨🏾‍❤‍💋‍👨🏻' => 'چمي: ماڻهو، ماڻهو، وچولو ڪارو رنگ, گوري رنگت',
    '👨🏾‍❤‍💋‍👨🏼' => 'چمي: ماڻهو، ماڻهو، وچولو ڪارو رنگ, وچولي گوري رنگت',
    '👨🏾‍❤‍💋‍👨🏽' => 'چمي: ماڻهو، ماڻهو، وچولو ڪارو رنگ, پڪو رنگ',
    '👨🏾‍❤‍💋‍👨🏾' => 'چمي: ماڻهو، ماڻهو, وچولو ڪارو رنگ',
    '👨🏾‍❤‍💋‍👨🏿' => 'چمي: ماڻهو، ماڻهو، وچولو ڪارو رنگ, ڪارو رنگ',
    '👨🏿‍❤‍💋‍👨🏻' => 'چمي: ماڻهو، ماڻهو، ڪارو رنگ, گوري رنگت',
    '👨🏿‍❤‍💋‍👨🏼' => 'چمي: ماڻهو، ماڻهو، ڪارو رنگ, وچولي گوري رنگت',
    '👨🏿‍❤‍💋‍👨🏽' => 'چمي: ماڻهو، ماڻهو، ڪارو رنگ, پڪو رنگ',
    '👨🏿‍❤‍💋‍👨🏾' => 'چمي: ماڻهو، ماڻهو، ڪارو رنگ, وچولو ڪارو رنگ',
    '👨🏿‍❤‍💋‍👨🏿' => 'چمي: ماڻهو، ماڻهو, ڪارو رنگ',
    '👩🏻‍❤‍💋‍👨🏻' => 'چمي: عورت، ماڻهو, گوري رنگت',
    '👩🏻‍❤‍💋‍👨🏼' => 'چمي: عورت، ماڻهو، گوري رنگت, وچولي گوري رنگت',
    '👩🏻‍❤‍💋‍👨🏽' => 'چمي: عورت، ماڻهو، گوري رنگت, پڪو رنگ',
    '👩🏻‍❤‍💋‍👨🏾' => 'چمي: عورت، ماڻهو، گوري رنگت, وچولو ڪارو رنگ',
    '👩🏻‍❤‍💋‍👨🏿' => 'چمي: عورت، ماڻهو، گوري رنگت, ڪارو رنگ',
    '👩🏼‍❤‍💋‍👨🏻' => 'چمي: عورت، ماڻهو، وچولي گوري رنگت, گوري رنگت',
    '👩🏼‍❤‍💋‍👨🏼' => 'چمي: عورت، ماڻهو, وچولي گوري رنگت',
    '👩🏼‍❤‍💋‍👨🏽' => 'چمي: عورت، ماڻهو، وچولي گوري رنگت, پڪو رنگ',
    '👩🏼‍❤‍💋‍👨🏾' => 'چمي: عورت، ماڻهو، وچولي گوري رنگت, وچولو ڪارو رنگ',
    '👩🏼‍❤‍💋‍👨🏿' => 'چمي: عورت، ماڻهو، وچولي گوري رنگت, ڪارو رنگ',
    '👩🏽‍❤‍💋‍👨🏻' => 'چمي: عورت، ماڻهو، پڪو رنگ, گوري رنگت',
    '👩🏽‍❤‍💋‍👨🏼' => 'چمي: عورت، ماڻهو، پڪو رنگ, وچولي گوري رنگت',
    '👩🏽‍❤‍💋‍👨🏽' => 'چمي: عورت، ماڻهو, پڪو رنگ',
    '👩🏽‍❤‍💋‍👨🏾' => 'چمي: عورت، ماڻهو، پڪو رنگ, وچولو ڪارو رنگ',
    '👩🏽‍❤‍💋‍👨🏿' => 'چمي: عورت، ماڻهو، پڪو رنگ, ڪارو رنگ',
    '👩🏾‍❤‍💋‍👨🏻' => 'چمي: عورت، ماڻهو، وچولو ڪارو رنگ, گوري رنگت',
    '👩🏾‍❤‍💋‍👨🏼' => 'چمي: عورت، ماڻهو، وچولو ڪارو رنگ, وچولي گوري رنگت',
    '👩🏾‍❤‍💋‍👨🏽' => 'چمي: عورت، ماڻهو، وچولو ڪارو رنگ, پڪو رنگ',
    '👩🏾‍❤‍💋‍👨🏾' => 'چمي: عورت، ماڻهو, وچولو ڪارو رنگ',
    '👩🏾‍❤‍💋‍👨🏿' => 'چمي: عورت، ماڻهو، وچولو ڪارو رنگ, ڪارو رنگ',
    '👩🏿‍❤‍💋‍👨🏻' => 'چمي: عورت، ماڻهو، ڪارو رنگ, گوري رنگت',
    '👩🏿‍❤‍💋‍👨🏼' => 'چمي: عورت، ماڻهو، ڪارو رنگ, وچولي گوري رنگت',
    '👩🏿‍❤‍💋‍👨🏽' => 'چمي: عورت، ماڻهو، ڪارو رنگ, پڪو رنگ',
    '👩🏿‍❤‍💋‍👨🏾' => 'چمي: عورت، ماڻهو، ڪارو رنگ, وچولو ڪارو رنگ',
    '👩🏿‍❤‍💋‍👨🏿' => 'چمي: عورت، ماڻهو, ڪارو رنگ',
    '👩🏻‍❤‍💋‍👩🏻' => 'چمي: عورت، عورت, گوري رنگت',
    '👩🏻‍❤‍💋‍👩🏼' => 'چمي: عورت، عورت، گوري رنگت, وچولي گوري رنگت',
    '👩🏻‍❤‍💋‍👩🏽' => 'چمي: عورت، عورت، گوري رنگت, پڪو رنگ',
    '👩🏻‍❤‍💋‍👩🏾' => 'چمي: عورت، عورت، گوري رنگت, وچولو ڪارو رنگ',
    '👩🏻‍❤‍💋‍👩🏿' => 'چمي: عورت، عورت، گوري رنگت, ڪارو رنگ',
    '👩🏼‍❤‍💋‍👩🏻' => 'چمي: عورت، عورت، وچولي گوري رنگت, گوري رنگت',
    '👩🏼‍❤‍💋‍👩🏼' => 'چمي: عورت، عورت, وچولي گوري رنگت',
    '👩🏼‍❤‍💋‍👩🏽' => 'چمي: عورت، عورت، وچولي گوري رنگت, پڪو رنگ',
    '👩🏼‍❤‍💋‍👩🏾' => 'چمي: عورت، عورت، وچولي گوري رنگت, وچولو ڪارو رنگ',
    '👩🏼‍❤‍💋‍👩🏿' => 'چمي: عورت، عورت، وچولي گوري رنگت, ڪارو رنگ',
    '👩🏽‍❤‍💋‍👩🏻' => 'چمي: عورت، عورت، پڪو رنگ, گوري رنگت',
    '👩🏽‍❤‍💋‍👩🏼' => 'چمي: عورت، عورت، پڪو رنگ, وچولي گوري رنگت',
    '👩🏽‍❤‍💋‍👩🏽' => 'چمي: عورت، عورت, پڪو رنگ',
    '👩🏽‍❤‍💋‍👩🏾' => 'چمي: عورت، عورت، پڪو رنگ, وچولو ڪارو رنگ',
    '👩🏽‍❤‍💋‍👩🏿' => 'چمي: عورت، عورت، پڪو رنگ, ڪارو رنگ',
    '👩🏾‍❤‍💋‍👩🏻' => 'چمي: عورت، عورت، وچولو ڪارو رنگ, گوري رنگت',
    '👩🏾‍❤‍💋‍👩🏼' => 'چمي: عورت، عورت، وچولو ڪارو رنگ, وچولي گوري رنگت',
    '👩🏾‍❤‍💋‍👩🏽' => 'چمي: عورت، عورت، وچولو ڪارو رنگ, پڪو رنگ',
    '👩🏾‍❤‍💋‍👩🏾' => 'چمي: عورت، عورت, وچولو ڪارو رنگ',
    '👩🏾‍❤‍💋‍👩🏿' => 'چمي: عورت، عورت، وچولو ڪارو رنگ, ڪارو رنگ',
    '👩🏿‍❤‍💋‍👩🏻' => 'چمي: عورت، عورت، ڪارو رنگ, گوري رنگت',
    '👩🏿‍❤‍💋‍👩🏼' => 'چمي: عورت، عورت، ڪارو رنگ, وچولي گوري رنگت',
    '👩🏿‍❤‍💋‍👩🏽' => 'چمي: عورت، عورت، ڪارو رنگ, پڪو رنگ',
    '👩🏿‍❤‍💋‍👩🏾' => 'چمي: عورت، عورت، ڪارو رنگ, وچولو ڪارو رنگ',
    '👩🏿‍❤‍💋‍👩🏿' => 'چمي: عورت، عورت, ڪارو رنگ',
    '🧑🏻‍🫯‍🧑🏼' => 'ماڻهو ڪشتي وڙهندي: گوري رنگت، وچولي گوري رنگت',
    '🧑🏻‍🫯‍🧑🏽' => 'ماڻهو ڪشتي وڙهندي: گوري رنگت، پڪو رنگ',
    '🧑🏻‍🫯‍🧑🏾' => 'ماڻهو ڪشتي وڙهندي: گوري رنگت، وچولو ڪارو رنگ',
    '🧑🏻‍🫯‍🧑🏿' => 'ماڻهو ڪشتي وڙهندي: گوري رنگت، ڪارو رنگ',
    '🧑🏼‍🫯‍🧑🏻' => 'ماڻهو ڪشتي وڙهندي: وچولي گوري رنگت، گوري رنگت',
    '🧑🏼‍🫯‍🧑🏽' => 'ماڻهو ڪشتي وڙهندي: وچولي گوري رنگت، پڪو رنگ',
    '🧑🏼‍🫯‍🧑🏾' => 'ماڻهو ڪشتي وڙهندي: وچولي گوري رنگت، وچولو ڪارو رنگ',
    '🧑🏼‍🫯‍🧑🏿' => 'ماڻهو ڪشتي وڙهندي: وچولي گوري رنگت، ڪارو رنگ',
    '🧑🏽‍🫯‍🧑🏻' => 'ماڻهو ڪشتي وڙهندي: پڪو رنگ، گوري رنگت',
    '🧑🏽‍🫯‍🧑🏼' => 'ماڻهو ڪشتي وڙهندي: پڪو رنگ، وچولي گوري رنگت',
    '🧑🏽‍🫯‍🧑🏾' => 'ماڻهو ڪشتي وڙهندي: پڪو رنگ، وچولو ڪارو رنگ',
    '🧑🏽‍🫯‍🧑🏿' => 'ماڻهو ڪشتي وڙهندي: پڪو رنگ، ڪارو رنگ',
    '🧑🏾‍🫯‍🧑🏻' => 'ماڻهو ڪشتي وڙهندي: وچولو ڪارو رنگ، گوري رنگت',
    '🧑🏾‍🫯‍🧑🏼' => 'ماڻهو ڪشتي وڙهندي: وچولو ڪارو رنگ، وچولي گوري رنگت',
    '🧑🏾‍🫯‍🧑🏽' => 'ماڻهو ڪشتي وڙهندي: وچولو ڪارو رنگ، پڪو رنگ',
    '🧑🏾‍🫯‍🧑🏿' => 'ماڻهو ڪشتي وڙهندي: وچولو ڪارو رنگ، ڪارو رنگ',
    '🧑🏿‍🫯‍🧑🏻' => 'ماڻهو ڪشتي وڙهندي: ڪارو رنگ، گوري رنگت',
    '🧑🏿‍🫯‍🧑🏼' => 'ماڻهو ڪشتي وڙهندي: ڪارو رنگ، وچولي گوري رنگت',
    '🧑🏿‍🫯‍🧑🏽' => 'ماڻهو ڪشتي وڙهندي: ڪارو رنگ، پڪو رنگ',
    '🧑🏿‍🫯‍🧑🏾' => 'ماڻهو ڪشتي وڙهندي: ڪارو رنگ، وچولو ڪارو رنگ',
    '🧑🏻‍❤‍🧑🏼' => 'دل سان جوڙو: بالغ، بالغ، گوري رنگت, وچولي گوري رنگت',
    '🧑🏻‍❤‍🧑🏽' => 'دل سان جوڙو: بالغ، بالغ، گوري رنگت, پڪو رنگ',
    '🧑🏻‍❤‍🧑🏾' => 'دل سان جوڙو: بالغ، بالغ، گوري رنگت, وچولو ڪارو رنگ',
    '🧑🏻‍❤‍🧑🏿' => 'دل سان جوڙو: بالغ، بالغ، گوري رنگت, ڪارو رنگ',
    '🧑🏼‍❤‍🧑🏻' => 'دل سان جوڙو: بالغ، بالغ، وچولي گوري رنگت, گوري رنگت',
    '🧑🏼‍❤‍🧑🏽' => 'دل سان جوڙو: بالغ، بالغ، وچولي گوري رنگت, پڪو رنگ',
    '🧑🏼‍❤‍🧑🏾' => 'دل سان جوڙو: بالغ، بالغ، وچولي گوري رنگت, وچولو ڪارو رنگ',
    '🧑🏼‍❤‍🧑🏿' => 'دل سان جوڙو: بالغ، بالغ، وچولي گوري رنگت, ڪارو رنگ',
    '🧑🏽‍❤‍🧑🏻' => 'دل سان جوڙو: بالغ، بالغ، پڪو رنگ, گوري رنگت',
    '🧑🏽‍❤‍🧑🏼' => 'دل سان جوڙو: بالغ، بالغ، پڪو رنگ, وچولي گوري رنگت',
    '🧑🏽‍❤‍🧑🏾' => 'دل سان جوڙو: بالغ، بالغ، پڪو رنگ, وچولو ڪارو رنگ',
    '🧑🏽‍❤‍🧑🏿' => 'دل سان جوڙو: بالغ، بالغ، پڪو رنگ, ڪارو رنگ',
    '🧑🏾‍❤‍🧑🏻' => 'دل سان جوڙو: بالغ، بالغ، وچولو ڪارو رنگ, گوري رنگت',
    '🧑🏾‍❤‍🧑🏼' => 'دل سان جوڙو: بالغ، بالغ، وچولو ڪارو رنگ, وچولي گوري رنگت',
    '🧑🏾‍❤‍🧑🏽' => 'دل سان جوڙو: بالغ، بالغ، وچولو ڪارو رنگ, پڪو رنگ',
    '🧑🏾‍❤‍🧑🏿' => 'دل سان جوڙو: بالغ، بالغ، وچولو ڪارو رنگ, ڪارو رنگ',
    '🧑🏿‍❤‍🧑🏻' => 'دل سان جوڙو: بالغ، بالغ، ڪارو رنگ, گوري رنگت',
    '🧑🏿‍❤‍🧑🏼' => 'دل سان جوڙو: بالغ، بالغ، ڪارو رنگ, وچولي گوري رنگت',
    '🧑🏿‍❤‍🧑🏽' => 'دل سان جوڙو: بالغ، بالغ، ڪارو رنگ, پڪو رنگ',
    '🧑🏿‍❤‍🧑🏾' => 'دل سان جوڙو: بالغ، بالغ، ڪارو رنگ, وچولو ڪارو رنگ',
    '🧑🏻‍🐰‍🧑🏼' => 'خرگوش جي ڪنن وارو ماڻهو: گوري رنگت، وچولي گوري رنگت',
    '🧑🏻‍🐰‍🧑🏽' => 'خرگوش جي ڪنن وارو ماڻهو: گوري رنگت، پڪو رنگ',
    '🧑🏻‍🐰‍🧑🏾' => 'خرگوش جي ڪنن وارو ماڻهو: گوري رنگت، وچولو ڪارو رنگ',
    '🧑🏻‍🐰‍🧑🏿' => 'خرگوش جي ڪنن وارو ماڻهو: گوري رنگت، ڪارو رنگ',
    '🧑🏼‍🐰‍🧑🏻' => 'خرگوش جي ڪنن وارو ماڻهو: وچولي گوري رنگت، گوري رنگت',
    '🧑🏼‍🐰‍🧑🏽' => 'خرگوش جي ڪنن وارو ماڻهو: وچولي گوري رنگت، پڪو رنگ',
    '🧑🏼‍🐰‍🧑🏾' => 'خرگوش جي ڪنن وارو ماڻهو: وچولي گوري رنگت، وچولو ڪارو رنگ',
    '🧑🏼‍🐰‍🧑🏿' => 'خرگوش جي ڪنن وارو ماڻهو: وچولي گوري رنگت، ڪارو رنگ',
    '🧑🏽‍🐰‍🧑🏻' => 'خرگوش جي ڪنن وارو ماڻهو: پڪو رنگ، گوري رنگت',
    '🧑🏽‍🐰‍🧑🏼' => 'خرگوش جي ڪنن وارو ماڻهو: پڪو رنگ، وچولي گوري رنگت',
    '🧑🏽‍🐰‍🧑🏾' => 'خرگوش جي ڪنن وارو ماڻهو: پڪو رنگ، وچولو ڪارو رنگ',
    '🧑🏽‍🐰‍🧑🏿' => 'خرگوش جي ڪنن وارو ماڻهو: پڪو رنگ، ڪارو رنگ',
    '🧑🏾‍🐰‍🧑🏻' => 'خرگوش جي ڪنن وارو ماڻهو: وچولو ڪارو رنگ، گوري رنگت',
    '🧑🏾‍🐰‍🧑🏼' => 'خرگوش جي ڪنن وارو ماڻهو: وچولو ڪارو رنگ، وچولي گوري رنگت',
    '🧑🏾‍🐰‍🧑🏽' => 'خرگوش جي ڪنن وارو ماڻهو: وچولو ڪارو رنگ، پڪو رنگ',
    '🧑🏾‍🐰‍🧑🏿' => 'خرگوش جي ڪنن وارو ماڻهو: وچولو ڪارو رنگ، ڪارو رنگ',
    '🧑🏿‍🐰‍🧑🏻' => 'خرگوش جي ڪنن وارو ماڻهو: ڪارو رنگ، گوري رنگت',
    '🧑🏿‍🐰‍🧑🏼' => 'خرگوش جي ڪنن وارو ماڻهو: ڪارو رنگ، وچولي گوري رنگت',
    '🧑🏿‍🐰‍🧑🏽' => 'خرگوش جي ڪنن وارو ماڻهو: ڪارو رنگ، پڪو رنگ',
    '🧑🏿‍🐰‍🧑🏾' => 'خرگوش جي ڪنن وارو ماڻهو: ڪارو رنگ، وچولو ڪارو رنگ',
    '👨🏻‍🫯‍👨🏼' => 'مرد ڪشتي وڙهندي: گوري رنگت، وچولي گوري رنگت',
    '👨🏻‍🫯‍👨🏽' => 'مرد ڪشتي وڙهندي: گوري رنگت، پڪو رنگ',
    '👨🏻‍🫯‍👨🏾' => 'مرد ڪشتي وڙهندي: گوري رنگت، وچولو ڪارو رنگ',
    '👨🏻‍🫯‍👨🏿' => 'مرد ڪشتي وڙهندي: گوري رنگت، ڪارو رنگ',
    '👨🏼‍🫯‍👨🏻' => 'مرد ڪشتي وڙهندي: وچولي گوري رنگت، گوري رنگت',
    '👨🏼‍🫯‍👨🏽' => 'مرد ڪشتي وڙهندي: وچولي گوري رنگت، پڪو رنگ',
    '👨🏼‍🫯‍👨🏾' => 'مرد ڪشتي وڙهندي: وچولي گوري رنگت، وچولو ڪارو رنگ',
    '👨🏼‍🫯‍👨🏿' => 'مرد ڪشتي وڙهندي: وچولي گوري رنگت، ڪارو رنگ',
    '👨🏽‍🫯‍👨🏻' => 'مرد ڪشتي وڙهندي: پڪو رنگ، گوري رنگت',
    '👨🏽‍🫯‍👨🏼' => 'مرد ڪشتي وڙهندي: پڪو رنگ، وچولي گوري رنگت',
    '👨🏽‍🫯‍👨🏾' => 'مرد ڪشتي وڙهندي: پڪو رنگ، وچولو ڪارو رنگ',
    '👨🏽‍🫯‍👨🏿' => 'مرد ڪشتي وڙهندي: پڪو رنگ، ڪارو رنگ',
    '👨🏾‍🫯‍👨🏻' => 'مرد ڪشتي وڙهندي: وچولو ڪارو رنگ، گوري رنگت',
    '👨🏾‍🫯‍👨🏼' => 'مرد ڪشتي وڙهندي: وچولو ڪارو رنگ، وچولي گوري رنگت',
    '👨🏾‍🫯‍👨🏽' => 'مرد ڪشتي وڙهندي: وچولو ڪارو رنگ، پڪو رنگ',
    '👨🏾‍🫯‍👨🏿' => 'مرد ڪشتي وڙهندي: وچولو ڪارو رنگ، ڪارو رنگ',
    '👨🏿‍🫯‍👨🏻' => 'مرد ڪشتي وڙهندي: ڪارو رنگ، گوري رنگت',
    '👨🏿‍🫯‍👨🏼' => 'مرد ڪشتي وڙهندي: ڪارو رنگ، وچولي گوري رنگت',
    '👨🏿‍🫯‍👨🏽' => 'مرد ڪشتي وڙهندي: ڪارو رنگ، پڪو رنگ',
    '👨🏿‍🫯‍👨🏾' => 'مرد ڪشتي وڙهندي: ڪارو رنگ، وچولو ڪارو رنگ',
    '👨🏻‍❤‍👨🏻' => 'دل سان جوڙو: ماڻهو، ماڻهو, گوري رنگت',
    '👨🏻‍❤‍👨🏼' => 'دل سان جوڙو: ماڻهو، ماڻهو، گوري رنگت, وچولي گوري رنگت',
    '👨🏻‍❤‍👨🏽' => 'دل سان جوڙو: ماڻهو، ماڻهو، گوري رنگت, پڪو رنگ',
    '👨🏻‍❤‍👨🏾' => 'دل سان جوڙو: ماڻهو، ماڻهو، گوري رنگت, وچولو ڪارو رنگ',
    '👨🏻‍❤‍👨🏿' => 'دل سان جوڙو: ماڻهو، ماڻهو، گوري رنگت, ڪارو رنگ',
    '👨🏼‍❤‍👨🏻' => 'دل سان جوڙو: ماڻهو، ماڻهو، وچولي گوري رنگت, گوري رنگت',
    '👨🏼‍❤‍👨🏼' => 'دل سان جوڙو: ماڻهو، ماڻهو, وچولي گوري رنگت',
    '👨🏼‍❤‍👨🏽' => 'دل سان جوڙو: ماڻهو، ماڻهو، وچولي گوري رنگت, پڪو رنگ',
    '👨🏼‍❤‍👨🏾' => 'دل سان جوڙو: ماڻهو، ماڻهو، وچولي گوري رنگت, وچولو ڪارو رنگ',
    '👨🏼‍❤‍👨🏿' => 'دل سان جوڙو: ماڻهو، ماڻهو، وچولي گوري رنگت, ڪارو رنگ',
    '👨🏽‍❤‍👨🏻' => 'دل سان جوڙو: ماڻهو، ماڻهو، پڪو رنگ, گوري رنگت',
    '👨🏽‍❤‍👨🏼' => 'دل سان جوڙو: ماڻهو، ماڻهو، پڪو رنگ, وچولي گوري رنگت',
    '👨🏽‍❤‍👨🏽' => 'دل سان جوڙو: ماڻهو، ماڻهو, پڪو رنگ',
    '👨🏽‍❤‍👨🏾' => 'دل سان جوڙو: ماڻهو، ماڻهو، پڪو رنگ, وچولو ڪارو رنگ',
    '👨🏽‍❤‍👨🏿' => 'دل سان جوڙو: ماڻهو، ماڻهو، پڪو رنگ, ڪارو رنگ',
    '👨🏾‍❤‍👨🏻' => 'دل سان جوڙو: ماڻهو، ماڻهو، وچولو ڪارو رنگ, گوري رنگت',
    '👨🏾‍❤‍👨🏼' => 'دل سان جوڙو: ماڻهو، ماڻهو، وچولو ڪارو رنگ, وچولي گوري رنگت',
    '👨🏾‍❤‍👨🏽' => 'دل سان جوڙو: ماڻهو، ماڻهو، وچولو ڪارو رنگ, پڪو رنگ',
    '👨🏾‍❤‍👨🏾' => 'دل سان جوڙو: ماڻهو، ماڻهو, وچولو ڪارو رنگ',
    '👨🏾‍❤‍👨🏿' => 'دل سان جوڙو: ماڻهو، ماڻهو، وچولو ڪارو رنگ, ڪارو رنگ',
    '👨🏿‍❤‍👨🏻' => 'دل سان جوڙو: ماڻهو، ماڻهو، ڪارو رنگ, گوري رنگت',
    '👨🏿‍❤‍👨🏼' => 'دل سان جوڙو: ماڻهو، ماڻهو، ڪارو رنگ, وچولي گوري رنگت',
    '👨🏿‍❤‍👨🏽' => 'دل سان جوڙو: ماڻهو، ماڻهو، ڪارو رنگ, پڪو رنگ',
    '👨🏿‍❤‍👨🏾' => 'دل سان جوڙو: ماڻهو، ماڻهو، ڪارو رنگ, وچولو ڪارو رنگ',
    '👨🏿‍❤‍👨🏿' => 'دل سان جوڙو: ماڻهو، ماڻهو, ڪارو رنگ',
    '👨🏻‍🐰‍👨🏼' => 'خرگوش جي ڪنن وارو مرد: گوري رنگت، وچولي گوري رنگت',
    '👨🏻‍🐰‍👨🏽' => 'خرگوش جي ڪنن وارو مرد: گوري رنگت، پڪو رنگ',
    '👨🏻‍🐰‍👨🏾' => 'خرگوش جي ڪنن وارو مرد: گوري رنگت، وچولو ڪارو رنگ',
    '👨🏻‍🐰‍👨🏿' => 'خرگوش جي ڪنن وارو مرد: گوري رنگت، ڪارو رنگ',
    '👨🏼‍🐰‍👨🏻' => 'خرگوش جي ڪنن وارو مرد: وچولي گوري رنگت، گوري رنگت',
    '👨🏼‍🐰‍👨🏽' => 'خرگوش جي ڪنن وارو مرد: وچولي گوري رنگت، پڪو رنگ',
    '👨🏼‍🐰‍👨🏾' => 'خرگوش جي ڪنن وارو مرد: وچولي گوري رنگت، وچولو ڪارو رنگ',
    '👨🏼‍🐰‍👨🏿' => 'خرگوش جي ڪنن وارو مرد: وچولي گوري رنگت، ڪارو رنگ',
    '👨🏽‍🐰‍👨🏻' => 'خرگوش جي ڪنن وارو مرد: پڪو رنگ، گوري رنگت',
    '👨🏽‍🐰‍👨🏼' => 'خرگوش جي ڪنن وارو مرد: پڪو رنگ، وچولي گوري رنگت',
    '👨🏽‍🐰‍👨🏾' => 'خرگوش جي ڪنن وارو مرد: پڪو رنگ، وچولو ڪارو رنگ',
    '👨🏽‍🐰‍👨🏿' => 'خرگوش جي ڪنن وارو مرد: پڪو رنگ، ڪارو رنگ',
    '👨🏾‍🐰‍👨🏻' => 'خرگوش جي ڪنن وارو مرد: وچولو ڪارو رنگ، گوري رنگت',
    '👨🏾‍🐰‍👨🏼' => 'خرگوش جي ڪنن وارو مرد: وچولو ڪارو رنگ، وچولي گوري رنگت',
    '👨🏾‍🐰‍👨🏽' => 'خرگوش جي ڪنن وارو مرد: وچولو ڪارو رنگ، پڪو رنگ',
    '👨🏾‍🐰‍👨🏿' => 'خرگوش جي ڪنن وارو مرد: وچولو ڪارو رنگ، ڪارو رنگ',
    '👨🏿‍🐰‍👨🏻' => 'خرگوش جي ڪنن وارو مرد: ڪارو رنگ، گوري رنگت',
    '👨🏿‍🐰‍👨🏼' => 'خرگوش جي ڪنن وارو مرد: ڪارو رنگ، وچولي گوري رنگت',
    '👨🏿‍🐰‍👨🏽' => 'خرگوش جي ڪنن وارو مرد: ڪارو رنگ، پڪو رنگ',
    '👨🏿‍🐰‍👨🏾' => 'خرگوش جي ڪنن وارو مرد: ڪارو رنگ، وچولو ڪارو رنگ',
    '👩🏻‍🫯‍👩🏼' => 'عورتون ڪشتي وڙهندي: گوري رنگت، وچولي گوري رنگت',
    '👩🏻‍🫯‍👩🏽' => 'عورتون ڪشتي وڙهندي: گوري رنگت، پڪو رنگ',
    '👩🏻‍🫯‍👩🏾' => 'عورتون ڪشتي وڙهندي: گوري رنگت، وچولو ڪارو رنگ',
    '👩🏻‍🫯‍👩🏿' => 'عورتون ڪشتي وڙهندي: گوري رنگت، ڪارو رنگ',
    '👩🏼‍🫯‍👩🏻' => 'عورتون ڪشتي وڙهندي: وچولي گوري رنگت، گوري رنگت',
    '👩🏼‍🫯‍👩🏽' => 'عورتون ڪشتي وڙهندي: وچولي گوري رنگت، پڪو رنگ',
    '👩🏼‍🫯‍👩🏾' => 'عورتون ڪشتي وڙهندي: وچولي گوري رنگت، وچولو ڪارو رنگ',
    '👩🏼‍🫯‍👩🏿' => 'عورتون ڪشتي وڙهندي: وچولي گوري رنگت، ڪارو رنگ',
    '👩🏽‍🫯‍👩🏻' => 'عورتون ڪشتي وڙهندي: پڪو رنگ، گوري رنگت',
    '👩🏽‍🫯‍👩🏼' => 'عورتون ڪشتي وڙهندي: پڪو رنگ، وچولي گوري رنگت',
    '👩🏽‍🫯‍👩🏾' => 'عورتون ڪشتي وڙهندي: پڪو رنگ، وچولو ڪارو رنگ',
    '👩🏽‍🫯‍👩🏿' => 'عورتون ڪشتي وڙهندي: پڪو رنگ، ڪارو رنگ',
    '👩🏾‍🫯‍👩🏻' => 'عورتون ڪشتي وڙهندي: وچولو ڪارو رنگ، گوري رنگت',
    '👩🏾‍🫯‍👩🏼' => 'عورتون ڪشتي وڙهندي: وچولو ڪارو رنگ، وچولي گوري رنگت',
    '👩🏾‍🫯‍👩🏽' => 'عورتون ڪشتي وڙهندي: وچولو ڪارو رنگ، پڪو رنگ',
    '👩🏾‍🫯‍👩🏿' => 'عورتون ڪشتي وڙهندي: وچولو ڪارو رنگ، ڪارو رنگ',
    '👩🏿‍🫯‍👩🏻' => 'عورتون ڪشتي وڙهندي: ڪارو رنگ، گوري رنگت',
    '👩🏿‍🫯‍👩🏼' => 'عورتون ڪشتي وڙهندي: ڪارو رنگ، وچولي گوري رنگت',
    '👩🏿‍🫯‍👩🏽' => 'عورتون ڪشتي وڙهندي: ڪارو رنگ، پڪو رنگ',
    '👩🏿‍🫯‍👩🏾' => 'عورتون ڪشتي وڙهندي: ڪارو رنگ، وچولو ڪارو رنگ',
    '👩🏻‍❤‍👨🏻' => 'دل سان جوڙو: عورت، ماڻهو, گوري رنگت',
    '👩🏻‍❤‍👨🏼' => 'دل سان جوڙو: عورت، ماڻهو، گوري رنگت, وچولي گوري رنگت',
    '👩🏻‍❤‍👨🏽' => 'دل سان جوڙو: عورت، ماڻهو، گوري رنگت, پڪو رنگ',
    '👩🏻‍❤‍👨🏾' => 'دل سان جوڙو: عورت، ماڻهو، گوري رنگت, وچولو ڪارو رنگ',
    '👩🏻‍❤‍👨🏿' => 'دل سان جوڙو: عورت، ماڻهو، گوري رنگت, ڪارو رنگ',
    '👩🏼‍❤‍👨🏻' => 'دل سان جوڙو: عورت، ماڻهو، وچولي گوري رنگت, گوري رنگت',
    '👩🏼‍❤‍👨🏼' => 'دل سان جوڙو: عورت، ماڻهو, وچولي گوري رنگت',
    '👩🏼‍❤‍👨🏽' => 'دل سان جوڙو: عورت، ماڻهو، وچولي گوري رنگت, پڪو رنگ',
    '👩🏼‍❤‍👨🏾' => 'دل سان جوڙو: عورت، ماڻهو، وچولي گوري رنگت, وچولو ڪارو رنگ',
    '👩🏼‍❤‍👨🏿' => 'دل سان جوڙو: عورت، ماڻهو، وچولي گوري رنگت, ڪارو رنگ',
    '👩🏽‍❤‍👨🏻' => 'دل سان جوڙو: عورت، ماڻهو، پڪو رنگ, گوري رنگت',
    '👩🏽‍❤‍👨🏼' => 'دل سان جوڙو: عورت، ماڻهو، پڪو رنگ, وچولي گوري رنگت',
    '👩🏽‍❤‍👨🏽' => 'دل سان جوڙو: عورت، ماڻهو, پڪو رنگ',
    '👩🏽‍❤‍👨🏾' => 'دل سان جوڙو: عورت، ماڻهو، پڪو رنگ, وچولو ڪارو رنگ',
    '👩🏽‍❤‍👨🏿' => 'دل سان جوڙو: عورت، ماڻهو، پڪو رنگ, ڪارو رنگ',
    '👩🏾‍❤‍👨🏻' => 'دل سان جوڙو: عورت، ماڻهو، وچولو ڪارو رنگ, گوري رنگت',
    '👩🏾‍❤‍👨🏼' => 'دل سان جوڙو: عورت، ماڻهو، وچولو ڪارو رنگ, وچولي گوري رنگت',
    '👩🏾‍❤‍👨🏽' => 'دل سان جوڙو: عورت، ماڻهو، وچولو ڪارو رنگ, پڪو رنگ',
    '👩🏾‍❤‍👨🏾' => 'دل سان جوڙو: عورت، ماڻهو, وچولو ڪارو رنگ',
    '👩🏾‍❤‍👨🏿' => 'دل سان جوڙو: عورت، ماڻهو، وچولو ڪارو رنگ, ڪارو رنگ',
    '👩🏿‍❤‍👨🏻' => 'دل سان جوڙو: عورت، ماڻهو، ڪارو رنگ, گوري رنگت',
    '👩🏿‍❤‍👨🏼' => 'دل سان جوڙو: عورت، ماڻهو، ڪارو رنگ, وچولي گوري رنگت',
    '👩🏿‍❤‍👨🏽' => 'دل سان جوڙو: عورت، ماڻهو، ڪارو رنگ, پڪو رنگ',
    '👩🏿‍❤‍👨🏾' => 'دل سان جوڙو: عورت، ماڻهو، ڪارو رنگ, وچولو ڪارو رنگ',
    '👩🏿‍❤‍👨🏿' => 'دل سان جوڙو: عورت، ماڻهو, ڪارو رنگ',
    '👩🏻‍❤‍👩🏻' => 'دل سان جوڙو: عورت، عورت, گوري رنگت',
    '👩🏻‍❤‍👩🏼' => 'دل سان جوڙو: عورت، عورت، گوري رنگت, وچولي گوري رنگت',
    '👩🏻‍❤‍👩🏽' => 'دل سان جوڙو: عورت، عورت، گوري رنگت, پڪو رنگ',
    '👩🏻‍❤‍👩🏾' => 'دل سان جوڙو: عورت، عورت، گوري رنگت, وچولو ڪارو رنگ',
    '👩🏻‍❤‍👩🏿' => 'دل سان جوڙو: عورت، عورت، گوري رنگت, ڪارو رنگ',
    '👩🏼‍❤‍👩🏻' => 'دل سان جوڙو: عورت، عورت، وچولي گوري رنگت, گوري رنگت',
    '👩🏼‍❤‍👩🏼' => 'دل سان جوڙو: عورت، عورت, وچولي گوري رنگت',
    '👩🏼‍❤‍👩🏽' => 'دل سان جوڙو: عورت، عورت، وچولي گوري رنگت, پڪو رنگ',
    '👩🏼‍❤‍👩🏾' => 'دل سان جوڙو: عورت، عورت، وچولي گوري رنگت, وچولو ڪارو رنگ',
    '👩🏼‍❤‍👩🏿' => 'دل سان جوڙو: عورت، عورت، وچولي گوري رنگت, ڪارو رنگ',
    '👩🏽‍❤‍👩🏻' => 'دل سان جوڙو: عورت، عورت، پڪو رنگ, گوري رنگت',
    '👩🏽‍❤‍👩🏼' => 'دل سان جوڙو: عورت، عورت، پڪو رنگ, وچولي گوري رنگت',
    '👩🏽‍❤‍👩🏽' => 'دل سان جوڙو: عورت، عورت, پڪو رنگ',
    '👩🏽‍❤‍👩🏾' => 'دل سان جوڙو: عورت، عورت، پڪو رنگ, وچولو ڪارو رنگ',
    '👩🏽‍❤‍👩🏿' => 'دل سان جوڙو: عورت، عورت، پڪو رنگ, ڪارو رنگ',
    '👩🏾‍❤‍👩🏻' => 'دل سان جوڙو: عورت، عورت، وچولو ڪارو رنگ, گوري رنگت',
    '👩🏾‍❤‍👩🏼' => 'دل سان جوڙو: عورت، عورت، وچولو ڪارو رنگ, وچولي گوري رنگت',
    '👩🏾‍❤‍👩🏽' => 'دل سان جوڙو: عورت، عورت، وچولو ڪارو رنگ, پڪو رنگ',
    '👩🏾‍❤‍👩🏾' => 'دل سان جوڙو: عورت، عورت, وچولو ڪارو رنگ',
    '👩🏾‍❤‍👩🏿' => 'دل سان جوڙو: عورت، عورت، وچولو ڪارو رنگ, ڪارو رنگ',
    '👩🏿‍❤‍👩🏻' => 'دل سان جوڙو: عورت، عورت، ڪارو رنگ, گوري رنگت',
    '👩🏿‍❤‍👩🏼' => 'دل سان جوڙو: عورت، عورت، ڪارو رنگ, وچولي گوري رنگت',
    '👩🏿‍❤‍👩🏽' => 'دل سان جوڙو: عورت، عورت، ڪارو رنگ, پڪو رنگ',
    '👩🏿‍❤‍👩🏾' => 'دل سان جوڙو: عورت، عورت، ڪارو رنگ, وچولو ڪارو رنگ',
    '👩🏿‍❤‍👩🏿' => 'دل سان جوڙو: عورت، عورت, ڪارو رنگ',
    '👩🏻‍🐰‍👩🏼' => 'خرگوش جي ڪنن وري عورت: گوري رنگت، وچولي گوري رنگت',
    '👩🏻‍🐰‍👩🏽' => 'خرگوش جي ڪنن وري عورت: گوري رنگت، پڪو رنگ',
    '👩🏻‍🐰‍👩🏾' => 'خرگوش جي ڪنن وري عورت: گوري رنگت، وچولو ڪارو رنگ',
    '👩🏻‍🐰‍👩🏿' => 'خرگوش جي ڪنن وري عورت: گوري رنگت، ڪارو رنگ',
    '👩🏼‍🐰‍👩🏻' => 'خرگوش جي ڪنن وري عورت: وچولي گوري رنگت، گوري رنگت',
    '👩🏼‍🐰‍👩🏽' => 'خرگوش جي ڪنن وري عورت: وچولي گوري رنگت، پڪو رنگ',
    '👩🏼‍🐰‍👩🏾' => 'خرگوش جي ڪنن وري عورت: وچولي گوري رنگت، وچولو ڪارو رنگ',
    '👩🏼‍🐰‍👩🏿' => 'خرگوش جي ڪنن وري عورت: وچولي گوري رنگت، ڪارو رنگ',
    '👩🏽‍🐰‍👩🏻' => 'خرگوش جي ڪنن وري عورت: پڪو رنگ، گوري رنگت',
    '👩🏽‍🐰‍👩🏼' => 'خرگوش جي ڪنن وري عورت: پڪو رنگ، وچولي گوري رنگت',
    '👩🏽‍🐰‍👩🏾' => 'خرگوش جي ڪنن وري عورت: پڪو رنگ، وچولو ڪارو رنگ',
    '👩🏽‍🐰‍👩🏿' => 'خرگوش جي ڪنن وري عورت: پڪو رنگ، ڪارو رنگ',
    '👩🏾‍🐰‍👩🏻' => 'خرگوش جي ڪنن وري عورت: وچولو ڪارو رنگ، گوري رنگت',
    '👩🏾‍🐰‍👩🏼' => 'خرگوش جي ڪنن وري عورت: وچولو ڪارو رنگ، وچولي گوري رنگت',
    '👩🏾‍🐰‍👩🏽' => 'خرگوش جي ڪنن وري عورت: وچولو ڪارو رنگ، پڪو رنگ',
    '👩🏾‍🐰‍👩🏿' => 'خرگوش جي ڪنن وري عورت: وچولو ڪارو رنگ، ڪارو رنگ',
    '👩🏿‍🐰‍👩🏻' => 'خرگوش جي ڪنن وري عورت: ڪارو رنگ، گوري رنگت',
    '👩🏿‍🐰‍👩🏼' => 'خرگوش جي ڪنن وري عورت: ڪارو رنگ، وچولي گوري رنگت',
    '👩🏿‍🐰‍👩🏽' => 'خرگوش جي ڪنن وري عورت: ڪارو رنگ، پڪو رنگ',
    '👩🏿‍🐰‍👩🏾' => 'خرگوش جي ڪنن وري عورت: ڪارو رنگ، وچولو ڪارو رنگ',
    '🧑🏻‍🤝‍🧑🏻' => 'هٿ جهليل ماڻهو: گوري رنگت',
    '🧑🏻‍🤝‍🧑🏼' => 'هٿ جهليل ماڻهو: گوري رنگت، وچولي گوري رنگت',
    '🧑🏻‍🤝‍🧑🏽' => 'هٿ جهليل ماڻهو: گوري رنگت، پڪو رنگ',
    '🧑🏻‍🤝‍🧑🏾' => 'هٿ جهليل ماڻهو: گوري رنگت، وچولو ڪارو رنگ',
    '🧑🏻‍🤝‍🧑🏿' => 'هٿ جهليل ماڻهو: گوري رنگت، ڪارو رنگ',
    '🧑🏼‍🤝‍🧑🏻' => 'هٿ جهليل ماڻهو: وچولي گوري رنگت، گوري رنگت',
    '🧑🏼‍🤝‍🧑🏼' => 'هٿ جهليل ماڻهو: وچولي گوري رنگت',
    '🧑🏼‍🤝‍🧑🏽' => 'هٿ جهليل ماڻهو: وچولي گوري رنگت، پڪو رنگ',
    '🧑🏼‍🤝‍🧑🏾' => 'هٿ جهليل ماڻهو: وچولي گوري رنگت، وچولو ڪارو رنگ',
    '🧑🏼‍🤝‍🧑🏿' => 'هٿ جهليل ماڻهو: وچولي گوري رنگت، ڪارو رنگ',
    '🧑🏽‍🤝‍🧑🏻' => 'هٿ جهليل ماڻهو: پڪو رنگ، گوري رنگت',
    '🧑🏽‍🤝‍🧑🏼' => 'هٿ جهليل ماڻهو: پڪو رنگ، وچولي گوري رنگت',
    '🧑🏽‍🤝‍🧑🏽' => 'هٿ جهليل ماڻهو: پڪو رنگ',
    '🧑🏽‍🤝‍🧑🏾' => 'هٿ جهليل ماڻهو: پڪو رنگ، وچولو ڪارو رنگ',
    '🧑🏽‍🤝‍🧑🏿' => 'هٿ جهليل ماڻهو: پڪو رنگ، ڪارو رنگ',
    '🧑🏾‍🤝‍🧑🏻' => 'هٿ جهليل ماڻهو: وچولو ڪارو رنگ، گوري رنگت',
    '🧑🏾‍🤝‍🧑🏼' => 'هٿ جهليل ماڻهو: وچولو ڪارو رنگ، وچولي گوري رنگت',
    '🧑🏾‍🤝‍🧑🏽' => 'هٿ جهليل ماڻهو: وچولو ڪارو رنگ، پڪو رنگ',
    '🧑🏾‍🤝‍🧑🏾' => 'هٿ جهليل ماڻهو: وچولو ڪارو رنگ',
    '🧑🏾‍🤝‍🧑🏿' => 'هٿ جهليل ماڻهو: وچولو ڪارو رنگ، ڪارو رنگ',
    '🧑🏿‍🤝‍🧑🏻' => 'هٿ جهليل ماڻهو: ڪارو رنگ، گوري رنگت',
    '🧑🏿‍🤝‍🧑🏼' => 'هٿ جهليل ماڻهو: ڪارو رنگ، وچولي گوري رنگت',
    '🧑🏿‍🤝‍🧑🏽' => 'هٿ جهليل ماڻهو: ڪارو رنگ، پڪو رنگ',
    '🧑🏿‍🤝‍🧑🏾' => 'هٿ جهليل ماڻهو: ڪارو رنگ، وچولو ڪارو رنگ',
    '🧑🏿‍🤝‍🧑🏿' => 'هٿ جهليل ماڻهو: ڪارو رنگ',
    '👩🏻‍🤝‍👩🏼' => 'هٿ جهليل عورتون: گوري رنگت، وچولي گوري رنگت',
    '👩🏻‍🤝‍👩🏽' => 'هٿ جهليل عورتون: گوري رنگت، پڪو رنگ',
    '👩🏻‍🤝‍👩🏾' => 'هٿ جهليل عورتون: گوري رنگت، وچولو ڪارو رنگ',
    '👩🏻‍🤝‍👩🏿' => 'هٿ جهليل عورتون: گوري رنگت، ڪارو رنگ',
    '👩🏼‍🤝‍👩🏻' => 'هٿ جهليل عورتون: وچولي گوري رنگت، گوري رنگت',
    '👩🏼‍🤝‍👩🏽' => 'هٿ جهليل عورتون: وچولي گوري رنگت، پڪو رنگ',
    '👩🏼‍🤝‍👩🏾' => 'هٿ جهليل عورتون: وچولي گوري رنگت، وچولو ڪارو رنگ',
    '👩🏼‍🤝‍👩🏿' => 'هٿ جهليل عورتون: وچولي گوري رنگت، ڪارو رنگ',
    '👩🏽‍🤝‍👩🏻' => 'هٿ جهليل عورتون: پڪو رنگ، گوري رنگت',
    '👩🏽‍🤝‍👩🏼' => 'هٿ جهليل عورتون: پڪو رنگ، وچولي گوري رنگت',
    '👩🏽‍🤝‍👩🏾' => 'هٿ جهليل عورتون: پڪو رنگ، وچولو ڪارو رنگ',
    '👩🏽‍🤝‍👩🏿' => 'هٿ جهليل عورتون: پڪو رنگ، ڪارو رنگ',
    '👩🏾‍🤝‍👩🏻' => 'هٿ جهليل عورتون: وچولو ڪارو رنگ، گوري رنگت',
    '👩🏾‍🤝‍👩🏼' => 'هٿ جهليل عورتون: وچولو ڪارو رنگ، وچولي گوري رنگت',
    '👩🏾‍🤝‍👩🏽' => 'هٿ جهليل عورتون: وچولو ڪارو رنگ، پڪو رنگ',
    '👩🏾‍🤝‍👩🏿' => 'هٿ جهليل عورتون: وچولو ڪارو رنگ، ڪارو رنگ',
    '👩🏿‍🤝‍👩🏻' => 'هٿ جهليل عورتون: ڪارو رنگ، گوري رنگت',
    '👩🏿‍🤝‍👩🏼' => 'هٿ جهليل عورتون: ڪارو رنگ، وچولي گوري رنگت',
    '👩🏿‍🤝‍👩🏽' => 'هٿ جهليل عورتون: ڪارو رنگ، پڪو رنگ',
    '👩🏿‍🤝‍👩🏾' => 'هٿ جهليل عورتون: ڪارو رنگ، وچولو ڪارو رنگ',
    '👩🏻‍🤝‍👨🏼' => 'هٿ جهليندي مرد ۽ عورت: گوري رنگت، وچولي گوري رنگت',
    '👩🏻‍🤝‍👨🏽' => 'هٿ جهليندي مرد ۽ عورت: گوري رنگت، پڪو رنگ',
    '👩🏻‍🤝‍👨🏾' => 'هٿ جهليندي مرد ۽ عورت: گوري رنگت، وچولو ڪارو رنگ',
    '👩🏻‍🤝‍👨🏿' => 'هٿ جهليندي مرد ۽ عورت: گوري رنگت، ڪارو رنگ',
    '👩🏼‍🤝‍👨🏻' => 'هٿ جهليندي مرد ۽ عورت: وچولي گوري رنگت، گوري رنگت',
    '👩🏼‍🤝‍👨🏽' => 'هٿ جهليندي مرد ۽ عورت: وچولي گوري رنگت، پڪو رنگ',
    '👩🏼‍🤝‍👨🏾' => 'هٿ جهليندي مرد ۽ عورت: وچولي گوري رنگت، وچولو ڪارو رنگ',
    '👩🏼‍🤝‍👨🏿' => 'هٿ جهليندي مرد ۽ عورت: وچولي گوري رنگت، ڪارو رنگ',
    '👩🏽‍🤝‍👨🏻' => 'هٿ جهليندي مرد ۽ عورت: پڪو رنگ، گوري رنگت',
    '👩🏽‍🤝‍👨🏼' => 'هٿ جهليندي مرد ۽ عورت: پڪو رنگ، وچولي گوري رنگت',
    '👩🏽‍🤝‍👨🏾' => 'هٿ جهليندي مرد ۽ عورت: پڪو رنگ، وچولو ڪارو رنگ',
    '👩🏽‍🤝‍👨🏿' => 'هٿ جهليندي مرد ۽ عورت: پڪو رنگ، ڪارو رنگ',
    '👩🏾‍🤝‍👨🏻' => 'هٿ جهليندي مرد ۽ عورت: وچولو ڪارو رنگ، گوري رنگت',
    '👩🏾‍🤝‍👨🏼' => 'هٿ جهليندي مرد ۽ عورت: وچولو ڪارو رنگ، وچولي گوري رنگت',
    '👩🏾‍🤝‍👨🏽' => 'هٿ جهليندي مرد ۽ عورت: وچولو ڪارو رنگ، پڪو رنگ',
    '👩🏾‍🤝‍👨🏿' => 'هٿ جهليندي مرد ۽ عورت: وچولو ڪارو رنگ، ڪارو رنگ',
    '👩🏿‍🤝‍👨🏻' => 'هٿ جهليندي مرد ۽ عورت: ڪارو رنگ، گوري رنگت',
    '👩🏿‍🤝‍👨🏼' => 'هٿ جهليندي مرد ۽ عورت: ڪارو رنگ، وچولي گوري رنگت',
    '👩🏿‍🤝‍👨🏽' => 'هٿ جهليندي مرد ۽ عورت: ڪارو رنگ، پڪو رنگ',
    '👩🏿‍🤝‍👨🏾' => 'هٿ جهليندي مرد ۽ عورت: ڪارو رنگ، وچولو ڪارو رنگ',
    '👨🏻‍🤝‍👨🏼' => 'ٻه مرد هٿ جهليندي: گوري رنگت، وچولي گوري رنگت',
    '👨🏻‍🤝‍👨🏽' => 'ٻه مرد هٿ جهليندي: گوري رنگت، پڪو رنگ',
    '👨🏻‍🤝‍👨🏾' => 'ٻه مرد هٿ جهليندي: گوري رنگت، وچولو ڪارو رنگ',
    '👨🏻‍🤝‍👨🏿' => 'ٻه مرد هٿ جهليندي: گوري رنگت، ڪارو رنگ',
    '👨🏼‍🤝‍👨🏻' => 'ٻه مرد هٿ جهليندي: وچولي گوري رنگت، گوري رنگت',
    '👨🏼‍🤝‍👨🏽' => 'ٻه مرد هٿ جهليندي: وچولي گوري رنگت، پڪو رنگ',
    '👨🏼‍🤝‍👨🏾' => 'ٻه مرد هٿ جهليندي: وچولي گوري رنگت، وچولو ڪارو رنگ',
    '👨🏼‍🤝‍👨🏿' => 'ٻه مرد هٿ جهليندي: وچولي گوري رنگت، ڪارو رنگ',
    '👨🏽‍🤝‍👨🏻' => 'ٻه مرد هٿ جهليندي: پڪو رنگ، گوري رنگت',
    '👨🏽‍🤝‍👨🏼' => 'ٻه مرد هٿ جهليندي: پڪو رنگ، وچولي گوري رنگت',
    '👨🏽‍🤝‍👨🏾' => 'ٻه مرد هٿ جهليندي: پڪو رنگ، وچولو ڪارو رنگ',
    '👨🏽‍🤝‍👨🏿' => 'ٻه مرد هٿ جهليندي: پڪو رنگ، ڪارو رنگ',
    '👨🏾‍🤝‍👨🏻' => 'ٻه مرد هٿ جهليندي: وچولو ڪارو رنگ، گوري رنگت',
    '👨🏾‍🤝‍👨🏼' => 'ٻه مرد هٿ جهليندي: وچولو ڪارو رنگ، وچولي گوري رنگت',
    '👨🏾‍🤝‍👨🏽' => 'ٻه مرد هٿ جهليندي: وچولو ڪارو رنگ، پڪو رنگ',
    '👨🏾‍🤝‍👨🏿' => 'ٻه مرد هٿ جهليندي: وچولو ڪارو رنگ، ڪارو رنگ',
    '👨🏿‍🤝‍👨🏻' => 'ٻه مرد هٿ جهليندي: ڪارو رنگ، گوري رنگت',
    '👨🏿‍🤝‍👨🏼' => 'ٻه مرد هٿ جهليندي: ڪارو رنگ، وچولي گوري رنگت',
    '👨🏿‍🤝‍👨🏽' => 'ٻه مرد هٿ جهليندي: ڪارو رنگ، پڪو رنگ',
    '👨🏿‍🤝‍👨🏾' => 'ٻه مرد هٿ جهليندي: ڪارو رنگ، وچولو ڪارو رنگ',
    '👩‍❤‍💋‍👨' => 'چمي: عورت، ماڻهو',
    '👨‍❤‍💋‍👨' => 'چمي: ماڻهو، ماڻهو',
    '👩‍❤‍💋‍👩' => 'چمي: عورت، عورت',
    '👨‍👩‍👧‍👦' => 'ڪٽنب: ماڻهو، عورت، ڇوڪري, ڇوڪرو',
    '👨‍👩‍👦‍👦' => 'ڪٽنب: ماڻهو، عورت، ڇوڪرو, ڇوڪرو',
    '👨‍👩‍👧‍👧' => 'ڪٽنب: ماڻهو، عورت، ڇوڪري, ڇوڪري',
    '👨‍👨‍👧‍👦' => 'ڪٽنب: ماڻهو، ماڻهو، ڇوڪري, ڇوڪرو',
    '👨‍👨‍👦‍👦' => 'ڪٽنب: ماڻهو، ماڻهو، ڇوڪرو, ڇوڪرو',
    '👨‍👨‍👧‍👧' => 'ڪٽنب: ماڻهو، ماڻهو، ڇوڪري, ڇوڪري',
    '👩‍👩‍👧‍👦' => 'ڪٽنب: عورت، عورت، ڇوڪري, ڇوڪرو',
    '👩‍👩‍👦‍👦' => 'ڪٽنب: عورت، عورت، ڇوڪرو, ڇوڪرو',
    '👩‍👩‍👧‍👧' => 'ڪٽنب: عورت، عورت، ڇوڪري, ڇوڪري',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'جهنڊو: انگلينڊ',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'جهنڊو: اسڪاٽلينڊ',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'جهنڊو: ويلز',
    '🧑‍🧑‍🧒‍🧒' => 'ڪٽنب: بالغ، بالغ، ٻار، ٻار',
    '🚶🏻‍♀‍➡' => 'عورت سير ڪندي: گوري رنگت، ساڄي طرف منهن',
    '🚶🏼‍♀‍➡' => 'عورت سير ڪندي: وچولي گوري رنگت، ساڄي طرف منهن',
    '🚶🏽‍♀‍➡' => 'عورت سير ڪندي: پڪو رنگ، ساڄي طرف منهن',
    '🚶🏾‍♀‍➡' => 'عورت سير ڪندي: وچولو ڪارو رنگ، ساڄي طرف منهن',
    '🚶🏿‍♀‍➡' => 'عورت سير ڪندي: ڪارو رنگ، ساڄي طرف منهن',
    '🚶🏻‍♂‍➡' => 'مرد سير ڪندي: گوري رنگت، ساڄي طرف منهن',
    '🚶🏼‍♂‍➡' => 'مرد سير ڪندي: وچولي گوري رنگت، ساڄي طرف منهن',
    '🚶🏽‍♂‍➡' => 'مرد سير ڪندي: پڪو رنگ، ساڄي طرف منهن',
    '🚶🏾‍♂‍➡' => 'مرد سير ڪندي: وچولو ڪارو رنگ، ساڄي طرف منهن',
    '🚶🏿‍♂‍➡' => 'مرد سير ڪندي: ڪارو رنگ، ساڄي طرف منهن',
    '🧎🏻‍♀‍➡' => 'گوڏا کوڙيل عورت: گوري رنگت، ساڄي طرف منهن',
    '🧎🏼‍♀‍➡' => 'گوڏا کوڙيل عورت: وچولي گوري رنگت، ساڄي طرف منهن',
    '🧎🏽‍♀‍➡' => 'گوڏا کوڙيل عورت: پڪو رنگ، ساڄي طرف منهن',
    '🧎🏾‍♀‍➡' => 'گوڏا کوڙيل عورت: وچولو ڪارو رنگ، ساڄي طرف منهن',
    '🧎🏿‍♀‍➡' => 'گوڏا کوڙيل عورت: ڪارو رنگ، ساڄي طرف منهن',
    '🧎🏻‍♂‍➡' => 'گوڏا کوڙيل ماڻهو: گوري رنگت، ساڄي طرف منهن',
    '🧎🏼‍♂‍➡' => 'گوڏا کوڙيل ماڻهو: وچولي گوري رنگت، ساڄي طرف منهن',
    '🧎🏽‍♂‍➡' => 'گوڏا کوڙيل ماڻهو: پڪو رنگ، ساڄي طرف منهن',
    '🧎🏾‍♂‍➡' => 'گوڏا کوڙيل ماڻهو: وچولو ڪارو رنگ، ساڄي طرف منهن',
    '🧎🏿‍♂‍➡' => 'گوڏا کوڙيل ماڻهو: ڪارو رنگ، ساڄي طرف منهن',
    '🧑🏻‍🦯‍➡' => 'پروبنگ لٺ وارو ماڻهو: گوري رنگت، ساڄي طرف منهن',
    '🧑🏼‍🦯‍➡' => 'پروبنگ لٺ وارو ماڻهو: وچولي گوري رنگت، ساڄي طرف منهن',
    '🧑🏽‍🦯‍➡' => 'پروبنگ لٺ وارو ماڻهو: پڪو رنگ، ساڄي طرف منهن',
    '🧑🏾‍🦯‍➡' => 'پروبنگ لٺ وارو ماڻهو: وچولو ڪارو رنگ، ساڄي طرف منهن',
    '🧑🏿‍🦯‍➡' => 'پروبنگ لٺ وارو ماڻهو: ڪارو رنگ، ساڄي طرف منهن',
    '👨🏻‍🦯‍➡' => 'پروبنگ ڪين سان ماڻهو: گوري رنگت، ساڄي طرف منهن',
    '👨🏼‍🦯‍➡' => 'پروبنگ ڪين سان ماڻهو: وچولي گوري رنگت، ساڄي طرف منهن',
    '👨🏽‍🦯‍➡' => 'پروبنگ ڪين سان ماڻهو: پڪو رنگ، ساڄي طرف منهن',
    '👨🏾‍🦯‍➡' => 'پروبنگ ڪين سان ماڻهو: وچولو ڪارو رنگ، ساڄي طرف منهن',
    '👨🏿‍🦯‍➡' => 'پروبنگ ڪين سان ماڻهو: ڪارو رنگ، ساڄي طرف منهن',
    '👩🏻‍🦯‍➡' => 'پروبنگ ڪين سان عورت: گوري رنگت، ساڄي طرف منهن',
    '👩🏼‍🦯‍➡' => 'پروبنگ ڪين سان عورت: وچولي گوري رنگت، ساڄي طرف منهن',
    '👩🏽‍🦯‍➡' => 'پروبنگ ڪين سان عورت: پڪو رنگ، ساڄي طرف منهن',
    '👩🏾‍🦯‍➡' => 'پروبنگ ڪين سان عورت: وچولو ڪارو رنگ، ساڄي طرف منهن',
    '👩🏿‍🦯‍➡' => 'پروبنگ ڪين سان عورت: ڪارو رنگ، ساڄي طرف منهن',
    '🧑🏻‍🦼‍➡' => 'موٽر واري وهيل چيئر تي شخص: گوري رنگت، ساڄي طرف منهن',
    '🧑🏼‍🦼‍➡' => 'موٽر واري وهيل چيئر تي شخص: وچولي گوري رنگت، ساڄي طرف منهن',
    '🧑🏽‍🦼‍➡' => 'موٽر واري وهيل چيئر تي شخص: پڪو رنگ، ساڄي طرف منهن',
    '🧑🏾‍🦼‍➡' => 'موٽر واري وهيل چيئر تي شخص: وچولو ڪارو رنگ، ساڄي طرف منهن',
    '🧑🏿‍🦼‍➡' => 'موٽر واري وهيل چيئر تي شخص: ڪارو رنگ، ساڄي طرف منهن',
    '👨🏻‍🦼‍➡' => 'موٽر واري وهيل چيئر ۾ ماڻهو: گوري رنگت، ساڄي طرف منهن',
    '👨🏼‍🦼‍➡' => 'موٽر واري وهيل چيئر ۾ ماڻهو: وچولي گوري رنگت، ساڄي طرف منهن',
    '👨🏽‍🦼‍➡' => 'موٽر واري وهيل چيئر ۾ ماڻهو: پڪو رنگ، ساڄي طرف منهن',
    '👨🏾‍🦼‍➡' => 'موٽر واري وهيل چيئر ۾ ماڻهو: وچولو ڪارو رنگ، ساڄي طرف منهن',
    '👨🏿‍🦼‍➡' => 'موٽر واري وهيل چيئر ۾ ماڻهو: ڪارو رنگ، ساڄي طرف منهن',
    '👩🏻‍🦼‍➡' => 'موٽر واري ڦيٿائين ڪرسي تي عورت: گوري رنگت، ساڄي طرف منهن',
    '👩🏼‍🦼‍➡' => 'موٽر واري ڦيٿائين ڪرسي تي عورت: وچولي گوري رنگت، ساڄي طرف منهن',
    '👩🏽‍🦼‍➡' => 'موٽر واري ڦيٿائين ڪرسي تي عورت: پڪو رنگ، ساڄي طرف منهن',
    '👩🏾‍🦼‍➡' => 'موٽر واري ڦيٿائين ڪرسي تي عورت: وچولو ڪارو رنگ، ساڄي طرف منهن',
    '👩🏿‍🦼‍➡' => 'موٽر واري ڦيٿائين ڪرسي تي عورت: ڪارو رنگ، ساڄي طرف منهن',
    '🧑🏻‍🦽‍➡' => 'ماڻھو دستي ويل چيئر تي: گوري رنگت، ساڄي طرف منهن',
    '🧑🏼‍🦽‍➡' => 'ماڻھو دستي ويل چيئر تي: وچولي گوري رنگت، ساڄي طرف منهن',
    '🧑🏽‍🦽‍➡' => 'ماڻھو دستي ويل چيئر تي: پڪو رنگ، ساڄي طرف منهن',
    '🧑🏾‍🦽‍➡' => 'ماڻھو دستي ويل چيئر تي: وچولو ڪارو رنگ، ساڄي طرف منهن',
    '🧑🏿‍🦽‍➡' => 'ماڻھو دستي ويل چيئر تي: ڪارو رنگ، ساڄي طرف منهن',
    '👨🏻‍🦽‍➡' => 'دستي وهيل چيئر ۾ ماڻهو: گوري رنگت، ساڄي طرف منهن',
    '👨🏼‍🦽‍➡' => 'دستي وهيل چيئر ۾ ماڻهو: وچولي گوري رنگت، ساڄي طرف منهن',
    '👨🏽‍🦽‍➡' => 'دستي وهيل چيئر ۾ ماڻهو: پڪو رنگ، ساڄي طرف منهن',
    '👨🏾‍🦽‍➡' => 'دستي وهيل چيئر ۾ ماڻهو: وچولو ڪارو رنگ، ساڄي طرف منهن',
    '👨🏿‍🦽‍➡' => 'دستي وهيل چيئر ۾ ماڻهو: ڪارو رنگ، ساڄي طرف منهن',
    '👩🏻‍🦽‍➡' => 'دستي وهيل چيئر ۾ عورت: گوري رنگت، ساڄي طرف منهن',
    '👩🏼‍🦽‍➡' => 'دستي وهيل چيئر ۾ عورت: وچولي گوري رنگت، ساڄي طرف منهن',
    '👩🏽‍🦽‍➡' => 'دستي وهيل چيئر ۾ عورت: پڪو رنگ، ساڄي طرف منهن',
    '👩🏾‍🦽‍➡' => 'دستي وهيل چيئر ۾ عورت: وچولو ڪارو رنگ، ساڄي طرف منهن',
    '👩🏿‍🦽‍➡' => 'دستي وهيل چيئر ۾ عورت: ڪارو رنگ، ساڄي طرف منهن',
    '🏃🏻‍♀‍➡' => 'ڊوڙندي عورت: گوري رنگت، ساڄي طرف منهن',
    '🏃🏼‍♀‍➡' => 'ڊوڙندي عورت: وچولي گوري رنگت، ساڄي طرف منهن',
    '🏃🏽‍♀‍➡' => 'ڊوڙندي عورت: پڪو رنگ، ساڄي طرف منهن',
    '🏃🏾‍♀‍➡' => 'ڊوڙندي عورت: وچولو ڪارو رنگ، ساڄي طرف منهن',
    '🏃🏿‍♀‍➡' => 'ڊوڙندي عورت: ڪارو رنگ، ساڄي طرف منهن',
    '🏃🏻‍♂‍➡' => 'مرد ڊوڙندي: گوري رنگت، ساڄي طرف منهن',
    '🏃🏼‍♂‍➡' => 'مرد ڊوڙندي: وچولي گوري رنگت، ساڄي طرف منهن',
    '🏃🏽‍♂‍➡' => 'مرد ڊوڙندي: پڪو رنگ، ساڄي طرف منهن',
    '🏃🏾‍♂‍➡' => 'مرد ڊوڙندي: وچولو ڪارو رنگ، ساڄي طرف منهن',
    '🏃🏿‍♂‍➡' => 'مرد ڊوڙندي: ڪارو رنگ، ساڄي طرف منهن',
    '🫱🏻‍🫲🏼' => 'هٿ ملائڻ: گوري رنگت، وچولي گوري رنگت',
    '🫱🏻‍🫲🏽' => 'هٿ ملائڻ: گوري رنگت، پڪو رنگ',
    '🫱🏻‍🫲🏾' => 'هٿ ملائڻ: گوري رنگت، وچولو ڪارو رنگ',
    '🫱🏻‍🫲🏿' => 'هٿ ملائڻ: گوري رنگت، ڪارو رنگ',
    '🫱🏼‍🫲🏻' => 'هٿ ملائڻ: وچولي گوري رنگت، گوري رنگت',
    '🫱🏼‍🫲🏽' => 'هٿ ملائڻ: وچولي گوري رنگت، پڪو رنگ',
    '🫱🏼‍🫲🏾' => 'هٿ ملائڻ: وچولي گوري رنگت، وچولو ڪارو رنگ',
    '🫱🏼‍🫲🏿' => 'هٿ ملائڻ: وچولي گوري رنگت، ڪارو رنگ',
    '🫱🏽‍🫲🏻' => 'هٿ ملائڻ: پڪو رنگ، گوري رنگت',
    '🫱🏽‍🫲🏼' => 'هٿ ملائڻ: پڪو رنگ، وچولي گوري رنگت',
    '🫱🏽‍🫲🏾' => 'هٿ ملائڻ: پڪو رنگ، وچولو ڪارو رنگ',
    '🫱🏽‍🫲🏿' => 'هٿ ملائڻ: پڪو رنگ، ڪارو رنگ',
    '🫱🏾‍🫲🏻' => 'هٿ ملائڻ: وچولو ڪارو رنگ، گوري رنگت',
    '🫱🏾‍🫲🏼' => 'هٿ ملائڻ: وچولو ڪارو رنگ، وچولي گوري رنگت',
    '🫱🏾‍🫲🏽' => 'هٿ ملائڻ: وچولو ڪارو رنگ، پڪو رنگ',
    '🫱🏾‍🫲🏿' => 'هٿ ملائڻ: وچولو ڪارو رنگ، ڪارو رنگ',
    '🫱🏿‍🫲🏻' => 'هٿ ملائڻ: ڪارو رنگ، گوري رنگت',
    '🫱🏿‍🫲🏼' => 'هٿ ملائڻ: ڪارو رنگ، وچولي گوري رنگت',
    '🫱🏿‍🫲🏽' => 'هٿ ملائڻ: ڪارو رنگ، پڪو رنگ',
    '🫱🏿‍🫲🏾' => 'هٿ ملائڻ: ڪارو رنگ، وچولو ڪارو رنگ',
    '🚶‍♀‍➡' => 'عورت سير ڪندي: ساڄي طرف منهن',
    '🚶‍♂‍➡' => 'مرد سير ڪندي: ساڄي طرف منهن',
    '🧎‍♀‍➡' => 'گوڏا کوڙيل عورت: ساڄي طرف منهن',
    '🧎‍♂‍➡' => 'گوڏا کوڙيل ماڻهو: ساڄي طرف منهن',
    '🧑‍🦯‍➡' => 'پروبنگ لٺ وارو ماڻهو: ساڄي طرف منهن',
    '👨‍🦯‍➡' => 'پروبنگ ڪين سان ماڻهو: ساڄي طرف منهن',
    '👩‍🦯‍➡' => 'پروبنگ ڪين سان عورت: ساڄي طرف منهن',
    '🧑‍🦼‍➡' => 'موٽر واري وهيل چيئر تي شخص: ساڄي طرف منهن',
    '👨‍🦼‍➡' => 'موٽر واري وهيل چيئر ۾ ماڻهو: ساڄي طرف منهن',
    '👩‍🦼‍➡' => 'موٽر واري ڦيٿائين ڪرسي تي عورت: ساڄي طرف منهن',
    '🧑‍🦽‍➡' => 'ماڻھو دستي ويل چيئر تي: ساڄي طرف منهن',
    '👨‍🦽‍➡' => 'دستي وهيل چيئر ۾ ماڻهو: ساڄي طرف منهن',
    '👩‍🦽‍➡' => 'دستي وهيل چيئر ۾ عورت: ساڄي طرف منهن',
    '🏃‍♀‍➡' => 'ڊوڙندي عورت: ساڄي طرف منهن',
    '🏃‍♂‍➡' => 'مرد ڊوڙندي: ساڄي طرف منهن',
    '👩‍❤‍👨' => 'دل سان جوڙو: عورت، ماڻهو',
    '👨‍❤‍👨' => 'دل سان جوڙو: ماڻهو، ماڻهو',
    '👩‍❤‍👩' => 'دل سان جوڙو: عورت، عورت',
    '👨‍👩‍👦' => 'ڪٽنب: ماڻهو، عورت, ڇوڪرو',
    '👨‍👩‍👧' => 'ڪٽنب: ماڻهو، عورت, ڇوڪري',
    '👨‍👨‍👦' => 'ڪٽنب: ماڻهو، ماڻهو, ڇوڪرو',
    '👨‍👨‍👧' => 'ڪٽنب: ماڻهو، ماڻهو, ڇوڪري',
    '👩‍👩‍👦' => 'ڪٽنب: عورت، عورت, ڇوڪرو',
    '👩‍👩‍👧' => 'ڪٽنب: عورت، عورت, ڇوڪري',
    '👨‍👦‍👦' => 'ڪٽنب: ماڻهو، ڇوڪرو, ڇوڪرو',
    '👨‍👧‍👦' => 'ڪٽنب: ماڻهو، ڇوڪري, ڇوڪرو',
    '👨‍👧‍👧' => 'ڪٽنب: ماڻهو، ڇوڪري, ڇوڪري',
    '👩‍👦‍👦' => 'ڪٽنب: عورت، ڇوڪرو, ڇوڪرو',
    '👩‍👧‍👦' => 'ڪٽنب: عورت، ڇوڪري, ڇوڪرو',
    '👩‍👧‍👧' => 'ڪٽنب: عورت، ڇوڪري, ڇوڪري',
    '🧑‍🤝‍🧑' => 'هٿ جهليل ماڻهو',
    '🧑‍🧑‍🧒' => 'ڪٽنب: بالغ، بالغ، ٻار',
    '🧑‍🧒‍🧒' => 'ڪٽنب: بالغ، ٻار، ٻار',
    '🧑🏻‍🦰' => 'بالغ: گوري رنگت، ڳاڙها وار',
    '🧑🏼‍🦰' => 'بالغ: وچولي گوري رنگت، ڳاڙها وار',
    '🧑🏽‍🦰' => 'بالغ: پڪو رنگ، ڳاڙها وار',
    '🧑🏾‍🦰' => 'بالغ: وچولو ڪارو رنگ، ڳاڙها وار',
    '🧑🏿‍🦰' => 'بالغ: ڪارو رنگ، ڳاڙها وار',
    '🧑🏻‍🦱' => 'بالغ: گوري رنگت، گهنگرالو وار',
    '🧑🏼‍🦱' => 'بالغ: وچولي گوري رنگت، گهنگرالو وار',
    '🧑🏽‍🦱' => 'بالغ: پڪو رنگ، گهنگرالو وار',
    '🧑🏾‍🦱' => 'بالغ: وچولو ڪارو رنگ، گهنگرالو وار',
    '🧑🏿‍🦱' => 'بالغ: ڪارو رنگ، گهنگرالو وار',
    '🧑🏻‍🦳' => 'بالغ: گوري رنگت، اڇا وار',
    '🧑🏼‍🦳' => 'بالغ: وچولي گوري رنگت، اڇا وار',
    '🧑🏽‍🦳' => 'بالغ: پڪو رنگ، اڇا وار',
    '🧑🏾‍🦳' => 'بالغ: وچولو ڪارو رنگ، اڇا وار',
    '🧑🏿‍🦳' => 'بالغ: ڪارو رنگ، اڇا وار',
    '🧑🏻‍🦲' => 'بالغ: گوري رنگت، گنجو',
    '🧑🏼‍🦲' => 'بالغ: وچولي گوري رنگت، گنجو',
    '🧑🏽‍🦲' => 'بالغ: پڪو رنگ، گنجو',
    '🧑🏾‍🦲' => 'بالغ: وچولو ڪارو رنگ، گنجو',
    '🧑🏿‍🦲' => 'بالغ: ڪارو رنگ، گنجو',
    '🧑🏻‍🩰' => 'بيلي ناچڻي: گوري رنگت',
    '🧑🏼‍🩰' => 'بيلي ناچڻي: وچولي گوري رنگت',
    '🧑🏽‍🩰' => 'بيلي ناچڻي: پڪو رنگ',
    '🧑🏾‍🩰' => 'بيلي ناچڻي: وچولو ڪارو رنگ',
    '🧑🏿‍🩰' => 'بيلي ناچڻي: ڪارو رنگ',
    '🧔🏻‍♂' => 'ماڻهو: گوري رنگت، ڏاڙهي',
    '🧔🏼‍♂' => 'ماڻهو: وچولي گوري رنگت، ڏاڙهي',
    '🧔🏽‍♂' => 'ماڻهو: پڪو رنگ، ڏاڙهي',
    '🧔🏾‍♂' => 'ماڻهو: وچولو ڪارو رنگ، ڏاڙهي',
    '🧔🏿‍♂' => 'ماڻهو: ڪارو رنگ، ڏاڙهي',
    '👱🏻‍♂' => 'ماڻهو: گوري رنگت، ڀورا وار',
    '👱🏼‍♂' => 'ماڻهو: وچولي گوري رنگت، ڀورا وار',
    '👱🏽‍♂' => 'ماڻهو: پڪو رنگ، ڀورا وار',
    '👱🏾‍♂' => 'ماڻهو: وچولو ڪارو رنگ، ڀورا وار',
    '👱🏿‍♂' => 'ماڻهو: ڪارو رنگ، ڀورا وار',
    '👨🏻‍🦰' => 'ماڻهو: گوري رنگت، ڳاڙها وار',
    '👨🏼‍🦰' => 'ماڻهو: وچولي گوري رنگت، ڳاڙها وار',
    '👨🏽‍🦰' => 'ماڻهو: پڪو رنگ، ڳاڙها وار',
    '👨🏾‍🦰' => 'ماڻهو: وچولو ڪارو رنگ، ڳاڙها وار',
    '👨🏿‍🦰' => 'ماڻهو: ڪارو رنگ، ڳاڙها وار',
    '👨🏻‍🦱' => 'ماڻهو: گوري رنگت، گهنگرالو وار',
    '👨🏼‍🦱' => 'ماڻهو: وچولي گوري رنگت، گهنگرالو وار',
    '👨🏽‍🦱' => 'ماڻهو: پڪو رنگ، گهنگرالو وار',
    '👨🏾‍🦱' => 'ماڻهو: وچولو ڪارو رنگ، گهنگرالو وار',
    '👨🏿‍🦱' => 'ماڻهو: ڪارو رنگ، گهنگرالو وار',
    '👨🏻‍🦳' => 'ماڻهو: گوري رنگت، اڇا وار',
    '👨🏼‍🦳' => 'ماڻهو: وچولي گوري رنگت، اڇا وار',
    '👨🏽‍🦳' => 'ماڻهو: پڪو رنگ، اڇا وار',
    '👨🏾‍🦳' => 'ماڻهو: وچولو ڪارو رنگ، اڇا وار',
    '👨🏿‍🦳' => 'ماڻهو: ڪارو رنگ، اڇا وار',
    '👨🏻‍🦲' => 'ماڻهو: گوري رنگت، گنجو',
    '👨🏼‍🦲' => 'ماڻهو: وچولي گوري رنگت، گنجو',
    '👨🏽‍🦲' => 'ماڻهو: پڪو رنگ، گنجو',
    '👨🏾‍🦲' => 'ماڻهو: وچولو ڪارو رنگ، گنجو',
    '👨🏿‍🦲' => 'ماڻهو: ڪارو رنگ، گنجو',
    '🧔🏻‍♀' => 'عورت: گوري رنگت، ڏاڙهي',
    '🧔🏼‍♀' => 'عورت: وچولي گوري رنگت، ڏاڙهي',
    '🧔🏽‍♀' => 'عورت: پڪو رنگ، ڏاڙهي',
    '🧔🏾‍♀' => 'عورت: وچولو ڪارو رنگ، ڏاڙهي',
    '🧔🏿‍♀' => 'عورت: ڪارو رنگ، ڏاڙهي',
    '👱🏻‍♀' => 'عورت: گوري رنگت، ڀورا وار',
    '👱🏼‍♀' => 'عورت: وچولي گوري رنگت، ڀورا وار',
    '👱🏽‍♀' => 'عورت: پڪو رنگ، ڀورا وار',
    '👱🏾‍♀' => 'عورت: وچولو ڪارو رنگ، ڀورا وار',
    '👱🏿‍♀' => 'عورت: ڪارو رنگ، ڀورا وار',
    '👩🏻‍🦰' => 'عورت: گوري رنگت، ڳاڙها وار',
    '👩🏼‍🦰' => 'عورت: وچولي گوري رنگت، ڳاڙها وار',
    '👩🏽‍🦰' => 'عورت: پڪو رنگ، ڳاڙها وار',
    '👩🏾‍🦰' => 'عورت: وچولو ڪارو رنگ، ڳاڙها وار',
    '👩🏿‍🦰' => 'عورت: ڪارو رنگ، ڳاڙها وار',
    '👩🏻‍🦱' => 'عورت: گوري رنگت، گهنگرالو وار',
    '👩🏼‍🦱' => 'عورت: وچولي گوري رنگت، گهنگرالو وار',
    '👩🏽‍🦱' => 'عورت: پڪو رنگ، گهنگرالو وار',
    '👩🏾‍🦱' => 'عورت: وچولو ڪارو رنگ، گهنگرالو وار',
    '👩🏿‍🦱' => 'عورت: ڪارو رنگ، گهنگرالو وار',
    '👩🏻‍🦳' => 'عورت: گوري رنگت، اڇا وار',
    '👩🏼‍🦳' => 'عورت: وچولي گوري رنگت، اڇا وار',
    '👩🏽‍🦳' => 'عورت: پڪو رنگ، اڇا وار',
    '👩🏾‍🦳' => 'عورت: وچولو ڪارو رنگ، اڇا وار',
    '👩🏿‍🦳' => 'عورت: ڪارو رنگ، اڇا وار',
    '👩🏻‍🦲' => 'عورت: گوري رنگت، گنجو',
    '👩🏼‍🦲' => 'عورت: وچولي گوري رنگت، گنجو',
    '👩🏽‍🦲' => 'عورت: پڪو رنگ، گنجو',
    '👩🏾‍🦲' => 'عورت: وچولو ڪارو رنگ، گنجو',
    '👩🏿‍🦲' => 'عورت: ڪارو رنگ، گنجو',
    '🙍🏻‍♂' => 'مرد پريشان: گوري رنگت',
    '🙍🏼‍♂' => 'مرد پريشان: وچولي گوري رنگت',
    '🙍🏽‍♂' => 'مرد پريشان: پڪو رنگ',
    '🙍🏾‍♂' => 'مرد پريشان: وچولو ڪارو رنگ',
    '🙍🏿‍♂' => 'مرد پريشان: ڪارو رنگ',
    '🙍🏻‍♀' => 'عورت پريشان: گوري رنگت',
    '🙍🏼‍♀' => 'عورت پريشان: وچولي گوري رنگت',
    '🙍🏽‍♀' => 'عورت پريشان: پڪو رنگ',
    '🙍🏾‍♀' => 'عورت پريشان: وچولو ڪارو رنگ',
    '🙍🏿‍♀' => 'عورت پريشان: ڪارو رنگ',
    '🙎🏻‍♂' => 'مرد ناپسند ڪندي: گوري رنگت',
    '🙎🏼‍♂' => 'مرد ناپسند ڪندي: وچولي گوري رنگت',
    '🙎🏽‍♂' => 'مرد ناپسند ڪندي: پڪو رنگ',
    '🙎🏾‍♂' => 'مرد ناپسند ڪندي: وچولو ڪارو رنگ',
    '🙎🏿‍♂' => 'مرد ناپسند ڪندي: ڪارو رنگ',
    '🙎🏻‍♀' => 'عورت ناپسند ڪندي: گوري رنگت',
    '🙎🏼‍♀' => 'عورت ناپسند ڪندي: وچولي گوري رنگت',
    '🙎🏽‍♀' => 'عورت ناپسند ڪندي: پڪو رنگ',
    '🙎🏾‍♀' => 'عورت ناپسند ڪندي: وچولو ڪارو رنگ',
    '🙎🏿‍♀' => 'عورت ناپسند ڪندي: ڪارو رنگ',
    '🙅🏻‍♂' => 'مرد نه جو اشارو ڪندي: گوري رنگت',
    '🙅🏼‍♂' => 'مرد نه جو اشارو ڪندي: وچولي گوري رنگت',
    '🙅🏽‍♂' => 'مرد نه جو اشارو ڪندي: پڪو رنگ',
    '🙅🏾‍♂' => 'مرد نه جو اشارو ڪندي: وچولو ڪارو رنگ',
    '🙅🏿‍♂' => 'مرد نه جو اشارو ڪندي: ڪارو رنگ',
    '🙅🏻‍♀' => 'عورت نه جو اشارو ڪندي: گوري رنگت',
    '🙅🏼‍♀' => 'عورت نه جو اشارو ڪندي: وچولي گوري رنگت',
    '🙅🏽‍♀' => 'عورت نه جو اشارو ڪندي: پڪو رنگ',
    '🙅🏾‍♀' => 'عورت نه جو اشارو ڪندي: وچولو ڪارو رنگ',
    '🙅🏿‍♀' => 'عورت نه جو اشارو ڪندي: ڪارو رنگ',
    '🙆🏻‍♂' => 'مرد ٺيڪ جو اشارو ڪندي: گوري رنگت',
    '🙆🏼‍♂' => 'مرد ٺيڪ جو اشارو ڪندي: وچولي گوري رنگت',
    '🙆🏽‍♂' => 'مرد ٺيڪ جو اشارو ڪندي: پڪو رنگ',
    '🙆🏾‍♂' => 'مرد ٺيڪ جو اشارو ڪندي: وچولو ڪارو رنگ',
    '🙆🏿‍♂' => 'مرد ٺيڪ جو اشارو ڪندي: ڪارو رنگ',
    '🙆🏻‍♀' => 'عورت ٺيڪ جو اشارو ڪندي: گوري رنگت',
    '🙆🏼‍♀' => 'عورت ٺيڪ جو اشارو ڪندي: وچولي گوري رنگت',
    '🙆🏽‍♀' => 'عورت ٺيڪ جو اشارو ڪندي: پڪو رنگ',
    '🙆🏾‍♀' => 'عورت ٺيڪ جو اشارو ڪندي: وچولو ڪارو رنگ',
    '🙆🏿‍♀' => 'عورت ٺيڪ جو اشارو ڪندي: ڪارو رنگ',
    '💁🏻‍♂' => 'مرد هٿ ٿپڪائيندي: گوري رنگت',
    '💁🏼‍♂' => 'مرد هٿ ٿپڪائيندي: وچولي گوري رنگت',
    '💁🏽‍♂' => 'مرد هٿ ٿپڪائيندي: پڪو رنگ',
    '💁🏾‍♂' => 'مرد هٿ ٿپڪائيندي: وچولو ڪارو رنگ',
    '💁🏿‍♂' => 'مرد هٿ ٿپڪائيندي: ڪارو رنگ',
    '💁🏻‍♀' => 'عورت هٿ ٿپڪائيندي: گوري رنگت',
    '💁🏼‍♀' => 'عورت هٿ ٿپڪائيندي: وچولي گوري رنگت',
    '💁🏽‍♀' => 'عورت هٿ ٿپڪائيندي: پڪو رنگ',
    '💁🏾‍♀' => 'عورت هٿ ٿپڪائيندي: وچولو ڪارو رنگ',
    '💁🏿‍♀' => 'عورت هٿ ٿپڪائيندي: ڪارو رنگ',
    '🙋🏻‍♂' => 'مرد هٿ مٿي ڪندي: گوري رنگت',
    '🙋🏼‍♂' => 'مرد هٿ مٿي ڪندي: وچولي گوري رنگت',
    '🙋🏽‍♂' => 'مرد هٿ مٿي ڪندي: پڪو رنگ',
    '🙋🏾‍♂' => 'مرد هٿ مٿي ڪندي: وچولو ڪارو رنگ',
    '🙋🏿‍♂' => 'مرد هٿ مٿي ڪندي: ڪارو رنگ',
    '🙋🏻‍♀' => 'عورت هٿ مٿي ڪندي: گوري رنگت',
    '🙋🏼‍♀' => 'عورت هٿ مٿي ڪندي: وچولي گوري رنگت',
    '🙋🏽‍♀' => 'عورت هٿ مٿي ڪندي: پڪو رنگ',
    '🙋🏾‍♀' => 'عورت هٿ مٿي ڪندي: وچولو ڪارو رنگ',
    '🙋🏿‍♀' => 'عورت هٿ مٿي ڪندي: ڪارو رنگ',
    '🧏🏻‍♂' => 'ٻوڙو ماڻهو: گوري رنگت',
    '🧏🏼‍♂' => 'ٻوڙو ماڻهو: وچولي گوري رنگت',
    '🧏🏽‍♂' => 'ٻوڙو ماڻهو: پڪو رنگ',
    '🧏🏾‍♂' => 'ٻوڙو ماڻهو: وچولو ڪارو رنگ',
    '🧏🏿‍♂' => 'ٻوڙو ماڻهو: ڪارو رنگ',
    '🧏🏻‍♀' => 'ٻوڙي عورت: گوري رنگت',
    '🧏🏼‍♀' => 'ٻوڙي عورت: وچولي گوري رنگت',
    '🧏🏽‍♀' => 'ٻوڙي عورت: پڪو رنگ',
    '🧏🏾‍♀' => 'ٻوڙي عورت: وچولو ڪارو رنگ',
    '🧏🏿‍♀' => 'ٻوڙي عورت: ڪارو رنگ',
    '🙇🏻‍♂' => 'مرد جهڪندي: گوري رنگت',
    '🙇🏼‍♂' => 'مرد جهڪندي: وچولي گوري رنگت',
    '🙇🏽‍♂' => 'مرد جهڪندي: پڪو رنگ',
    '🙇🏾‍♂' => 'مرد جهڪندي: وچولو ڪارو رنگ',
    '🙇🏿‍♂' => 'مرد جهڪندي: ڪارو رنگ',
    '🙇🏻‍♀' => 'عورت جھڪندي: گوري رنگت',
    '🙇🏼‍♀' => 'عورت جھڪندي: وچولي گوري رنگت',
    '🙇🏽‍♀' => 'عورت جھڪندي: پڪو رنگ',
    '🙇🏾‍♀' => 'عورت جھڪندي: وچولو ڪارو رنگ',
    '🙇🏿‍♀' => 'عورت جھڪندي: ڪارو رنگ',
    '🤦🏻‍♂' => 'ماڻهو جو نراڙ تي هٿ ڏيڻ: گوري رنگت',
    '🤦🏼‍♂' => 'ماڻهو جو نراڙ تي هٿ ڏيڻ: وچولي گوري رنگت',
    '🤦🏽‍♂' => 'ماڻهو جو نراڙ تي هٿ ڏيڻ: پڪو رنگ',
    '🤦🏾‍♂' => 'ماڻهو جو نراڙ تي هٿ ڏيڻ: وچولو ڪارو رنگ',
    '🤦🏿‍♂' => 'ماڻهو جو نراڙ تي هٿ ڏيڻ: ڪارو رنگ',
    '🤦🏻‍♀' => 'عورت جو نراڙ تي هٿ ڏيڻ: گوري رنگت',
    '🤦🏼‍♀' => 'عورت جو نراڙ تي هٿ ڏيڻ: وچولي گوري رنگت',
    '🤦🏽‍♀' => 'عورت جو نراڙ تي هٿ ڏيڻ: پڪو رنگ',
    '🤦🏾‍♀' => 'عورت جو نراڙ تي هٿ ڏيڻ: وچولو ڪارو رنگ',
    '🤦🏿‍♀' => 'عورت جو نراڙ تي هٿ ڏيڻ: ڪارو رنگ',
    '🤷🏻‍♂' => 'مرد اچڪائيندي: گوري رنگت',
    '🤷🏼‍♂' => 'مرد اچڪائيندي: وچولي گوري رنگت',
    '🤷🏽‍♂' => 'مرد اچڪائيندي: پڪو رنگ',
    '🤷🏾‍♂' => 'مرد اچڪائيندي: وچولو ڪارو رنگ',
    '🤷🏿‍♂' => 'مرد اچڪائيندي: ڪارو رنگ',
    '🤷🏻‍♀' => 'عورت اچڪائيندي: گوري رنگت',
    '🤷🏼‍♀' => 'عورت اچڪائيندي: وچولي گوري رنگت',
    '🤷🏽‍♀' => 'عورت اچڪائيندي: پڪو رنگ',
    '🤷🏾‍♀' => 'عورت اچڪائيندي: وچولو ڪارو رنگ',
    '🤷🏿‍♀' => 'عورت اچڪائيندي: ڪارو رنگ',
    '🧑🏻‍⚕' => 'هيلٿ ورڪر: گوري رنگت',
    '🧑🏼‍⚕' => 'هيلٿ ورڪر: وچولي گوري رنگت',
    '🧑🏽‍⚕' => 'هيلٿ ورڪر: پڪو رنگ',
    '🧑🏾‍⚕' => 'هيلٿ ورڪر: وچولو ڪارو رنگ',
    '🧑🏿‍⚕' => 'هيلٿ ورڪر: ڪارو رنگ',
    '👨🏻‍⚕' => 'ماڻهو صحت خدمتگار: گوري رنگت',
    '👨🏼‍⚕' => 'ماڻهو صحت خدمتگار: وچولي گوري رنگت',
    '👨🏽‍⚕' => 'ماڻهو صحت خدمتگار: پڪو رنگ',
    '👨🏾‍⚕' => 'ماڻهو صحت خدمتگار: وچولو ڪارو رنگ',
    '👨🏿‍⚕' => 'ماڻهو صحت خدمتگار: ڪارو رنگ',
    '👩🏻‍⚕' => 'عورت صحت خدمتگار: گوري رنگت',
    '👩🏼‍⚕' => 'عورت صحت خدمتگار: وچولي گوري رنگت',
    '👩🏽‍⚕' => 'عورت صحت خدمتگار: پڪو رنگ',
    '👩🏾‍⚕' => 'عورت صحت خدمتگار: وچولو ڪارو رنگ',
    '👩🏿‍⚕' => 'عورت صحت خدمتگار: ڪارو رنگ',
    '🧑🏻‍🎓' => 'شاگرد: گوري رنگت',
    '🧑🏼‍🎓' => 'شاگرد: وچولي گوري رنگت',
    '🧑🏽‍🎓' => 'شاگرد: پڪو رنگ',
    '🧑🏾‍🎓' => 'شاگرد: وچولو ڪارو رنگ',
    '🧑🏿‍🎓' => 'شاگرد: ڪارو رنگ',
    '👨🏻‍🎓' => 'مرد شاگرد: گوري رنگت',
    '👨🏼‍🎓' => 'مرد شاگرد: وچولي گوري رنگت',
    '👨🏽‍🎓' => 'مرد شاگرد: پڪو رنگ',
    '👨🏾‍🎓' => 'مرد شاگرد: وچولو ڪارو رنگ',
    '👨🏿‍🎓' => 'مرد شاگرد: ڪارو رنگ',
    '👩🏻‍🎓' => 'عورت شاگرد: گوري رنگت',
    '👩🏼‍🎓' => 'عورت شاگرد: وچولي گوري رنگت',
    '👩🏽‍🎓' => 'عورت شاگرد: پڪو رنگ',
    '👩🏾‍🎓' => 'عورت شاگرد: وچولو ڪارو رنگ',
    '👩🏿‍🎓' => 'عورت شاگرد: ڪارو رنگ',
    '🧑🏻‍🏫' => 'استاد: گوري رنگت',
    '🧑🏼‍🏫' => 'استاد: وچولي گوري رنگت',
    '🧑🏽‍🏫' => 'استاد: پڪو رنگ',
    '🧑🏾‍🏫' => 'استاد: وچولو ڪارو رنگ',
    '🧑🏿‍🏫' => 'استاد: ڪارو رنگ',
    '👨🏻‍🏫' => 'مرد استاد: گوري رنگت',
    '👨🏼‍🏫' => 'مرد استاد: وچولي گوري رنگت',
    '👨🏽‍🏫' => 'مرد استاد: پڪو رنگ',
    '👨🏾‍🏫' => 'مرد استاد: وچولو ڪارو رنگ',
    '👨🏿‍🏫' => 'مرد استاد: ڪارو رنگ',
    '👩🏻‍🏫' => 'عورت استاد: گوري رنگت',
    '👩🏼‍🏫' => 'عورت استاد: وچولي گوري رنگت',
    '👩🏽‍🏫' => 'عورت استاد: پڪو رنگ',
    '👩🏾‍🏫' => 'عورت استاد: وچولو ڪارو رنگ',
    '👩🏿‍🏫' => 'عورت استاد: ڪارو رنگ',
    '🧑🏻‍⚖' => 'جج: گوري رنگت',
    '🧑🏼‍⚖' => 'جج: وچولي گوري رنگت',
    '🧑🏽‍⚖' => 'جج: پڪو رنگ',
    '🧑🏾‍⚖' => 'جج: وچولو ڪارو رنگ',
    '🧑🏿‍⚖' => 'جج: ڪارو رنگ',
    '👨🏻‍⚖' => 'مرد جج: گوري رنگت',
    '👨🏼‍⚖' => 'مرد جج: وچولي گوري رنگت',
    '👨🏽‍⚖' => 'مرد جج: پڪو رنگ',
    '👨🏾‍⚖' => 'مرد جج: وچولو ڪارو رنگ',
    '👨🏿‍⚖' => 'مرد جج: ڪارو رنگ',
    '👩🏻‍⚖' => 'عورت جج: گوري رنگت',
    '👩🏼‍⚖' => 'عورت جج: وچولي گوري رنگت',
    '👩🏽‍⚖' => 'عورت جج: پڪو رنگ',
    '👩🏾‍⚖' => 'عورت جج: وچولو ڪارو رنگ',
    '👩🏿‍⚖' => 'عورت جج: ڪارو رنگ',
    '🧑🏻‍🌾' => 'هاري: گوري رنگت',
    '🧑🏼‍🌾' => 'هاري: وچولي گوري رنگت',
    '🧑🏽‍🌾' => 'هاري: پڪو رنگ',
    '🧑🏾‍🌾' => 'هاري: وچولو ڪارو رنگ',
    '🧑🏿‍🌾' => 'هاري: ڪارو رنگ',
    '👨🏻‍🌾' => 'مرد هاري: گوري رنگت',
    '👨🏼‍🌾' => 'مرد هاري: وچولي گوري رنگت',
    '👨🏽‍🌾' => 'مرد هاري: پڪو رنگ',
    '👨🏾‍🌾' => 'مرد هاري: وچولو ڪارو رنگ',
    '👨🏿‍🌾' => 'مرد هاري: ڪارو رنگ',
    '👩🏻‍🌾' => 'عورت هاري: گوري رنگت',
    '👩🏼‍🌾' => 'عورت هاري: وچولي گوري رنگت',
    '👩🏽‍🌾' => 'عورت هاري: پڪو رنگ',
    '👩🏾‍🌾' => 'عورت هاري: وچولو ڪارو رنگ',
    '👩🏿‍🌾' => 'عورت هاري: ڪارو رنگ',
    '🧑🏻‍🍳' => 'باورچي: گوري رنگت',
    '🧑🏼‍🍳' => 'باورچي: وچولي گوري رنگت',
    '🧑🏽‍🍳' => 'باورچي: پڪو رنگ',
    '🧑🏾‍🍳' => 'باورچي: وچولو ڪارو رنگ',
    '🧑🏿‍🍳' => 'باورچي: ڪارو رنگ',
    '👨🏻‍🍳' => 'مرد بورچي: گوري رنگت',
    '👨🏼‍🍳' => 'مرد بورچي: وچولي گوري رنگت',
    '👨🏽‍🍳' => 'مرد بورچي: پڪو رنگ',
    '👨🏾‍🍳' => 'مرد بورچي: وچولو ڪارو رنگ',
    '👨🏿‍🍳' => 'مرد بورچي: ڪارو رنگ',
    '👩🏻‍🍳' => 'عورت بورچي: گوري رنگت',
    '👩🏼‍🍳' => 'عورت بورچي: وچولي گوري رنگت',
    '👩🏽‍🍳' => 'عورت بورچي: پڪو رنگ',
    '👩🏾‍🍳' => 'عورت بورچي: وچولو ڪارو رنگ',
    '👩🏿‍🍳' => 'عورت بورچي: ڪارو رنگ',
    '🧑🏻‍🔧' => 'مستري: گوري رنگت',
    '🧑🏼‍🔧' => 'مستري: وچولي گوري رنگت',
    '🧑🏽‍🔧' => 'مستري: پڪو رنگ',
    '🧑🏾‍🔧' => 'مستري: وچولو ڪارو رنگ',
    '🧑🏿‍🔧' => 'مستري: ڪارو رنگ',
    '👨🏻‍🔧' => 'مرد مستري: گوري رنگت',
    '👨🏼‍🔧' => 'مرد مستري: وچولي گوري رنگت',
    '👨🏽‍🔧' => 'مرد مستري: پڪو رنگ',
    '👨🏾‍🔧' => 'مرد مستري: وچولو ڪارو رنگ',
    '👨🏿‍🔧' => 'مرد مستري: ڪارو رنگ',
    '👩🏻‍🔧' => 'عورت مستري: گوري رنگت',
    '👩🏼‍🔧' => 'عورت مستري: وچولي گوري رنگت',
    '👩🏽‍🔧' => 'عورت مستري: پڪو رنگ',
    '👩🏾‍🔧' => 'عورت مستري: وچولو ڪارو رنگ',
    '👩🏿‍🔧' => 'عورت مستري: ڪارو رنگ',
    '🧑🏻‍🏭' => 'فيڪٽري ورڪر: گوري رنگت',
    '🧑🏼‍🏭' => 'فيڪٽري ورڪر: وچولي گوري رنگت',
    '🧑🏽‍🏭' => 'فيڪٽري ورڪر: پڪو رنگ',
    '🧑🏾‍🏭' => 'فيڪٽري ورڪر: وچولو ڪارو رنگ',
    '🧑🏿‍🏭' => 'فيڪٽري ورڪر: ڪارو رنگ',
    '👨🏻‍🏭' => 'مرد ڪارخانو مزدور: گوري رنگت',
    '👨🏼‍🏭' => 'مرد ڪارخانو مزدور: وچولي گوري رنگت',
    '👨🏽‍🏭' => 'مرد ڪارخانو مزدور: پڪو رنگ',
    '👨🏾‍🏭' => 'مرد ڪارخانو مزدور: وچولو ڪارو رنگ',
    '👨🏿‍🏭' => 'مرد ڪارخانو مزدور: ڪارو رنگ',
    '👩🏻‍🏭' => 'عورت ڪارخانو مزدور: گوري رنگت',
    '👩🏼‍🏭' => 'عورت ڪارخانو مزدور: وچولي گوري رنگت',
    '👩🏽‍🏭' => 'عورت ڪارخانو مزدور: پڪو رنگ',
    '👩🏾‍🏭' => 'عورت ڪارخانو مزدور: وچولو ڪارو رنگ',
    '👩🏿‍🏭' => 'عورت ڪارخانو مزدور: ڪارو رنگ',
    '🧑🏻‍💼' => 'آفيس ورڪر: گوري رنگت',
    '🧑🏼‍💼' => 'آفيس ورڪر: وچولي گوري رنگت',
    '🧑🏽‍💼' => 'آفيس ورڪر: پڪو رنگ',
    '🧑🏾‍💼' => 'آفيس ورڪر: وچولو ڪارو رنگ',
    '🧑🏿‍💼' => 'آفيس ورڪر: ڪارو رنگ',
    '👨🏻‍💼' => 'مرد آفيس ورڪر: گوري رنگت',
    '👨🏼‍💼' => 'مرد آفيس ورڪر: وچولي گوري رنگت',
    '👨🏽‍💼' => 'مرد آفيس ورڪر: پڪو رنگ',
    '👨🏾‍💼' => 'مرد آفيس ورڪر: وچولو ڪارو رنگ',
    '👨🏿‍💼' => 'مرد آفيس ورڪر: ڪارو رنگ',
    '👩🏻‍💼' => 'عورت آفيس ورڪر: گوري رنگت',
    '👩🏼‍💼' => 'عورت آفيس ورڪر: وچولي گوري رنگت',
    '👩🏽‍💼' => 'عورت آفيس ورڪر: پڪو رنگ',
    '👩🏾‍💼' => 'عورت آفيس ورڪر: وچولو ڪارو رنگ',
    '👩🏿‍💼' => 'عورت آفيس ورڪر: ڪارو رنگ',
    '🧑🏻‍🔬' => 'سائنس دان: گوري رنگت',
    '🧑🏼‍🔬' => 'سائنس دان: وچولي گوري رنگت',
    '🧑🏽‍🔬' => 'سائنس دان: پڪو رنگ',
    '🧑🏾‍🔬' => 'سائنس دان: وچولو ڪارو رنگ',
    '🧑🏿‍🔬' => 'سائنس دان: ڪارو رنگ',
    '👨🏻‍🔬' => 'مرد سائنسدان: گوري رنگت',
    '👨🏼‍🔬' => 'مرد سائنسدان: وچولي گوري رنگت',
    '👨🏽‍🔬' => 'مرد سائنسدان: پڪو رنگ',
    '👨🏾‍🔬' => 'مرد سائنسدان: وچولو ڪارو رنگ',
    '👨🏿‍🔬' => 'مرد سائنسدان: ڪارو رنگ',
    '👩🏻‍🔬' => 'عورت سائنسدان: گوري رنگت',
    '👩🏼‍🔬' => 'عورت سائنسدان: وچولي گوري رنگت',
    '👩🏽‍🔬' => 'عورت سائنسدان: پڪو رنگ',
    '👩🏾‍🔬' => 'عورت سائنسدان: وچولو ڪارو رنگ',
    '👩🏿‍🔬' => 'عورت سائنسدان: ڪارو رنگ',
    '🧑🏻‍💻' => 'ٽيڪنو لاجسٽ: گوري رنگت',
    '🧑🏼‍💻' => 'ٽيڪنو لاجسٽ: وچولي گوري رنگت',
    '🧑🏽‍💻' => 'ٽيڪنو لاجسٽ: پڪو رنگ',
    '🧑🏾‍💻' => 'ٽيڪنو لاجسٽ: وچولو ڪارو رنگ',
    '🧑🏿‍💻' => 'ٽيڪنو لاجسٽ: ڪارو رنگ',
    '👨🏻‍💻' => 'مرد ٽيڪنالوجسٽ: گوري رنگت',
    '👨🏼‍💻' => 'مرد ٽيڪنالوجسٽ: وچولي گوري رنگت',
    '👨🏽‍💻' => 'مرد ٽيڪنالوجسٽ: پڪو رنگ',
    '👨🏾‍💻' => 'مرد ٽيڪنالوجسٽ: وچولو ڪارو رنگ',
    '👨🏿‍💻' => 'مرد ٽيڪنالوجسٽ: ڪارو رنگ',
    '👩🏻‍💻' => 'عورت ٽيڪنالوجسٽ: گوري رنگت',
    '👩🏼‍💻' => 'عورت ٽيڪنالوجسٽ: وچولي گوري رنگت',
    '👩🏽‍💻' => 'عورت ٽيڪنالوجسٽ: پڪو رنگ',
    '👩🏾‍💻' => 'عورت ٽيڪنالوجسٽ: وچولو ڪارو رنگ',
    '👩🏿‍💻' => 'عورت ٽيڪنالوجسٽ: ڪارو رنگ',
    '🧑🏻‍🎤' => 'ڳائڻو: گوري رنگت',
    '🧑🏼‍🎤' => 'ڳائڻو: وچولي گوري رنگت',
    '🧑🏽‍🎤' => 'ڳائڻو: پڪو رنگ',
    '🧑🏾‍🎤' => 'ڳائڻو: وچولو ڪارو رنگ',
    '🧑🏿‍🎤' => 'ڳائڻو: ڪارو رنگ',
    '👨🏻‍🎤' => 'مرد ڳائڻو: گوري رنگت',
    '👨🏼‍🎤' => 'مرد ڳائڻو: وچولي گوري رنگت',
    '👨🏽‍🎤' => 'مرد ڳائڻو: پڪو رنگ',
    '👨🏾‍🎤' => 'مرد ڳائڻو: وچولو ڪارو رنگ',
    '👨🏿‍🎤' => 'مرد ڳائڻو: ڪارو رنگ',
    '👩🏻‍🎤' => 'عورت ڳائڻي: گوري رنگت',
    '👩🏼‍🎤' => 'عورت ڳائڻي: وچولي گوري رنگت',
    '👩🏽‍🎤' => 'عورت ڳائڻي: پڪو رنگ',
    '👩🏾‍🎤' => 'عورت ڳائڻي: وچولو ڪارو رنگ',
    '👩🏿‍🎤' => 'عورت ڳائڻي: ڪارو رنگ',
    '🧑🏻‍🎨' => 'فنڪار: گوري رنگت',
    '🧑🏼‍🎨' => 'فنڪار: وچولي گوري رنگت',
    '🧑🏽‍🎨' => 'فنڪار: پڪو رنگ',
    '🧑🏾‍🎨' => 'فنڪار: وچولو ڪارو رنگ',
    '🧑🏿‍🎨' => 'فنڪار: ڪارو رنگ',
    '👨🏻‍🎨' => 'مرد فنڪار: گوري رنگت',
    '👨🏼‍🎨' => 'مرد فنڪار: وچولي گوري رنگت',
    '👨🏽‍🎨' => 'مرد فنڪار: پڪو رنگ',
    '👨🏾‍🎨' => 'مرد فنڪار: وچولو ڪارو رنگ',
    '👨🏿‍🎨' => 'مرد فنڪار: ڪارو رنگ',
    '👩🏻‍🎨' => 'عورت فنڪار: گوري رنگت',
    '👩🏼‍🎨' => 'عورت فنڪار: وچولي گوري رنگت',
    '👩🏽‍🎨' => 'عورت فنڪار: پڪو رنگ',
    '👩🏾‍🎨' => 'عورت فنڪار: وچولو ڪارو رنگ',
    '👩🏿‍🎨' => 'عورت فنڪار: ڪارو رنگ',
    '🧑🏻‍✈' => 'پائيليٽ: گوري رنگت',
    '🧑🏼‍✈' => 'پائيليٽ: وچولي گوري رنگت',
    '🧑🏽‍✈' => 'پائيليٽ: پڪو رنگ',
    '🧑🏾‍✈' => 'پائيليٽ: وچولو ڪارو رنگ',
    '🧑🏿‍✈' => 'پائيليٽ: ڪارو رنگ',
    '👨🏻‍✈' => 'مرد پائيليٽ: گوري رنگت',
    '👨🏼‍✈' => 'مرد پائيليٽ: وچولي گوري رنگت',
    '👨🏽‍✈' => 'مرد پائيليٽ: پڪو رنگ',
    '👨🏾‍✈' => 'مرد پائيليٽ: وچولو ڪارو رنگ',
    '👨🏿‍✈' => 'مرد پائيليٽ: ڪارو رنگ',
    '👩🏻‍✈' => 'عورت پائيليٽ: گوري رنگت',
    '👩🏼‍✈' => 'عورت پائيليٽ: وچولي گوري رنگت',
    '👩🏽‍✈' => 'عورت پائيليٽ: پڪو رنگ',
    '👩🏾‍✈' => 'عورت پائيليٽ: وچولو ڪارو رنگ',
    '👩🏿‍✈' => 'عورت پائيليٽ: ڪارو رنگ',
    '🧑🏻‍🚀' => 'ايسٽرو ناٽ: گوري رنگت',
    '🧑🏼‍🚀' => 'ايسٽرو ناٽ: وچولي گوري رنگت',
    '🧑🏽‍🚀' => 'ايسٽرو ناٽ: پڪو رنگ',
    '🧑🏾‍🚀' => 'ايسٽرو ناٽ: وچولو ڪارو رنگ',
    '🧑🏿‍🚀' => 'ايسٽرو ناٽ: ڪارو رنگ',
    '👨🏻‍🚀' => 'مرد خلانورد: گوري رنگت',
    '👨🏼‍🚀' => 'مرد خلانورد: وچولي گوري رنگت',
    '👨🏽‍🚀' => 'مرد خلانورد: پڪو رنگ',
    '👨🏾‍🚀' => 'مرد خلانورد: وچولو ڪارو رنگ',
    '👨🏿‍🚀' => 'مرد خلانورد: ڪارو رنگ',
    '👩🏻‍🚀' => 'عورت خلانورد: گوري رنگت',
    '👩🏼‍🚀' => 'عورت خلانورد: وچولي گوري رنگت',
    '👩🏽‍🚀' => 'عورت خلانورد: پڪو رنگ',
    '👩🏾‍🚀' => 'عورت خلانورد: وچولو ڪارو رنگ',
    '👩🏿‍🚀' => 'عورت خلانورد: ڪارو رنگ',
    '🧑🏻‍🚒' => 'باهه وسائينڙ: گوري رنگت',
    '🧑🏼‍🚒' => 'باهه وسائينڙ: وچولي گوري رنگت',
    '🧑🏽‍🚒' => 'باهه وسائينڙ: پڪو رنگ',
    '🧑🏾‍🚒' => 'باهه وسائينڙ: وچولو ڪارو رنگ',
    '🧑🏿‍🚒' => 'باهه وسائينڙ: ڪارو رنگ',
    '👨🏻‍🚒' => 'مرد باهه وسائيندڙ: گوري رنگت',
    '👨🏼‍🚒' => 'مرد باهه وسائيندڙ: وچولي گوري رنگت',
    '👨🏽‍🚒' => 'مرد باهه وسائيندڙ: پڪو رنگ',
    '👨🏾‍🚒' => 'مرد باهه وسائيندڙ: وچولو ڪارو رنگ',
    '👨🏿‍🚒' => 'مرد باهه وسائيندڙ: ڪارو رنگ',
    '👩🏻‍🚒' => 'عورت باهه وسائيندڙ: گوري رنگت',
    '👩🏼‍🚒' => 'عورت باهه وسائيندڙ: وچولي گوري رنگت',
    '👩🏽‍🚒' => 'عورت باهه وسائيندڙ: پڪو رنگ',
    '👩🏾‍🚒' => 'عورت باهه وسائيندڙ: وچولو ڪارو رنگ',
    '👩🏿‍🚒' => 'عورت باهه وسائيندڙ: ڪارو رنگ',
    '👮🏻‍♂' => 'مرد پوليس آفيسر: گوري رنگت',
    '👮🏼‍♂' => 'مرد پوليس آفيسر: وچولي گوري رنگت',
    '👮🏽‍♂' => 'مرد پوليس آفيسر: پڪو رنگ',
    '👮🏾‍♂' => 'مرد پوليس آفيسر: وچولو ڪارو رنگ',
    '👮🏿‍♂' => 'مرد پوليس آفيسر: ڪارو رنگ',
    '👮🏻‍♀' => 'عورت پوليس آفيسر: گوري رنگت',
    '👮🏼‍♀' => 'عورت پوليس آفيسر: وچولي گوري رنگت',
    '👮🏽‍♀' => 'عورت پوليس آفيسر: پڪو رنگ',
    '👮🏾‍♀' => 'عورت پوليس آفيسر: وچولو ڪارو رنگ',
    '👮🏿‍♀' => 'عورت پوليس آفيسر: ڪارو رنگ',
    '🕵🏻‍♂' => 'مرد جاسوس: گوري رنگت',
    '🕵🏼‍♂' => 'مرد جاسوس: وچولي گوري رنگت',
    '🕵🏽‍♂' => 'مرد جاسوس: پڪو رنگ',
    '🕵🏾‍♂' => 'مرد جاسوس: وچولو ڪارو رنگ',
    '🕵🏿‍♂' => 'مرد جاسوس: ڪارو رنگ',
    '🕵🏻‍♀' => 'عورت جاسوس: گوري رنگت',
    '🕵🏼‍♀' => 'عورت جاسوس: وچولي گوري رنگت',
    '🕵🏽‍♀' => 'عورت جاسوس: پڪو رنگ',
    '🕵🏾‍♀' => 'عورت جاسوس: وچولو ڪارو رنگ',
    '🕵🏿‍♀' => 'عورت جاسوس: ڪارو رنگ',
    '💂🏻‍♂' => 'مرد نگهبان: گوري رنگت',
    '💂🏼‍♂' => 'مرد نگهبان: وچولي گوري رنگت',
    '💂🏽‍♂' => 'مرد نگهبان: پڪو رنگ',
    '💂🏾‍♂' => 'مرد نگهبان: وچولو ڪارو رنگ',
    '💂🏿‍♂' => 'مرد نگهبان: ڪارو رنگ',
    '💂🏻‍♀' => 'عورت نگهبان: گوري رنگت',
    '💂🏼‍♀' => 'عورت نگهبان: وچولي گوري رنگت',
    '💂🏽‍♀' => 'عورت نگهبان: پڪو رنگ',
    '💂🏾‍♀' => 'عورت نگهبان: وچولو ڪارو رنگ',
    '💂🏿‍♀' => 'عورت نگهبان: ڪارو رنگ',
    '👷🏻‍♂' => 'مرد اڏاوت جو ڪم ڪندڙ: گوري رنگت',
    '👷🏼‍♂' => 'مرد اڏاوت جو ڪم ڪندڙ: وچولي گوري رنگت',
    '👷🏽‍♂' => 'مرد اڏاوت جو ڪم ڪندڙ: پڪو رنگ',
    '👷🏾‍♂' => 'مرد اڏاوت جو ڪم ڪندڙ: وچولو ڪارو رنگ',
    '👷🏿‍♂' => 'مرد اڏاوت جو ڪم ڪندڙ: ڪارو رنگ',
    '👷🏻‍♀' => 'عورت اڏاوت جو ڪم ڪندڙ: گوري رنگت',
    '👷🏼‍♀' => 'عورت اڏاوت جو ڪم ڪندڙ: وچولي گوري رنگت',
    '👷🏽‍♀' => 'عورت اڏاوت جو ڪم ڪندڙ: پڪو رنگ',
    '👷🏾‍♀' => 'عورت اڏاوت جو ڪم ڪندڙ: وچولو ڪارو رنگ',
    '👷🏿‍♀' => 'عورت اڏاوت جو ڪم ڪندڙ: ڪارو رنگ',
    '👳🏻‍♂' => 'مرد کي پگڙي پاتل: گوري رنگت',
    '👳🏼‍♂' => 'مرد کي پگڙي پاتل: وچولي گوري رنگت',
    '👳🏽‍♂' => 'مرد کي پگڙي پاتل: پڪو رنگ',
    '👳🏾‍♂' => 'مرد کي پگڙي پاتل: وچولو ڪارو رنگ',
    '👳🏿‍♂' => 'مرد کي پگڙي پاتل: ڪارو رنگ',
    '👳🏻‍♀' => 'عورت کي پگڙي پاتل: گوري رنگت',
    '👳🏼‍♀' => 'عورت کي پگڙي پاتل: وچولي گوري رنگت',
    '👳🏽‍♀' => 'عورت کي پگڙي پاتل: پڪو رنگ',
    '👳🏾‍♀' => 'عورت کي پگڙي پاتل: وچولو ڪارو رنگ',
    '👳🏿‍♀' => 'عورت کي پگڙي پاتل: ڪارو رنگ',
    '🤵🏻‍♂' => 'ٽيڪسيڊو ۾ ماڻهو: گوري رنگت',
    '🤵🏼‍♂' => 'ٽيڪسيڊو ۾ ماڻهو: وچولي گوري رنگت',
    '🤵🏽‍♂' => 'ٽيڪسيڊو ۾ ماڻهو: پڪو رنگ',
    '🤵🏾‍♂' => 'ٽيڪسيڊو ۾ ماڻهو: وچولو ڪارو رنگ',
    '🤵🏿‍♂' => 'ٽيڪسيڊو ۾ ماڻهو: ڪارو رنگ',
    '🤵🏻‍♀' => 'ٽيڪسيڊو ۾ عورت: گوري رنگت',
    '🤵🏼‍♀' => 'ٽيڪسيڊو ۾ عورت: وچولي گوري رنگت',
    '🤵🏽‍♀' => 'ٽيڪسيڊو ۾ عورت: پڪو رنگ',
    '🤵🏾‍♀' => 'ٽيڪسيڊو ۾ عورت: وچولو ڪارو رنگ',
    '🤵🏿‍♀' => 'ٽيڪسيڊو ۾ عورت: ڪارو رنگ',
    '👰🏻‍♂' => 'ويل سان مرد: گوري رنگت',
    '👰🏼‍♂' => 'ويل سان مرد: وچولي گوري رنگت',
    '👰🏽‍♂' => 'ويل سان مرد: پڪو رنگ',
    '👰🏾‍♂' => 'ويل سان مرد: وچولو ڪارو رنگ',
    '👰🏿‍♂' => 'ويل سان مرد: ڪارو رنگ',
    '👰🏻‍♀' => 'ويل سان عورت: گوري رنگت',
    '👰🏼‍♀' => 'ويل سان عورت: وچولي گوري رنگت',
    '👰🏽‍♀' => 'ويل سان عورت: پڪو رنگ',
    '👰🏾‍♀' => 'ويل سان عورت: وچولو ڪارو رنگ',
    '👰🏿‍♀' => 'ويل سان عورت: ڪارو رنگ',
    '👩🏻‍🍼' => 'ٻار کي کير پياريندڙ عورت: گوري رنگت',
    '👩🏼‍🍼' => 'ٻار کي کير پياريندڙ عورت: وچولي گوري رنگت',
    '👩🏽‍🍼' => 'ٻار کي کير پياريندڙ عورت: پڪو رنگ',
    '👩🏾‍🍼' => 'ٻار کي کير پياريندڙ عورت: وچولو ڪارو رنگ',
    '👩🏿‍🍼' => 'ٻار کي کير پياريندڙ عورت: ڪارو رنگ',
    '👨🏻‍🍼' => 'ٻار کي کير پياريندڙ ماڻهو: گوري رنگت',
    '👨🏼‍🍼' => 'ٻار کي کير پياريندڙ ماڻهو: وچولي گوري رنگت',
    '👨🏽‍🍼' => 'ٻار کي کير پياريندڙ ماڻهو: پڪو رنگ',
    '👨🏾‍🍼' => 'ٻار کي کير پياريندڙ ماڻهو: وچولو ڪارو رنگ',
    '👨🏿‍🍼' => 'ٻار کي کير پياريندڙ ماڻهو: ڪارو رنگ',
    '🧑🏻‍🍼' => 'ٻار کي کير پياريندڙ شخص: گوري رنگت',
    '🧑🏼‍🍼' => 'ٻار کي کير پياريندڙ شخص: وچولي گوري رنگت',
    '🧑🏽‍🍼' => 'ٻار کي کير پياريندڙ شخص: پڪو رنگ',
    '🧑🏾‍🍼' => 'ٻار کي کير پياريندڙ شخص: وچولو ڪارو رنگ',
    '🧑🏿‍🍼' => 'ٻار کي کير پياريندڙ شخص: ڪارو رنگ',
    '🧑🏻‍🎄' => 'مڪس ڪلاز: گوري رنگت',
    '🧑🏼‍🎄' => 'مڪس ڪلاز: وچولي گوري رنگت',
    '🧑🏽‍🎄' => 'مڪس ڪلاز: پڪو رنگ',
    '🧑🏾‍🎄' => 'مڪس ڪلاز: وچولو ڪارو رنگ',
    '🧑🏿‍🎄' => 'مڪس ڪلاز: ڪارو رنگ',
    '🦸🏻‍♂' => 'مرد سپر هيرو: گوري رنگت',
    '🦸🏼‍♂' => 'مرد سپر هيرو: وچولي گوري رنگت',
    '🦸🏽‍♂' => 'مرد سپر هيرو: پڪو رنگ',
    '🦸🏾‍♂' => 'مرد سپر هيرو: وچولو ڪارو رنگ',
    '🦸🏿‍♂' => 'مرد سپر هيرو: ڪارو رنگ',
    '🦸🏻‍♀' => 'عورت سپر هيرو: گوري رنگت',
    '🦸🏼‍♀' => 'عورت سپر هيرو: وچولي گوري رنگت',
    '🦸🏽‍♀' => 'عورت سپر هيرو: پڪو رنگ',
    '🦸🏾‍♀' => 'عورت سپر هيرو: وچولو ڪارو رنگ',
    '🦸🏿‍♀' => 'عورت سپر هيرو: ڪارو رنگ',
    '🦹🏻‍♂' => 'مرد سپر ولن: گوري رنگت',
    '🦹🏼‍♂' => 'مرد سپر ولن: وچولي گوري رنگت',
    '🦹🏽‍♂' => 'مرد سپر ولن: پڪو رنگ',
    '🦹🏾‍♂' => 'مرد سپر ولن: وچولو ڪارو رنگ',
    '🦹🏿‍♂' => 'مرد سپر ولن: ڪارو رنگ',
    '🦹🏻‍♀' => 'عورت سپر ولن: گوري رنگت',
    '🦹🏼‍♀' => 'عورت سپر ولن: وچولي گوري رنگت',
    '🦹🏽‍♀' => 'عورت سپر ولن: پڪو رنگ',
    '🦹🏾‍♀' => 'عورت سپر ولن: وچولو ڪارو رنگ',
    '🦹🏿‍♀' => 'عورت سپر ولن: ڪارو رنگ',
    '🧙🏻‍♂' => 'مرد، جادوگر: گوري رنگت',
    '🧙🏼‍♂' => 'مرد، جادوگر: وچولي گوري رنگت',
    '🧙🏽‍♂' => 'مرد، جادوگر: پڪو رنگ',
    '🧙🏾‍♂' => 'مرد، جادوگر: وچولو ڪارو رنگ',
    '🧙🏿‍♂' => 'مرد، جادوگر: ڪارو رنگ',
    '🧙🏻‍♀' => 'عورت جادوگرني: گوري رنگت',
    '🧙🏼‍♀' => 'عورت جادوگرني: وچولي گوري رنگت',
    '🧙🏽‍♀' => 'عورت جادوگرني: پڪو رنگ',
    '🧙🏾‍♀' => 'عورت جادوگرني: وچولو ڪارو رنگ',
    '🧙🏿‍♀' => 'عورت جادوگرني: ڪارو رنگ',
    '🧚🏻‍♂' => 'مرد فرشتو: گوري رنگت',
    '🧚🏼‍♂' => 'مرد فرشتو: وچولي گوري رنگت',
    '🧚🏽‍♂' => 'مرد فرشتو: پڪو رنگ',
    '🧚🏾‍♂' => 'مرد فرشتو: وچولو ڪارو رنگ',
    '🧚🏿‍♂' => 'مرد فرشتو: ڪارو رنگ',
    '🧚🏻‍♀' => 'عورت پري: گوري رنگت',
    '🧚🏼‍♀' => 'عورت پري: وچولي گوري رنگت',
    '🧚🏽‍♀' => 'عورت پري: پڪو رنگ',
    '🧚🏾‍♀' => 'عورت پري: وچولو ڪارو رنگ',
    '🧚🏿‍♀' => 'عورت پري: ڪارو رنگ',
    '🧛🏻‍♂' => 'مرد ڀوت: گوري رنگت',
    '🧛🏼‍♂' => 'مرد ڀوت: وچولي گوري رنگت',
    '🧛🏽‍♂' => 'مرد ڀوت: پڪو رنگ',
    '🧛🏾‍♂' => 'مرد ڀوت: وچولو ڪارو رنگ',
    '🧛🏿‍♂' => 'مرد ڀوت: ڪارو رنگ',
    '🧛🏻‍♀' => 'عورت ڀوت: گوري رنگت',
    '🧛🏼‍♀' => 'عورت ڀوت: وچولي گوري رنگت',
    '🧛🏽‍♀' => 'عورت ڀوت: پڪو رنگ',
    '🧛🏾‍♀' => 'عورت ڀوت: وچولو ڪارو رنگ',
    '🧛🏿‍♀' => 'عورت ڀوت: ڪارو رنگ',
    '🧜🏻‍♂' => 'جل مانس: گوري رنگت',
    '🧜🏼‍♂' => 'جل مانس: وچولي گوري رنگت',
    '🧜🏽‍♂' => 'جل مانس: پڪو رنگ',
    '🧜🏾‍♂' => 'جل مانس: وچولو ڪارو رنگ',
    '🧜🏿‍♂' => 'جل مانس: ڪارو رنگ',
    '🧜🏻‍♀' => 'جل پري: گوري رنگت',
    '🧜🏼‍♀' => 'جل پري: وچولي گوري رنگت',
    '🧜🏽‍♀' => 'جل پري: پڪو رنگ',
    '🧜🏾‍♀' => 'جل پري: وچولو ڪارو رنگ',
    '🧜🏿‍♀' => 'جل پري: ڪارو رنگ',
    '🧝🏻‍♂' => 'مرد بونا: گوري رنگت',
    '🧝🏼‍♂' => 'مرد بونا: وچولي گوري رنگت',
    '🧝🏽‍♂' => 'مرد بونا: پڪو رنگ',
    '🧝🏾‍♂' => 'مرد بونا: وچولو ڪارو رنگ',
    '🧝🏿‍♂' => 'مرد بونا: ڪارو رنگ',
    '🧝🏻‍♀' => 'عورت بونا: گوري رنگت',
    '🧝🏼‍♀' => 'عورت بونا: وچولي گوري رنگت',
    '🧝🏽‍♀' => 'عورت بونا: پڪو رنگ',
    '🧝🏾‍♀' => 'عورت بونا: وچولو ڪارو رنگ',
    '🧝🏿‍♀' => 'عورت بونا: ڪارو رنگ',
    '💆🏻‍♂' => 'مساج وٺندڙ مرد: گوري رنگت',
    '💆🏼‍♂' => 'مساج وٺندڙ مرد: وچولي گوري رنگت',
    '💆🏽‍♂' => 'مساج وٺندڙ مرد: پڪو رنگ',
    '💆🏾‍♂' => 'مساج وٺندڙ مرد: وچولو ڪارو رنگ',
    '💆🏿‍♂' => 'مساج وٺندڙ مرد: ڪارو رنگ',
    '💆🏻‍♀' => 'مساج وٺندڙ عورت: گوري رنگت',
    '💆🏼‍♀' => 'مساج وٺندڙ عورت: وچولي گوري رنگت',
    '💆🏽‍♀' => 'مساج وٺندڙ عورت: پڪو رنگ',
    '💆🏾‍♀' => 'مساج وٺندڙ عورت: وچولو ڪارو رنگ',
    '💆🏿‍♀' => 'مساج وٺندڙ عورت: ڪارو رنگ',
    '💇🏻‍♂' => 'مرد وار ڪٽرائيندي: گوري رنگت',
    '💇🏼‍♂' => 'مرد وار ڪٽرائيندي: وچولي گوري رنگت',
    '💇🏽‍♂' => 'مرد وار ڪٽرائيندي: پڪو رنگ',
    '💇🏾‍♂' => 'مرد وار ڪٽرائيندي: وچولو ڪارو رنگ',
    '💇🏿‍♂' => 'مرد وار ڪٽرائيندي: ڪارو رنگ',
    '💇🏻‍♀' => 'عورت وار ڪٽرائيندي: گوري رنگت',
    '💇🏼‍♀' => 'عورت وار ڪٽرائيندي: وچولي گوري رنگت',
    '💇🏽‍♀' => 'عورت وار ڪٽرائيندي: پڪو رنگ',
    '💇🏾‍♀' => 'عورت وار ڪٽرائيندي: وچولو ڪارو رنگ',
    '💇🏿‍♀' => 'عورت وار ڪٽرائيندي: ڪارو رنگ',
    '🚶🏻‍♂' => 'مرد سير ڪندي: گوري رنگت',
    '🚶🏼‍♂' => 'مرد سير ڪندي: وچولي گوري رنگت',
    '🚶🏽‍♂' => 'مرد سير ڪندي: پڪو رنگ',
    '🚶🏾‍♂' => 'مرد سير ڪندي: وچولو ڪارو رنگ',
    '🚶🏿‍♂' => 'مرد سير ڪندي: ڪارو رنگ',
    '🚶🏻‍♀' => 'عورت سير ڪندي: گوري رنگت',
    '🚶🏼‍♀' => 'عورت سير ڪندي: وچولي گوري رنگت',
    '🚶🏽‍♀' => 'عورت سير ڪندي: پڪو رنگ',
    '🚶🏾‍♀' => 'عورت سير ڪندي: وچولو ڪارو رنگ',
    '🚶🏿‍♀' => 'عورت سير ڪندي: ڪارو رنگ',
    '🚶🏻‍➡' => 'شخص هلندي: گوري رنگت، ساڄي طرف منهن',
    '🚶🏼‍➡' => 'شخص هلندي: وچولي گوري رنگت، ساڄي طرف منهن',
    '🚶🏽‍➡' => 'شخص هلندي: پڪو رنگ، ساڄي طرف منهن',
    '🚶🏾‍➡' => 'شخص هلندي: وچولو ڪارو رنگ، ساڄي طرف منهن',
    '🚶🏿‍➡' => 'شخص هلندي: ڪارو رنگ، ساڄي طرف منهن',
    '🧍🏻‍♂' => 'ماڻهو بيٺل: گوري رنگت',
    '🧍🏼‍♂' => 'ماڻهو بيٺل: وچولي گوري رنگت',
    '🧍🏽‍♂' => 'ماڻهو بيٺل: پڪو رنگ',
    '🧍🏾‍♂' => 'ماڻهو بيٺل: وچولو ڪارو رنگ',
    '🧍🏿‍♂' => 'ماڻهو بيٺل: ڪارو رنگ',
    '🧍🏻‍♀' => 'بيٺل عورت: گوري رنگت',
    '🧍🏼‍♀' => 'بيٺل عورت: وچولي گوري رنگت',
    '🧍🏽‍♀' => 'بيٺل عورت: پڪو رنگ',
    '🧍🏾‍♀' => 'بيٺل عورت: وچولو ڪارو رنگ',
    '🧍🏿‍♀' => 'بيٺل عورت: ڪارو رنگ',
    '🧎🏻‍♂' => 'گوڏا کوڙيل ماڻهو: گوري رنگت',
    '🧎🏼‍♂' => 'گوڏا کوڙيل ماڻهو: وچولي گوري رنگت',
    '🧎🏽‍♂' => 'گوڏا کوڙيل ماڻهو: پڪو رنگ',
    '🧎🏾‍♂' => 'گوڏا کوڙيل ماڻهو: وچولو ڪارو رنگ',
    '🧎🏿‍♂' => 'گوڏا کوڙيل ماڻهو: ڪارو رنگ',
    '🧎🏻‍♀' => 'گوڏا کوڙيل عورت: گوري رنگت',
    '🧎🏼‍♀' => 'گوڏا کوڙيل عورت: وچولي گوري رنگت',
    '🧎🏽‍♀' => 'گوڏا کوڙيل عورت: پڪو رنگ',
    '🧎🏾‍♀' => 'گوڏا کوڙيل عورت: وچولو ڪارو رنگ',
    '🧎🏿‍♀' => 'گوڏا کوڙيل عورت: ڪارو رنگ',
    '🧎🏻‍➡' => 'گوڏن ڀر ويٺل ماڻهو: گوري رنگت، ساڄي طرف منهن',
    '🧎🏼‍➡' => 'گوڏن ڀر ويٺل ماڻهو: وچولي گوري رنگت، ساڄي طرف منهن',
    '🧎🏽‍➡' => 'گوڏن ڀر ويٺل ماڻهو: پڪو رنگ، ساڄي طرف منهن',
    '🧎🏾‍➡' => 'گوڏن ڀر ويٺل ماڻهو: وچولو ڪارو رنگ، ساڄي طرف منهن',
    '🧎🏿‍➡' => 'گوڏن ڀر ويٺل ماڻهو: ڪارو رنگ، ساڄي طرف منهن',
    '🧑🏻‍🦯' => 'پروبنگ لٺ وارو ماڻهو: گوري رنگت',
    '🧑🏼‍🦯' => 'پروبنگ لٺ وارو ماڻهو: وچولي گوري رنگت',
    '🧑🏽‍🦯' => 'پروبنگ لٺ وارو ماڻهو: پڪو رنگ',
    '🧑🏾‍🦯' => 'پروبنگ لٺ وارو ماڻهو: وچولو ڪارو رنگ',
    '🧑🏿‍🦯' => 'پروبنگ لٺ وارو ماڻهو: ڪارو رنگ',
    '👨🏻‍🦯' => 'پروبنگ ڪين سان ماڻهو: گوري رنگت',
    '👨🏼‍🦯' => 'پروبنگ ڪين سان ماڻهو: وچولي گوري رنگت',
    '👨🏽‍🦯' => 'پروبنگ ڪين سان ماڻهو: پڪو رنگ',
    '👨🏾‍🦯' => 'پروبنگ ڪين سان ماڻهو: وچولو ڪارو رنگ',
    '👨🏿‍🦯' => 'پروبنگ ڪين سان ماڻهو: ڪارو رنگ',
    '👩🏻‍🦯' => 'پروبنگ ڪين سان عورت: گوري رنگت',
    '👩🏼‍🦯' => 'پروبنگ ڪين سان عورت: وچولي گوري رنگت',
    '👩🏽‍🦯' => 'پروبنگ ڪين سان عورت: پڪو رنگ',
    '👩🏾‍🦯' => 'پروبنگ ڪين سان عورت: وچولو ڪارو رنگ',
    '👩🏿‍🦯' => 'پروبنگ ڪين سان عورت: ڪارو رنگ',
    '🧑🏻‍🦼' => 'موٽر واري وهيل چيئر تي شخص: گوري رنگت',
    '🧑🏼‍🦼' => 'موٽر واري وهيل چيئر تي شخص: وچولي گوري رنگت',
    '🧑🏽‍🦼' => 'موٽر واري وهيل چيئر تي شخص: پڪو رنگ',
    '🧑🏾‍🦼' => 'موٽر واري وهيل چيئر تي شخص: وچولو ڪارو رنگ',
    '🧑🏿‍🦼' => 'موٽر واري وهيل چيئر تي شخص: ڪارو رنگ',
    '👨🏻‍🦼' => 'موٽر واري وهيل چيئر ۾ ماڻهو: گوري رنگت',
    '👨🏼‍🦼' => 'موٽر واري وهيل چيئر ۾ ماڻهو: وچولي گوري رنگت',
    '👨🏽‍🦼' => 'موٽر واري وهيل چيئر ۾ ماڻهو: پڪو رنگ',
    '👨🏾‍🦼' => 'موٽر واري وهيل چيئر ۾ ماڻهو: وچولو ڪارو رنگ',
    '👨🏿‍🦼' => 'موٽر واري وهيل چيئر ۾ ماڻهو: ڪارو رنگ',
    '👩🏻‍🦼' => 'موٽر واري ڦيٿائين ڪرسي تي عورت: گوري رنگت',
    '👩🏼‍🦼' => 'موٽر واري ڦيٿائين ڪرسي تي عورت: وچولي گوري رنگت',
    '👩🏽‍🦼' => 'موٽر واري ڦيٿائين ڪرسي تي عورت: پڪو رنگ',
    '👩🏾‍🦼' => 'موٽر واري ڦيٿائين ڪرسي تي عورت: وچولو ڪارو رنگ',
    '👩🏿‍🦼' => 'موٽر واري ڦيٿائين ڪرسي تي عورت: ڪارو رنگ',
    '🧑🏻‍🦽' => 'ماڻھو دستي ويل چيئر تي: گوري رنگت',
    '🧑🏼‍🦽' => 'ماڻھو دستي ويل چيئر تي: وچولي گوري رنگت',
    '🧑🏽‍🦽' => 'ماڻھو دستي ويل چيئر تي: پڪو رنگ',
    '🧑🏾‍🦽' => 'ماڻھو دستي ويل چيئر تي: وچولو ڪارو رنگ',
    '🧑🏿‍🦽' => 'ماڻھو دستي ويل چيئر تي: ڪارو رنگ',
    '👨🏻‍🦽' => 'دستي وهيل چيئر ۾ ماڻهو: گوري رنگت',
    '👨🏼‍🦽' => 'دستي وهيل چيئر ۾ ماڻهو: وچولي گوري رنگت',
    '👨🏽‍🦽' => 'دستي وهيل چيئر ۾ ماڻهو: پڪو رنگ',
    '👨🏾‍🦽' => 'دستي وهيل چيئر ۾ ماڻهو: وچولو ڪارو رنگ',
    '👨🏿‍🦽' => 'دستي وهيل چيئر ۾ ماڻهو: ڪارو رنگ',
    '👩🏻‍🦽' => 'دستي وهيل چيئر ۾ عورت: گوري رنگت',
    '👩🏼‍🦽' => 'دستي وهيل چيئر ۾ عورت: وچولي گوري رنگت',
    '👩🏽‍🦽' => 'دستي وهيل چيئر ۾ عورت: پڪو رنگ',
    '👩🏾‍🦽' => 'دستي وهيل چيئر ۾ عورت: وچولو ڪارو رنگ',
    '👩🏿‍🦽' => 'دستي وهيل چيئر ۾ عورت: ڪارو رنگ',
    '🏃🏻‍♂' => 'مرد ڊوڙندي: گوري رنگت',
    '🏃🏼‍♂' => 'مرد ڊوڙندي: وچولي گوري رنگت',
    '🏃🏽‍♂' => 'مرد ڊوڙندي: پڪو رنگ',
    '🏃🏾‍♂' => 'مرد ڊوڙندي: وچولو ڪارو رنگ',
    '🏃🏿‍♂' => 'مرد ڊوڙندي: ڪارو رنگ',
    '🏃🏻‍♀' => 'ڊوڙندي عورت: گوري رنگت',
    '🏃🏼‍♀' => 'ڊوڙندي عورت: وچولي گوري رنگت',
    '🏃🏽‍♀' => 'ڊوڙندي عورت: پڪو رنگ',
    '🏃🏾‍♀' => 'ڊوڙندي عورت: وچولو ڪارو رنگ',
    '🏃🏿‍♀' => 'ڊوڙندي عورت: ڪارو رنگ',
    '🏃🏻‍➡' => 'شخص ڊوڙندي: گوري رنگت، ساڄي طرف منهن',
    '🏃🏼‍➡' => 'شخص ڊوڙندي: وچولي گوري رنگت، ساڄي طرف منهن',
    '🏃🏽‍➡' => 'شخص ڊوڙندي: پڪو رنگ، ساڄي طرف منهن',
    '🏃🏾‍➡' => 'شخص ڊوڙندي: وچولو ڪارو رنگ، ساڄي طرف منهن',
    '🏃🏿‍➡' => 'شخص ڊوڙندي: ڪارو رنگ، ساڄي طرف منهن',
    '👯🏻‍♀' => 'خرگوش جي ڪنن وري عورت: گوري رنگت',
    '👯🏼‍♀' => 'خرگوش جي ڪنن وري عورت: وچولي گوري رنگت',
    '👯🏽‍♀' => 'خرگوش جي ڪنن وري عورت: پڪو رنگ',
    '👯🏾‍♀' => 'خرگوش جي ڪنن وري عورت: وچولو ڪارو رنگ',
    '👯🏿‍♀' => 'خرگوش جي ڪنن وري عورت: ڪارو رنگ',
    '👯🏻‍♂' => 'خرگوش جي ڪنن وارو مرد: گوري رنگت',
    '👯🏼‍♂' => 'خرگوش جي ڪنن وارو مرد: وچولي گوري رنگت',
    '👯🏽‍♂' => 'خرگوش جي ڪنن وارو مرد: پڪو رنگ',
    '👯🏾‍♂' => 'خرگوش جي ڪنن وارو مرد: وچولو ڪارو رنگ',
    '👯🏿‍♂' => 'خرگوش جي ڪنن وارو مرد: ڪارو رنگ',
    '🧖🏻‍♂' => 'مرد ٻاڦ واري ڪمري ۾: گوري رنگت',
    '🧖🏼‍♂' => 'مرد ٻاڦ واري ڪمري ۾: وچولي گوري رنگت',
    '🧖🏽‍♂' => 'مرد ٻاڦ واري ڪمري ۾: پڪو رنگ',
    '🧖🏾‍♂' => 'مرد ٻاڦ واري ڪمري ۾: وچولو ڪارو رنگ',
    '🧖🏿‍♂' => 'مرد ٻاڦ واري ڪمري ۾: ڪارو رنگ',
    '🧖🏻‍♀' => 'عورت ٻاڦ واري ڪمري ۾: گوري رنگت',
    '🧖🏼‍♀' => 'عورت ٻاڦ واري ڪمري ۾: وچولي گوري رنگت',
    '🧖🏽‍♀' => 'عورت ٻاڦ واري ڪمري ۾: پڪو رنگ',
    '🧖🏾‍♀' => 'عورت ٻاڦ واري ڪمري ۾: وچولو ڪارو رنگ',
    '🧖🏿‍♀' => 'عورت ٻاڦ واري ڪمري ۾: ڪارو رنگ',
    '🧗🏻‍♂' => 'مرد چڙهندي: گوري رنگت',
    '🧗🏼‍♂' => 'مرد چڙهندي: وچولي گوري رنگت',
    '🧗🏽‍♂' => 'مرد چڙهندي: پڪو رنگ',
    '🧗🏾‍♂' => 'مرد چڙهندي: وچولو ڪارو رنگ',
    '🧗🏿‍♂' => 'مرد چڙهندي: ڪارو رنگ',
    '🧗🏻‍♀' => 'عورت چڙهندي: گوري رنگت',
    '🧗🏼‍♀' => 'عورت چڙهندي: وچولي گوري رنگت',
    '🧗🏽‍♀' => 'عورت چڙهندي: پڪو رنگ',
    '🧗🏾‍♀' => 'عورت چڙهندي: وچولو ڪارو رنگ',
    '🧗🏿‍♀' => 'عورت چڙهندي: ڪارو رنگ',
    '🏌🏻‍♂' => 'مرد گولف کيڏيندي: گوري رنگت',
    '🏌🏼‍♂' => 'مرد گولف کيڏيندي: وچولي گوري رنگت',
    '🏌🏽‍♂' => 'مرد گولف کيڏيندي: پڪو رنگ',
    '🏌🏾‍♂' => 'مرد گولف کيڏيندي: وچولو ڪارو رنگ',
    '🏌🏿‍♂' => 'مرد گولف کيڏيندي: ڪارو رنگ',
    '🏌🏻‍♀' => 'عورت گولف کيڏيندي: گوري رنگت',
    '🏌🏼‍♀' => 'عورت گولف کيڏيندي: وچولي گوري رنگت',
    '🏌🏽‍♀' => 'عورت گولف کيڏيندي: پڪو رنگ',
    '🏌🏾‍♀' => 'عورت گولف کيڏيندي: وچولو ڪارو رنگ',
    '🏌🏿‍♀' => 'عورت گولف کيڏيندي: ڪارو رنگ',
    '🏄🏻‍♂' => 'مرد سرفنگ ڪندي: گوري رنگت',
    '🏄🏼‍♂' => 'مرد سرفنگ ڪندي: وچولي گوري رنگت',
    '🏄🏽‍♂' => 'مرد سرفنگ ڪندي: پڪو رنگ',
    '🏄🏾‍♂' => 'مرد سرفنگ ڪندي: وچولو ڪارو رنگ',
    '🏄🏿‍♂' => 'مرد سرفنگ ڪندي: ڪارو رنگ',
    '🏄🏻‍♀' => 'عورت سرفنگ ڪندي: گوري رنگت',
    '🏄🏼‍♀' => 'عورت سرفنگ ڪندي: وچولي گوري رنگت',
    '🏄🏽‍♀' => 'عورت سرفنگ ڪندي: پڪو رنگ',
    '🏄🏾‍♀' => 'عورت سرفنگ ڪندي: وچولو ڪارو رنگ',
    '🏄🏿‍♀' => 'عورت سرفنگ ڪندي: ڪارو رنگ',
    '🚣🏻‍♂' => 'مرد ٻيڙي ۾ چپو هلائيندي: گوري رنگت',
    '🚣🏼‍♂' => 'مرد ٻيڙي ۾ چپو هلائيندي: وچولي گوري رنگت',
    '🚣🏽‍♂' => 'مرد ٻيڙي ۾ چپو هلائيندي: پڪو رنگ',
    '🚣🏾‍♂' => 'مرد ٻيڙي ۾ چپو هلائيندي: وچولو ڪارو رنگ',
    '🚣🏿‍♂' => 'مرد ٻيڙي ۾ چپو هلائيندي: ڪارو رنگ',
    '🚣🏻‍♀' => 'عورت ٻيڙي ۾ چپو هلائيندي: گوري رنگت',
    '🚣🏼‍♀' => 'عورت ٻيڙي ۾ چپو هلائيندي: وچولي گوري رنگت',
    '🚣🏽‍♀' => 'عورت ٻيڙي ۾ چپو هلائيندي: پڪو رنگ',
    '🚣🏾‍♀' => 'عورت ٻيڙي ۾ چپو هلائيندي: وچولو ڪارو رنگ',
    '🚣🏿‍♀' => 'عورت ٻيڙي ۾ چپو هلائيندي: ڪارو رنگ',
    '🏊🏻‍♂' => 'مرد ترندي: گوري رنگت',
    '🏊🏼‍♂' => 'مرد ترندي: وچولي گوري رنگت',
    '🏊🏽‍♂' => 'مرد ترندي: پڪو رنگ',
    '🏊🏾‍♂' => 'مرد ترندي: وچولو ڪارو رنگ',
    '🏊🏿‍♂' => 'مرد ترندي: ڪارو رنگ',
    '🏊🏻‍♀' => 'عورت ترندي: گوري رنگت',
    '🏊🏼‍♀' => 'عورت ترندي: وچولي گوري رنگت',
    '🏊🏽‍♀' => 'عورت ترندي: پڪو رنگ',
    '🏊🏾‍♀' => 'عورت ترندي: وچولو ڪارو رنگ',
    '🏊🏿‍♀' => 'عورت ترندي: ڪارو رنگ',
    '⛹🏻‍♂' => 'مرد بائونسنگ بال سان کيڏندي: گوري رنگت',
    '⛹🏼‍♂' => 'مرد بائونسنگ بال سان کيڏندي: وچولي گوري رنگت',
    '⛹🏽‍♂' => 'مرد بائونسنگ بال سان کيڏندي: پڪو رنگ',
    '⛹🏾‍♂' => 'مرد بائونسنگ بال سان کيڏندي: وچولو ڪارو رنگ',
    '⛹🏿‍♂' => 'مرد بائونسنگ بال سان کيڏندي: ڪارو رنگ',
    '⛹🏻‍♀' => 'عورت بائونسنگ بال سان کيڏندي: گوري رنگت',
    '⛹🏼‍♀' => 'عورت بائونسنگ بال سان کيڏندي: وچولي گوري رنگت',
    '⛹🏽‍♀' => 'عورت بائونسنگ بال سان کيڏندي: پڪو رنگ',
    '⛹🏾‍♀' => 'عورت بائونسنگ بال سان کيڏندي: وچولو ڪارو رنگ',
    '⛹🏿‍♀' => 'عورت بائونسنگ بال سان کيڏندي: ڪارو رنگ',
    '🏋🏻‍♂' => 'مرد وزن کڻندي: گوري رنگت',
    '🏋🏼‍♂' => 'مرد وزن کڻندي: وچولي گوري رنگت',
    '🏋🏽‍♂' => 'مرد وزن کڻندي: پڪو رنگ',
    '🏋🏾‍♂' => 'مرد وزن کڻندي: وچولو ڪارو رنگ',
    '🏋🏿‍♂' => 'مرد وزن کڻندي: ڪارو رنگ',
    '🏋🏻‍♀' => 'عورت وزن کڻندي: گوري رنگت',
    '🏋🏼‍♀' => 'عورت وزن کڻندي: وچولي گوري رنگت',
    '🏋🏽‍♀' => 'عورت وزن کڻندي: پڪو رنگ',
    '🏋🏾‍♀' => 'عورت وزن کڻندي: وچولو ڪارو رنگ',
    '🏋🏿‍♀' => 'عورت وزن کڻندي: ڪارو رنگ',
    '🚴🏻‍♂' => 'مرد سائيڪل هلائيندي: گوري رنگت',
    '🚴🏼‍♂' => 'مرد سائيڪل هلائيندي: وچولي گوري رنگت',
    '🚴🏽‍♂' => 'مرد سائيڪل هلائيندي: پڪو رنگ',
    '🚴🏾‍♂' => 'مرد سائيڪل هلائيندي: وچولو ڪارو رنگ',
    '🚴🏿‍♂' => 'مرد سائيڪل هلائيندي: ڪارو رنگ',
    '🚴🏻‍♀' => 'عورت سائيڪل هلائيندي: گوري رنگت',
    '🚴🏼‍♀' => 'عورت سائيڪل هلائيندي: وچولي گوري رنگت',
    '🚴🏽‍♀' => 'عورت سائيڪل هلائيندي: پڪو رنگ',
    '🚴🏾‍♀' => 'عورت سائيڪل هلائيندي: وچولو ڪارو رنگ',
    '🚴🏿‍♀' => 'عورت سائيڪل هلائيندي: ڪارو رنگ',
    '🚵🏻‍♂' => 'مرد جبل تي سائيڪل هلائيندي: گوري رنگت',
    '🚵🏼‍♂' => 'مرد جبل تي سائيڪل هلائيندي: وچولي گوري رنگت',
    '🚵🏽‍♂' => 'مرد جبل تي سائيڪل هلائيندي: پڪو رنگ',
    '🚵🏾‍♂' => 'مرد جبل تي سائيڪل هلائيندي: وچولو ڪارو رنگ',
    '🚵🏿‍♂' => 'مرد جبل تي سائيڪل هلائيندي: ڪارو رنگ',
    '🚵🏻‍♀' => 'عورت جبل تي سائيڪل هلائيندي: گوري رنگت',
    '🚵🏼‍♀' => 'عورت جبل تي سائيڪل هلائيندي: وچولي گوري رنگت',
    '🚵🏽‍♀' => 'عورت جبل تي سائيڪل هلائيندي: پڪو رنگ',
    '🚵🏾‍♀' => 'عورت جبل تي سائيڪل هلائيندي: وچولو ڪارو رنگ',
    '🚵🏿‍♀' => 'عورت جبل تي سائيڪل هلائيندي: ڪارو رنگ',
    '🤸🏻‍♂' => 'مرد ڪارٽ وهيلنگ ڪندي: گوري رنگت',
    '🤸🏼‍♂' => 'مرد ڪارٽ وهيلنگ ڪندي: وچولي گوري رنگت',
    '🤸🏽‍♂' => 'مرد ڪارٽ وهيلنگ ڪندي: پڪو رنگ',
    '🤸🏾‍♂' => 'مرد ڪارٽ وهيلنگ ڪندي: وچولو ڪارو رنگ',
    '🤸🏿‍♂' => 'مرد ڪارٽ وهيلنگ ڪندي: ڪارو رنگ',
    '🤸🏻‍♀' => 'عورت ڪارٽ وهيلنگ ڪندي: گوري رنگت',
    '🤸🏼‍♀' => 'عورت ڪارٽ وهيلنگ ڪندي: وچولي گوري رنگت',
    '🤸🏽‍♀' => 'عورت ڪارٽ وهيلنگ ڪندي: پڪو رنگ',
    '🤸🏾‍♀' => 'عورت ڪارٽ وهيلنگ ڪندي: وچولو ڪارو رنگ',
    '🤸🏿‍♀' => 'عورت ڪارٽ وهيلنگ ڪندي: ڪارو رنگ',
    '🤼🏻‍♀' => 'عورتون ڪشتي وڙهندي: گوري رنگت',
    '🤼🏼‍♀' => 'عورتون ڪشتي وڙهندي: وچولي گوري رنگت',
    '🤼🏽‍♀' => 'عورتون ڪشتي وڙهندي: پڪو رنگ',
    '🤼🏾‍♀' => 'عورتون ڪشتي وڙهندي: وچولو ڪارو رنگ',
    '🤼🏿‍♀' => 'عورتون ڪشتي وڙهندي: ڪارو رنگ',
    '🤼🏻‍♂' => 'مرد ڪشتي وڙهندي: گوري رنگت',
    '🤼🏼‍♂' => 'مرد ڪشتي وڙهندي: وچولي گوري رنگت',
    '🤼🏽‍♂' => 'مرد ڪشتي وڙهندي: پڪو رنگ',
    '🤼🏾‍♂' => 'مرد ڪشتي وڙهندي: وچولو ڪارو رنگ',
    '🤼🏿‍♂' => 'مرد ڪشتي وڙهندي: ڪارو رنگ',
    '🤽🏻‍♂' => 'مرد پاڻي وارو پولو کيڏيندي: گوري رنگت',
    '🤽🏼‍♂' => 'مرد پاڻي وارو پولو کيڏيندي: وچولي گوري رنگت',
    '🤽🏽‍♂' => 'مرد پاڻي وارو پولو کيڏيندي: پڪو رنگ',
    '🤽🏾‍♂' => 'مرد پاڻي وارو پولو کيڏيندي: وچولو ڪارو رنگ',
    '🤽🏿‍♂' => 'مرد پاڻي وارو پولو کيڏيندي: ڪارو رنگ',
    '🤽🏻‍♀' => 'عورت پاڻي وارو پولو کيڏيندي: گوري رنگت',
    '🤽🏼‍♀' => 'عورت پاڻي وارو پولو کيڏيندي: وچولي گوري رنگت',
    '🤽🏽‍♀' => 'عورت پاڻي وارو پولو کيڏيندي: پڪو رنگ',
    '🤽🏾‍♀' => 'عورت پاڻي وارو پولو کيڏيندي: وچولو ڪارو رنگ',
    '🤽🏿‍♀' => 'عورت پاڻي وارو پولو کيڏيندي: ڪارو رنگ',
    '🤾🏻‍♂' => 'ماڻهو هٿ جو بال کيڏيندي: گوري رنگت',
    '🤾🏼‍♂' => 'ماڻهو هٿ جو بال کيڏيندي: وچولي گوري رنگت',
    '🤾🏽‍♂' => 'ماڻهو هٿ جو بال کيڏيندي: پڪو رنگ',
    '🤾🏾‍♂' => 'ماڻهو هٿ جو بال کيڏيندي: وچولو ڪارو رنگ',
    '🤾🏿‍♂' => 'ماڻهو هٿ جو بال کيڏيندي: ڪارو رنگ',
    '🤾🏻‍♀' => 'عورت هٿ جو بال کيڏيندي: گوري رنگت',
    '🤾🏼‍♀' => 'عورت هٿ جو بال کيڏيندي: وچولي گوري رنگت',
    '🤾🏽‍♀' => 'عورت هٿ جو بال کيڏيندي: پڪو رنگ',
    '🤾🏾‍♀' => 'عورت هٿ جو بال کيڏيندي: وچولو ڪارو رنگ',
    '🤾🏿‍♀' => 'عورت هٿ جو بال کيڏيندي: ڪارو رنگ',
    '🤹🏻‍♂' => 'مرد جادوگري ڪندي: گوري رنگت',
    '🤹🏼‍♂' => 'مرد جادوگري ڪندي: وچولي گوري رنگت',
    '🤹🏽‍♂' => 'مرد جادوگري ڪندي: پڪو رنگ',
    '🤹🏾‍♂' => 'مرد جادوگري ڪندي: وچولو ڪارو رنگ',
    '🤹🏿‍♂' => 'مرد جادوگري ڪندي: ڪارو رنگ',
    '🤹🏻‍♀' => 'عورت جادوگري ڪندي: گوري رنگت',
    '🤹🏼‍♀' => 'عورت جادوگري ڪندي: وچولي گوري رنگت',
    '🤹🏽‍♀' => 'عورت جادوگري ڪندي: پڪو رنگ',
    '🤹🏾‍♀' => 'عورت جادوگري ڪندي: وچولو ڪارو رنگ',
    '🤹🏿‍♀' => 'عورت جادوگري ڪندي: ڪارو رنگ',
    '🧘🏻‍♂' => 'مرد لوٽس پوزيشن ۾: گوري رنگت',
    '🧘🏼‍♂' => 'مرد لوٽس پوزيشن ۾: وچولي گوري رنگت',
    '🧘🏽‍♂' => 'مرد لوٽس پوزيشن ۾: پڪو رنگ',
    '🧘🏾‍♂' => 'مرد لوٽس پوزيشن ۾: وچولو ڪارو رنگ',
    '🧘🏿‍♂' => 'مرد لوٽس پوزيشن ۾: ڪارو رنگ',
    '🧘🏻‍♀' => 'عورت لوٽس پوزيشن ۾: گوري رنگت',
    '🧘🏼‍♀' => 'عورت لوٽس پوزيشن ۾: وچولي گوري رنگت',
    '🧘🏽‍♀' => 'عورت لوٽس پوزيشن ۾: پڪو رنگ',
    '🧘🏾‍♀' => 'عورت لوٽس پوزيشن ۾: وچولو ڪارو رنگ',
    '🧘🏿‍♀' => 'عورت لوٽس پوزيشن ۾: ڪارو رنگ',
    '🧑‍🦰' => 'بالغ: ڳاڙها وار',
    '🧑‍🦱' => 'بالغ: گهنگرالو وار',
    '🧑‍🦳' => 'بالغ: اڇا وار',
    '🧑‍🦲' => 'بالغ: گنجو',
    '👨‍🦰' => 'ماڻهو: ڳاڙها وار',
    '👨‍🦱' => 'ماڻهو: گهنگرالو وار',
    '👨‍🦳' => 'ماڻهو: اڇا وار',
    '👨‍🦲' => 'ماڻهو: گنجو',
    '👩‍🦰' => 'عورت: ڳاڙها وار',
    '👩‍🦱' => 'عورت: گهنگرالو وار',
    '👩‍🦳' => 'عورت: اڇا وار',
    '👩‍🦲' => 'عورت: گنجو',
    '🚶‍➡' => 'شخص هلندي: ساڄي طرف منهن',
    '🧎‍➡' => 'گوڏن ڀر ويٺل ماڻهو: ساڄي طرف منهن',
    '🏃‍➡' => 'شخص ڊوڙندي: ساڄي طرف منهن',
    '👨‍👦' => 'ڪٽنب: ماڻهو، ڇوڪرو',
    '👨‍👧' => 'ڪٽنب: ماڻهو، ڇوڪري',
    '👩‍👦' => 'ڪٽنب: عورت، ڇوڪرو',
    '👩‍👧' => 'ڪٽنب: عورت، ڇوڪري',
    '😶‍🌫' => 'بادلن ۾ چهرو',
    '😮‍💨' => 'ساه ڇڏڻ وارو چهرو',
    '🙂‍↕' => 'عمودي طور تي مٿو لوڌڻ',
    '😵‍💫' => 'پيچدار اک وارو چهرو',
    '❤‍🔥' => 'باھ ۾ دل',
    '❤‍🩹' => 'زخمي دل',
    '👁‍🗨' => 'ڳالهه بلبلن ۾ اک',
    '🧔‍♂' => 'ماڻهو: ڏاڙهي',
    '👱‍♂' => 'ماڻهو: ڀورا وار',
    '🧔‍♀' => 'عورت: ڏاڙهي',
    '👱‍♀' => 'عورت: ڀورا وار',
    '🙍‍♂' => 'مرد پريشان',
    '🙍‍♀' => 'عورت پريشان',
    '🙎‍♂' => 'مرد ناپسند ڪندي',
    '🙎‍♀' => 'عورت ناپسند ڪندي',
    '🙅‍♂' => 'مرد نه جو اشارو ڪندي',
    '🙅‍♀' => 'عورت نه جو اشارو ڪندي',
    '🙆‍♂' => 'مرد ٺيڪ جو اشارو ڪندي',
    '🙆‍♀' => 'عورت ٺيڪ جو اشارو ڪندي',
    '💁‍♂' => 'مرد هٿ ٿپڪائيندي',
    '💁‍♀' => 'عورت هٿ ٿپڪائيندي',
    '🙋‍♂' => 'مرد هٿ مٿي ڪندي',
    '🙋‍♀' => 'عورت هٿ مٿي ڪندي',
    '🧏‍♂' => 'ٻوڙو ماڻهو',
    '🧏‍♀' => 'ٻوڙي عورت',
    '🙇‍♂' => 'مرد جهڪندي',
    '🙇‍♀' => 'عورت جھڪندي',
    '🤦‍♂' => 'ماڻهو جو نراڙ تي هٿ ڏيڻ',
    '🤦‍♀' => 'عورت جو نراڙ تي هٿ ڏيڻ',
    '🤷‍♂' => 'مرد اچڪائيندي',
    '🤷‍♀' => 'عورت اچڪائيندي',
    '🧑‍⚕' => 'هيلٿ ورڪر',
    '👨‍⚕' => 'ماڻهو صحت خدمتگار',
    '👩‍⚕' => 'عورت صحت خدمتگار',
    '🧑‍🎓' => 'شاگرد',
    '👨‍🎓' => 'مرد شاگرد',
    '👩‍🎓' => 'عورت شاگرد',
    '🧑‍🏫' => 'استاد',
    '👨‍🏫' => 'مرد استاد',
    '👩‍🏫' => 'عورت استاد',
    '🧑‍⚖' => 'جج',
    '👨‍⚖' => 'مرد جج',
    '👩‍⚖' => 'عورت جج',
    '🧑‍🌾' => 'هاري',
    '👨‍🌾' => 'مرد هاري',
    '👩‍🌾' => 'عورت هاري',
    '🧑‍🍳' => 'باورچي',
    '👨‍🍳' => 'مرد بورچي',
    '👩‍🍳' => 'عورت بورچي',
    '🧑‍🔧' => 'مستري',
    '👨‍🔧' => 'مرد مستري',
    '👩‍🔧' => 'عورت مستري',
    '🧑‍🏭' => 'فيڪٽري ورڪر',
    '👨‍🏭' => 'مرد ڪارخانو مزدور',
    '👩‍🏭' => 'عورت ڪارخانو مزدور',
    '🧑‍💼' => 'آفيس ورڪر',
    '👨‍💼' => 'مرد آفيس ورڪر',
    '👩‍💼' => 'عورت آفيس ورڪر',
    '🧑‍🔬' => 'سائنس دان',
    '👨‍🔬' => 'مرد سائنسدان',
    '👩‍🔬' => 'عورت سائنسدان',
    '🧑‍💻' => 'ٽيڪنو لاجسٽ',
    '👨‍💻' => 'مرد ٽيڪنالوجسٽ',
    '👩‍💻' => 'عورت ٽيڪنالوجسٽ',
    '🧑‍🎤' => 'ڳائڻو',
    '👨‍🎤' => 'مرد ڳائڻو',
    '👩‍🎤' => 'عورت ڳائڻي',
    '🧑‍🎨' => 'فنڪار',
    '👨‍🎨' => 'مرد فنڪار',
    '👩‍🎨' => 'عورت فنڪار',
    '🧑‍✈' => 'پائيليٽ',
    '👨‍✈' => 'مرد پائيليٽ',
    '👩‍✈' => 'عورت پائيليٽ',
    '🧑‍🚀' => 'ايسٽرو ناٽ',
    '👨‍🚀' => 'مرد خلانورد',
    '👩‍🚀' => 'عورت خلانورد',
    '🧑‍🚒' => 'باهه وسائينڙ',
    '👨‍🚒' => 'مرد باهه وسائيندڙ',
    '👩‍🚒' => 'عورت باهه وسائيندڙ',
    '👮‍♂' => 'مرد پوليس آفيسر',
    '👮‍♀' => 'عورت پوليس آفيسر',
    '🕵‍♂' => 'مرد جاسوس',
    '🕵‍♀' => 'عورت جاسوس',
    '💂‍♂' => 'مرد نگهبان',
    '💂‍♀' => 'عورت نگهبان',
    '👷‍♂' => 'مرد اڏاوت جو ڪم ڪندڙ',
    '👷‍♀' => 'عورت اڏاوت جو ڪم ڪندڙ',
    '👳‍♂' => 'مرد کي پگڙي پاتل',
    '👳‍♀' => 'عورت کي پگڙي پاتل',
    '🤵‍♂' => 'ٽيڪسيڊو ۾ ماڻهو',
    '🤵‍♀' => 'ٽيڪسيڊو ۾ عورت',
    '👰‍♂' => 'ويل سان مرد',
    '👰‍♀' => 'ويل سان عورت',
    '👩‍🍼' => 'ٻار کي کير پياريندڙ عورت',
    '👨‍🍼' => 'ٻار کي کير پياريندڙ ماڻهو',
    '🧑‍🍼' => 'ٻار کي کير پياريندڙ شخص',
    '🧑‍🎄' => 'مڪس ڪلاز',
    '🦸‍♂' => 'مرد سپر هيرو',
    '🦸‍♀' => 'عورت سپر هيرو',
    '🦹‍♂' => 'مرد سپر ولن',
    '🦹‍♀' => 'عورت سپر ولن',
    '🧙‍♂' => 'مرد، جادوگر',
    '🧙‍♀' => 'عورت جادوگرني',
    '🧚‍♂' => 'مرد فرشتو',
    '🧚‍♀' => 'عورت پري',
    '🧛‍♂' => 'مرد ڀوت',
    '🧛‍♀' => 'عورت ڀوت',
    '🧜‍♂' => 'جل مانس',
    '🧜‍♀' => 'جل پري',
    '🧝‍♂' => 'مرد بونا',
    '🧝‍♀' => 'عورت بونا',
    '🧞‍♂' => 'مرد جن',
    '🧞‍♀' => 'عورت جن',
    '🧟‍♂' => 'مرد زومبي',
    '🧟‍♀' => 'عورت زومبي',
    '💆‍♂' => 'مساج وٺندڙ مرد',
    '💆‍♀' => 'مساج وٺندڙ عورت',
    '💇‍♂' => 'مرد وار ڪٽرائيندي',
    '💇‍♀' => 'عورت وار ڪٽرائيندي',
    '🚶‍♂' => 'مرد سير ڪندي',
    '🚶‍♀' => 'عورت سير ڪندي',
    '🧍‍♂' => 'ماڻهو بيٺل',
    '🧍‍♀' => 'بيٺل عورت',
    '🧎‍♂' => 'گوڏا کوڙيل ماڻهو',
    '🧎‍♀' => 'گوڏا کوڙيل عورت',
    '🧑‍🦯' => 'پروبنگ لٺ وارو ماڻهو',
    '👨‍🦯' => 'پروبنگ ڪين سان ماڻهو',
    '👩‍🦯' => 'پروبنگ ڪين سان عورت',
    '🧑‍🦼' => 'موٽر واري وهيل چيئر تي شخص',
    '👨‍🦼' => 'موٽر واري وهيل چيئر ۾ ماڻهو',
    '👩‍🦼' => 'موٽر واري ڦيٿائين ڪرسي تي عورت',
    '🧑‍🦽' => 'ماڻھو دستي ويل چيئر تي',
    '👨‍🦽' => 'دستي وهيل چيئر ۾ ماڻهو',
    '👩‍🦽' => 'دستي وهيل چيئر ۾ عورت',
    '🏃‍♂' => 'مرد ڊوڙندي',
    '🏃‍♀' => 'ڊوڙندي عورت',
    '🧑‍🩰' => 'بيلي ناچڻي',
    '👯‍♂' => 'خرگوش جي ڪنن وارو مرد',
    '👯‍♀' => 'خرگوش جي ڪنن وري عورت',
    '🧖‍♂' => 'مرد ٻاڦ واري ڪمري ۾',
    '🧖‍♀' => 'عورت ٻاڦ واري ڪمري ۾',
    '🧗‍♂' => 'مرد چڙهندي',
    '🧗‍♀' => 'عورت چڙهندي',
    '🏌‍♂' => 'مرد گولف کيڏيندي',
    '🏌‍♀' => 'عورت گولف کيڏيندي',
    '🏄‍♂' => 'مرد سرفنگ ڪندي',
    '🏄‍♀' => 'عورت سرفنگ ڪندي',
    '🚣‍♂' => 'مرد ٻيڙي ۾ چپو هلائيندي',
    '🚣‍♀' => 'عورت ٻيڙي ۾ چپو هلائيندي',
    '🏊‍♂' => 'مرد ترندي',
    '🏊‍♀' => 'عورت ترندي',
    '⛹‍♂' => 'مرد بائونسنگ بال سان کيڏندي',
    '⛹‍♀' => 'عورت بائونسنگ بال سان کيڏندي',
    '🏋‍♂' => 'مرد وزن کڻندي',
    '🏋‍♀' => 'عورت وزن کڻندي',
    '🚴‍♂' => 'مرد سائيڪل هلائيندي',
    '🚴‍♀' => 'عورت سائيڪل هلائيندي',
    '🚵‍♂' => 'مرد جبل تي سائيڪل هلائيندي',
    '🚵‍♀' => 'عورت جبل تي سائيڪل هلائيندي',
    '🤸‍♂' => 'مرد ڪارٽ وهيلنگ ڪندي',
    '🤸‍♀' => 'عورت ڪارٽ وهيلنگ ڪندي',
    '🤼‍♂' => 'مرد ڪشتي وڙهندي',
    '🤼‍♀' => 'عورتون ڪشتي وڙهندي',
    '🤽‍♂' => 'مرد پاڻي وارو پولو کيڏيندي',
    '🤽‍♀' => 'عورت پاڻي وارو پولو کيڏيندي',
    '🤾‍♂' => 'ماڻهو هٿ جو بال کيڏيندي',
    '🤾‍♀' => 'عورت هٿ جو بال کيڏيندي',
    '🤹‍♂' => 'مرد جادوگري ڪندي',
    '🤹‍♀' => 'عورت جادوگري ڪندي',
    '🧘‍♂' => 'مرد لوٽس پوزيشن ۾',
    '🧘‍♀' => 'عورت لوٽس پوزيشن ۾',
    '🧑‍🧒' => 'ڪٽنب: بالغ، ٻار',
    '🐕‍🦺' => 'خدمتي ڪتو',
    '🐈‍⬛' => 'ڪاري ٻليءَ',
    '🐻‍❄' => 'پولر رِڇ',
    '🐦‍⬛' => 'ڪارو پکي',
    '🐦‍🔥' => 'خيالي پکي',
    '🍋‍🟩' => 'وڏو ليمو',
    '🍄‍🟫' => 'ناسي کنڀي',
    '⛓‍💥' => 'ٽٽل زنجير',
    '🏳‍🌈' => 'انڊلٺي جھنڊو',
    '🏳‍⚧' => 'نيرو، گلابي، ۽ اڇي جهنڊي',
    '🏴‍☠' => 'پائريٽ نشان',
    '👋🏻' => 'لڏندڙ هٿ: گوري رنگت',
    '👋🏼' => 'لڏندڙ هٿ: وچولي گوري رنگت',
    '👋🏽' => 'لڏندڙ هٿ: پڪو رنگ',
    '👋🏾' => 'لڏندڙ هٿ: وچولو ڪارو رنگ',
    '👋🏿' => 'لڏندڙ هٿ: ڪارو رنگ',
    '🤚🏻' => 'هٿ جي پٺ مٿي ڪيل: گوري رنگت',
    '🤚🏼' => 'هٿ جي پٺ مٿي ڪيل: وچولي گوري رنگت',
    '🤚🏽' => 'هٿ جي پٺ مٿي ڪيل: پڪو رنگ',
    '🤚🏾' => 'هٿ جي پٺ مٿي ڪيل: وچولو ڪارو رنگ',
    '🤚🏿' => 'هٿ جي پٺ مٿي ڪيل: ڪارو رنگ',
    '🖐🏻' => 'مٿي ڪيل هٿ کليل آڱرين سان: گوري رنگت',
    '🖐🏼' => 'مٿي ڪيل هٿ کليل آڱرين سان: وچولي گوري رنگت',
    '🖐🏽' => 'مٿي ڪيل هٿ کليل آڱرين سان: پڪو رنگ',
    '🖐🏾' => 'مٿي ڪيل هٿ کليل آڱرين سان: وچولو ڪارو رنگ',
    '🖐🏿' => 'مٿي ڪيل هٿ کليل آڱرين سان: ڪارو رنگ',
    '✋🏻' => 'مٿي ڪيل هٿ: گوري رنگت',
    '✋🏼' => 'مٿي ڪيل هٿ: وچولي گوري رنگت',
    '✋🏽' => 'مٿي ڪيل هٿ: پڪو رنگ',
    '✋🏾' => 'مٿي ڪيل هٿ: وچولو ڪارو رنگ',
    '✋🏿' => 'مٿي ڪيل هٿ: ڪارو رنگ',
    '🖖🏻' => 'ولڪن سلام: گوري رنگت',
    '🖖🏼' => 'ولڪن سلام: وچولي گوري رنگت',
    '🖖🏽' => 'ولڪن سلام: پڪو رنگ',
    '🖖🏾' => 'ولڪن سلام: وچولو ڪارو رنگ',
    '🖖🏿' => 'ولڪن سلام: ڪارو رنگ',
    '🫱🏻' => 'ساڄي پاسي ويندڙ ھٿ: گوري رنگت',
    '🫱🏼' => 'ساڄي پاسي ويندڙ ھٿ: وچولي گوري رنگت',
    '🫱🏽' => 'ساڄي پاسي ويندڙ ھٿ: پڪو رنگ',
    '🫱🏾' => 'ساڄي پاسي ويندڙ ھٿ: وچولو ڪارو رنگ',
    '🫱🏿' => 'ساڄي پاسي ويندڙ ھٿ: ڪارو رنگ',
    '🫲🏻' => 'کاٻي پاسي ويندڙ ھٿ: گوري رنگت',
    '🫲🏼' => 'کاٻي پاسي ويندڙ ھٿ: وچولي گوري رنگت',
    '🫲🏽' => 'کاٻي پاسي ويندڙ ھٿ: پڪو رنگ',
    '🫲🏾' => 'کاٻي پاسي ويندڙ ھٿ: وچولو ڪارو رنگ',
    '🫲🏿' => 'کاٻي پاسي ويندڙ ھٿ: ڪارو رنگ',
    '🫳🏻' => 'ھيٺ تري وارو ھٿ: گوري رنگت',
    '🫳🏼' => 'ھيٺ تري وارو ھٿ: وچولي گوري رنگت',
    '🫳🏽' => 'ھيٺ تري وارو ھٿ: پڪو رنگ',
    '🫳🏾' => 'ھيٺ تري وارو ھٿ: وچولو ڪارو رنگ',
    '🫳🏿' => 'ھيٺ تري وارو ھٿ: ڪارو رنگ',
    '🫴🏻' => 'مٿي تري وارو ھٿ: گوري رنگت',
    '🫴🏼' => 'مٿي تري وارو ھٿ: وچولي گوري رنگت',
    '🫴🏽' => 'مٿي تري وارو ھٿ: پڪو رنگ',
    '🫴🏾' => 'مٿي تري وارو ھٿ: وچولو ڪارو رنگ',
    '🫴🏿' => 'مٿي تري وارو ھٿ: ڪارو رنگ',
    '🫷🏻' => 'کاٻي پاسي ڌڪيندڙ ھٿ: گوري رنگت',
    '🫷🏼' => 'کاٻي پاسي ڌڪيندڙ ھٿ: وچولي گوري رنگت',
    '🫷🏽' => 'کاٻي پاسي ڌڪيندڙ ھٿ: پڪو رنگ',
    '🫷🏾' => 'کاٻي پاسي ڌڪيندڙ ھٿ: وچولو ڪارو رنگ',
    '🫷🏿' => 'کاٻي پاسي ڌڪيندڙ ھٿ: ڪارو رنگ',
    '🫸🏻' => 'ساڄي پاسي ڌڪيندڙ ھٿ: گوري رنگت',
    '🫸🏼' => 'ساڄي پاسي ڌڪيندڙ ھٿ: وچولي گوري رنگت',
    '🫸🏽' => 'ساڄي پاسي ڌڪيندڙ ھٿ: پڪو رنگ',
    '🫸🏾' => 'ساڄي پاسي ڌڪيندڙ ھٿ: وچولو ڪارو رنگ',
    '🫸🏿' => 'ساڄي پاسي ڌڪيندڙ ھٿ: ڪارو رنگ',
    '👌🏻' => 'ٺيڪ وارو هٿ: گوري رنگت',
    '👌🏼' => 'ٺيڪ وارو هٿ: وچولي گوري رنگت',
    '👌🏽' => 'ٺيڪ وارو هٿ: پڪو رنگ',
    '👌🏾' => 'ٺيڪ وارو هٿ: وچولو ڪارو رنگ',
    '👌🏿' => 'ٺيڪ وارو هٿ: ڪارو رنگ',
    '🤌🏻' => 'پنچ ٿيل آڱريون: گوري رنگت',
    '🤌🏼' => 'پنچ ٿيل آڱريون: وچولي گوري رنگت',
    '🤌🏽' => 'پنچ ٿيل آڱريون: پڪو رنگ',
    '🤌🏾' => 'پنچ ٿيل آڱريون: وچولو ڪارو رنگ',
    '🤌🏿' => 'پنچ ٿيل آڱريون: ڪارو رنگ',
    '🤏🏻' => 'پنچنگ هٿ: گوري رنگت',
    '🤏🏼' => 'پنچنگ هٿ: وچولي گوري رنگت',
    '🤏🏽' => 'پنچنگ هٿ: پڪو رنگ',
    '🤏🏾' => 'پنچنگ هٿ: وچولو ڪارو رنگ',
    '🤏🏿' => 'پنچنگ هٿ: ڪارو رنگ',
    '✌🏻' => 'فتح جو نشان: گوري رنگت',
    '✌🏼' => 'فتح جو نشان: وچولي گوري رنگت',
    '✌🏽' => 'فتح جو نشان: پڪو رنگ',
    '✌🏾' => 'فتح جو نشان: وچولو ڪارو رنگ',
    '✌🏿' => 'فتح جو نشان: ڪارو رنگ',
    '🤞🏻' => 'ڪراس ٿيل آڱريون: گوري رنگت',
    '🤞🏼' => 'ڪراس ٿيل آڱريون: وچولي گوري رنگت',
    '🤞🏽' => 'ڪراس ٿيل آڱريون: پڪو رنگ',
    '🤞🏾' => 'ڪراس ٿيل آڱريون: وچولو ڪارو رنگ',
    '🤞🏿' => 'ڪراس ٿيل آڱريون: ڪارو رنگ',
    '🫰🏻' => 'پھرين آڱر ۽ آڱوٺو مڙيل ھٿ: گوري رنگت',
    '🫰🏼' => 'پھرين آڱر ۽ آڱوٺو مڙيل ھٿ: وچولي گوري رنگت',
    '🫰🏽' => 'پھرين آڱر ۽ آڱوٺو مڙيل ھٿ: پڪو رنگ',
    '🫰🏾' => 'پھرين آڱر ۽ آڱوٺو مڙيل ھٿ: وچولو ڪارو رنگ',
    '🫰🏿' => 'پھرين آڱر ۽ آڱوٺو مڙيل ھٿ: ڪارو رنگ',
    '🤟🏻' => 'پيار جو اشارو: گوري رنگت',
    '🤟🏼' => 'پيار جو اشارو: وچولي گوري رنگت',
    '🤟🏽' => 'پيار جو اشارو: پڪو رنگ',
    '🤟🏾' => 'پيار جو اشارو: وچولو ڪارو رنگ',
    '🤟🏿' => 'پيار جو اشارو: ڪارو رنگ',
    '🤘🏻' => 'سڱن جو نشان: گوري رنگت',
    '🤘🏼' => 'سڱن جو نشان: وچولي گوري رنگت',
    '🤘🏽' => 'سڱن جو نشان: پڪو رنگ',
    '🤘🏾' => 'سڱن جو نشان: وچولو ڪارو رنگ',
    '🤘🏿' => 'سڱن جو نشان: ڪارو رنگ',
    '🤙🏻' => 'مونکي ڪال ڪريو هٿ: گوري رنگت',
    '🤙🏼' => 'مونکي ڪال ڪريو هٿ: وچولي گوري رنگت',
    '🤙🏽' => 'مونکي ڪال ڪريو هٿ: پڪو رنگ',
    '🤙🏾' => 'مونکي ڪال ڪريو هٿ: وچولو ڪارو رنگ',
    '🤙🏿' => 'مونکي ڪال ڪريو هٿ: ڪارو رنگ',
    '👈🏻' => 'کاٻي هٿ جي آڱر کاٻي طرف اشارو ڪندي: گوري رنگت',
    '👈🏼' => 'کاٻي هٿ جي آڱر کاٻي طرف اشارو ڪندي: وچولي گوري رنگت',
    '👈🏽' => 'کاٻي هٿ جي آڱر کاٻي طرف اشارو ڪندي: پڪو رنگ',
    '👈🏾' => 'کاٻي هٿ جي آڱر کاٻي طرف اشارو ڪندي: وچولو ڪارو رنگ',
    '👈🏿' => 'کاٻي هٿ جي آڱر کاٻي طرف اشارو ڪندي: ڪارو رنگ',
    '👉🏻' => 'کاٻي هٿ جي آڱر ساڄي طرف اشارو ڪندي: گوري رنگت',
    '👉🏼' => 'کاٻي هٿ جي آڱر ساڄي طرف اشارو ڪندي: وچولي گوري رنگت',
    '👉🏽' => 'کاٻي هٿ جي آڱر ساڄي طرف اشارو ڪندي: پڪو رنگ',
    '👉🏾' => 'کاٻي هٿ جي آڱر ساڄي طرف اشارو ڪندي: وچولو ڪارو رنگ',
    '👉🏿' => 'کاٻي هٿ جي آڱر ساڄي طرف اشارو ڪندي: ڪارو رنگ',
    '👆🏻' => 'کاٻي هٿ جي آڱر مٿي اشارو ڪندي: گوري رنگت',
    '👆🏼' => 'کاٻي هٿ جي آڱر مٿي اشارو ڪندي: وچولي گوري رنگت',
    '👆🏽' => 'کاٻي هٿ جي آڱر مٿي اشارو ڪندي: پڪو رنگ',
    '👆🏾' => 'کاٻي هٿ جي آڱر مٿي اشارو ڪندي: وچولو ڪارو رنگ',
    '👆🏿' => 'کاٻي هٿ جي آڱر مٿي اشارو ڪندي: ڪارو رنگ',
    '🖕🏻' => 'وچين آڱر: گوري رنگت',
    '🖕🏼' => 'وچين آڱر: وچولي گوري رنگت',
    '🖕🏽' => 'وچين آڱر: پڪو رنگ',
    '🖕🏾' => 'وچين آڱر: وچولو ڪارو رنگ',
    '🖕🏿' => 'وچين آڱر: ڪارو رنگ',
    '👇🏻' => 'کاٻي هٿ جي آڱر هيٺ اشارو ڪندي: گوري رنگت',
    '👇🏼' => 'کاٻي هٿ جي آڱر هيٺ اشارو ڪندي: وچولي گوري رنگت',
    '👇🏽' => 'کاٻي هٿ جي آڱر هيٺ اشارو ڪندي: پڪو رنگ',
    '👇🏾' => 'کاٻي هٿ جي آڱر هيٺ اشارو ڪندي: وچولو ڪارو رنگ',
    '👇🏿' => 'کاٻي هٿ جي آڱر هيٺ اشارو ڪندي: ڪارو رنگ',
    '☝🏻' => 'آڱر مٿي طرف اشارو ڪندي: گوري رنگت',
    '☝🏼' => 'آڱر مٿي طرف اشارو ڪندي: وچولي گوري رنگت',
    '☝🏽' => 'آڱر مٿي طرف اشارو ڪندي: پڪو رنگ',
    '☝🏾' => 'آڱر مٿي طرف اشارو ڪندي: وچولو ڪارو رنگ',
    '☝🏿' => 'آڱر مٿي طرف اشارو ڪندي: ڪارو رنگ',
    '🫵🏻' => 'ڏسڻي آڱر ڏسڻ واري ڏانھن اشارو ڪندي: گوري رنگت',
    '🫵🏼' => 'ڏسڻي آڱر ڏسڻ واري ڏانھن اشارو ڪندي: وچولي گوري رنگت',
    '🫵🏽' => 'ڏسڻي آڱر ڏسڻ واري ڏانھن اشارو ڪندي: پڪو رنگ',
    '🫵🏾' => 'ڏسڻي آڱر ڏسڻ واري ڏانھن اشارو ڪندي: وچولو ڪارو رنگ',
    '🫵🏿' => 'ڏسڻي آڱر ڏسڻ واري ڏانھن اشارو ڪندي: ڪارو رنگ',
    '👍🏻' => 'مٿي انگوٺو: گوري رنگت',
    '👍🏼' => 'مٿي انگوٺو: وچولي گوري رنگت',
    '👍🏽' => 'مٿي انگوٺو: پڪو رنگ',
    '👍🏾' => 'مٿي انگوٺو: وچولو ڪارو رنگ',
    '👍🏿' => 'مٿي انگوٺو: ڪارو رنگ',
    '👎🏻' => 'هيٺ انگوٺو: گوري رنگت',
    '👎🏼' => 'هيٺ انگوٺو: وچولي گوري رنگت',
    '👎🏽' => 'هيٺ انگوٺو: پڪو رنگ',
    '👎🏾' => 'هيٺ انگوٺو: وچولو ڪارو رنگ',
    '👎🏿' => 'هيٺ انگوٺو: ڪارو رنگ',
    '✊🏻' => 'مٿي ڪيل مٺي: گوري رنگت',
    '✊🏼' => 'مٿي ڪيل مٺي: وچولي گوري رنگت',
    '✊🏽' => 'مٿي ڪيل مٺي: پڪو رنگ',
    '✊🏾' => 'مٿي ڪيل مٺي: وچولو ڪارو رنگ',
    '✊🏿' => 'مٿي ڪيل مٺي: ڪارو رنگ',
    '👊🏻' => 'ايندڙ مڪو: گوري رنگت',
    '👊🏼' => 'ايندڙ مڪو: وچولي گوري رنگت',
    '👊🏽' => 'ايندڙ مڪو: پڪو رنگ',
    '👊🏾' => 'ايندڙ مڪو: وچولو ڪارو رنگ',
    '👊🏿' => 'ايندڙ مڪو: ڪارو رنگ',
    '🤛🏻' => 'کاٻي طرف منهن ڪندڙ مٺي: گوري رنگت',
    '🤛🏼' => 'کاٻي طرف منهن ڪندڙ مٺي: وچولي گوري رنگت',
    '🤛🏽' => 'کاٻي طرف منهن ڪندڙ مٺي: پڪو رنگ',
    '🤛🏾' => 'کاٻي طرف منهن ڪندڙ مٺي: وچولو ڪارو رنگ',
    '🤛🏿' => 'کاٻي طرف منهن ڪندڙ مٺي: ڪارو رنگ',
    '🤜🏻' => 'ساڄي طرف منهن ڪندڙ مٺي: گوري رنگت',
    '🤜🏼' => 'ساڄي طرف منهن ڪندڙ مٺي: وچولي گوري رنگت',
    '🤜🏽' => 'ساڄي طرف منهن ڪندڙ مٺي: پڪو رنگ',
    '🤜🏾' => 'ساڄي طرف منهن ڪندڙ مٺي: وچولو ڪارو رنگ',
    '🤜🏿' => 'ساڄي طرف منهن ڪندڙ مٺي: ڪارو رنگ',
    '👏🏻' => 'تاڙيون وڄائيندڙ هٿ: گوري رنگت',
    '👏🏼' => 'تاڙيون وڄائيندڙ هٿ: وچولي گوري رنگت',
    '👏🏽' => 'تاڙيون وڄائيندڙ هٿ: پڪو رنگ',
    '👏🏾' => 'تاڙيون وڄائيندڙ هٿ: وچولو ڪارو رنگ',
    '👏🏿' => 'تاڙيون وڄائيندڙ هٿ: ڪارو رنگ',
    '🙌🏻' => 'مٿي ٿيندڙ هٿ: گوري رنگت',
    '🙌🏼' => 'مٿي ٿيندڙ هٿ: وچولي گوري رنگت',
    '🙌🏽' => 'مٿي ٿيندڙ هٿ: پڪو رنگ',
    '🙌🏾' => 'مٿي ٿيندڙ هٿ: وچولو ڪارو رنگ',
    '🙌🏿' => 'مٿي ٿيندڙ هٿ: ڪارو رنگ',
    '🫶🏻' => 'دل جي شڪل وارا ھٿ: گوري رنگت',
    '🫶🏼' => 'دل جي شڪل وارا ھٿ: وچولي گوري رنگت',
    '🫶🏽' => 'دل جي شڪل وارا ھٿ: پڪو رنگ',
    '🫶🏾' => 'دل جي شڪل وارا ھٿ: وچولو ڪارو رنگ',
    '🫶🏿' => 'دل جي شڪل وارا ھٿ: ڪارو رنگ',
    '👐🏻' => 'کليل هٿ: گوري رنگت',
    '👐🏼' => 'کليل هٿ: وچولي گوري رنگت',
    '👐🏽' => 'کليل هٿ: پڪو رنگ',
    '👐🏾' => 'کليل هٿ: وچولو ڪارو رنگ',
    '👐🏿' => 'کليل هٿ: ڪارو رنگ',
    '🤲🏻' => 'تريون مٿي گڏ: گوري رنگت',
    '🤲🏼' => 'تريون مٿي گڏ: وچولي گوري رنگت',
    '🤲🏽' => 'تريون مٿي گڏ: پڪو رنگ',
    '🤲🏾' => 'تريون مٿي گڏ: وچولو ڪارو رنگ',
    '🤲🏿' => 'تريون مٿي گڏ: ڪارو رنگ',
    '🤝🏻' => 'هٿ ملائڻ: گوري رنگت',
    '🤝🏼' => 'هٿ ملائڻ: وچولي گوري رنگت',
    '🤝🏽' => 'هٿ ملائڻ: پڪو رنگ',
    '🤝🏾' => 'هٿ ملائڻ: وچولو ڪارو رنگ',
    '🤝🏿' => 'هٿ ملائڻ: ڪارو رنگ',
    '🙏🏻' => 'ويڙهيل هٿ: گوري رنگت',
    '🙏🏼' => 'ويڙهيل هٿ: وچولي گوري رنگت',
    '🙏🏽' => 'ويڙهيل هٿ: پڪو رنگ',
    '🙏🏾' => 'ويڙهيل هٿ: وچولو ڪارو رنگ',
    '🙏🏿' => 'ويڙهيل هٿ: ڪارو رنگ',
    '✍🏻' => 'لکندڙ هٿ: گوري رنگت',
    '✍🏼' => 'لکندڙ هٿ: وچولي گوري رنگت',
    '✍🏽' => 'لکندڙ هٿ: پڪو رنگ',
    '✍🏾' => 'لکندڙ هٿ: وچولو ڪارو رنگ',
    '✍🏿' => 'لکندڙ هٿ: ڪارو رنگ',
    '💅🏻' => 'ننهن پالش: گوري رنگت',
    '💅🏼' => 'ننهن پالش: وچولي گوري رنگت',
    '💅🏽' => 'ننهن پالش: پڪو رنگ',
    '💅🏾' => 'ننهن پالش: وچولو ڪارو رنگ',
    '💅🏿' => 'ننهن پالش: ڪارو رنگ',
    '🤳🏻' => 'سيلفي: گوري رنگت',
    '🤳🏼' => 'سيلفي: وچولي گوري رنگت',
    '🤳🏽' => 'سيلفي: پڪو رنگ',
    '🤳🏾' => 'سيلفي: وچولو ڪارو رنگ',
    '🤳🏿' => 'سيلفي: ڪارو رنگ',
    '💪🏻' => 'مڙيل ٻانهن تي ڏورو: گوري رنگت',
    '💪🏼' => 'مڙيل ٻانهن تي ڏورو: وچولي گوري رنگت',
    '💪🏽' => 'مڙيل ٻانهن تي ڏورو: پڪو رنگ',
    '💪🏾' => 'مڙيل ٻانهن تي ڏورو: وچولو ڪارو رنگ',
    '💪🏿' => 'مڙيل ٻانهن تي ڏورو: ڪارو رنگ',
    '🦵🏻' => 'ٽنگهه: گوري رنگت',
    '🦵🏼' => 'ٽنگهه: وچولي گوري رنگت',
    '🦵🏽' => 'ٽنگهه: پڪو رنگ',
    '🦵🏾' => 'ٽنگهه: وچولو ڪارو رنگ',
    '🦵🏿' => 'ٽنگهه: ڪارو رنگ',
    '🦶🏻' => 'پير: گوري رنگت',
    '🦶🏼' => 'پير: وچولي گوري رنگت',
    '🦶🏽' => 'پير: پڪو رنگ',
    '🦶🏾' => 'پير: وچولو ڪارو رنگ',
    '🦶🏿' => 'پير: ڪارو رنگ',
    '👂🏻' => 'ڪن: گوري رنگت',
    '👂🏼' => 'ڪن: وچولي گوري رنگت',
    '👂🏽' => 'ڪن: پڪو رنگ',
    '👂🏾' => 'ڪن: وچولو ڪارو رنگ',
    '👂🏿' => 'ڪن: ڪارو رنگ',
    '🦻🏻' => 'ٻڌڻ جي آلي سان ڪن: گوري رنگت',
    '🦻🏼' => 'ٻڌڻ جي آلي سان ڪن: وچولي گوري رنگت',
    '🦻🏽' => 'ٻڌڻ جي آلي سان ڪن: پڪو رنگ',
    '🦻🏾' => 'ٻڌڻ جي آلي سان ڪن: وچولو ڪارو رنگ',
    '🦻🏿' => 'ٻڌڻ جي آلي سان ڪن: ڪارو رنگ',
    '👃🏻' => 'نڪ: گوري رنگت',
    '👃🏼' => 'نڪ: وچولي گوري رنگت',
    '👃🏽' => 'نڪ: پڪو رنگ',
    '👃🏾' => 'نڪ: وچولو ڪارو رنگ',
    '👃🏿' => 'نڪ: ڪارو رنگ',
    '👶🏻' => 'ننڍو ٻار: گوري رنگت',
    '👶🏼' => 'ننڍو ٻار: وچولي گوري رنگت',
    '👶🏽' => 'ننڍو ٻار: پڪو رنگ',
    '👶🏾' => 'ننڍو ٻار: وچولو ڪارو رنگ',
    '👶🏿' => 'ننڍو ٻار: ڪارو رنگ',
    '🧒🏻' => 'ٻار: گوري رنگت',
    '🧒🏼' => 'ٻار: وچولي گوري رنگت',
    '🧒🏽' => 'ٻار: پڪو رنگ',
    '🧒🏾' => 'ٻار: وچولو ڪارو رنگ',
    '🧒🏿' => 'ٻار: ڪارو رنگ',
    '👦🏻' => 'ڇوڪرو: گوري رنگت',
    '👦🏼' => 'ڇوڪرو: وچولي گوري رنگت',
    '👦🏽' => 'ڇوڪرو: پڪو رنگ',
    '👦🏾' => 'ڇوڪرو: وچولو ڪارو رنگ',
    '👦🏿' => 'ڇوڪرو: ڪارو رنگ',
    '👧🏻' => 'ڇوڪري: گوري رنگت',
    '👧🏼' => 'ڇوڪري: وچولي گوري رنگت',
    '👧🏽' => 'ڇوڪري: پڪو رنگ',
    '👧🏾' => 'ڇوڪري: وچولو ڪارو رنگ',
    '👧🏿' => 'ڇوڪري: ڪارو رنگ',
    '🧑🏻' => 'بالغ: گوري رنگت',
    '🧑🏼' => 'بالغ: وچولي گوري رنگت',
    '🧑🏽' => 'بالغ: پڪو رنگ',
    '🧑🏾' => 'بالغ: وچولو ڪارو رنگ',
    '🧑🏿' => 'بالغ: ڪارو رنگ',
    '👱🏻' => 'شخش: گوري رنگت، سنهڙا وار',
    '👱🏼' => 'شخش: وچولي گوري رنگت، سنهڙا وار',
    '👱🏽' => 'شخش: پڪو رنگ، سنهڙا وار',
    '👱🏾' => 'شخش: وچولو ڪارو رنگ، سنهڙا وار',
    '👱🏿' => 'شخش: ڪارو رنگ، سنهڙا وار',
    '👨🏻' => 'ماڻهو: گوري رنگت',
    '👨🏼' => 'ماڻهو: وچولي گوري رنگت',
    '👨🏽' => 'ماڻهو: پڪو رنگ',
    '👨🏾' => 'ماڻهو: وچولو ڪارو رنگ',
    '👨🏿' => 'ماڻهو: ڪارو رنگ',
    '🧔🏻' => 'شخص: گوري رنگت، ڏاڙهي',
    '🧔🏼' => 'شخص: وچولي گوري رنگت، ڏاڙهي',
    '🧔🏽' => 'شخص: پڪو رنگ، ڏاڙهي',
    '🧔🏾' => 'شخص: وچولو ڪارو رنگ، ڏاڙهي',
    '🧔🏿' => 'شخص: ڪارو رنگ، ڏاڙهي',
    '👩🏻' => 'عورت: گوري رنگت',
    '👩🏼' => 'عورت: وچولي گوري رنگت',
    '👩🏽' => 'عورت: پڪو رنگ',
    '👩🏾' => 'عورت: وچولو ڪارو رنگ',
    '👩🏿' => 'عورت: ڪارو رنگ',
    '🧓🏻' => 'وڏي عمر جو بالغ: گوري رنگت',
    '🧓🏼' => 'وڏي عمر جو بالغ: وچولي گوري رنگت',
    '🧓🏽' => 'وڏي عمر جو بالغ: پڪو رنگ',
    '🧓🏾' => 'وڏي عمر جو بالغ: وچولو ڪارو رنگ',
    '🧓🏿' => 'وڏي عمر جو بالغ: ڪارو رنگ',
    '👴🏻' => 'پوڙهو ماڻهو: گوري رنگت',
    '👴🏼' => 'پوڙهو ماڻهو: وچولي گوري رنگت',
    '👴🏽' => 'پوڙهو ماڻهو: پڪو رنگ',
    '👴🏾' => 'پوڙهو ماڻهو: وچولو ڪارو رنگ',
    '👴🏿' => 'پوڙهو ماڻهو: ڪارو رنگ',
    '👵🏻' => 'پوڙهي عورت: گوري رنگت',
    '👵🏼' => 'پوڙهي عورت: وچولي گوري رنگت',
    '👵🏽' => 'پوڙهي عورت: پڪو رنگ',
    '👵🏾' => 'پوڙهي عورت: وچولو ڪارو رنگ',
    '👵🏿' => 'پوڙهي عورت: ڪارو رنگ',
    '🙍🏻' => 'پريشان ماڻهو: گوري رنگت',
    '🙍🏼' => 'پريشان ماڻهو: وچولي گوري رنگت',
    '🙍🏽' => 'پريشان ماڻهو: پڪو رنگ',
    '🙍🏾' => 'پريشان ماڻهو: وچولو ڪارو رنگ',
    '🙍🏿' => 'پريشان ماڻهو: ڪارو رنگ',
    '🙎🏻' => 'ماڻهو ناپسند ڪندي: گوري رنگت',
    '🙎🏼' => 'ماڻهو ناپسند ڪندي: وچولي گوري رنگت',
    '🙎🏽' => 'ماڻهو ناپسند ڪندي: پڪو رنگ',
    '🙎🏾' => 'ماڻهو ناپسند ڪندي: وچولو ڪارو رنگ',
    '🙎🏿' => 'ماڻهو ناپسند ڪندي: ڪارو رنگ',
    '🙅🏻' => 'ماڻهو نه جو اشارو ڪندي: گوري رنگت',
    '🙅🏼' => 'ماڻهو نه جو اشارو ڪندي: وچولي گوري رنگت',
    '🙅🏽' => 'ماڻهو نه جو اشارو ڪندي: پڪو رنگ',
    '🙅🏾' => 'ماڻهو نه جو اشارو ڪندي: وچولو ڪارو رنگ',
    '🙅🏿' => 'ماڻهو نه جو اشارو ڪندي: ڪارو رنگ',
    '🙆🏻' => 'ماڻهو ٺيڪ جو اشارو ڪندي: گوري رنگت',
    '🙆🏼' => 'ماڻهو ٺيڪ جو اشارو ڪندي: وچولي گوري رنگت',
    '🙆🏽' => 'ماڻهو ٺيڪ جو اشارو ڪندي: پڪو رنگ',
    '🙆🏾' => 'ماڻهو ٺيڪ جو اشارو ڪندي: وچولو ڪارو رنگ',
    '🙆🏿' => 'ماڻهو ٺيڪ جو اشارو ڪندي: ڪارو رنگ',
    '💁🏻' => 'شخص هٿ ٿپڪائيندي: گوري رنگت',
    '💁🏼' => 'شخص هٿ ٿپڪائيندي: وچولي گوري رنگت',
    '💁🏽' => 'شخص هٿ ٿپڪائيندي: پڪو رنگ',
    '💁🏾' => 'شخص هٿ ٿپڪائيندي: وچولو ڪارو رنگ',
    '💁🏿' => 'شخص هٿ ٿپڪائيندي: ڪارو رنگ',
    '🙋🏻' => 'شخص هٿ مٿي ڪندي: گوري رنگت',
    '🙋🏼' => 'شخص هٿ مٿي ڪندي: وچولي گوري رنگت',
    '🙋🏽' => 'شخص هٿ مٿي ڪندي: پڪو رنگ',
    '🙋🏾' => 'شخص هٿ مٿي ڪندي: وچولو ڪارو رنگ',
    '🙋🏿' => 'شخص هٿ مٿي ڪندي: ڪارو رنگ',
    '🧏🏻' => 'ٻورو شخص: گوري رنگت',
    '🧏🏼' => 'ٻورو شخص: وچولي گوري رنگت',
    '🧏🏽' => 'ٻورو شخص: پڪو رنگ',
    '🧏🏾' => 'ٻورو شخص: وچولو ڪارو رنگ',
    '🧏🏿' => 'ٻورو شخص: ڪارو رنگ',
    '🙇🏻' => 'شخص جهڪندي: گوري رنگت',
    '🙇🏼' => 'شخص جهڪندي: وچولي گوري رنگت',
    '🙇🏽' => 'شخص جهڪندي: پڪو رنگ',
    '🙇🏾' => 'شخص جهڪندي: وچولو ڪارو رنگ',
    '🙇🏿' => 'شخص جهڪندي: ڪارو رنگ',
    '🤦🏻' => 'شخص جو نراڙ تي هٿ ڏيڻ: گوري رنگت',
    '🤦🏼' => 'شخص جو نراڙ تي هٿ ڏيڻ: وچولي گوري رنگت',
    '🤦🏽' => 'شخص جو نراڙ تي هٿ ڏيڻ: پڪو رنگ',
    '🤦🏾' => 'شخص جو نراڙ تي هٿ ڏيڻ: وچولو ڪارو رنگ',
    '🤦🏿' => 'شخص جو نراڙ تي هٿ ڏيڻ: ڪارو رنگ',
    '🤷🏻' => 'شخص اچڪائيندي: گوري رنگت',
    '🤷🏼' => 'شخص اچڪائيندي: وچولي گوري رنگت',
    '🤷🏽' => 'شخص اچڪائيندي: پڪو رنگ',
    '🤷🏾' => 'شخص اچڪائيندي: وچولو ڪارو رنگ',
    '🤷🏿' => 'شخص اچڪائيندي: ڪارو رنگ',
    '👮🏻' => 'پوليس آفيسر: گوري رنگت',
    '👮🏼' => 'پوليس آفيسر: وچولي گوري رنگت',
    '👮🏽' => 'پوليس آفيسر: پڪو رنگ',
    '👮🏾' => 'پوليس آفيسر: وچولو ڪارو رنگ',
    '👮🏿' => 'پوليس آفيسر: ڪارو رنگ',
    '🕵🏻' => 'جاسوس: گوري رنگت',
    '🕵🏼' => 'جاسوس: وچولي گوري رنگت',
    '🕵🏽' => 'جاسوس: پڪو رنگ',
    '🕵🏾' => 'جاسوس: وچولو ڪارو رنگ',
    '🕵🏿' => 'جاسوس: ڪارو رنگ',
    '💂🏻' => 'نگهبان: گوري رنگت',
    '💂🏼' => 'نگهبان: وچولي گوري رنگت',
    '💂🏽' => 'نگهبان: پڪو رنگ',
    '💂🏾' => 'نگهبان: وچولو ڪارو رنگ',
    '💂🏿' => 'نگهبان: ڪارو رنگ',
    '🥷🏻' => 'ننجا: گوري رنگت',
    '🥷🏼' => 'ننجا: وچولي گوري رنگت',
    '🥷🏽' => 'ننجا: پڪو رنگ',
    '🥷🏾' => 'ننجا: وچولو ڪارو رنگ',
    '🥷🏿' => 'ننجا: ڪارو رنگ',
    '👷🏻' => 'اڏاوت جو ڪم ڪندڙ: گوري رنگت',
    '👷🏼' => 'اڏاوت جو ڪم ڪندڙ: وچولي گوري رنگت',
    '👷🏽' => 'اڏاوت جو ڪم ڪندڙ: پڪو رنگ',
    '👷🏾' => 'اڏاوت جو ڪم ڪندڙ: وچولو ڪارو رنگ',
    '👷🏿' => 'اڏاوت جو ڪم ڪندڙ: ڪارو رنگ',
    '🫅🏻' => 'تاج پاتل ماڻھو: گوري رنگت',
    '🫅🏼' => 'تاج پاتل ماڻھو: وچولي گوري رنگت',
    '🫅🏽' => 'تاج پاتل ماڻھو: پڪو رنگ',
    '🫅🏾' => 'تاج پاتل ماڻھو: وچولو ڪارو رنگ',
    '🫅🏿' => 'تاج پاتل ماڻھو: ڪارو رنگ',
    '🤴🏻' => 'شهزادو: گوري رنگت',
    '🤴🏼' => 'شهزادو: وچولي گوري رنگت',
    '🤴🏽' => 'شهزادو: پڪو رنگ',
    '🤴🏾' => 'شهزادو: وچولو ڪارو رنگ',
    '🤴🏿' => 'شهزادو: ڪارو رنگ',
    '👸🏻' => 'شهزادي: گوري رنگت',
    '👸🏼' => 'شهزادي: وچولي گوري رنگت',
    '👸🏽' => 'شهزادي: پڪو رنگ',
    '👸🏾' => 'شهزادي: وچولو ڪارو رنگ',
    '👸🏿' => 'شهزادي: ڪارو رنگ',
    '👳🏻' => 'ماڻهو کي پگڙي پاتل: گوري رنگت',
    '👳🏼' => 'ماڻهو کي پگڙي پاتل: وچولي گوري رنگت',
    '👳🏽' => 'ماڻهو کي پگڙي پاتل: پڪو رنگ',
    '👳🏾' => 'ماڻهو کي پگڙي پاتل: وچولو ڪارو رنگ',
    '👳🏿' => 'ماڻهو کي پگڙي پاتل: ڪارو رنگ',
    '👲🏻' => 'چيني ٽوپي وارو ماڻهو: گوري رنگت',
    '👲🏼' => 'چيني ٽوپي وارو ماڻهو: وچولي گوري رنگت',
    '👲🏽' => 'چيني ٽوپي وارو ماڻهو: پڪو رنگ',
    '👲🏾' => 'چيني ٽوپي وارو ماڻهو: وچولو ڪارو رنگ',
    '👲🏿' => 'چيني ٽوپي وارو ماڻهو: ڪارو رنگ',
    '🧕🏻' => 'حجاب سان عورت: گوري رنگت',
    '🧕🏼' => 'حجاب سان عورت: وچولي گوري رنگت',
    '🧕🏽' => 'حجاب سان عورت: پڪو رنگ',
    '🧕🏾' => 'حجاب سان عورت: وچولو ڪارو رنگ',
    '🧕🏿' => 'حجاب سان عورت: ڪارو رنگ',
    '🤵🏻' => 'سوٽ ۾ ماڻهو: گوري رنگت',
    '🤵🏼' => 'سوٽ ۾ ماڻهو: وچولي گوري رنگت',
    '🤵🏽' => 'سوٽ ۾ ماڻهو: پڪو رنگ',
    '🤵🏾' => 'سوٽ ۾ ماڻهو: وچولو ڪارو رنگ',
    '🤵🏿' => 'سوٽ ۾ ماڻهو: ڪارو رنگ',
    '👰🏻' => 'شادي جي لباس سان ڪنوار: گوري رنگت',
    '👰🏼' => 'شادي جي لباس سان ڪنوار: وچولي گوري رنگت',
    '👰🏽' => 'شادي جي لباس سان ڪنوار: پڪو رنگ',
    '👰🏾' => 'شادي جي لباس سان ڪنوار: وچولو ڪارو رنگ',
    '👰🏿' => 'شادي جي لباس سان ڪنوار: ڪارو رنگ',
    '🤰🏻' => 'ڳورهاري عورت: گوري رنگت',
    '🤰🏼' => 'ڳورهاري عورت: وچولي گوري رنگت',
    '🤰🏽' => 'ڳورهاري عورت: پڪو رنگ',
    '🤰🏾' => 'ڳورهاري عورت: وچولو ڪارو رنگ',
    '🤰🏿' => 'ڳورهاري عورت: ڪارو رنگ',
    '🫃🏻' => 'ڳورھارو مرد: گوري رنگت',
    '🫃🏼' => 'ڳورھارو مرد: وچولي گوري رنگت',
    '🫃🏽' => 'ڳورھارو مرد: پڪو رنگ',
    '🫃🏾' => 'ڳورھارو مرد: وچولو ڪارو رنگ',
    '🫃🏿' => 'ڳورھارو مرد: ڪارو رنگ',
    '🫄🏻' => 'ڳورھارو ماڻھو: گوري رنگت',
    '🫄🏼' => 'ڳورھارو ماڻھو: وچولي گوري رنگت',
    '🫄🏽' => 'ڳورھارو ماڻھو: پڪو رنگ',
    '🫄🏾' => 'ڳورھارو ماڻھو: وچولو ڪارو رنگ',
    '🫄🏿' => 'ڳورھارو ماڻھو: ڪارو رنگ',
    '🤱🏻' => 'ٿڃ پيارڻ: گوري رنگت',
    '🤱🏼' => 'ٿڃ پيارڻ: وچولي گوري رنگت',
    '🤱🏽' => 'ٿڃ پيارڻ: پڪو رنگ',
    '🤱🏾' => 'ٿڃ پيارڻ: وچولو ڪارو رنگ',
    '🤱🏿' => 'ٿڃ پيارڻ: ڪارو رنگ',
    '👼🏻' => 'ننڍي پري: گوري رنگت',
    '👼🏼' => 'ننڍي پري: وچولي گوري رنگت',
    '👼🏽' => 'ننڍي پري: پڪو رنگ',
    '👼🏾' => 'ننڍي پري: وچولو ڪارو رنگ',
    '👼🏿' => 'ننڍي پري: ڪارو رنگ',
    '🎅🏻' => 'سانتا ڪلاز: گوري رنگت',
    '🎅🏼' => 'سانتا ڪلاز: وچولي گوري رنگت',
    '🎅🏽' => 'سانتا ڪلاز: پڪو رنگ',
    '🎅🏾' => 'سانتا ڪلاز: وچولو ڪارو رنگ',
    '🎅🏿' => 'سانتا ڪلاز: ڪارو رنگ',
    '🤶🏻' => 'ڪلاز جي مائي: گوري رنگت',
    '🤶🏼' => 'ڪلاز جي مائي: وچولي گوري رنگت',
    '🤶🏽' => 'ڪلاز جي مائي: پڪو رنگ',
    '🤶🏾' => 'ڪلاز جي مائي: وچولو ڪارو رنگ',
    '🤶🏿' => 'ڪلاز جي مائي: ڪارو رنگ',
    '🦸🏻' => 'سپر هيرو: گوري رنگت',
    '🦸🏼' => 'سپر هيرو: وچولي گوري رنگت',
    '🦸🏽' => 'سپر هيرو: پڪو رنگ',
    '🦸🏾' => 'سپر هيرو: وچولو ڪارو رنگ',
    '🦸🏿' => 'سپر هيرو: ڪارو رنگ',
    '🦹🏻' => 'سپر ولن: گوري رنگت',
    '🦹🏼' => 'سپر ولن: وچولي گوري رنگت',
    '🦹🏽' => 'سپر ولن: پڪو رنگ',
    '🦹🏾' => 'سپر ولن: وچولو ڪارو رنگ',
    '🦹🏿' => 'سپر ولن: ڪارو رنگ',
    '🧙🏻' => 'جادوگر: گوري رنگت',
    '🧙🏼' => 'جادوگر: وچولي گوري رنگت',
    '🧙🏽' => 'جادوگر: پڪو رنگ',
    '🧙🏾' => 'جادوگر: وچولو ڪارو رنگ',
    '🧙🏿' => 'جادوگر: ڪارو رنگ',
    '🧚🏻' => 'پري: گوري رنگت',
    '🧚🏼' => 'پري: وچولي گوري رنگت',
    '🧚🏽' => 'پري: پڪو رنگ',
    '🧚🏾' => 'پري: وچولو ڪارو رنگ',
    '🧚🏿' => 'پري: ڪارو رنگ',
    '🧛🏻' => 'ڏائڻ: گوري رنگت',
    '🧛🏼' => 'ڏائڻ: وچولي گوري رنگت',
    '🧛🏽' => 'ڏائڻ: پڪو رنگ',
    '🧛🏾' => 'ڏائڻ: وچولو ڪارو رنگ',
    '🧛🏿' => 'ڏائڻ: ڪارو رنگ',
    '🧜🏻' => 'ميل پرسن: گوري رنگت',
    '🧜🏼' => 'ميل پرسن: وچولي گوري رنگت',
    '🧜🏽' => 'ميل پرسن: پڪو رنگ',
    '🧜🏾' => 'ميل پرسن: وچولو ڪارو رنگ',
    '🧜🏿' => 'ميل پرسن: ڪارو رنگ',
    '🧝🏻' => 'بونا: گوري رنگت',
    '🧝🏼' => 'بونا: وچولي گوري رنگت',
    '🧝🏽' => 'بونا: پڪو رنگ',
    '🧝🏾' => 'بونا: وچولو ڪارو رنگ',
    '🧝🏿' => 'بونا: ڪارو رنگ',
    '💆🏻' => 'مساج وٺندڙ شخص: گوري رنگت',
    '💆🏼' => 'مساج وٺندڙ شخص: وچولي گوري رنگت',
    '💆🏽' => 'مساج وٺندڙ شخص: پڪو رنگ',
    '💆🏾' => 'مساج وٺندڙ شخص: وچولو ڪارو رنگ',
    '💆🏿' => 'مساج وٺندڙ شخص: ڪارو رنگ',
    '💇🏻' => 'وارن جي ڪٽ وٺندڙ شخص: گوري رنگت',
    '💇🏼' => 'وارن جي ڪٽ وٺندڙ شخص: وچولي گوري رنگت',
    '💇🏽' => 'وارن جي ڪٽ وٺندڙ شخص: پڪو رنگ',
    '💇🏾' => 'وارن جي ڪٽ وٺندڙ شخص: وچولو ڪارو رنگ',
    '💇🏿' => 'وارن جي ڪٽ وٺندڙ شخص: ڪارو رنگ',
    '🚶🏻' => 'شخص هلندي: گوري رنگت',
    '🚶🏼' => 'شخص هلندي: وچولي گوري رنگت',
    '🚶🏽' => 'شخص هلندي: پڪو رنگ',
    '🚶🏾' => 'شخص هلندي: وچولو ڪارو رنگ',
    '🚶🏿' => 'شخص هلندي: ڪارو رنگ',
    '🧍🏻' => 'بيٺل ماڻهو: گوري رنگت',
    '🧍🏼' => 'بيٺل ماڻهو: وچولي گوري رنگت',
    '🧍🏽' => 'بيٺل ماڻهو: پڪو رنگ',
    '🧍🏾' => 'بيٺل ماڻهو: وچولو ڪارو رنگ',
    '🧍🏿' => 'بيٺل ماڻهو: ڪارو رنگ',
    '🧎🏻' => 'گوڏن ڀر ويٺل ماڻهو: گوري رنگت',
    '🧎🏼' => 'گوڏن ڀر ويٺل ماڻهو: وچولي گوري رنگت',
    '🧎🏽' => 'گوڏن ڀر ويٺل ماڻهو: پڪو رنگ',
    '🧎🏾' => 'گوڏن ڀر ويٺل ماڻهو: وچولو ڪارو رنگ',
    '🧎🏿' => 'گوڏن ڀر ويٺل ماڻهو: ڪارو رنگ',
    '🏃🏻' => 'شخص ڊوڙندي: گوري رنگت',
    '🏃🏼' => 'شخص ڊوڙندي: وچولي گوري رنگت',
    '🏃🏽' => 'شخص ڊوڙندي: پڪو رنگ',
    '🏃🏾' => 'شخص ڊوڙندي: وچولو ڪارو رنگ',
    '🏃🏿' => 'شخص ڊوڙندي: ڪارو رنگ',
    '💃🏻' => 'عورت نچندي: گوري رنگت',
    '💃🏼' => 'عورت نچندي: وچولي گوري رنگت',
    '💃🏽' => 'عورت نچندي: پڪو رنگ',
    '💃🏾' => 'عورت نچندي: وچولو ڪارو رنگ',
    '💃🏿' => 'عورت نچندي: ڪارو رنگ',
    '🕺🏻' => 'مرد نچندي: گوري رنگت',
    '🕺🏼' => 'مرد نچندي: وچولي گوري رنگت',
    '🕺🏽' => 'مرد نچندي: پڪو رنگ',
    '🕺🏾' => 'مرد نچندي: وچولو ڪارو رنگ',
    '🕺🏿' => 'مرد نچندي: ڪارو رنگ',
    '🕴🏻' => 'مرد سوٽ ۾: گوري رنگت',
    '🕴🏼' => 'مرد سوٽ ۾: وچولي گوري رنگت',
    '🕴🏽' => 'مرد سوٽ ۾: پڪو رنگ',
    '🕴🏾' => 'مرد سوٽ ۾: وچولو ڪارو رنگ',
    '🕴🏿' => 'مرد سوٽ ۾: ڪارو رنگ',
    '👯🏻' => 'خرگوش جي ڪنن وارو ماڻهو: گوري رنگت',
    '👯🏼' => 'خرگوش جي ڪنن وارو ماڻهو: وچولي گوري رنگت',
    '👯🏽' => 'خرگوش جي ڪنن وارو ماڻهو: پڪو رنگ',
    '👯🏾' => 'خرگوش جي ڪنن وارو ماڻهو: وچولو ڪارو رنگ',
    '👯🏿' => 'خرگوش جي ڪنن وارو ماڻهو: ڪارو رنگ',
    '🧖🏻' => 'شخص ٻاڦ واري ڪمري ۾: گوري رنگت',
    '🧖🏼' => 'شخص ٻاڦ واري ڪمري ۾: وچولي گوري رنگت',
    '🧖🏽' => 'شخص ٻاڦ واري ڪمري ۾: پڪو رنگ',
    '🧖🏾' => 'شخص ٻاڦ واري ڪمري ۾: وچولو ڪارو رنگ',
    '🧖🏿' => 'شخص ٻاڦ واري ڪمري ۾: ڪارو رنگ',
    '🧗🏻' => 'شخص چڙهندي: گوري رنگت',
    '🧗🏼' => 'شخص چڙهندي: وچولي گوري رنگت',
    '🧗🏽' => 'شخص چڙهندي: پڪو رنگ',
    '🧗🏾' => 'شخص چڙهندي: وچولو ڪارو رنگ',
    '🧗🏿' => 'شخص چڙهندي: ڪارو رنگ',
    '🏇🏻' => 'گهوڙي جي ڊوڙ: گوري رنگت',
    '🏇🏼' => 'گهوڙي جي ڊوڙ: وچولي گوري رنگت',
    '🏇🏽' => 'گهوڙي جي ڊوڙ: پڪو رنگ',
    '🏇🏾' => 'گهوڙي جي ڊوڙ: وچولو ڪارو رنگ',
    '🏇🏿' => 'گهوڙي جي ڊوڙ: ڪارو رنگ',
    '🏂🏻' => 'سنوبورڊر: گوري رنگت',
    '🏂🏼' => 'سنوبورڊر: وچولي گوري رنگت',
    '🏂🏽' => 'سنوبورڊر: پڪو رنگ',
    '🏂🏾' => 'سنوبورڊر: وچولو ڪارو رنگ',
    '🏂🏿' => 'سنوبورڊر: ڪارو رنگ',
    '🏌🏻' => 'شخص گولف کيڏيندي: گوري رنگت',
    '🏌🏼' => 'شخص گولف کيڏيندي: وچولي گوري رنگت',
    '🏌🏽' => 'شخص گولف کيڏيندي: پڪو رنگ',
    '🏌🏾' => 'شخص گولف کيڏيندي: وچولو ڪارو رنگ',
    '🏌🏿' => 'شخص گولف کيڏيندي: ڪارو رنگ',
    '🏄🏻' => 'شخص سرفنگ ڪندي: گوري رنگت',
    '🏄🏼' => 'شخص سرفنگ ڪندي: وچولي گوري رنگت',
    '🏄🏽' => 'شخص سرفنگ ڪندي: پڪو رنگ',
    '🏄🏾' => 'شخص سرفنگ ڪندي: وچولو ڪارو رنگ',
    '🏄🏿' => 'شخص سرفنگ ڪندي: ڪارو رنگ',
    '🚣🏻' => 'شخص ٻيڙي ۾ چپو هلائيندي: گوري رنگت',
    '🚣🏼' => 'شخص ٻيڙي ۾ چپو هلائيندي: وچولي گوري رنگت',
    '🚣🏽' => 'شخص ٻيڙي ۾ چپو هلائيندي: پڪو رنگ',
    '🚣🏾' => 'شخص ٻيڙي ۾ چپو هلائيندي: وچولو ڪارو رنگ',
    '🚣🏿' => 'شخص ٻيڙي ۾ چپو هلائيندي: ڪارو رنگ',
    '🏊🏻' => 'شخص ترندي: گوري رنگت',
    '🏊🏼' => 'شخص ترندي: وچولي گوري رنگت',
    '🏊🏽' => 'شخص ترندي: پڪو رنگ',
    '🏊🏾' => 'شخص ترندي: وچولو ڪارو رنگ',
    '🏊🏿' => 'شخص ترندي: ڪارو رنگ',
    '⛹🏻' => 'شخص بائونسنگ بال سان کيڏندي: گوري رنگت',
    '⛹🏼' => 'شخص بائونسنگ بال سان کيڏندي: وچولي گوري رنگت',
    '⛹🏽' => 'شخص بائونسنگ بال سان کيڏندي: پڪو رنگ',
    '⛹🏾' => 'شخص بائونسنگ بال سان کيڏندي: وچولو ڪارو رنگ',
    '⛹🏿' => 'شخص بائونسنگ بال سان کيڏندي: ڪارو رنگ',
    '🏋🏻' => 'شخض وزن کڻندي: گوري رنگت',
    '🏋🏼' => 'شخض وزن کڻندي: وچولي گوري رنگت',
    '🏋🏽' => 'شخض وزن کڻندي: پڪو رنگ',
    '🏋🏾' => 'شخض وزن کڻندي: وچولو ڪارو رنگ',
    '🏋🏿' => 'شخض وزن کڻندي: ڪارو رنگ',
    '🚴🏻' => 'شخص بائيڪ هلائيندي: گوري رنگت',
    '🚴🏼' => 'شخص بائيڪ هلائيندي: وچولي گوري رنگت',
    '🚴🏽' => 'شخص بائيڪ هلائيندي: پڪو رنگ',
    '🚴🏾' => 'شخص بائيڪ هلائيندي: وچولو ڪارو رنگ',
    '🚴🏿' => 'شخص بائيڪ هلائيندي: ڪارو رنگ',
    '🚵🏻' => 'شخص جبل تي سائيڪل هلائيندي: گوري رنگت',
    '🚵🏼' => 'شخص جبل تي سائيڪل هلائيندي: وچولي گوري رنگت',
    '🚵🏽' => 'شخص جبل تي سائيڪل هلائيندي: پڪو رنگ',
    '🚵🏾' => 'شخص جبل تي سائيڪل هلائيندي: وچولو ڪارو رنگ',
    '🚵🏿' => 'شخص جبل تي سائيڪل هلائيندي: ڪارو رنگ',
    '🤸🏻' => 'شخص ڪارٽ وهلينگ ڪندي: گوري رنگت',
    '🤸🏼' => 'شخص ڪارٽ وهلينگ ڪندي: وچولي گوري رنگت',
    '🤸🏽' => 'شخص ڪارٽ وهلينگ ڪندي: پڪو رنگ',
    '🤸🏾' => 'شخص ڪارٽ وهلينگ ڪندي: وچولو ڪارو رنگ',
    '🤸🏿' => 'شخص ڪارٽ وهلينگ ڪندي: ڪارو رنگ',
    '🤼🏻' => 'ماڻهو ڪشتي وڙهندي: گوري رنگت',
    '🤼🏼' => 'ماڻهو ڪشتي وڙهندي: وچولي گوري رنگت',
    '🤼🏽' => 'ماڻهو ڪشتي وڙهندي: پڪو رنگ',
    '🤼🏾' => 'ماڻهو ڪشتي وڙهندي: وچولو ڪارو رنگ',
    '🤼🏿' => 'ماڻهو ڪشتي وڙهندي: ڪارو رنگ',
    '🤽🏻' => 'ماڻهو پاڻي وارو پولو کيڏيندي: گوري رنگت',
    '🤽🏼' => 'ماڻهو پاڻي وارو پولو کيڏيندي: وچولي گوري رنگت',
    '🤽🏽' => 'ماڻهو پاڻي وارو پولو کيڏيندي: پڪو رنگ',
    '🤽🏾' => 'ماڻهو پاڻي وارو پولو کيڏيندي: وچولو ڪارو رنگ',
    '🤽🏿' => 'ماڻهو پاڻي وارو پولو کيڏيندي: ڪارو رنگ',
    '🤾🏻' => 'ماڻهو هٿ جو بال کيڏندي: گوري رنگت',
    '🤾🏼' => 'ماڻهو هٿ جو بال کيڏندي: وچولي گوري رنگت',
    '🤾🏽' => 'ماڻهو هٿ جو بال کيڏندي: پڪو رنگ',
    '🤾🏾' => 'ماڻهو هٿ جو بال کيڏندي: وچولو ڪارو رنگ',
    '🤾🏿' => 'ماڻهو هٿ جو بال کيڏندي: ڪارو رنگ',
    '🤹🏻' => 'شخص جادوگري ڪندي: گوري رنگت',
    '🤹🏼' => 'شخص جادوگري ڪندي: وچولي گوري رنگت',
    '🤹🏽' => 'شخص جادوگري ڪندي: پڪو رنگ',
    '🤹🏾' => 'شخص جادوگري ڪندي: وچولو ڪارو رنگ',
    '🤹🏿' => 'شخص جادوگري ڪندي: ڪارو رنگ',
    '🧘🏻' => 'شخص لوٽس پوزيشن ۾: گوري رنگت',
    '🧘🏼' => 'شخص لوٽس پوزيشن ۾: وچولي گوري رنگت',
    '🧘🏽' => 'شخص لوٽس پوزيشن ۾: پڪو رنگ',
    '🧘🏾' => 'شخص لوٽس پوزيشن ۾: وچولو ڪارو رنگ',
    '🧘🏿' => 'شخص لوٽس پوزيشن ۾: ڪارو رنگ',
    '🛀🏻' => 'شخص وهجندي: گوري رنگت',
    '🛀🏼' => 'شخص وهجندي: وچولي گوري رنگت',
    '🛀🏽' => 'شخص وهجندي: پڪو رنگ',
    '🛀🏾' => 'شخص وهجندي: وچولو ڪارو رنگ',
    '🛀🏿' => 'شخص وهجندي: ڪارو رنگ',
    '🛌🏻' => 'بستر ۾ شخص: گوري رنگت',
    '🛌🏼' => 'بستر ۾ شخص: وچولي گوري رنگت',
    '🛌🏽' => 'بستر ۾ شخص: پڪو رنگ',
    '🛌🏾' => 'بستر ۾ شخص: وچولو ڪارو رنگ',
    '🛌🏿' => 'بستر ۾ شخص: ڪارو رنگ',
    '👭🏻' => 'هٿ جهليل عورتون: گوري رنگت',
    '👭🏼' => 'هٿ جهليل عورتون: وچولي گوري رنگت',
    '👭🏽' => 'هٿ جهليل عورتون: پڪو رنگ',
    '👭🏾' => 'هٿ جهليل عورتون: وچولو ڪارو رنگ',
    '👭🏿' => 'هٿ جهليل عورتون: ڪارو رنگ',
    '👫🏻' => 'هٿ جهليندي مرد ۽ عورت: گوري رنگت',
    '👫🏼' => 'هٿ جهليندي مرد ۽ عورت: وچولي گوري رنگت',
    '👫🏽' => 'هٿ جهليندي مرد ۽ عورت: پڪو رنگ',
    '👫🏾' => 'هٿ جهليندي مرد ۽ عورت: وچولو ڪارو رنگ',
    '👫🏿' => 'هٿ جهليندي مرد ۽ عورت: ڪارو رنگ',
    '👬🏻' => 'ٻه مرد هٿ جهليندي: گوري رنگت',
    '👬🏼' => 'ٻه مرد هٿ جهليندي: وچولي گوري رنگت',
    '👬🏽' => 'ٻه مرد هٿ جهليندي: پڪو رنگ',
    '👬🏾' => 'ٻه مرد هٿ جهليندي: وچولو ڪارو رنگ',
    '👬🏿' => 'ٻه مرد هٿ جهليندي: ڪارو رنگ',
    '💏🏻' => 'چمي: گوري رنگت',
    '💏🏼' => 'چمي: وچولي گوري رنگت',
    '💏🏽' => 'چمي: پڪو رنگ',
    '💏🏾' => 'چمي: وچولو ڪارو رنگ',
    '💏🏿' => 'چمي: ڪارو رنگ',
    '💑🏻' => 'دل سان جوڙو: گوري رنگت',
    '💑🏼' => 'دل سان جوڙو: وچولي گوري رنگت',
    '💑🏽' => 'دل سان جوڙو: پڪو رنگ',
    '💑🏾' => 'دل سان جوڙو: وچولو ڪارو رنگ',
    '💑🏿' => 'دل سان جوڙو: ڪارو رنگ',
    '🇦🇨' => 'جهنڊو: طلوع ٻيٽ',
    '🇦🇩' => 'جهنڊو: اندورا',
    '🇦🇪' => 'جهنڊو: متحده عرب امارات',
    '🇦🇫' => 'جهنڊو: افغانستان',
    '🇦🇬' => 'جهنڊو: اينٽيگا ۽ باربوڊا',
    '🇦🇮' => 'جهنڊو: انگويلا',
    '🇦🇱' => 'جهنڊو: البانيا',
    '🇦🇲' => 'جهنڊو: آرمينيا',
    '🇦🇴' => 'جهنڊو: انگولا',
    '🇦🇶' => 'جهنڊو: انٽارڪٽيڪا',
    '🇦🇷' => 'جهنڊو: ارجنٽينا',
    '🇦🇸' => 'جهنڊو: آمريڪي ساموا',
    '🇦🇹' => 'جهنڊو: آسٽريا',
    '🇦🇺' => 'جهنڊو: آسٽريليا',
    '🇦🇼' => 'جهنڊو: عروبا',
    '🇦🇽' => 'جهنڊو: الند ٻيٽ',
    '🇦🇿' => 'جهنڊو: آذربائيجان',
    '🇧🇦' => 'جهنڊو: بوسنيا ۽ هرزيگووينا',
    '🇧🇧' => 'جهنڊو: باربڊوس',
    '🇧🇩' => 'جهنڊو: بنگلاديش',
    '🇧🇪' => 'جهنڊو: بيلجيم',
    '🇧🇫' => 'جهنڊو: برڪينا فاسو',
    '🇧🇬' => 'جهنڊو: بلغاريا',
    '🇧🇭' => 'جهنڊو: بحرين',
    '🇧🇮' => 'جهنڊو: برونڊي',
    '🇧🇯' => 'جهنڊو: بينن',
    '🇧🇱' => 'جهنڊو: سینٽ برٿلیمی',
    '🇧🇲' => 'جهنڊو: برمودا',
    '🇧🇳' => 'جهنڊو: برونائي',
    '🇧🇴' => 'جهنڊو: بوليويا',
    '🇧🇶' => 'جهنڊو: ڪيريبين نيدرلينڊ',
    '🇧🇷' => 'جهنڊو: برازيل',
    '🇧🇸' => 'جهنڊو: باهاماس',
    '🇧🇹' => 'جهنڊو: ڀوٽان',
    '🇧🇻' => 'جهنڊو: بووٽ ٻيٽ',
    '🇧🇼' => 'جهنڊو: بوٽسوانا',
    '🇧🇾' => 'جهنڊو: بيلاروس',
    '🇧🇿' => 'جهنڊو: بيليز',
    '🇨🇦' => 'جهنڊو: ڪينيڊا',
    '🇨🇨' => 'جهنڊو: ڪوڪوس ٻيٽ',
    '🇨🇩' => 'جهنڊو: ڪانگو -ڪنشاسا',
    '🇨🇫' => 'جهنڊو: وچ آفريقي جمهوريه',
    '🇨🇬' => 'جهنڊو: ڪانگو - برازاویل',
    '🇨🇭' => 'جهنڊو: سوئزرلينڊ',
    '🇨🇮' => 'جهنڊو: ڪوٽي ويرا',
    '🇨🇰' => 'جهنڊو: ڪوڪ ٻيٽ',
    '🇨🇱' => 'جهنڊو: چلي',
    '🇨🇲' => 'جهنڊو: ڪيمرون',
    '🇨🇳' => 'جهنڊو: چين',
    '🇨🇴' => 'جهنڊو: ڪولمبيا',
    '🇨🇵' => 'جهنڊو: ڪلپرٽن ٻيٽ',
    '🇨🇶' => 'جهنڊو: سارڪ',
    '🇨🇷' => 'جهنڊو: ڪوسٽا ريڪا',
    '🇨🇺' => 'جهنڊو: ڪيوبا',
    '🇨🇻' => 'جهنڊو: ڪيپ وردي',
    '🇨🇼' => 'جهنڊو: ڪيوراسائو',
    '🇨🇽' => 'جهنڊو: ڪرسمس ٻيٽ',
    '🇨🇾' => 'جهنڊو: سائپرس',
    '🇨🇿' => 'جهنڊو: چيڪيا',
    '🇩🇪' => 'جهنڊو: جرمني',
    '🇩🇬' => 'جهنڊو: ڊئيگو گارسيا',
    '🇩🇯' => 'جهنڊو: ڊجبيوتي',
    '🇩🇰' => 'جهنڊو: ڊينمارڪ',
    '🇩🇲' => 'جهنڊو: ڊومينيڪا',
    '🇩🇴' => 'جهنڊو: ڊومينيڪن جمهوريه',
    '🇩🇿' => 'جهنڊو: الجيريا',
    '🇪🇦' => 'جهنڊو: سیوٽا ۽ میلیلا',
    '🇪🇨' => 'جهنڊو: ايڪواڊور',
    '🇪🇪' => 'جهنڊو: ايسٽونيا',
    '🇪🇬' => 'جهنڊو: مصر',
    '🇪🇭' => 'جهنڊو: اولهه صحارا',
    '🇪🇷' => 'جهنڊو: ايريٽيريا',
    '🇪🇸' => 'جهنڊو: اسپين',
    '🇪🇹' => 'جهنڊو: ايٿوپيا',
    '🇪🇺' => 'جهنڊو: يورپين يونين',
    '🇫🇮' => 'جهنڊو: فن لينڊ',
    '🇫🇯' => 'جهنڊو: فجي',
    '🇫🇰' => 'جهنڊو: فاڪ لينڊ ٻيٽ',
    '🇫🇲' => 'جهنڊو: مائڪرونيشيا',
    '🇫🇴' => 'جهنڊو: فارو ٻيٽ',
    '🇫🇷' => 'جهنڊو: فرانس',
    '🇬🇦' => 'جهنڊو: گبون',
    '🇬🇧' => 'جهنڊو: برطانيہ',
    '🇬🇩' => 'جهنڊو: گريناڊا',
    '🇬🇪' => 'جهنڊو: جارجيا',
    '🇬🇫' => 'جهنڊو: فرانسيسي گيانا',
    '🇬🇬' => 'جهنڊو: گورنسي',
    '🇬🇭' => 'جهنڊو: گهانا',
    '🇬🇮' => 'جهنڊو: جبرالٽر',
    '🇬🇱' => 'جهنڊو: گرين لينڊ',
    '🇬🇲' => 'جهنڊو: گيمبيا',
    '🇬🇳' => 'جهنڊو: گني',
    '🇬🇵' => 'جهنڊو: گواڊیلوپ',
    '🇬🇶' => 'جهنڊو: ايڪوٽوريل گائينا',
    '🇬🇷' => 'جهنڊو: يونان',
    '🇬🇸' => 'جهنڊو: ڏکڻ جارجيا ۽ ڏکڻ سينڊوچ ٻيٽ',
    '🇬🇹' => 'جهنڊو: گوئٽي مالا',
    '🇬🇺' => 'جهنڊو: گوام',
    '🇬🇼' => 'جهنڊو: گني بسائو',
    '🇬🇾' => 'جهنڊو: گيانا',
    '🇭🇰' => 'جهنڊو: هانگ ڪانگ SAR چين',
    '🇭🇲' => 'جهنڊو: هرڊ ۽ مڪڊونلڊ ٻيٽ',
    '🇭🇳' => 'جهنڊو: هنڊورس',
    '🇭🇷' => 'جهنڊو: ڪروئيشيا',
    '🇭🇹' => 'جهنڊو: هيٽي',
    '🇭🇺' => 'جهنڊو: هنگري',
    '🇮🇨' => 'جهنڊو: ڪينري ٻيٽ',
    '🇮🇩' => 'جهنڊو: انڊونيشيا',
    '🇮🇪' => 'جهنڊو: آئرلينڊ',
    '🇮🇱' => 'جهنڊو: اسرائيل',
    '🇮🇲' => 'جهنڊو: انسانن جو ٻيٽ',
    '🇮🇳' => 'جهنڊو: ڀارت',
    '🇮🇴' => 'جهنڊو: برطانوي هندي سمنڊ خطو',
    '🇮🇶' => 'جهنڊو: عراق',
    '🇮🇷' => 'جهنڊو: ايران',
    '🇮🇸' => 'جهنڊو: آئس لينڊ',
    '🇮🇹' => 'جهنڊو: اٽلي',
    '🇯🇪' => 'جهنڊو: جرسي',
    '🇯🇲' => 'جهنڊو: جميڪا',
    '🇯🇴' => 'جهنڊو: اردن',
    '🇯🇵' => 'جهنڊو: جاپان',
    '🇰🇪' => 'جهنڊو: ڪينيا',
    '🇰🇬' => 'جهنڊو: ڪرغستان',
    '🇰🇭' => 'جهنڊو: ڪمبوڊيا',
    '🇰🇮' => 'جهنڊو: ڪرباتي',
    '🇰🇲' => 'جهنڊو: ڪوموروس',
    '🇰🇳' => 'جهنڊو: سينٽ ڪٽس و نيوس',
    '🇰🇵' => 'جهنڊو: اتر ڪوريا',
    '🇰🇷' => 'جهنڊو: ڏکڻ ڪوريا',
    '🇰🇼' => 'جهنڊو: ڪويت',
    '🇰🇾' => 'جهنڊو: ڪي مين ٻيٽ',
    '🇰🇿' => 'جهنڊو: قازقستان',
    '🇱🇦' => 'جهنڊو: لائوس',
    '🇱🇧' => 'جهنڊو: لبنان',
    '🇱🇨' => 'جهنڊو: سينٽ لوسيا',
    '🇱🇮' => 'جهنڊو: لچي ٽينسٽين',
    '🇱🇰' => 'جهنڊو: سري لنڪا',
    '🇱🇷' => 'جهنڊو: لائبیریا',
    '🇱🇸' => 'جهنڊو: ليسوٿو',
    '🇱🇹' => 'جهنڊو: لٿونيا',
    '🇱🇺' => 'جهنڊو: لگزمبرگ',
    '🇱🇻' => 'جهنڊو: لاتويا',
    '🇱🇾' => 'جهنڊو: لبيا',
    '🇲🇦' => 'جهنڊو: مراڪش',
    '🇲🇨' => 'جهنڊو: موناڪو',
    '🇲🇩' => 'جهنڊو: مالدووا',
    '🇲🇪' => 'جهنڊو: مونٽي نيگرو',
    '🇲🇫' => 'جهنڊو: سينٽ مارٽن',
    '🇲🇬' => 'جهنڊو: مدگاسڪر',
    '🇲🇭' => 'جهنڊو: مارشل ٻيٽ',
    '🇲🇰' => 'جهنڊو: اتر مقدونيا',
    '🇲🇱' => 'جهنڊو: مالي',
    '🇲🇲' => 'جهنڊو: ميانمار (برما)',
    '🇲🇳' => 'جهنڊو: منگوليا',
    '🇲🇴' => 'جهنڊو: مڪائو SAR چين',
    '🇲🇵' => 'جهنڊو: اتريان ماريانا ٻيٽ',
    '🇲🇶' => 'جهنڊو: مارتينڪ',
    '🇲🇷' => 'جهنڊو: موريتانيا',
    '🇲🇸' => 'جهنڊو: مونٽسراٽ',
    '🇲🇹' => 'جهنڊو: مالٽا',
    '🇲🇺' => 'جهنڊو: موريشس',
    '🇲🇻' => 'جهنڊو: مالديپ',
    '🇲🇼' => 'جهنڊو: مالاوي',
    '🇲🇽' => 'جهنڊو: ميڪسيڪو',
    '🇲🇾' => 'جهنڊو: ملائيشيا',
    '🇲🇿' => 'جهنڊو: موزمبیق',
    '🇳🇦' => 'جهنڊو: نيميبيا',
    '🇳🇨' => 'جهنڊو: نیو ڪالیڊونیا',
    '🇳🇪' => 'جهنڊو: نائيجر',
    '🇳🇫' => 'جهنڊو: نورفوڪ ٻيٽ',
    '🇳🇬' => 'جهنڊو: نائيجيريا',
    '🇳🇮' => 'جهنڊو: نڪراگوا',
    '🇳🇱' => 'جهنڊو: نيدرلينڊ',
    '🇳🇴' => 'جهنڊو: ناروي',
    '🇳🇵' => 'جهنڊو: نيپال',
    '🇳🇷' => 'جهنڊو: نائورو',
    '🇳🇺' => 'جهنڊو: نووي',
    '🇳🇿' => 'جهنڊو: نيو زيلينڊ',
    '🇴🇲' => 'جهنڊو: عمان',
    '🇵🇦' => 'جهنڊو: پناما',
    '🇵🇪' => 'جهنڊو: پيرو',
    '🇵🇫' => 'جهنڊو: فرانسيسي پولينيشيا',
    '🇵🇬' => 'جهنڊو: پاپوا نیو گني',
    '🇵🇭' => 'جهنڊو: فلپائن',
    '🇵🇰' => 'جهنڊو: پاڪستان',
    '🇵🇱' => 'جهنڊو: پولينڊ',
    '🇵🇲' => 'جهنڊو: سينٽ پيئر ۽ ميڪيلون',
    '🇵🇳' => 'جهنڊو: پٽڪئرن ٻيٽ',
    '🇵🇷' => 'جهنڊو: پيوئرٽو ريڪو',
    '🇵🇸' => 'جهنڊو: فلسطيني علائقا',
    '🇵🇹' => 'جهنڊو: پرتگال',
    '🇵🇼' => 'جهنڊو: پلائو',
    '🇵🇾' => 'جهنڊو: پيراگوءِ',
    '🇶🇦' => 'جهنڊو: قطر',
    '🇷🇪' => 'جهنڊو: ري يونين',
    '🇷🇴' => 'جهنڊو: رومانيا',
    '🇷🇸' => 'جهنڊو: سربيا',
    '🇷🇺' => 'جهنڊو: روس',
    '🇷🇼' => 'جهنڊو: روانڊا',
    '🇸🇦' => 'جهنڊو: سعودي عرب',
    '🇸🇧' => 'جهنڊو: سولومون ٻيٽَ',
    '🇸🇨' => 'جهنڊو: شي شلز',
    '🇸🇩' => 'جهنڊو: سوڊان',
    '🇸🇪' => 'جهنڊو: سوئيڊن',
    '🇸🇬' => 'جهنڊو: سنگاپور',
    '🇸🇭' => 'جهنڊو: سينٽ ھيلينا',
    '🇸🇮' => 'جهنڊو: سلوینیا',
    '🇸🇯' => 'جهنڊو: سوالبارڊ ۽ يان ماین',
    '🇸🇰' => 'جهنڊو: سلوواڪيا',
    '🇸🇱' => 'جهنڊو: سيرا ليون',
    '🇸🇲' => 'جهنڊو: سان مرینو',
    '🇸🇳' => 'جهنڊو: سينيگال',
    '🇸🇴' => 'جهنڊو: سوماليا',
    '🇸🇷' => 'جهنڊو: سورينام',
    '🇸🇸' => 'جهنڊو: ڏکڻ سوڊان',
    '🇸🇹' => 'جهنڊو: سائو ٽومي ۽ پرنسپیي',
    '🇸🇻' => 'جهنڊو: ال سلواڊور',
    '🇸🇽' => 'جهنڊو: سنٽ مارٽن',
    '🇸🇾' => 'جهنڊو: شام',
    '🇸🇿' => 'جهنڊو: ايسواٽني',
    '🇹🇦' => 'جهنڊو: ٽرسٽن دا ڪوها',
    '🇹🇨' => 'جهنڊو: ترڪ ۽ ڪيڪوس ٻيٽ',
    '🇹🇩' => 'جهنڊو: چاڊ',
    '🇹🇫' => 'جهنڊو: فرانسيسي ڏاکڻي علائقا',
    '🇹🇬' => 'جهنڊو: ٽوگو',
    '🇹🇭' => 'جهنڊو: ٿائيليند',
    '🇹🇯' => 'جهنڊو: تاجڪستان',
    '🇹🇰' => 'جهنڊو: ٽوڪلائو',
    '🇹🇱' => 'جهنڊو: تيمور ليستي',
    '🇹🇲' => 'جهنڊو: ترڪمانستان',
    '🇹🇳' => 'جهنڊو: تيونيسيا',
    '🇹🇴' => 'جهنڊو: ٽونگا',
    '🇹🇷' => 'جهنڊو: ترڪييي',
    '🇹🇹' => 'جهنڊو: ٽرينيڊاڊ ۽ ٽوباگو',
    '🇹🇻' => 'جهنڊو: توالو',
    '🇹🇼' => 'جهنڊو: تائیوان',
    '🇹🇿' => 'جهنڊو: تنزانيا',
    '🇺🇦' => 'جهنڊو: يوڪرين',
    '🇺🇬' => 'جهنڊو: يوگنڊا',
    '🇺🇲' => 'جهنڊو: آمريڪي خارجي ٻيٽ',
    '🇺🇳' => 'جهنڊو: گڏيل قومون',
    '🇺🇸' => 'جهنڊو: آمريڪا جون گڏيل رياستون',
    '🇺🇾' => 'جهنڊو: يوروگوءِ',
    '🇺🇿' => 'جهنڊو: ازبڪستان',
    '🇻🇦' => 'جهنڊو: ويٽڪين سٽي',
    '🇻🇨' => 'جهنڊو: سینٽ ونسنت ۽ گریناڊینز',
    '🇻🇪' => 'جهنڊو: وينزويلا',
    '🇻🇬' => 'جهنڊو: برطانوي ورجن ٻيٽ',
    '🇻🇮' => 'جهنڊو: آمريڪي ورجن ٻيٽ',
    '🇻🇳' => 'جهنڊو: ويتنام',
    '🇻🇺' => 'جهنڊو: وينيٽيو',
    '🇼🇫' => 'جهنڊو: والس ۽ فتونا',
    '🇼🇸' => 'جهنڊو: ساموا',
    '🇽🇰' => 'جهنڊو: ڪوسووو',
    '🇾🇪' => 'جهنڊو: يمن',
    '🇾🇹' => 'جهنڊو: مياتي',
    '🇿🇦' => 'جهنڊو: ڏکڻ آفريقا',
    '🇿🇲' => 'جهنڊو: زيمبيا',
    '🇿🇼' => 'جهنڊو: زمبابوي',
    '🔟' => 'ڪي ڪيپ: 10',
    '🏻' => 'گوري رنگت',
    '🏼' => 'وچولي گوري رنگت',
    '🏽' => 'پڪو رنگ',
    '🏾' => 'وچولو ڪارو رنگ',
    '🏿' => 'ڪارو رنگ',
    '😀' => 'وڏي کل وارو چهرو',
    '😃' => 'وڏين انکين سان وڏي کل وارو چهرو',
    '😄' => 'کلندڙ اکين سان وڏي کل وارو چهرو',
    '😁' => 'کلندڙ اکين سان گڏ چمڪندڙ چهرو',
    '😆' => 'وڏي کل وارو ڦريل انکين وارو چهرو',
    '😅' => 'پگهر سان وڏي کل وارو چهرو',
    '🤣' => 'کلندي فرش تي ليٿڙيون پائيندي',
    '😂' => 'خوشي جي ڳوڙهن وارو چهرو',
    '🙂' => 'هلڪو مسڪرائيندڙ چهرو',
    '🙃' => 'ابتو چهرو',
    '🫠' => 'رجندڙ چھرو',
    '😉' => 'اک هڻڻ',
    '😊' => 'کلندڙ انکين سان کلندڙ چهرو',
    '😇' => 'نور جي حلقي سان مسڪرائيندڙ چهرو',
    '🥰' => 'دلين سان گڏ مرڪندڙ چهرو',
    '😍' => 'دل واري اکين سان مسڪرائيندڙ چهرو',
    '🤩' => 'اکيون تاري نما',
    '😘' => 'هڪ چمي موڪليندڙ چهرو',
    '😗' => 'چمي ڏيندڙ چهرو',
    '☺' => 'مرڪندڙ چهرو',
    '😚' => 'بند اکين سان گڏ چمي ڏيندڙ چهرو',
    '😙' => 'مسڪرائيندڙ اکين سان گڏ چمي ڏيندڙ چهرو',
    '🥲' => 'ڳوڙهن سان مسڪرائيندڙ چهرو',
    '😋' => 'کاڌي تي وات ۾ پاڻي اچڻ',
    '😛' => 'زبان وارو چهرو',
    '😜' => 'زبان سان گڏ چهرو انک هڻندي',
    '🤪' => 'چريو چهرو',
    '😝' => 'زبان سان گڏ انک بند ڪندي چهرو',
    '🤑' => 'وات ۾ پئسن وارو چهرو',
    '🤗' => 'ڀاڪر پائيندڙ چهرو',
    '🤭' => 'وات تي هٿ وارو چهرو',
    '🫢' => 'کليل اکين ۽ وات تي ھٿ ڏنل چھرو',
    '🫣' => 'لڪي ڏسڻ وارو چھرو',
    '🤫' => 'چپ چهرو',
    '🤔' => 'سوچيندڙ چهرو',
    '🫡' => 'سلام ڪندڙ چھرو',
    '🤐' => 'زپ ٿيل وات وارو چهرو',
    '🤨' => 'اڀريل ڀرن سان چهرو',
    '😐' => 'غير جانبدار چهرو',
    '😑' => 'بغير اظهاري وارو چهرو',
    '😶' => 'بغير وات وارو چهرو',
    '🫥' => 'ٽٻڪن واري لڪير وارو چھرو',
    '😏' => 'بناوٽي چهرو',
    '😒' => 'ناخوش چهرو',
    '🙄' => 'ڦرندڙ اکين سان چهرو',
    '😬' => 'بناوٽي صورت ٺاهيندڙ چهرو',
    '🤥' => 'ڪوڙ ڳالهائيندڙ چهرو',
    '🫨' => 'ڏڪندڙ چھرو',
    '😌' => 'آجو ٿيل چهرو',
    '😔' => 'فڪرمند چهرو',
    '😪' => 'ننڊ وارو چهرو',
    '🤤' => 'رال ٽپڪائيندڙ چهرو',
    '😴' => 'سمهندڙ چهرو',
    '🫩' => 'اکيون سڄل وارو منهن',
    '😷' => 'ميڊيڪل ماسڪ سان گڏ چهرو',
    '🤒' => 'ٿرماميٽر سان گڏ چهرو',
    '🤕' => 'مٿي تي پٽي ٻڌل چهرو',
    '🤢' => 'الٽي ايندڙ چهرو',
    '🤮' => 'چهرو الٽي ڪندي',
    '🤧' => 'ڇڪ ڏيندڙ چهرو',
    '🥵' => 'گرم چهرو',
    '🥶' => 'ٿڌو چهرو',
    '🥴' => 'ووزي چهرو',
    '😵' => 'چڪرائيندڙ چهرو',
    '🤯' => 'ڦاٽندڙ مٿو',
    '🤠' => 'ڪائوبوائي ٽوپي وارو چهرو',
    '🥳' => 'پارٽي ڪندڙ چهرو',
    '🥸' => 'لڪيل چهرو',
    '😎' => 'اس جي چشمي سان گڏ مسڪرائيندڙ چهرو',
    '🤓' => 'بيوقوف چهرو',
    '🧐' => 'هڪ عينڪ وارو چهرو',
    '😕' => 'الجهيل چهرو',
    '🫤' => 'ترڇي وات وارو چھرو',
    '😟' => 'پريشان چهرو',
    '🙁' => 'هلڪو لٿل چهرو',
    '☹' => 'لٿل چهرو',
    '😮' => 'کليل وات سان چهرو',
    '😯' => 'چپ ٿيل چهرو',
    '😲' => 'حيران ٿيل چهرو',
    '😳' => 'سرخي ڇانيل چهرو',
    '🫪' => 'بگڙيل چهرو',
    '🥺' => 'دلڪش چهرو',
    '🥹' => 'ڳوڙھا لڪائيندڙ چھرو',
    '😦' => 'کليل وات سان اداس چهرو',
    '😧' => 'ڏکايل چهرو',
    '😨' => 'ڊنل چهرو',
    '😰' => 'پگهر سان فڪرمند چهرو',
    '😥' => 'اداس پر سڪون وارو چهرو',
    '😢' => 'روئندڙ چهرو',
    '😭' => 'وڏي آواز سان روئندڙ چهرو',
    '😱' => 'ڊپ ۾ رڙيون ڪندڙ چهرو',
    '😖' => 'شرمنده چهرو',
    '😣' => 'چهرو',
    '😞' => 'نااميد چهرو',
    '😓' => 'هلڪي آنسن سان لٿل چهرو',
    '😩' => 'اکڙيل چهرو',
    '😫' => 'ٿڪل چهرو',
    '🥱' => 'اوٻاسيندڙ چهرو',
    '😤' => 'نڪ مان ٻاڦ نڪرندڙ چهرو',
    '😡' => 'منهن بسوريندڙ چهرو',
    '😠' => 'ڪاوڙيل چهرو',
    '🤬' => 'وات تي نشان سان گڏ چهرو',
    '😈' => 'سڱن وارو مسڪرائيندڙ چهرو',
    '👿' => 'سڱن وارو ڪاوڙيل چهرو',
    '💀' => 'کوپڙي',
    '☠' => 'کوپڙي ۽ خطري جي نشاني',
    '💩' => 'ڊڄارڻ جي شڪل جو انبار',
    '🤡' => 'جوڪر وارو چهرو',
    '👹' => 'آدمخور',
    '👺' => 'بونو',
    '👻' => 'ڀوت',
    '👽' => 'خلائي مخلوق',
    '👾' => 'خلائي مخلوق حيوان',
    '🤖' => 'روبوٽ',
    '😺' => 'ٻلي جو مسڪرائيندڙ چهرو',
    '😸' => 'مسڪرائيندڙ اکين سان گڏ مسڪرائيندڙ ٻلي',
    '😹' => 'خوشي جي لڙڪن سان ٻلي',
    '😻' => 'دل واري اکين سان مسڪرائيندڙ ٻلي',
    '😼' => 'بدشڪل مسڪراهٽ سان ٻلي',
    '😽' => 'چمي ڏيندڙ ٻلي',
    '🙀' => 'عجيب ٻلي',
    '😿' => 'روئندڙ ٻلي',
    '😾' => 'پائوٽنگ ٻلي',
    '🙈' => 'ڪا-شيطاني-نه-ڏسو وارو ڀولڙو',
    '🙉' => 'ڪا-شيطاني-نه-ٻڌو وارو ڀولڙو',
    '🙊' => 'ڪا-شيطاني-نه-ڳالهايو وارو ڀولڙو',
    '💌' => 'پيار جو خط',
    '💘' => 'دل جي وچ ۾ تير',
    '💝' => 'ربن سان گڏ دل',
    '💖' => 'ٽمڪندڙ دل',
    '💗' => 'وڌندڙ دل',
    '💓' => 'ڌڙڪندڙ دل',
    '💞' => 'ڦرندڙ دليون',
    '💕' => 'ٻه دليون',
    '💟' => 'دل جي سجاوٽ',
    '❣' => 'دل واري عجب جي نشاني',
    '💔' => 'ٽٽل دل',
    '❤' => 'ڳاڙهي دل',
    '🩷' => 'گلابي دل',
    '🧡' => 'نارنگي دل',
    '💛' => 'پيلي دل',
    '💚' => 'سائي دل',
    '💙' => 'نيري دل',
    '🩵' => 'ھلڪي نيري دل',
    '💜' => 'واڱڻائي دل',
    '🤎' => 'برائون دل',
    '🖤' => 'ڪاري دل',
    '🩶' => 'سرمائي دل',
    '🤍' => 'سفيد دل',
    '💋' => 'چمي جو نشان',
    '💯' => 'سو نقطا',
    '💢' => 'ڪاوڙ جي نشاني',
    '🫯' => 'جهيڙي وارو ڪڪر',
    '💥' => 'ٽڪراءُ',
    '💫' => 'چڪرائيندڙ',
    '💦' => 'پگهر جا قطرا',
    '💨' => 'پري اڇلائڻ',
    '🕳' => 'سوراخ',
    '💬' => 'ڳالهائڻ وارو ڦوڪڻو',
    '🗨' => 'کاٻي طرف بلبلا ڳالهه ٻولهه',
    '🗯' => 'ساڄي پاسي ڪاوڙ جا بلبلا',
    '💭' => 'خيال وارو ڦوڪڻو',
    '💤' => 'هلڪي نڊ',
    '👋' => 'لڏندڙ هٿ',
    '🤚' => 'هٿ جي پٺ مٿي ڪيل',
    '🖐' => 'مٿي ڪيل هٿ کليل آڱرين سان',
    '✋' => 'مٿي ڪيل هٿ',
    '🖖' => 'ولڪن سلام',
    '🫱' => 'ساڄي پاسي ويندڙ ھٿ',
    '🫲' => 'کاٻي پاسي ويندڙ ھٿ',
    '🫳' => 'ھيٺ تري وارو ھٿ',
    '🫴' => 'مٿي تري وارو ھٿ',
    '🫷' => 'کاٻي پاسي ڌڪيندڙ ھٿ',
    '🫸' => 'ساڄي پاسي ڌڪيندڙ ھٿ',
    '👌' => 'ٺيڪ وارو هٿ',
    '🤌' => 'پنچ ٿيل آڱريون',
    '🤏' => 'پنچنگ هٿ',
    '✌' => 'فتح جو نشان',
    '🤞' => 'ڪراس ٿيل آڱريون',
    '🫰' => 'پھرين آڱر ۽ آڱوٺو مڙيل ھٿ',
    '🤟' => 'پيار جو اشارو',
    '🤘' => 'سڱن جو نشان',
    '🤙' => 'مونکي ڪال ڪريو هٿ',
    '👈' => 'کاٻي هٿ جي آڱر کاٻي طرف اشارو ڪندي',
    '👉' => 'کاٻي هٿ جي آڱر ساڄي طرف اشارو ڪندي',
    '👆' => 'کاٻي هٿ جي آڱر مٿي اشارو ڪندي',
    '🖕' => 'وچين آڱر',
    '👇' => 'کاٻي هٿ جي آڱر هيٺ اشارو ڪندي',
    '☝' => 'آڱر مٿي طرف اشارو ڪندي',
    '🫵' => 'ڏسڻي آڱر ڏسڻ واري ڏانھن اشارو ڪندي',
    '👍' => 'مٿي انگوٺو',
    '👎' => 'هيٺ انگوٺو',
    '✊' => 'مٿي ڪيل مٺي',
    '👊' => 'ايندڙ مڪو',
    '🤛' => 'کاٻي طرف منهن ڪندڙ مٺي',
    '🤜' => 'ساڄي طرف منهن ڪندڙ مٺي',
    '👏' => 'تاڙيون وڄائيندڙ هٿ',
    '🙌' => 'مٿي ٿيندڙ هٿ',
    '🫶' => 'دل جي شڪل وارا ھٿ',
    '👐' => 'کليل هٿ',
    '🤲' => 'تريون مٿي گڏ',
    '🤝' => 'هٿ ملائڻ',
    '🙏' => 'ويڙهيل هٿ',
    '✍' => 'لکندڙ هٿ',
    '💅' => 'ننهن پالش',
    '🤳' => 'سيلفي',
    '💪' => 'مڙيل ٻانهن تي ڏورو',
    '🦾' => 'مڪينيڪل هٿ',
    '🦿' => 'ميڪينيڪل ٽنگ',
    '🦵' => 'ٽنگهه',
    '🦶' => 'پير',
    '👂' => 'ڪن',
    '🦻' => 'ٻڌڻ جي آلي سان ڪن',
    '👃' => 'نڪ',
    '🧠' => 'دماغ',
    '🫀' => 'دل عضوو',
    '🫁' => 'ڦڦڙ',
    '🦷' => 'ڏند',
    '🦴' => 'هڏي',
    '👀' => 'اکيون',
    '👁' => 'اک',
    '👅' => 'زبان',
    '👄' => 'وات',
    '🫦' => 'چپ کي چڪ ھڻڻ',
    '👶' => 'ننڍو ٻار',
    '🧒' => 'ٻار',
    '👦' => 'ڇوڪرو',
    '👧' => 'ڇوڪري',
    '🧑' => 'بالغ',
    '👱' => 'شخش: سنهڙا وار',
    '👨' => 'ماڻهو',
    '🧔' => 'شخص: ڏاڙهي',
    '👩' => 'عورت',
    '🧓' => 'وڏي عمر جو بالغ',
    '👴' => 'پوڙهو ماڻهو',
    '👵' => 'پوڙهي عورت',
    '🙍' => 'پريشان ماڻهو',
    '🙎' => 'ماڻهو ناپسند ڪندي',
    '🙅' => 'ماڻهو نه جو اشارو ڪندي',
    '🙆' => 'ماڻهو ٺيڪ جو اشارو ڪندي',
    '💁' => 'شخص هٿ ٿپڪائيندي',
    '🙋' => 'شخص هٿ مٿي ڪندي',
    '🧏' => 'ٻورو شخص',
    '🙇' => 'شخص جهڪندي',
    '🤦' => 'شخص جو نراڙ تي هٿ ڏيڻ',
    '🤷' => 'شخص اچڪائيندي',
    '👮' => 'پوليس آفيسر',
    '🕵' => 'جاسوس',
    '💂' => 'نگهبان',
    '🥷' => 'ننجا',
    '👷' => 'اڏاوت جو ڪم ڪندڙ',
    '🫅' => 'تاج پاتل ماڻھو',
    '🤴' => 'شهزادو',
    '👸' => 'شهزادي',
    '👳' => 'ماڻهو کي پگڙي پاتل',
    '👲' => 'چيني ٽوپي وارو ماڻهو',
    '🧕' => 'حجاب سان عورت',
    '🤵' => 'سوٽ ۾ ماڻهو',
    '👰' => 'شادي جي لباس سان ڪنوار',
    '🤰' => 'ڳورهاري عورت',
    '🫃' => 'ڳورھارو مرد',
    '🫄' => 'ڳورھارو ماڻھو',
    '🤱' => 'ٿڃ پيارڻ',
    '👼' => 'ننڍي پري',
    '🎅' => 'سانتا ڪلاز',
    '🤶' => 'ڪلاز جي مائي',
    '🦸' => 'سپر هيرو',
    '🦹' => 'سپر ولن',
    '🧙' => 'جادوگر',
    '🧚' => 'پري',
    '🧛' => 'ڏائڻ',
    '🧜' => 'ميل پرسن',
    '🧝' => 'بونا',
    '🧞' => 'جن',
    '🧟' => 'زومبي',
    '🧌' => 'جنڙو',
    '🫈' => 'بجري مخلوق',
    '💆' => 'مساج وٺندڙ شخص',
    '💇' => 'وارن جي ڪٽ وٺندڙ شخص',
    '🚶' => 'شخص هلندي',
    '🧍' => 'بيٺل ماڻهو',
    '🧎' => 'گوڏن ڀر ويٺل ماڻهو',
    '🏃' => 'شخص ڊوڙندي',
    '💃' => 'عورت نچندي',
    '🕺' => 'مرد نچندي',
    '🕴' => 'مرد سوٽ ۾',
    '👯' => 'خرگوش جي ڪنن وارو ماڻهو',
    '🧖' => 'شخص ٻاڦ واري ڪمري ۾',
    '🧗' => 'شخص چڙهندي',
    '🤺' => 'شخص بچاءُ ڪندي',
    '🏇' => 'گهوڙي جي ڊوڙ',
    '⛷' => 'برف تي کيڏي ويندڙ راند',
    '🏂' => 'سنوبورڊر',
    '🏌' => 'شخص گولف کيڏيندي',
    '🏄' => 'شخص سرفنگ ڪندي',
    '🚣' => 'شخص ٻيڙي ۾ چپو هلائيندي',
    '🏊' => 'شخص ترندي',
    '⛹' => 'شخص بائونسنگ بال سان کيڏندي',
    '🏋' => 'شخض وزن کڻندي',
    '🚴' => 'شخص بائيڪ هلائيندي',
    '🚵' => 'شخص جبل تي سائيڪل هلائيندي',
    '🤸' => 'شخص ڪارٽ وهلينگ ڪندي',
    '🤼' => 'ماڻهو ڪشتي وڙهندي',
    '🤽' => 'ماڻهو پاڻي وارو پولو کيڏيندي',
    '🤾' => 'ماڻهو هٿ جو بال کيڏندي',
    '🤹' => 'شخص جادوگري ڪندي',
    '🧘' => 'شخص لوٽس پوزيشن ۾',
    '🛀' => 'شخص وهجندي',
    '🛌' => 'بستر ۾ شخص',
    '👭' => 'هٿ جهليل عورتون',
    '👫' => 'هٿ جهليندي مرد ۽ عورت',
    '👬' => 'ٻه مرد هٿ جهليندي',
    '💏' => 'چمي',
    '💑' => 'دل سان جوڙو',
    '🗣' => 'مٿو ڳالهائيندي',
    '👤' => 'خطي تصوير ۾ مورتي',
    '👥' => 'خطي تصوير ۾ مورتيون',
    '🫂' => 'ڀاڪر پائيندڙ شخص',
    '👪' => 'ڪٽنب',
    '👣' => 'پيرن جا نشان',
    '🫆' => 'آڱرين جا نشان',
    '🦰' => 'ڳاڙها وار',
    '🦱' => 'گهنگرالو وار',
    '🦳' => 'اڇا وار',
    '🦲' => 'گنجو',
    '🐵' => 'ڀولو مهانڊو',
    '🐒' => 'ڀولڙو',
    '🦍' => 'گوريلا',
    '🦧' => 'اورنگٽان',
    '🐶' => 'ڪتو مهاندو',
    '🐕' => 'ڪتو',
    '🦮' => 'گائيڊ ڪتو',
    '🐩' => 'بوجرو ڪتو',
    '🐺' => 'بگهڙ',
    '🦊' => 'لومڙي',
    '🦝' => 'ريڪون',
    '🐱' => 'ٻلي مهانڊو',
    '🐈' => 'ٻلي',
    '🦁' => 'شينهن',
    '🐯' => 'چيتو مهانڊو',
    '🐅' => 'چيتو',
    '🐆' => 'باگ',
    '🐴' => 'گهوڙو مهانڊو',
    '🫎' => 'ڦاڙھو',
    '🫏' => 'گڏھ',
    '🐎' => 'گهوڙو',
    '🦄' => 'يونيڪورن',
    '🦓' => 'زيبرا',
    '🦌' => 'هرڻ',
    '🦬' => 'جهنگلي ڍڳو',
    '🐮' => 'ڍڳي مهانڊو',
    '🐂' => 'ڍڳو',
    '🐃' => 'پاڻي واري مينهن',
    '🐄' => 'ڍڳي',
    '🐷' => 'سوئر مهانڊو',
    '🐖' => 'سوئر',
    '🐗' => 'نر سوئر',
    '🐽' => 'سوئر نڪ',
    '🐏' => 'گهيٽو',
    '🐑' => 'رڍ',
    '🐐' => 'ٻڪري',
    '🐪' => 'اٺ',
    '🐫' => 'ٻن ٿوهن وارو اٺ',
    '🦙' => 'الاما',
    '🦒' => 'جراف',
    '🐘' => 'هاٿي',
    '🦣' => 'هاٿي جوناياب قسم',
    '🦏' => 'گينڊو',
    '🦛' => 'دريائي گهوڙو',
    '🐭' => 'ڪوئو مهانڊو',
    '🐁' => 'ڪوئو',
    '🐀' => 'چوهو',
    '🐹' => 'ڪوئي مهانڊو',
    '🐰' => 'سهو مهانڊو',
    '🐇' => 'سهو',
    '🐿' => 'نوريئوڙو',
    '🦫' => 'اود بل',
    '🦔' => 'سيهڙ',
    '🦇' => 'چمڙو',
    '🐻' => 'رڇ',
    '🐨' => 'خرسڪ',
    '🐼' => 'پانڊا',
    '🦥' => 'سلوٿ',
    '🦦' => 'اوٽر',
    '🦨' => 'اسڪنڪ',
    '🦘' => 'ڪينگرو',
    '🦡' => 'بيجر',
    '🐾' => 'چنبي جا نشان',
    '🦃' => 'ٽرڪي',
    '🐔' => 'مرغي',
    '🐓' => 'مرغو',
    '🐣' => 'بيضي مان نڪرندڙ چوزو',
    '🐤' => 'ننڍو مرغي جو ٻچو',
    '🐥' => 'اڳيان کان ننڍو مرغي جو ٻچو',
    '🐦' => 'پکي',
    '🐧' => 'پينگوئن',
    '🕊' => 'ڪبوتر',
    '🦅' => 'باز',
    '🦆' => 'بدڪ',
    '🦢' => 'سوان',
    '🦉' => 'چٻرو',
    '🦤' => 'ڊوڊو',
    '🪶' => 'کنڀ',
    '🦩' => 'فليمنگو',
    '🦚' => 'مور',
    '🦜' => 'طوطو',
    '🪽' => 'پر',
    '🪿' => 'ھنج',
    '🐸' => 'ڏيڏر',
    '🐊' => 'واڳون',
    '🐢' => 'ڪمي',
    '🦎' => 'ڪرڙي',
    '🐍' => 'نانگ',
    '🐲' => 'بلا مهانڊو',
    '🐉' => 'بلا',
    '🦕' => 'سارپا',
    '🦖' => 'ڊائنوسار',
    '🐳' => 'اسپائوٽنگ وهيل',
    '🐋' => 'وهيل',
    '🐬' => 'ڊالفن',
    '🫍' => 'اورڪا',
    '🦭' => 'سيل',
    '🐟' => 'مڇي',
    '🐠' => 'مداريني مڇي',
    '🐡' => 'بلوفش',
    '🦈' => 'شارڪ',
    '🐙' => 'ڪيڪڙو',
    '🐚' => 'ور وڪڙ واري ڪوڏي',
    '🪸' => 'مرجاني پٿر',
    '🪼' => 'جيلي فش',
    '🦀' => 'سرطان',
    '🦞' => 'لوبسٽر',
    '🦐' => 'جهينگو',
    '🦑' => 'اسڪواڊ',
    '🦪' => 'اوئيسٽر',
    '🐌' => 'سيپي',
    '🦋' => 'پوپٽ',
    '🐛' => 'مونگهڻ',
    '🐜' => 'ماڪوڙي',
    '🐝' => 'ماکي جي مک',
    '🪲' => 'بيٽل',
    '🐞' => 'ليڊي بيٽل',
    '🦗' => 'تڏ',
    '🪳' => 'ڪاڪروچ',
    '🕷' => 'ڪوريئڙو',
    '🕸' => 'ڪوريئڙي جي ڄار',
    '🦂' => 'وڇون',
    '🦟' => 'مڇر',
    '🪰' => 'مک',
    '🪱' => 'ڪيڙو',
    '🦠' => 'مائڪروب',
    '💐' => 'گلدستو',
    '🌸' => 'چيري بلاسم',
    '💮' => 'اڇو گل',
    '🪷' => 'ڪنول',
    '🏵' => 'گل نما',
    '🌹' => 'گلاب جو گل',
    '🥀' => 'ڪومايل گل',
    '🌺' => 'گل خطمي',
    '🌻' => 'سورج مکي',
    '🌼' => 'ٽڙيل',
    '🌷' => 'نرگس جو گل',
    '🪻' => 'سنبل گل',
    '🌱' => 'ٻج وارو گل',
    '🪴' => 'ڪونڊي ۾ ٻوٽو',
    '🌲' => 'سدا بهار وڻ',
    '🌳' => 'پتا ڇاڙيندڙ وڻ',
    '🌴' => 'کجي جو وڻ',
    '🌵' => 'ٿوهر',
    '🌾' => 'چانور جو پلندو',
    '🌿' => 'جڙي ٻوٽيون',
    '☘' => 'شيمراڪ',
    '🍀' => 'چار پنن وارو گاه',
    '🍁' => 'ميپل جو پن',
    '🍂' => 'ڇڻيل پن',
    '🍃' => 'هوا ۾ لڏندڙ پن',
    '🪹' => 'خالي آکيرو',
    '🪺' => 'آنن وارو آکيرو',
    '🍄' => 'خمبي',
    '🪾' => 'ٺوڙهو وڻ',
    '🍇' => 'انگور',
    '🍈' => 'گدرو',
    '🍉' => 'ڇانهه',
    '🍊' => 'طنچوري نارنگي',
    '🍋' => 'ليمو',
    '🍌' => 'ڪيلو',
    '🍍' => 'انناس',
    '🥭' => 'انب',
    '🍎' => 'ڳاڙهو صوف',
    '🍏' => 'سائو صوف',
    '🍐' => 'ناشپتي',
    '🍑' => 'آڙو',
    '🍒' => 'چيري',
    '🍓' => 'اسٽرابيري',
    '🫐' => 'بلو بيريز',
    '🥝' => 'ڪيوي ميوو',
    '🍅' => 'ٽماٽو',
    '🫒' => 'زيتون',
    '🥥' => 'ڪوپرو',
    '🥑' => 'مگر ناشپتي',
    '🍆' => 'وانڱڻ',
    '🥔' => 'پٽاٽو',
    '🥕' => 'گجر',
    '🌽' => 'مڪئي جا داڻا',
    '🌶' => 'گرم مرچ',
    '🫑' => 'بيل پيپر',
    '🥒' => 'کهيرو',
    '🥬' => 'پتيدار سائو',
    '🥦' => 'شاخ گوبي',
    '🧄' => 'ٿوم',
    '🧅' => 'بصر',
    '🥜' => 'کاڄو',
    '🫘' => 'رانھان',
    '🌰' => 'شاه بلوط',
    '🫚' => 'ادرڪ',
    '🫛' => 'مٽرن جي ڦري',
    '🫜' => 'پاڙي سبزي',
    '🍞' => 'روٽي',
    '🥐' => 'ڪروئيسانٽ',
    '🥖' => 'باگيٽ ماني',
    '🫓' => 'نان',
    '🥨' => 'پريٽزل',
    '🥯' => 'بيگل',
    '🥞' => 'پراٺو',
    '🧇' => 'ويفل',
    '🧀' => 'پنير پچر',
    '🍖' => 'هڏي تي گوشت',
    '🍗' => 'مرغي جي ٽنگ',
    '🥩' => 'گوشت جا وڍ',
    '🥓' => 'سوئر جو نمڪين گوشت',
    '🍔' => 'هيمبرگر',
    '🍟' => 'فرينچ فرائيز',
    '🍕' => 'پيزا',
    '🌭' => 'هاٽ ڊاگ',
    '🥪' => 'سينڊوچ',
    '🌮' => 'ٽاڪو',
    '🌯' => 'بريٽو',
    '🫔' => 'ٽيميل',
    '🥙' => 'ڪوڪي',
    '🧆' => 'فلافيل',
    '🥚' => 'بيضو',
    '🍳' => 'کاڌو پچائڻ',
    '🥘' => 'توو',
    '🍲' => 'کاڌي جو برتن',
    '🫕' => 'فانڊيو',
    '🥣' => 'چمچ سان برتن',
    '🥗' => 'سائو سلاد',
    '🍿' => 'مڪئي جا ڦلا',
    '🧈' => 'مکڻ',
    '🧂' => 'لوڻ',
    '🥫' => 'ڏٻي وارو کاڌو',
    '🍱' => 'کاڌي جو ڏٻو',
    '🍘' => 'چانور جو بسڪيٽ',
    '🍙' => 'چانور جو بال',
    '🍚' => 'پچيل چانور',
    '🍛' => 'ڪڙي چانور',
    '🍜' => 'گرم برتن',
    '🍝' => 'اسپگيٽي',
    '🍠' => 'ڀڳل مٺي گجر',
    '🍢' => 'اوڊن',
    '🍣' => 'سوشي',
    '🍤' => 'تريل جهينگا',
    '🍥' => 'گول مڇي ڪيڪ',
    '🥮' => 'مون ڪيڪ',
    '🍡' => 'ڊانگو',
    '🥟' => 'پڪوڙو',
    '🥠' => 'فارچيون ڪوڪي',
    '🥡' => 'ٻاهر وٺي وڃڻ وارو ڏٻو',
    '🍦' => 'نرم آئسڪريم',
    '🍧' => 'گنڊو',
    '🍨' => 'آئسڪريم',
    '🍩' => 'ڊونٽ',
    '🍪' => 'بسڪيٽ',
    '🎂' => 'جنم ڏينهن جو ڪيڪ',
    '🍰' => 'ننڍو ڪيڪ',
    '🧁' => 'ڪپ ڪيڪ',
    '🥧' => 'پائي',
    '🍫' => 'چاڪليٽ لڙي',
    '🍬' => 'کٽمٺو',
    '🍭' => 'چومپڙي',
    '🍮' => 'ڪسٽرڊ',
    '🍯' => 'ماکي جو برتن',
    '🍼' => 'ننڍن ٻارن جي بوتل',
    '🥛' => 'کير جو گلاس',
    '☕' => 'گرم مشروب',
    '🫖' => 'چانهه جو برتن',
    '🍵' => 'بغير ڪڙي جي چانهن جو ڪپ',
    '🍶' => 'سيڪ',
    '🍾' => 'پوپنگ ڪارڪ واري بوتل',
    '🍷' => 'وائين جو گلاس',
    '🍸' => 'ڪاڪٽيل جو گلاس',
    '🍹' => 'مداريني مشروب',
    '🍺' => 'بيئر مگ',
    '🍻' => 'ٽڪرائيجندڙ بيئر مگ',
    '🥂' => 'ٽڪرائيجندڙ گلاس',
    '🥃' => 'لوٽي نما گلاس',
    '🫗' => 'پاڻياٺ اوتڻ',
    '🥤' => 'اسٽرا سان ڪپ',
    '🧋' => 'ببل چانهن',
    '🧃' => 'بيوريج باڪس',
    '🧉' => 'ميٽ',
    '🧊' => 'آئيس ڪيوب',
    '🥢' => 'کاڌو کائڻ جون ڪاٺيون',
    '🍽' => 'پليٽ سان ڇري ۽ ڪانٽو',
    '🍴' => 'ڇري ۽ ڪانٽو',
    '🥄' => 'چمچ',
    '🔪' => 'رڌڻي جي ڇري',
    '🫙' => 'برني',
    '🏺' => 'صراحي',
    '🌍' => 'گلوب يورپ ايشيا ڏيکاري پيو',
    '🌎' => 'گلوب آمريڪا ڏيکاري پيو',
    '🌏' => 'گلوب ايشيا آسٽريليا ڏيکاري پيو',
    '🌐' => 'ميريڊيئن سان گلوب',
    '🗺' => 'دنيا جو نقشو',
    '🗾' => 'جاپاني نقشو',
    '🧭' => 'ڪمپاس',
    '🏔' => 'برف سان ڍڪيل جبل',
    '⛰' => 'جبل',
    '🛘' => 'زميني تودو',
    '🌋' => 'ٻرندڙ جبل',
    '🗻' => 'مائونٽ فوجي',
    '🏕' => 'ڪيمپ لڳائڻ',
    '🏖' => 'ڇٽي سان سامونڊي ڪناري',
    '🏜' => 'ريگستاني',
    '🏝' => 'ريگستاني ٻيٽ',
    '🏞' => 'قومي پارڪ',
    '🏟' => 'اسٽيڊيم',
    '🏛' => 'پراڻي عمارت',
    '🏗' => 'عمارت جي اڏاوت',
    '🧱' => 'سر',
    '🪨' => 'ٽڪري',
    '🪵' => 'ڪاٺي',
    '🛖' => 'جهوپڙي',
    '🏘' => 'گهرَ',
    '🏚' => 'لاوارث گهر',
    '🏠' => 'گهر',
    '🏡' => 'باغيچي وارو گهر',
    '🏢' => 'آفيس جي عمارت',
    '🏣' => 'جاپاني پوسٽ آفيس',
    '🏤' => 'پوسٽ آفيس',
    '🏥' => 'اسپتال',
    '🏦' => 'بئنڪ',
    '🏨' => 'هوٽل',
    '🏩' => 'پيار جي هوٽل',
    '🏪' => 'سهولت اسٽور',
    '🏫' => 'اسڪول',
    '🏬' => 'وڏي دڪان',
    '🏭' => 'فيڪٽري',
    '🏯' => 'جاپاني محل',
    '🏰' => 'محل',
    '💒' => 'شادي',
    '🗼' => 'ٽوڪيو ٽاور',
    '🗽' => 'آزادي جو مجسمو',
    '⛪' => 'چرچ',
    '🕌' => 'مسجد',
    '🛕' => 'هندو مندر',
    '🕍' => 'سناگاگ',
    '⛩' => 'شنٽو جي مزار',
    '🕋' => 'ڪعبو',
    '⛲' => 'ڦوهارو',
    '⛺' => 'خيمو',
    '🌁' => 'دهند',
    '🌃' => 'تارن واري رات',
    '🏙' => 'شهر جو منظر',
    '🌄' => 'جبلن مٿان سج اڀرندي',
    '🌅' => 'سج اڀرڻ',
    '🌆' => 'سج لهڻ تي شهر جو منظر',
    '🌇' => 'سج لهڻ',
    '🌉' => 'رات ۾ پل',
    '♨' => 'گرم چشما',
    '🎠' => 'جهولي جو گهوڙو',
    '🛝' => 'راند جي ميدان واري ترڪڻي',
    '🎡' => 'فيرس ڦيٿو',
    '🎢' => 'رولر ڪوسٽر',
    '💈' => 'حجام جي نشاني',
    '🎪' => 'سرڪس تنبو',
    '🚂' => 'ريل جو انجڻ',
    '🚃' => 'ريلوي ڪار',
    '🚄' => 'تيز رفتار واري ٽرين',
    '🚅' => 'گولي ريل گاڏي',
    '🚆' => 'ريل گاڏي',
    '🚇' => 'ميٽرو',
    '🚈' => 'برقي جي ري گاڏي',
    '🚉' => 'اسٽيشن',
    '🚊' => 'ٽرام',
    '🚝' => 'مونوريل',
    '🚞' => 'جابلو ريلوي',
    '🚋' => 'ٽرام ڪار',
    '🚌' => 'بس',
    '🚍' => 'ايندڙ بس',
    '🚎' => 'ٽرالي بس',
    '🚐' => 'ننڍي بس',
    '🚑' => 'ايمبولينس',
    '🚒' => 'باھ جي انجڻ',
    '🚓' => 'پوليس ڪار',
    '🚔' => 'ايندڙ پوليس ڪار',
    '🚕' => 'ٽيڪسي',
    '🚖' => 'ايندڙ ٽيڪسي',
    '🚗' => 'گاڏي',
    '🚘' => 'ايندڙ گاڏي',
    '🚙' => 'راند جي استعمال جي گاڏي',
    '🛻' => 'پڪ اپ ٽرڪ',
    '🚚' => 'پهچائڻ جي ٽرڪ',
    '🚛' => 'ٽرالر',
    '🚜' => 'ٽريڪٽر',
    '🏎' => 'ريسنگ جي ڪار',
    '🏍' => 'موٽر سائيڪل',
    '🛵' => 'موٽر اسڪوٽر',
    '🦽' => 'دستي وهيل چيئر',
    '🦼' => 'موٽر واري وهيل چيئر',
    '🛺' => 'آٽو رڪشا',
    '🚲' => 'سائيڪل',
    '🛴' => 'ڪڪ اسڪوٽر',
    '🛹' => 'اسڪيٽ بورڊ',
    '🛼' => 'رولر اسڪيٽ',
    '🚏' => 'بسن جو اڏو',
    '🛣' => 'موٽروي',
    '🛤' => 'ريلوي جي رستو',
    '🛢' => 'تيل جو ڊرم',
    '⛽' => 'اينڌن جو پمپ',
    '🛞' => 'ڦيٿو',
    '🚨' => 'پوليس ڪار جي لائيٽ',
    '🚥' => 'افقي ٽريفڪ جي لائيٽ',
    '🚦' => 'عمودي ٽريفڪ جي لائيٽ',
    '🛑' => 'روڪڻ جو نشان',
    '🚧' => 'اڏاوت',
    '⚓' => 'لنگر',
    '🛟' => 'ھوا سان ڀريل سيڻاھ',
    '⛵' => 'بادباني ٻيڙي',
    '🛶' => 'ڊونگي',
    '🚤' => 'تيز رفتار ٻيڙي',
    '🛳' => 'مسافر بحري جهاز',
    '⛴' => 'ٻيڙين جو اڏو',
    '🛥' => 'موٽر واري ٻيڙي',
    '🚢' => 'بحري جهاز',
    '✈' => 'هوائي جهاز',
    '🛩' => 'ننڍو هوائي جهاز',
    '🛫' => 'هوائي جهاز جي روانگي',
    '🛬' => 'هوائي جهاز جي آمد',
    '🪂' => 'پيراشوٽ',
    '💺' => 'سيٽ',
    '🚁' => 'هيلي ڪاپٽر',
    '🚟' => 'لٽڪيل ريلوي',
    '🚠' => 'جابلو ڪيبل وي',
    '🚡' => 'فضائي ٽرام وي',
    '🛰' => 'سيٽلائيٽ',
    '🚀' => 'راڪيٽ',
    '🛸' => 'اڏامندڙ بس',
    '🛎' => 'ڌيان چڪائڻ واري گهنٽي',
    '🧳' => 'ٻولي',
    '⌛' => 'ريت گهڙي پوري ٿي',
    '⏳' => 'ريت گهڙي پوري نه ٿي',
    '⌚' => 'گهڙي',
    '⏰' => 'الارم وارو گھڙيال',
    '⏱' => 'روڪ گهڙي',
    '⏲' => 'وقت اندازو ڪرڻ واري گهڙي',
    '🕰' => 'آتش دان جي گهڙي',
    '🕛' => '12 وڳين',
    '🕧' => '12 لڳي 30 منٽ',
    '🕐' => '1 وڳين',
    '🕜' => '1 لڳي 30 منٽ',
    '🕑' => 'ٻه وڳين',
    '🕝' => '2 لڳي 30 منٽ',
    '🕒' => '3 :00 وڳين',
    '🕞' => '3 لڳي 30 منٽ',
    '🕓' => '4 وڳين',
    '🕟' => '4 لڳي 30 منٽ',
    '🕔' => '5 وڳين',
    '🕠' => '5 لڳي 30 منٽ',
    '🕕' => '6:00 وڳين',
    '🕡' => '6:30 منٽ',
    '🕖' => '7:00 وڳين',
    '🕢' => '7:30',
    '🕗' => '8 وڳين',
    '🕣' => '8:30',
    '🕘' => '9:00 لڳي',
    '🕤' => '9:30',
    '🕙' => '10:00 لڳي',
    '🕥' => '10:30، 10 لڳي 30 منٽ',
    '🕚' => '11:00',
    '🕦' => '11:30',
    '🌑' => 'نئون چنڊ',
    '🌒' => 'ننڍي چنڊ ڏانهن وڌندڙ',
    '🌓' => 'پهرين عشري جو چنڊ',
    '🌔' => 'پوري چنڊ ڏانهن وڌندڙ',
    '🌕' => 'پورو چنڊ',
    '🌖' => 'ويننگ گبوس چنڊ',
    '🌗' => 'آخري عشري جو چنڊ',
    '🌘' => 'ويننگ ڪريسينٽ چنڊ',
    '🌙' => 'ڪريسينٽ چنڊ',
    '🌚' => 'نئين چنڊ جو چهرو',
    '🌛' => 'چهري سان گڏ پهري عشري جو چنڊ',
    '🌜' => 'چهري سان گڏ آخري عشري جو چنڊ',
    '🌡' => 'ٿرماميٽر',
    '☀' => 'سج',
    '🌝' => 'پوري چهري سان چنڊ',
    '🌞' => 'چهري سان گڏ سج',
    '🪐' => 'رنگ وارو پلانيٽ',
    '⭐' => 'سفيد وچولو تارو',
    '🌟' => 'چمڪندڙ تارو',
    '🌠' => 'ٽٽندڙ تارو',
    '🌌' => 'ڪهڪشان',
    '☁' => 'ڪڪر',
    '⛅' => 'ڪڪر جي پويان سج',
    '⛈' => 'ڪڪر سان کنوڻ ۽ برسات',
    '🌤' => 'ننڍن ڪڪرن پٺيان سج',
    '🌥' => 'وڏن ڪڪرن پويان سج',
    '🌦' => 'برساتي ڪڪرن پٺيان سج',
    '🌧' => 'ڪڪر سان گڏ برسات',
    '🌨' => 'ڪڪر سان گڏ برفباري',
    '🌩' => 'ڪڪر سان گڏ کنوڻ',
    '🌪' => 'طوفان',
    '🌫' => 'ڌنڌ',
    '🌬' => 'هوائي چهرو',
    '🌀' => 'سائيڪلون',
    '🌈' => 'انڊلٺ',
    '🌂' => 'بند ڇتي',
    '☂' => 'ڇٽي',
    '☔' => 'برسات جي ڇنتن سان گڏ ڇٽي',
    '⛱' => 'زمين تي ڇٽي',
    '⚡' => 'وڏا وولٽيج',
    '❄' => 'برف جو گولو',
    '☃' => 'برف وارا ماڻهو',
    '⛄' => 'بغير برف جي برف وارو ماڻهو',
    '☄' => 'پڇڙ تارو',
    '🔥' => 'باھ',
    '💧' => 'قطرو',
    '🌊' => 'پاڻي جي لهر',
    '🎃' => 'جيڪ او لالٽين',
    '🎄' => 'ڪرشمس وڻ',
    '🎆' => 'آتشبازي',
    '🎇' => 'ڦلجڙي',
    '🧨' => 'فائر ڪريڪر',
    '✨' => 'ڦلجڙيون',
    '🎈' => 'ڦوڪڻو',
    '🎉' => 'پارٽي پوپر',
    '🎊' => 'ڪانفيتي بال',
    '🎋' => 'تاناباتا وڻ',
    '🎍' => 'پائن سينگار',
    '🎎' => 'جاپاني گڏيون',
    '🎏' => 'ڪارپ اسٽيمر',
    '🎐' => 'هوا جي گهنٽي',
    '🎑' => 'چنڊ ڏسڻ جي رسم',
    '🧧' => 'ڳاڙهو لفافو',
    '🎀' => 'ڏوري',
    '🎁' => 'ويڙهيل تحفو',
    '🎗' => 'ياد ڏياريندڙ ڏوري',
    '🎟' => 'داخلا ٽڪيٽ',
    '🎫' => 'ٽڪيٽ',
    '🎖' => 'فوجي تمغو',
    '🏆' => 'ٽرافي',
    '🏅' => 'راندين جو تمغو',
    '🥇' => 'پهرين نمبر وارو تمغو',
    '🥈' => 'ٻي نمبر واري تمغو',
    '🥉' => 'ٽين نمبر وارو تمغو',
    '⚽' => 'ساڪر بال',
    '⚾' => 'بيس بال',
    '🥎' => 'نرم بال',
    '🏀' => 'باسڪيٽ بال',
    '🏐' => 'والي بال',
    '🏈' => 'آمريڪي فٽبال',
    '🏉' => 'رگبي فٽبال',
    '🎾' => 'ٽينس',
    '🥏' => 'فلائنگ ڊسڪ',
    '🎳' => 'بائولنگ',
    '🏏' => 'ڪرڪيٽ راند',
    '🏑' => 'فيلڊ هاڪي',
    '🏒' => 'برفاني هاڪي',
    '🥍' => 'ليڪروز',
    '🏓' => 'پنگ پانگ',
    '🏸' => 'بيڊمنٽن',
    '🥊' => 'باڪسنگ دستانو',
    '🥋' => 'مارشل آرٽ جي وردي',
    '🥅' => 'گول جي ڄاري',
    '⛳' => 'ٻر ۾ جهنڊي',
    '⛸' => 'آئس اسڪيٽ',
    '🎣' => 'فشنگ پول',
    '🤿' => 'ڊرائيونگ ماسڪ',
    '🎽' => 'هلندڙ شرٽ',
    '🎿' => 'اسڪائيز',
    '🛷' => 'سليڊ',
    '🥌' => 'ڪرلنگ اسٽور',
    '🎯' => 'سڌو هڻڻ',
    '🪀' => 'یو-یو',
    '🪁' => 'لغڙ',
    '🔫' => 'پسٽل',
    '🎱' => 'پول 8 بال',
    '🔮' => 'شيشي جو بال',
    '🪄' => 'جادوئي لفظ',
    '🎮' => 'ويڊيو راند',
    '🕹' => 'جوائي اسٽڪ',
    '🎰' => 'خانن واري مشيني راند',
    '🎲' => 'راند جي داڻي',
    '🧩' => 'پزل پيس',
    '🧸' => 'ٽيڊي بيئر',
    '🪅' => 'piñata',
    '🪩' => 'آئينن جو ٺھيل بال',
    '🪆' => 'آکاري واريون گڏيون',
    '♠' => 'اسپيڊ سوٽ',
    '♥' => 'هرٽ سوٽ',
    '♦' => 'ڊائيمند سوٽ',
    '♣' => 'ڪلب سوٽ',
    '♟' => 'چيس جو پيادو',
    '🃏' => 'جوڪر',
    '🀄' => 'مهيجونگ ريڊ ڊريگون',
    '🎴' => 'فلاور پلئينگ ڪارڊ',
    '🎭' => 'فن ڏيکاريندي',
    '🖼' => 'فريم ٿيل تصوير',
    '🎨' => 'پينٽر جي رنگ جي تختي',
    '🧵' => 'ڌاڳو',
    '🪡' => 'سلائي جو نيڊل',
    '🧶' => 'يارن',
    '🪢' => 'ڳنڍ',
    '👓' => 'عينڪ',
    '🕶' => 'اُس جا چشما',
    '🥽' => 'چشما',
    '🥼' => 'ليب ڪوٽ',
    '🦺' => 'تحفظ ڪوٽ',
    '👔' => 'ٽائي',
    '👕' => 'ٽي شرٽ',
    '👖' => 'جينس',
    '🧣' => 'حجاب',
    '🧤' => 'دستانا',
    '🧥' => 'ڪوٽ',
    '🧦' => 'جوراب',
    '👗' => 'وڳو',
    '👘' => 'گائون',
    '🥻' => 'ساڙي',
    '🩱' => 'هڪ-پيس سوم سوٽ',
    '🩲' => 'بريفس',
    '🩳' => 'شارٽس',
    '👙' => 'بڪني',
    '👚' => 'عورت جا ڪپڙا',
    '🪭' => 'ھٿ وارو پکو',
    '👛' => 'ٻٽون',
    '👜' => 'هٿ جو ٿيلو',
    '👝' => 'عورتن جو ٻٽون',
    '🛍' => 'خريداري جي ٿيلي',
    '🎒' => 'اسڪول جو پٺن وارو ٿيلو',
    '🩴' => 'ٿونگ سينڊل',
    '👞' => 'مرد جو جوتو',
    '👟' => 'ڊوڙڻ وارو جوتو',
    '🥾' => 'هائيڪنگ بوٽ',
    '🥿' => 'فليٽ جوتو',
    '👠' => 'وڏي کڙي وارو جوتو',
    '👡' => 'عورت جو سينڊل',
    '🩰' => 'بيليٽ جوتا',
    '👢' => 'عورت جو بوٽ',
    '🪮' => 'مٿو کنھڻ وارو ڪنگو',
    '👑' => 'تاج',
    '👒' => 'عورت جي ٽوپي',
    '🎩' => 'مٿي جي ٽوپي',
    '🎓' => 'گريجوئيشن واري ٽوپي',
    '🧢' => 'ڇاڄي واري ٽوپي',
    '🪖' => 'مليٽري هيلمينٽ',
    '⛑' => 'بچاءُ ڪارڪن جي ٽوپي',
    '📿' => 'تسبي',
    '💄' => 'سرخي',
    '💍' => 'منڊي',
    '💎' => 'قيمتي پٿر',
    '🔇' => 'آوازبند ڪيل اسپيڪر',
    '🔈' => 'اسپيڪر جو آواز گهٽ',
    '🔉' => 'اسپيڪر جو وچولو آواز',
    '🔊' => 'اسپيڪر جو وڏو آواز',
    '📢' => 'لائوڊ اسپيڪر',
    '📣' => 'وڏو فون',
    '📯' => 'پوسٽل هارون',
    '🔔' => 'گهنٽي',
    '🔕' => 'سليش سان گهنٽي',
    '🎼' => 'موسيقي جو دڪان',
    '🎵' => 'موسيقي جا نوٽ',
    '🎶' => 'موسيقي وارا نوٽ',
    '🎙' => 'اسٽوڊيو جو مائيڪروفون',
    '🎚' => 'ليول سلائيڊر',
    '🎛' => 'ڪنٽرول نابس',
    '🎤' => 'مائيڪروفون',
    '🎧' => 'هيڊ فون',
    '📻' => 'ريڊيو',
    '🎷' => 'سيڪسو فون',
    '🎺' => 'ترم',
    '🪊' => 'ٽرومبون',
    '🪗' => 'اڪورڊيون',
    '🎸' => 'گٽار',
    '🎹' => 'موسيقي وارو ڪيبورڊ',
    '🎻' => 'وائلن',
    '🪕' => 'بانجو',
    '🥁' => 'ڊهول',
    '🪘' => 'وڏو ڊرم',
    '🪇' => 'ڇمڪڻا',
    '🪈' => 'بانسري',
    '🪉' => 'سرندو',
    '📱' => 'موبائيل فون',
    '📲' => 'تير سان گڏ موبائل فون',
    '☎' => 'ٽيليفون',
    '📞' => 'ٽيليفون جو رسيور',
    '📟' => 'پيجر',
    '📠' => 'فيڪس مشين',
    '🔋' => 'بيٽري',
    '🪫' => 'گھٽ بيٽري',
    '🔌' => 'برقي پلگ',
    '💻' => 'ليپٽاپ ڪمپيوٽر',
    '🖥' => 'ڊيسڪٽاپ ڪمپيوٽر',
    '🖨' => 'پرنٽر',
    '⌨' => 'ڪليدي بورڊ',
    '🖱' => 'ڪمپيوٽر مائوس',
    '🖲' => 'ٽريڪ بال',
    '💽' => 'ڪمپيوٽر جي ڊسڪ',
    '💾' => 'فلاپي ڊسڪ',
    '💿' => 'آپٽيڪل ڊسڪ',
    '📀' => 'ڊي وي ڊي',
    '🧮' => 'ابيڪس',
    '🎥' => 'مووي ڪئيمرا',
    '🎞' => 'فلم فريم',
    '📽' => 'فلم پروجيڪٽر',
    '🎬' => 'ڪليپربورڊ',
    '📺' => 'ٽيليوزن',
    '📷' => 'ڪئميرا',
    '📸' => 'فليش واري ڪئميرا',
    '📹' => 'ويڊيو ڪئميرا',
    '📼' => 'ويڊيو ڪيسٽ',
    '🔍' => 'ميگنيفائينگ کاٻي پاسي مڙيل شيشو',
    '🔎' => 'ميگنيفائينگ ساڄي پاسي مڙيل شيشو',
    '🕯' => 'ميڻ بتي',
    '💡' => 'روشني جو بلب',
    '🔦' => 'فليش لائيٽ',
    '🏮' => 'ڳاڙهي ڪاغذ واري لينٽرن',
    '🪔' => 'ڏيو بتي',
    '📔' => 'سينگاريل پاٺي وارو ڪتاب',
    '📕' => 'بند ڪتاب',
    '📖' => 'کليل ڪتاب',
    '📗' => 'سائو ڪتاب',
    '📘' => 'نيرو ڪتاب',
    '📙' => 'نارنگي ڪتاب',
    '📚' => 'ڪتابون',
    '📓' => 'نوٽ بڪ',
    '📒' => 'ليجر',
    '📃' => 'وڪڙ سان صفحو',
    '📜' => 'ويڙهيل',
    '📄' => 'مٿي منهن ڪندڙ صفحو',
    '📰' => 'اخبار',
    '🗞' => 'ويڙهيل اخبار',
    '📑' => 'بڪ مارڪ وارا ٽيب',
    '🔖' => 'بڪ مارڪ',
    '🏷' => 'ٺپو',
    '🪙' => 'سڪو',
    '💰' => 'پئسن جي ڳوٿري',
    '🪎' => 'خزاني جي پيٽي',
    '💴' => 'يين بئنڪ نوٽ',
    '💵' => 'ڊائر بئنڪ نوٽ',
    '💶' => 'يورو بئنڪ نوٽ',
    '💷' => 'پائونڊ بئنڪ نوٽ',
    '💸' => 'پرن وارا پئسا',
    '💳' => 'ڪريڊٽ ڊالر',
    '🧾' => 'رسيد',
    '💹' => 'يين سان گڏ وڌندڙ چارٽ',
    '✉' => 'لفافو',
    '📧' => 'اي-ميل',
    '📨' => 'ايندڙ لفافو',
    '📩' => 'تير سان لفافو',
    '📤' => 'آئوٽ باڪس ٽري',
    '📥' => 'انباڪس ٽري',
    '📦' => 'پئڪيج',
    '📫' => 'مٿي ڪيل جهنڊي سان گڏ بند ٿيل ميل باڪس',
    '📪' => 'هيٺ ڪيل جهنڊي سان گڏ بند ٿيل ميل باڪس',
    '📬' => 'مٿي ڪيل جهنڊي سان گڏ کليل ميل باڪس',
    '📭' => 'هيٺ ڪيل جهنڊي سان گڏ کليل ميل باڪس',
    '📮' => 'پوسٽ باڪس',
    '🗳' => 'بيلٽ باڪس سان بيلٽ',
    '✏' => 'پينسل',
    '✒' => 'ڪاري نب',
    '🖋' => 'فائونٽين پين',
    '🖊' => 'قلم',
    '🖌' => 'پينٽ برش',
    '🖍' => 'رنگدار',
    '📝' => 'ميمو',
    '💼' => 'بريف ڪيس',
    '📁' => 'فائل فولڊر',
    '📂' => 'کليل فائل فولڊر',
    '🗂' => 'ڪارڊ ترتيب سان ورهائيندڙ',
    '📅' => 'ڪئلينڊر',
    '📆' => 'ٽوڙڻ وارو ڪئلينڊر',
    '🗒' => 'اسپائرل نوٽ پيڊ',
    '🗓' => 'اسپائرل ڪئلينڊر',
    '📇' => 'ڪارڊ انڊيڪس',
    '📈' => 'وڌندڙ چارٽ',
    '📉' => 'چارٽ گهٽجندي',
    '📊' => 'بار چارٽ',
    '📋' => 'ڪلپ بورڊ',
    '📌' => 'دٻائڻ واري پن',
    '📍' => 'گول دٻائڻ واري پن',
    '📎' => 'ڪاغذ جهلڻ وارو ڪلپ',
    '🖇' => 'ڪاغذ جهلڻ وارو ڳنڍيل ڪلپ',
    '📏' => 'سڌو ماپيندڙ',
    '📐' => 'ٽڪنڊو ماپيندڙ',
    '✂' => 'قينچي',
    '🗃' => 'ڪارڊ فائيل باڪس',
    '🗄' => 'فائل رکڻ جو دراز',
    '🗑' => 'ڪچري جي ٽوڪري',
    '🔒' => 'لاڪ ٿيل',
    '🔓' => 'کليل',
    '🔏' => 'پين سان لاڪ',
    '🔐' => 'چاٻي سان لاڪ',
    '🔑' => 'چاٻي',
    '🗝' => 'پراڻي چاٻي',
    '🔨' => 'هٿوڙو',
    '🪓' => 'ڪهاڙو',
    '⛏' => 'ٽيڪم',
    '⚒' => 'هٿوڙو ۽ ٽيڪم',
    '🛠' => 'هٿوڙو ۽ پانو',
    '🗡' => 'خنجر',
    '⚔' => 'آمهون سامهون تلوار',
    '💣' => 'بم',
    '🪃' => 'بومرانگ',
    '🏹' => 'ڪمان ۽ تير',
    '🛡' => 'ڍال',
    '🪚' => 'واڍي جي ڪارائي',
    '🔧' => 'پانو',
    '🪛' => 'اسڪرو ڊرائيور',
    '🔩' => 'نٽ ۽ بولٽ',
    '⚙' => 'گيئر',
    '🗜' => 'ڪلپ',
    '⚖' => 'متوازن ماپو',
    '🦯' => 'پروبنگ ڪين',
    '🔗' => 'ڪڙي',
    '⛓' => 'زنجير',
    '🪝' => 'هوڪ',
    '🧰' => 'ٽول باڪس',
    '🧲' => 'ميگنيٽ',
    '🪜' => 'چاڙهي',
    '🪏' => 'بيلچو',
    '⚗' => 'اليمبڪ',
    '🧪' => 'ٽيسٽ ٽيوب',
    '🧫' => 'پيٽري ڊش',
    '🧬' => 'ڊي اين اي',
    '🔬' => 'مائڪرو اسڪوپ',
    '🔭' => 'ٽيلي اسڪوپ',
    '📡' => 'سيٽ لائيٽ اينٽينا',
    '💉' => 'سرنج',
    '🩸' => 'رت جو فڙو',
    '💊' => 'گوري',
    '🩹' => 'چمبڙندڙ پٽي',
    '🩼' => 'بيساکي',
    '🩺' => 'اسٽيٿو اسڪوپ',
    '🩻' => 'ايڪسري',
    '🚪' => 'دروازو',
    '🛗' => 'ايليويٽر',
    '🪞' => 'آئينو',
    '🪟' => 'دري',
    '🛏' => 'بسترو',
    '🛋' => 'صوفو ۽ بتي',
    '🪑' => 'ڪرسي',
    '🚽' => 'بيت الاخلا',
    '🪠' => 'پلونگر',
    '🚿' => 'ڦوارو',
    '🛁' => 'وهنجڻ جو ڪونڏو',
    '🪤' => 'مائوس ٽريپ',
    '🪒' => 'ريزر',
    '🧴' => 'لوشن جي بوتل',
    '🧷' => 'حفاظتي پن',
    '🧹' => 'ٻهاري',
    '🧺' => 'ٽوڪري',
    '🧻' => 'پيپر جو رول',
    '🪣' => 'بڪيٽ',
    '🧼' => 'صابڻ',
    '🫧' => 'بوڻيا',
    '🪥' => 'ٽوٿ برش',
    '🧽' => 'جذب ڪار',
    '🧯' => 'باهه وسائيندڙ',
    '🛒' => 'خريداري جو گاڏو',
    '🚬' => 'سگريٽ',
    '⚰' => 'ڪفن',
    '🪦' => 'وڏو پٿر',
    '⚱' => 'جنازي جي خاڪ واري صراحي',
    '🧿' => 'نزر اميوليٽ',
    '🪬' => 'ھمسا',
    '🗿' => 'موئي',
    '🪧' => 'پليس ڪارڊ',
    '🪪' => 'سڃاڻپ ڪارڊ',
    '🏧' => 'اي ٽي ايم جي نشاني',
    '🚮' => 'ڪچرو دٻي ۾ اڇلائڻ جي نشاني',
    '🚰' => 'پيئڻ جو پاڻي',
    '♿' => 'ڦيٿي واري ڪرسي جي نشاني',
    '🚹' => 'مردن جو ڪمرو',
    '🚺' => 'عورتن جو ڪمرو',
    '🚻' => 'آرام جو ڪمرو',
    '🚼' => 'ٻار جو نشان',
    '🚾' => 'پاڻي جو هبار',
    '🛂' => 'پاسپورٽ ڪنٽرول',
    '🛃' => 'ڪسٽمز',
    '🛄' => 'سامان جو دعوو',
    '🛅' => 'ڇڏيل سامان',
    '⚠' => 'انتباھ',
    '🚸' => 'ٻارن جو گذرڻ',
    '⛔' => 'داخلا ممنوع',
    '🚫' => 'منع ڪيل',
    '🚳' => 'سائيڪلون نه',
    '🚭' => 'سگريٽ پيئڻ منع آهي',
    '🚯' => 'ڪچرو اڇلائن منع آهي',
    '🚱' => 'پيئڻ جو پاڻي ناهي',
    '🚷' => 'هلڻو ناهي',
    '📵' => 'موبائيل فون نه',
    '🔞' => 'ارڙهن کان گهٽ ڪو به نه',
    '☢' => 'تابڪاري',
    '☣' => 'حياتي لاءِ نقصانڪار',
    '⬆' => 'مٿي تير',
    '↗' => 'مٿي ساڄي تير',
    '➡' => 'ساڄي تير',
    '↘' => 'هيٺ ساڄي طرف تير',
    '⬇' => 'هيٺ تير',
    '↙' => 'هيٺ کاٻي طرف تير',
    '⬅' => 'کاٻي طرف تير',
    '↖' => 'مٿ کاٻي طرف تير',
    '↕' => 'مٿي هيٺ طرف تير',
    '↔' => 'ساڄي کاٻي پاسي تير',
    '↩' => 'ساڄي تير مڙندي کاٻي طرف',
    '↪' => 'کاٻي تير مڙندي ساڄي طرف',
    '⤴' => 'ساڄي تير مڙندي مٿين طرف',
    '⤵' => 'هيٺ مڙندي ساڄي طرف تير',
    '🔃' => 'ڪلاڪ وانگي عمودي تير',
    '🔄' => 'ابتي ڪلاڪ وانگي تيري بٽڻ',
    '🔙' => 'پٺيان وارو تير',
    '🔚' => 'پڇاڙي وارو تير',
    '🔛' => 'آن! تير',
    '🔜' => 'جلدي تير',
    '🔝' => 'مٿيون تير',
    '🛐' => 'عبادت جي جڳھ',
    '⚛' => 'ائٽم جي نشاني',
    '🕉' => 'اوم',
    '✡' => 'ڊيوڊ جو تارو',
    '☸' => 'ڌرما جو ڦيٿو',
    '☯' => 'ين يينگ',
    '✝' => 'لاطيني ڪراس',
    '☦' => 'آرٿوڊوڪس ڪراس',
    '☪' => 'تارو ۽ چنڊ',
    '☮' => 'امن جي نشاني',
    '🕎' => 'مينوره',
    '🔯' => 'ڊاٽ وارو ڇھ نقطن وارو تارو',
    '🪯' => 'کانڊا',
    '♈' => 'برج حمل',
    '♉' => 'برج ثور',
    '♊' => 'برج جوزا',
    '♋' => 'برج سرطان',
    '♌' => 'برج اسد',
    '♍' => 'برج سنبله',
    '♎' => 'برج ميزان',
    '♏' => 'برج عقرب',
    '♐' => 'برج قوس',
    '♑' => 'برج جدي',
    '♒' => 'برج دلو',
    '♓' => 'برج حوت',
    '⛎' => 'علم نجوم',
    '🔀' => 'شفل ٽريڪ بٽڻ',
    '🔁' => 'ورجائڻ وارو بٽڻ',
    '🔂' => 'اڪيلو ورجائڻ وارو بٽڻ',
    '▶' => 'هلائڻ وارو بٽڻ',
    '⏩' => 'تڪڙو اڳتي ڪرڻ جو بٽڻ',
    '⏭' => 'اڳيئن ٽريڪ جو بٽڻ',
    '⏯' => 'هلائڻ ۽ ساڪت جو بٽڻ',
    '◀' => 'پوئتي ڪرڻ جو بٽڻ',
    '⏪' => 'تڪڙو پٺتي ڪرڻ جو بٽڻ',
    '⏮' => 'آخري ٽريڪ جو بٽڻ',
    '🔼' => 'مٿي وارو بٽڻ',
    '⏫' => 'تڪڙو مٿي ڪرڻ جو بٽڻ',
    '🔽' => 'هيٺ وارو بٽڻ',
    '⏬' => 'تڪڙو هيٺ ڪرڻ وارو بٽڻ',
    '⏸' => 'ساڪت ڪرڻ جو بٽڻ',
    '⏹' => 'بند ڪرڻ وارو بٽڻ',
    '⏺' => 'ڀرڻ جو بٽڻ',
    '⏏' => 'ڪڍڻ جو بٽڻ',
    '🎦' => 'سئنيما',
    '🔅' => 'ڊم ڪرڻ وارو بٽڻ',
    '🔆' => 'روشن ڪرڻ وارو بٽڻ',
    '📶' => 'اينٽينا بار',
    '🛜' => 'وائرليس',
    '📳' => 'حرڪت وارو موڊ',
    '📴' => 'موبائيل فون بند',
    '♀' => 'عورت جي نشاني',
    '♂' => 'مرد جي نشاني',
    '⚧' => 'وچ جنس جي نشاني',
    '✖' => 'ضرب',
    '➕' => 'واڌو جي نشاني',
    '➖' => 'ڪاٽو جي نشاني',
    '➗' => 'ونڊ',
    '🟰' => 'برابر جي ڳوري نشاني',
    '♾' => 'انفينٽي',
    '‼' => 'ٻٽي عجب جي نشاني',
    '⁉' => 'عجب جي سوال جو نشان',
    '❓' => 'ڳاڙهي سوال جي نشاني',
    '❔' => 'سفيد سوال جي نشاني',
    '❕' => 'سفيد عجب جي نشاني',
    '❗' => 'ڳاڙهي عجب جي نشاني',
    '〰' => 'لڏندڙ ڊيش',
    '💱' => 'سڪو مٽاسٽا',
    '💲' => 'ٿلهي ڊالر جي نشاني',
    '⚕' => 'ميڊيڪل جي نشاني',
    '♻' => 'ٻيهر استعمال جي نشاني',
    '⚜' => 'للي جو گل',
    '🔱' => 'ترشول جو نشان',
    '📛' => 'نالي جو بيج',
    '🔰' => 'شروعات ڪندڙ جي لاءِ جاپاني نشاني',
    '⭕' => 'ٿلهو وڏو دائرو',
    '✅' => 'چيڪ مارڪ بٽڻ',
    '☑' => 'چيڪ سان چيڪ باڪس',
    '✔' => 'چيڪ مارڪ',
    '❌' => 'ڪراس جي نشاني',
    '❎' => 'ڪراس نشاني وارو بٽڻ',
    '➰' => 'گھنڊيدار لوپ',
    '➿' => 'ٻٽي مڙيل لوپ',
    '〽' => 'حصو ڦير جو نشان',
    '✳' => 'اٺ ڳالهائڻ جا ايسٽيرڪ',
    '✴' => 'اٺ نوڪدار نشان',
    '❇' => 'ٽمڪڻ',
    '™' => 'ٽريڊ مارڪ',
    '🫟' => 'ڦهلائڻ',
    '🔠' => 'انپٽ لاطيني وڏو ڪيس',
    '🔡' => 'انپٽ لاطيني ننڍو ڪيس',
    '🔢' => 'انپٽ نمبر',
    '🔣' => 'انپٽ نشانيون',
    '🔤' => 'انپٽ لاطيني اکر',
    '🅰' => 'A بٽڻ ( رت جو قسم)',
    '🆎' => 'AB بٽڻ (رت جو قسم)',
    '🅱' => 'B بٽڻ (رت جو قسم)',
    '🆑' => 'CL بٽڻ',
    '🆒' => 'ٿڌ جو بٽڻ',
    '🆓' => 'مفت بٽڻ',
    'ℹ' => 'معلومات',
    '🆔' => 'ID بٽڻ',
    'Ⓜ' => 'سرڪل ٿيل M',
    '🆕' => 'نئون بٽڻ',
    '🆖' => 'NG بٽڻ',
    '🅾' => 'O بٽڻ (رت جو قسم)',
    '🆗' => 'OK بٽڻ',
    '🅿' => 'P بٽڻ',
    '🆘' => 'SOS بٽڻ',
    '🆙' => 'مٿي! بٽڻ',
    '🆚' => 'VS بٽڻ',
    '🈁' => 'جاپاني ‘هتي’ بٽڻ',
    '🈂' => 'جاپاني “سروس چارج” بٽڻ',
    '🈷' => 'جاپاني “ماهوار رقم” بٽڻ',
    '🈶' => 'جاپاني ‘مفت ۾ نه آهي’ بٽڻ',
    '🈯' => 'جاپاني ‘‘رکيل’‘ بٽڻ',
    '🉐' => 'جاپاني ‘سودو’ بٽڻ',
    '🈹' => 'جاپاني "رعايت" بٽڻ',
    '🈚' => 'جاپاني ‘مفت ۾‘ بٽڻ',
    '🈲' => 'جاپاني ‘منع ڪيل’ بٽڻ',
    '🉑' => 'جاپاني ‘قابلِ قبول’ بٽڻ',
    '🈸' => 'جاپاني ‘درخواست’ بٽڻ',
    '🈴' => 'جاپاني ‘پاس ٿيڻ جو گريڊ’ بٽڻ',
    '🈳' => 'جاپاني ‘ويڪنسي’ بٽڻ',
    '㊗' => 'جاپاني “مبارڪباد” بٽڻ',
    '㊙' => 'جاپاني “راز” بٽڻ',
    '🈺' => 'جاپاني ‘ڪاروبار لاءِ کليل’ بٽڻ',
    '🈵' => 'جاپاني ‘ويڪنسي نه آهي’ بٽڻ',
    '🔴' => 'ڳاڙهو دائرو',
    '🟠' => 'نارنگي دائرو',
    '🟡' => 'پيلو دائرو',
    '🟢' => 'سائو دائرو',
    '🔵' => 'نيرو دائرو',
    '🟣' => 'جامني دائرو',
    '🟤' => 'برائون دائرو',
    '⚫' => 'ڪارو دائرو',
    '⚪' => 'اڇو دائرو',
    '🟥' => 'ڳاڙهو چورس',
    '🟧' => 'نارنگي چورس',
    '🟨' => 'پيلو چورس',
    '🟩' => 'سائو چورس',
    '🟦' => 'نيرو چورس',
    '🟪' => 'جامني چورس',
    '🟫' => 'برائون چورس',
    '⬛' => 'ڪارو وڏو چورس',
    '⬜' => 'سفيد وڏو چورس',
    '◼' => 'ڪارو وچولو چورس',
    '◻' => 'سفيد وچولو چورس',
    '◾' => 'ڪارو وچولو-ننڍو چورس',
    '◽' => 'سفيد وچولو-ننڍو چورس',
    '▪' => 'ڪارو ننڍو چورس',
    '▫' => 'اڇو ننڍو چورس',
    '🔶' => 'وڏو نارنگي هيرو',
    '🔷' => 'وڏو نيرو هيرو',
    '🔸' => 'ننڍو نارنگي هيرو',
    '🔹' => 'ننڍو نيرو هيرو',
    '🔺' => 'ڳاڙهو ٽڪنڊو مٿي اشارو ڪيل',
    '🔻' => 'ڳاڙهو ٽڪنڊو هيٺ اشارو ڪيل',
    '💠' => 'هڪ نقطي سان گڏ هيرو',
    '🔘' => 'ريڊيو بٽڻ',
    '🔳' => 'اڇو چورس بٽڻ',
    '🔲' => 'چورس ڪارو بٽڻ',
    '🏁' => 'چيڪر جهنڊو',
    '🚩' => 'ٽڪنڊو جھنڊو',
    '🎌' => 'ڪرسڊ جهنڊا',
    '🏴' => 'ڪارو جهنڊو',
    '🏳' => 'اڇو جهنڊو',
];
