<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'چومنا: بالغ, بالغ, ہلکی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'چومنا: بالغ, بالغ, ہلکی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'چومنا: بالغ, بالغ, ہلکی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'چومنا: بالغ, بالغ, ہلکی رنگت آلی جلد, کالی رنگت آلی جلد',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'چومنا: بالغ, بالغ, ہلکی درمیانی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'چومنا: بالغ, بالغ, ہلکی درمیانی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'چومنا: بالغ, بالغ, ہلکی درمیانی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'چومنا: بالغ, بالغ, ہلکی درمیانی رنگت آلی جلد, کالی رنگت آلی جلد',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'چومنا: بالغ, بالغ, درمیانی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'چومنا: بالغ, بالغ, درمیانی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'چومنا: بالغ, بالغ, درمیانی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'چومنا: بالغ, بالغ, درمیانی رنگت آلی جلد, کالی رنگت آلی جلد',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'چومنا: بالغ, بالغ, درمیانی کالی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'چومنا: بالغ, بالغ, درمیانی کالی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'چومنا: بالغ, بالغ, درمیانی کالی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'چومنا: بالغ, بالغ, درمیانی کالی رنگت آلی جلد, کالی رنگت آلی جلد',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'چومنا: بالغ, بالغ, کالی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'چومنا: بالغ, بالغ, کالی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'چومنا: بالغ, بالغ, کالی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'چومنا: بالغ, بالغ, کالی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👨🏻‍❤‍💋‍👨🏻' => 'چومنا: بندہ, بندہ, ہلکی رنگت آلی جلد',
    '👨🏻‍❤‍💋‍👨🏼' => 'چومنا: بندہ, بندہ, ہلکی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👨🏻‍❤‍💋‍👨🏽' => 'چومنا: بندہ, بندہ, ہلکی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👨🏻‍❤‍💋‍👨🏾' => 'چومنا: بندہ, بندہ, ہلکی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👨🏻‍❤‍💋‍👨🏿' => 'چومنا: بندہ, بندہ, ہلکی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👨🏼‍❤‍💋‍👨🏻' => 'چومنا: بندہ, بندہ, ہلکی درمیانی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👨🏼‍❤‍💋‍👨🏼' => 'چومنا: بندہ, بندہ, ہلکی درمیانی رنگت آلی جلد',
    '👨🏼‍❤‍💋‍👨🏽' => 'چومنا: بندہ, بندہ, ہلکی درمیانی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👨🏼‍❤‍💋‍👨🏾' => 'چومنا: بندہ, بندہ, ہلکی درمیانی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👨🏼‍❤‍💋‍👨🏿' => 'چومنا: بندہ, بندہ, ہلکی درمیانی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👨🏽‍❤‍💋‍👨🏻' => 'چومنا: بندہ, بندہ, درمیانی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👨🏽‍❤‍💋‍👨🏼' => 'چومنا: بندہ, بندہ, درمیانی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👨🏽‍❤‍💋‍👨🏽' => 'چومنا: بندہ, بندہ, درمیانی رنگت آلی جلد',
    '👨🏽‍❤‍💋‍👨🏾' => 'چومنا: بندہ, بندہ, درمیانی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👨🏽‍❤‍💋‍👨🏿' => 'چومنا: بندہ, بندہ, درمیانی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👨🏾‍❤‍💋‍👨🏻' => 'چومنا: بندہ, بندہ, درمیانی کالی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👨🏾‍❤‍💋‍👨🏼' => 'چومنا: بندہ, بندہ, درمیانی کالی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👨🏾‍❤‍💋‍👨🏽' => 'چومنا: بندہ, بندہ, درمیانی کالی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👨🏾‍❤‍💋‍👨🏾' => 'چومنا: بندہ, بندہ, درمیانی کالی رنگت آلی جلد',
    '👨🏾‍❤‍💋‍👨🏿' => 'چومنا: بندہ, بندہ, درمیانی کالی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👨🏿‍❤‍💋‍👨🏻' => 'چومنا: بندہ, بندہ, کالی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👨🏿‍❤‍💋‍👨🏼' => 'چومنا: بندہ, بندہ, کالی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👨🏿‍❤‍💋‍👨🏽' => 'چومنا: بندہ, بندہ, کالی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👨🏿‍❤‍💋‍👨🏾' => 'چومنا: بندہ, بندہ, کالی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👨🏿‍❤‍💋‍👨🏿' => 'چومنا: بندہ, بندہ, کالی رنگت آلی جلد',
    '👩🏻‍❤‍💋‍👨🏻' => 'چومنا: زنانی, بندہ, ہلکی رنگت آلی جلد',
    '👩🏻‍❤‍💋‍👨🏼' => 'چومنا: زنانی, بندہ, ہلکی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👩🏻‍❤‍💋‍👨🏽' => 'چومنا: زنانی, بندہ, ہلکی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👩🏻‍❤‍💋‍👨🏾' => 'چومنا: زنانی, بندہ, ہلکی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👩🏻‍❤‍💋‍👨🏿' => 'چومنا: زنانی, بندہ, ہلکی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👩🏼‍❤‍💋‍👨🏻' => 'چومنا: زنانی, بندہ, ہلکی درمیانی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👩🏼‍❤‍💋‍👨🏼' => 'چومنا: زنانی, بندہ, ہلکی درمیانی رنگت آلی جلد',
    '👩🏼‍❤‍💋‍👨🏽' => 'چومنا: زنانی, بندہ, ہلکی درمیانی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👩🏼‍❤‍💋‍👨🏾' => 'چومنا: زنانی, بندہ, ہلکی درمیانی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👩🏼‍❤‍💋‍👨🏿' => 'چومنا: زنانی, بندہ, ہلکی درمیانی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👩🏽‍❤‍💋‍👨🏻' => 'چومنا: زنانی, بندہ, درمیانی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👩🏽‍❤‍💋‍👨🏼' => 'چومنا: زنانی, بندہ, درمیانی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👩🏽‍❤‍💋‍👨🏽' => 'چومنا: زنانی, بندہ, درمیانی رنگت آلی جلد',
    '👩🏽‍❤‍💋‍👨🏾' => 'چومنا: زنانی, بندہ, درمیانی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👩🏽‍❤‍💋‍👨🏿' => 'چومنا: زنانی, بندہ, درمیانی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👩🏾‍❤‍💋‍👨🏻' => 'چومنا: زنانی, بندہ, درمیانی کالی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👩🏾‍❤‍💋‍👨🏼' => 'چومنا: زنانی, بندہ, درمیانی کالی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👩🏾‍❤‍💋‍👨🏽' => 'چومنا: زنانی, بندہ, درمیانی کالی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👩🏾‍❤‍💋‍👨🏾' => 'چومنا: زنانی, بندہ, درمیانی کالی رنگت آلی جلد',
    '👩🏾‍❤‍💋‍👨🏿' => 'چومنا: زنانی, بندہ, درمیانی کالی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👩🏿‍❤‍💋‍👨🏻' => 'چومنا: زنانی, بندہ, کالی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👩🏿‍❤‍💋‍👨🏼' => 'چومنا: زنانی, بندہ, کالی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👩🏿‍❤‍💋‍👨🏽' => 'چومنا: زنانی, بندہ, کالی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👩🏿‍❤‍💋‍👨🏾' => 'چومنا: زنانی, بندہ, کالی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👩🏿‍❤‍💋‍👨🏿' => 'چومنا: زنانی, بندہ, کالی رنگت آلی جلد',
    '👩🏻‍❤‍💋‍👩🏻' => 'چومنا: زنانی, زنانی, ہلکی رنگت آلی جلد',
    '👩🏻‍❤‍💋‍👩🏼' => 'چومنا: زنانی, زنانی, ہلکی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👩🏻‍❤‍💋‍👩🏽' => 'چومنا: زنانی, زنانی, ہلکی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👩🏻‍❤‍💋‍👩🏾' => 'چومنا: زنانی, زنانی, ہلکی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👩🏻‍❤‍💋‍👩🏿' => 'چومنا: زنانی, زنانی, ہلکی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👩🏼‍❤‍💋‍👩🏻' => 'چومنا: زنانی, زنانی, ہلکی درمیانی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👩🏼‍❤‍💋‍👩🏼' => 'چومنا: زنانی, زنانی, ہلکی درمیانی رنگت آلی جلد',
    '👩🏼‍❤‍💋‍👩🏽' => 'چومنا: زنانی, زنانی, ہلکی درمیانی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👩🏼‍❤‍💋‍👩🏾' => 'چومنا: زنانی, زنانی, ہلکی درمیانی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👩🏼‍❤‍💋‍👩🏿' => 'چومنا: زنانی, زنانی, ہلکی درمیانی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👩🏽‍❤‍💋‍👩🏻' => 'چومنا: زنانی, زنانی, درمیانی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👩🏽‍❤‍💋‍👩🏼' => 'چومنا: زنانی, زنانی, درمیانی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👩🏽‍❤‍💋‍👩🏽' => 'چومنا: زنانی, زنانی, درمیانی رنگت آلی جلد',
    '👩🏽‍❤‍💋‍👩🏾' => 'چومنا: زنانی, زنانی, درمیانی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👩🏽‍❤‍💋‍👩🏿' => 'چومنا: زنانی, زنانی, درمیانی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👩🏾‍❤‍💋‍👩🏻' => 'چومنا: زنانی, زنانی, درمیانی کالی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👩🏾‍❤‍💋‍👩🏼' => 'چومنا: زنانی, زنانی, درمیانی کالی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👩🏾‍❤‍💋‍👩🏽' => 'چومنا: زنانی, زنانی, درمیانی کالی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👩🏾‍❤‍💋‍👩🏾' => 'چومنا: زنانی, زنانی, درمیانی کالی رنگت آلی جلد',
    '👩🏾‍❤‍💋‍👩🏿' => 'چومنا: زنانی, زنانی, درمیانی کالی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👩🏿‍❤‍💋‍👩🏻' => 'چومنا: زنانی, زنانی, کالی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👩🏿‍❤‍💋‍👩🏼' => 'چومنا: زنانی, زنانی, کالی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👩🏿‍❤‍💋‍👩🏽' => 'چومنا: زنانی, زنانی, کالی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👩🏿‍❤‍💋‍👩🏾' => 'چومنا: زنانی, زنانی, کالی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👩🏿‍❤‍💋‍👩🏿' => 'چومنا: زنانی, زنانی, کالی رنگت آلی جلد',
    '🧑🏻‍🫯‍🧑🏼' => 'کُشتی کردا بندہ: ہلکی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '🧑🏻‍🫯‍🧑🏽' => 'کُشتی کردا بندہ: ہلکی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '🧑🏻‍🫯‍🧑🏾' => 'کُشتی کردا بندہ: ہلکی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '🧑🏻‍🫯‍🧑🏿' => 'کُشتی کردا بندہ: ہلکی رنگت آلی جلد, کالی رنگت آلی جلد',
    '🧑🏼‍🫯‍🧑🏻' => 'کُشتی کردا بندہ: ہلکی درمیانی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '🧑🏼‍🫯‍🧑🏽' => 'کُشتی کردا بندہ: ہلکی درمیانی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '🧑🏼‍🫯‍🧑🏾' => 'کُشتی کردا بندہ: ہلکی درمیانی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '🧑🏼‍🫯‍🧑🏿' => 'کُشتی کردا بندہ: ہلکی درمیانی رنگت آلی جلد, کالی رنگت آلی جلد',
    '🧑🏽‍🫯‍🧑🏻' => 'کُشتی کردا بندہ: درمیانی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '🧑🏽‍🫯‍🧑🏼' => 'کُشتی کردا بندہ: درمیانی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '🧑🏽‍🫯‍🧑🏾' => 'کُشتی کردا بندہ: درمیانی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '🧑🏽‍🫯‍🧑🏿' => 'کُشتی کردا بندہ: درمیانی رنگت آلی جلد, کالی رنگت آلی جلد',
    '🧑🏾‍🫯‍🧑🏻' => 'کُشتی کردا بندہ: درمیانی کالی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '🧑🏾‍🫯‍🧑🏼' => 'کُشتی کردا بندہ: درمیانی کالی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '🧑🏾‍🫯‍🧑🏽' => 'کُشتی کردا بندہ: درمیانی کالی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '🧑🏾‍🫯‍🧑🏿' => 'کُشتی کردا بندہ: درمیانی کالی رنگت آلی جلد, کالی رنگت آلی جلد',
    '🧑🏿‍🫯‍🧑🏻' => 'کُشتی کردا بندہ: کالی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '🧑🏿‍🫯‍🧑🏼' => 'کُشتی کردا بندہ: کالی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '🧑🏿‍🫯‍🧑🏽' => 'کُشتی کردا بندہ: کالی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '🧑🏿‍🫯‍🧑🏾' => 'کُشتی کردا بندہ: کالی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '🧑🏻‍❤‍🧑🏼' => 'دل نال جوڑا: بالغ, بالغ, ہلکی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '🧑🏻‍❤‍🧑🏽' => 'دل نال جوڑا: بالغ, بالغ, ہلکی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '🧑🏻‍❤‍🧑🏾' => 'دل نال جوڑا: بالغ, بالغ, ہلکی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '🧑🏻‍❤‍🧑🏿' => 'دل نال جوڑا: بالغ, بالغ, ہلکی رنگت آلی جلد, کالی رنگت آلی جلد',
    '🧑🏼‍❤‍🧑🏻' => 'دل نال جوڑا: بالغ, بالغ, ہلکی درمیانی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '🧑🏼‍❤‍🧑🏽' => 'دل نال جوڑا: بالغ, بالغ, ہلکی درمیانی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '🧑🏼‍❤‍🧑🏾' => 'دل نال جوڑا: بالغ, بالغ, ہلکی درمیانی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '🧑🏼‍❤‍🧑🏿' => 'دل نال جوڑا: بالغ, بالغ, ہلکی درمیانی رنگت آلی جلد, کالی رنگت آلی جلد',
    '🧑🏽‍❤‍🧑🏻' => 'دل نال جوڑا: بالغ, بالغ, درمیانی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '🧑🏽‍❤‍🧑🏼' => 'دل نال جوڑا: بالغ, بالغ, درمیانی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '🧑🏽‍❤‍🧑🏾' => 'دل نال جوڑا: بالغ, بالغ, درمیانی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '🧑🏽‍❤‍🧑🏿' => 'دل نال جوڑا: بالغ, بالغ, درمیانی رنگت آلی جلد, کالی رنگت آلی جلد',
    '🧑🏾‍❤‍🧑🏻' => 'دل نال جوڑا: بالغ, بالغ, درمیانی کالی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '🧑🏾‍❤‍🧑🏼' => 'دل نال جوڑا: بالغ, بالغ, درمیانی کالی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '🧑🏾‍❤‍🧑🏽' => 'دل نال جوڑا: بالغ, بالغ, درمیانی کالی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '🧑🏾‍❤‍🧑🏿' => 'دل نال جوڑا: بالغ, بالغ, درمیانی کالی رنگت آلی جلد, کالی رنگت آلی جلد',
    '🧑🏿‍❤‍🧑🏻' => 'دل نال جوڑا: بالغ, بالغ, کالی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '🧑🏿‍❤‍🧑🏼' => 'دل نال جوڑا: بالغ, بالغ, کالی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '🧑🏿‍❤‍🧑🏽' => 'دل نال جوڑا: بالغ, بالغ, کالی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '🧑🏿‍❤‍🧑🏾' => 'دل نال جوڑا: بالغ, بالغ, کالی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '🧑🏻‍🐰‍🧑🏼' => 'بنی دے کناں نال پارٹی کردے لوکیں: ہلکی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '🧑🏻‍🐰‍🧑🏽' => 'بنی دے کناں نال پارٹی کردے لوکیں: ہلکی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '🧑🏻‍🐰‍🧑🏾' => 'بنی دے کناں نال پارٹی کردے لوکیں: ہلکی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '🧑🏻‍🐰‍🧑🏿' => 'بنی دے کناں نال پارٹی کردے لوکیں: ہلکی رنگت آلی جلد, کالی رنگت آلی جلد',
    '🧑🏼‍🐰‍🧑🏻' => 'بنی دے کناں نال پارٹی کردے لوکیں: ہلکی درمیانی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '🧑🏼‍🐰‍🧑🏽' => 'بنی دے کناں نال پارٹی کردے لوکیں: ہلکی درمیانی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '🧑🏼‍🐰‍🧑🏾' => 'بنی دے کناں نال پارٹی کردے لوکیں: ہلکی درمیانی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '🧑🏼‍🐰‍🧑🏿' => 'بنی دے کناں نال پارٹی کردے لوکیں: ہلکی درمیانی رنگت آلی جلد, کالی رنگت آلی جلد',
    '🧑🏽‍🐰‍🧑🏻' => 'بنی دے کناں نال پارٹی کردے لوکیں: درمیانی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '🧑🏽‍🐰‍🧑🏼' => 'بنی دے کناں نال پارٹی کردے لوکیں: درمیانی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '🧑🏽‍🐰‍🧑🏾' => 'بنی دے کناں نال پارٹی کردے لوکیں: درمیانی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '🧑🏽‍🐰‍🧑🏿' => 'بنی دے کناں نال پارٹی کردے لوکیں: درمیانی رنگت آلی جلد, کالی رنگت آلی جلد',
    '🧑🏾‍🐰‍🧑🏻' => 'بنی دے کناں نال پارٹی کردے لوکیں: درمیانی کالی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '🧑🏾‍🐰‍🧑🏼' => 'بنی دے کناں نال پارٹی کردے لوکیں: درمیانی کالی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '🧑🏾‍🐰‍🧑🏽' => 'بنی دے کناں نال پارٹی کردے لوکیں: درمیانی کالی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '🧑🏾‍🐰‍🧑🏿' => 'بنی دے کناں نال پارٹی کردے لوکیں: درمیانی کالی رنگت آلی جلد, کالی رنگت آلی جلد',
    '🧑🏿‍🐰‍🧑🏻' => 'بنی دے کناں نال پارٹی کردے لوکیں: کالی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '🧑🏿‍🐰‍🧑🏼' => 'بنی دے کناں نال پارٹی کردے لوکیں: کالی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '🧑🏿‍🐰‍🧑🏽' => 'بنی دے کناں نال پارٹی کردے لوکیں: کالی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '🧑🏿‍🐰‍🧑🏾' => 'بنی دے کناں نال پارٹی کردے لوکیں: کالی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👨🏻‍🫯‍👨🏼' => 'کُشتی لڑدے بندے: ہلکی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👨🏻‍🫯‍👨🏽' => 'کُشتی لڑدے بندے: ہلکی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👨🏻‍🫯‍👨🏾' => 'کُشتی لڑدے بندے: ہلکی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👨🏻‍🫯‍👨🏿' => 'کُشتی لڑدے بندے: ہلکی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👨🏼‍🫯‍👨🏻' => 'کُشتی لڑدے بندے: ہلکی درمیانی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👨🏼‍🫯‍👨🏽' => 'کُشتی لڑدے بندے: ہلکی درمیانی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👨🏼‍🫯‍👨🏾' => 'کُشتی لڑدے بندے: ہلکی درمیانی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👨🏼‍🫯‍👨🏿' => 'کُشتی لڑدے بندے: ہلکی درمیانی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👨🏽‍🫯‍👨🏻' => 'کُشتی لڑدے بندے: درمیانی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👨🏽‍🫯‍👨🏼' => 'کُشتی لڑدے بندے: درمیانی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👨🏽‍🫯‍👨🏾' => 'کُشتی لڑدے بندے: درمیانی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👨🏽‍🫯‍👨🏿' => 'کُشتی لڑدے بندے: درمیانی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👨🏾‍🫯‍👨🏻' => 'کُشتی لڑدے بندے: درمیانی کالی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👨🏾‍🫯‍👨🏼' => 'کُشتی لڑدے بندے: درمیانی کالی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👨🏾‍🫯‍👨🏽' => 'کُشتی لڑدے بندے: درمیانی کالی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👨🏾‍🫯‍👨🏿' => 'کُشتی لڑدے بندے: درمیانی کالی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👨🏿‍🫯‍👨🏻' => 'کُشتی لڑدے بندے: کالی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👨🏿‍🫯‍👨🏼' => 'کُشتی لڑدے بندے: کالی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👨🏿‍🫯‍👨🏽' => 'کُشتی لڑدے بندے: کالی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👨🏿‍🫯‍👨🏾' => 'کُشتی لڑدے بندے: کالی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👨🏻‍❤‍👨🏻' => 'دل نال جوڑا: بندہ, بندہ, ہلکی رنگت آلی جلد',
    '👨🏻‍❤‍👨🏼' => 'دل نال جوڑا: بندہ, بندہ, ہلکی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👨🏻‍❤‍👨🏽' => 'دل نال جوڑا: بندہ, بندہ, ہلکی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👨🏻‍❤‍👨🏾' => 'دل نال جوڑا: بندہ, بندہ, ہلکی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👨🏻‍❤‍👨🏿' => 'دل نال جوڑا: بندہ, بندہ, ہلکی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👨🏼‍❤‍👨🏻' => 'دل نال جوڑا: بندہ, بندہ, ہلکی درمیانی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👨🏼‍❤‍👨🏼' => 'دل نال جوڑا: بندہ, بندہ, ہلکی درمیانی رنگت آلی جلد',
    '👨🏼‍❤‍👨🏽' => 'دل نال جوڑا: بندہ, بندہ, ہلکی درمیانی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👨🏼‍❤‍👨🏾' => 'دل نال جوڑا: بندہ, بندہ, ہلکی درمیانی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👨🏼‍❤‍👨🏿' => 'دل نال جوڑا: بندہ, بندہ, ہلکی درمیانی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👨🏽‍❤‍👨🏻' => 'دل نال جوڑا: بندہ, بندہ, درمیانی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👨🏽‍❤‍👨🏼' => 'دل نال جوڑا: بندہ, بندہ, درمیانی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👨🏽‍❤‍👨🏽' => 'دل نال جوڑا: بندہ, بندہ, درمیانی رنگت آلی جلد',
    '👨🏽‍❤‍👨🏾' => 'دل نال جوڑا: بندہ, بندہ, درمیانی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👨🏽‍❤‍👨🏿' => 'دل نال جوڑا: بندہ, بندہ, درمیانی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👨🏾‍❤‍👨🏻' => 'دل نال جوڑا: بندہ, بندہ, درمیانی کالی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👨🏾‍❤‍👨🏼' => 'دل نال جوڑا: بندہ, بندہ, درمیانی کالی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👨🏾‍❤‍👨🏽' => 'دل نال جوڑا: بندہ, بندہ, درمیانی کالی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👨🏾‍❤‍👨🏾' => 'دل نال جوڑا: بندہ, بندہ, درمیانی کالی رنگت آلی جلد',
    '👨🏾‍❤‍👨🏿' => 'دل نال جوڑا: بندہ, بندہ, درمیانی کالی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👨🏿‍❤‍👨🏻' => 'دل نال جوڑا: بندہ, بندہ, کالی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👨🏿‍❤‍👨🏼' => 'دل نال جوڑا: بندہ, بندہ, کالی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👨🏿‍❤‍👨🏽' => 'دل نال جوڑا: بندہ, بندہ, کالی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👨🏿‍❤‍👨🏾' => 'دل نال جوڑا: بندہ, بندہ, کالی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👨🏿‍❤‍👨🏿' => 'دل نال جوڑا: بندہ, بندہ, کالی رنگت آلی جلد',
    '👨🏻‍🐰‍👨🏼' => 'خرگوش دے کناں آلا پارٹی کردا بندا: ہلکی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👨🏻‍🐰‍👨🏽' => 'خرگوش دے کناں آلا پارٹی کردا بندا: ہلکی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👨🏻‍🐰‍👨🏾' => 'خرگوش دے کناں آلا پارٹی کردا بندا: ہلکی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👨🏻‍🐰‍👨🏿' => 'خرگوش دے کناں آلا پارٹی کردا بندا: ہلکی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👨🏼‍🐰‍👨🏻' => 'خرگوش دے کناں آلا پارٹی کردا بندا: ہلکی درمیانی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👨🏼‍🐰‍👨🏽' => 'خرگوش دے کناں آلا پارٹی کردا بندا: ہلکی درمیانی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👨🏼‍🐰‍👨🏾' => 'خرگوش دے کناں آلا پارٹی کردا بندا: ہلکی درمیانی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👨🏼‍🐰‍👨🏿' => 'خرگوش دے کناں آلا پارٹی کردا بندا: ہلکی درمیانی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👨🏽‍🐰‍👨🏻' => 'خرگوش دے کناں آلا پارٹی کردا بندا: درمیانی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👨🏽‍🐰‍👨🏼' => 'خرگوش دے کناں آلا پارٹی کردا بندا: درمیانی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👨🏽‍🐰‍👨🏾' => 'خرگوش دے کناں آلا پارٹی کردا بندا: درمیانی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👨🏽‍🐰‍👨🏿' => 'خرگوش دے کناں آلا پارٹی کردا بندا: درمیانی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👨🏾‍🐰‍👨🏻' => 'خرگوش دے کناں آلا پارٹی کردا بندا: درمیانی کالی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👨🏾‍🐰‍👨🏼' => 'خرگوش دے کناں آلا پارٹی کردا بندا: درمیانی کالی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👨🏾‍🐰‍👨🏽' => 'خرگوش دے کناں آلا پارٹی کردا بندا: درمیانی کالی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👨🏾‍🐰‍👨🏿' => 'خرگوش دے کناں آلا پارٹی کردا بندا: درمیانی کالی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👨🏿‍🐰‍👨🏻' => 'خرگوش دے کناں آلا پارٹی کردا بندا: کالی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👨🏿‍🐰‍👨🏼' => 'خرگوش دے کناں آلا پارٹی کردا بندا: کالی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👨🏿‍🐰‍👨🏽' => 'خرگوش دے کناں آلا پارٹی کردا بندا: کالی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👨🏿‍🐰‍👨🏾' => 'خرگوش دے کناں آلا پارٹی کردا بندا: کالی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👩🏻‍🫯‍👩🏼' => 'کُشتی لڑدیاں زنانیاں: ہلکی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👩🏻‍🫯‍👩🏽' => 'کُشتی لڑدیاں زنانیاں: ہلکی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👩🏻‍🫯‍👩🏾' => 'کُشتی لڑدیاں زنانیاں: ہلکی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👩🏻‍🫯‍👩🏿' => 'کُشتی لڑدیاں زنانیاں: ہلکی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👩🏼‍🫯‍👩🏻' => 'کُشتی لڑدیاں زنانیاں: ہلکی درمیانی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👩🏼‍🫯‍👩🏽' => 'کُشتی لڑدیاں زنانیاں: ہلکی درمیانی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👩🏼‍🫯‍👩🏾' => 'کُشتی لڑدیاں زنانیاں: ہلکی درمیانی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👩🏼‍🫯‍👩🏿' => 'کُشتی لڑدیاں زنانیاں: ہلکی درمیانی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👩🏽‍🫯‍👩🏻' => 'کُشتی لڑدیاں زنانیاں: درمیانی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👩🏽‍🫯‍👩🏼' => 'کُشتی لڑدیاں زنانیاں: درمیانی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👩🏽‍🫯‍👩🏾' => 'کُشتی لڑدیاں زنانیاں: درمیانی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👩🏽‍🫯‍👩🏿' => 'کُشتی لڑدیاں زنانیاں: درمیانی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👩🏾‍🫯‍👩🏻' => 'کُشتی لڑدیاں زنانیاں: درمیانی کالی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👩🏾‍🫯‍👩🏼' => 'کُشتی لڑدیاں زنانیاں: درمیانی کالی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👩🏾‍🫯‍👩🏽' => 'کُشتی لڑدیاں زنانیاں: درمیانی کالی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👩🏾‍🫯‍👩🏿' => 'کُشتی لڑدیاں زنانیاں: درمیانی کالی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👩🏿‍🫯‍👩🏻' => 'کُشتی لڑدیاں زنانیاں: کالی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👩🏿‍🫯‍👩🏼' => 'کُشتی لڑدیاں زنانیاں: کالی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👩🏿‍🫯‍👩🏽' => 'کُشتی لڑدیاں زنانیاں: کالی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👩🏿‍🫯‍👩🏾' => 'کُشتی لڑدیاں زنانیاں: کالی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👩🏻‍❤‍👨🏻' => 'دل نال جوڑا: زنانی, بندہ, ہلکی رنگت آلی جلد',
    '👩🏻‍❤‍👨🏼' => 'دل نال جوڑا: زنانی, بندہ, ہلکی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👩🏻‍❤‍👨🏽' => 'دل نال جوڑا: زنانی, بندہ, ہلکی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👩🏻‍❤‍👨🏾' => 'دل نال جوڑا: زنانی, بندہ, ہلکی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👩🏻‍❤‍👨🏿' => 'دل نال جوڑا: زنانی, بندہ, ہلکی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👩🏼‍❤‍👨🏻' => 'دل نال جوڑا: زنانی, بندہ, ہلکی درمیانی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👩🏼‍❤‍👨🏼' => 'دل نال جوڑا: زنانی, بندہ, ہلکی درمیانی رنگت آلی جلد',
    '👩🏼‍❤‍👨🏽' => 'دل نال جوڑا: زنانی, بندہ, ہلکی درمیانی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👩🏼‍❤‍👨🏾' => 'دل نال جوڑا: زنانی, بندہ, ہلکی درمیانی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👩🏼‍❤‍👨🏿' => 'دل نال جوڑا: زنانی, بندہ, ہلکی درمیانی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👩🏽‍❤‍👨🏻' => 'دل نال جوڑا: زنانی, بندہ, درمیانی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👩🏽‍❤‍👨🏼' => 'دل نال جوڑا: زنانی, بندہ, درمیانی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👩🏽‍❤‍👨🏽' => 'دل نال جوڑا: زنانی, بندہ, درمیانی رنگت آلی جلد',
    '👩🏽‍❤‍👨🏾' => 'دل نال جوڑا: زنانی, بندہ, درمیانی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👩🏽‍❤‍👨🏿' => 'دل نال جوڑا: زنانی, بندہ, درمیانی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👩🏾‍❤‍👨🏻' => 'دل نال جوڑا: زنانی, بندہ, درمیانی کالی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👩🏾‍❤‍👨🏼' => 'دل نال جوڑا: زنانی, بندہ, درمیانی کالی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👩🏾‍❤‍👨🏽' => 'دل نال جوڑا: زنانی, بندہ, درمیانی کالی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👩🏾‍❤‍👨🏾' => 'دل نال جوڑا: زنانی, بندہ, درمیانی کالی رنگت آلی جلد',
    '👩🏾‍❤‍👨🏿' => 'دل نال جوڑا: زنانی, بندہ, درمیانی کالی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👩🏿‍❤‍👨🏻' => 'دل نال جوڑا: زنانی, بندہ, کالی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👩🏿‍❤‍👨🏼' => 'دل نال جوڑا: زنانی, بندہ, کالی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👩🏿‍❤‍👨🏽' => 'دل نال جوڑا: زنانی, بندہ, کالی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👩🏿‍❤‍👨🏾' => 'دل نال جوڑا: زنانی, بندہ, کالی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👩🏿‍❤‍👨🏿' => 'دل نال جوڑا: زنانی, بندہ, کالی رنگت آلی جلد',
    '👩🏻‍❤‍👩🏻' => 'دل نال جوڑا: زنانی, زنانی, ہلکی رنگت آلی جلد',
    '👩🏻‍❤‍👩🏼' => 'دل نال جوڑا: زنانی, زنانی, ہلکی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👩🏻‍❤‍👩🏽' => 'دل نال جوڑا: زنانی, زنانی, ہلکی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👩🏻‍❤‍👩🏾' => 'دل نال جوڑا: زنانی, زنانی, ہلکی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👩🏻‍❤‍👩🏿' => 'دل نال جوڑا: زنانی, زنانی, ہلکی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👩🏼‍❤‍👩🏻' => 'دل نال جوڑا: زنانی, زنانی, ہلکی درمیانی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👩🏼‍❤‍👩🏼' => 'دل نال جوڑا: زنانی, زنانی, ہلکی درمیانی رنگت آلی جلد',
    '👩🏼‍❤‍👩🏽' => 'دل نال جوڑا: زنانی, زنانی, ہلکی درمیانی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👩🏼‍❤‍👩🏾' => 'دل نال جوڑا: زنانی, زنانی, ہلکی درمیانی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👩🏼‍❤‍👩🏿' => 'دل نال جوڑا: زنانی, زنانی, ہلکی درمیانی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👩🏽‍❤‍👩🏻' => 'دل نال جوڑا: زنانی, زنانی, درمیانی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👩🏽‍❤‍👩🏼' => 'دل نال جوڑا: زنانی, زنانی, درمیانی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👩🏽‍❤‍👩🏽' => 'دل نال جوڑا: زنانی, زنانی, درمیانی رنگت آلی جلد',
    '👩🏽‍❤‍👩🏾' => 'دل نال جوڑا: زنانی, زنانی, درمیانی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👩🏽‍❤‍👩🏿' => 'دل نال جوڑا: زنانی, زنانی, درمیانی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👩🏾‍❤‍👩🏻' => 'دل نال جوڑا: زنانی, زنانی, درمیانی کالی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👩🏾‍❤‍👩🏼' => 'دل نال جوڑا: زنانی, زنانی, درمیانی کالی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👩🏾‍❤‍👩🏽' => 'دل نال جوڑا: زنانی, زنانی, درمیانی کالی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👩🏾‍❤‍👩🏾' => 'دل نال جوڑا: زنانی, زنانی, درمیانی کالی رنگت آلی جلد',
    '👩🏾‍❤‍👩🏿' => 'دل نال جوڑا: زنانی, زنانی, درمیانی کالی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👩🏿‍❤‍👩🏻' => 'دل نال جوڑا: زنانی, زنانی, کالی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👩🏿‍❤‍👩🏼' => 'دل نال جوڑا: زنانی, زنانی, کالی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👩🏿‍❤‍👩🏽' => 'دل نال جوڑا: زنانی, زنانی, کالی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👩🏿‍❤‍👩🏾' => 'دل نال جوڑا: زنانی, زنانی, کالی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👩🏿‍❤‍👩🏿' => 'دل نال جوڑا: زنانی, زنانی, کالی رنگت آلی جلد',
    '👩🏻‍🐰‍👩🏼' => 'خرگوش دے کناں آلی پارٹی کردی زنانی: ہلکی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👩🏻‍🐰‍👩🏽' => 'خرگوش دے کناں آلی پارٹی کردی زنانی: ہلکی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👩🏻‍🐰‍👩🏾' => 'خرگوش دے کناں آلی پارٹی کردی زنانی: ہلکی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👩🏻‍🐰‍👩🏿' => 'خرگوش دے کناں آلی پارٹی کردی زنانی: ہلکی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👩🏼‍🐰‍👩🏻' => 'خرگوش دے کناں آلی پارٹی کردی زنانی: ہلکی درمیانی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👩🏼‍🐰‍👩🏽' => 'خرگوش دے کناں آلی پارٹی کردی زنانی: ہلکی درمیانی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👩🏼‍🐰‍👩🏾' => 'خرگوش دے کناں آلی پارٹی کردی زنانی: ہلکی درمیانی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👩🏼‍🐰‍👩🏿' => 'خرگوش دے کناں آلی پارٹی کردی زنانی: ہلکی درمیانی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👩🏽‍🐰‍👩🏻' => 'خرگوش دے کناں آلی پارٹی کردی زنانی: درمیانی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👩🏽‍🐰‍👩🏼' => 'خرگوش دے کناں آلی پارٹی کردی زنانی: درمیانی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👩🏽‍🐰‍👩🏾' => 'خرگوش دے کناں آلی پارٹی کردی زنانی: درمیانی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👩🏽‍🐰‍👩🏿' => 'خرگوش دے کناں آلی پارٹی کردی زنانی: درمیانی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👩🏾‍🐰‍👩🏻' => 'خرگوش دے کناں آلی پارٹی کردی زنانی: درمیانی کالی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👩🏾‍🐰‍👩🏼' => 'خرگوش دے کناں آلی پارٹی کردی زنانی: درمیانی کالی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👩🏾‍🐰‍👩🏽' => 'خرگوش دے کناں آلی پارٹی کردی زنانی: درمیانی کالی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👩🏾‍🐰‍👩🏿' => 'خرگوش دے کناں آلی پارٹی کردی زنانی: درمیانی کالی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👩🏿‍🐰‍👩🏻' => 'خرگوش دے کناں آلی پارٹی کردی زنانی: کالی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👩🏿‍🐰‍👩🏼' => 'خرگوش دے کناں آلی پارٹی کردی زنانی: کالی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👩🏿‍🐰‍👩🏽' => 'خرگوش دے کناں آلی پارٹی کردی زنانی: کالی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👩🏿‍🐰‍👩🏾' => 'خرگوش دے کناں آلی پارٹی کردی زنانی: کالی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '🧑🏻‍🤝‍🧑🏻' => 'ਹੱਥ ਫੜਦੇ ਹੋਏ ਲੋਕ: ਗੋਰਾ ਰੰਗ',
    '🧑🏻‍🤝‍🧑🏼' => 'ਹੱਥ ਫੜਦੇ ਹੋਏ ਲੋਕ: ਗੋਰਾ ਰੰਗ, ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏻‍🤝‍🧑🏽' => 'ਹੱਥ ਫੜਦੇ ਹੋਏ ਲੋਕ: ਗੋਰਾ ਰੰਗ, ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏻‍🤝‍🧑🏾' => 'ਹੱਥ ਫੜਦੇ ਹੋਏ ਲੋਕ: ਗੋਰਾ ਰੰਗ, ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🧑🏻‍🤝‍🧑🏿' => 'ਹੱਥ ਫੜਦੇ ਹੋਏ ਲੋਕ: ਗੋਰਾ ਰੰਗ, ਕਾਲਾ ਰੰਗ',
    '🧑🏼‍🤝‍🧑🏻' => 'ਹੱਥ ਫੜਦੇ ਹੋਏ ਲੋਕ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ, ਗੋਰਾ ਰੰਗ',
    '🧑🏼‍🤝‍🧑🏼' => 'ਹੱਥ ਫੜਦੇ ਹੋਏ ਲੋਕ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏼‍🤝‍🧑🏽' => 'ਹੱਥ ਫੜਦੇ ਹੋਏ ਲੋਕ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ, ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏼‍🤝‍🧑🏾' => 'ਹੱਥ ਫੜਦੇ ਹੋਏ ਲੋਕ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ, ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🧑🏼‍🤝‍🧑🏿' => 'ਹੱਥ ਫੜਦੇ ਹੋਏ ਲੋਕ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ, ਕਾਲਾ ਰੰਗ',
    '🧑🏽‍🤝‍🧑🏻' => 'ਹੱਥ ਫੜਦੇ ਹੋਏ ਲੋਕ: ਕਣਕਵੰਨਾ ਰੰਗ, ਗੋਰਾ ਰੰਗ',
    '🧑🏽‍🤝‍🧑🏼' => 'ਹੱਥ ਫੜਦੇ ਹੋਏ ਲੋਕ: ਕਣਕਵੰਨਾ ਰੰਗ, ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏽‍🤝‍🧑🏽' => 'ਹੱਥ ਫੜਦੇ ਹੋਏ ਲੋਕ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏽‍🤝‍🧑🏾' => 'ਹੱਥ ਫੜਦੇ ਹੋਏ ਲੋਕ: ਕਣਕਵੰਨਾ ਰੰਗ, ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🧑🏽‍🤝‍🧑🏿' => 'ਹੱਥ ਫੜਦੇ ਹੋਏ ਲੋਕ: ਕਣਕਵੰਨਾ ਰੰਗ, ਕਾਲਾ ਰੰਗ',
    '🧑🏾‍🤝‍🧑🏻' => 'ਹੱਥ ਫੜਦੇ ਹੋਏ ਲੋਕ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ, ਗੋਰਾ ਰੰਗ',
    '🧑🏾‍🤝‍🧑🏼' => 'ਹੱਥ ਫੜਦੇ ਹੋਏ ਲੋਕ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ, ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏾‍🤝‍🧑🏽' => 'ਹੱਥ ਫੜਦੇ ਹੋਏ ਲੋਕ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ, ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏾‍🤝‍🧑🏾' => 'ਹੱਥ ਫੜਦੇ ਹੋਏ ਲੋਕ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🧑🏾‍🤝‍🧑🏿' => 'ਹੱਥ ਫੜਦੇ ਹੋਏ ਲੋਕ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ, ਕਾਲਾ ਰੰਗ',
    '🧑🏿‍🤝‍🧑🏻' => 'ਹੱਥ ਫੜਦੇ ਹੋਏ ਲੋਕ: ਕਾਲਾ ਰੰਗ, ਗੋਰਾ ਰੰਗ',
    '🧑🏿‍🤝‍🧑🏼' => 'ਹੱਥ ਫੜਦੇ ਹੋਏ ਲੋਕ: ਕਾਲਾ ਰੰਗ, ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏿‍🤝‍🧑🏽' => 'ਹੱਥ ਫੜਦੇ ਹੋਏ ਲੋਕ: ਕਾਲਾ ਰੰਗ, ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏿‍🤝‍🧑🏾' => 'ਹੱਥ ਫੜਦੇ ਹੋਏ ਲੋਕ: ਕਾਲਾ ਰੰਗ, ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🧑🏿‍🤝‍🧑🏿' => 'ਹੱਥ ਫੜਦੇ ਹੋਏ ਲੋਕ: ਕਾਲਾ ਰੰਗ',
    '👩🏻‍🤝‍👩🏼' => 'ہتھ پھڑدیاں دو زنانیاں: ہلکی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👩🏻‍🤝‍👩🏽' => 'ہتھ پھڑدیاں دو زنانیاں: ہلکی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👩🏻‍🤝‍👩🏾' => 'ہتھ پھڑدیاں دو زنانیاں: ہلکی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👩🏻‍🤝‍👩🏿' => 'ہتھ پھڑدیاں دو زنانیاں: ہلکی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👩🏼‍🤝‍👩🏻' => 'ہتھ پھڑدیاں دو زنانیاں: ہلکی درمیانی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👩🏼‍🤝‍👩🏽' => 'ہتھ پھڑدیاں دو زنانیاں: ہلکی درمیانی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👩🏼‍🤝‍👩🏾' => 'ہتھ پھڑدیاں دو زنانیاں: ہلکی درمیانی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👩🏼‍🤝‍👩🏿' => 'ہتھ پھڑدیاں دو زنانیاں: ہلکی درمیانی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👩🏽‍🤝‍👩🏻' => 'ہتھ پھڑدیاں دو زنانیاں: درمیانی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👩🏽‍🤝‍👩🏼' => 'ہتھ پھڑدیاں دو زنانیاں: درمیانی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👩🏽‍🤝‍👩🏾' => 'ہتھ پھڑدیاں دو زنانیاں: درمیانی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👩🏽‍🤝‍👩🏿' => 'ہتھ پھڑدیاں دو زنانیاں: درمیانی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👩🏾‍🤝‍👩🏻' => 'ہتھ پھڑدیاں دو زنانیاں: درمیانی کالی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👩🏾‍🤝‍👩🏼' => 'ہتھ پھڑدیاں دو زنانیاں: درمیانی کالی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👩🏾‍🤝‍👩🏽' => 'ہتھ پھڑدیاں دو زنانیاں: درمیانی کالی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👩🏾‍🤝‍👩🏿' => 'ہتھ پھڑدیاں دو زنانیاں: درمیانی کالی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👩🏿‍🤝‍👩🏻' => 'ہتھ پھڑدیاں دو زنانیاں: کالی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👩🏿‍🤝‍👩🏼' => 'ہتھ پھڑدیاں دو زنانیاں: کالی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👩🏿‍🤝‍👩🏽' => 'ہتھ پھڑدیاں دو زنانیاں: کالی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👩🏿‍🤝‍👩🏾' => 'ہتھ پھڑدیاں دو زنانیاں: کالی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👩🏻‍🤝‍👨🏼' => 'ہتھ پھڑے ہوئے بندہ اتے زنانی: ہلکی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👩🏻‍🤝‍👨🏽' => 'ہتھ پھڑے ہوئے بندہ اتے زنانی: ہلکی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👩🏻‍🤝‍👨🏾' => 'ہتھ پھڑے ہوئے بندہ اتے زنانی: ہلکی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👩🏻‍🤝‍👨🏿' => 'ہتھ پھڑے ہوئے بندہ اتے زنانی: ہلکی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👩🏼‍🤝‍👨🏻' => 'ہتھ پھڑے ہوئے بندہ اتے زنانی: ہلکی درمیانی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👩🏼‍🤝‍👨🏽' => 'ہتھ پھڑے ہوئے بندہ اتے زنانی: ہلکی درمیانی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👩🏼‍🤝‍👨🏾' => 'ہتھ پھڑے ہوئے بندہ اتے زنانی: ہلکی درمیانی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👩🏼‍🤝‍👨🏿' => 'ہتھ پھڑے ہوئے بندہ اتے زنانی: ہلکی درمیانی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👩🏽‍🤝‍👨🏻' => 'ہتھ پھڑے ہوئے بندہ اتے زنانی: درمیانی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👩🏽‍🤝‍👨🏼' => 'ہتھ پھڑے ہوئے بندہ اتے زنانی: درمیانی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👩🏽‍🤝‍👨🏾' => 'ہتھ پھڑے ہوئے بندہ اتے زنانی: درمیانی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👩🏽‍🤝‍👨🏿' => 'ہتھ پھڑے ہوئے بندہ اتے زنانی: درمیانی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👩🏾‍🤝‍👨🏻' => 'ہتھ پھڑے ہوئے بندہ اتے زنانی: درمیانی کالی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👩🏾‍🤝‍👨🏼' => 'ہتھ پھڑے ہوئے بندہ اتے زنانی: درمیانی کالی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👩🏾‍🤝‍👨🏽' => 'ہتھ پھڑے ہوئے بندہ اتے زنانی: درمیانی کالی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👩🏾‍🤝‍👨🏿' => 'ہتھ پھڑے ہوئے بندہ اتے زنانی: درمیانی کالی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👩🏿‍🤝‍👨🏻' => 'ہتھ پھڑے ہوئے بندہ اتے زنانی: کالی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👩🏿‍🤝‍👨🏼' => 'ہتھ پھڑے ہوئے بندہ اتے زنانی: کالی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👩🏿‍🤝‍👨🏽' => 'ہتھ پھڑے ہوئے بندہ اتے زنانی: کالی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👩🏿‍🤝‍👨🏾' => 'ہتھ پھڑے ہوئے بندہ اتے زنانی: کالی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👨🏻‍🤝‍👨🏼' => 'ہتھ پھڑدے دو بندے: ہلکی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👨🏻‍🤝‍👨🏽' => 'ہتھ پھڑدے دو بندے: ہلکی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👨🏻‍🤝‍👨🏾' => 'ہتھ پھڑدے دو بندے: ہلکی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👨🏻‍🤝‍👨🏿' => 'ہتھ پھڑدے دو بندے: ہلکی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👨🏼‍🤝‍👨🏻' => 'ہتھ پھڑدے دو بندے: ہلکی درمیانی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👨🏼‍🤝‍👨🏽' => 'ہتھ پھڑدے دو بندے: ہلکی درمیانی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👨🏼‍🤝‍👨🏾' => 'ہتھ پھڑدے دو بندے: ہلکی درمیانی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👨🏼‍🤝‍👨🏿' => 'ہتھ پھڑدے دو بندے: ہلکی درمیانی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👨🏽‍🤝‍👨🏻' => 'ہتھ پھڑدے دو بندے: درمیانی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👨🏽‍🤝‍👨🏼' => 'ہتھ پھڑدے دو بندے: درمیانی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👨🏽‍🤝‍👨🏾' => 'ہتھ پھڑدے دو بندے: درمیانی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👨🏽‍🤝‍👨🏿' => 'ہتھ پھڑدے دو بندے: درمیانی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👨🏾‍🤝‍👨🏻' => 'ہتھ پھڑدے دو بندے: درمیانی کالی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👨🏾‍🤝‍👨🏼' => 'ہتھ پھڑدے دو بندے: درمیانی کالی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👨🏾‍🤝‍👨🏽' => 'ہتھ پھڑدے دو بندے: درمیانی کالی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👨🏾‍🤝‍👨🏿' => 'ہتھ پھڑدے دو بندے: درمیانی کالی رنگت آلی جلد, کالی رنگت آلی جلد',
    '👨🏿‍🤝‍👨🏻' => 'ہتھ پھڑدے دو بندے: کالی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '👨🏿‍🤝‍👨🏼' => 'ہتھ پھڑدے دو بندے: کالی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '👨🏿‍🤝‍👨🏽' => 'ہتھ پھڑدے دو بندے: کالی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '👨🏿‍🤝‍👨🏾' => 'ہتھ پھڑدے دو بندے: کالی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '👩‍❤‍💋‍👨' => 'چومنا: زنانی, بندہ',
    '👨‍❤‍💋‍👨' => 'چومنا: بندہ, بندہ',
    '👩‍❤‍💋‍👩' => 'چومنا: زنانی, زنانی',
    '👨‍👩‍👧‍👦' => 'ٹبّر: بندہ, زنانی, کڑی, منڈا',
    '👨‍👩‍👦‍👦' => 'ٹبّر: بندہ, زنانی, منڈا, منڈا',
    '👨‍👩‍👧‍👧' => 'ٹبّر: بندہ, زنانی, کڑی, کڑی',
    '👨‍👨‍👧‍👦' => 'ٹبّر: بندہ, بندہ, کڑی, منڈا',
    '👨‍👨‍👦‍👦' => 'ٹبّر: بندہ, بندہ, منڈا, منڈا',
    '👨‍👨‍👧‍👧' => 'ٹبّر: بندہ, بندہ, کڑی, کڑی',
    '👩‍👩‍👧‍👦' => 'ٹبّر: زنانی, زنانی, کڑی, منڈا',
    '👩‍👩‍👦‍👦' => 'ٹبّر: زنانی, زنانی, منڈا, منڈا',
    '👩‍👩‍👧‍👧' => 'ٹبّر: زنانی, زنانی, کڑی, کڑی',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'ਝੰਡਾ: ਇੰਗਲੈਂਡ',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'ਝੰਡਾ: ਸਕਾਟਲੈਂਡ',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'ਝੰਡਾ: ਵੇਲਸ',
    '🧑‍🧑‍🧒‍🧒' => 'ਪਰਿਵਾਰ: ਮਾਤਾ-ਪਿਤਾ, ਦੋ ਬੱਚੇ',
    '🚶🏻‍♀‍➡' => 'ਪੈਦਲ ਚਲਦੀ ਇਸਤਰੀ: ਗੋਰਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🚶🏼‍♀‍➡' => 'ਪੈਦਲ ਚਲਦੀ ਇਸਤਰੀ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🚶🏽‍♀‍➡' => 'ਪੈਦਲ ਚਲਦੀ ਇਸਤਰੀ: ਕਣਕਵੰਨਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🚶🏾‍♀‍➡' => 'ਪੈਦਲ ਚਲਦੀ ਇਸਤਰੀ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🚶🏿‍♀‍➡' => 'ਪੈਦਲ ਚਲਦੀ ਇਸਤਰੀ: ਕਾਲਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🚶🏻‍♂‍➡' => 'ਪੈਦਲ ਚਲਦਾ ਪੁਰਸ਼: ਗੋਰਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🚶🏼‍♂‍➡' => 'ਪੈਦਲ ਚਲਦਾ ਪੁਰਸ਼: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🚶🏽‍♂‍➡' => 'ਪੈਦਲ ਚਲਦਾ ਪੁਰਸ਼: ਕਣਕਵੰਨਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🚶🏾‍♂‍➡' => 'ਪੈਦਲ ਚਲਦਾ ਪੁਰਸ਼: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🚶🏿‍♂‍➡' => 'ਪੈਦਲ ਚਲਦਾ ਪੁਰਸ਼: ਕਾਲਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🧎🏻‍♀‍➡' => 'ਗੋਡਿਆਂ ਭਾਰ ਬੈਠੀ ਔਰਤ: ਗੋਰਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🧎🏼‍♀‍➡' => 'ਗੋਡਿਆਂ ਭਾਰ ਬੈਠੀ ਔਰਤ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🧎🏽‍♀‍➡' => 'ਗੋਡਿਆਂ ਭਾਰ ਬੈਠੀ ਔਰਤ: ਕਣਕਵੰਨਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🧎🏾‍♀‍➡' => 'ਗੋਡਿਆਂ ਭਾਰ ਬੈਠੀ ਔਰਤ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🧎🏿‍♀‍➡' => 'ਗੋਡਿਆਂ ਭਾਰ ਬੈਠੀ ਔਰਤ: ਕਾਲਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🧎🏻‍♂‍➡' => 'ਗੋਡਿਆਂ ਭਾਰ ਬੈਠਾ ਆਦਮੀ: ਗੋਰਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🧎🏼‍♂‍➡' => 'ਗੋਡਿਆਂ ਭਾਰ ਬੈਠਾ ਆਦਮੀ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🧎🏽‍♂‍➡' => 'ਗੋਡਿਆਂ ਭਾਰ ਬੈਠਾ ਆਦਮੀ: ਕਣਕਵੰਨਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🧎🏾‍♂‍➡' => 'ਗੋਡਿਆਂ ਭਾਰ ਬੈਠਾ ਆਦਮੀ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🧎🏿‍♂‍➡' => 'ਗੋਡਿਆਂ ਭਾਰ ਬੈਠਾ ਆਦਮੀ: ਕਾਲਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🧑🏻‍🦯‍➡' => 'ਟਟੋਲਣ ਵਾਲੀ ਸੋਟੀ ਫੜੀ ਵਿਅਕਤੀ: ਗੋਰਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🧑🏼‍🦯‍➡' => 'ਟਟੋਲਣ ਵਾਲੀ ਸੋਟੀ ਫੜੀ ਵਿਅਕਤੀ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🧑🏽‍🦯‍➡' => 'ਟਟੋਲਣ ਵਾਲੀ ਸੋਟੀ ਫੜੀ ਵਿਅਕਤੀ: ਕਣਕਵੰਨਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🧑🏾‍🦯‍➡' => 'ਟਟੋਲਣ ਵਾਲੀ ਸੋਟੀ ਫੜੀ ਵਿਅਕਤੀ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🧑🏿‍🦯‍➡' => 'ਟਟੋਲਣ ਵਾਲੀ ਸੋਟੀ ਫੜੀ ਵਿਅਕਤੀ: ਕਾਲਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '👨🏻‍🦯‍➡' => 'ਪ੍ਰੋਬਿੰਗ ਕੈਨ ਵਾਲਾ ਆਦਮੀ: ਗੋਰਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '👨🏼‍🦯‍➡' => 'ਪ੍ਰੋਬਿੰਗ ਕੈਨ ਵਾਲਾ ਆਦਮੀ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '👨🏽‍🦯‍➡' => 'ਪ੍ਰੋਬਿੰਗ ਕੈਨ ਵਾਲਾ ਆਦਮੀ: ਕਣਕਵੰਨਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '👨🏾‍🦯‍➡' => 'ਪ੍ਰੋਬਿੰਗ ਕੈਨ ਵਾਲਾ ਆਦਮੀ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '👨🏿‍🦯‍➡' => 'ਪ੍ਰੋਬਿੰਗ ਕੈਨ ਵਾਲਾ ਆਦਮੀ: ਕਾਲਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '👩🏻‍🦯‍➡' => 'ਪ੍ਰੋਬਿੰਗ ਕੈਨ ਵਾਲੀ ਔਰਤ: ਗੋਰਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '👩🏼‍🦯‍➡' => 'ਪ੍ਰੋਬਿੰਗ ਕੈਨ ਵਾਲੀ ਔਰਤ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '👩🏽‍🦯‍➡' => 'ਪ੍ਰੋਬਿੰਗ ਕੈਨ ਵਾਲੀ ਔਰਤ: ਕਣਕਵੰਨਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '👩🏾‍🦯‍➡' => 'ਪ੍ਰੋਬਿੰਗ ਕੈਨ ਵਾਲੀ ਔਰਤ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '👩🏿‍🦯‍➡' => 'ਪ੍ਰੋਬਿੰਗ ਕੈਨ ਵਾਲੀ ਔਰਤ: ਕਾਲਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🧑🏻‍🦼‍➡' => 'ਮੋਟਰ ਵ੍ਹੀਲਚੇਅਰ ਵਿੱਚ ਵਿਅਕਤੀ: ਗੋਰਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🧑🏼‍🦼‍➡' => 'ਮੋਟਰ ਵ੍ਹੀਲਚੇਅਰ ਵਿੱਚ ਵਿਅਕਤੀ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🧑🏽‍🦼‍➡' => 'ਮੋਟਰ ਵ੍ਹੀਲਚੇਅਰ ਵਿੱਚ ਵਿਅਕਤੀ: ਕਣਕਵੰਨਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🧑🏾‍🦼‍➡' => 'ਮੋਟਰ ਵ੍ਹੀਲਚੇਅਰ ਵਿੱਚ ਵਿਅਕਤੀ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🧑🏿‍🦼‍➡' => 'ਮੋਟਰ ਵ੍ਹੀਲਚੇਅਰ ਵਿੱਚ ਵਿਅਕਤੀ: ਕਾਲਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '👨🏻‍🦼‍➡' => 'ਮੋਟਰ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ‘ਤੇ ਬੈਠਾ ਆਦਮੀ: ਗੋਰਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '👨🏼‍🦼‍➡' => 'ਮੋਟਰ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ‘ਤੇ ਬੈਠਾ ਆਦਮੀ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '👨🏽‍🦼‍➡' => 'ਮੋਟਰ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ‘ਤੇ ਬੈਠਾ ਆਦਮੀ: ਕਣਕਵੰਨਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '👨🏾‍🦼‍➡' => 'ਮੋਟਰ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ‘ਤੇ ਬੈਠਾ ਆਦਮੀ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '👨🏿‍🦼‍➡' => 'ਮੋਟਰ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ‘ਤੇ ਬੈਠਾ ਆਦਮੀ: ਕਾਲਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '👩🏻‍🦼‍➡' => 'ਮੋਟਰ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ‘ਤੇ ਬੈਠੀ ਔਰਤ: ਗੋਰਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '👩🏼‍🦼‍➡' => 'ਮੋਟਰ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ‘ਤੇ ਬੈਠੀ ਔਰਤ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '👩🏽‍🦼‍➡' => 'ਮੋਟਰ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ‘ਤੇ ਬੈਠੀ ਔਰਤ: ਕਣਕਵੰਨਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '👩🏾‍🦼‍➡' => 'ਮੋਟਰ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ‘ਤੇ ਬੈਠੀ ਔਰਤ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '👩🏿‍🦼‍➡' => 'ਮੋਟਰ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ‘ਤੇ ਬੈਠੀ ਔਰਤ: ਕਾਲਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🧑🏻‍🦽‍➡' => 'ਹੱਥੀਂ ਚੱਲਣ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ਵਿੱਚ ਵਿਅਕਤੀ: ਗੋਰਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🧑🏼‍🦽‍➡' => 'ਹੱਥੀਂ ਚੱਲਣ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ਵਿੱਚ ਵਿਅਕਤੀ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🧑🏽‍🦽‍➡' => 'ਹੱਥੀਂ ਚੱਲਣ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ਵਿੱਚ ਵਿਅਕਤੀ: ਕਣਕਵੰਨਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🧑🏾‍🦽‍➡' => 'ਹੱਥੀਂ ਚੱਲਣ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ਵਿੱਚ ਵਿਅਕਤੀ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🧑🏿‍🦽‍➡' => 'ਹੱਥੀਂ ਚੱਲਣ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ਵਿੱਚ ਵਿਅਕਤੀ: ਕਾਲਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '👨🏻‍🦽‍➡' => 'ਹੱਥ ਨਾਲ ਚੱਲਣ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ‘ਤੇ ਬੈਠਾ ਆਦਮੀ: ਗੋਰਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '👨🏼‍🦽‍➡' => 'ਹੱਥ ਨਾਲ ਚੱਲਣ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ‘ਤੇ ਬੈਠਾ ਆਦਮੀ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '👨🏽‍🦽‍➡' => 'ਹੱਥ ਨਾਲ ਚੱਲਣ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ‘ਤੇ ਬੈਠਾ ਆਦਮੀ: ਕਣਕਵੰਨਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '👨🏾‍🦽‍➡' => 'ਹੱਥ ਨਾਲ ਚੱਲਣ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ‘ਤੇ ਬੈਠਾ ਆਦਮੀ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '👨🏿‍🦽‍➡' => 'ਹੱਥ ਨਾਲ ਚੱਲਣ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ‘ਤੇ ਬੈਠਾ ਆਦਮੀ: ਕਾਲਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '👩🏻‍🦽‍➡' => 'ਹੱਥ ਨਾਲ ਚੱਲਣ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ‘ਤੇ ਬੈਠੀ ਔਰਤ: ਗੋਰਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '👩🏼‍🦽‍➡' => 'ਹੱਥ ਨਾਲ ਚੱਲਣ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ‘ਤੇ ਬੈਠੀ ਔਰਤ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '👩🏽‍🦽‍➡' => 'ਹੱਥ ਨਾਲ ਚੱਲਣ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ‘ਤੇ ਬੈਠੀ ਔਰਤ: ਕਣਕਵੰਨਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '👩🏾‍🦽‍➡' => 'ਹੱਥ ਨਾਲ ਚੱਲਣ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ‘ਤੇ ਬੈਠੀ ਔਰਤ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '👩🏿‍🦽‍➡' => 'ਹੱਥ ਨਾਲ ਚੱਲਣ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ‘ਤੇ ਬੈਠੀ ਔਰਤ: ਕਾਲਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🏃🏻‍♀‍➡' => 'ਦੌੜਦੀ ਇਸਤਰੀ: ਗੋਰਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🏃🏼‍♀‍➡' => 'ਦੌੜਦੀ ਇਸਤਰੀ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🏃🏽‍♀‍➡' => 'ਦੌੜਦੀ ਇਸਤਰੀ: ਕਣਕਵੰਨਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🏃🏾‍♀‍➡' => 'ਦੌੜਦੀ ਇਸਤਰੀ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🏃🏿‍♀‍➡' => 'ਦੌੜਦੀ ਇਸਤਰੀ: ਕਾਲਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🏃🏻‍♂‍➡' => 'ਦੌੜਦਾ ਪੁਰਸ਼: ਗੋਰਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🏃🏼‍♂‍➡' => 'ਦੌੜਦਾ ਪੁਰਸ਼: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🏃🏽‍♂‍➡' => 'ਦੌੜਦਾ ਪੁਰਸ਼: ਕਣਕਵੰਨਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🏃🏾‍♂‍➡' => 'ਦੌੜਦਾ ਪੁਰਸ਼: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🏃🏿‍♂‍➡' => 'ਦੌੜਦਾ ਪੁਰਸ਼: ਕਾਲਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🫱🏻‍🫲🏼' => 'ہتھ ملانا: ہلکی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '🫱🏻‍🫲🏽' => 'ہتھ ملانا: ہلکی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '🫱🏻‍🫲🏾' => 'ہتھ ملانا: ہلکی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '🫱🏻‍🫲🏿' => 'ہتھ ملانا: ہلکی رنگت آلی جلد, کالی رنگت آلی جلد',
    '🫱🏼‍🫲🏻' => 'ہتھ ملانا: ہلکی درمیانی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '🫱🏼‍🫲🏽' => 'ہتھ ملانا: ہلکی درمیانی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '🫱🏼‍🫲🏾' => 'ہتھ ملانا: ہلکی درمیانی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '🫱🏼‍🫲🏿' => 'ہتھ ملانا: ہلکی درمیانی رنگت آلی جلد, کالی رنگت آلی جلد',
    '🫱🏽‍🫲🏻' => 'ہتھ ملانا: درمیانی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '🫱🏽‍🫲🏼' => 'ہتھ ملانا: درمیانی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '🫱🏽‍🫲🏾' => 'ہتھ ملانا: درمیانی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '🫱🏽‍🫲🏿' => 'ہتھ ملانا: درمیانی رنگت آلی جلد, کالی رنگت آلی جلد',
    '🫱🏾‍🫲🏻' => 'ہتھ ملانا: درمیانی کالی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '🫱🏾‍🫲🏼' => 'ہتھ ملانا: درمیانی کالی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '🫱🏾‍🫲🏽' => 'ہتھ ملانا: درمیانی کالی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '🫱🏾‍🫲🏿' => 'ہتھ ملانا: درمیانی کالی رنگت آلی جلد, کالی رنگت آلی جلد',
    '🫱🏿‍🫲🏻' => 'ہتھ ملانا: کالی رنگت آلی جلد, ہلکی رنگت آلی جلد',
    '🫱🏿‍🫲🏼' => 'ہتھ ملانا: کالی رنگت آلی جلد, ہلکی درمیانی رنگت آلی جلد',
    '🫱🏿‍🫲🏽' => 'ہتھ ملانا: کالی رنگت آلی جلد, درمیانی رنگت آلی جلد',
    '🫱🏿‍🫲🏾' => 'ہتھ ملانا: کالی رنگت آلی جلد, درمیانی کالی رنگت آلی جلد',
    '🚶‍♀‍➡' => 'ਪੈਦਲ ਚਲਦੀ ਇਸਤਰੀ: ਸੱਜੇ ਪਾਸੇ',
    '🚶‍♂‍➡' => 'ਪੈਦਲ ਚਲਦਾ ਪੁਰਸ਼: ਸੱਜੇ ਪਾਸੇ',
    '🧎‍♀‍➡' => 'ਗੋਡਿਆਂ ਭਾਰ ਬੈਠੀ ਔਰਤ: ਸੱਜੇ ਪਾਸੇ',
    '🧎‍♂‍➡' => 'ਗੋਡਿਆਂ ਭਾਰ ਬੈਠਾ ਆਦਮੀ: ਸੱਜੇ ਪਾਸੇ',
    '🧑‍🦯‍➡' => 'ਟਟੋਲਣ ਵਾਲੀ ਸੋਟੀ ਫੜੀ ਵਿਅਕਤੀ: ਸੱਜੇ ਪਾਸੇ',
    '👨‍🦯‍➡' => 'ਪ੍ਰੋਬਿੰਗ ਕੈਨ ਵਾਲਾ ਆਦਮੀ: ਸੱਜੇ ਪਾਸੇ',
    '👩‍🦯‍➡' => 'ਪ੍ਰੋਬਿੰਗ ਕੈਨ ਵਾਲੀ ਔਰਤ: ਸੱਜੇ ਪਾਸੇ',
    '🧑‍🦼‍➡' => 'ਮੋਟਰ ਵ੍ਹੀਲਚੇਅਰ ਵਿੱਚ ਵਿਅਕਤੀ: ਸੱਜੇ ਪਾਸੇ',
    '👨‍🦼‍➡' => 'ਮੋਟਰ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ‘ਤੇ ਬੈਠਾ ਆਦਮੀ: ਸੱਜੇ ਪਾਸੇ',
    '👩‍🦼‍➡' => 'ਮੋਟਰ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ‘ਤੇ ਬੈਠੀ ਔਰਤ: ਸੱਜੇ ਪਾਸੇ',
    '🧑‍🦽‍➡' => 'ਹੱਥੀਂ ਚੱਲਣ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ਵਿੱਚ ਵਿਅਕਤੀ: ਸੱਜੇ ਪਾਸੇ',
    '👨‍🦽‍➡' => 'ਹੱਥ ਨਾਲ ਚੱਲਣ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ‘ਤੇ ਬੈਠਾ ਆਦਮੀ: ਸੱਜੇ ਪਾਸੇ',
    '👩‍🦽‍➡' => 'ਹੱਥ ਨਾਲ ਚੱਲਣ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ‘ਤੇ ਬੈਠੀ ਔਰਤ: ਸੱਜੇ ਪਾਸੇ',
    '🏃‍♀‍➡' => 'ਦੌੜਦੀ ਇਸਤਰੀ: ਸੱਜੇ ਪਾਸੇ',
    '🏃‍♂‍➡' => 'ਦੌੜਦਾ ਪੁਰਸ਼: ਸੱਜੇ ਪਾਸੇ',
    '👩‍❤‍👨' => 'دل نال جوڑا: زنانی, بندہ',
    '👨‍❤‍👨' => 'دل نال جوڑا: بندہ, بندہ',
    '👩‍❤‍👩' => 'دل نال جوڑا: زنانی, زنانی',
    '👨‍👩‍👦' => 'ٹبّر: بندہ, زنانی, منڈا',
    '👨‍👩‍👧' => 'ٹبّر: بندہ, زنانی, کڑی',
    '👨‍👨‍👦' => 'ٹبّر: بندہ, بندہ, منڈا',
    '👨‍👨‍👧' => 'ٹبّر: بندہ, بندہ, کڑی',
    '👩‍👩‍👦' => 'ٹبّر: زنانی, زنانی, منڈا',
    '👩‍👩‍👧' => 'ٹبّر: زنانی, زنانی, کڑی',
    '👨‍👦‍👦' => 'ٹبّر: بندہ, منڈا, منڈا',
    '👨‍👧‍👦' => 'ٹبّر: بندہ, کڑی, منڈا',
    '👨‍👧‍👧' => 'ٹبّر: بندہ, کڑی, کڑی',
    '👩‍👦‍👦' => 'ٹبّر: زنانی, منڈا, منڈا',
    '👩‍👧‍👦' => 'ٹبّر: زنانی, کڑی, منڈا',
    '👩‍👧‍👧' => 'ٹبّر: زنانی, کڑی, کڑی',
    '🧑‍🤝‍🧑' => 'ਹੱਥ ਫੜਦੇ ਹੋਏ ਲੋਕ',
    '🧑‍🧑‍🧒' => 'ਪਰਿਵਾਰ: ਮਾਤਾ-ਪਿਤਾ, ਬੱਚਾ',
    '🧑‍🧒‍🧒' => 'ਪਰਿਵਾਰ: ਪਿਤਾ, ਦੋ ਬੱਚੇ',
    '🧑🏻‍🦰' => 'ਵਿਅਕਤੀ: ਗੋਰਾ ਰੰਗ, ਲਾਲ ਰੰਗ ਦੇ ਵਾਲ',
    '🧑🏼‍🦰' => 'ਵਿਅਕਤੀ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ, ਲਾਲ ਰੰਗ ਦੇ ਵਾਲ',
    '🧑🏽‍🦰' => 'ਵਿਅਕਤੀ: ਕਣਕਵੰਨਾ ਰੰਗ, ਲਾਲ ਰੰਗ ਦੇ ਵਾਲ',
    '🧑🏾‍🦰' => 'ਵਿਅਕਤੀ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ, ਲਾਲ ਰੰਗ ਦੇ ਵਾਲ',
    '🧑🏿‍🦰' => 'ਵਿਅਕਤੀ: ਕਾਲਾ ਰੰਗ, ਲਾਲ ਰੰਗ ਦੇ ਵਾਲ',
    '🧑🏻‍🦱' => 'ਵਿਅਕਤੀ: ਗੋਰਾ ਰੰਗ, ਘੁੰਗਰਾਲੇ ਵਾਲ',
    '🧑🏼‍🦱' => 'ਵਿਅਕਤੀ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ, ਘੁੰਗਰਾਲੇ ਵਾਲ',
    '🧑🏽‍🦱' => 'ਵਿਅਕਤੀ: ਕਣਕਵੰਨਾ ਰੰਗ, ਘੁੰਗਰਾਲੇ ਵਾਲ',
    '🧑🏾‍🦱' => 'ਵਿਅਕਤੀ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ, ਘੁੰਗਰਾਲੇ ਵਾਲ',
    '🧑🏿‍🦱' => 'ਵਿਅਕਤੀ: ਕਾਲਾ ਰੰਗ, ਘੁੰਗਰਾਲੇ ਵਾਲ',
    '🧑🏻‍🦳' => 'ਵਿਅਕਤੀ: ਗੋਰਾ ਰੰਗ, ਚਿੱਟੇ ਵਾਲ',
    '🧑🏼‍🦳' => 'ਵਿਅਕਤੀ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ, ਚਿੱਟੇ ਵਾਲ',
    '🧑🏽‍🦳' => 'ਵਿਅਕਤੀ: ਕਣਕਵੰਨਾ ਰੰਗ, ਚਿੱਟੇ ਵਾਲ',
    '🧑🏾‍🦳' => 'ਵਿਅਕਤੀ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ, ਚਿੱਟੇ ਵਾਲ',
    '🧑🏿‍🦳' => 'ਵਿਅਕਤੀ: ਕਾਲਾ ਰੰਗ, ਚਿੱਟੇ ਵਾਲ',
    '🧑🏻‍🦲' => 'ਵਿਅਕਤੀ: ਗੋਰਾ ਰੰਗ, ਗੰਜਾ ਸਿਰ',
    '🧑🏼‍🦲' => 'ਵਿਅਕਤੀ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ, ਗੰਜਾ ਸਿਰ',
    '🧑🏽‍🦲' => 'ਵਿਅਕਤੀ: ਕਣਕਵੰਨਾ ਰੰਗ, ਗੰਜਾ ਸਿਰ',
    '🧑🏾‍🦲' => 'ਵਿਅਕਤੀ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ, ਗੰਜਾ ਸਿਰ',
    '🧑🏿‍🦲' => 'ਵਿਅਕਤੀ: ਕਾਲਾ ਰੰਗ, ਗੰਜਾ ਸਿਰ',
    '🧑🏻‍🩰' => 'ਬੈਲੇ ਡਾਂਸਰ: ਗੋਰਾ ਰੰਗ',
    '🧑🏼‍🩰' => 'ਬੈਲੇ ਡਾਂਸਰ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏽‍🩰' => 'ਬੈਲੇ ਡਾਂਸਰ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏾‍🩰' => 'ਬੈਲੇ ਡਾਂਸਰ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🧑🏿‍🩰' => 'ਬੈਲੇ ਡਾਂਸਰ: ਕਾਲਾ ਰੰਗ',
    '🧔🏻‍♂' => 'ਆਦਮੀ: ਗੋਰਾ ਰੰਗ, ਦਾੜ੍ਹੀ',
    '🧔🏼‍♂' => 'ਆਦਮੀ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ, ਦਾੜ੍ਹੀ',
    '🧔🏽‍♂' => 'ਆਦਮੀ: ਕਣਕਵੰਨਾ ਰੰਗ, ਦਾੜ੍ਹੀ',
    '🧔🏾‍♂' => 'ਆਦਮੀ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ, ਦਾੜ੍ਹੀ',
    '🧔🏿‍♂' => 'ਆਦਮੀ: ਕਾਲਾ ਰੰਗ, ਦਾੜ੍ਹੀ',
    '👱🏻‍♂' => 'بُھورے والاں آلا آدمی: ہلکی رنگت آلی جلد',
    '👱🏼‍♂' => 'بُھورے والاں آلا آدمی: ہلکی درمیانی رنگت آلی جلد',
    '👱🏽‍♂' => 'بُھورے والاں آلا آدمی: درمیانی رنگت آلی جلد',
    '👱🏾‍♂' => 'بُھورے والاں آلا آدمی: درمیانی کالی رنگت آلی جلد',
    '👱🏿‍♂' => 'بُھورے والاں آلا آدمی: کالی رنگت آلی جلد',
    '👨🏻‍🦰' => 'ਆਦਮੀ: ਗੋਰਾ ਰੰਗ, ਲਾਲ ਰੰਗ ਦੇ ਵਾਲ',
    '👨🏼‍🦰' => 'ਆਦਮੀ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ, ਲਾਲ ਰੰਗ ਦੇ ਵਾਲ',
    '👨🏽‍🦰' => 'ਆਦਮੀ: ਕਣਕਵੰਨਾ ਰੰਗ, ਲਾਲ ਰੰਗ ਦੇ ਵਾਲ',
    '👨🏾‍🦰' => 'ਆਦਮੀ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ, ਲਾਲ ਰੰਗ ਦੇ ਵਾਲ',
    '👨🏿‍🦰' => 'ਆਦਮੀ: ਕਾਲਾ ਰੰਗ, ਲਾਲ ਰੰਗ ਦੇ ਵਾਲ',
    '👨🏻‍🦱' => 'ਆਦਮੀ: ਗੋਰਾ ਰੰਗ, ਘੁੰਗਰਾਲੇ ਵਾਲ',
    '👨🏼‍🦱' => 'ਆਦਮੀ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ, ਘੁੰਗਰਾਲੇ ਵਾਲ',
    '👨🏽‍🦱' => 'ਆਦਮੀ: ਕਣਕਵੰਨਾ ਰੰਗ, ਘੁੰਗਰਾਲੇ ਵਾਲ',
    '👨🏾‍🦱' => 'ਆਦਮੀ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ, ਘੁੰਗਰਾਲੇ ਵਾਲ',
    '👨🏿‍🦱' => 'ਆਦਮੀ: ਕਾਲਾ ਰੰਗ, ਘੁੰਗਰਾਲੇ ਵਾਲ',
    '👨🏻‍🦳' => 'ਆਦਮੀ: ਗੋਰਾ ਰੰਗ, ਚਿੱਟੇ ਵਾਲ',
    '👨🏼‍🦳' => 'ਆਦਮੀ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ, ਚਿੱਟੇ ਵਾਲ',
    '👨🏽‍🦳' => 'ਆਦਮੀ: ਕਣਕਵੰਨਾ ਰੰਗ, ਚਿੱਟੇ ਵਾਲ',
    '👨🏾‍🦳' => 'ਆਦਮੀ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ, ਚਿੱਟੇ ਵਾਲ',
    '👨🏿‍🦳' => 'ਆਦਮੀ: ਕਾਲਾ ਰੰਗ, ਚਿੱਟੇ ਵਾਲ',
    '👨🏻‍🦲' => 'ਆਦਮੀ: ਗੋਰਾ ਰੰਗ, ਗੰਜਾ ਸਿਰ',
    '👨🏼‍🦲' => 'ਆਦਮੀ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ, ਗੰਜਾ ਸਿਰ',
    '👨🏽‍🦲' => 'ਆਦਮੀ: ਕਣਕਵੰਨਾ ਰੰਗ, ਗੰਜਾ ਸਿਰ',
    '👨🏾‍🦲' => 'ਆਦਮੀ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ, ਗੰਜਾ ਸਿਰ',
    '👨🏿‍🦲' => 'ਆਦਮੀ: ਕਾਲਾ ਰੰਗ, ਗੰਜਾ ਸਿਰ',
    '🧔🏻‍♀' => 'ਔਰਤ: ਗੋਰਾ ਰੰਗ, ਦਾੜ੍ਹੀ',
    '🧔🏼‍♀' => 'ਔਰਤ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ, ਦਾੜ੍ਹੀ',
    '🧔🏽‍♀' => 'ਔਰਤ: ਕਣਕਵੰਨਾ ਰੰਗ, ਦਾੜ੍ਹੀ',
    '🧔🏾‍♀' => 'ਔਰਤ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ, ਦਾੜ੍ਹੀ',
    '🧔🏿‍♀' => 'ਔਰਤ: ਕਾਲਾ ਰੰਗ, ਦਾੜ੍ਹੀ',
    '👱🏻‍♀' => 'بُھورے والاں آلی زنانی: ہلکی رنگت آلی جلد',
    '👱🏼‍♀' => 'بُھورے والاں آلی زنانی: ہلکی درمیانی رنگت آلی جلد',
    '👱🏽‍♀' => 'بُھورے والاں آلی زنانی: درمیانی رنگت آلی جلد',
    '👱🏾‍♀' => 'بُھورے والاں آلی زنانی: درمیانی کالی رنگت آلی جلد',
    '👱🏿‍♀' => 'بُھورے والاں آلی زنانی: کالی رنگت آلی جلد',
    '👩🏻‍🦰' => 'ਔਰਤ: ਗੋਰਾ ਰੰਗ, ਲਾਲ ਰੰਗ ਦੇ ਵਾਲ',
    '👩🏼‍🦰' => 'ਔਰਤ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ, ਲਾਲ ਰੰਗ ਦੇ ਵਾਲ',
    '👩🏽‍🦰' => 'ਔਰਤ: ਕਣਕਵੰਨਾ ਰੰਗ, ਲਾਲ ਰੰਗ ਦੇ ਵਾਲ',
    '👩🏾‍🦰' => 'ਔਰਤ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ, ਲਾਲ ਰੰਗ ਦੇ ਵਾਲ',
    '👩🏿‍🦰' => 'ਔਰਤ: ਕਾਲਾ ਰੰਗ, ਲਾਲ ਰੰਗ ਦੇ ਵਾਲ',
    '👩🏻‍🦱' => 'ਔਰਤ: ਗੋਰਾ ਰੰਗ, ਘੁੰਗਰਾਲੇ ਵਾਲ',
    '👩🏼‍🦱' => 'ਔਰਤ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ, ਘੁੰਗਰਾਲੇ ਵਾਲ',
    '👩🏽‍🦱' => 'ਔਰਤ: ਕਣਕਵੰਨਾ ਰੰਗ, ਘੁੰਗਰਾਲੇ ਵਾਲ',
    '👩🏾‍🦱' => 'ਔਰਤ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ, ਘੁੰਗਰਾਲੇ ਵਾਲ',
    '👩🏿‍🦱' => 'ਔਰਤ: ਕਾਲਾ ਰੰਗ, ਘੁੰਗਰਾਲੇ ਵਾਲ',
    '👩🏻‍🦳' => 'ਔਰਤ: ਗੋਰਾ ਰੰਗ, ਚਿੱਟੇ ਵਾਲ',
    '👩🏼‍🦳' => 'ਔਰਤ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ, ਚਿੱਟੇ ਵਾਲ',
    '👩🏽‍🦳' => 'ਔਰਤ: ਕਣਕਵੰਨਾ ਰੰਗ, ਚਿੱਟੇ ਵਾਲ',
    '👩🏾‍🦳' => 'ਔਰਤ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ, ਚਿੱਟੇ ਵਾਲ',
    '👩🏿‍🦳' => 'ਔਰਤ: ਕਾਲਾ ਰੰਗ, ਚਿੱਟੇ ਵਾਲ',
    '👩🏻‍🦲' => 'ਔਰਤ: ਗੋਰਾ ਰੰਗ, ਗੰਜਾ ਸਿਰ',
    '👩🏼‍🦲' => 'ਔਰਤ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ, ਗੰਜਾ ਸਿਰ',
    '👩🏽‍🦲' => 'ਔਰਤ: ਕਣਕਵੰਨਾ ਰੰਗ, ਗੰਜਾ ਸਿਰ',
    '👩🏾‍🦲' => 'ਔਰਤ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ, ਗੰਜਾ ਸਿਰ',
    '👩🏿‍🦲' => 'ਔਰਤ: ਕਾਲਾ ਰੰਗ, ਗੰਜਾ ਸਿਰ',
    '🙍🏻‍♂' => 'تیوری چڑھاندا بندہ: ہلکی رنگت آلی جلد',
    '🙍🏼‍♂' => 'تیوری چڑھاندا بندہ: ہلکی درمیانی رنگت آلی جلد',
    '🙍🏽‍♂' => 'تیوری چڑھاندا بندہ: درمیانی رنگت آلی جلد',
    '🙍🏾‍♂' => 'تیوری چڑھاندا بندہ: درمیانی کالی رنگت آلی جلد',
    '🙍🏿‍♂' => 'تیوری چڑھاندا بندہ: کالی رنگت آلی جلد',
    '🙍🏻‍♀' => 'تیوری چڑھاندی زنانی: ہلکی رنگت آلی جلد',
    '🙍🏼‍♀' => 'تیوری چڑھاندی زنانی: ہلکی درمیانی رنگت آلی جلد',
    '🙍🏽‍♀' => 'تیوری چڑھاندی زنانی: درمیانی رنگت آلی جلد',
    '🙍🏾‍♀' => 'تیوری چڑھاندی زنانی: درمیانی کالی رنگت آلی جلد',
    '🙍🏿‍♀' => 'تیوری چڑھاندی زنانی: کالی رنگت آلی جلد',
    '🙎🏻‍♂' => 'منہ بسوردا بندہ: ہلکی رنگت آلی جلد',
    '🙎🏼‍♂' => 'منہ بسوردا بندہ: ہلکی درمیانی رنگت آلی جلد',
    '🙎🏽‍♂' => 'منہ بسوردا بندہ: درمیانی رنگت آلی جلد',
    '🙎🏾‍♂' => 'منہ بسوردا بندہ: درمیانی کالی رنگت آلی جلد',
    '🙎🏿‍♂' => 'منہ بسوردا بندہ: کالی رنگت آلی جلد',
    '🙎🏻‍♀' => 'منہ بسوردی زنانی: ہلکی رنگت آلی جلد',
    '🙎🏼‍♀' => 'منہ بسوردی زنانی: ہلکی درمیانی رنگت آلی جلد',
    '🙎🏽‍♀' => 'منہ بسوردی زنانی: درمیانی رنگت آلی جلد',
    '🙎🏾‍♀' => 'منہ بسوردی زنانی: درمیانی کالی رنگت آلی جلد',
    '🙎🏿‍♀' => 'منہ بسوردی زنانی: کالی رنگت آلی جلد',
    '🙅🏻‍♂' => 'نہیں دا اشارہ کردا بندہ: ہلکی رنگت آلی جلد',
    '🙅🏼‍♂' => 'نہیں دا اشارہ کردا بندہ: ہلکی درمیانی رنگت آلی جلد',
    '🙅🏽‍♂' => 'نہیں دا اشارہ کردا بندہ: درمیانی رنگت آلی جلد',
    '🙅🏾‍♂' => 'نہیں دا اشارہ کردا بندہ: درمیانی کالی رنگت آلی جلد',
    '🙅🏿‍♂' => 'نہیں دا اشارہ کردا بندہ: کالی رنگت آلی جلد',
    '🙅🏻‍♀' => 'نہیں دا اشارہ کردی زنانی: ہلکی رنگت آلی جلد',
    '🙅🏼‍♀' => 'نہیں دا اشارہ کردی زنانی: ہلکی درمیانی رنگت آلی جلد',
    '🙅🏽‍♀' => 'نہیں دا اشارہ کردی زنانی: درمیانی رنگت آلی جلد',
    '🙅🏾‍♀' => 'نہیں دا اشارہ کردی زنانی: درمیانی کالی رنگت آلی جلد',
    '🙅🏿‍♀' => 'نہیں دا اشارہ کردی زنانی: کالی رنگت آلی جلد',
    '🙆🏻‍♂' => 'ٹھیک اے دا اشارہ کردا بندہ: ہلکی رنگت آلی جلد',
    '🙆🏼‍♂' => 'ٹھیک اے دا اشارہ کردا بندہ: ہلکی درمیانی رنگت آلی جلد',
    '🙆🏽‍♂' => 'ٹھیک اے دا اشارہ کردا بندہ: درمیانی رنگت آلی جلد',
    '🙆🏾‍♂' => 'ٹھیک اے دا اشارہ کردا بندہ: درمیانی کالی رنگت آلی جلد',
    '🙆🏿‍♂' => 'ٹھیک اے دا اشارہ کردا بندہ: کالی رنگت آلی جلد',
    '🙆🏻‍♀' => 'ٹھیک اے دا اشارہ کردی زنانی: ہلکی رنگت آلی جلد',
    '🙆🏼‍♀' => 'ٹھیک اے دا اشارہ کردی زنانی: ہلکی درمیانی رنگت آلی جلد',
    '🙆🏽‍♀' => 'ٹھیک اے دا اشارہ کردی زنانی: درمیانی رنگت آلی جلد',
    '🙆🏾‍♀' => 'ٹھیک اے دا اشارہ کردی زنانی: درمیانی کالی رنگت آلی جلد',
    '🙆🏿‍♀' => 'ٹھیک اے دا اشارہ کردی زنانی: کالی رنگت آلی جلد',
    '💁🏻‍♂' => 'تھپکی دیندا مرد: ہلکی رنگت آلی جلد',
    '💁🏼‍♂' => 'تھپکی دیندا مرد: ہلکی درمیانی رنگت آلی جلد',
    '💁🏽‍♂' => 'تھپکی دیندا مرد: درمیانی رنگت آلی جلد',
    '💁🏾‍♂' => 'تھپکی دیندا مرد: درمیانی کالی رنگت آلی جلد',
    '💁🏿‍♂' => 'تھپکی دیندا مرد: کالی رنگت آلی جلد',
    '💁🏻‍♀' => 'تھپکی دیندی زنانی: ہلکی رنگت آلی جلد',
    '💁🏼‍♀' => 'تھپکی دیندی زنانی: ہلکی درمیانی رنگت آلی جلد',
    '💁🏽‍♀' => 'تھپکی دیندی زنانی: درمیانی رنگت آلی جلد',
    '💁🏾‍♀' => 'تھپکی دیندی زنانی: درمیانی کالی رنگت آلی جلد',
    '💁🏿‍♀' => 'تھپکی دیندی زنانی: کالی رنگت آلی جلد',
    '🙋🏻‍♂' => 'ہتھ اُوتے کردا بندہ: ہلکی رنگت آلی جلد',
    '🙋🏼‍♂' => 'ہتھ اُوتے کردا بندہ: ہلکی درمیانی رنگت آلی جلد',
    '🙋🏽‍♂' => 'ہتھ اُوتے کردا بندہ: درمیانی رنگت آلی جلد',
    '🙋🏾‍♂' => 'ہتھ اُوتے کردا بندہ: درمیانی کالی رنگت آلی جلد',
    '🙋🏿‍♂' => 'ہتھ اُوتے کردا بندہ: کالی رنگت آلی جلد',
    '🙋🏻‍♀' => 'ہتھ اُوتے کردی زنانی: ہلکی رنگت آلی جلد',
    '🙋🏼‍♀' => 'ہتھ اُوتے کردی زنانی: ہلکی درمیانی رنگت آلی جلد',
    '🙋🏽‍♀' => 'ہتھ اُوتے کردی زنانی: درمیانی رنگت آلی جلد',
    '🙋🏾‍♀' => 'ہتھ اُوتے کردی زنانی: درمیانی کالی رنگت آلی جلد',
    '🙋🏿‍♀' => 'ہتھ اُوتے کردی زنانی: کالی رنگت آلی جلد',
    '🧏🏻‍♂' => 'ਬੋਲ਼ਾ ਆਦਮੀ: ਗੋਰਾ ਰੰਗ',
    '🧏🏼‍♂' => 'ਬੋਲ਼ਾ ਆਦਮੀ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧏🏽‍♂' => 'ਬੋਲ਼ਾ ਆਦਮੀ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧏🏾‍♂' => 'ਬੋਲ਼ਾ ਆਦਮੀ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🧏🏿‍♂' => 'ਬੋਲ਼ਾ ਆਦਮੀ: ਕਾਲਾ ਰੰਗ',
    '🧏🏻‍♀' => 'ਬੋਲ਼ੀ ਔਰਤ: ਗੋਰਾ ਰੰਗ',
    '🧏🏼‍♀' => 'ਬੋਲ਼ੀ ਔਰਤ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧏🏽‍♀' => 'ਬੋਲ਼ੀ ਔਰਤ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧏🏾‍♀' => 'ਬੋਲ਼ੀ ਔਰਤ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🧏🏿‍♀' => 'ਬੋਲ਼ੀ ਔਰਤ: ਕਾਲਾ ਰੰਗ',
    '🙇🏻‍♂' => 'جُھکدا بندہ: ہلکی رنگت آلی جلد',
    '🙇🏼‍♂' => 'جُھکدا بندہ: ہلکی درمیانی رنگت آلی جلد',
    '🙇🏽‍♂' => 'جُھکدا بندہ: درمیانی رنگت آلی جلد',
    '🙇🏾‍♂' => 'جُھکدا بندہ: درمیانی کالی رنگت آلی جلد',
    '🙇🏿‍♂' => 'جُھکدا بندہ: کالی رنگت آلی جلد',
    '🙇🏻‍♀' => 'جُھکدی زنانی: ہلکی رنگت آلی جلد',
    '🙇🏼‍♀' => 'جُھکدی زنانی: ہلکی درمیانی رنگت آلی جلد',
    '🙇🏽‍♀' => 'جُھکدی زنانی: درمیانی رنگت آلی جلد',
    '🙇🏾‍♀' => 'جُھکدی زنانی: درمیانی کالی رنگت آلی جلد',
    '🙇🏿‍♀' => 'جُھکدی زنانی: کالی رنگت آلی جلد',
    '🤦🏻‍♂' => 'منہ اوتے ہتھ رکھدا بندہ: ہلکی رنگت آلی جلد',
    '🤦🏼‍♂' => 'منہ اوتے ہتھ رکھدا بندہ: ہلکی درمیانی رنگت آلی جلد',
    '🤦🏽‍♂' => 'منہ اوتے ہتھ رکھدا بندہ: درمیانی رنگت آلی جلد',
    '🤦🏾‍♂' => 'منہ اوتے ہتھ رکھدا بندہ: درمیانی کالی رنگت آلی جلد',
    '🤦🏿‍♂' => 'منہ اوتے ہتھ رکھدا بندہ: کالی رنگت آلی جلد',
    '🤦🏻‍♀' => 'منہ اوتے ہتھ رکھدی زنانی: ہلکی رنگت آلی جلد',
    '🤦🏼‍♀' => 'منہ اوتے ہتھ رکھدی زنانی: ہلکی درمیانی رنگت آلی جلد',
    '🤦🏽‍♀' => 'منہ اوتے ہتھ رکھدی زنانی: درمیانی رنگت آلی جلد',
    '🤦🏾‍♀' => 'منہ اوتے ہتھ رکھدی زنانی: درمیانی کالی رنگت آلی جلد',
    '🤦🏿‍♀' => 'منہ اوتے ہتھ رکھدی زنانی: کالی رنگت آلی جلد',
    '🤷🏻‍♂' => 'مونڈھے اچکاندا بندہ: ہلکی رنگت آلی جلد',
    '🤷🏼‍♂' => 'مونڈھے اچکاندا بندہ: ہلکی درمیانی رنگت آلی جلد',
    '🤷🏽‍♂' => 'مونڈھے اچکاندا بندہ: درمیانی رنگت آلی جلد',
    '🤷🏾‍♂' => 'مونڈھے اچکاندا بندہ: درمیانی کالی رنگت آلی جلد',
    '🤷🏿‍♂' => 'مونڈھے اچکاندا بندہ: کالی رنگت آلی جلد',
    '🤷🏻‍♀' => 'مونڈھے اچکاندی زنانی: ہلکی رنگت آلی جلد',
    '🤷🏼‍♀' => 'مونڈھے اچکاندی زنانی: ہلکی درمیانی رنگت آلی جلد',
    '🤷🏽‍♀' => 'مونڈھے اچکاندی زنانی: درمیانی رنگت آلی جلد',
    '🤷🏾‍♀' => 'مونڈھے اچکاندی زنانی: درمیانی کالی رنگت آلی جلد',
    '🤷🏿‍♀' => 'مونڈھے اچکاندی زنانی: کالی رنگت آلی جلد',
    '🧑🏻‍⚕' => 'ਸਿਹਤਕਰਮੀ: ਗੋਰਾ ਰੰਗ',
    '🧑🏼‍⚕' => 'ਸਿਹਤਕਰਮੀ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏽‍⚕' => 'ਸਿਹਤਕਰਮੀ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏾‍⚕' => 'ਸਿਹਤਕਰਮੀ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🧑🏿‍⚕' => 'ਸਿਹਤਕਰਮੀ: ਕਾਲਾ ਰੰਗ',
    '👨🏻‍⚕' => 'صحت تے کم کرن آلا بندہ: ہلکی رنگت آلی جلد',
    '👨🏼‍⚕' => 'صحت تے کم کرن آلا بندہ: ہلکی درمیانی رنگت آلی جلد',
    '👨🏽‍⚕' => 'صحت تے کم کرن آلا بندہ: درمیانی رنگت آلی جلد',
    '👨🏾‍⚕' => 'صحت تے کم کرن آلا بندہ: درمیانی کالی رنگت آلی جلد',
    '👨🏿‍⚕' => 'صحت تے کم کرن آلا بندہ: کالی رنگت آلی جلد',
    '👩🏻‍⚕' => 'صحت تے کم کرن آلی زنانی: ہلکی رنگت آلی جلد',
    '👩🏼‍⚕' => 'صحت تے کم کرن آلی زنانی: ہلکی درمیانی رنگت آلی جلد',
    '👩🏽‍⚕' => 'صحت تے کم کرن آلی زنانی: درمیانی رنگت آلی جلد',
    '👩🏾‍⚕' => 'صحت تے کم کرن آلی زنانی: درمیانی کالی رنگت آلی جلد',
    '👩🏿‍⚕' => 'صحت تے کم کرن آلی زنانی: کالی رنگت آلی جلد',
    '🧑🏻‍🎓' => 'ਸਿਖਿਆਰਥੀ: ਗੋਰਾ ਰੰਗ',
    '🧑🏼‍🎓' => 'ਸਿਖਿਆਰਥੀ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏽‍🎓' => 'ਸਿਖਿਆਰਥੀ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏾‍🎓' => 'ਸਿਖਿਆਰਥੀ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🧑🏿‍🎓' => 'ਸਿਖਿਆਰਥੀ: ਕਾਲਾ ਰੰਗ',
    '👨🏻‍🎓' => 'مرد طالب علم: ہلکی رنگت آلی جلد',
    '👨🏼‍🎓' => 'مرد طالب علم: ہلکی درمیانی رنگت آلی جلد',
    '👨🏽‍🎓' => 'مرد طالب علم: درمیانی رنگت آلی جلد',
    '👨🏾‍🎓' => 'مرد طالب علم: درمیانی کالی رنگت آلی جلد',
    '👨🏿‍🎓' => 'مرد طالب علم: کالی رنگت آلی جلد',
    '👩🏻‍🎓' => 'طالبہ: ہلکی رنگت آلی جلد',
    '👩🏼‍🎓' => 'طالبہ: ہلکی درمیانی رنگت آلی جلد',
    '👩🏽‍🎓' => 'طالبہ: درمیانی رنگت آلی جلد',
    '👩🏾‍🎓' => 'طالبہ: درمیانی کالی رنگت آلی جلد',
    '👩🏿‍🎓' => 'طالبہ: کالی رنگت آلی جلد',
    '🧑🏻‍🏫' => 'ਸਿੱਖਿਅਕ: ਗੋਰਾ ਰੰਗ',
    '🧑🏼‍🏫' => 'ਸਿੱਖਿਅਕ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏽‍🏫' => 'ਸਿੱਖਿਅਕ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏾‍🏫' => 'ਸਿੱਖਿਅਕ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🧑🏿‍🏫' => 'ਸਿੱਖਿਅਕ: ਕਾਲਾ ਰੰਗ',
    '👨🏻‍🏫' => 'مرد استاد: ہلکی رنگت آلی جلد',
    '👨🏼‍🏫' => 'مرد استاد: ہلکی درمیانی رنگت آلی جلد',
    '👨🏽‍🏫' => 'مرد استاد: درمیانی رنگت آلی جلد',
    '👨🏾‍🏫' => 'مرد استاد: درمیانی کالی رنگت آلی جلد',
    '👨🏿‍🏫' => 'مرد استاد: کالی رنگت آلی جلد',
    '👩🏻‍🏫' => 'زنانہ استانی: ہلکی رنگت آلی جلد',
    '👩🏼‍🏫' => 'زنانہ استانی: ہلکی درمیانی رنگت آلی جلد',
    '👩🏽‍🏫' => 'زنانہ استانی: درمیانی رنگت آلی جلد',
    '👩🏾‍🏫' => 'زنانہ استانی: درمیانی کالی رنگت آلی جلد',
    '👩🏿‍🏫' => 'زنانہ استانی: کالی رنگت آلی جلد',
    '🧑🏻‍⚖' => 'ਜੱਜ: ਗੋਰਾ ਰੰਗ',
    '🧑🏼‍⚖' => 'ਜੱਜ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏽‍⚖' => 'ਜੱਜ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏾‍⚖' => 'ਜੱਜ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🧑🏿‍⚖' => 'ਜੱਜ: ਕਾਲਾ ਰੰਗ',
    '👨🏻‍⚖' => 'مرد جج: ہلکی رنگت آلی جلد',
    '👨🏼‍⚖' => 'مرد جج: ہلکی درمیانی رنگت آلی جلد',
    '👨🏽‍⚖' => 'مرد جج: درمیانی رنگت آلی جلد',
    '👨🏾‍⚖' => 'مرد جج: درمیانی کالی رنگت آلی جلد',
    '👨🏿‍⚖' => 'مرد جج: کالی رنگت آلی جلد',
    '👩🏻‍⚖' => 'جج زنانی: ہلکی رنگت آلی جلد',
    '👩🏼‍⚖' => 'جج زنانی: ہلکی درمیانی رنگت آلی جلد',
    '👩🏽‍⚖' => 'جج زنانی: درمیانی رنگت آلی جلد',
    '👩🏾‍⚖' => 'جج زنانی: درمیانی کالی رنگت آلی جلد',
    '👩🏿‍⚖' => 'جج زنانی: کالی رنگت آلی جلد',
    '🧑🏻‍🌾' => 'ਕਿਸਾਨ: ਗੋਰਾ ਰੰਗ',
    '🧑🏼‍🌾' => 'ਕਿਸਾਨ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏽‍🌾' => 'ਕਿਸਾਨ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏾‍🌾' => 'ਕਿਸਾਨ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🧑🏿‍🌾' => 'ਕਿਸਾਨ: ਕਾਲਾ ਰੰਗ',
    '👨🏻‍🌾' => 'مرد کسان: ہلکی رنگت آلی جلد',
    '👨🏼‍🌾' => 'مرد کسان: ہلکی درمیانی رنگت آلی جلد',
    '👨🏽‍🌾' => 'مرد کسان: درمیانی رنگت آلی جلد',
    '👨🏾‍🌾' => 'مرد کسان: درمیانی کالی رنگت آلی جلد',
    '👨🏿‍🌾' => 'مرد کسان: کالی رنگت آلی جلد',
    '👩🏻‍🌾' => 'زنانی کسان: ہلکی رنگت آلی جلد',
    '👩🏼‍🌾' => 'زنانی کسان: ہلکی درمیانی رنگت آلی جلد',
    '👩🏽‍🌾' => 'زنانی کسان: درمیانی رنگت آلی جلد',
    '👩🏾‍🌾' => 'زنانی کسان: درمیانی کالی رنگت آلی جلد',
    '👩🏿‍🌾' => 'زنانی کسان: کالی رنگت آلی جلد',
    '🧑🏻‍🍳' => 'ਲਾਂਗਰੀ: ਗੋਰਾ ਰੰਗ',
    '🧑🏼‍🍳' => 'ਲਾਂਗਰੀ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏽‍🍳' => 'ਲਾਂਗਰੀ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏾‍🍳' => 'ਲਾਂਗਰੀ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🧑🏿‍🍳' => 'ਲਾਂਗਰੀ: ਕਾਲਾ ਰੰਗ',
    '👨🏻‍🍳' => 'کھانا پکان آلا بندہ: ہلکی رنگت آلی جلد',
    '👨🏼‍🍳' => 'کھانا پکان آلا بندہ: ہلکی درمیانی رنگت آلی جلد',
    '👨🏽‍🍳' => 'کھانا پکان آلا بندہ: درمیانی رنگت آلی جلد',
    '👨🏾‍🍳' => 'کھانا پکان آلا بندہ: درمیانی کالی رنگت آلی جلد',
    '👨🏿‍🍳' => 'کھانا پکان آلا بندہ: کالی رنگت آلی جلد',
    '👩🏻‍🍳' => 'کھانا پکان آلی زنانی: ہلکی رنگت آلی جلد',
    '👩🏼‍🍳' => 'کھانا پکان آلی زنانی: ہلکی درمیانی رنگت آلی جلد',
    '👩🏽‍🍳' => 'کھانا پکان آلی زنانی: درمیانی رنگت آلی جلد',
    '👩🏾‍🍳' => 'کھانا پکان آلی زنانی: درمیانی کالی رنگت آلی جلد',
    '👩🏿‍🍳' => 'کھانا پکان آلی زنانی: کالی رنگت آلی جلد',
    '🧑🏻‍🔧' => 'ਮਸ਼ੀਨਸਾਜ਼: ਗੋਰਾ ਰੰਗ',
    '🧑🏼‍🔧' => 'ਮਸ਼ੀਨਸਾਜ਼: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏽‍🔧' => 'ਮਸ਼ੀਨਸਾਜ਼: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏾‍🔧' => 'ਮਸ਼ੀਨਸਾਜ਼: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🧑🏿‍🔧' => 'ਮਸ਼ੀਨਸਾਜ਼: ਕਾਲਾ ਰੰਗ',
    '👨🏻‍🔧' => 'مرد مکینک: ہلکی رنگت آلی جلد',
    '👨🏼‍🔧' => 'مرد مکینک: ہلکی درمیانی رنگت آلی جلد',
    '👨🏽‍🔧' => 'مرد مکینک: درمیانی رنگت آلی جلد',
    '👨🏾‍🔧' => 'مرد مکینک: درمیانی کالی رنگت آلی جلد',
    '👨🏿‍🔧' => 'مرد مکینک: کالی رنگت آلی جلد',
    '👩🏻‍🔧' => 'مکینک زنانی: ہلکی رنگت آلی جلد',
    '👩🏼‍🔧' => 'مکینک زنانی: ہلکی درمیانی رنگت آلی جلد',
    '👩🏽‍🔧' => 'مکینک زنانی: درمیانی رنگت آلی جلد',
    '👩🏾‍🔧' => 'مکینک زنانی: درمیانی کالی رنگت آلی جلد',
    '👩🏿‍🔧' => 'مکینک زنانی: کالی رنگت آلی جلد',
    '🧑🏻‍🏭' => 'ਕਾਰਖਾਨਾ ਮਜ਼ਦੂਰ: ਗੋਰਾ ਰੰਗ',
    '🧑🏼‍🏭' => 'ਕਾਰਖਾਨਾ ਮਜ਼ਦੂਰ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏽‍🏭' => 'ਕਾਰਖਾਨਾ ਮਜ਼ਦੂਰ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏾‍🏭' => 'ਕਾਰਖਾਨਾ ਮਜ਼ਦੂਰ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🧑🏿‍🏭' => 'ਕਾਰਖਾਨਾ ਮਜ਼ਦੂਰ: ਕਾਲਾ ਰੰਗ',
    '👨🏻‍🏭' => 'فیکٹری وچ کم کرن آلا بندہ: ہلکی رنگت آلی جلد',
    '👨🏼‍🏭' => 'فیکٹری وچ کم کرن آلا بندہ: ہلکی درمیانی رنگت آلی جلد',
    '👨🏽‍🏭' => 'فیکٹری وچ کم کرن آلا بندہ: درمیانی رنگت آلی جلد',
    '👨🏾‍🏭' => 'فیکٹری وچ کم کرن آلا بندہ: درمیانی کالی رنگت آلی جلد',
    '👨🏿‍🏭' => 'فیکٹری وچ کم کرن آلا بندہ: کالی رنگت آلی جلد',
    '👩🏻‍🏭' => 'فیکٹری وچ کم کرن آلی زنانی: ہلکی رنگت آلی جلد',
    '👩🏼‍🏭' => 'فیکٹری وچ کم کرن آلی زنانی: ہلکی درمیانی رنگت آلی جلد',
    '👩🏽‍🏭' => 'فیکٹری وچ کم کرن آلی زنانی: درمیانی رنگت آلی جلد',
    '👩🏾‍🏭' => 'فیکٹری وچ کم کرن آلی زنانی: درمیانی کالی رنگت آلی جلد',
    '👩🏿‍🏭' => 'فیکٹری وچ کم کرن آلی زنانی: کالی رنگت آلی جلد',
    '🧑🏻‍💼' => 'ਦਫ਼ਤਰ ਕਰਮਚਾਰੀ: ਗੋਰਾ ਰੰਗ',
    '🧑🏼‍💼' => 'ਦਫ਼ਤਰ ਕਰਮਚਾਰੀ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏽‍💼' => 'ਦਫ਼ਤਰ ਕਰਮਚਾਰੀ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏾‍💼' => 'ਦਫ਼ਤਰ ਕਰਮਚਾਰੀ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🧑🏿‍💼' => 'ਦਫ਼ਤਰ ਕਰਮਚਾਰੀ: ਕਾਲਾ ਰੰਗ',
    '👨🏻‍💼' => 'دفتر وچ کم کرن آلا مرد: ہلکی رنگت آلی جلد',
    '👨🏼‍💼' => 'دفتر وچ کم کرن آلا مرد: ہلکی درمیانی رنگت آلی جلد',
    '👨🏽‍💼' => 'دفتر وچ کم کرن آلا مرد: درمیانی رنگت آلی جلد',
    '👨🏾‍💼' => 'دفتر وچ کم کرن آلا مرد: درمیانی کالی رنگت آلی جلد',
    '👨🏿‍💼' => 'دفتر وچ کم کرن آلا مرد: کالی رنگت آلی جلد',
    '👩🏻‍💼' => 'دفتر وچ کم کرن آلی زنانی: ہلکی رنگت آلی جلد',
    '👩🏼‍💼' => 'دفتر وچ کم کرن آلی زنانی: ہلکی درمیانی رنگت آلی جلد',
    '👩🏽‍💼' => 'دفتر وچ کم کرن آلی زنانی: درمیانی رنگت آلی جلد',
    '👩🏾‍💼' => 'دفتر وچ کم کرن آلی زنانی: درمیانی کالی رنگت آلی جلد',
    '👩🏿‍💼' => 'دفتر وچ کم کرن آلی زنانی: کالی رنگت آلی جلد',
    '🧑🏻‍🔬' => 'ਵਿਗਿਆਨੀ: ਗੋਰਾ ਰੰਗ',
    '🧑🏼‍🔬' => 'ਵਿਗਿਆਨੀ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏽‍🔬' => 'ਵਿਗਿਆਨੀ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏾‍🔬' => 'ਵਿਗਿਆਨੀ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🧑🏿‍🔬' => 'ਵਿਗਿਆਨੀ: ਕਾਲਾ ਰੰਗ',
    '👨🏻‍🔬' => 'مرد سائنسدان: ہلکی رنگت آلی جلد',
    '👨🏼‍🔬' => 'مرد سائنسدان: ہلکی درمیانی رنگت آلی جلد',
    '👨🏽‍🔬' => 'مرد سائنسدان: درمیانی رنگت آلی جلد',
    '👨🏾‍🔬' => 'مرد سائنسدان: درمیانی کالی رنگت آلی جلد',
    '👨🏿‍🔬' => 'مرد سائنسدان: کالی رنگت آلی جلد',
    '👩🏻‍🔬' => 'سائنسدان زنانی: ہلکی رنگت آلی جلد',
    '👩🏼‍🔬' => 'سائنسدان زنانی: ہلکی درمیانی رنگت آلی جلد',
    '👩🏽‍🔬' => 'سائنسدان زنانی: درمیانی رنگت آلی جلد',
    '👩🏾‍🔬' => 'سائنسدان زنانی: درمیانی کالی رنگت آلی جلد',
    '👩🏿‍🔬' => 'سائنسدان زنانی: کالی رنگت آلی جلد',
    '🧑🏻‍💻' => 'ਟੈਕਨੋਲੋਜਿਸਟ: ਗੋਰਾ ਰੰਗ',
    '🧑🏼‍💻' => 'ਟੈਕਨੋਲੋਜਿਸਟ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏽‍💻' => 'ਟੈਕਨੋਲੋਜਿਸਟ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏾‍💻' => 'ਟੈਕਨੋਲੋਜਿਸਟ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🧑🏿‍💻' => 'ਟੈਕਨੋਲੋਜਿਸਟ: ਕਾਲਾ ਰੰਗ',
    '👨🏻‍💻' => 'تکنیک دان بندہ: ہلکی رنگت آلی جلد',
    '👨🏼‍💻' => 'تکنیک دان بندہ: ہلکی درمیانی رنگت آلی جلد',
    '👨🏽‍💻' => 'تکنیک دان بندہ: درمیانی رنگت آلی جلد',
    '👨🏾‍💻' => 'تکنیک دان بندہ: درمیانی کالی رنگت آلی جلد',
    '👨🏿‍💻' => 'تکنیک دان بندہ: کالی رنگت آلی جلد',
    '👩🏻‍💻' => 'تکنیک دان زنانی: ہلکی رنگت آلی جلد',
    '👩🏼‍💻' => 'تکنیک دان زنانی: ہلکی درمیانی رنگت آلی جلد',
    '👩🏽‍💻' => 'تکنیک دان زنانی: درمیانی رنگت آلی جلد',
    '👩🏾‍💻' => 'تکنیک دان زنانی: درمیانی کالی رنگت آلی جلد',
    '👩🏿‍💻' => 'تکنیک دان زنانی: کالی رنگت آلی جلد',
    '🧑🏻‍🎤' => 'ਗਵੱਈਆ: ਗੋਰਾ ਰੰਗ',
    '🧑🏼‍🎤' => 'ਗਵੱਈਆ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏽‍🎤' => 'ਗਵੱਈਆ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏾‍🎤' => 'ਗਵੱਈਆ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🧑🏿‍🎤' => 'ਗਵੱਈਆ: ਕਾਲਾ ਰੰਗ',
    '👨🏻‍🎤' => 'گلوکار: ہلکی رنگت آلی جلد',
    '👨🏼‍🎤' => 'گلوکار: ہلکی درمیانی رنگت آلی جلد',
    '👨🏽‍🎤' => 'گلوکار: درمیانی رنگت آلی جلد',
    '👨🏾‍🎤' => 'گلوکار: درمیانی کالی رنگت آلی جلد',
    '👨🏿‍🎤' => 'گلوکار: کالی رنگت آلی جلد',
    '👩🏻‍🎤' => 'گلوکارہ: ہلکی رنگت آلی جلد',
    '👩🏼‍🎤' => 'گلوکارہ: ہلکی درمیانی رنگت آلی جلد',
    '👩🏽‍🎤' => 'گلوکارہ: درمیانی رنگت آلی جلد',
    '👩🏾‍🎤' => 'گلوکارہ: درمیانی کالی رنگت آلی جلد',
    '👩🏿‍🎤' => 'گلوکارہ: کالی رنگت آلی جلد',
    '🧑🏻‍🎨' => 'ਚਿੱਤਰਕਾਰ: ਗੋਰਾ ਰੰਗ',
    '🧑🏼‍🎨' => 'ਚਿੱਤਰਕਾਰ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏽‍🎨' => 'ਚਿੱਤਰਕਾਰ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏾‍🎨' => 'ਚਿੱਤਰਕਾਰ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🧑🏿‍🎨' => 'ਚਿੱਤਰਕਾਰ: ਕਾਲਾ ਰੰਗ',
    '👨🏻‍🎨' => 'مرد فنکار: ہلکی رنگت آلی جلد',
    '👨🏼‍🎨' => 'مرد فنکار: ہلکی درمیانی رنگت آلی جلد',
    '👨🏽‍🎨' => 'مرد فنکار: درمیانی رنگت آلی جلد',
    '👨🏾‍🎨' => 'مرد فنکار: درمیانی کالی رنگت آلی جلد',
    '👨🏿‍🎨' => 'مرد فنکار: کالی رنگت آلی جلد',
    '👩🏻‍🎨' => 'فنکار زنانی: ہلکی رنگت آلی جلد',
    '👩🏼‍🎨' => 'فنکار زنانی: ہلکی درمیانی رنگت آلی جلد',
    '👩🏽‍🎨' => 'فنکار زنانی: درمیانی رنگت آلی جلد',
    '👩🏾‍🎨' => 'فنکار زنانی: درمیانی کالی رنگت آلی جلد',
    '👩🏿‍🎨' => 'فنکار زنانی: کالی رنگت آلی جلد',
    '🧑🏻‍✈' => 'ਹਵਾਈ ਜਹਾਜ਼ ਚਾਲਕ: ਗੋਰਾ ਰੰਗ',
    '🧑🏼‍✈' => 'ਹਵਾਈ ਜਹਾਜ਼ ਚਾਲਕ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏽‍✈' => 'ਹਵਾਈ ਜਹਾਜ਼ ਚਾਲਕ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏾‍✈' => 'ਹਵਾਈ ਜਹਾਜ਼ ਚਾਲਕ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🧑🏿‍✈' => 'ਹਵਾਈ ਜਹਾਜ਼ ਚਾਲਕ: ਕਾਲਾ ਰੰਗ',
    '👨🏻‍✈' => 'مرد پائلٹ: ہلکی رنگت آلی جلد',
    '👨🏼‍✈' => 'مرد پائلٹ: ہلکی درمیانی رنگت آلی جلد',
    '👨🏽‍✈' => 'مرد پائلٹ: درمیانی رنگت آلی جلد',
    '👨🏾‍✈' => 'مرد پائلٹ: درمیانی کالی رنگت آلی جلد',
    '👨🏿‍✈' => 'مرد پائلٹ: کالی رنگت آلی جلد',
    '👩🏻‍✈' => 'زنانی پائلٹ: ہلکی رنگت آلی جلد',
    '👩🏼‍✈' => 'زنانی پائلٹ: ہلکی درمیانی رنگت آلی جلد',
    '👩🏽‍✈' => 'زنانی پائلٹ: درمیانی رنگت آلی جلد',
    '👩🏾‍✈' => 'زنانی پائلٹ: درمیانی کالی رنگت آلی جلد',
    '👩🏿‍✈' => 'زنانی پائلٹ: کالی رنگت آلی جلد',
    '🧑🏻‍🚀' => 'ਪੁਲਾੜ ਯਾਤਰੀ: ਗੋਰਾ ਰੰਗ',
    '🧑🏼‍🚀' => 'ਪੁਲਾੜ ਯਾਤਰੀ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏽‍🚀' => 'ਪੁਲਾੜ ਯਾਤਰੀ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏾‍🚀' => 'ਪੁਲਾੜ ਯਾਤਰੀ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🧑🏿‍🚀' => 'ਪੁਲਾੜ ਯਾਤਰੀ: ਕਾਲਾ ਰੰਗ',
    '👨🏻‍🚀' => 'مرد خلاء باز: ہلکی رنگت آلی جلد',
    '👨🏼‍🚀' => 'مرد خلاء باز: ہلکی درمیانی رنگت آلی جلد',
    '👨🏽‍🚀' => 'مرد خلاء باز: درمیانی رنگت آلی جلد',
    '👨🏾‍🚀' => 'مرد خلاء باز: درمیانی کالی رنگت آلی جلد',
    '👨🏿‍🚀' => 'مرد خلاء باز: کالی رنگت آلی جلد',
    '👩🏻‍🚀' => 'خلاء باز زنانی: ہلکی رنگت آلی جلد',
    '👩🏼‍🚀' => 'خلاء باز زنانی: ہلکی درمیانی رنگت آلی جلد',
    '👩🏽‍🚀' => 'خلاء باز زنانی: درمیانی رنگت آلی جلد',
    '👩🏾‍🚀' => 'خلاء باز زنانی: درمیانی کالی رنگت آلی جلد',
    '👩🏿‍🚀' => 'خلاء باز زنانی: کالی رنگت آلی جلد',
    '🧑🏻‍🚒' => 'ਫਾਇਰਫਾਈਟਰ: ਗੋਰਾ ਰੰਗ',
    '🧑🏼‍🚒' => 'ਫਾਇਰਫਾਈਟਰ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏽‍🚒' => 'ਫਾਇਰਫਾਈਟਰ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏾‍🚒' => 'ਫਾਇਰਫਾਈਟਰ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🧑🏿‍🚒' => 'ਫਾਇਰਫਾਈਟਰ: ਕਾਲਾ ਰੰਗ',
    '👨🏻‍🚒' => 'آگ بجھان آلا بندہ: ہلکی رنگت آلی جلد',
    '👨🏼‍🚒' => 'آگ بجھان آلا بندہ: ہلکی درمیانی رنگت آلی جلد',
    '👨🏽‍🚒' => 'آگ بجھان آلا بندہ: درمیانی رنگت آلی جلد',
    '👨🏾‍🚒' => 'آگ بجھان آلا بندہ: درمیانی کالی رنگت آلی جلد',
    '👨🏿‍🚒' => 'آگ بجھان آلا بندہ: کالی رنگت آلی جلد',
    '👩🏻‍🚒' => 'آگ بجان آلی زنانی: ہلکی رنگت آلی جلد',
    '👩🏼‍🚒' => 'آگ بجان آلی زنانی: ہلکی درمیانی رنگت آلی جلد',
    '👩🏽‍🚒' => 'آگ بجان آلی زنانی: درمیانی رنگت آلی جلد',
    '👩🏾‍🚒' => 'آگ بجان آلی زنانی: درمیانی کالی رنگت آلی جلد',
    '👩🏿‍🚒' => 'آگ بجان آلی زنانی: کالی رنگت آلی جلد',
    '👮🏻‍♂' => 'پُلس آفسر بندہ: ہلکی رنگت آلی جلد',
    '👮🏼‍♂' => 'پُلس آفسر بندہ: ہلکی درمیانی رنگت آلی جلد',
    '👮🏽‍♂' => 'پُلس آفسر بندہ: درمیانی رنگت آلی جلد',
    '👮🏾‍♂' => 'پُلس آفسر بندہ: درمیانی کالی رنگت آلی جلد',
    '👮🏿‍♂' => 'پُلس آفسر بندہ: کالی رنگت آلی جلد',
    '👮🏻‍♀' => 'پُلس آفسر زنانی: ہلکی رنگت آلی جلد',
    '👮🏼‍♀' => 'پُلس آفسر زنانی: ہلکی درمیانی رنگت آلی جلد',
    '👮🏽‍♀' => 'پُلس آفسر زنانی: درمیانی رنگت آلی جلد',
    '👮🏾‍♀' => 'پُلس آفسر زنانی: درمیانی کالی رنگت آلی جلد',
    '👮🏿‍♀' => 'پُلس آفسر زنانی: کالی رنگت آلی جلد',
    '🕵🏻‍♂' => 'جاسوس بندہ: ہلکی رنگت آلی جلد',
    '🕵🏼‍♂' => 'جاسوس بندہ: ہلکی درمیانی رنگت آلی جلد',
    '🕵🏽‍♂' => 'جاسوس بندہ: درمیانی رنگت آلی جلد',
    '🕵🏾‍♂' => 'جاسوس بندہ: درمیانی کالی رنگت آلی جلد',
    '🕵🏿‍♂' => 'جاسوس بندہ: کالی رنگت آلی جلد',
    '🕵🏻‍♀' => 'جاسوس زنانی: ہلکی رنگت آلی جلد',
    '🕵🏼‍♀' => 'جاسوس زنانی: ہلکی درمیانی رنگت آلی جلد',
    '🕵🏽‍♀' => 'جاسوس زنانی: درمیانی رنگت آلی جلد',
    '🕵🏾‍♀' => 'جاسوس زنانی: درمیانی کالی رنگت آلی جلد',
    '🕵🏿‍♀' => 'جاسوس زنانی: کالی رنگت آلی جلد',
    '💂🏻‍♂' => 'چوکیدار بندہ: ہلکی رنگت آلی جلد',
    '💂🏼‍♂' => 'چوکیدار بندہ: ہلکی درمیانی رنگت آلی جلد',
    '💂🏽‍♂' => 'چوکیدار بندہ: درمیانی رنگت آلی جلد',
    '💂🏾‍♂' => 'چوکیدار بندہ: درمیانی کالی رنگت آلی جلد',
    '💂🏿‍♂' => 'چوکیدار بندہ: کالی رنگت آلی جلد',
    '💂🏻‍♀' => 'چوکیدار زنانی: ہلکی رنگت آلی جلد',
    '💂🏼‍♀' => 'چوکیدار زنانی: ہلکی درمیانی رنگت آلی جلد',
    '💂🏽‍♀' => 'چوکیدار زنانی: درمیانی رنگت آلی جلد',
    '💂🏾‍♀' => 'چوکیدار زنانی: درمیانی کالی رنگت آلی جلد',
    '💂🏿‍♀' => 'چوکیدار زنانی: کالی رنگت آلی جلد',
    '👷🏻‍♂' => 'تعمیری کم کرن آلا بندہ: ہلکی رنگت آلی جلد',
    '👷🏼‍♂' => 'تعمیری کم کرن آلا بندہ: ہلکی درمیانی رنگت آلی جلد',
    '👷🏽‍♂' => 'تعمیری کم کرن آلا بندہ: درمیانی رنگت آلی جلد',
    '👷🏾‍♂' => 'تعمیری کم کرن آلا بندہ: درمیانی کالی رنگت آلی جلد',
    '👷🏿‍♂' => 'تعمیری کم کرن آلا بندہ: کالی رنگت آلی جلد',
    '👷🏻‍♀' => 'تعمیری کم کرن آلی زنانی: ہلکی رنگت آلی جلد',
    '👷🏼‍♀' => 'تعمیری کم کرن آلی زنانی: ہلکی درمیانی رنگت آلی جلد',
    '👷🏽‍♀' => 'تعمیری کم کرن آلی زنانی: درمیانی رنگت آلی جلد',
    '👷🏾‍♀' => 'تعمیری کم کرن آلی زنانی: درمیانی کالی رنگت آلی جلد',
    '👷🏿‍♀' => 'تعمیری کم کرن آلی زنانی: کالی رنگت آلی جلد',
    '👳🏻‍♂' => 'پگڑی پاندا بندا: ہلکی رنگت آلی جلد',
    '👳🏼‍♂' => 'پگڑی پاندا بندا: ہلکی درمیانی رنگت آلی جلد',
    '👳🏽‍♂' => 'پگڑی پاندا بندا: درمیانی رنگت آلی جلد',
    '👳🏾‍♂' => 'پگڑی پاندا بندا: درمیانی کالی رنگت آلی جلد',
    '👳🏿‍♂' => 'پگڑی پاندا بندا: کالی رنگت آلی جلد',
    '👳🏻‍♀' => 'پگڑی پاندی زنانی: ہلکی رنگت آلی جلد',
    '👳🏼‍♀' => 'پگڑی پاندی زنانی: ہلکی درمیانی رنگت آلی جلد',
    '👳🏽‍♀' => 'پگڑی پاندی زنانی: درمیانی رنگت آلی جلد',
    '👳🏾‍♀' => 'پگڑی پاندی زنانی: درمیانی کالی رنگت آلی جلد',
    '👳🏿‍♀' => 'پگڑی پاندی زنانی: کالی رنگت آلی جلد',
    '🤵🏻‍♂' => 'ਬਣਿਆ-ਠਣਿਆ ਆਦਮੀ: ਗੋਰਾ ਰੰਗ',
    '🤵🏼‍♂' => 'ਬਣਿਆ-ਠਣਿਆ ਆਦਮੀ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🤵🏽‍♂' => 'ਬਣਿਆ-ਠਣਿਆ ਆਦਮੀ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🤵🏾‍♂' => 'ਬਣਿਆ-ਠਣਿਆ ਆਦਮੀ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🤵🏿‍♂' => 'ਬਣਿਆ-ਠਣਿਆ ਆਦਮੀ: ਕਾਲਾ ਰੰਗ',
    '🤵🏻‍♀' => 'ਬਣੀ ਠਣੀ ਔਰਤ: ਗੋਰਾ ਰੰਗ',
    '🤵🏼‍♀' => 'ਬਣੀ ਠਣੀ ਔਰਤ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🤵🏽‍♀' => 'ਬਣੀ ਠਣੀ ਔਰਤ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🤵🏾‍♀' => 'ਬਣੀ ਠਣੀ ਔਰਤ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🤵🏿‍♀' => 'ਬਣੀ ਠਣੀ ਔਰਤ: ਕਾਲਾ ਰੰਗ',
    '👰🏻‍♂' => 'ਘੁੰਡ ਵਿੱਚ ਆਦਮੀ: ਗੋਰਾ ਰੰਗ',
    '👰🏼‍♂' => 'ਘੁੰਡ ਵਿੱਚ ਆਦਮੀ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '👰🏽‍♂' => 'ਘੁੰਡ ਵਿੱਚ ਆਦਮੀ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '👰🏾‍♂' => 'ਘੁੰਡ ਵਿੱਚ ਆਦਮੀ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '👰🏿‍♂' => 'ਘੁੰਡ ਵਿੱਚ ਆਦਮੀ: ਕਾਲਾ ਰੰਗ',
    '👰🏻‍♀' => 'ਘੁੰਡ ਵਿੱਚ ਔਰਤ: ਗੋਰਾ ਰੰਗ',
    '👰🏼‍♀' => 'ਘੁੰਡ ਵਿੱਚ ਔਰਤ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '👰🏽‍♀' => 'ਘੁੰਡ ਵਿੱਚ ਔਰਤ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '👰🏾‍♀' => 'ਘੁੰਡ ਵਿੱਚ ਔਰਤ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '👰🏿‍♀' => 'ਘੁੰਡ ਵਿੱਚ ਔਰਤ: ਕਾਲਾ ਰੰਗ',
    '👩🏻‍🍼' => 'ਬੱਚੇ ਨੂੰ ਦੁੱਧ ਚੁੰਘਾਉਂਦੀ ਔਰਤ: ਗੋਰਾ ਰੰਗ',
    '👩🏼‍🍼' => 'ਬੱਚੇ ਨੂੰ ਦੁੱਧ ਚੁੰਘਾਉਂਦੀ ਔਰਤ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '👩🏽‍🍼' => 'ਬੱਚੇ ਨੂੰ ਦੁੱਧ ਚੁੰਘਾਉਂਦੀ ਔਰਤ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '👩🏾‍🍼' => 'ਬੱਚੇ ਨੂੰ ਦੁੱਧ ਚੁੰਘਾਉਂਦੀ ਔਰਤ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '👩🏿‍🍼' => 'ਬੱਚੇ ਨੂੰ ਦੁੱਧ ਚੁੰਘਾਉਂਦੀ ਔਰਤ: ਕਾਲਾ ਰੰਗ',
    '👨🏻‍🍼' => 'ਬੱਚੇ ਨੂੰ ਦੁੱਧ ਪਿਲਾਉਂਦਾ ਆਦਮੀ: ਗੋਰਾ ਰੰਗ',
    '👨🏼‍🍼' => 'ਬੱਚੇ ਨੂੰ ਦੁੱਧ ਪਿਲਾਉਂਦਾ ਆਦਮੀ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '👨🏽‍🍼' => 'ਬੱਚੇ ਨੂੰ ਦੁੱਧ ਪਿਲਾਉਂਦਾ ਆਦਮੀ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '👨🏾‍🍼' => 'ਬੱਚੇ ਨੂੰ ਦੁੱਧ ਪਿਲਾਉਂਦਾ ਆਦਮੀ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '👨🏿‍🍼' => 'ਬੱਚੇ ਨੂੰ ਦੁੱਧ ਪਿਲਾਉਂਦਾ ਆਦਮੀ: ਕਾਲਾ ਰੰਗ',
    '🧑🏻‍🍼' => 'ਬੱਚੇ ਨੂੰ ਦੁੱਧ ਪਿਲਾਉਂਦਾ ਵਿਅਕਤੀ: ਗੋਰਾ ਰੰਗ',
    '🧑🏼‍🍼' => 'ਬੱਚੇ ਨੂੰ ਦੁੱਧ ਪਿਲਾਉਂਦਾ ਵਿਅਕਤੀ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏽‍🍼' => 'ਬੱਚੇ ਨੂੰ ਦੁੱਧ ਪਿਲਾਉਂਦਾ ਵਿਅਕਤੀ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏾‍🍼' => 'ਬੱਚੇ ਨੂੰ ਦੁੱਧ ਪਿਲਾਉਂਦਾ ਵਿਅਕਤੀ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🧑🏿‍🍼' => 'ਬੱਚੇ ਨੂੰ ਦੁੱਧ ਪਿਲਾਉਂਦਾ ਵਿਅਕਤੀ: ਕਾਲਾ ਰੰਗ',
    '🧑🏻‍🎄' => 'ਐਮਐਕਸ ਕਲਾਜ਼: ਗੋਰਾ ਰੰਗ',
    '🧑🏼‍🎄' => 'ਐਮਐਕਸ ਕਲਾਜ਼: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏽‍🎄' => 'ਐਮਐਕਸ ਕਲਾਜ਼: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏾‍🎄' => 'ਐਮਐਕਸ ਕਲਾਜ਼: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🧑🏿‍🎄' => 'ਐਮਐਕਸ ਕਲਾਜ਼: ਕਾਲਾ ਰੰਗ',
    '🦸🏻‍♂' => 'ਪੁਰਸ਼ ਸੁਪਰਹੀਰੋ: ਗੋਰਾ ਰੰਗ',
    '🦸🏼‍♂' => 'ਪੁਰਸ਼ ਸੁਪਰਹੀਰੋ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🦸🏽‍♂' => 'ਪੁਰਸ਼ ਸੁਪਰਹੀਰੋ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🦸🏾‍♂' => 'ਪੁਰਸ਼ ਸੁਪਰਹੀਰੋ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🦸🏿‍♂' => 'ਪੁਰਸ਼ ਸੁਪਰਹੀਰੋ: ਕਾਲਾ ਰੰਗ',
    '🦸🏻‍♀' => 'ਇਸਤਰੀ ਸੁਪਰਹੀਰੋ: ਗੋਰਾ ਰੰਗ',
    '🦸🏼‍♀' => 'ਇਸਤਰੀ ਸੁਪਰਹੀਰੋ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🦸🏽‍♀' => 'ਇਸਤਰੀ ਸੁਪਰਹੀਰੋ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🦸🏾‍♀' => 'ਇਸਤਰੀ ਸੁਪਰਹੀਰੋ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🦸🏿‍♀' => 'ਇਸਤਰੀ ਸੁਪਰਹੀਰੋ: ਕਾਲਾ ਰੰਗ',
    '🦹🏻‍♂' => 'ਪੁਰਸ਼ ਮਹਾਂ-ਖਲਨਾਇਕ: ਗੋਰਾ ਰੰਗ',
    '🦹🏼‍♂' => 'ਪੁਰਸ਼ ਮਹਾਂ-ਖਲਨਾਇਕ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🦹🏽‍♂' => 'ਪੁਰਸ਼ ਮਹਾਂ-ਖਲਨਾਇਕ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🦹🏾‍♂' => 'ਪੁਰਸ਼ ਮਹਾਂ-ਖਲਨਾਇਕ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🦹🏿‍♂' => 'ਪੁਰਸ਼ ਮਹਾਂ-ਖਲਨਾਇਕ: ਕਾਲਾ ਰੰਗ',
    '🦹🏻‍♀' => 'ਇਸਤਰੀ ਮਹਾਂ-ਖਲਨਾਇਕ: ਗੋਰਾ ਰੰਗ',
    '🦹🏼‍♀' => 'ਇਸਤਰੀ ਮਹਾਂ-ਖਲਨਾਇਕ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🦹🏽‍♀' => 'ਇਸਤਰੀ ਮਹਾਂ-ਖਲਨਾਇਕ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🦹🏾‍♀' => 'ਇਸਤਰੀ ਮਹਾਂ-ਖਲਨਾਇਕ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🦹🏿‍♀' => 'ਇਸਤਰੀ ਮਹਾਂ-ਖਲਨਾਇਕ: ਕਾਲਾ ਰੰਗ',
    '🧙🏻‍♂' => 'جادوگر بندہ: ہلکی رنگت آلی جلد',
    '🧙🏼‍♂' => 'جادوگر بندہ: ہلکی درمیانی رنگت آلی جلد',
    '🧙🏽‍♂' => 'جادوگر بندہ: درمیانی رنگت آلی جلد',
    '🧙🏾‍♂' => 'جادوگر بندہ: درمیانی کالی رنگت آلی جلد',
    '🧙🏿‍♂' => 'جادوگر بندہ: کالی رنگت آلی جلد',
    '🧙🏻‍♀' => 'جادوگر زنانی: ہلکی رنگت آلی جلد',
    '🧙🏼‍♀' => 'جادوگر زنانی: ہلکی درمیانی رنگت آلی جلد',
    '🧙🏽‍♀' => 'جادوگر زنانی: درمیانی رنگت آلی جلد',
    '🧙🏾‍♀' => 'جادوگر زنانی: درمیانی کالی رنگت آلی جلد',
    '🧙🏿‍♀' => 'جادوگر زنانی: کالی رنگت آلی جلد',
    '🧚🏻‍♂' => 'فیری بندہ: ہلکی رنگت آلی جلد',
    '🧚🏼‍♂' => 'فیری بندہ: ہلکی درمیانی رنگت آلی جلد',
    '🧚🏽‍♂' => 'فیری بندہ: درمیانی رنگت آلی جلد',
    '🧚🏾‍♂' => 'فیری بندہ: درمیانی کالی رنگت آلی جلد',
    '🧚🏿‍♂' => 'فیری بندہ: کالی رنگت آلی جلد',
    '🧚🏻‍♀' => 'فیری زنانی: ہلکی رنگت آلی جلد',
    '🧚🏼‍♀' => 'فیری زنانی: ہلکی درمیانی رنگت آلی جلد',
    '🧚🏽‍♀' => 'فیری زنانی: درمیانی رنگت آلی جلد',
    '🧚🏾‍♀' => 'فیری زنانی: درمیانی کالی رنگت آلی جلد',
    '🧚🏿‍♀' => 'فیری زنانی: کالی رنگت آلی جلد',
    '🧛🏻‍♂' => 'خونخوار مرد: ہلکی رنگت آلی جلد',
    '🧛🏼‍♂' => 'خونخوار مرد: ہلکی درمیانی رنگت آلی جلد',
    '🧛🏽‍♂' => 'خونخوار مرد: درمیانی رنگت آلی جلد',
    '🧛🏾‍♂' => 'خونخوار مرد: درمیانی کالی رنگت آلی جلد',
    '🧛🏿‍♂' => 'خونخوار مرد: کالی رنگت آلی جلد',
    '🧛🏻‍♀' => 'خونخوار زنانی: ہلکی رنگت آلی جلد',
    '🧛🏼‍♀' => 'خونخوار زنانی: ہلکی درمیانی رنگت آلی جلد',
    '🧛🏽‍♀' => 'خونخوار زنانی: درمیانی رنگت آلی جلد',
    '🧛🏾‍♀' => 'خونخوار زنانی: درمیانی کالی رنگت آلی جلد',
    '🧛🏿‍♀' => 'خونخوار زنانی: کالی رنگت آلی جلد',
    '🧜🏻‍♂' => 'جل مانس: ہلکی رنگت آلی جلد',
    '🧜🏼‍♂' => 'جل مانس: ہلکی درمیانی رنگت آلی جلد',
    '🧜🏽‍♂' => 'جل مانس: درمیانی رنگت آلی جلد',
    '🧜🏾‍♂' => 'جل مانس: درمیانی کالی رنگت آلی جلد',
    '🧜🏿‍♂' => 'جل مانس: کالی رنگت آلی جلد',
    '🧜🏻‍♀' => 'ماہی زن: ہلکی رنگت آلی جلد',
    '🧜🏼‍♀' => 'ماہی زن: ہلکی درمیانی رنگت آلی جلد',
    '🧜🏽‍♀' => 'ماہی زن: درمیانی رنگت آلی جلد',
    '🧜🏾‍♀' => 'ماہی زن: درمیانی کالی رنگت آلی جلد',
    '🧜🏿‍♀' => 'ماہی زن: کالی رنگت آلی جلد',
    '🧝🏻‍♂' => 'بُھوت بندا: ہلکی رنگت آلی جلد',
    '🧝🏼‍♂' => 'بُھوت بندا: ہلکی درمیانی رنگت آلی جلد',
    '🧝🏽‍♂' => 'بُھوت بندا: درمیانی رنگت آلی جلد',
    '🧝🏾‍♂' => 'بُھوت بندا: درمیانی کالی رنگت آلی جلد',
    '🧝🏿‍♂' => 'بُھوت بندا: کالی رنگت آلی جلد',
    '🧝🏻‍♀' => 'بُھوت زنانی: ہلکی رنگت آلی جلد',
    '🧝🏼‍♀' => 'بُھوت زنانی: ہلکی درمیانی رنگت آلی جلد',
    '🧝🏽‍♀' => 'بُھوت زنانی: درمیانی رنگت آلی جلد',
    '🧝🏾‍♀' => 'بُھوت زنانی: درمیانی کالی رنگت آلی جلد',
    '🧝🏿‍♀' => 'بُھوت زنانی: کالی رنگت آلی جلد',
    '💆🏻‍♂' => 'پیغام لیندا مرد: ہلکی رنگت آلی جلد',
    '💆🏼‍♂' => 'پیغام لیندا مرد: ہلکی درمیانی رنگت آلی جلد',
    '💆🏽‍♂' => 'پیغام لیندا مرد: درمیانی رنگت آلی جلد',
    '💆🏾‍♂' => 'پیغام لیندا مرد: درمیانی کالی رنگت آلی جلد',
    '💆🏿‍♂' => 'پیغام لیندا مرد: کالی رنگت آلی جلد',
    '💆🏻‍♀' => 'پیغام لیندی زنانی: ہلکی رنگت آلی جلد',
    '💆🏼‍♀' => 'پیغام لیندی زنانی: ہلکی درمیانی رنگت آلی جلد',
    '💆🏽‍♀' => 'پیغام لیندی زنانی: درمیانی رنگت آلی جلد',
    '💆🏾‍♀' => 'پیغام لیندی زنانی: درمیانی کالی رنگت آلی جلد',
    '💆🏿‍♀' => 'پیغام لیندی زنانی: کالی رنگت آلی جلد',
    '💇🏻‍♂' => 'وال کٹاندا بندا: ہلکی رنگت آلی جلد',
    '💇🏼‍♂' => 'وال کٹاندا بندا: ہلکی درمیانی رنگت آلی جلد',
    '💇🏽‍♂' => 'وال کٹاندا بندا: درمیانی رنگت آلی جلد',
    '💇🏾‍♂' => 'وال کٹاندا بندا: درمیانی کالی رنگت آلی جلد',
    '💇🏿‍♂' => 'وال کٹاندا بندا: کالی رنگت آلی جلد',
    '💇🏻‍♀' => 'وال کٹاندی زنانی: ہلکی رنگت آلی جلد',
    '💇🏼‍♀' => 'وال کٹاندی زنانی: ہلکی درمیانی رنگت آلی جلد',
    '💇🏽‍♀' => 'وال کٹاندی زنانی: درمیانی رنگت آلی جلد',
    '💇🏾‍♀' => 'وال کٹاندی زنانی: درمیانی کالی رنگت آلی جلد',
    '💇🏿‍♀' => 'وال کٹاندی زنانی: کالی رنگت آلی جلد',
    '🚶🏻‍♂' => 'پیدل تُردا بندہ: ہلکی رنگت آلی جلد',
    '🚶🏼‍♂' => 'پیدل تُردا بندہ: ہلکی درمیانی رنگت آلی جلد',
    '🚶🏽‍♂' => 'پیدل تُردا بندہ: درمیانی رنگت آلی جلد',
    '🚶🏾‍♂' => 'پیدل تُردا بندہ: درمیانی کالی رنگت آلی جلد',
    '🚶🏿‍♂' => 'پیدل تُردا بندہ: کالی رنگت آلی جلد',
    '🚶🏻‍♀' => 'پیدل تُردی زنانی: ہلکی رنگت آلی جلد',
    '🚶🏼‍♀' => 'پیدل تُردی زنانی: ہلکی درمیانی رنگت آلی جلد',
    '🚶🏽‍♀' => 'پیدل تُردی زنانی: درمیانی رنگت آلی جلد',
    '🚶🏾‍♀' => 'پیدل تُردی زنانی: درمیانی کالی رنگت آلی جلد',
    '🚶🏿‍♀' => 'پیدل تُردی زنانی: کالی رنگت آلی جلد',
    '🚶🏻‍➡' => 'ਪੈਦਲ ਵਿਅਕਤੀ: ਗੋਰਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🚶🏼‍➡' => 'ਪੈਦਲ ਵਿਅਕਤੀ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🚶🏽‍➡' => 'ਪੈਦਲ ਵਿਅਕਤੀ: ਕਣਕਵੰਨਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🚶🏾‍➡' => 'ਪੈਦਲ ਵਿਅਕਤੀ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🚶🏿‍➡' => 'ਪੈਦਲ ਵਿਅਕਤੀ: ਕਾਲਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🧍🏻‍♂' => 'ਖੜ੍ਹਾ ਆਦਮੀ: ਗੋਰਾ ਰੰਗ',
    '🧍🏼‍♂' => 'ਖੜ੍ਹਾ ਆਦਮੀ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧍🏽‍♂' => 'ਖੜ੍ਹਾ ਆਦਮੀ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧍🏾‍♂' => 'ਖੜ੍ਹਾ ਆਦਮੀ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🧍🏿‍♂' => 'ਖੜ੍ਹਾ ਆਦਮੀ: ਕਾਲਾ ਰੰਗ',
    '🧍🏻‍♀' => 'ਖੜ੍ਹੀ ਔਰਤ: ਗੋਰਾ ਰੰਗ',
    '🧍🏼‍♀' => 'ਖੜ੍ਹੀ ਔਰਤ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧍🏽‍♀' => 'ਖੜ੍ਹੀ ਔਰਤ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧍🏾‍♀' => 'ਖੜ੍ਹੀ ਔਰਤ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🧍🏿‍♀' => 'ਖੜ੍ਹੀ ਔਰਤ: ਕਾਲਾ ਰੰਗ',
    '🧎🏻‍♂' => 'ਗੋਡਿਆਂ ਭਾਰ ਬੈਠਾ ਆਦਮੀ: ਗੋਰਾ ਰੰਗ',
    '🧎🏼‍♂' => 'ਗੋਡਿਆਂ ਭਾਰ ਬੈਠਾ ਆਦਮੀ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧎🏽‍♂' => 'ਗੋਡਿਆਂ ਭਾਰ ਬੈਠਾ ਆਦਮੀ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧎🏾‍♂' => 'ਗੋਡਿਆਂ ਭਾਰ ਬੈਠਾ ਆਦਮੀ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🧎🏿‍♂' => 'ਗੋਡਿਆਂ ਭਾਰ ਬੈਠਾ ਆਦਮੀ: ਕਾਲਾ ਰੰਗ',
    '🧎🏻‍♀' => 'ਗੋਡਿਆਂ ਭਾਰ ਬੈਠੀ ਔਰਤ: ਗੋਰਾ ਰੰਗ',
    '🧎🏼‍♀' => 'ਗੋਡਿਆਂ ਭਾਰ ਬੈਠੀ ਔਰਤ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧎🏽‍♀' => 'ਗੋਡਿਆਂ ਭਾਰ ਬੈਠੀ ਔਰਤ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧎🏾‍♀' => 'ਗੋਡਿਆਂ ਭਾਰ ਬੈਠੀ ਔਰਤ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🧎🏿‍♀' => 'ਗੋਡਿਆਂ ਭਾਰ ਬੈਠੀ ਔਰਤ: ਕਾਲਾ ਰੰਗ',
    '🧎🏻‍➡' => 'ਗੋਡਿਆਂ ਭਾਰ ਬੈਠਾ ਵਿਅਕਤੀ: ਗੋਰਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🧎🏼‍➡' => 'ਗੋਡਿਆਂ ਭਾਰ ਬੈਠਾ ਵਿਅਕਤੀ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🧎🏽‍➡' => 'ਗੋਡਿਆਂ ਭਾਰ ਬੈਠਾ ਵਿਅਕਤੀ: ਕਣਕਵੰਨਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🧎🏾‍➡' => 'ਗੋਡਿਆਂ ਭਾਰ ਬੈਠਾ ਵਿਅਕਤੀ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🧎🏿‍➡' => 'ਗੋਡਿਆਂ ਭਾਰ ਬੈਠਾ ਵਿਅਕਤੀ: ਕਾਲਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🧑🏻‍🦯' => 'ਟਟੋਲਣ ਵਾਲੀ ਸੋਟੀ ਫੜੀ ਵਿਅਕਤੀ: ਗੋਰਾ ਰੰਗ',
    '🧑🏼‍🦯' => 'ਟਟੋਲਣ ਵਾਲੀ ਸੋਟੀ ਫੜੀ ਵਿਅਕਤੀ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏽‍🦯' => 'ਟਟੋਲਣ ਵਾਲੀ ਸੋਟੀ ਫੜੀ ਵਿਅਕਤੀ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏾‍🦯' => 'ਟਟੋਲਣ ਵਾਲੀ ਸੋਟੀ ਫੜੀ ਵਿਅਕਤੀ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🧑🏿‍🦯' => 'ਟਟੋਲਣ ਵਾਲੀ ਸੋਟੀ ਫੜੀ ਵਿਅਕਤੀ: ਕਾਲਾ ਰੰਗ',
    '👨🏻‍🦯' => 'ਪ੍ਰੋਬਿੰਗ ਕੈਨ ਵਾਲਾ ਆਦਮੀ: ਗੋਰਾ ਰੰਗ',
    '👨🏼‍🦯' => 'ਪ੍ਰੋਬਿੰਗ ਕੈਨ ਵਾਲਾ ਆਦਮੀ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '👨🏽‍🦯' => 'ਪ੍ਰੋਬਿੰਗ ਕੈਨ ਵਾਲਾ ਆਦਮੀ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '👨🏾‍🦯' => 'ਪ੍ਰੋਬਿੰਗ ਕੈਨ ਵਾਲਾ ਆਦਮੀ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '👨🏿‍🦯' => 'ਪ੍ਰੋਬਿੰਗ ਕੈਨ ਵਾਲਾ ਆਦਮੀ: ਕਾਲਾ ਰੰਗ',
    '👩🏻‍🦯' => 'ਪ੍ਰੋਬਿੰਗ ਕੈਨ ਵਾਲੀ ਔਰਤ: ਗੋਰਾ ਰੰਗ',
    '👩🏼‍🦯' => 'ਪ੍ਰੋਬਿੰਗ ਕੈਨ ਵਾਲੀ ਔਰਤ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '👩🏽‍🦯' => 'ਪ੍ਰੋਬਿੰਗ ਕੈਨ ਵਾਲੀ ਔਰਤ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '👩🏾‍🦯' => 'ਪ੍ਰੋਬਿੰਗ ਕੈਨ ਵਾਲੀ ਔਰਤ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '👩🏿‍🦯' => 'ਪ੍ਰੋਬਿੰਗ ਕੈਨ ਵਾਲੀ ਔਰਤ: ਕਾਲਾ ਰੰਗ',
    '🧑🏻‍🦼' => 'ਮੋਟਰ ਵ੍ਹੀਲਚੇਅਰ ਵਿੱਚ ਵਿਅਕਤੀ: ਗੋਰਾ ਰੰਗ',
    '🧑🏼‍🦼' => 'ਮੋਟਰ ਵ੍ਹੀਲਚੇਅਰ ਵਿੱਚ ਵਿਅਕਤੀ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏽‍🦼' => 'ਮੋਟਰ ਵ੍ਹੀਲਚੇਅਰ ਵਿੱਚ ਵਿਅਕਤੀ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏾‍🦼' => 'ਮੋਟਰ ਵ੍ਹੀਲਚੇਅਰ ਵਿੱਚ ਵਿਅਕਤੀ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🧑🏿‍🦼' => 'ਮੋਟਰ ਵ੍ਹੀਲਚੇਅਰ ਵਿੱਚ ਵਿਅਕਤੀ: ਕਾਲਾ ਰੰਗ',
    '👨🏻‍🦼' => 'ਮੋਟਰ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ‘ਤੇ ਬੈਠਾ ਆਦਮੀ: ਗੋਰਾ ਰੰਗ',
    '👨🏼‍🦼' => 'ਮੋਟਰ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ‘ਤੇ ਬੈਠਾ ਆਦਮੀ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '👨🏽‍🦼' => 'ਮੋਟਰ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ‘ਤੇ ਬੈਠਾ ਆਦਮੀ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '👨🏾‍🦼' => 'ਮੋਟਰ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ‘ਤੇ ਬੈਠਾ ਆਦਮੀ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '👨🏿‍🦼' => 'ਮੋਟਰ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ‘ਤੇ ਬੈਠਾ ਆਦਮੀ: ਕਾਲਾ ਰੰਗ',
    '👩🏻‍🦼' => 'ਮੋਟਰ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ‘ਤੇ ਬੈਠੀ ਔਰਤ: ਗੋਰਾ ਰੰਗ',
    '👩🏼‍🦼' => 'ਮੋਟਰ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ‘ਤੇ ਬੈਠੀ ਔਰਤ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '👩🏽‍🦼' => 'ਮੋਟਰ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ‘ਤੇ ਬੈਠੀ ਔਰਤ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '👩🏾‍🦼' => 'ਮੋਟਰ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ‘ਤੇ ਬੈਠੀ ਔਰਤ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '👩🏿‍🦼' => 'ਮੋਟਰ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ‘ਤੇ ਬੈਠੀ ਔਰਤ: ਕਾਲਾ ਰੰਗ',
    '🧑🏻‍🦽' => 'ਹੱਥੀਂ ਚੱਲਣ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ਵਿੱਚ ਵਿਅਕਤੀ: ਗੋਰਾ ਰੰਗ',
    '🧑🏼‍🦽' => 'ਹੱਥੀਂ ਚੱਲਣ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ਵਿੱਚ ਵਿਅਕਤੀ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏽‍🦽' => 'ਹੱਥੀਂ ਚੱਲਣ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ਵਿੱਚ ਵਿਅਕਤੀ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧑🏾‍🦽' => 'ਹੱਥੀਂ ਚੱਲਣ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ਵਿੱਚ ਵਿਅਕਤੀ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🧑🏿‍🦽' => 'ਹੱਥੀਂ ਚੱਲਣ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ਵਿੱਚ ਵਿਅਕਤੀ: ਕਾਲਾ ਰੰਗ',
    '👨🏻‍🦽' => 'ਹੱਥ ਨਾਲ ਚੱਲਣ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ‘ਤੇ ਬੈਠਾ ਆਦਮੀ: ਗੋਰਾ ਰੰਗ',
    '👨🏼‍🦽' => 'ਹੱਥ ਨਾਲ ਚੱਲਣ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ‘ਤੇ ਬੈਠਾ ਆਦਮੀ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '👨🏽‍🦽' => 'ਹੱਥ ਨਾਲ ਚੱਲਣ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ‘ਤੇ ਬੈਠਾ ਆਦਮੀ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '👨🏾‍🦽' => 'ਹੱਥ ਨਾਲ ਚੱਲਣ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ‘ਤੇ ਬੈਠਾ ਆਦਮੀ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '👨🏿‍🦽' => 'ਹੱਥ ਨਾਲ ਚੱਲਣ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ‘ਤੇ ਬੈਠਾ ਆਦਮੀ: ਕਾਲਾ ਰੰਗ',
    '👩🏻‍🦽' => 'ਹੱਥ ਨਾਲ ਚੱਲਣ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ‘ਤੇ ਬੈਠੀ ਔਰਤ: ਗੋਰਾ ਰੰਗ',
    '👩🏼‍🦽' => 'ਹੱਥ ਨਾਲ ਚੱਲਣ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ‘ਤੇ ਬੈਠੀ ਔਰਤ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '👩🏽‍🦽' => 'ਹੱਥ ਨਾਲ ਚੱਲਣ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ‘ਤੇ ਬੈਠੀ ਔਰਤ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '👩🏾‍🦽' => 'ਹੱਥ ਨਾਲ ਚੱਲਣ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ‘ਤੇ ਬੈਠੀ ਔਰਤ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '👩🏿‍🦽' => 'ਹੱਥ ਨਾਲ ਚੱਲਣ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ‘ਤੇ ਬੈਠੀ ਔਰਤ: ਕਾਲਾ ਰੰਗ',
    '🏃🏻‍♂' => 'بھجدا مرد: ہلکی رنگت آلی جلد',
    '🏃🏼‍♂' => 'بھجدا مرد: ہلکی درمیانی رنگت آلی جلد',
    '🏃🏽‍♂' => 'بھجدا مرد: درمیانی رنگت آلی جلد',
    '🏃🏾‍♂' => 'بھجدا مرد: درمیانی کالی رنگت آلی جلد',
    '🏃🏿‍♂' => 'بھجدا مرد: کالی رنگت آلی جلد',
    '🏃🏻‍♀' => 'بھجدی زنانی: ہلکی رنگت آلی جلد',
    '🏃🏼‍♀' => 'بھجدی زنانی: ہلکی درمیانی رنگت آلی جلد',
    '🏃🏽‍♀' => 'بھجدی زنانی: درمیانی رنگت آلی جلد',
    '🏃🏾‍♀' => 'بھجدی زنانی: درمیانی کالی رنگت آلی جلد',
    '🏃🏿‍♀' => 'بھجدی زنانی: کالی رنگت آلی جلد',
    '🏃🏻‍➡' => 'ਦੌੜਦਾ ਵਿਅਕਤੀ: ਗੋਰਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🏃🏼‍➡' => 'ਦੌੜਦਾ ਵਿਅਕਤੀ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🏃🏽‍➡' => 'ਦੌੜਦਾ ਵਿਅਕਤੀ: ਕਣਕਵੰਨਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🏃🏾‍➡' => 'ਦੌੜਦਾ ਵਿਅਕਤੀ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '🏃🏿‍➡' => 'ਦੌੜਦਾ ਵਿਅਕਤੀ: ਕਾਲਾ ਰੰਗ, ਸੱਜੇ ਪਾਸੇ',
    '👯🏻‍♀' => 'خرگوش دے کناں آلی پارٹی کردی زنانی: ہلکی رنگت آلی جلد',
    '👯🏼‍♀' => 'خرگوش دے کناں آلی پارٹی کردی زنانی: ہلکی درمیانی رنگت آلی جلد',
    '👯🏽‍♀' => 'خرگوش دے کناں آلی پارٹی کردی زنانی: درمیانی رنگت آلی جلد',
    '👯🏾‍♀' => 'خرگوش دے کناں آلی پارٹی کردی زنانی: درمیانی کالی رنگت آلی جلد',
    '👯🏿‍♀' => 'خرگوش دے کناں آلی پارٹی کردی زنانی: کالی رنگت آلی جلد',
    '👯🏻‍♂' => 'خرگوش دے کناں آلا پارٹی کردا بندا: ہلکی رنگت آلی جلد',
    '👯🏼‍♂' => 'خرگوش دے کناں آلا پارٹی کردا بندا: ہلکی درمیانی رنگت آلی جلد',
    '👯🏽‍♂' => 'خرگوش دے کناں آلا پارٹی کردا بندا: درمیانی رنگت آلی جلد',
    '👯🏾‍♂' => 'خرگوش دے کناں آلا پارٹی کردا بندا: درمیانی کالی رنگت آلی جلد',
    '👯🏿‍♂' => 'خرگوش دے کناں آلا پارٹی کردا بندا: کالی رنگت آلی جلد',
    '🧖🏻‍♂' => 'بھاپ نال بھرے کمرے وچ مرد: ہلکی رنگت آلی جلد',
    '🧖🏼‍♂' => 'بھاپ نال بھرے کمرے وچ مرد: ہلکی درمیانی رنگت آلی جلد',
    '🧖🏽‍♂' => 'بھاپ نال بھرے کمرے وچ مرد: درمیانی رنگت آلی جلد',
    '🧖🏾‍♂' => 'بھاپ نال بھرے کمرے وچ مرد: درمیانی کالی رنگت آلی جلد',
    '🧖🏿‍♂' => 'بھاپ نال بھرے کمرے وچ مرد: کالی رنگت آلی جلد',
    '🧖🏻‍♀' => 'بھاپ نال بھرے کمرے وچ زنانی: ہلکی رنگت آلی جلد',
    '🧖🏼‍♀' => 'بھاپ نال بھرے کمرے وچ زنانی: ہلکی درمیانی رنگت آلی جلد',
    '🧖🏽‍♀' => 'بھاپ نال بھرے کمرے وچ زنانی: درمیانی رنگت آلی جلد',
    '🧖🏾‍♀' => 'بھاپ نال بھرے کمرے وچ زنانی: درمیانی کالی رنگت آلی جلد',
    '🧖🏿‍♀' => 'بھاپ نال بھرے کمرے وچ زنانی: کالی رنگت آلی جلد',
    '🧗🏻‍♂' => 'کوہ پیمائی کردا مرد: ہلکی رنگت آلی جلد',
    '🧗🏼‍♂' => 'کوہ پیمائی کردا مرد: ہلکی درمیانی رنگت آلی جلد',
    '🧗🏽‍♂' => 'کوہ پیمائی کردا مرد: درمیانی رنگت آلی جلد',
    '🧗🏾‍♂' => 'کوہ پیمائی کردا مرد: درمیانی کالی رنگت آلی جلد',
    '🧗🏿‍♂' => 'کوہ پیمائی کردا مرد: کالی رنگت آلی جلد',
    '🧗🏻‍♀' => 'کوہ پیمائی کردی زنانی: ہلکی رنگت آلی جلد',
    '🧗🏼‍♀' => 'کوہ پیمائی کردی زنانی: ہلکی درمیانی رنگت آلی جلد',
    '🧗🏽‍♀' => 'کوہ پیمائی کردی زنانی: درمیانی رنگت آلی جلد',
    '🧗🏾‍♀' => 'کوہ پیمائی کردی زنانی: درمیانی کالی رنگت آلی جلد',
    '🧗🏿‍♀' => 'کوہ پیمائی کردی زنانی: کالی رنگت آلی جلد',
    '🏌🏻‍♂' => 'گالف کھیڈدا مرد: ہلکی رنگت آلی جلد',
    '🏌🏼‍♂' => 'گالف کھیڈدا مرد: ہلکی درمیانی رنگت آلی جلد',
    '🏌🏽‍♂' => 'گالف کھیڈدا مرد: درمیانی رنگت آلی جلد',
    '🏌🏾‍♂' => 'گالف کھیڈدا مرد: درمیانی کالی رنگت آلی جلد',
    '🏌🏿‍♂' => 'گالف کھیڈدا مرد: کالی رنگت آلی جلد',
    '🏌🏻‍♀' => 'گالف کھیڈدی زنانی: ہلکی رنگت آلی جلد',
    '🏌🏼‍♀' => 'گالف کھیڈدی زنانی: ہلکی درمیانی رنگت آلی جلد',
    '🏌🏽‍♀' => 'گالف کھیڈدی زنانی: درمیانی رنگت آلی جلد',
    '🏌🏾‍♀' => 'گالف کھیڈدی زنانی: درمیانی کالی رنگت آلی جلد',
    '🏌🏿‍♀' => 'گالف کھیڈدی زنانی: کالی رنگت آلی جلد',
    '🏄🏻‍♂' => 'صرف کردا بندا: ہلکی رنگت آلی جلد',
    '🏄🏼‍♂' => 'صرف کردا بندا: ہلکی درمیانی رنگت آلی جلد',
    '🏄🏽‍♂' => 'صرف کردا بندا: درمیانی رنگت آلی جلد',
    '🏄🏾‍♂' => 'صرف کردا بندا: درمیانی کالی رنگت آلی جلد',
    '🏄🏿‍♂' => 'صرف کردا بندا: کالی رنگت آلی جلد',
    '🏄🏻‍♀' => 'صرف کردی زنانی: ہلکی رنگت آلی جلد',
    '🏄🏼‍♀' => 'صرف کردی زنانی: ہلکی درمیانی رنگت آلی جلد',
    '🏄🏽‍♀' => 'صرف کردی زنانی: درمیانی رنگت آلی جلد',
    '🏄🏾‍♀' => 'صرف کردی زنانی: درمیانی کالی رنگت آلی جلد',
    '🏄🏿‍♀' => 'صرف کردی زنانی: کالی رنگت آلی جلد',
    '🚣🏻‍♂' => 'چپُو چلاندا بندہ: ہلکی رنگت آلی جلد',
    '🚣🏼‍♂' => 'چپُو چلاندا بندہ: ہلکی درمیانی رنگت آلی جلد',
    '🚣🏽‍♂' => 'چپُو چلاندا بندہ: درمیانی رنگت آلی جلد',
    '🚣🏾‍♂' => 'چپُو چلاندا بندہ: درمیانی کالی رنگت آلی جلد',
    '🚣🏿‍♂' => 'چپُو چلاندا بندہ: کالی رنگت آلی جلد',
    '🚣🏻‍♀' => 'چپُو چلاندی زنانی: ہلکی رنگت آلی جلد',
    '🚣🏼‍♀' => 'چپُو چلاندی زنانی: ہلکی درمیانی رنگت آلی جلد',
    '🚣🏽‍♀' => 'چپُو چلاندی زنانی: درمیانی رنگت آلی جلد',
    '🚣🏾‍♀' => 'چپُو چلاندی زنانی: درمیانی کالی رنگت آلی جلد',
    '🚣🏿‍♀' => 'چپُو چلاندی زنانی: کالی رنگت آلی جلد',
    '🏊🏻‍♂' => 'تیراکی کردا بندہ: ہلکی رنگت آلی جلد',
    '🏊🏼‍♂' => 'تیراکی کردا بندہ: ہلکی درمیانی رنگت آلی جلد',
    '🏊🏽‍♂' => 'تیراکی کردا بندہ: درمیانی رنگت آلی جلد',
    '🏊🏾‍♂' => 'تیراکی کردا بندہ: درمیانی کالی رنگت آلی جلد',
    '🏊🏿‍♂' => 'تیراکی کردا بندہ: کالی رنگت آلی جلد',
    '🏊🏻‍♀' => 'تیراکی کردی زنانی: ہلکی رنگت آلی جلد',
    '🏊🏼‍♀' => 'تیراکی کردی زنانی: ہلکی درمیانی رنگت آلی جلد',
    '🏊🏽‍♀' => 'تیراکی کردی زنانی: درمیانی رنگت آلی جلد',
    '🏊🏾‍♀' => 'تیراکی کردی زنانی: درمیانی کالی رنگت آلی جلد',
    '🏊🏿‍♀' => 'تیراکی کردی زنانی: کالی رنگت آلی جلد',
    '⛹🏻‍♂' => 'زور نال گیند کراندا آدمی: ہلکی رنگت آلی جلد',
    '⛹🏼‍♂' => 'زور نال گیند کراندا آدمی: ہلکی درمیانی رنگت آلی جلد',
    '⛹🏽‍♂' => 'زور نال گیند کراندا آدمی: درمیانی رنگت آلی جلد',
    '⛹🏾‍♂' => 'زور نال گیند کراندا آدمی: درمیانی کالی رنگت آلی جلد',
    '⛹🏿‍♂' => 'زور نال گیند کراندا آدمی: کالی رنگت آلی جلد',
    '⛹🏻‍♀' => 'زور نال گیند کراندی زنانی: ہلکی رنگت آلی جلد',
    '⛹🏼‍♀' => 'زور نال گیند کراندی زنانی: ہلکی درمیانی رنگت آلی جلد',
    '⛹🏽‍♀' => 'زور نال گیند کراندی زنانی: درمیانی رنگت آلی جلد',
    '⛹🏾‍♀' => 'زور نال گیند کراندی زنانی: درمیانی کالی رنگت آلی جلد',
    '⛹🏿‍♀' => 'زور نال گیند کراندی زنانی: کالی رنگت آلی جلد',
    '🏋🏻‍♂' => 'بھار چُکدا مرد: ہلکی رنگت آلی جلد',
    '🏋🏼‍♂' => 'بھار چُکدا مرد: ہلکی درمیانی رنگت آلی جلد',
    '🏋🏽‍♂' => 'بھار چُکدا مرد: درمیانی رنگت آلی جلد',
    '🏋🏾‍♂' => 'بھار چُکدا مرد: درمیانی کالی رنگت آلی جلد',
    '🏋🏿‍♂' => 'بھار چُکدا مرد: کالی رنگت آلی جلد',
    '🏋🏻‍♀' => 'بھار چُکدی زنانی: ہلکی رنگت آلی جلد',
    '🏋🏼‍♀' => 'بھار چُکدی زنانی: ہلکی درمیانی رنگت آلی جلد',
    '🏋🏽‍♀' => 'بھار چُکدی زنانی: درمیانی رنگت آلی جلد',
    '🏋🏾‍♀' => 'بھار چُکدی زنانی: درمیانی کالی رنگت آلی جلد',
    '🏋🏿‍♀' => 'بھار چُکدی زنانی: کالی رنگت آلی جلد',
    '🚴🏻‍♂' => 'بائیک چلاندا بندا: ہلکی رنگت آلی جلد',
    '🚴🏼‍♂' => 'بائیک چلاندا بندا: ہلکی درمیانی رنگت آلی جلد',
    '🚴🏽‍♂' => 'بائیک چلاندا بندا: درمیانی رنگت آلی جلد',
    '🚴🏾‍♂' => 'بائیک چلاندا بندا: درمیانی کالی رنگت آلی جلد',
    '🚴🏿‍♂' => 'بائیک چلاندا بندا: کالی رنگت آلی جلد',
    '🚴🏻‍♀' => 'بائیک چلاندی زنانی: ہلکی رنگت آلی جلد',
    '🚴🏼‍♀' => 'بائیک چلاندی زنانی: ہلکی درمیانی رنگت آلی جلد',
    '🚴🏽‍♀' => 'بائیک چلاندی زنانی: درمیانی رنگت آلی جلد',
    '🚴🏾‍♀' => 'بائیک چلاندی زنانی: درمیانی کالی رنگت آلی جلد',
    '🚴🏿‍♀' => 'بائیک چلاندی زنانی: کالی رنگت آلی جلد',
    '🚵🏻‍♂' => 'پہاڑ تے موٹر سائیکل چلاندا بندا: ہلکی رنگت آلی جلد',
    '🚵🏼‍♂' => 'پہاڑ تے موٹر سائیکل چلاندا بندا: ہلکی درمیانی رنگت آلی جلد',
    '🚵🏽‍♂' => 'پہاڑ تے موٹر سائیکل چلاندا بندا: درمیانی رنگت آلی جلد',
    '🚵🏾‍♂' => 'پہاڑ تے موٹر سائیکل چلاندا بندا: درمیانی کالی رنگت آلی جلد',
    '🚵🏿‍♂' => 'پہاڑ تے موٹر سائیکل چلاندا بندا: کالی رنگت آلی جلد',
    '🚵🏻‍♀' => 'پہاڑ تے موٹر سائیکل چلاندی زنانی: ہلکی رنگت آلی جلد',
    '🚵🏼‍♀' => 'پہاڑ تے موٹر سائیکل چلاندی زنانی: ہلکی درمیانی رنگت آلی جلد',
    '🚵🏽‍♀' => 'پہاڑ تے موٹر سائیکل چلاندی زنانی: درمیانی رنگت آلی جلد',
    '🚵🏾‍♀' => 'پہاڑ تے موٹر سائیکل چلاندی زنانی: درمیانی کالی رنگت آلی جلد',
    '🚵🏿‍♀' => 'پہاڑ تے موٹر سائیکل چلاندی زنانی: کالی رنگت آلی جلد',
    '🤸🏻‍♂' => 'چھکڑے دا پہیہ چلاندا بندہ: ہلکی رنگت آلی جلد',
    '🤸🏼‍♂' => 'چھکڑے دا پہیہ چلاندا بندہ: ہلکی درمیانی رنگت آلی جلد',
    '🤸🏽‍♂' => 'چھکڑے دا پہیہ چلاندا بندہ: درمیانی رنگت آلی جلد',
    '🤸🏾‍♂' => 'چھکڑے دا پہیہ چلاندا بندہ: درمیانی کالی رنگت آلی جلد',
    '🤸🏿‍♂' => 'چھکڑے دا پہیہ چلاندا بندہ: کالی رنگت آلی جلد',
    '🤸🏻‍♀' => 'چھکڑے دا پہیہ چلاندی زنانی: ہلکی رنگت آلی جلد',
    '🤸🏼‍♀' => 'چھکڑے دا پہیہ چلاندی زنانی: ہلکی درمیانی رنگت آلی جلد',
    '🤸🏽‍♀' => 'چھکڑے دا پہیہ چلاندی زنانی: درمیانی رنگت آلی جلد',
    '🤸🏾‍♀' => 'چھکڑے دا پہیہ چلاندی زنانی: درمیانی کالی رنگت آلی جلد',
    '🤸🏿‍♀' => 'چھکڑے دا پہیہ چلاندی زنانی: کالی رنگت آلی جلد',
    '🤼🏻‍♀' => 'کُشتی لڑدیاں زنانیاں: ہلکی رنگت آلی جلد',
    '🤼🏼‍♀' => 'کُشتی لڑدیاں زنانیاں: ہلکی درمیانی رنگت آلی جلد',
    '🤼🏽‍♀' => 'کُشتی لڑدیاں زنانیاں: درمیانی رنگت آلی جلد',
    '🤼🏾‍♀' => 'کُشتی لڑدیاں زنانیاں: درمیانی کالی رنگت آلی جلد',
    '🤼🏿‍♀' => 'کُشتی لڑدیاں زنانیاں: کالی رنگت آلی جلد',
    '🤼🏻‍♂' => 'کُشتی لڑدے بندے: ہلکی رنگت آلی جلد',
    '🤼🏼‍♂' => 'کُشتی لڑدے بندے: ہلکی درمیانی رنگت آلی جلد',
    '🤼🏽‍♂' => 'کُشتی لڑدے بندے: درمیانی رنگت آلی جلد',
    '🤼🏾‍♂' => 'کُشتی لڑدے بندے: درمیانی کالی رنگت آلی جلد',
    '🤼🏿‍♂' => 'کُشتی لڑدے بندے: کالی رنگت آلی جلد',
    '🤽🏻‍♂' => 'آبی پولو کھیڈدا بندہ: ہلکی رنگت آلی جلد',
    '🤽🏼‍♂' => 'آبی پولو کھیڈدا بندہ: ہلکی درمیانی رنگت آلی جلد',
    '🤽🏽‍♂' => 'آبی پولو کھیڈدا بندہ: درمیانی رنگت آلی جلد',
    '🤽🏾‍♂' => 'آبی پولو کھیڈدا بندہ: درمیانی کالی رنگت آلی جلد',
    '🤽🏿‍♂' => 'آبی پولو کھیڈدا بندہ: کالی رنگت آلی جلد',
    '🤽🏻‍♀' => 'آبی پولو کھیڈدی زنانی: ہلکی رنگت آلی جلد',
    '🤽🏼‍♀' => 'آبی پولو کھیڈدی زنانی: ہلکی درمیانی رنگت آلی جلد',
    '🤽🏽‍♀' => 'آبی پولو کھیڈدی زنانی: درمیانی رنگت آلی جلد',
    '🤽🏾‍♀' => 'آبی پولو کھیڈدی زنانی: درمیانی کالی رنگت آلی جلد',
    '🤽🏿‍♀' => 'آبی پولو کھیڈدی زنانی: کالی رنگت آلی جلد',
    '🤾🏻‍♂' => 'ہینڈ بال کھیڈدا بندہ: ہلکی رنگت آلی جلد',
    '🤾🏼‍♂' => 'ہینڈ بال کھیڈدا بندہ: ہلکی درمیانی رنگت آلی جلد',
    '🤾🏽‍♂' => 'ہینڈ بال کھیڈدا بندہ: درمیانی رنگت آلی جلد',
    '🤾🏾‍♂' => 'ہینڈ بال کھیڈدا بندہ: درمیانی کالی رنگت آلی جلد',
    '🤾🏿‍♂' => 'ہینڈ بال کھیڈدا بندہ: کالی رنگت آلی جلد',
    '🤾🏻‍♀' => 'ہینڈ بال کھیڈدی زنانی: ہلکی رنگت آلی جلد',
    '🤾🏼‍♀' => 'ہینڈ بال کھیڈدی زنانی: ہلکی درمیانی رنگت آلی جلد',
    '🤾🏽‍♀' => 'ہینڈ بال کھیڈدی زنانی: درمیانی رنگت آلی جلد',
    '🤾🏾‍♀' => 'ہینڈ بال کھیڈدی زنانی: درمیانی کالی رنگت آلی جلد',
    '🤾🏿‍♀' => 'ہینڈ بال کھیڈدی زنانی: کالی رنگت آلی جلد',
    '🤹🏻‍♂' => 'کرتب وکھاندا بندہ: ہلکی رنگت آلی جلد',
    '🤹🏼‍♂' => 'کرتب وکھاندا بندہ: ہلکی درمیانی رنگت آلی جلد',
    '🤹🏽‍♂' => 'کرتب وکھاندا بندہ: درمیانی رنگت آلی جلد',
    '🤹🏾‍♂' => 'کرتب وکھاندا بندہ: درمیانی کالی رنگت آلی جلد',
    '🤹🏿‍♂' => 'کرتب وکھاندا بندہ: کالی رنگت آلی جلد',
    '🤹🏻‍♀' => 'کرتب وکھاندی زنانی: ہلکی رنگت آلی جلد',
    '🤹🏼‍♀' => 'کرتب وکھاندی زنانی: ہلکی درمیانی رنگت آلی جلد',
    '🤹🏽‍♀' => 'کرتب وکھاندی زنانی: درمیانی رنگت آلی جلد',
    '🤹🏾‍♀' => 'کرتب وکھاندی زنانی: درمیانی کالی رنگت آلی جلد',
    '🤹🏿‍♀' => 'کرتب وکھاندی زنانی: کالی رنگت آلی جلد',
    '🧘🏻‍♂' => 'کنول دی حآلت وچ مرد: ہلکی رنگت آلی جلد',
    '🧘🏼‍♂' => 'کنول دی حآلت وچ مرد: ہلکی درمیانی رنگت آلی جلد',
    '🧘🏽‍♂' => 'کنول دی حآلت وچ مرد: درمیانی رنگت آلی جلد',
    '🧘🏾‍♂' => 'کنول دی حآلت وچ مرد: درمیانی کالی رنگت آلی جلد',
    '🧘🏿‍♂' => 'کنول دی حآلت وچ مرد: کالی رنگت آلی جلد',
    '🧘🏻‍♀' => 'کنول دی حالت وچ زنانی: ہلکی رنگت آلی جلد',
    '🧘🏼‍♀' => 'کنول دی حالت وچ زنانی: ہلکی درمیانی رنگت آلی جلد',
    '🧘🏽‍♀' => 'کنول دی حالت وچ زنانی: درمیانی رنگت آلی جلد',
    '🧘🏾‍♀' => 'کنول دی حالت وچ زنانی: درمیانی کالی رنگت آلی جلد',
    '🧘🏿‍♀' => 'کنول دی حالت وچ زنانی: کالی رنگت آلی جلد',
    '🧑‍🦰' => 'ਵਿਅਕਤੀ: ਲਾਲ ਰੰਗ ਦੇ ਵਾਲ',
    '🧑‍🦱' => 'ਵਿਅਕਤੀ: ਘੁੰਗਰਾਲੇ ਵਾਲ',
    '🧑‍🦳' => 'ਵਿਅਕਤੀ: ਚਿੱਟੇ ਵਾਲ',
    '🧑‍🦲' => 'ਵਿਅਕਤੀ: ਗੰਜਾ ਸਿਰ',
    '👨‍🦰' => 'ਆਦਮੀ: ਲਾਲ ਰੰਗ ਦੇ ਵਾਲ',
    '👨‍🦱' => 'ਆਦਮੀ: ਘੁੰਗਰਾਲੇ ਵਾਲ',
    '👨‍🦳' => 'ਆਦਮੀ: ਚਿੱਟੇ ਵਾਲ',
    '👨‍🦲' => 'ਆਦਮੀ: ਗੰਜਾ ਸਿਰ',
    '👩‍🦰' => 'ਔਰਤ: ਲਾਲ ਰੰਗ ਦੇ ਵਾਲ',
    '👩‍🦱' => 'ਔਰਤ: ਘੁੰਗਰਾਲੇ ਵਾਲ',
    '👩‍🦳' => 'ਔਰਤ: ਚਿੱਟੇ ਵਾਲ',
    '👩‍🦲' => 'ਔਰਤ: ਗੰਜਾ ਸਿਰ',
    '🚶‍➡' => 'ਪੈਦਲ ਵਿਅਕਤੀ: ਸੱਜੇ ਪਾਸੇ',
    '🧎‍➡' => 'ਗੋਡਿਆਂ ਭਾਰ ਬੈਠਾ ਵਿਅਕਤੀ: ਸੱਜੇ ਪਾਸੇ',
    '🏃‍➡' => 'ਦੌੜਦਾ ਵਿਅਕਤੀ: ਸੱਜੇ ਪਾਸੇ',
    '👨‍👦' => 'ٹبّر: بندہ, منڈا',
    '👨‍👧' => 'ٹبّر: بندہ, کڑی',
    '👩‍👦' => 'ٹبّر: زنانی, منڈا',
    '👩‍👧' => 'ٹبّر: زنانی, کڑی',
    '😶‍🌫' => 'ਬੱਦਲਾਂ ਵਿੱਚ ਚਿਹਰਾ',
    '😮‍💨' => 'ਸਾਹ ਭਰਦਾ ਚਿਹਰਾ',
    '🙂‍↕' => 'ਉੱਪਰ ਤੋਂ ਥੱਲੇ ਪਾਸੇ ਵੱਲ ਸਿਰ ਹਿਲਾਉਣਾ',
    '😵‍💫' => 'ਚੱਕਰੀ ਅੱਖਾਂ ਵਾਲਾ ਚਿਹਰਾ',
    '❤‍🔥' => 'ਜਲਦਾ ਦਿਲ',
    '❤‍🩹' => 'ਤੰਦਰੁਸਤ ਹੁੰਦਾ ਦਿਲ',
    '👁‍🗨' => 'تقریری حباب وچ اکھ',
    '🧔‍♂' => 'ਆਦਮੀ: ਦਾੜ੍ਹੀ',
    '👱‍♂' => 'بُھورے والاں آلا آدمی',
    '🧔‍♀' => 'ਔਰਤ: ਦਾੜ੍ਹੀ',
    '👱‍♀' => 'بُھورے والاں آلی زنانی',
    '🙍‍♂' => 'تیوری چڑھاندا بندہ',
    '🙍‍♀' => 'تیوری چڑھاندی زنانی',
    '🙎‍♂' => 'منہ بسوردا بندہ',
    '🙎‍♀' => 'منہ بسوردی زنانی',
    '🙅‍♂' => 'نہیں دا اشارہ کردا بندہ',
    '🙅‍♀' => 'نہیں دا اشارہ کردی زنانی',
    '🙆‍♂' => 'ٹھیک اے دا اشارہ کردا بندہ',
    '🙆‍♀' => 'ٹھیک اے دا اشارہ کردی زنانی',
    '💁‍♂' => 'تھپکی دیندا مرد',
    '💁‍♀' => 'تھپکی دیندی زنانی',
    '🙋‍♂' => 'ہتھ اُوتے کردا بندہ',
    '🙋‍♀' => 'ہتھ اُوتے کردی زنانی',
    '🧏‍♂' => 'ਬੋਲ਼ਾ ਆਦਮੀ',
    '🧏‍♀' => 'ਬੋਲ਼ੀ ਔਰਤ',
    '🙇‍♂' => 'جُھکدا بندہ',
    '🙇‍♀' => 'جُھکدی زنانی',
    '🤦‍♂' => 'منہ اوتے ہتھ رکھدا بندہ',
    '🤦‍♀' => 'منہ اوتے ہتھ رکھدی زنانی',
    '🤷‍♂' => 'مونڈھے اچکاندا بندہ',
    '🤷‍♀' => 'مونڈھے اچکاندی زنانی',
    '🧑‍⚕' => 'ਸਿਹਤਕਰਮੀ',
    '👨‍⚕' => 'صحت تے کم کرن آلا بندہ',
    '👩‍⚕' => 'صحت تے کم کرن آلی زنانی',
    '🧑‍🎓' => 'ਸਿਖਿਆਰਥੀ',
    '👨‍🎓' => 'مرد طالب علم',
    '👩‍🎓' => 'طالبہ',
    '🧑‍🏫' => 'ਸਿੱਖਿਅਕ',
    '👨‍🏫' => 'مرد استاد',
    '👩‍🏫' => 'زنانہ استانی',
    '🧑‍⚖' => 'ਜੱਜ',
    '👨‍⚖' => 'مرد جج',
    '👩‍⚖' => 'جج زنانی',
    '🧑‍🌾' => 'ਕਿਸਾਨ',
    '👨‍🌾' => 'مرد کسان',
    '👩‍🌾' => 'زنانی کسان',
    '🧑‍🍳' => 'ਲਾਂਗਰੀ',
    '👨‍🍳' => 'کھانا پکان آلا بندہ',
    '👩‍🍳' => 'کھانا پکان آلی زنانی',
    '🧑‍🔧' => 'ਮਸ਼ੀਨਸਾਜ਼',
    '👨‍🔧' => 'مرد مکینک',
    '👩‍🔧' => 'مکینک زنانی',
    '🧑‍🏭' => 'ਕਾਰਖਾਨਾ ਮਜ਼ਦੂਰ',
    '👨‍🏭' => 'فیکٹری وچ کم کرن آلا بندہ',
    '👩‍🏭' => 'فیکٹری وچ کم کرن آلی زنانی',
    '🧑‍💼' => 'ਦਫ਼ਤਰ ਕਰਮਚਾਰੀ',
    '👨‍💼' => 'دفتر وچ کم کرن آلا مرد',
    '👩‍💼' => 'دفتر وچ کم کرن آلی زنانی',
    '🧑‍🔬' => 'ਵਿਗਿਆਨੀ',
    '👨‍🔬' => 'مرد سائنسدان',
    '👩‍🔬' => 'سائنسدان زنانی',
    '🧑‍💻' => 'ਟੈਕਨੋਲੋਜਿਸਟ',
    '👨‍💻' => 'تکنیک دان بندہ',
    '👩‍💻' => 'تکنیک دان زنانی',
    '🧑‍🎤' => 'ਗਵੱਈਆ',
    '👨‍🎤' => 'گلوکار',
    '👩‍🎤' => 'گلوکارہ',
    '🧑‍🎨' => 'ਚਿੱਤਰਕਾਰ',
    '👨‍🎨' => 'مرد فنکار',
    '👩‍🎨' => 'فنکار زنانی',
    '🧑‍✈' => 'ਹਵਾਈ ਜਹਾਜ਼ ਚਾਲਕ',
    '👨‍✈' => 'مرد پائلٹ',
    '👩‍✈' => 'زنانی پائلٹ',
    '🧑‍🚀' => 'ਪੁਲਾੜ ਯਾਤਰੀ',
    '👨‍🚀' => 'مرد خلاء باز',
    '👩‍🚀' => 'خلاء باز زنانی',
    '🧑‍🚒' => 'ਫਾਇਰਫਾਈਟਰ',
    '👨‍🚒' => 'آگ بجھان آلا بندہ',
    '👩‍🚒' => 'آگ بجان آلی زنانی',
    '👮‍♂' => 'پُلس آفسر بندہ',
    '👮‍♀' => 'پُلس آفسر زنانی',
    '🕵‍♂' => 'جاسوس بندہ',
    '🕵‍♀' => 'جاسوس زنانی',
    '💂‍♂' => 'چوکیدار بندہ',
    '💂‍♀' => 'چوکیدار زنانی',
    '👷‍♂' => 'تعمیری کم کرن آلا بندہ',
    '👷‍♀' => 'تعمیری کم کرن آلی زنانی',
    '👳‍♂' => 'پگڑی پاندا بندا',
    '👳‍♀' => 'پگڑی پاندی زنانی',
    '🤵‍♂' => 'ਬਣਿਆ-ਠਣਿਆ ਆਦਮੀ',
    '🤵‍♀' => 'ਬਣੀ ਠਣੀ ਔਰਤ',
    '👰‍♂' => 'ਘੁੰਡ ਵਿੱਚ ਆਦਮੀ',
    '👰‍♀' => 'ਘੁੰਡ ਵਿੱਚ ਔਰਤ',
    '👩‍🍼' => 'ਬੱਚੇ ਨੂੰ ਦੁੱਧ ਚੁੰਘਾਉਂਦੀ ਔਰਤ',
    '👨‍🍼' => 'ਬੱਚੇ ਨੂੰ ਦੁੱਧ ਪਿਲਾਉਂਦਾ ਆਦਮੀ',
    '🧑‍🍼' => 'ਬੱਚੇ ਨੂੰ ਦੁੱਧ ਪਿਲਾਉਂਦਾ ਵਿਅਕਤੀ',
    '🧑‍🎄' => 'ਐਮਐਕਸ ਕਲਾਜ਼',
    '🦸‍♂' => 'ਪੁਰਸ਼ ਸੁਪਰਹੀਰੋ',
    '🦸‍♀' => 'ਇਸਤਰੀ ਸੁਪਰਹੀਰੋ',
    '🦹‍♂' => 'ਪੁਰਸ਼ ਮਹਾਂ-ਖਲਨਾਇਕ',
    '🦹‍♀' => 'ਇਸਤਰੀ ਮਹਾਂ-ਖਲਨਾਇਕ',
    '🧙‍♂' => 'جادوگر بندہ',
    '🧙‍♀' => 'جادوگر زنانی',
    '🧚‍♂' => 'فیری بندہ',
    '🧚‍♀' => 'فیری زنانی',
    '🧛‍♂' => 'خونخوار مرد',
    '🧛‍♀' => 'خونخوار زنانی',
    '🧜‍♂' => 'جل مانس',
    '🧜‍♀' => 'ماہی زن',
    '🧝‍♂' => 'بُھوت بندا',
    '🧝‍♀' => 'بُھوت زنانی',
    '🧞‍♂' => 'مرد جن',
    '🧞‍♀' => 'زنانی جن',
    '🧟‍♂' => 'بندا زومبی',
    '🧟‍♀' => 'زنانی زومبی',
    '💆‍♂' => 'پیغام لیندا مرد',
    '💆‍♀' => 'پیغام لیندی زنانی',
    '💇‍♂' => 'وال کٹاندا بندا',
    '💇‍♀' => 'وال کٹاندی زنانی',
    '🚶‍♂' => 'پیدل تُردا بندہ',
    '🚶‍♀' => 'پیدل تُردی زنانی',
    '🧍‍♂' => 'ਖੜ੍ਹਾ ਆਦਮੀ',
    '🧍‍♀' => 'ਖੜ੍ਹੀ ਔਰਤ',
    '🧎‍♂' => 'ਗੋਡਿਆਂ ਭਾਰ ਬੈਠਾ ਆਦਮੀ',
    '🧎‍♀' => 'ਗੋਡਿਆਂ ਭਾਰ ਬੈਠੀ ਔਰਤ',
    '🧑‍🦯' => 'ਟਟੋਲਣ ਵਾਲੀ ਸੋਟੀ ਫੜੀ ਵਿਅਕਤੀ',
    '👨‍🦯' => 'ਪ੍ਰੋਬਿੰਗ ਕੈਨ ਵਾਲਾ ਆਦਮੀ',
    '👩‍🦯' => 'ਪ੍ਰੋਬਿੰਗ ਕੈਨ ਵਾਲੀ ਔਰਤ',
    '🧑‍🦼' => 'ਮੋਟਰ ਵ੍ਹੀਲਚੇਅਰ ਵਿੱਚ ਵਿਅਕਤੀ',
    '👨‍🦼' => 'ਮੋਟਰ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ‘ਤੇ ਬੈਠਾ ਆਦਮੀ',
    '👩‍🦼' => 'ਮੋਟਰ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ‘ਤੇ ਬੈਠੀ ਔਰਤ',
    '🧑‍🦽' => 'ਹੱਥੀਂ ਚੱਲਣ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ਵਿੱਚ ਵਿਅਕਤੀ',
    '👨‍🦽' => 'ਹੱਥ ਨਾਲ ਚੱਲਣ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ‘ਤੇ ਬੈਠਾ ਆਦਮੀ',
    '👩‍🦽' => 'ਹੱਥ ਨਾਲ ਚੱਲਣ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ ‘ਤੇ ਬੈਠੀ ਔਰਤ',
    '🏃‍♂' => 'بھجدا مرد',
    '🏃‍♀' => 'بھجدی زنانی',
    '🧑‍🩰' => 'ਬੈਲੇ ਡਾਂਸਰ',
    '👯‍♂' => 'خرگوش دے کناں آلا پارٹی کردا بندا',
    '👯‍♀' => 'خرگوش دے کناں آلی پارٹی کردی زنانی',
    '🧖‍♂' => 'بھاپ نال بھرے کمرے وچ مرد',
    '🧖‍♀' => 'بھاپ نال بھرے کمرے وچ زنانی',
    '🧗‍♂' => 'کوہ پیمائی کردا مرد',
    '🧗‍♀' => 'کوہ پیمائی کردی زنانی',
    '🏌‍♂' => 'گالف کھیڈدا مرد',
    '🏌‍♀' => 'گالف کھیڈدی زنانی',
    '🏄‍♂' => 'صرف کردا بندا',
    '🏄‍♀' => 'صرف کردی زنانی',
    '🚣‍♂' => 'چپُو چلاندا بندہ',
    '🚣‍♀' => 'چپُو چلاندی زنانی',
    '🏊‍♂' => 'تیراکی کردا بندہ',
    '🏊‍♀' => 'تیراکی کردی زنانی',
    '⛹‍♂' => 'زور نال گیند کراندا آدمی',
    '⛹‍♀' => 'زور نال گیند کراندی زنانی',
    '🏋‍♂' => 'بھار چُکدا مرد',
    '🏋‍♀' => 'بھار چُکدی زنانی',
    '🚴‍♂' => 'بائیک چلاندا بندا',
    '🚴‍♀' => 'بائیک چلاندی زنانی',
    '🚵‍♂' => 'پہاڑ تے موٹر سائیکل چلاندا بندا',
    '🚵‍♀' => 'پہاڑ تے موٹر سائیکل چلاندی زنانی',
    '🤸‍♂' => 'چھکڑے دا پہیہ چلاندا بندہ',
    '🤸‍♀' => 'چھکڑے دا پہیہ چلاندی زنانی',
    '🤼‍♂' => 'کُشتی لڑدے بندے',
    '🤼‍♀' => 'کُشتی لڑدیاں زنانیاں',
    '🤽‍♂' => 'آبی پولو کھیڈدا بندہ',
    '🤽‍♀' => 'آبی پولو کھیڈدی زنانی',
    '🤾‍♂' => 'ہینڈ بال کھیڈدا بندہ',
    '🤾‍♀' => 'ہینڈ بال کھیڈدی زنانی',
    '🤹‍♂' => 'کرتب وکھاندا بندہ',
    '🤹‍♀' => 'کرتب وکھاندی زنانی',
    '🧘‍♂' => 'کنول دی حآلت وچ مرد',
    '🧘‍♀' => 'کنول دی حالت وچ زنانی',
    '🧑‍🧒' => 'ਪਰਿਵਾਰ: ਪਿਤਾ, ਬੱਚਾ',
    '🐕‍🦺' => 'ਸੇਵਾਦਾਰ ਕੁੱਤਾ',
    '🐈‍⬛' => 'ਕਾਲੀ ਬਿੱਲੀ',
    '🐻‍❄' => 'ਧਰੁਵੀ ਭਾਲੂ',
    '🐦‍⬛' => 'ਕਾਲਾ ਪੰਛੀ',
    '🐦‍🔥' => 'ਫੀਨਿਕਸ',
    '🍋‍🟩' => 'ਲਾਈਮ',
    '🍄‍🟫' => 'ਭੂਰੇ ਮਸ਼ਰੂਮ',
    '⛓‍💥' => 'ਟੁੱਟੀ ਚੇਨ',
    '🏳‍🌈' => 'قوسِ قزح آلا جھنڈا',
    '🏳‍⚧' => 'ਟਰਾਂਸਜੈਂਡਰ ਝੰਡਾ',
    '🏴‍☠' => 'ਲੁਟੇਰਿਆਂ ਦਾ ਝੰਡਾ',
    '👋🏻' => 'ہتھ ہلاندیاں: ہلکی رنگت آلی جلد',
    '👋🏼' => 'ہتھ ہلاندیاں: ہلکی درمیانی رنگت آلی جلد',
    '👋🏽' => 'ہتھ ہلاندیاں: درمیانی رنگت آلی جلد',
    '👋🏾' => 'ہتھ ہلاندیاں: درمیانی کالی رنگت آلی جلد',
    '👋🏿' => 'ہتھ ہلاندیاں: کالی رنگت آلی جلد',
    '🤚🏻' => 'ہتھ دا ابھریا پچھلا پاسا: ہلکی رنگت آلی جلد',
    '🤚🏼' => 'ہتھ دا ابھریا پچھلا پاسا: ہلکی درمیانی رنگت آلی جلد',
    '🤚🏽' => 'ہتھ دا ابھریا پچھلا پاسا: درمیانی رنگت آلی جلد',
    '🤚🏾' => 'ہتھ دا ابھریا پچھلا پاسا: درمیانی کالی رنگت آلی جلد',
    '🤚🏿' => 'ہتھ دا ابھریا پچھلا پاسا: کالی رنگت آلی جلد',
    '🖐🏻' => 'چوڑیاں کیتیاں اُنگلاں نال اُوتے کیتا ہتھ: ہلکی رنگت آلی جلد',
    '🖐🏼' => 'چوڑیاں کیتیاں اُنگلاں نال اُوتے کیتا ہتھ: ہلکی درمیانی رنگت آلی جلد',
    '🖐🏽' => 'چوڑیاں کیتیاں اُنگلاں نال اُوتے کیتا ہتھ: درمیانی رنگت آلی جلد',
    '🖐🏾' => 'چوڑیاں کیتیاں اُنگلاں نال اُوتے کیتا ہتھ: درمیانی کالی رنگت آلی جلد',
    '🖐🏿' => 'چوڑیاں کیتیاں اُنگلاں نال اُوتے کیتا ہتھ: کالی رنگت آلی جلد',
    '✋🏻' => 'اُوتے کیتا ہتھ: ہلکی رنگت آلی جلد',
    '✋🏼' => 'اُوتے کیتا ہتھ: ہلکی درمیانی رنگت آلی جلد',
    '✋🏽' => 'اُوتے کیتا ہتھ: درمیانی رنگت آلی جلد',
    '✋🏾' => 'اُوتے کیتا ہتھ: درمیانی کالی رنگت آلی جلد',
    '✋🏿' => 'اُوتے کیتا ہتھ: کالی رنگت آلی جلد',
    '🖖🏻' => 'قلزات دے دیوتا نوں سلامی دینا: ہلکی رنگت آلی جلد',
    '🖖🏼' => 'قلزات دے دیوتا نوں سلامی دینا: ہلکی درمیانی رنگت آلی جلد',
    '🖖🏽' => 'قلزات دے دیوتا نوں سلامی دینا: درمیانی رنگت آلی جلد',
    '🖖🏾' => 'قلزات دے دیوتا نوں سلامی دینا: درمیانی کالی رنگت آلی جلد',
    '🖖🏿' => 'قلزات دے دیوتا نوں سلامی دینا: کالی رنگت آلی جلد',
    '🫱🏻' => 'ਸੱਜੇ ਪਾਸੇ ਹੱਥ: ਗੋਰਾ ਰੰਗ',
    '🫱🏼' => 'ਸੱਜੇ ਪਾਸੇ ਹੱਥ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🫱🏽' => 'ਸੱਜੇ ਪਾਸੇ ਹੱਥ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🫱🏾' => 'ਸੱਜੇ ਪਾਸੇ ਹੱਥ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🫱🏿' => 'ਸੱਜੇ ਪਾਸੇ ਹੱਥ: ਕਾਲਾ ਰੰਗ',
    '🫲🏻' => 'ਖੱਬੇ ਪਾਸੇ ਹੱਥ: ਗੋਰਾ ਰੰਗ',
    '🫲🏼' => 'ਖੱਬੇ ਪਾਸੇ ਹੱਥ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🫲🏽' => 'ਖੱਬੇ ਪਾਸੇ ਹੱਥ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🫲🏾' => 'ਖੱਬੇ ਪਾਸੇ ਹੱਥ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🫲🏿' => 'ਖੱਬੇ ਪਾਸੇ ਹੱਥ: ਕਾਲਾ ਰੰਗ',
    '🫳🏻' => 'ਥੱਲੇ ਵੱਲ ਹਥੇਲੀ: ਗੋਰਾ ਰੰਗ',
    '🫳🏼' => 'ਥੱਲੇ ਵੱਲ ਹਥੇਲੀ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🫳🏽' => 'ਥੱਲੇ ਵੱਲ ਹਥੇਲੀ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🫳🏾' => 'ਥੱਲੇ ਵੱਲ ਹਥੇਲੀ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🫳🏿' => 'ਥੱਲੇ ਵੱਲ ਹਥੇਲੀ: ਕਾਲਾ ਰੰਗ',
    '🫴🏻' => 'ਉੱਤੇ ਵੱਲ ਹਥੇਲੀ: ਗੋਰਾ ਰੰਗ',
    '🫴🏼' => 'ਉੱਤੇ ਵੱਲ ਹਥੇਲੀ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🫴🏽' => 'ਉੱਤੇ ਵੱਲ ਹਥੇਲੀ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🫴🏾' => 'ਉੱਤੇ ਵੱਲ ਹਥੇਲੀ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🫴🏿' => 'ਉੱਤੇ ਵੱਲ ਹਥੇਲੀ: ਕਾਲਾ ਰੰਗ',
    '🫷🏻' => 'ਖੱਬੀ ਦਿਸ਼ਾ ਵੱਲ ਧੱਕਾ ਲਾਉਂਦਾ ਹੱਥ: ਗੋਰਾ ਰੰਗ',
    '🫷🏼' => 'ਖੱਬੀ ਦਿਸ਼ਾ ਵੱਲ ਧੱਕਾ ਲਾਉਂਦਾ ਹੱਥ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🫷🏽' => 'ਖੱਬੀ ਦਿਸ਼ਾ ਵੱਲ ਧੱਕਾ ਲਾਉਂਦਾ ਹੱਥ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🫷🏾' => 'ਖੱਬੀ ਦਿਸ਼ਾ ਵੱਲ ਧੱਕਾ ਲਾਉਂਦਾ ਹੱਥ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🫷🏿' => 'ਖੱਬੀ ਦਿਸ਼ਾ ਵੱਲ ਧੱਕਾ ਲਾਉਂਦਾ ਹੱਥ: ਕਾਲਾ ਰੰਗ',
    '🫸🏻' => 'ਸੱਜੀ ਦਿਸ਼ਾ ਵੱਲ ਧੱਕਾ ਲਾਉਂਦਾ ਹੱਥ: ਗੋਰਾ ਰੰਗ',
    '🫸🏼' => 'ਸੱਜੀ ਦਿਸ਼ਾ ਵੱਲ ਧੱਕਾ ਲਾਉਂਦਾ ਹੱਥ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🫸🏽' => 'ਸੱਜੀ ਦਿਸ਼ਾ ਵੱਲ ਧੱਕਾ ਲਾਉਂਦਾ ਹੱਥ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🫸🏾' => 'ਸੱਜੀ ਦਿਸ਼ਾ ਵੱਲ ਧੱਕਾ ਲਾਉਂਦਾ ਹੱਥ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🫸🏿' => 'ਸੱਜੀ ਦਿਸ਼ਾ ਵੱਲ ਧੱਕਾ ਲਾਉਂਦਾ ਹੱਥ: ਕਾਲਾ ਰੰਗ',
    '👌🏻' => 'ٹھیک اے ہتھ: ہلکی رنگت آلی جلد',
    '👌🏼' => 'ٹھیک اے ہتھ: ہلکی درمیانی رنگت آلی جلد',
    '👌🏽' => 'ٹھیک اے ہتھ: درمیانی رنگت آلی جلد',
    '👌🏾' => 'ٹھیک اے ہتھ: درمیانی کالی رنگت آلی جلد',
    '👌🏿' => 'ٹھیک اے ہتھ: کالی رنگت آلی جلد',
    '🤌🏻' => 'ਇਕੱਠੀਆਂ ਉਂਗਲਾਂ: ਗੋਰਾ ਰੰਗ',
    '🤌🏼' => 'ਇਕੱਠੀਆਂ ਉਂਗਲਾਂ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🤌🏽' => 'ਇਕੱਠੀਆਂ ਉਂਗਲਾਂ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🤌🏾' => 'ਇਕੱਠੀਆਂ ਉਂਗਲਾਂ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🤌🏿' => 'ਇਕੱਠੀਆਂ ਉਂਗਲਾਂ: ਕਾਲਾ ਰੰਗ',
    '🤏🏻' => 'ਚੂੰਢੀ ਜਿੰਨਾ: ਗੋਰਾ ਰੰਗ',
    '🤏🏼' => 'ਚੂੰਢੀ ਜਿੰਨਾ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🤏🏽' => 'ਚੂੰਢੀ ਜਿੰਨਾ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🤏🏾' => 'ਚੂੰਢੀ ਜਿੰਨਾ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🤏🏿' => 'ਚੂੰਢੀ ਜਿੰਨਾ: ਕਾਲਾ ਰੰਗ',
    '✌🏻' => 'فتح دا ہتھ: ہلکی رنگت آلی جلد',
    '✌🏼' => 'فتح دا ہتھ: ہلکی درمیانی رنگت آلی جلد',
    '✌🏽' => 'فتح دا ہتھ: درمیانی رنگت آلی جلد',
    '✌🏾' => 'فتح دا ہتھ: درمیانی کالی رنگت آلی جلد',
    '✌🏿' => 'فتح دا ہتھ: کالی رنگت آلی جلد',
    '🤞🏻' => 'اُنگلاں آرپار کرنا: ہلکی رنگت آلی جلد',
    '🤞🏼' => 'اُنگلاں آرپار کرنا: ہلکی درمیانی رنگت آلی جلد',
    '🤞🏽' => 'اُنگلاں آرپار کرنا: درمیانی رنگت آلی جلد',
    '🤞🏾' => 'اُنگلاں آرپار کرنا: درمیانی کالی رنگت آلی جلد',
    '🤞🏿' => 'اُنگلاں آرپار کرنا: کالی رنگت آلی جلد',
    '🫰🏻' => 'ਚੁਟਕੀ ਮਾਰਦਾ ਹੱਥ: ਗੋਰਾ ਰੰਗ',
    '🫰🏼' => 'ਚੁਟਕੀ ਮਾਰਦਾ ਹੱਥ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🫰🏽' => 'ਚੁਟਕੀ ਮਾਰਦਾ ਹੱਥ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🫰🏾' => 'ਚੁਟਕੀ ਮਾਰਦਾ ਹੱਥ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🫰🏿' => 'ਚੁਟਕੀ ਮਾਰਦਾ ਹੱਥ: ਕਾਲਾ ਰੰਗ',
    '🤟🏻' => 'تہاڈے نال پریم آ دا اشارہ: ہلکی رنگت آلی جلد',
    '🤟🏼' => 'تہاڈے نال پریم آ دا اشارہ: ہلکی درمیانی رنگت آلی جلد',
    '🤟🏽' => 'تہاڈے نال پریم آ دا اشارہ: درمیانی رنگت آلی جلد',
    '🤟🏾' => 'تہاڈے نال پریم آ دا اشارہ: درمیانی کالی رنگت آلی جلد',
    '🤟🏿' => 'تہاڈے نال پریم آ دا اشارہ: کالی رنگت آلی جلد',
    '🤘🏻' => 'سینگ سائن آف کرو: ہلکی رنگت آلی جلد',
    '🤘🏼' => 'سینگ سائن آف کرو: ہلکی درمیانی رنگت آلی جلد',
    '🤘🏽' => 'سینگ سائن آف کرو: درمیانی رنگت آلی جلد',
    '🤘🏾' => 'سینگ سائن آف کرو: درمیانی کالی رنگت آلی جلد',
    '🤘🏿' => 'سینگ سائن آف کرو: کالی رنگت آلی جلد',
    '🤙🏻' => 'کال کردا ہتھ: ہلکی رنگت آلی جلد',
    '🤙🏼' => 'کال کردا ہتھ: ہلکی درمیانی رنگت آلی جلد',
    '🤙🏽' => 'کال کردا ہتھ: درمیانی رنگت آلی جلد',
    '🤙🏾' => 'کال کردا ہتھ: درمیانی کالی رنگت آلی جلد',
    '🤙🏿' => 'کال کردا ہتھ: کالی رنگت آلی جلد',
    '👈🏻' => 'ہتھ دے مخالف پاسیوں شہادت دی انگلی نال اوتے کھبے اشارہ کردیاں ہوئیاں: ہلکی رنگت آلی جلد',
    '👈🏼' => 'ہتھ دے مخالف پاسیوں شہادت دی انگلی نال اوتے کھبے اشارہ کردیاں ہوئیاں: ہلکی درمیانی رنگت آلی جلد',
    '👈🏽' => 'ہتھ دے مخالف پاسیوں شہادت دی انگلی نال اوتے کھبے اشارہ کردیاں ہوئیاں: درمیانی رنگت آلی جلد',
    '👈🏾' => 'ہتھ دے مخالف پاسیوں شہادت دی انگلی نال اوتے کھبے اشارہ کردیاں ہوئیاں: درمیانی کالی رنگت آلی جلد',
    '👈🏿' => 'ہتھ دے مخالف پاسیوں شہادت دی انگلی نال اوتے کھبے اشارہ کردیاں ہوئیاں: کالی رنگت آلی جلد',
    '👉🏻' => 'ہتھ دے مخالف پاسیوں شہادت دی انگلی نال سجے اشارہ کردیاں ہوئیاں: ہلکی رنگت آلی جلد',
    '👉🏼' => 'ہتھ دے مخالف پاسیوں شہادت دی انگلی نال سجے اشارہ کردیاں ہوئیاں: ہلکی درمیانی رنگت آلی جلد',
    '👉🏽' => 'ہتھ دے مخالف پاسیوں شہادت دی انگلی نال سجے اشارہ کردیاں ہوئیاں: درمیانی رنگت آلی جلد',
    '👉🏾' => 'ہتھ دے مخالف پاسیوں شہادت دی انگلی نال سجے اشارہ کردیاں ہوئیاں: درمیانی کالی رنگت آلی جلد',
    '👉🏿' => 'ہتھ دے مخالف پاسیوں شہادت دی انگلی نال سجے اشارہ کردیاں ہوئیاں: کالی رنگت آلی جلد',
    '👆🏻' => 'ہتھ دے مخالف پاسیوں شہادت دی انگلی نال اوتے اشارہ کردیاں ہوئیاں: ہلکی رنگت آلی جلد',
    '👆🏼' => 'ہتھ دے مخالف پاسیوں شہادت دی انگلی نال اوتے اشارہ کردیاں ہوئیاں: ہلکی درمیانی رنگت آلی جلد',
    '👆🏽' => 'ہتھ دے مخالف پاسیوں شہادت دی انگلی نال اوتے اشارہ کردیاں ہوئیاں: درمیانی رنگت آلی جلد',
    '👆🏾' => 'ہتھ دے مخالف پاسیوں شہادت دی انگلی نال اوتے اشارہ کردیاں ہوئیاں: درمیانی کالی رنگت آلی جلد',
    '👆🏿' => 'ہتھ دے مخالف پاسیوں شہادت دی انگلی نال اوتے اشارہ کردیاں ہوئیاں: کالی رنگت آلی جلد',
    '🖕🏻' => 'درمیانی اُنگل: ہلکی رنگت آلی جلد',
    '🖕🏼' => 'درمیانی اُنگل: ہلکی درمیانی رنگت آلی جلد',
    '🖕🏽' => 'درمیانی اُنگل: درمیانی رنگت آلی جلد',
    '🖕🏾' => 'درمیانی اُنگل: درمیانی کالی رنگت آلی جلد',
    '🖕🏿' => 'درمیانی اُنگل: کالی رنگت آلی جلد',
    '👇🏻' => 'ہتھ دے مخالف پاسیوں انگشت شہادت نال ہیٹھاں اشارہ کردیاں ہوئیاں: ہلکی رنگت آلی جلد',
    '👇🏼' => 'ہتھ دے مخالف پاسیوں انگشت شہادت نال ہیٹھاں اشارہ کردیاں ہوئیاں: ہلکی درمیانی رنگت آلی جلد',
    '👇🏽' => 'ہتھ دے مخالف پاسیوں انگشت شہادت نال ہیٹھاں اشارہ کردیاں ہوئیاں: درمیانی رنگت آلی جلد',
    '👇🏾' => 'ہتھ دے مخالف پاسیوں انگشت شہادت نال ہیٹھاں اشارہ کردیاں ہوئیاں: درمیانی کالی رنگت آلی جلد',
    '👇🏿' => 'ہتھ دے مخالف پاسیوں انگشت شہادت نال ہیٹھاں اشارہ کردیاں ہوئیاں: کالی رنگت آلی جلد',
    '☝🏻' => 'اوتے اشارہ کردی شہادت آلی اُنگل: ہلکی رنگت آلی جلد',
    '☝🏼' => 'اوتے اشارہ کردی شہادت آلی اُنگل: ہلکی درمیانی رنگت آلی جلد',
    '☝🏽' => 'اوتے اشارہ کردی شہادت آلی اُنگل: درمیانی رنگت آلی جلد',
    '☝🏾' => 'اوتے اشارہ کردی شہادت آلی اُنگل: درمیانی کالی رنگت آلی جلد',
    '☝🏿' => 'اوتے اشارہ کردی شہادت آلی اُنگل: کالی رنگت آلی جلد',
    '🫵🏻' => 'ਦਰਸ਼ਕ ਵੱਲ ਇਸ਼ਾਰਾ ਕਰਦੀ ਉਂਗਲ: ਗੋਰਾ ਰੰਗ',
    '🫵🏼' => 'ਦਰਸ਼ਕ ਵੱਲ ਇਸ਼ਾਰਾ ਕਰਦੀ ਉਂਗਲ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🫵🏽' => 'ਦਰਸ਼ਕ ਵੱਲ ਇਸ਼ਾਰਾ ਕਰਦੀ ਉਂਗਲ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🫵🏾' => 'ਦਰਸ਼ਕ ਵੱਲ ਇਸ਼ਾਰਾ ਕਰਦੀ ਉਂਗਲ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🫵🏿' => 'ਦਰਸ਼ਕ ਵੱਲ ਇਸ਼ਾਰਾ ਕਰਦੀ ਉਂਗਲ: ਕਾਲਾ ਰੰਗ',
    '👍🏻' => 'انگوٹھا اوتے: ہلکی رنگت آلی جلد',
    '👍🏼' => 'انگوٹھا اوتے: ہلکی درمیانی رنگت آلی جلد',
    '👍🏽' => 'انگوٹھا اوتے: درمیانی رنگت آلی جلد',
    '👍🏾' => 'انگوٹھا اوتے: درمیانی کالی رنگت آلی جلد',
    '👍🏿' => 'انگوٹھا اوتے: کالی رنگت آلی جلد',
    '👎🏻' => 'انگوٹھا ہیٹھاں: ہلکی رنگت آلی جلد',
    '👎🏼' => 'انگوٹھا ہیٹھاں: ہلکی درمیانی رنگت آلی جلد',
    '👎🏽' => 'انگوٹھا ہیٹھاں: درمیانی رنگت آلی جلد',
    '👎🏾' => 'انگوٹھا ہیٹھاں: درمیانی کالی رنگت آلی جلد',
    '👎🏿' => 'انگوٹھا ہیٹھاں: کالی رنگت آلی جلد',
    '✊🏻' => 'ابھاری ہوئی مُٹھی: ہلکی رنگت آلی جلد',
    '✊🏼' => 'ابھاری ہوئی مُٹھی: ہلکی درمیانی رنگت آلی جلد',
    '✊🏽' => 'ابھاری ہوئی مُٹھی: درمیانی رنگت آلی جلد',
    '✊🏾' => 'ابھاری ہوئی مُٹھی: درمیانی کالی رنگت آلی جلد',
    '✊🏿' => 'ابھاری ہوئی مُٹھی: کالی رنگت آلی جلد',
    '👊🏻' => 'آن آلی مُٹھی: ہلکی رنگت آلی جلد',
    '👊🏼' => 'آن آلی مُٹھی: ہلکی درمیانی رنگت آلی جلد',
    '👊🏽' => 'آن آلی مُٹھی: درمیانی رنگت آلی جلد',
    '👊🏾' => 'آن آلی مُٹھی: درمیانی کالی رنگت آلی جلد',
    '👊🏿' => 'آن آلی مُٹھی: کالی رنگت آلی جلد',
    '🤛🏻' => 'کھبے پاسے سامنا کردی مُٹھی: ہلکی رنگت آلی جلد',
    '🤛🏼' => 'کھبے پاسے سامنا کردی مُٹھی: ہلکی درمیانی رنگت آلی جلد',
    '🤛🏽' => 'کھبے پاسے سامنا کردی مُٹھی: درمیانی رنگت آلی جلد',
    '🤛🏾' => 'کھبے پاسے سامنا کردی مُٹھی: درمیانی کالی رنگت آلی جلد',
    '🤛🏿' => 'کھبے پاسے سامنا کردی مُٹھی: کالی رنگت آلی جلد',
    '🤜🏻' => 'سجے پاسے سامنا کردی مٹھی: ہلکی رنگت آلی جلد',
    '🤜🏼' => 'سجے پاسے سامنا کردی مٹھی: ہلکی درمیانی رنگت آلی جلد',
    '🤜🏽' => 'سجے پاسے سامنا کردی مٹھی: درمیانی رنگت آلی جلد',
    '🤜🏾' => 'سجے پاسے سامنا کردی مٹھی: درمیانی کالی رنگت آلی جلد',
    '🤜🏿' => 'سجے پاسے سامنا کردی مٹھی: کالی رنگت آلی جلد',
    '👏🏻' => 'تالیاں وجاندا ہتھ: ہلکی رنگت آلی جلد',
    '👏🏼' => 'تالیاں وجاندا ہتھ: ہلکی درمیانی رنگت آلی جلد',
    '👏🏽' => 'تالیاں وجاندا ہتھ: درمیانی رنگت آلی جلد',
    '👏🏾' => 'تالیاں وجاندا ہتھ: درمیانی کالی رنگت آلی جلد',
    '👏🏿' => 'تالیاں وجاندا ہتھ: کالی رنگت آلی جلد',
    '🙌🏻' => 'ہتھ اُوچا کرنا: ہلکی رنگت آلی جلد',
    '🙌🏼' => 'ہتھ اُوچا کرنا: ہلکی درمیانی رنگت آلی جلد',
    '🙌🏽' => 'ہتھ اُوچا کرنا: درمیانی رنگت آلی جلد',
    '🙌🏾' => 'ہتھ اُوچا کرنا: درمیانی کالی رنگت آلی جلد',
    '🙌🏿' => 'ہتھ اُوچا کرنا: کالی رنگت آلی جلد',
    '🫶🏻' => 'ਦਿਲ ਬਣੇ ਹੱਥ: ਗੋਰਾ ਰੰਗ',
    '🫶🏼' => 'ਦਿਲ ਬਣੇ ਹੱਥ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🫶🏽' => 'ਦਿਲ ਬਣੇ ਹੱਥ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🫶🏾' => 'ਦਿਲ ਬਣੇ ਹੱਥ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🫶🏿' => 'ਦਿਲ ਬਣੇ ਹੱਥ: ਕਾਲਾ ਰੰਗ',
    '👐🏻' => 'کھلے ہتھ: ہلکی رنگت آلی جلد',
    '👐🏼' => 'کھلے ہتھ: ہلکی درمیانی رنگت آلی جلد',
    '👐🏽' => 'کھلے ہتھ: درمیانی رنگت آلی جلد',
    '👐🏾' => 'کھلے ہتھ: درمیانی کالی رنگت آلی جلد',
    '👐🏿' => 'کھلے ہتھ: کالی رنگت آلی جلد',
    '🤲🏻' => 'اکٹھے ہتھلیاں اُوتے کرنا: ہلکی رنگت آلی جلد',
    '🤲🏼' => 'اکٹھے ہتھلیاں اُوتے کرنا: ہلکی درمیانی رنگت آلی جلد',
    '🤲🏽' => 'اکٹھے ہتھلیاں اُوتے کرنا: درمیانی رنگت آلی جلد',
    '🤲🏾' => 'اکٹھے ہتھلیاں اُوتے کرنا: درمیانی کالی رنگت آلی جلد',
    '🤲🏿' => 'اکٹھے ہتھلیاں اُوتے کرنا: کالی رنگت آلی جلد',
    '🤝🏻' => 'ہتھ ملانا: ہلکی رنگت آلی جلد',
    '🤝🏼' => 'ہتھ ملانا: ہلکی درمیانی رنگت آلی جلد',
    '🤝🏽' => 'ہتھ ملانا: درمیانی رنگت آلی جلد',
    '🤝🏾' => 'ہتھ ملانا: درمیانی کالی رنگت آلی جلد',
    '🤝🏿' => 'ہتھ ملانا: کالی رنگت آلی جلد',
    '🙏🏻' => 'دوہرے کیتے ہتھ: ہلکی رنگت آلی جلد',
    '🙏🏼' => 'دوہرے کیتے ہتھ: ہلکی درمیانی رنگت آلی جلد',
    '🙏🏽' => 'دوہرے کیتے ہتھ: درمیانی رنگت آلی جلد',
    '🙏🏾' => 'دوہرے کیتے ہتھ: درمیانی کالی رنگت آلی جلد',
    '🙏🏿' => 'دوہرے کیتے ہتھ: کالی رنگت آلی جلد',
    '✍🏻' => 'لکھائی کردا ہتھ: ہلکی رنگت آلی جلد',
    '✍🏼' => 'لکھائی کردا ہتھ: ہلکی درمیانی رنگت آلی جلد',
    '✍🏽' => 'لکھائی کردا ہتھ: درمیانی رنگت آلی جلد',
    '✍🏾' => 'لکھائی کردا ہتھ: درمیانی کالی رنگت آلی جلد',
    '✍🏿' => 'لکھائی کردا ہتھ: کالی رنگت آلی جلد',
    '💅🏻' => 'نوں پالش: ہلکی رنگت آلی جلد',
    '💅🏼' => 'نوں پالش: ہلکی درمیانی رنگت آلی جلد',
    '💅🏽' => 'نوں پالش: درمیانی رنگت آلی جلد',
    '💅🏾' => 'نوں پالش: درمیانی کالی رنگت آلی جلد',
    '💅🏿' => 'نوں پالش: کالی رنگت آلی جلد',
    '🤳🏻' => 'سیلفی: ہلکی رنگت آلی جلد',
    '🤳🏼' => 'سیلفی: ہلکی درمیانی رنگت آلی جلد',
    '🤳🏽' => 'سیلفی: درمیانی رنگت آلی جلد',
    '🤳🏾' => 'سیلفی: درمیانی کالی رنگت آلی جلد',
    '🤳🏿' => 'سیلفی: کالی رنگت آلی جلد',
    '💪🏻' => 'دو سراں آلا خم دار پٹھا: ہلکی رنگت آلی جلد',
    '💪🏼' => 'دو سراں آلا خم دار پٹھا: ہلکی درمیانی رنگت آلی جلد',
    '💪🏽' => 'دو سراں آلا خم دار پٹھا: درمیانی رنگت آلی جلد',
    '💪🏾' => 'دو سراں آلا خم دار پٹھا: درمیانی کالی رنگت آلی جلد',
    '💪🏿' => 'دو سراں آلا خم دار پٹھا: کالی رنگت آلی جلد',
    '🦵🏻' => 'ਲੱਤ: ਗੋਰਾ ਰੰਗ',
    '🦵🏼' => 'ਲੱਤ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🦵🏽' => 'ਲੱਤ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🦵🏾' => 'ਲੱਤ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🦵🏿' => 'ਲੱਤ: ਕਾਲਾ ਰੰਗ',
    '🦶🏻' => 'ਪੈਰ: ਗੋਰਾ ਰੰਗ',
    '🦶🏼' => 'ਪੈਰ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🦶🏽' => 'ਪੈਰ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🦶🏾' => 'ਪੈਰ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🦶🏿' => 'ਪੈਰ: ਕਾਲਾ ਰੰਗ',
    '👂🏻' => 'کان: ہلکی رنگت آلی جلد',
    '👂🏼' => 'کان: ہلکی درمیانی رنگت آلی جلد',
    '👂🏽' => 'کان: درمیانی رنگت آلی جلد',
    '👂🏾' => 'کان: درمیانی کالی رنگت آلی جلد',
    '👂🏿' => 'کان: کالی رنگت آلی جلد',
    '🦻🏻' => 'ਸੁਣਨ ਵਾਲੀ ਮਸ਼ੀਨ ਲੱਗਿਆ ਕੰਨ: ਗੋਰਾ ਰੰਗ',
    '🦻🏼' => 'ਸੁਣਨ ਵਾਲੀ ਮਸ਼ੀਨ ਲੱਗਿਆ ਕੰਨ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🦻🏽' => 'ਸੁਣਨ ਵਾਲੀ ਮਸ਼ੀਨ ਲੱਗਿਆ ਕੰਨ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🦻🏾' => 'ਸੁਣਨ ਵਾਲੀ ਮਸ਼ੀਨ ਲੱਗਿਆ ਕੰਨ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🦻🏿' => 'ਸੁਣਨ ਵਾਲੀ ਮਸ਼ੀਨ ਲੱਗਿਆ ਕੰਨ: ਕਾਲਾ ਰੰਗ',
    '👃🏻' => 'نک: ہلکی رنگت آلی جلد',
    '👃🏼' => 'نک: ہلکی درمیانی رنگت آلی جلد',
    '👃🏽' => 'نک: درمیانی رنگت آلی جلد',
    '👃🏾' => 'نک: درمیانی کالی رنگت آلی جلد',
    '👃🏿' => 'نک: کالی رنگت آلی جلد',
    '👶🏻' => 'نیانا: ہلکی رنگت آلی جلد',
    '👶🏼' => 'نیانا: ہلکی درمیانی رنگت آلی جلد',
    '👶🏽' => 'نیانا: درمیانی رنگت آلی جلد',
    '👶🏾' => 'نیانا: درمیانی کالی رنگت آلی جلد',
    '👶🏿' => 'نیانا: کالی رنگت آلی جلد',
    '🧒🏻' => 'بال: ہلکی رنگت آلی جلد',
    '🧒🏼' => 'بال: ہلکی درمیانی رنگت آلی جلد',
    '🧒🏽' => 'بال: درمیانی رنگت آلی جلد',
    '🧒🏾' => 'بال: درمیانی کالی رنگت آلی جلد',
    '🧒🏿' => 'بال: کالی رنگت آلی جلد',
    '👦🏻' => 'منڈا: ہلکی رنگت آلی جلد',
    '👦🏼' => 'منڈا: ہلکی درمیانی رنگت آلی جلد',
    '👦🏽' => 'منڈا: درمیانی رنگت آلی جلد',
    '👦🏾' => 'منڈا: درمیانی کالی رنگت آلی جلد',
    '👦🏿' => 'منڈا: کالی رنگت آلی جلد',
    '👧🏻' => 'کڑی: ہلکی رنگت آلی جلد',
    '👧🏼' => 'کڑی: ہلکی درمیانی رنگت آلی جلد',
    '👧🏽' => 'کڑی: درمیانی رنگت آلی جلد',
    '👧🏾' => 'کڑی: درمیانی کالی رنگت آلی جلد',
    '👧🏿' => 'کڑی: کالی رنگت آلی جلد',
    '🧑🏻' => 'بالغ: ہلکی رنگت آلی جلد',
    '🧑🏼' => 'بالغ: ہلکی درمیانی رنگت آلی جلد',
    '🧑🏽' => 'بالغ: درمیانی رنگت آلی جلد',
    '🧑🏾' => 'بالغ: درمیانی کالی رنگت آلی جلد',
    '🧑🏿' => 'بالغ: کالی رنگت آلی جلد',
    '👱🏻' => 'بُھورے والاں آلا بندہ: ہلکی رنگت آلی جلد',
    '👱🏼' => 'بُھورے والاں آلا بندہ: ہلکی درمیانی رنگت آلی جلد',
    '👱🏽' => 'بُھورے والاں آلا بندہ: درمیانی رنگت آلی جلد',
    '👱🏾' => 'بُھورے والاں آلا بندہ: درمیانی کالی رنگت آلی جلد',
    '👱🏿' => 'بُھورے والاں آلا بندہ: کالی رنگت آلی جلد',
    '👨🏻' => 'بندہ: ہلکی رنگت آلی جلد',
    '👨🏼' => 'بندہ: ہلکی درمیانی رنگت آلی جلد',
    '👨🏽' => 'بندہ: درمیانی رنگت آلی جلد',
    '👨🏾' => 'بندہ: درمیانی کالی رنگت آلی جلد',
    '👨🏿' => 'بندہ: کالی رنگت آلی جلد',
    '🧔🏻' => 'داڑھی آلا بندا: ہلکی رنگت آلی جلد',
    '🧔🏼' => 'داڑھی آلا بندا: ہلکی درمیانی رنگت آلی جلد',
    '🧔🏽' => 'داڑھی آلا بندا: درمیانی رنگت آلی جلد',
    '🧔🏾' => 'داڑھی آلا بندا: درمیانی کالی رنگت آلی جلد',
    '🧔🏿' => 'داڑھی آلا بندا: کالی رنگت آلی جلد',
    '👩🏻' => 'زنانی: ہلکی رنگت آلی جلد',
    '👩🏼' => 'زنانی: ہلکی درمیانی رنگت آلی جلد',
    '👩🏽' => 'زنانی: درمیانی رنگت آلی جلد',
    '👩🏾' => 'زنانی: درمیانی کالی رنگت آلی جلد',
    '👩🏿' => 'زنانی: کالی رنگت آلی جلد',
    '🧓🏻' => 'سیانے بالغ: ہلکی رنگت آلی جلد',
    '🧓🏼' => 'سیانے بالغ: ہلکی درمیانی رنگت آلی جلد',
    '🧓🏽' => 'سیانے بالغ: درمیانی رنگت آلی جلد',
    '🧓🏾' => 'سیانے بالغ: درمیانی کالی رنگت آلی جلد',
    '🧓🏿' => 'سیانے بالغ: کالی رنگت آلی جلد',
    '👴🏻' => 'بڈھا بندا: ہلکی رنگت آلی جلد',
    '👴🏼' => 'بڈھا بندا: ہلکی درمیانی رنگت آلی جلد',
    '👴🏽' => 'بڈھا بندا: درمیانی رنگت آلی جلد',
    '👴🏾' => 'بڈھا بندا: درمیانی کالی رنگت آلی جلد',
    '👴🏿' => 'بڈھا بندا: کالی رنگت آلی جلد',
    '👵🏻' => 'بڈھی زنانی: ہلکی رنگت آلی جلد',
    '👵🏼' => 'بڈھی زنانی: ہلکی درمیانی رنگت آلی جلد',
    '👵🏽' => 'بڈھی زنانی: درمیانی رنگت آلی جلد',
    '👵🏾' => 'بڈھی زنانی: درمیانی کالی رنگت آلی جلد',
    '👵🏿' => 'بڈھی زنانی: کالی رنگت آلی جلد',
    '🙍🏻' => 'تیوری آلا بندہ: ہلکی رنگت آلی جلد',
    '🙍🏼' => 'تیوری آلا بندہ: ہلکی درمیانی رنگت آلی جلد',
    '🙍🏽' => 'تیوری آلا بندہ: درمیانی رنگت آلی جلد',
    '🙍🏾' => 'تیوری آلا بندہ: درمیانی کالی رنگت آلی جلد',
    '🙍🏿' => 'تیوری آلا بندہ: کالی رنگت آلی جلد',
    '🙎🏻' => 'لٹکیا ہوئیا بندہ: ہلکی رنگت آلی جلد',
    '🙎🏼' => 'لٹکیا ہوئیا بندہ: ہلکی درمیانی رنگت آلی جلد',
    '🙎🏽' => 'لٹکیا ہوئیا بندہ: درمیانی رنگت آلی جلد',
    '🙎🏾' => 'لٹکیا ہوئیا بندہ: درمیانی کالی رنگت آلی جلد',
    '🙎🏿' => 'لٹکیا ہوئیا بندہ: کالی رنگت آلی جلد',
    '🙅🏻' => 'بندہ نہیں دا اشارہ کر دیاں ہوئیاں: ہلکی رنگت آلی جلد',
    '🙅🏼' => 'بندہ نہیں دا اشارہ کر دیاں ہوئیاں: ہلکی درمیانی رنگت آلی جلد',
    '🙅🏽' => 'بندہ نہیں دا اشارہ کر دیاں ہوئیاں: درمیانی رنگت آلی جلد',
    '🙅🏾' => 'بندہ نہیں دا اشارہ کر دیاں ہوئیاں: درمیانی کالی رنگت آلی جلد',
    '🙅🏿' => 'بندہ نہیں دا اشارہ کر دیاں ہوئیاں: کالی رنگت آلی جلد',
    '🙆🏻' => 'بندہ ٹھیک اے دا اشارہ کر دیاں ہوئیاں: ہلکی رنگت آلی جلد',
    '🙆🏼' => 'بندہ ٹھیک اے دا اشارہ کر دیاں ہوئیاں: ہلکی درمیانی رنگت آلی جلد',
    '🙆🏽' => 'بندہ ٹھیک اے دا اشارہ کر دیاں ہوئیاں: درمیانی رنگت آلی جلد',
    '🙆🏾' => 'بندہ ٹھیک اے دا اشارہ کر دیاں ہوئیاں: درمیانی کالی رنگت آلی جلد',
    '🙆🏿' => 'بندہ ٹھیک اے دا اشارہ کر دیاں ہوئیاں: کالی رنگت آلی جلد',
    '💁🏻' => 'ہتھ نال تھپکی دیندا بندہ: ہلکی رنگت آلی جلد',
    '💁🏼' => 'ہتھ نال تھپکی دیندا بندہ: ہلکی درمیانی رنگت آلی جلد',
    '💁🏽' => 'ہتھ نال تھپکی دیندا بندہ: درمیانی رنگت آلی جلد',
    '💁🏾' => 'ہتھ نال تھپکی دیندا بندہ: درمیانی کالی رنگت آلی جلد',
    '💁🏿' => 'ہتھ نال تھپکی دیندا بندہ: کالی رنگت آلی جلد',
    '🙋🏻' => 'ہتھ اُوچا کردا بندا: ہلکی رنگت آلی جلد',
    '🙋🏼' => 'ہتھ اُوچا کردا بندا: ہلکی درمیانی رنگت آلی جلد',
    '🙋🏽' => 'ہتھ اُوچا کردا بندا: درمیانی رنگت آلی جلد',
    '🙋🏾' => 'ہتھ اُوچا کردا بندا: درمیانی کالی رنگت آلی جلد',
    '🙋🏿' => 'ہتھ اُوچا کردا بندا: کالی رنگت آلی جلد',
    '🧏🏻' => 'ਬੋਲ਼ਾ ਵਿਅਕਤੀ: ਗੋਰਾ ਰੰਗ',
    '🧏🏼' => 'ਬੋਲ਼ਾ ਵਿਅਕਤੀ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧏🏽' => 'ਬੋਲ਼ਾ ਵਿਅਕਤੀ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧏🏾' => 'ਬੋਲ਼ਾ ਵਿਅਕਤੀ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🧏🏿' => 'ਬੋਲ਼ਾ ਵਿਅਕਤੀ: ਕਾਲਾ ਰੰਗ',
    '🙇🏻' => 'جُھکیا ہوئیا بندہ: ہلکی رنگت آلی جلد',
    '🙇🏼' => 'جُھکیا ہوئیا بندہ: ہلکی درمیانی رنگت آلی جلد',
    '🙇🏽' => 'جُھکیا ہوئیا بندہ: درمیانی رنگت آلی جلد',
    '🙇🏾' => 'جُھکیا ہوئیا بندہ: درمیانی کالی رنگت آلی جلد',
    '🙇🏿' => 'جُھکیا ہوئیا بندہ: کالی رنگت آلی جلد',
    '🤦🏻' => 'ہتھ منہ اوتے رکھدا بندہ: ہلکی رنگت آلی جلد',
    '🤦🏼' => 'ہتھ منہ اوتے رکھدا بندہ: ہلکی درمیانی رنگت آلی جلد',
    '🤦🏽' => 'ہتھ منہ اوتے رکھدا بندہ: درمیانی رنگت آلی جلد',
    '🤦🏾' => 'ہتھ منہ اوتے رکھدا بندہ: درمیانی کالی رنگت آلی جلد',
    '🤦🏿' => 'ہتھ منہ اوتے رکھدا بندہ: کالی رنگت آلی جلد',
    '🤷🏻' => 'مُڈے اچکاندا بندہ: ہلکی رنگت آلی جلد',
    '🤷🏼' => 'مُڈے اچکاندا بندہ: ہلکی درمیانی رنگت آلی جلد',
    '🤷🏽' => 'مُڈے اچکاندا بندہ: درمیانی رنگت آلی جلد',
    '🤷🏾' => 'مُڈے اچکاندا بندہ: درمیانی کالی رنگت آلی جلد',
    '🤷🏿' => 'مُڈے اچکاندا بندہ: کالی رنگت آلی جلد',
    '👮🏻' => 'پُلس دا افسر: ہلکی رنگت آلی جلد',
    '👮🏼' => 'پُلس دا افسر: ہلکی درمیانی رنگت آلی جلد',
    '👮🏽' => 'پُلس دا افسر: درمیانی رنگت آلی جلد',
    '👮🏾' => 'پُلس دا افسر: درمیانی کالی رنگت آلی جلد',
    '👮🏿' => 'پُلس دا افسر: کالی رنگت آلی جلد',
    '🕵🏻' => 'جاسوس: ہلکی رنگت آلی جلد',
    '🕵🏼' => 'جاسوس: ہلکی درمیانی رنگت آلی جلد',
    '🕵🏽' => 'جاسوس: درمیانی رنگت آلی جلد',
    '🕵🏾' => 'جاسوس: درمیانی کالی رنگت آلی جلد',
    '🕵🏿' => 'جاسوس: کالی رنگت آلی جلد',
    '💂🏻' => 'چوکیدار: ہلکی رنگت آلی جلد',
    '💂🏼' => 'چوکیدار: ہلکی درمیانی رنگت آلی جلد',
    '💂🏽' => 'چوکیدار: درمیانی رنگت آلی جلد',
    '💂🏾' => 'چوکیدار: درمیانی کالی رنگت آلی جلد',
    '💂🏿' => 'چوکیدار: کالی رنگت آلی جلد',
    '🥷🏻' => 'ਨਿੰਜਾ: ਗੋਰਾ ਰੰਗ',
    '🥷🏼' => 'ਨਿੰਜਾ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🥷🏽' => 'ਨਿੰਜਾ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🥷🏾' => 'ਨਿੰਜਾ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🥷🏿' => 'ਨਿੰਜਾ: ਕਾਲਾ ਰੰਗ',
    '👷🏻' => 'تعمیری کم کرن آلے: ہلکی رنگت آلی جلد',
    '👷🏼' => 'تعمیری کم کرن آلے: ہلکی درمیانی رنگت آلی جلد',
    '👷🏽' => 'تعمیری کم کرن آلے: درمیانی رنگت آلی جلد',
    '👷🏾' => 'تعمیری کم کرن آلے: درمیانی کالی رنگت آلی جلد',
    '👷🏿' => 'تعمیری کم کرن آلے: کالی رنگت آلی جلد',
    '🫅🏻' => 'ਤਾਜ ਵਾਲਾ ਵਿਅਕਤੀ: ਗੋਰਾ ਰੰਗ',
    '🫅🏼' => 'ਤਾਜ ਵਾਲਾ ਵਿਅਕਤੀ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🫅🏽' => 'ਤਾਜ ਵਾਲਾ ਵਿਅਕਤੀ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🫅🏾' => 'ਤਾਜ ਵਾਲਾ ਵਿਅਕਤੀ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🫅🏿' => 'ਤਾਜ ਵਾਲਾ ਵਿਅਕਤੀ: ਕਾਲਾ ਰੰਗ',
    '🤴🏻' => 'شہزادہ: ہلکی رنگت آلی جلد',
    '🤴🏼' => 'شہزادہ: ہلکی درمیانی رنگت آلی جلد',
    '🤴🏽' => 'شہزادہ: درمیانی رنگت آلی جلد',
    '🤴🏾' => 'شہزادہ: درمیانی کالی رنگت آلی جلد',
    '🤴🏿' => 'شہزادہ: کالی رنگت آلی جلد',
    '👸🏻' => 'شہزادی: ہلکی رنگت آلی جلد',
    '👸🏼' => 'شہزادی: ہلکی درمیانی رنگت آلی جلد',
    '👸🏽' => 'شہزادی: درمیانی رنگت آلی جلد',
    '👸🏾' => 'شہزادی: درمیانی کالی رنگت آلی جلد',
    '👸🏿' => 'شہزادی: کالی رنگت آلی جلد',
    '👳🏻' => 'پگڑی پاندا بندہ: ہلکی رنگت آلی جلد',
    '👳🏼' => 'پگڑی پاندا بندہ: ہلکی درمیانی رنگت آلی جلد',
    '👳🏽' => 'پگڑی پاندا بندہ: درمیانی رنگت آلی جلد',
    '👳🏾' => 'پگڑی پاندا بندہ: درمیانی کالی رنگت آلی جلد',
    '👳🏿' => 'پگڑی پاندا بندہ: کالی رنگت آلی جلد',
    '👲🏻' => 'چینی ٹوپی نال بندہ: ہلکی رنگت آلی جلد',
    '👲🏼' => 'چینی ٹوپی نال بندہ: ہلکی درمیانی رنگت آلی جلد',
    '👲🏽' => 'چینی ٹوپی نال بندہ: درمیانی رنگت آلی جلد',
    '👲🏾' => 'چینی ٹوپی نال بندہ: درمیانی کالی رنگت آلی جلد',
    '👲🏿' => 'چینی ٹوپی نال بندہ: کالی رنگت آلی جلد',
    '🧕🏻' => 'سر دے رومال نال زنانی: ہلکی رنگت آلی جلد',
    '🧕🏼' => 'سر دے رومال نال زنانی: ہلکی درمیانی رنگت آلی جلد',
    '🧕🏽' => 'سر دے رومال نال زنانی: درمیانی رنگت آلی جلد',
    '🧕🏾' => 'سر دے رومال نال زنانی: درمیانی کالی رنگت آلی جلد',
    '🧕🏿' => 'سر دے رومال نال زنانی: کالی رنگت آلی جلد',
    '🤵🏻' => 'خاص جیکٹ وچ بندہ: ہلکی رنگت آلی جلد',
    '🤵🏼' => 'خاص جیکٹ وچ بندہ: ہلکی درمیانی رنگت آلی جلد',
    '🤵🏽' => 'خاص جیکٹ وچ بندہ: درمیانی رنگت آلی جلد',
    '🤵🏾' => 'خاص جیکٹ وچ بندہ: درمیانی کالی رنگت آلی جلد',
    '🤵🏿' => 'خاص جیکٹ وچ بندہ: کالی رنگت آلی جلد',
    '👰🏻' => 'نقاب نال ووہٹی: ہلکی رنگت آلی جلد',
    '👰🏼' => 'نقاب نال ووہٹی: ہلکی درمیانی رنگت آلی جلد',
    '👰🏽' => 'نقاب نال ووہٹی: درمیانی رنگت آلی جلد',
    '👰🏾' => 'نقاب نال ووہٹی: درمیانی کالی رنگت آلی جلد',
    '👰🏿' => 'نقاب نال ووہٹی: کالی رنگت آلی جلد',
    '🤰🏻' => 'حاملہ زنانی: ہلکی رنگت آلی جلد',
    '🤰🏼' => 'حاملہ زنانی: ہلکی درمیانی رنگت آلی جلد',
    '🤰🏽' => 'حاملہ زنانی: درمیانی رنگت آلی جلد',
    '🤰🏾' => 'حاملہ زنانی: درمیانی کالی رنگت آلی جلد',
    '🤰🏿' => 'حاملہ زنانی: کالی رنگت آلی جلد',
    '🫃🏻' => 'ਗਰਭਵਤੀ ਦਿਸਦਾ ਆਦਮੀ: ਗੋਰਾ ਰੰਗ',
    '🫃🏼' => 'ਗਰਭਵਤੀ ਦਿਸਦਾ ਆਦਮੀ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🫃🏽' => 'ਗਰਭਵਤੀ ਦਿਸਦਾ ਆਦਮੀ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🫃🏾' => 'ਗਰਭਵਤੀ ਦਿਸਦਾ ਆਦਮੀ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🫃🏿' => 'ਗਰਭਵਤੀ ਦਿਸਦਾ ਆਦਮੀ: ਕਾਲਾ ਰੰਗ',
    '🫄🏻' => 'ਗਰਭਵਤੀ ਦਿਸਦਾ ਵਿਅਕਤੀ: ਗੋਰਾ ਰੰਗ',
    '🫄🏼' => 'ਗਰਭਵਤੀ ਦਿਸਦਾ ਵਿਅਕਤੀ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🫄🏽' => 'ਗਰਭਵਤੀ ਦਿਸਦਾ ਵਿਅਕਤੀ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🫄🏾' => 'ਗਰਭਵਤੀ ਦਿਸਦਾ ਵਿਅਕਤੀ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🫄🏿' => 'ਗਰਭਵਤੀ ਦਿਸਦਾ ਵਿਅਕਤੀ: ਕਾਲਾ ਰੰਗ',
    '🤱🏻' => 'دودھ پین آلا: ہلکی رنگت آلی جلد',
    '🤱🏼' => 'دودھ پین آلا: ہلکی درمیانی رنگت آلی جلد',
    '🤱🏽' => 'دودھ پین آلا: درمیانی رنگت آلی جلد',
    '🤱🏾' => 'دودھ پین آلا: درمیانی کالی رنگت آلی جلد',
    '🤱🏿' => 'دودھ پین آلا: کالی رنگت آلی جلد',
    '👼🏻' => 'فرشتہ بال: ہلکی رنگت آلی جلد',
    '👼🏼' => 'فرشتہ بال: ہلکی درمیانی رنگت آلی جلد',
    '👼🏽' => 'فرشتہ بال: درمیانی رنگت آلی جلد',
    '👼🏾' => 'فرشتہ بال: درمیانی کالی رنگت آلی جلد',
    '👼🏿' => 'فرشتہ بال: کالی رنگت آلی جلد',
    '🎅🏻' => 'سنٹا کلاز: ہلکی رنگت آلی جلد',
    '🎅🏼' => 'سنٹا کلاز: ہلکی درمیانی رنگت آلی جلد',
    '🎅🏽' => 'سنٹا کلاز: درمیانی رنگت آلی جلد',
    '🎅🏾' => 'سنٹا کلاز: درمیانی کالی رنگت آلی جلد',
    '🎅🏿' => 'سنٹا کلاز: کالی رنگت آلی جلد',
    '🤶🏻' => 'مسز کلاز: ہلکی رنگت آلی جلد',
    '🤶🏼' => 'مسز کلاز: ہلکی درمیانی رنگت آلی جلد',
    '🤶🏽' => 'مسز کلاز: درمیانی رنگت آلی جلد',
    '🤶🏾' => 'مسز کلاز: درمیانی کالی رنگت آلی جلد',
    '🤶🏿' => 'مسز کلاز: کالی رنگت آلی جلد',
    '🦸🏻' => 'ਸੁਪਰ-ਹੀਰੋ: ਗੋਰਾ ਰੰਗ',
    '🦸🏼' => 'ਸੁਪਰ-ਹੀਰੋ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🦸🏽' => 'ਸੁਪਰ-ਹੀਰੋ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🦸🏾' => 'ਸੁਪਰ-ਹੀਰੋ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🦸🏿' => 'ਸੁਪਰ-ਹੀਰੋ: ਕਾਲਾ ਰੰਗ',
    '🦹🏻' => 'ਮਹਾਂ-ਖਲਨਾਇਕ: ਗੋਰਾ ਰੰਗ',
    '🦹🏼' => 'ਮਹਾਂ-ਖਲਨਾਇਕ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🦹🏽' => 'ਮਹਾਂ-ਖਲਨਾਇਕ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🦹🏾' => 'ਮਹਾਂ-ਖਲਨਾਇਕ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🦹🏿' => 'ਮਹਾਂ-ਖਲਨਾਇਕ: ਕਾਲਾ ਰੰਗ',
    '🧙🏻' => 'جادوگر: ہلکی رنگت آلی جلد',
    '🧙🏼' => 'جادوگر: ہلکی درمیانی رنگت آلی جلد',
    '🧙🏽' => 'جادوگر: درمیانی رنگت آلی جلد',
    '🧙🏾' => 'جادوگر: درمیانی کالی رنگت آلی جلد',
    '🧙🏿' => 'جادوگر: کالی رنگت آلی جلد',
    '🧚🏻' => 'فیری: ہلکی رنگت آلی جلد',
    '🧚🏼' => 'فیری: ہلکی درمیانی رنگت آلی جلد',
    '🧚🏽' => 'فیری: درمیانی رنگت آلی جلد',
    '🧚🏾' => 'فیری: درمیانی کالی رنگت آلی جلد',
    '🧚🏿' => 'فیری: کالی رنگت آلی جلد',
    '🧛🏻' => 'خونخوار بلا: ہلکی رنگت آلی جلد',
    '🧛🏼' => 'خونخوار بلا: ہلکی درمیانی رنگت آلی جلد',
    '🧛🏽' => 'خونخوار بلا: درمیانی رنگت آلی جلد',
    '🧛🏾' => 'خونخوار بلا: درمیانی کالی رنگت آلی جلد',
    '🧛🏿' => 'خونخوار بلا: کالی رنگت آلی جلد',
    '🧜🏻' => 'جل دیو: ہلکی رنگت آلی جلد',
    '🧜🏼' => 'جل دیو: ہلکی درمیانی رنگت آلی جلد',
    '🧜🏽' => 'جل دیو: درمیانی رنگت آلی جلد',
    '🧜🏾' => 'جل دیو: درمیانی کالی رنگت آلی جلد',
    '🧜🏿' => 'جل دیو: کالی رنگت آلی جلد',
    '🧝🏻' => 'بُھوت: ہلکی رنگت آلی جلد',
    '🧝🏼' => 'بُھوت: ہلکی درمیانی رنگت آلی جلد',
    '🧝🏽' => 'بُھوت: درمیانی رنگت آلی جلد',
    '🧝🏾' => 'بُھوت: درمیانی کالی رنگت آلی جلد',
    '🧝🏿' => 'بُھوت: کالی رنگت آلی جلد',
    '💆🏻' => 'پیغام لیندا بندہ: ہلکی رنگت آلی جلد',
    '💆🏼' => 'پیغام لیندا بندہ: ہلکی درمیانی رنگت آلی جلد',
    '💆🏽' => 'پیغام لیندا بندہ: درمیانی رنگت آلی جلد',
    '💆🏾' => 'پیغام لیندا بندہ: درمیانی کالی رنگت آلی جلد',
    '💆🏿' => 'پیغام لیندا بندہ: کالی رنگت آلی جلد',
    '💇🏻' => 'حجامت کراندا بندہ: ہلکی رنگت آلی جلد',
    '💇🏼' => 'حجامت کراندا بندہ: ہلکی درمیانی رنگت آلی جلد',
    '💇🏽' => 'حجامت کراندا بندہ: درمیانی رنگت آلی جلد',
    '💇🏾' => 'حجامت کراندا بندہ: درمیانی کالی رنگت آلی جلد',
    '💇🏿' => 'حجامت کراندا بندہ: کالی رنگت آلی جلد',
    '🚶🏻' => 'ٹردا بندہ: ہلکی رنگت آلی جلد',
    '🚶🏼' => 'ٹردا بندہ: ہلکی درمیانی رنگت آلی جلد',
    '🚶🏽' => 'ٹردا بندہ: درمیانی رنگت آلی جلد',
    '🚶🏾' => 'ٹردا بندہ: درمیانی کالی رنگت آلی جلد',
    '🚶🏿' => 'ٹردا بندہ: کالی رنگت آلی جلد',
    '🧍🏻' => 'ਖੜ੍ਹਾ ਵਿਅਕਤੀ: ਗੋਰਾ ਰੰਗ',
    '🧍🏼' => 'ਖੜ੍ਹਾ ਵਿਅਕਤੀ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧍🏽' => 'ਖੜ੍ਹਾ ਵਿਅਕਤੀ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧍🏾' => 'ਖੜ੍ਹਾ ਵਿਅਕਤੀ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🧍🏿' => 'ਖੜ੍ਹਾ ਵਿਅਕਤੀ: ਕਾਲਾ ਰੰਗ',
    '🧎🏻' => 'ਗੋਡਿਆਂ ਭਾਰ ਬੈਠਾ ਵਿਅਕਤੀ: ਗੋਰਾ ਰੰਗ',
    '🧎🏼' => 'ਗੋਡਿਆਂ ਭਾਰ ਬੈਠਾ ਵਿਅਕਤੀ: ਹਲਕਾ ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧎🏽' => 'ਗੋਡਿਆਂ ਭਾਰ ਬੈਠਾ ਵਿਅਕਤੀ: ਕਣਕਵੰਨਾ ਰੰਗ',
    '🧎🏾' => 'ਗੋਡਿਆਂ ਭਾਰ ਬੈਠਾ ਵਿਅਕਤੀ: ਦਰਮਿਆਨਾ ਕਾਲਾ ਰੰਗ',
    '🧎🏿' => 'ਗੋਡਿਆਂ ਭਾਰ ਬੈਠਾ ਵਿਅਕਤੀ: ਕਾਲਾ ਰੰਗ',
    '🏃🏻' => 'بھجدا بندہ: ہلکی رنگت آلی جلد',
    '🏃🏼' => 'بھجدا بندہ: ہلکی درمیانی رنگت آلی جلد',
    '🏃🏽' => 'بھجدا بندہ: درمیانی رنگت آلی جلد',
    '🏃🏾' => 'بھجدا بندہ: درمیانی کالی رنگت آلی جلد',
    '🏃🏿' => 'بھجدا بندہ: کالی رنگت آلی جلد',
    '💃🏻' => 'نچدیاں زنانیاں: ہلکی رنگت آلی جلد',
    '💃🏼' => 'نچدیاں زنانیاں: ہلکی درمیانی رنگت آلی جلد',
    '💃🏽' => 'نچدیاں زنانیاں: درمیانی رنگت آلی جلد',
    '💃🏾' => 'نچدیاں زنانیاں: درمیانی کالی رنگت آلی جلد',
    '💃🏿' => 'نچدیاں زنانیاں: کالی رنگت آلی جلد',
    '🕺🏻' => 'نچدا بندہ: ہلکی رنگت آلی جلد',
    '🕺🏼' => 'نچدا بندہ: ہلکی درمیانی رنگت آلی جلد',
    '🕺🏽' => 'نچدا بندہ: درمیانی رنگت آلی جلد',
    '🕺🏾' => 'نچدا بندہ: درمیانی کالی رنگت آلی جلد',
    '🕺🏿' => 'نچدا بندہ: کالی رنگت آلی جلد',
    '🕴🏻' => 'اُڈدے ہوئے بیوپاری لباس وچ بندہ: ہلکی رنگت آلی جلد',
    '🕴🏼' => 'اُڈدے ہوئے بیوپاری لباس وچ بندہ: ہلکی درمیانی رنگت آلی جلد',
    '🕴🏽' => 'اُڈدے ہوئے بیوپاری لباس وچ بندہ: درمیانی رنگت آلی جلد',
    '🕴🏾' => 'اُڈدے ہوئے بیوپاری لباس وچ بندہ: درمیانی کالی رنگت آلی جلد',
    '🕴🏿' => 'اُڈدے ہوئے بیوپاری لباس وچ بندہ: کالی رنگت آلی جلد',
    '👯🏻' => 'بنی دے کناں نال پارٹی کردے لوکیں: ہلکی رنگت آلی جلد',
    '👯🏼' => 'بنی دے کناں نال پارٹی کردے لوکیں: ہلکی درمیانی رنگت آلی جلد',
    '👯🏽' => 'بنی دے کناں نال پارٹی کردے لوکیں: درمیانی رنگت آلی جلد',
    '👯🏾' => 'بنی دے کناں نال پارٹی کردے لوکیں: درمیانی کالی رنگت آلی جلد',
    '👯🏿' => 'بنی دے کناں نال پارٹی کردے لوکیں: کالی رنگت آلی جلد',
    '🧖🏻' => 'بھاپ نال بھرے کمرے وچ بندا: ہلکی رنگت آلی جلد',
    '🧖🏼' => 'بھاپ نال بھرے کمرے وچ بندا: ہلکی درمیانی رنگت آلی جلد',
    '🧖🏽' => 'بھاپ نال بھرے کمرے وچ بندا: درمیانی رنگت آلی جلد',
    '🧖🏾' => 'بھاپ نال بھرے کمرے وچ بندا: درمیانی کالی رنگت آلی جلد',
    '🧖🏿' => 'بھاپ نال بھرے کمرے وچ بندا: کالی رنگت آلی جلد',
    '🧗🏻' => 'کوہ پیمائی کردا بندا: ہلکی رنگت آلی جلد',
    '🧗🏼' => 'کوہ پیمائی کردا بندا: ہلکی درمیانی رنگت آلی جلد',
    '🧗🏽' => 'کوہ پیمائی کردا بندا: درمیانی رنگت آلی جلد',
    '🧗🏾' => 'کوہ پیمائی کردا بندا: درمیانی کالی رنگت آلی جلد',
    '🧗🏿' => 'کوہ پیمائی کردا بندا: کالی رنگت آلی جلد',
    '🏇🏻' => 'گھوڑے دی دوڑ: ہلکی رنگت آلی جلد',
    '🏇🏼' => 'گھوڑے دی دوڑ: ہلکی درمیانی رنگت آلی جلد',
    '🏇🏽' => 'گھوڑے دی دوڑ: درمیانی رنگت آلی جلد',
    '🏇🏾' => 'گھوڑے دی دوڑ: درمیانی کالی رنگت آلی جلد',
    '🏇🏿' => 'گھوڑے دی دوڑ: کالی رنگت آلی جلد',
    '🏂🏻' => 'برف دے پھٹے تے گیھسیاں لین آلا بندہ: ہلکی رنگت آلی جلد',
    '🏂🏼' => 'برف دے پھٹے تے گیھسیاں لین آلا بندہ: ہلکی درمیانی رنگت آلی جلد',
    '🏂🏽' => 'برف دے پھٹے تے گیھسیاں لین آلا بندہ: درمیانی رنگت آلی جلد',
    '🏂🏾' => 'برف دے پھٹے تے گیھسیاں لین آلا بندہ: درمیانی کالی رنگت آلی جلد',
    '🏂🏿' => 'برف دے پھٹے تے گیھسیاں لین آلا بندہ: کالی رنگت آلی جلد',
    '🏌🏻' => 'گالف کھیڈدا بندا: ہلکی رنگت آلی جلد',
    '🏌🏼' => 'گالف کھیڈدا بندا: ہلکی درمیانی رنگت آلی جلد',
    '🏌🏽' => 'گالف کھیڈدا بندا: درمیانی رنگت آلی جلد',
    '🏌🏾' => 'گالف کھیڈدا بندا: درمیانی کالی رنگت آلی جلد',
    '🏌🏿' => 'گالف کھیڈدا بندا: کالی رنگت آلی جلد',
    '🏄🏻' => 'ویلا گزادا بندہ: ہلکی رنگت آلی جلد',
    '🏄🏼' => 'ویلا گزادا بندہ: ہلکی درمیانی رنگت آلی جلد',
    '🏄🏽' => 'ویلا گزادا بندہ: درمیانی رنگت آلی جلد',
    '🏄🏾' => 'ویلا گزادا بندہ: درمیانی کالی رنگت آلی جلد',
    '🏄🏿' => 'ویلا گزادا بندہ: کالی رنگت آلی جلد',
    '🚣🏻' => 'کشتی چلاندا بندہ: ہلکی رنگت آلی جلد',
    '🚣🏼' => 'کشتی چلاندا بندہ: ہلکی درمیانی رنگت آلی جلد',
    '🚣🏽' => 'کشتی چلاندا بندہ: درمیانی رنگت آلی جلد',
    '🚣🏾' => 'کشتی چلاندا بندہ: درمیانی کالی رنگت آلی جلد',
    '🚣🏿' => 'کشتی چلاندا بندہ: کالی رنگت آلی جلد',
    '🏊🏻' => 'تیردا بندہ: ہلکی رنگت آلی جلد',
    '🏊🏼' => 'تیردا بندہ: ہلکی درمیانی رنگت آلی جلد',
    '🏊🏽' => 'تیردا بندہ: درمیانی رنگت آلی جلد',
    '🏊🏾' => 'تیردا بندہ: درمیانی کالی رنگت آلی جلد',
    '🏊🏿' => 'تیردا بندہ: کالی رنگت آلی جلد',
    '⛹🏻' => 'زور نال گیند کراندا بندا: ہلکی رنگت آلی جلد',
    '⛹🏼' => 'زور نال گیند کراندا بندا: ہلکی درمیانی رنگت آلی جلد',
    '⛹🏽' => 'زور نال گیند کراندا بندا: درمیانی رنگت آلی جلد',
    '⛹🏾' => 'زور نال گیند کراندا بندا: درمیانی کالی رنگت آلی جلد',
    '⛹🏿' => 'زور نال گیند کراندا بندا: کالی رنگت آلی جلد',
    '🏋🏻' => 'بھار چُکدا بندا: ہلکی رنگت آلی جلد',
    '🏋🏼' => 'بھار چُکدا بندا: ہلکی درمیانی رنگت آلی جلد',
    '🏋🏽' => 'بھار چُکدا بندا: درمیانی رنگت آلی جلد',
    '🏋🏾' => 'بھار چُکدا بندا: درمیانی کالی رنگت آلی جلد',
    '🏋🏿' => 'بھار چُکدا بندا: کالی رنگت آلی جلد',
    '🚴🏻' => 'موٹر سائیکل چلاندا بندہ: ہلکی رنگت آلی جلد',
    '🚴🏼' => 'موٹر سائیکل چلاندا بندہ: ہلکی درمیانی رنگت آلی جلد',
    '🚴🏽' => 'موٹر سائیکل چلاندا بندہ: درمیانی رنگت آلی جلد',
    '🚴🏾' => 'موٹر سائیکل چلاندا بندہ: درمیانی کالی رنگت آلی جلد',
    '🚴🏿' => 'موٹر سائیکل چلاندا بندہ: کالی رنگت آلی جلد',
    '🚵🏻' => 'پہاڑ تے موٹرسائیکل چلاندا بندہ: ہلکی رنگت آلی جلد',
    '🚵🏼' => 'پہاڑ تے موٹرسائیکل چلاندا بندہ: ہلکی درمیانی رنگت آلی جلد',
    '🚵🏽' => 'پہاڑ تے موٹرسائیکل چلاندا بندہ: درمیانی رنگت آلی جلد',
    '🚵🏾' => 'پہاڑ تے موٹرسائیکل چلاندا بندہ: درمیانی کالی رنگت آلی جلد',
    '🚵🏿' => 'پہاڑ تے موٹرسائیکل چلاندا بندہ: کالی رنگت آلی جلد',
    '🤸🏻' => 'چھکڑے دا پہيا چلاندا بندہ: ہلکی رنگت آلی جلد',
    '🤸🏼' => 'چھکڑے دا پہيا چلاندا بندہ: ہلکی درمیانی رنگت آلی جلد',
    '🤸🏽' => 'چھکڑے دا پہيا چلاندا بندہ: درمیانی رنگت آلی جلد',
    '🤸🏾' => 'چھکڑے دا پہيا چلاندا بندہ: درمیانی کالی رنگت آلی جلد',
    '🤸🏿' => 'چھکڑے دا پہيا چلاندا بندہ: کالی رنگت آلی جلد',
    '🤼🏻' => 'کُشتی کردا بندہ: ہلکی رنگت آلی جلد',
    '🤼🏼' => 'کُشتی کردا بندہ: ہلکی درمیانی رنگت آلی جلد',
    '🤼🏽' => 'کُشتی کردا بندہ: درمیانی رنگت آلی جلد',
    '🤼🏾' => 'کُشتی کردا بندہ: درمیانی کالی رنگت آلی جلد',
    '🤼🏿' => 'کُشتی کردا بندہ: کالی رنگت آلی جلد',
    '🤽🏻' => 'واٹر پولو کھیڈدا بندہ: ہلکی رنگت آلی جلد',
    '🤽🏼' => 'واٹر پولو کھیڈدا بندہ: ہلکی درمیانی رنگت آلی جلد',
    '🤽🏽' => 'واٹر پولو کھیڈدا بندہ: درمیانی رنگت آلی جلد',
    '🤽🏾' => 'واٹر پولو کھیڈدا بندہ: درمیانی کالی رنگت آلی جلد',
    '🤽🏿' => 'واٹر پولو کھیڈدا بندہ: کالی رنگت آلی جلد',
    '🤾🏻' => 'ہینڈبال نال کھیڈدا بندہ: ہلکی رنگت آلی جلد',
    '🤾🏼' => 'ہینڈبال نال کھیڈدا بندہ: ہلکی درمیانی رنگت آلی جلد',
    '🤾🏽' => 'ہینڈبال نال کھیڈدا بندہ: درمیانی رنگت آلی جلد',
    '🤾🏾' => 'ہینڈبال نال کھیڈدا بندہ: درمیانی کالی رنگت آلی جلد',
    '🤾🏿' => 'ہینڈبال نال کھیڈدا بندہ: کالی رنگت آلی جلد',
    '🤹🏻' => 'نظر بند بندہ: ہلکی رنگت آلی جلد',
    '🤹🏼' => 'نظر بند بندہ: ہلکی درمیانی رنگت آلی جلد',
    '🤹🏽' => 'نظر بند بندہ: درمیانی رنگت آلی جلد',
    '🤹🏾' => 'نظر بند بندہ: درمیانی کالی رنگت آلی جلد',
    '🤹🏿' => 'نظر بند بندہ: کالی رنگت آلی جلد',
    '🧘🏻' => 'کنول دی حالت وچ بندا: ہلکی رنگت آلی جلد',
    '🧘🏼' => 'کنول دی حالت وچ بندا: ہلکی درمیانی رنگت آلی جلد',
    '🧘🏽' => 'کنول دی حالت وچ بندا: درمیانی رنگت آلی جلد',
    '🧘🏾' => 'کنول دی حالت وچ بندا: درمیانی کالی رنگت آلی جلد',
    '🧘🏿' => 'کنول دی حالت وچ بندا: کالی رنگت آلی جلد',
    '🛀🏻' => 'بندہ غسل کر دیاں ہوئیاں: ہلکی رنگت آلی جلد',
    '🛀🏼' => 'بندہ غسل کر دیاں ہوئیاں: ہلکی درمیانی رنگت آلی جلد',
    '🛀🏽' => 'بندہ غسل کر دیاں ہوئیاں: درمیانی رنگت آلی جلد',
    '🛀🏾' => 'بندہ غسل کر دیاں ہوئیاں: درمیانی کالی رنگت آلی جلد',
    '🛀🏿' => 'بندہ غسل کر دیاں ہوئیاں: کالی رنگت آلی جلد',
    '🛌🏻' => 'بیڈ وچ بندہ: ہلکی رنگت آلی جلد',
    '🛌🏼' => 'بیڈ وچ بندہ: ہلکی درمیانی رنگت آلی جلد',
    '🛌🏽' => 'بیڈ وچ بندہ: درمیانی رنگت آلی جلد',
    '🛌🏾' => 'بیڈ وچ بندہ: درمیانی کالی رنگت آلی جلد',
    '🛌🏿' => 'بیڈ وچ بندہ: کالی رنگت آلی جلد',
    '👭🏻' => 'ہتھ پھڑدیاں دو زنانیاں: ہلکی رنگت آلی جلد',
    '👭🏼' => 'ہتھ پھڑدیاں دو زنانیاں: ہلکی درمیانی رنگت آلی جلد',
    '👭🏽' => 'ہتھ پھڑدیاں دو زنانیاں: درمیانی رنگت آلی جلد',
    '👭🏾' => 'ہتھ پھڑدیاں دو زنانیاں: درمیانی کالی رنگت آلی جلد',
    '👭🏿' => 'ہتھ پھڑدیاں دو زنانیاں: کالی رنگت آلی جلد',
    '👫🏻' => 'ہتھ پھڑے ہوئے بندہ اتے زنانی: ہلکی رنگت آلی جلد',
    '👫🏼' => 'ہتھ پھڑے ہوئے بندہ اتے زنانی: ہلکی درمیانی رنگت آلی جلد',
    '👫🏽' => 'ہتھ پھڑے ہوئے بندہ اتے زنانی: درمیانی رنگت آلی جلد',
    '👫🏾' => 'ہتھ پھڑے ہوئے بندہ اتے زنانی: درمیانی کالی رنگت آلی جلد',
    '👫🏿' => 'ہتھ پھڑے ہوئے بندہ اتے زنانی: کالی رنگت آلی جلد',
    '👬🏻' => 'ہتھ پھڑدے دو بندے: ہلکی رنگت آلی جلد',
    '👬🏼' => 'ہتھ پھڑدے دو بندے: ہلکی درمیانی رنگت آلی جلد',
    '👬🏽' => 'ہتھ پھڑدے دو بندے: درمیانی رنگت آلی جلد',
    '👬🏾' => 'ہتھ پھڑدے دو بندے: درمیانی کالی رنگت آلی جلد',
    '👬🏿' => 'ہتھ پھڑدے دو بندے: کالی رنگت آلی جلد',
    '💏🏻' => 'چومنا: ہلکی رنگت آلی جلد',
    '💏🏼' => 'چومنا: ہلکی درمیانی رنگت آلی جلد',
    '💏🏽' => 'چومنا: درمیانی رنگت آلی جلد',
    '💏🏾' => 'چومنا: درمیانی کالی رنگت آلی جلد',
    '💏🏿' => 'چومنا: کالی رنگت آلی جلد',
    '💑🏻' => 'دل نال جوڑا: ہلکی رنگت آلی جلد',
    '💑🏼' => 'دل نال جوڑا: ہلکی درمیانی رنگت آلی جلد',
    '💑🏽' => 'دل نال جوڑا: درمیانی رنگت آلی جلد',
    '💑🏾' => 'دل نال جوڑا: درمیانی کالی رنگت آلی جلد',
    '💑🏿' => 'دل نال جوڑا: کالی رنگت آلی جلد',
    '🇦🇨' => 'ਝੰਡਾ: ਅਸੈਂਸ਼ਨ ਟਾਪੂ',
    '🇦🇩' => 'ਝੰਡਾ: ਅੰਡੋਰਾ',
    '🇦🇪' => 'ਝੰਡਾ: ਸੰਯੁਕਤ ਅਰਬ ਅਮੀਰਾਤ',
    '🇦🇫' => 'ਝੰਡਾ: ਅਫ਼ਗਾਨਿਸਤਾਨ',
    '🇦🇬' => 'ਝੰਡਾ: ਐਂਟੀਗੁਆ ਅਤੇ ਬਾਰਬੁਡਾ',
    '🇦🇮' => 'ਝੰਡਾ: ਅੰਗੁਇਲਾ',
    '🇦🇱' => 'ਝੰਡਾ: ਅਲਬਾਨੀਆ',
    '🇦🇲' => 'ਝੰਡਾ: ਅਰਮੀਨੀਆ',
    '🇦🇴' => 'ਝੰਡਾ: ਅੰਗੋਲਾ',
    '🇦🇶' => 'ਝੰਡਾ: ਅੰਟਾਰਕਟਿਕਾ',
    '🇦🇷' => 'ਝੰਡਾ: ਅਰਜਨਟੀਨਾ',
    '🇦🇸' => 'ਝੰਡਾ: ਅਮੈਰੀਕਨ ਸਮੋਆ',
    '🇦🇹' => 'ਝੰਡਾ: ਆਸਟਰੀਆ',
    '🇦🇺' => 'ਝੰਡਾ: ਆਸਟ੍ਰੇਲੀਆ',
    '🇦🇼' => 'ਝੰਡਾ: ਅਰੂਬਾ',
    '🇦🇽' => 'ਝੰਡਾ: ਅਲੈਂਡ ਟਾਪੂ',
    '🇦🇿' => 'ਝੰਡਾ: ਅਜ਼ਰਬਾਈਜਾਨ',
    '🇧🇦' => 'ਝੰਡਾ: ਬੋਸਨੀਆ ਅਤੇ ਹਰਜ਼ੇਗੋਵੀਨਾ',
    '🇧🇧' => 'ਝੰਡਾ: ਬਾਰਬਾਡੋਸ',
    '🇧🇩' => 'ਝੰਡਾ: ਬੰਗਲਾਦੇਸ਼',
    '🇧🇪' => 'ਝੰਡਾ: ਬੈਲਜੀਅਮ',
    '🇧🇫' => 'ਝੰਡਾ: ਬੁਰਕੀਨਾ ਫ਼ਾਸੋ',
    '🇧🇬' => 'ਝੰਡਾ: ਬੁਲਗਾਰੀਆ',
    '🇧🇭' => 'ਝੰਡਾ: ਬਹਿਰੀਨ',
    '🇧🇮' => 'ਝੰਡਾ: ਬੁਰੁੰਡੀ',
    '🇧🇯' => 'ਝੰਡਾ: ਬੇਨਿਨ',
    '🇧🇱' => 'ਝੰਡਾ: ਸੇਂਟ ਬਾਰਥੇਲੇਮੀ',
    '🇧🇲' => 'ਝੰਡਾ: ਬਰਮੂਡਾ',
    '🇧🇳' => 'ਝੰਡਾ: ਬਰੂਨੇਈ',
    '🇧🇴' => 'ਝੰਡਾ: ਬੋਲੀਵੀਆ',
    '🇧🇶' => 'ਝੰਡਾ: ਕੈਰੇਬੀਆਈ ਨੀਦਰਲੈਂਡ',
    '🇧🇷' => 'ਝੰਡਾ: ਬ੍ਰਾਜ਼ੀਲ',
    '🇧🇸' => 'ਝੰਡਾ: ਬਹਾਮਾਸ',
    '🇧🇹' => 'ਝੰਡਾ: ਭੂਟਾਨ',
    '🇧🇻' => 'ਝੰਡਾ: ਬੌਵੇਟ ਟਾਪੂ',
    '🇧🇼' => 'ਝੰਡਾ: ਬੋਤਸਵਾਨਾ',
    '🇧🇾' => 'ਝੰਡਾ: ਬੇਲਾਰੂਸ',
    '🇧🇿' => 'ਝੰਡਾ: ਬੇਲੀਜ਼',
    '🇨🇦' => 'ਝੰਡਾ: ਕੈਨੇਡਾ',
    '🇨🇨' => 'ਝੰਡਾ: ਕੋਕੋਸ (ਕੀਲਿੰਗ) ਟਾਪੂ',
    '🇨🇩' => 'ਝੰਡਾ: ਕਾਂਗੋ - ਕਿੰਸ਼ਾਸਾ',
    '🇨🇫' => 'ਝੰਡਾ: ਕੇਂਦਰੀ ਅਫ਼ਰੀਕੀ ਗਣਰਾਜ',
    '🇨🇬' => 'ਝੰਡਾ: ਕਾਂਗੋ - ਬ੍ਰਾਜ਼ਾਵਿਲੇ',
    '🇨🇭' => 'ਝੰਡਾ: ਸਵਿਟਜ਼ਰਲੈਂਡ',
    '🇨🇮' => 'ਝੰਡਾ: ਕੋਟ ਡੀਵੋਆਰ',
    '🇨🇰' => 'ਝੰਡਾ: ਕੁੱਕ ਟਾਪੂ',
    '🇨🇱' => 'ਝੰਡਾ: ਚਿਲੀ',
    '🇨🇲' => 'ਝੰਡਾ: ਕੈਮਰੂਨ',
    '🇨🇳' => 'ਝੰਡਾ: ਚੀਨ',
    '🇨🇴' => 'ਝੰਡਾ: ਕੋਲੰਬੀਆ',
    '🇨🇵' => 'ਝੰਡਾ: ਕਲਿੱਪਰਟਨ ਟਾਪੂ',
    '🇨🇶' => 'ਝੰਡਾ: ਸਾਰਕ',
    '🇨🇷' => 'ਝੰਡਾ: ਕੋਸਟਾ ਰੀਕਾ',
    '🇨🇺' => 'ਝੰਡਾ: ਕਿਊਬਾ',
    '🇨🇻' => 'ਝੰਡਾ: ਕੇਪ ਵਰਡੇ',
    '🇨🇼' => 'ਝੰਡਾ: ਕੁਰਾਕਾਓ',
    '🇨🇽' => 'ਝੰਡਾ: ਕ੍ਰਿਸਮਿਸ ਟਾਪੂ',
    '🇨🇾' => 'ਝੰਡਾ: ਸਾਇਪ੍ਰਸ',
    '🇨🇿' => 'ਝੰਡਾ: ਚੈਕੀਆ',
    '🇩🇪' => 'ਝੰਡਾ: ਜਰਮਨੀ',
    '🇩🇬' => 'ਝੰਡਾ: ਡੀਇਗੋ ਗਾਰਸੀਆ',
    '🇩🇯' => 'ਝੰਡਾ: ਜਿਬੂਤੀ',
    '🇩🇰' => 'ਝੰਡਾ: ਡੈਨਮਾਰਕ',
    '🇩🇲' => 'ਝੰਡਾ: ਡੋਮੀਨਿਕਾ',
    '🇩🇴' => 'ਝੰਡਾ: ਡੋਮੀਨਿਕਾਈ ਗਣਰਾਜ',
    '🇩🇿' => 'ਝੰਡਾ: ਅਲਜੀਰੀਆ',
    '🇪🇦' => 'ਝੰਡਾ: ਸਿਓਟਾ ਅਤੇ ਮੇਲਿੱਲਾ',
    '🇪🇨' => 'ਝੰਡਾ: ਇਕਵੇਡੋਰ',
    '🇪🇪' => 'ਝੰਡਾ: ਇਸਟੋਨੀਆ',
    '🇪🇬' => 'ਝੰਡਾ: ਮਿਸਰ',
    '🇪🇭' => 'ਝੰਡਾ: ਪੱਛਮੀ ਸਹਾਰਾ',
    '🇪🇷' => 'ਝੰਡਾ: ਇਰੀਟ੍ਰਿਆ',
    '🇪🇸' => 'ਝੰਡਾ: ਸਪੇਨ',
    '🇪🇹' => 'ਝੰਡਾ: ਇਥੋਪੀਆ',
    '🇪🇺' => 'ਝੰਡਾ: ਯੂਰਪੀ ਸੰਘ',
    '🇫🇮' => 'ਝੰਡਾ: ਫਿਨਲੈਂਡ',
    '🇫🇯' => 'ਝੰਡਾ: ਫ਼ਿਜੀ',
    '🇫🇰' => 'ਝੰਡਾ: ਫ਼ਾਕਲੈਂਡ ਟਾਪੂ',
    '🇫🇲' => 'ਝੰਡਾ: ਮਾਇਕ੍ਰੋਨੇਸ਼ੀਆ',
    '🇫🇴' => 'ਝੰਡਾ: ਫੈਰੋ ਟਾਪੂ',
    '🇫🇷' => 'ਝੰਡਾ: ਫ਼ਰਾਂਸ',
    '🇬🇦' => 'ਝੰਡਾ: ਗਬੋਨ',
    '🇬🇧' => 'ਝੰਡਾ: ਯੂਨਾਈਟਡ ਕਿੰਗਡਮ',
    '🇬🇩' => 'ਝੰਡਾ: ਗ੍ਰੇਨਾਡਾ',
    '🇬🇪' => 'ਝੰਡਾ: ਜਾਰਜੀਆ',
    '🇬🇫' => 'ਝੰਡਾ: ਫਰੈਂਚ ਗੁਇਆਨਾ',
    '🇬🇬' => 'ਝੰਡਾ: ਗਰਨਜੀ',
    '🇬🇭' => 'ਝੰਡਾ: ਘਾਨਾ',
    '🇬🇮' => 'ਝੰਡਾ: ਜਿਬਰਾਲਟਰ',
    '🇬🇱' => 'ਝੰਡਾ: ਗ੍ਰੀਨਲੈਂਡ',
    '🇬🇲' => 'ਝੰਡਾ: ਗੈਂਬੀਆ',
    '🇬🇳' => 'ਝੰਡਾ: ਗਿਨੀ',
    '🇬🇵' => 'ਝੰਡਾ: ਗੁਆਡੇਲੋਪ',
    '🇬🇶' => 'ਝੰਡਾ: ਭੂ-ਖੰਡੀ ਗਿਨੀ',
    '🇬🇷' => 'ਝੰਡਾ: ਗ੍ਰੀਸ',
    '🇬🇸' => 'ਝੰਡਾ: ਦੱਖਣੀ ਜਾਰਜੀਆ ਅਤੇ ਦੱਖਣੀ ਸੈਂਡਵਿਚ ਟਾਪੂ',
    '🇬🇹' => 'ਝੰਡਾ: ਗੁਆਟੇਮਾਲਾ',
    '🇬🇺' => 'ਝੰਡਾ: ਗੁਆਮ',
    '🇬🇼' => 'ਝੰਡਾ: ਗਿਨੀ-ਬਿਸਾਉ',
    '🇬🇾' => 'ਝੰਡਾ: ਗੁਯਾਨਾ',
    '🇭🇰' => 'ਝੰਡਾ: ਹਾਂਗ ਕਾਂਗ ਐਸਏਆਰ ਚੀਨ',
    '🇭🇲' => 'ਝੰਡਾ: ਹਰਡ ਤੇ ਮੈਕਡੋਨਾਲਡ ਟਾਪੂ',
    '🇭🇳' => 'ਝੰਡਾ: ਹੋਂਡੁਰਸ',
    '🇭🇷' => 'ਝੰਡਾ: ਕਰੋਏਸ਼ੀਆ',
    '🇭🇹' => 'ਝੰਡਾ: ਹੈਤੀ',
    '🇭🇺' => 'ਝੰਡਾ: ਹੰਗਰੀ',
    '🇮🇨' => 'ਝੰਡਾ: ਕੇਨਾਰੀ ਟਾਪੂ',
    '🇮🇩' => 'ਝੰਡਾ: ਇੰਡੋਨੇਸ਼ੀਆ',
    '🇮🇪' => 'ਝੰਡਾ: ਆਇਰਲੈਂਡ',
    '🇮🇱' => 'ਝੰਡਾ: ਇਜ਼ਰਾਈਲ',
    '🇮🇲' => 'ਝੰਡਾ: ਆਇਲ ਆਫ ਮੈਨ',
    '🇮🇳' => 'ਝੰਡਾ: ਭਾਰਤ',
    '🇮🇴' => 'ਝੰਡਾ: ਬਰਤਾਨਵੀ ਹਿੰਦ ਮਹਾਂਸਾਗਰ ਖਿੱਤਾ',
    '🇮🇶' => 'ਝੰਡਾ: ਇਰਾਕ',
    '🇮🇷' => 'ਝੰਡਾ: ਈਰਾਨ',
    '🇮🇸' => 'ਝੰਡਾ: ਆਈਸਲੈਂਡ',
    '🇮🇹' => 'ਝੰਡਾ: ਇਟਲੀ',
    '🇯🇪' => 'ਝੰਡਾ: ਜਰਸੀ',
    '🇯🇲' => 'ਝੰਡਾ: ਜਮਾਇਕਾ',
    '🇯🇴' => 'ਝੰਡਾ: ਜੌਰਡਨ',
    '🇯🇵' => 'ਝੰਡਾ: ਜਪਾਨ',
    '🇰🇪' => 'ਝੰਡਾ: ਕੀਨੀਆ',
    '🇰🇬' => 'ਝੰਡਾ: ਕਿਰਗਿਜ਼ਸਤਾਨ',
    '🇰🇭' => 'ਝੰਡਾ: ਕੰਬੋਡੀਆ',
    '🇰🇮' => 'ਝੰਡਾ: ਕਿਰਬਾਤੀ',
    '🇰🇲' => 'ਝੰਡਾ: ਕੋਮੋਰੋਸ',
    '🇰🇳' => 'ਝੰਡਾ: ਸੇਂਟ ਕਿਟਸ ਐਂਡ ਨੇਵਿਸ',
    '🇰🇵' => 'ਝੰਡਾ: ਉੱਤਰੀ ਕੋਰੀਆ',
    '🇰🇷' => 'ਝੰਡਾ: ਦੱਖਣੀ ਕੋਰੀਆ',
    '🇰🇼' => 'ਝੰਡਾ: ਕੁਵੈਤ',
    '🇰🇾' => 'ਝੰਡਾ: ਕੇਮੈਨ ਟਾਪੂ',
    '🇰🇿' => 'ਝੰਡਾ: ਕਜ਼ਾਖਸਤਾਨ',
    '🇱🇦' => 'ਝੰਡਾ: ਲਾਓਸ',
    '🇱🇧' => 'ਝੰਡਾ: ਲਿਬਨਾਨ',
    '🇱🇨' => 'ਝੰਡਾ: ਸੇਂਟ ਲੂਸੀਆ',
    '🇱🇮' => 'ਝੰਡਾ: ਲਿਚੇਂਸਟਾਇਨ',
    '🇱🇰' => 'ਝੰਡਾ: ਸ੍ਰੀ ਲੰਕਾ',
    '🇱🇷' => 'ਝੰਡਾ: ਲਾਈਬੀਰੀਆ',
    '🇱🇸' => 'ਝੰਡਾ: ਲੇਸੋਥੋ',
    '🇱🇹' => 'ਝੰਡਾ: ਲਿਥੁਆਨੀਆ',
    '🇱🇺' => 'ਝੰਡਾ: ਲਕਜ਼ਮਬਰਗ',
    '🇱🇻' => 'ਝੰਡਾ: ਲਾਤਵੀਆ',
    '🇱🇾' => 'ਝੰਡਾ: ਲੀਬੀਆ',
    '🇲🇦' => 'ਝੰਡਾ: ਮੋਰੱਕੋ',
    '🇲🇨' => 'ਝੰਡਾ: ਮੋਨਾਕੋ',
    '🇲🇩' => 'ਝੰਡਾ: ਮੋਲਡੋਵਾ',
    '🇲🇪' => 'ਝੰਡਾ: ਮੋਂਟੇਨੇਗਰੋ',
    '🇲🇫' => 'ਝੰਡਾ: ਸੇਂਟ ਮਾਰਟਿਨ',
    '🇲🇬' => 'ਝੰਡਾ: ਮੈਡਾਗਾਸਕਰ',
    '🇲🇭' => 'ਝੰਡਾ: ਮਾਰਸ਼ਲ ਟਾਪੂ',
    '🇲🇰' => 'ਝੰਡਾ: ਉੱਤਰੀ ਮੈਕਡੋਨੀਆ',
    '🇲🇱' => 'ਝੰਡਾ: ਮਾਲੀ',
    '🇲🇲' => 'ਝੰਡਾ: ਮਿਆਂਮਾਰ (ਬਰਮਾ)',
    '🇲🇳' => 'ਝੰਡਾ: ਮੰਗੋਲੀਆ',
    '🇲🇴' => 'ਝੰਡਾ: ਮਕਾਉ ਐਸਏਆਰ ਚੀਨ',
    '🇲🇵' => 'ਝੰਡਾ: ਉੱਤਰੀ ਮਾਰੀਆਨਾ ਟਾਪੂ',
    '🇲🇶' => 'ਝੰਡਾ: ਮਾਰਟੀਨਿਕ',
    '🇲🇷' => 'ਝੰਡਾ: ਮੋਰਿਟਾਨੀਆ',
    '🇲🇸' => 'ਝੰਡਾ: ਮੋਂਟਸੇਰਾਤ',
    '🇲🇹' => 'ਝੰਡਾ: ਮਾਲਟਾ',
    '🇲🇺' => 'ਝੰਡਾ: ਮੌਰੀਸ਼ਸ',
    '🇲🇻' => 'ਝੰਡਾ: ਮਾਲਦੀਵ',
    '🇲🇼' => 'ਝੰਡਾ: ਮਲਾਵੀ',
    '🇲🇽' => 'ਝੰਡਾ: ਮੈਕਸੀਕੋ',
    '🇲🇾' => 'ਝੰਡਾ: ਮਲੇਸ਼ੀਆ',
    '🇲🇿' => 'ਝੰਡਾ: ਮੋਜ਼ਾਮਬੀਕ',
    '🇳🇦' => 'ਝੰਡਾ: ਨਾਮੀਬੀਆ',
    '🇳🇨' => 'ਝੰਡਾ: ਨਿਊ ਕੈਲੇਡੋਨੀਆ',
    '🇳🇪' => 'ਝੰਡਾ: ਨਾਈਜਰ',
    '🇳🇫' => 'ਝੰਡਾ: ਨੋਰਫੌਕ ਟਾਪੂ',
    '🇳🇬' => 'ਝੰਡਾ: ਨਾਈਜੀਰੀਆ',
    '🇳🇮' => 'ਝੰਡਾ: ਨਿਕਾਰਾਗੁਆ',
    '🇳🇱' => 'ਝੰਡਾ: ਨੀਦਰਲੈਂਡ',
    '🇳🇴' => 'ਝੰਡਾ: ਨਾਰਵੇ',
    '🇳🇵' => 'ਝੰਡਾ: ਨੇਪਾਲ',
    '🇳🇷' => 'ਝੰਡਾ: ਨਾਉਰੂ',
    '🇳🇺' => 'ਝੰਡਾ: ਨਿਯੂ',
    '🇳🇿' => 'ਝੰਡਾ: ਨਿਊਜ਼ੀਲੈਂਡ',
    '🇴🇲' => 'ਝੰਡਾ: ਓਮਾਨ',
    '🇵🇦' => 'ਝੰਡਾ: ਪਨਾਮਾ',
    '🇵🇪' => 'ਝੰਡਾ: ਪੇਰੂ',
    '🇵🇫' => 'ਝੰਡਾ: ਫਰੈਂਚ ਪੋਲੀਨੇਸ਼ੀਆ',
    '🇵🇬' => 'ਝੰਡਾ: ਪਾਪੂਆ ਨਿਊ ਗਿਨੀ',
    '🇵🇭' => 'ਝੰਡਾ: ਫਿਲੀਪੀਨਜ',
    '🇵🇰' => 'ਝੰਡਾ: ਪਾਕਿਸਤਾਨ',
    '🇵🇱' => 'ਝੰਡਾ: ਪੋਲੈਂਡ',
    '🇵🇲' => 'ਝੰਡਾ: ਸੇਂਟ ਪੀਅਰੇ ਐਂਡ ਮਿਕੇਲਨ',
    '🇵🇳' => 'ਝੰਡਾ: ਪਿਟਕੇਰਨ ਟਾਪੂ',
    '🇵🇷' => 'ਝੰਡਾ: ਪਿਊਰਟੋ ਰਿਕੋ',
    '🇵🇸' => 'ਝੰਡਾ: ਫਿਲਸਤੀਨੀ ਖਿੱਤੇ',
    '🇵🇹' => 'ਝੰਡਾ: ਪੁਰਤਗਾਲ',
    '🇵🇼' => 'ਝੰਡਾ: ਪਲਾਉ',
    '🇵🇾' => 'ਝੰਡਾ: ਪੈਰਾਗਵੇ',
    '🇶🇦' => 'ਝੰਡਾ: ਕਤਰ',
    '🇷🇪' => 'ਝੰਡਾ: ਰਿਯੂਨੀਅਨ',
    '🇷🇴' => 'ਝੰਡਾ: ਰੋਮਾਨੀਆ',
    '🇷🇸' => 'ਝੰਡਾ: ਸਰਬੀਆ',
    '🇷🇺' => 'ਝੰਡਾ: ਰੂਸ',
    '🇷🇼' => 'ਝੰਡਾ: ਰਵਾਂਡਾ',
    '🇸🇦' => 'ਝੰਡਾ: ਸਾਊਦੀ ਅਰਬ',
    '🇸🇧' => 'ਝੰਡਾ: ਸੋਲੋਮਨ ਟਾਪੂ',
    '🇸🇨' => 'ਝੰਡਾ: ਸੇਸ਼ਲਸ',
    '🇸🇩' => 'ਝੰਡਾ: ਸੂਡਾਨ',
    '🇸🇪' => 'ਝੰਡਾ: ਸਵੀਡਨ',
    '🇸🇬' => 'ਝੰਡਾ: ਸਿੰਗਾਪੁਰ',
    '🇸🇭' => 'ਝੰਡਾ: ਸੇਂਟ ਹੇਲੇਨਾ',
    '🇸🇮' => 'ਝੰਡਾ: ਸਲੋਵੇਨੀਆ',
    '🇸🇯' => 'ਝੰਡਾ: ਸਵਾਲਬਰਡ ਅਤੇ ਜਾਨ ਮਾਯੇਨ',
    '🇸🇰' => 'ਝੰਡਾ: ਸਲੋਵਾਕੀਆ',
    '🇸🇱' => 'ਝੰਡਾ: ਸਿਏਰਾ ਲਿਓਨ',
    '🇸🇲' => 'ਝੰਡਾ: ਸੈਨ ਮਰੀਨੋ',
    '🇸🇳' => 'ਝੰਡਾ: ਸੇਨੇਗਲ',
    '🇸🇴' => 'ਝੰਡਾ: ਸੋਮਾਲੀਆ',
    '🇸🇷' => 'ਝੰਡਾ: ਸੂਰੀਨਾਮ',
    '🇸🇸' => 'ਝੰਡਾ: ਦੱਖਣ ਸੁਡਾਨ',
    '🇸🇹' => 'ਝੰਡਾ: ਸਾਓ ਟੋਮ ਅਤੇ ਪ੍ਰਿੰਸੀਪੇ',
    '🇸🇻' => 'ਝੰਡਾ: ਅਲ ਸਲਵਾਡੋਰ',
    '🇸🇽' => 'ਝੰਡਾ: ਸਿੰਟ ਮਾਰਟੀਨ',
    '🇸🇾' => 'ਝੰਡਾ: ਸੀਰੀਆ',
    '🇸🇿' => 'ਝੰਡਾ: ਇਸਵਾਤੀਨੀ',
    '🇹🇦' => 'ਝੰਡਾ: ਟ੍ਰਿਸਟਾਨ ਦਾ ਕੁੰਹਾ',
    '🇹🇨' => 'ਝੰਡਾ: ਟੁਰਕਸ ਅਤੇ ਕੈਕੋਸ ਟਾਪੂ',
    '🇹🇩' => 'ਝੰਡਾ: ਚਾਡ',
    '🇹🇫' => 'ਝੰਡਾ: ਫਰੈਂਚ ਦੱਖਣੀ ਪ੍ਰਦੇਸ਼',
    '🇹🇬' => 'ਝੰਡਾ: ਟੋਗੋ',
    '🇹🇭' => 'ਝੰਡਾ: ਥਾਈਲੈਂਡ',
    '🇹🇯' => 'ਝੰਡਾ: ਤਾਜਿਕਿਸਤਾਨ',
    '🇹🇰' => 'ਝੰਡਾ: ਟੋਕੇਲਾਉ',
    '🇹🇱' => 'ਝੰਡਾ: ਤਿਮੋਰ-ਲੇਸਤੇ',
    '🇹🇲' => 'ਝੰਡਾ: ਤੁਰਕਮੇਨਿਸਤਾਨ',
    '🇹🇳' => 'ਝੰਡਾ: ਟਿਊਨੀਸ਼ੀਆ',
    '🇹🇴' => 'ਝੰਡਾ: ਟੌਂਗਾ',
    '🇹🇷' => 'ਝੰਡਾ: ਤੁਰਕੀ',
    '🇹🇹' => 'ਝੰਡਾ: ਟ੍ਰਿਨੀਡਾਡ ਅਤੇ ਟੋਬਾਗੋ',
    '🇹🇻' => 'ਝੰਡਾ: ਟੁਵਾਲੂ',
    '🇹🇼' => 'ਝੰਡਾ: ਤਾਇਵਾਨ',
    '🇹🇿' => 'ਝੰਡਾ: ਤਨਜ਼ਾਨੀਆ',
    '🇺🇦' => 'ਝੰਡਾ: ਯੂਕਰੇਨ',
    '🇺🇬' => 'ਝੰਡਾ: ਯੂਗਾਂਡਾ',
    '🇺🇲' => 'ਝੰਡਾ: ਯੂ.ਐੱਸ. ਦੂਰ-ਦੁਰਾਡੇ ਟਾਪੂ',
    '🇺🇳' => 'ਝੰਡਾ: ਸੰਯੁਕਤ ਰਾਸ਼ਟਰ',
    '🇺🇸' => 'ਝੰਡਾ: ਸੰਯੁਕਤ ਰਾਜ (ਅਮਰੀਕਾ)',
    '🇺🇾' => 'ਝੰਡਾ: ਉਰੂਗਵੇ',
    '🇺🇿' => 'ਝੰਡਾ: ਉਜ਼ਬੇਕਿਸਤਾਨ',
    '🇻🇦' => 'ਝੰਡਾ: ਵੈਟੀਕਨ ਸਿਟੀ',
    '🇻🇨' => 'ਝੰਡਾ: ਸੇਂਟ ਵਿਨਸੈਂਟ ਐਂਡ ਗ੍ਰੇਨਾਡੀਨਸ',
    '🇻🇪' => 'ਝੰਡਾ: ਵੇਨੇਜ਼ੂਏਲਾ',
    '🇻🇬' => 'ਝੰਡਾ: ਬ੍ਰਿਟਿਸ਼ ਵਰਜਿਨ ਟਾਪੂ',
    '🇻🇮' => 'ਝੰਡਾ: ਯੂ ਐੱਸ ਵਰਜਿਨ ਟਾਪੂ',
    '🇻🇳' => 'ਝੰਡਾ: ਵੀਅਤਨਾਮ',
    '🇻🇺' => 'ਝੰਡਾ: ਵਾਨੂਆਟੂ',
    '🇼🇫' => 'ਝੰਡਾ: ਵਾਲਿਸ ਅਤੇ ਫੂਟੂਨਾ',
    '🇼🇸' => 'ਝੰਡਾ: ਸਾਮੋਆ',
    '🇽🇰' => 'ਝੰਡਾ: ਕੋਸੋਵੋ',
    '🇾🇪' => 'ਝੰਡਾ: ਯਮਨ',
    '🇾🇹' => 'ਝੰਡਾ: ਮਾਯੋਟੀ',
    '🇿🇦' => 'ਝੰਡਾ: ਦੱਖਣੀ ਅਫਰੀਕਾ',
    '🇿🇲' => 'ਝੰਡਾ: ਜ਼ਾਮਬੀਆ',
    '🇿🇼' => 'ਝੰਡਾ: ਜ਼ਿੰਬਾਬਵੇ',
    '🔟' => 'ਕੀਕੈਪ: 10',
    '🏻' => 'ہلکی رنگت آلی جلد',
    '🏼' => 'ہلکی درمیانی رنگت آلی جلد',
    '🏽' => 'درمیانی رنگت آلی جلد',
    '🏾' => 'درمیانی کالی رنگت آلی جلد',
    '🏿' => 'کالی رنگت آلی جلد',
    '😀' => 'دند پیسدی شکل',
    '😃' => 'کھلے منہ نال مسکراندی شکل',
    '😄' => 'کھلے مُنہ اتے مسکراندیاں اکھاں نال مسکراندی شکل',
    '😁' => 'مسکراندیاں اکھاں نال دند پیسدی شکل',
    '😆' => 'کُھلے منہ اتے بند کیتیاں اکھاں نال مسکراندی شکل',
    '😅' => 'کُھلے منہ اتے مڑکے نال مسکراندی شکل',
    '🤣' => 'قہقہے نال زمین اوتے لوٹ پھوٹ',
    '😂' => 'خوشی دے اتھرواں نال شکل',
    '🙂' => 'ہلکی مسکراندی ہوئی شکل',
    '🙃' => 'پُٹھی شکل',
    '🫠' => 'ਪਿਘਲਦਾ ਹੋਇਆ ਚਿਹਰਾ',
    '😉' => 'اکھ مار دی شکل',
    '😊' => 'مسکراندیاں اکھاں نال مسکراندی شکل',
    '😇' => 'چمک نال مسکراندی شکل',
    '🥰' => 'ਦਿਲਾਂ ਨਾਲ ਮੁਸਕੁਰਾਉਂਦਾ ਚਿਹਰਾ',
    '😍' => 'دل آلیاں اکھاں نال مسکراندی شکل',
    '🤩' => 'نامور شخصیتاں دا دلدادہ',
    '😘' => 'ہوا وچ چومی اڑاندی شکل',
    '😗' => 'چومیاں کردی شکل',
    '☺' => 'مسکراندی شکل',
    '😚' => 'بند اکھاں نال چومی کردی شکل',
    '😙' => 'مسکراندیاں اکھاں نال چومیاں کردی شکل',
    '🥲' => 'ਅੱਥਰੂ ਨਾਲ ਮੁਸਕਰਾਉਂਦਾ ਚਿਹਰਾ',
    '😋' => 'مزے دار خوراک دا سواد لیندی شکل',
    '😛' => 'باہر کڈی زبان آلی شکل',
    '😜' => 'باہر کڈی زبان نال شکل اتے پلک جھپکدی اکھ',
    '🤪' => 'پاگل پن آلی شکل',
    '😝' => 'باہر کڈی زنان آلی شکل اتے بند کیتیاں اکھاں',
    '🤑' => 'پیسیاں دے منہ آلی شکل',
    '🤗' => 'گلے ملدی شکل',
    '🤭' => 'منہ اُوتے ہتھ نال شکل',
    '🫢' => 'ਖੁੱਲ੍ਹੀਆਂ ਅੱਖਾਂ ਵਾਲਾ ਚਿਹਰਾ ਅਤੇ ਮੂੰਹ ਤੇ ਹੱਥ',
    '🫣' => 'ਝਾਤ ਮਾਰਦਾ ਚਿਹਰਾ',
    '🤫' => 'خاموش کراندی ہوئی شکل',
    '🤔' => 'سوچدی شکل',
    '🫡' => 'ਸਲਾਮ ਕਰਦਾ ਚਿਹਰਾ',
    '🤐' => 'زپرـمنہ آلی شکل',
    '🤨' => 'اُٹھدی ہوئیاں بھنواں نال شکل',
    '😐' => 'غیر جانبدار شکل',
    '😑' => 'لا اظہاری شکل',
    '😶' => 'منہ دے بغیر شکل',
    '🫥' => 'ਬਿੰਦੀਆਂ ਵਾਲਾ ਚਿਹਰਾ',
    '😏' => 'بناوٹی شکل',
    '😒' => 'ناخوش شکل',
    '🙄' => 'گھمدیاں اکھاں نال شکل',
    '😬' => 'منہ بناندی شکل',
    '🤥' => 'جھوٹ بولدی شکل',
    '🫨' => 'ਥਰਥਰਾਉਂਦਾ ਚਿਹਰਾ',
    '😌' => 'آرام دہ شکل',
    '😔' => 'اداس شکل',
    '😪' => 'سُتی شکل',
    '🤤' => 'رال ٹپکاندی شکل',
    '😴' => 'سوندی شکل',
    '🫩' => 'ਸੁਜੀਆਂ ਅੱਖਾਂ ਵਾਲਾ ਚਿਹਰਾ',
    '😷' => 'طبی ماسک نال شکل',
    '🤒' => 'تھرمامیٹر نال شکل',
    '🤕' => 'سر آلی پٹی نال شکل',
    '🤢' => 'متلی آلی شکل',
    '🤮' => 'آلٹی آن آلی شکل',
    '🤧' => 'چھیک ماردی شکل',
    '🥵' => 'ਤਪਿਆ ਹੋਇਆ ਚਿਹਰਾ',
    '🥶' => 'ਠੰਢਾ ਚਿਹਰਾ',
    '🥴' => 'ਚਕਰਾਉਂਦਾ ਚਿਹਰਾ',
    '😵' => 'بدحواس شکل',
    '🤯' => 'پاٹا سر',
    '🤠' => 'گوالے دے کلاے دی شکل',
    '🥳' => 'ਪਾਰਟੀ ਮਨਾਉਂਦਾ ਚਿਹਰਾ',
    '🥸' => 'ਢੌਂਗੀ ਚਿਹਰਾ',
    '😎' => 'دُھوب آلی عینک نال مسکراندی شکل',
    '🤓' => 'بیوقوف شکل',
    '🧐' => 'یک چشمی شکل',
    '😕' => 'متذبذب شکل',
    '🫤' => 'ਤਿਰਛੇ ਮੂੰਹ ਵਾਲਾ ਚਿਹਰਾ',
    '😟' => 'پریشان ہوئی شکل',
    '🙁' => 'ہلکی تیوری آلی شکل',
    '☹' => 'تیوری آلی شکل',
    '😮' => 'کھلے منہ آلی شکل',
    '😯' => 'منہ بند کیتی شکل',
    '😲' => 'حیرت زدہ شکل',
    '😳' => 'جوشیلی شکل',
    '🫪' => 'ਫ਼ਿਕਰਮੰਦ ਚਿਹਰਾ',
    '🥺' => 'ਸਫ਼ਾਈ ਦਿੰਦਾ ਚਿਹਰਾ',
    '🥹' => 'ਹੰਝੂ ਰੋਕਣ ਦੀ ਕੋਸ਼ਿਸ਼ ਕਰ ਰਿਹਾ ਚਿਹਰਾ',
    '😦' => 'کھلے منہ نال تیوری آلی شکل',
    '😧' => 'دُکھی شکل',
    '😨' => 'خوفزدہ شکل',
    '😰' => 'کُھلے منہ اتے مڑکے آلی شکل',
    '😥' => 'مایوس پر آرام دہ شکل',
    '😢' => 'روندی شکل',
    '😭' => 'اوچا روندی شکل',
    '😱' => 'خوف وچ چیخدی شکل',
    '😖' => 'ہکّی بکّی شکل',
    '😣' => 'ثابت قدم شکل',
    '😞' => 'مایوس شکل',
    '😓' => 'ٹھنڈے پسینے آلی شکل',
    '😩' => 'بیزار شکل',
    '😫' => 'تھکی شکل',
    '🥱' => 'ਉਬਾਸੀ ਲੈਂਦਾ ਚਿਹਰਾ',
    '😤' => 'چوندے ہوئے ناک نال شکل',
    '😡' => 'لٹکی ہوئی شکل',
    '😠' => 'رُسی شکل',
    '🤬' => 'منہ اُوتے علامتاں نال شکل',
    '😈' => 'سینگاں نال مسکراندی شکل',
    '👿' => 'سینگاں نال غصے آلی شکل',
    '💀' => 'کھوپڑی',
    '☠' => 'انتباہ دی علامت اتے کھوپڑی',
    '💩' => 'پو دا انبار',
    '🤡' => 'مسخرے دی شکل',
    '👹' => 'دیو',
    '👺' => 'آسیب',
    '👻' => 'بھوت',
    '👽' => 'اجنبی',
    '👾' => 'بدصورت اجنبی',
    '🤖' => 'روبوٹ دی شکل',
    '😺' => 'کھلے منہ نال بلی دی مسکراندی شکل',
    '😸' => 'مسکراندیاں اکھاں نال دند پیسدی بلی دی شکل',
    '😹' => 'خوشی دے اتھرواں نال بلی دی شکل',
    '😻' => 'دل آلیاں ـ اکھاں نال مسکراندی شکل',
    '😼' => 'وگڑی ہوئی مسکراہٹ نال بلی دی شکل',
    '😽' => 'بند اکھاں نال بلی دی چومدی ہوئی شکل',
    '🙀' => 'بلی دی بیزار شکل',
    '😿' => 'بلی دی روندی شکل',
    '😾' => 'بلی دی لٹکی شکل',
    '🙈' => 'ویکھو-کوئی-شیطان باندر نہیں',
    '🙉' => 'سنو-کوئی-شیطان باندر نہیں',
    '🙊' => 'بولو-کوئی-شیطان-باندر نہیں',
    '💌' => 'پیار دا پتر',
    '💘' => 'تیر نال دل',
    '💝' => 'فیتے نال دل',
    '💖' => 'عشق دا اظہار کردا دل',
    '💗' => 'وددھا ہوئیا دل',
    '💓' => 'دھڑکدا دل',
    '💞' => 'گھومدا دل',
    '💕' => 'دو دل',
    '💟' => 'دل دی سجاوٹ',
    '❣' => 'دل دی زور دا پُکار',
    '💔' => 'ٹوٹیا ہوئیا دل',
    '❤' => 'لال دل',
    '🩷' => 'ਗੁਲਾਬੀ ਦਿਲ',
    '🧡' => 'نارنگی دل',
    '💛' => 'پیلا دل',
    '💚' => 'سبز دل',
    '💙' => 'نیلا دل',
    '🩵' => 'ਹਲਕਾ ਨੀਲਾ ਦਿਲ',
    '💜' => 'جامنی دل',
    '🤎' => 'ਭੂਰਾ ਦਿਲ',
    '🖤' => 'کالا دل',
    '🩶' => 'ਸਲੇਟੀ ਦਿਲ',
    '🤍' => 'ਚਿੱਟਾ ਦਿਲ',
    '💋' => 'چومی دا نشان',
    '💯' => 'سو نکات',
    '💢' => 'غصے دی علامت',
    '🫯' => 'ਹੱਥੋਪਾਈ',
    '💥' => 'ٹکرونا',
    '💫' => 'بدحواس',
    '💦' => 'پسینے دا نیکا جیہا قطرہ',
    '💨' => 'خوش باش وکھرے ہو رہے',
    '🕳' => 'موری',
    '💬' => 'تقریری بھکانہ',
    '🗨' => 'تقریر دا کھبا حباب',
    '🗯' => 'غصے دا سجّا حباب',
    '💭' => 'خیالی بھکانہ',
    '💤' => 'zzz',
    '👋' => 'ہتھ ہلاندیاں',
    '🤚' => 'ہتھ دا ابھریا پچھلا پاسا',
    '🖐' => 'چوڑیاں کیتیاں اُنگلاں نال اُوتے کیتا ہتھ',
    '✋' => 'اُوتے کیتا ہتھ',
    '🖖' => 'قلزات دے دیوتا نوں سلامی دینا',
    '🫱' => 'ਸੱਜੇ ਪਾਸੇ ਹੱਥ',
    '🫲' => 'ਖੱਬੇ ਪਾਸੇ ਹੱਥ',
    '🫳' => 'ਥੱਲੇ ਵੱਲ ਹਥੇਲੀ',
    '🫴' => 'ਉੱਤੇ ਵੱਲ ਹਥੇਲੀ',
    '🫷' => 'ਖੱਬੀ ਦਿਸ਼ਾ ਵੱਲ ਧੱਕਾ ਲਾਉਂਦਾ ਹੱਥ',
    '🫸' => 'ਸੱਜੀ ਦਿਸ਼ਾ ਵੱਲ ਧੱਕਾ ਲਾਉਂਦਾ ਹੱਥ',
    '👌' => 'ٹھیک اے ہتھ',
    '🤌' => 'ਇਕੱਠੀਆਂ ਉਂਗਲਾਂ',
    '🤏' => 'ਚੂੰਢੀ ਜਿੰਨਾ',
    '✌' => 'فتح دا ہتھ',
    '🤞' => 'اُنگلاں آرپار کرنا',
    '🫰' => 'ਚੁਟਕੀ ਮਾਰਦਾ ਹੱਥ',
    '🤟' => 'تہاڈے نال پریم آ دا اشارہ',
    '🤘' => 'سینگ سائن آف کرو',
    '🤙' => 'کال کردا ہتھ',
    '👈' => 'ہتھ دے مخالف پاسیوں شہادت دی انگلی نال اوتے کھبے اشارہ کردیاں ہوئیاں',
    '👉' => 'ہتھ دے مخالف پاسیوں شہادت دی انگلی نال سجے اشارہ کردیاں ہوئیاں',
    '👆' => 'ہتھ دے مخالف پاسیوں شہادت دی انگلی نال اوتے اشارہ کردیاں ہوئیاں',
    '🖕' => 'درمیانی اُنگل',
    '👇' => 'ہتھ دے مخالف پاسیوں انگشت شہادت نال ہیٹھاں اشارہ کردیاں ہوئیاں',
    '☝' => 'اوتے اشارہ کردی شہادت آلی اُنگل',
    '🫵' => 'ਦਰਸ਼ਕ ਵੱਲ ਇਸ਼ਾਰਾ ਕਰਦੀ ਉਂਗਲ',
    '👍' => 'انگوٹھا اوتے',
    '👎' => 'انگوٹھا ہیٹھاں',
    '✊' => 'ابھاری ہوئی مُٹھی',
    '👊' => 'آن آلی مُٹھی',
    '🤛' => 'کھبے پاسے سامنا کردی مُٹھی',
    '🤜' => 'سجے پاسے سامنا کردی مٹھی',
    '👏' => 'تالیاں وجاندا ہتھ',
    '🙌' => 'ہتھ اُوچا کرنا',
    '🫶' => 'ਦਿਲ ਬਣੇ ਹੱਥ',
    '👐' => 'کھلے ہتھ',
    '🤲' => 'اکٹھے ہتھلیاں اُوتے کرنا',
    '🤝' => 'ہتھ ملانا',
    '🙏' => 'دوہرے کیتے ہتھ',
    '✍' => 'لکھائی کردا ہتھ',
    '💅' => 'نوں پالش',
    '🤳' => 'سیلفی',
    '💪' => 'دو سراں آلا خم دار پٹھا',
    '🦾' => 'ਮਕੈਨੀਕਲ ਬਾਂਹ',
    '🦿' => 'ਮਕੈਨੀਕਲ ਲੱਤ',
    '🦵' => 'ਲੱਤ',
    '🦶' => 'ਪੈਰ',
    '👂' => 'کان',
    '🦻' => 'ਸੁਣਨ ਵਾਲੀ ਮਸ਼ੀਨ ਲੱਗਿਆ ਕੰਨ',
    '👃' => 'نک',
    '🧠' => 'دماغ',
    '🫀' => 'ਦਿਲ ਦੇ ਅੰਗ',
    '🫁' => 'ਫੇਫੜੇ',
    '🦷' => 'ਦੰਦ',
    '🦴' => 'ਹੱਡੀ',
    '👀' => 'اکھاں',
    '👁' => 'اکھ',
    '👅' => 'جیب',
    '👄' => 'منہ',
    '🫦' => 'ਬੁੱਲ੍ਹਾਂ ਨੂੰ ਕੱਟਣਾ',
    '👶' => 'نیانا',
    '🧒' => 'بال',
    '👦' => 'منڈا',
    '👧' => 'کڑی',
    '🧑' => 'بالغ',
    '👱' => 'بُھورے والاں آلا بندہ',
    '👨' => 'بندہ',
    '🧔' => 'داڑھی آلا بندا',
    '👩' => 'زنانی',
    '🧓' => 'سیانے بالغ',
    '👴' => 'بڈھا بندا',
    '👵' => 'بڈھی زنانی',
    '🙍' => 'تیوری آلا بندہ',
    '🙎' => 'لٹکیا ہوئیا بندہ',
    '🙅' => 'بندہ نہیں دا اشارہ کر دیاں ہوئیاں',
    '🙆' => 'بندہ ٹھیک اے دا اشارہ کر دیاں ہوئیاں',
    '💁' => 'ہتھ نال تھپکی دیندا بندہ',
    '🙋' => 'ہتھ اُوچا کردا بندا',
    '🧏' => 'ਬੋਲ਼ਾ ਵਿਅਕਤੀ',
    '🙇' => 'جُھکیا ہوئیا بندہ',
    '🤦' => 'ہتھ منہ اوتے رکھدا بندہ',
    '🤷' => 'مُڈے اچکاندا بندہ',
    '👮' => 'پُلس دا افسر',
    '🕵' => 'جاسوس',
    '💂' => 'چوکیدار',
    '🥷' => 'ਨਿੰਜਾ',
    '👷' => 'تعمیری کم کرن آلے',
    '🫅' => 'ਤਾਜ ਵਾਲਾ ਵਿਅਕਤੀ',
    '🤴' => 'شہزادہ',
    '👸' => 'شہزادی',
    '👳' => 'پگڑی پاندا بندہ',
    '👲' => 'چینی ٹوپی نال بندہ',
    '🧕' => 'سر دے رومال نال زنانی',
    '🤵' => 'خاص جیکٹ وچ بندہ',
    '👰' => 'نقاب نال ووہٹی',
    '🤰' => 'حاملہ زنانی',
    '🫃' => 'ਗਰਭਵਤੀ ਦਿਸਦਾ ਆਦਮੀ',
    '🫄' => 'ਗਰਭਵਤੀ ਦਿਸਦਾ ਵਿਅਕਤੀ',
    '🤱' => 'دودھ پین آلا',
    '👼' => 'فرشتہ بال',
    '🎅' => 'سنٹا کلاز',
    '🤶' => 'مسز کلاز',
    '🦸' => 'ਸੁਪਰ-ਹੀਰੋ',
    '🦹' => 'ਮਹਾਂ-ਖਲਨਾਇਕ',
    '🧙' => 'جادوگر',
    '🧚' => 'فیری',
    '🧛' => 'خونخوار بلا',
    '🧜' => 'جل دیو',
    '🧝' => 'بُھوت',
    '🧞' => 'جن',
    '🧟' => 'زومبی',
    '🧌' => 'ਟਰੋਲ',
    '🫈' => 'ਜੱਤ ਵਾਲਾ ਪ੍ਰਾਣੀ',
    '💆' => 'پیغام لیندا بندہ',
    '💇' => 'حجامت کراندا بندہ',
    '🚶' => 'ٹردا بندہ',
    '🧍' => 'ਖੜ੍ਹਾ ਵਿਅਕਤੀ',
    '🧎' => 'ਗੋਡਿਆਂ ਭਾਰ ਬੈਠਾ ਵਿਅਕਤੀ',
    '🏃' => 'بھجدا بندہ',
    '💃' => 'نچدیاں زنانیاں',
    '🕺' => 'نچدا بندہ',
    '🕴' => 'اُڈدے ہوئے بیوپاری لباس وچ بندہ',
    '👯' => 'بنی دے کناں نال پارٹی کردے لوکیں',
    '🧖' => 'بھاپ نال بھرے کمرے وچ بندا',
    '🧗' => 'کوہ پیمائی کردا بندا',
    '🤺' => 'باڑ لاندا بندہ',
    '🏇' => 'گھوڑے دی دوڑ',
    '⛷' => 'اسکی باز',
    '🏂' => 'برف دے پھٹے تے گیھسیاں لین آلا بندہ',
    '🏌' => 'گالف کھیڈدا بندا',
    '🏄' => 'ویلا گزادا بندہ',
    '🚣' => 'کشتی چلاندا بندہ',
    '🏊' => 'تیردا بندہ',
    '⛹' => 'زور نال گیند کراندا بندا',
    '🏋' => 'بھار چُکدا بندا',
    '🚴' => 'موٹر سائیکل چلاندا بندہ',
    '🚵' => 'پہاڑ تے موٹرسائیکل چلاندا بندہ',
    '🤸' => 'چھکڑے دا پہيا چلاندا بندہ',
    '🤼' => 'کُشتی کردا بندہ',
    '🤽' => 'واٹر پولو کھیڈدا بندہ',
    '🤾' => 'ہینڈبال نال کھیڈدا بندہ',
    '🤹' => 'نظر بند بندہ',
    '🧘' => 'کنول دی حالت وچ بندا',
    '🛀' => 'بندہ غسل کر دیاں ہوئیاں',
    '🛌' => 'بیڈ وچ بندہ',
    '👭' => 'ہتھ پھڑدیاں دو زنانیاں',
    '👫' => 'ہتھ پھڑے ہوئے بندہ اتے زنانی',
    '👬' => 'ہتھ پھڑدے دو بندے',
    '💏' => 'چومنا',
    '💑' => 'دل نال جوڑا',
    '🗣' => 'بولن آلا سر',
    '👤' => 'خاکے وچ زنانی دی چھاتی',
    '👥' => 'خاکے وچ زنانیاں دیاں چھاتیاں',
    '🫂' => 'ਗਲੇ ਮਿਲ ਰਹੇ ਲੋਕ',
    '👪' => 'ٹبّر',
    '👣' => 'پیرا دے نشان',
    '🫆' => 'ਉਂਗਲਾਂ ਦੇ ਨਿਸ਼ਾਨ',
    '🦰' => 'ਲਾਲ ਰੰਗ ਦੇ ਵਾਲ',
    '🦱' => 'ਘੁੰਗਰਾਲੇ ਵਾਲ',
    '🦳' => 'ਚਿੱਟੇ ਵਾਲ',
    '🦲' => 'ਗੰਜਾ ਸਿਰ',
    '🐵' => 'باندر دی شکل',
    '🐒' => 'باندر',
    '🦍' => 'گوریلا',
    '🦧' => 'ਬਣਮਾਣਸ',
    '🐶' => 'کتے دی شکل',
    '🐕' => 'کتا',
    '🦮' => 'ਰਾਹਬਰ ਕੁੱਤਾ',
    '🐩' => 'پالتُو کتا',
    '🐺' => 'بھیڑیے دی شکل',
    '🦊' => 'لومڑی دی شکل',
    '🦝' => 'ਰੇਕੂਨ',
    '🐱' => 'بلی دی شکل',
    '🐈' => 'بلی',
    '🦁' => 'شیر دی شکل',
    '🐯' => 'چیتے دی شکل',
    '🐅' => 'چیتا',
    '🐆' => 'تیندوا',
    '🐴' => 'گھوڑے دی شکل',
    '🫎' => 'ਮੂਸ',
    '🫏' => 'ਗਧਾ',
    '🐎' => 'گھوڑا',
    '🦄' => 'گینڈے دی شکل',
    '🦓' => 'زیبرا',
    '🦌' => 'ہرن',
    '🦬' => 'ਜੰਗਲੀ ਸਾਨ੍ਹ',
    '🐮' => 'گاں دی شکل',
    '🐂' => 'ٹگا',
    '🐃' => 'پانی دا سنڈا',
    '🐄' => 'گاں',
    '🐷' => 'سور دی شکل',
    '🐖' => 'سور',
    '🐗' => 'جنگلی سور',
    '🐽' => 'سور دا ناک',
    '🐏' => 'دنبہ',
    '🐑' => 'پھیڈ',
    '🐐' => 'بکری',
    '🐪' => 'اوٹھ',
    '🐫' => 'دو کوہاناں آلا اوٹھ',
    '🦙' => 'ਲਾਮਾ',
    '🦒' => 'زرافہ',
    '🐘' => 'ہاتھی',
    '🦣' => 'ਮੈਮਥ',
    '🦏' => 'گینڈا',
    '🦛' => 'ਦਰਿਆਈ ਘੋੜਾ',
    '🐭' => 'چووے دی شکل',
    '🐁' => 'چوا',
    '🐀' => 'چووا',
    '🐹' => 'موش نما دی شکل',
    '🐰' => 'خرگوش دی شکل',
    '🐇' => 'خرگوش',
    '🐿' => 'دھاری دار گلہری',
    '🦫' => 'ਊਦਬਿਲਾਉ',
    '🦔' => 'جنگلی چوہا',
    '🦇' => 'چمگادڑ',
    '🐻' => 'ریچھ دی شکل',
    '🐨' => 'کوآلہ',
    '🐼' => 'پانڈے دی شکل',
    '🦥' => 'ਸਲੌਥ',
    '🦦' => 'ਊਦ ਬਿਲਾਵ',
    '🦨' => 'ਸਕੰਕ',
    '🦘' => 'ਕੰਗਾਰੂ',
    '🦡' => 'ਬਿੱਜੂ',
    '🐾' => 'پنجے دے نشان',
    '🦃' => 'ترکی',
    '🐔' => 'پالتُو کُکڑ',
    '🐓' => 'کُکڑ',
    '🐣' => 'انڈے چُوں نکلدا چوچا',
    '🐤' => 'چھوٹا چوچا',
    '🐥' => 'اگیوں سامنا کردا نیکا چوچا',
    '🐦' => 'پنچھی',
    '🐧' => 'پینگوئن',
    '🕊' => 'فاختہ',
    '🦅' => 'عقاب',
    '🦆' => 'بطخ',
    '🦢' => 'ਹੰਸ',
    '🦉' => 'الو',
    '🦤' => 'ਡੋਡੋ',
    '🪶' => 'ਖੰਭ',
    '🦩' => 'ਲਮਢੀਂਗ',
    '🦚' => 'ਮੋਰ',
    '🦜' => 'ਤੋਤਾ',
    '🪽' => 'ਪੰਖ',
    '🪿' => 'ਬੱਤਖ ਦੀ ਨਸਲ ਦਾ ਪੰਛੀ',
    '🐸' => 'ڈڈو دی شکل',
    '🐊' => 'مگرمچھ',
    '🐢' => 'کچھوا',
    '🦎' => 'کوڑ-کرلی',
    '🐍' => 'سپ',
    '🐲' => 'اژدھا دی شکل',
    '🐉' => 'اژدھا',
    '🦕' => 'سارپا',
    '🦖' => 'ٹی-ریکس',
    '🐳' => 'پانی وچ اُچھلدی وہیل',
    '🐋' => 'وہیل',
    '🐬' => 'ڈولفن',
    '🫍' => 'ਓਰਕਾ ਮੱਛੀ',
    '🦭' => 'ਸੀਲ ਮੱਛੀ',
    '🐟' => 'مچھی',
    '🐠' => 'گرم علاقے دی مچھی',
    '🐡' => 'دھونک مچھی',
    '🦈' => 'شارک',
    '🐙' => 'اکٹوپس',
    '🐚' => 'مرغولے دی شکل آلا شیل',
    '🪸' => 'ਕੋਰਲ',
    '🪼' => 'ਜੈਲੀਫਿਸ਼',
    '🦀' => 'اخبوط',
    '🦞' => 'ਝੀਂਗਾ ਮੱਛੀ',
    '🦐' => 'جھینگا',
    '🦑' => 'قیر ماہی',
    '🦪' => 'ਸਿੱਪ',
    '🐌' => 'گھونگا',
    '🦋' => 'تتلی',
    '🐛' => 'کھٹمل',
    '🐜' => 'کیڑی',
    '🐝' => 'شہد دی مکھی',
    '🪲' => 'ਬੀਂਡਾ',
    '🐞' => 'پنبہ دوز',
    '🦗' => 'کرکٹ',
    '🪳' => 'ਕਾਕਰੋਚ',
    '🕷' => 'مکڑی',
    '🕸' => 'مکڑی دا جالا',
    '🦂' => 'بچھو',
    '🦟' => 'ਮੱਛਰ',
    '🪰' => 'ਮੱਖੀ',
    '🪱' => 'ਸੁੰਡ',
    '🦠' => 'ਜੀਵਾਣੂ',
    '💐' => 'گلدستہ',
    '🌸' => 'چیری دا کِھلنا',
    '💮' => 'چٹّا پھول',
    '🪷' => 'ਕੰਵਲ',
    '🏵' => 'چمکدار فیتے دا بنیا پُھل',
    '🌹' => 'گلاب',
    '🥀' => 'مرجھایا ہویا پھول',
    '🌺' => 'جنس بٹوا',
    '🌻' => 'سورج مکھی',
    '🌼' => 'پھلاں دا کِھلنا',
    '🌷' => 'گلِ لالہ',
    '🪻' => 'ਹਾਇਸਿੰਥ',
    '🌱' => 'پنیری',
    '🪴' => 'ਗਮਲੇ ਵਾਲਾ ਪੌਦਾ',
    '🌲' => 'سدا بہار درخت',
    '🌳' => 'پت جھڑا درخت',
    '🌴' => 'کھجور دا درخت',
    '🌵' => 'ناگ پھنی',
    '🌾' => 'چولاں دا پلندہ',
    '🌿' => 'جڑی بوٹی',
    '☘' => 'چِیٹا لونگ',
    '🍀' => 'سہ شاخے چار پتّے',
    '🍁' => 'شکر دے درخت دا پتّا',
    '🍂' => 'ڈگدا پتّا',
    '🍃' => 'ہوا وچ پھڑپھڑاندا پتّا',
    '🪹' => 'ਖਾਲੀ ਆਲ੍ਹਣਾ',
    '🪺' => 'ਆਂਡਿਆਂ ਵਾਲਾ ਆਲ੍ਹਣਾ',
    '🍄' => 'کھمبی',
    '🪾' => 'ਪੱਤੇ ਰਹਿਤ ਰੁੱਖ',
    '🍇' => 'انگور',
    '🍈' => 'خربوزہ',
    '🍉' => 'دوانا',
    '🍊' => 'طنچوی نارنگی',
    '🍋' => 'نیمبو',
    '🍌' => 'کيلا',
    '🍍' => 'انناس',
    '🥭' => 'ਅੰਬ',
    '🍎' => 'لال سیب',
    '🍏' => 'ہرا سیپ',
    '🍐' => 'ناشپاتی',
    '🍑' => 'آڑو',
    '🍒' => 'شاہ دانہ',
    '🍓' => 'سٹابری',
    '🫐' => 'ਬਲੂਬੇਰੀ',
    '🥝' => 'کیوی پھل',
    '🍅' => 'ٹماٹر',
    '🫒' => 'ਜੈਤੂਨ',
    '🥥' => 'ناریل',
    '🥑' => 'مگر ناشپاتی',
    '🍆' => 'بتوں',
    '🥔' => 'آلو',
    '🥕' => 'گاجر',
    '🌽' => 'مکئی دا کان',
    '🌶' => 'تیز مرچ',
    '🫑' => 'ਲਾਲ ਸ਼ਿਮਲਾ ਮਿਰਚ',
    '🥒' => 'کھیرا',
    '🥬' => 'ਹਰੀਆਂ ਪੱਤੇਦਾਰ ਸਬਜ਼ੀਆਂ',
    '🥦' => 'شاخ گوبھی',
    '🧄' => 'ਲਸਣ',
    '🧅' => 'ਪਿਆਜ',
    '🥜' => 'مونگ پھلی',
    '🫘' => 'ਫਲੀਦਾਰ ਪੌਦਾ',
    '🌰' => 'شاہ بلوط',
    '🫚' => 'ਅਦਰਕ ਦੀ ਜੜ੍ਹ',
    '🫛' => 'ਮਟਰ ਦੀ ਫਲੀ',
    '🫜' => 'ਚੁਕੰਦਰ',
    '🍞' => 'روٹی',
    '🥐' => 'آٹے دی ہلالی شکل دی روٹی',
    '🥖' => 'کڑی ہوئی روٹی',
    '🫓' => 'ਪਰੌਂਠਾ',
    '🥨' => 'خستہ ول دار بسکٹ',
    '🥯' => 'ਗੋਲ ਬ੍ਰੈੱਡ',
    '🥞' => 'پین کیکس',
    '🧇' => 'ਵਫ਼ਲ',
    '🧀' => 'پنیر گاڑنا',
    '🍖' => 'ہڈی تے گوشت',
    '🍗' => 'کُکڑ دی لت',
    '🥩' => 'گوشت دا ٹکڑا',
    '🥓' => 'سور دا لُونا گوشت',
    '🍔' => 'ہیم برگرز',
    '🍟' => 'چپس',
    '🍕' => 'پیزا',
    '🌭' => 'ہاٹ ڈاگ',
    '🥪' => 'سینڈوچ',
    '🌮' => 'ٹیکو',
    '🌯' => 'بوریٹو',
    '🫔' => 'ਤਮਾਲ',
    '🥙' => 'پری ہوئی برابر روٹی',
    '🧆' => 'ਫਲਾਫੇਲ',
    '🥚' => 'انڈہ',
    '🍳' => 'کھانا-پکانا',
    '🥘' => 'خوراک لئی گھٹ ڈونگا توا',
    '🍲' => 'خوراک دی ہانڈی',
    '🫕' => 'ਫੋਂਡਜੂ',
    '🥣' => 'چمچ نال پیالہ',
    '🥗' => 'ہرا سلاد',
    '🍿' => 'پھولے',
    '🧈' => 'ਮੱਖਣ',
    '🧂' => 'ਨਮਕ',
    '🥫' => 'کین کیتی خوراک',
    '🍱' => 'بینٹو دا ڈبہ',
    '🍘' => 'خستہ چولاں آلا بسکٹ',
    '🍙' => 'چولاں دیاں گینداں',
    '🍚' => 'پکے ہوئے چول',
    '🍛' => 'شورے آلے چول',
    '🍜' => 'بھاپ آلی کولی',
    '🍝' => 'سپیکٹی',
    '🍠' => 'تلے ہوئے میٹھے آلو',
    '🍢' => 'اوڈن',
    '🍣' => 'سوشی',
    '🍤' => 'تلیا ہوئیا جھینگا',
    '🍥' => 'بھنور نال مچھی دا کیک',
    '🥮' => 'ਮੂਨ ਕੇਕ',
    '🍡' => 'ڈینگو',
    '🥟' => 'ڈمپلنگ',
    '🥠' => 'فارچیون کُکی',
    '🥡' => 'ٹیک آؤٹ باکس',
    '🍦' => 'نرم آئس کریم',
    '🍧' => 'منڈوی برف',
    '🍨' => 'آئس کریم',
    '🍩' => 'ڈونٹ',
    '🍪' => 'کوکی',
    '🎂' => 'سالگرہ دا کیک',
    '🍰' => 'شارٹ کیک',
    '🧁' => 'ਕੱਪਕੇਕ',
    '🥧' => 'پائی',
    '🍫' => 'چاکلیٹ بار',
    '🍬' => 'کھان آلی میٹھی ٹافی',
    '🍭' => 'لالی پاپ',
    '🍮' => 'کسٹرڈ',
    '🍯' => 'شہد دی ہانڈی',
    '🍼' => 'بال دی بوتل',
    '🥛' => 'دودھ دا گلاس',
    '☕' => 'گرم مشروب',
    '🫖' => 'ਕੇਤਲੀ',
    '🍵' => 'موٹھ تُوں بغیر چا آلا کپ',
    '🍶' => 'مقصد',
    '🍾' => 'کھولدے ڈھکن آلی بوتل',
    '🍷' => 'شراب دا گلاس',
    '🍸' => 'کاک ٹیل دا گلاس',
    '🍹' => 'گرمی دے مشروب',
    '🍺' => 'شراب دا پیالہ',
    '🍻' => 'لڑھکدے ہوئے شراب دے پیالے',
    '🥂' => 'لڑھکدے ہوئے گلاس',
    '🥃' => 'لڑھکدا ہویا گلاس',
    '🫗' => 'ਤਰਲ ਪਦਾਰਥ ਡੋਲ੍ਹਣਾ',
    '🥤' => 'نلکی نال کپ',
    '🧋' => 'ਬਬਲ ਚਾਹ',
    '🧃' => 'ਪੇਅ ਬਾਕਸ',
    '🧉' => 'ਮੇਟ',
    '🧊' => 'ਬਰਫ਼ ਦਾ ਟੁਕੜਾ',
    '🥢' => 'چاپ سٹکس',
    '🍽' => 'چھری اتے کانٹے نال تھالی',
    '🍴' => 'چھری اتے کانٹا',
    '🥄' => 'چمچ',
    '🔪' => 'باورچی خانے دی چھری',
    '🫙' => 'ਮਰਤਬਾਨ',
    '🏺' => 'دلو',
    '🌍' => 'گلوب یورپ ـ افریقہ وکھا رہیا اے',
    '🌎' => 'گلوب امریکہ یکھا رہیا اے',
    '🌏' => 'گلوب ایشیا ـ آسٹریلیا وکھا رہیا اے',
    '🌐' => 'طول البدل نال گلوب',
    '🗺' => 'دنیا دا نقشہ',
    '🗾' => 'جاپان دا نقشہ',
    '🧭' => 'ਕੰਪਾਸ',
    '🏔' => 'برف نال-ڈھکے پہاڑ',
    '⛰' => 'پہاڑ',
    '🛘' => 'ਪਹਾੜ ਖਿਸਕਣਾ',
    '🌋' => 'آتش فشاں',
    '🗻' => 'ماؤنٹ فجی',
    '🏕' => 'خیمہ زنی',
    '🏖' => 'چھتری نال ساحل سمندر',
    '🏜' => 'صحرا',
    '🏝' => 'صحرائی جزیرہ',
    '🏞' => 'قومی پارک',
    '🏟' => 'اسٹیڈیم',
    '🏛' => 'کلاسیکل عمارت',
    '🏗' => 'عمارت دی تعمیر',
    '🧱' => 'ਇੱਟ',
    '🪨' => 'ਪੱਥਰ',
    '🪵' => 'ਲੱਕੜ',
    '🛖' => 'ਝੌਂਪੜੀ',
    '🏘' => 'مکان',
    '🏚' => 'متروکہ گھر',
    '🏠' => 'گھر',
    '🏡' => 'باغیچے نال گھر',
    '🏢' => 'دفتر دی عمارت',
    '🏣' => 'جاپانیاں دا ڈاکخانہ',
    '🏤' => 'ڈاکخانہ',
    '🏥' => 'ہسپتال',
    '🏦' => 'بینک',
    '🏨' => 'ہوٹل',
    '🏩' => 'پیار دا ہوٹل',
    '🏪' => 'سٹور دا سُکھ',
    '🏫' => 'سکول',
    '🏬' => 'ڈیپارٹمنٹ سٹور',
    '🏭' => 'فیکٹری',
    '🏯' => 'جاپانیاں دا قلعہ',
    '🏰' => 'قلعہ',
    '💒' => 'ویاہ',
    '🗼' => 'ٹوکیو دا مینار',
    '🗽' => 'آزادی دا مجسمہ',
    '⛪' => 'چرچ',
    '🕌' => 'مسیت',
    '🛕' => 'ਹਿੰਦੂ ਮੰਦਿਰ',
    '🕍' => 'یہودیاں-دی-عبادت-گاہ',
    '⛩' => 'درگاہ شنٹو',
    '🕋' => 'کعبہ',
    '⛲' => 'فوارہ',
    '⛺' => 'خیمہ',
    '🌁' => 'دُھندلا',
    '🌃' => 'ستاریاں نال رات',
    '🏙' => 'شہر دا نظارہ',
    '🌄' => 'پہاڑاں اوتے سورج نکلنا',
    '🌅' => 'سورج نکلنا',
    '🌆' => 'تاریکی تے سٹی سکیپ',
    '🌇' => 'سورج غروب ہونا',
    '🌉' => 'رات ویلے پُل',
    '♨' => 'تتّے چشمے',
    '🎠' => 'ہنڈولا گھوڑا',
    '🛝' => 'ਖੇਡ ਦੇ ਮੈਦਾਨ ਵਾਲਾ ਸਲਾਈਡ',
    '🎡' => 'فیرس وہیل',
    '🎢' => 'تفریحی پارک وچ لگی بالاں دی ریل',
    '💈' => 'نائی دا قطب',
    '🎪' => 'سرکس دے تنبو',
    '🚂' => 'ریل دا انجن',
    '🚃' => 'ریل دی پٹری دی کار',
    '🚄' => 'تیز-رفتار ٹرین',
    '🚅' => 'گولی دے نک وانگوں تیز-رفتار ٹرین',
    '🚆' => 'ٹرین',
    '🚇' => 'میٹرو',
    '🚈' => 'لائٹ ٹرین',
    '🚉' => 'سٹیشن',
    '🚊' => 'ٹرام',
    '🚝' => 'مونو ریل',
    '🚞' => 'پہاڑی ریلوے',
    '🚋' => 'ٹرام کار',
    '🚌' => 'بس',
    '🚍' => 'آن آلی بس',
    '🚎' => 'بجلی نال چلن آلی بس',
    '🚐' => 'نیکی بس',
    '🚑' => 'ایمبولینس',
    '🚒' => 'آگ آلا انجن',
    '🚓' => 'پُلس دی کار',
    '🚔' => 'آن آلی پُلس دی کار',
    '🚕' => 'ٹیکسی',
    '🚖' => 'آن آلی ٹیکسی',
    '🚗' => 'آٹو موبائل',
    '🚘' => 'آن آلی آٹو موبائل',
    '🚙' => 'کھیڈ دی افادی گڈی',
    '🛻' => 'ਪਿੱਕਅੱਪ ਟਰੱਕ',
    '🚚' => 'ڈیلیوری آلا ٹرک',
    '🚛' => 'جوڑ دار لاری',
    '🚜' => 'ٹریکٹر',
    '🏎' => 'دوڑ وچ حصّہ لین آلی کار',
    '🏍' => 'موٹر سائیکل',
    '🛵' => 'موٹر سکوٹر',
    '🦽' => 'ਹੱਥਾਂ ਨਾਲ ਚੱਲਣ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ',
    '🦼' => 'ਮੋਟਰ ਨਾਲ ਚੱਲਣ ਵਾਲੀ ਵ੍ਹੀਲਚੇਅਰ',
    '🛺' => 'ਆਟੋ ਰਿਕਸ਼ਾ',
    '🚲' => 'بائیسیکل',
    '🛴' => 'کک سکوٹر',
    '🛹' => 'ਸਕੇਟਬੋਰਡ',
    '🛼' => 'ਰੋਲਰ ਸਕੇਟ',
    '🚏' => 'بس سٹاپ',
    '🛣' => 'موٹر وے',
    '🛤' => 'پٹڑی',
    '🛢' => 'تیل دا ڈرم',
    '⛽' => 'ایندھن دا پمپ',
    '🛞' => 'ਪਹੀਆ',
    '🚨' => 'پُلس دی گڈی دی بتی',
    '🚥' => 'ٹریفک دی اُفقی بتی',
    '🚦' => 'ٹریفک دی عمودی بتی',
    '🛑' => 'رکن دا اشارہ',
    '🚧' => 'تعمیر',
    '⚓' => 'لنگر',
    '🛟' => 'ਰਿੰਗ ਬੁਆਏ',
    '⛵' => 'بادبانی کشتی',
    '🛶' => 'نیکی کشتی',
    '🚤' => 'تیز رفتار کشتی',
    '🛳' => 'مسافر بحری جہاز',
    '⛴' => 'کشتی نال دریا پار کرنا',
    '🛥' => 'موٹر آلی کشتی',
    '🚢' => 'بحری-جہاز',
    '✈' => 'ہوائی جہاز',
    '🛩' => 'نیکا ہوائی جہاز',
    '🛫' => 'ہوائی جہاز دی روانگی',
    '🛬' => 'ہوائی جہاز دی آمد',
    '🪂' => 'ਪੈਰਾਸ਼ੂਟ',
    '💺' => 'نشست',
    '🚁' => 'ہیلی کاپٹر',
    '🚟' => 'ریلولے معطل',
    '🚠' => 'پہاڑ دا طنابی راہ',
    '🚡' => 'ٹرام دا ہوائی راہ',
    '🛰' => 'سیٹلائٹ',
    '🚀' => 'راکٹ',
    '🛸' => 'اُڑن طشتری',
    '🛎' => 'وردی پوش دربان دی گھنٹی',
    '🧳' => 'ਸਾਮਾਨ',
    '⌛' => 'ریت گھڑی',
    '⏳' => 'بہندی ہوئی ریت نال ریت گڈی',
    '⌚' => 'ویکھو',
    '⏰' => 'گھڑی دا الارم',
    '⏱' => 'سٹاپ واچ',
    '⏲' => 'وقت پیما گھڑی',
    '🕰' => 'کارنس گھڑی',
    '🕛' => 'بارہ وجے',
    '🕧' => 'ساڑھے بارہ',
    '🕐' => 'ایک وجے',
    '🕜' => 'ڈیڑھ وجے',
    '🕑' => 'دو وجے',
    '🕝' => 'ڈھائی وجے',
    '🕒' => 'تین وجے',
    '🕞' => 'ساڑھے تین',
    '🕓' => 'جار وجے',
    '🕟' => 'ساڑھے چار',
    '🕔' => 'پانچ وجے',
    '🕠' => 'ساڑھے پانج',
    '🕕' => 'چھ وجے',
    '🕡' => 'ساڑھے چھ',
    '🕖' => 'ست وجے',
    '🕢' => 'ساڑھے ست',
    '🕗' => 'اٹھ وجے',
    '🕣' => 'ساڑھے اٹھ',
    '🕘' => 'نو وجے',
    '🕤' => 'ساڑھے نو',
    '🕙' => 'دس وجے',
    '🕥' => 'ساڑھے دس',
    '🕚' => 'گیارہ وجے',
    '🕦' => 'ساڑھے گیارہ',
    '🌑' => 'نواں چاند',
    '🌒' => 'نشوونما پاندا ہلالی چاند',
    '🌓' => 'چاند دا پہلا چوتھائی حصہ',
    '🌔' => 'نشوونما پاندا مُحدِب چاند',
    '🌕' => 'پورا چاند',
    '🌖' => 'گھٹدا ہوئیا مُحدِب چاند',
    '🌗' => 'چاند دا آخری چوتھائی حصہ',
    '🌘' => 'گھٹدا ہوئیا مُحدِب چن',
    '🌙' => 'ہلالی چاند',
    '🌚' => 'نوے چاند دی شکل',
    '🌛' => 'شکل نال چاند دا پہلا چوتھائی حصہ',
    '🌜' => 'شکل نال چاند دا آخری چوتھائی حصہ',
    '🌡' => 'حرارت پیما',
    '☀' => 'سورج',
    '🌝' => 'شکل نال پورا چاند',
    '🌞' => 'شکل نال سورج',
    '🪐' => 'ਚੱਕਰਾਕਾਰ ਗ੍ਰਹਿ',
    '⭐' => 'درمیانہ چٹّا ستارہ',
    '🌟' => 'روشن ستارہ',
    '🌠' => 'شوٹنگ ستارہ',
    '🌌' => 'کہکشاں',
    '☁' => 'بدل',
    '⛅' => 'بدل دے پیچھے سورج',
    '⛈' => 'بجلی گرجن اتے مینہ دے نال بادل',
    '🌤' => 'نِکّے بادل دے پیچھے سورج',
    '🌥' => 'وڈے بادل دے پیچھے سورج',
    '🌦' => 'مینہ دے بادل پیچھے سورج',
    '🌧' => 'بادل نال مینہ',
    '🌨' => 'بادل نال برف باری',
    '🌩' => 'بادل نال بجلی',
    '🌪' => 'طوفان',
    '🌫' => 'دھُند',
    '🌬' => 'شکل تے پُھونک مارنا',
    '🌀' => 'ہنیری',
    '🌈' => 'قوس قزح',
    '🌂' => 'بند چھتری',
    '☂' => 'چھتری',
    '☔' => 'بارش دے قطریاں نال چھتری',
    '⛱' => 'زمین اُوتے چھتری',
    '⚡' => 'ہائی وولٹیج',
    '❄' => 'برف دا گولا',
    '☃' => 'برفانی پُتلا',
    '⛄' => 'پرف تُوں بغیر پرفانی پتلا',
    '☄' => 'دم دار تارہ',
    '🔥' => 'اگ',
    '💧' => 'قطرہ',
    '🌊' => 'پانی دی لہر',
    '🎃' => 'آتَشیں سَراب',
    '🎄' => 'کرسمس ٹری',
    '🎆' => 'آتشبازی',
    '🎇' => 'چمک کرنا آلا',
    '🧨' => 'ਪਟਾਖੇ',
    '✨' => 'چمکیلا',
    '🎈' => 'پکانہ',
    '🎉' => 'پارٹی وچ پٹاکیاں دی واج',
    '🎊' => 'شیرنی دی گیند',
    '🎋' => 'تانابتا ٹری',
    '🎍' => 'صنوبر دی آرائش',
    '🎎' => 'جاپانی گُڈیاں',
    '🎏' => 'بہندی ہوئی میٹھے پانی دی مچھی',
    '🎐' => 'ہوا دی جھنکار',
    '🎑' => 'چاند ویکھن دی تقریب',
    '🧧' => 'ਲਾਲ ਲਿਫ਼ਾਫਾ',
    '🎀' => 'فیتہ',
    '🎁' => 'لویٹیا تحفہ',
    '🎗' => 'یاد دہانی دا فیتہ',
    '🎟' => 'داخلے دیاں ٹکٹاں',
    '🎫' => 'ٹکٹ',
    '🎖' => 'فوجی تمغہ',
    '🏆' => 'ٹرافی',
    '🏅' => 'کھیڈاں دا تمغہ',
    '🥇' => 'پہلے نمبر دا تمغہ',
    '🥈' => 'دوجے نمبر دا تمغہ',
    '🥉' => 'تیجے نمبر دا تمغہ',
    '⚽' => 'سوکر بال',
    '⚾' => 'بیس بال',
    '🥎' => 'ਸਾਫਟਬਾਲ',
    '🏀' => 'باسکٹ بال',
    '🏐' => 'والی بال',
    '🏈' => 'امریکا دا فٹ بال',
    '🏉' => 'فٹ بال دا کھیڈ',
    '🎾' => 'ٹینس',
    '🥏' => 'ਫਲਾਇੰਗ ਡਿਸਕ',
    '🎳' => 'گیند کرانا',
    '🏏' => 'کرکٹ دی کھیڈ',
    '🏑' => 'میدانی ہاکی',
    '🏒' => 'برفانی ہاکی',
    '🥍' => 'ਲੈਕ੍ਰੋਸ',
    '🏓' => 'پنگ پانگ',
    '🏸' => 'چڑی-چھکا',
    '🥊' => 'باکسنگ دا دستانہ',
    '🥋' => 'مارشل آرٹس دی وردی',
    '🥅' => 'گول دا نیٹ',
    '⛳' => 'مغوری وچ جھنڈا',
    '⛸' => 'برف آلی جوتی',
    '🎣' => 'ماہی گیری دا پول',
    '🤿' => 'ਡਾਈਵਿੰਗ ਮਾਸਕ',
    '🎽' => 'بھجن آلی شرٹ',
    '🎿' => 'سکس',
    '🛷' => 'رہڑو',
    '🥌' => 'وڈھا بیضوی شکل دا پتھر',
    '🎯' => 'براہ راست ضرب لونا',
    '🪀' => 'ਯੋ-ਯੋ',
    '🪁' => 'ਪਤੰਗ',
    '🔫' => 'پستول',
    '🎱' => 'پول 8 بال',
    '🔮' => 'قلمی گیند',
    '🪄' => 'ਜਾਦੂਈ ਛੜੀ',
    '🎮' => 'بصری کھیڈ',
    '🕹' => 'جوائے سٹک',
    '🎰' => 'مغوری کرن آلی مشین',
    '🎲' => 'ڈائی کھیڈ',
    '🧩' => 'ਜਿਗਸਾਅ',
    '🧸' => 'ਖਿਡੌਣਾ ਭਾਲੂ',
    '🪅' => 'ਪਿਨਯਾਟਾ',
    '🪩' => 'ਸ਼ੀਸ਼ੇ ਦੀ ਗੇਂਦ',
    '🪆' => 'ਨੈਸਟਿੰਗ ਡੋਲ',
    '♠' => 'پھاؤڑا لباس',
    '♥' => 'دل دا لباس',
    '♦' => 'ہیرے دا لباس',
    '♣' => 'کلب دا لباس',
    '♟' => 'ਸ਼ਤਰੰਜ ਦਾ ਪਿਆਦਾ',
    '🃏' => 'مسخرہ',
    '🀄' => 'مہجونگ ریڈ ڈریگن',
    '🎴' => 'کارڈ کھیڈدے ہوئے پھول',
    '🎭' => 'فن انجام دیندیاں ہوئیاں',
    '🖼' => 'فریم آلی تصّویر',
    '🎨' => 'مصور دی تختی',
    '🧵' => 'ਧਾਗਾ',
    '🪡' => 'ਸੂਈ',
    '🧶' => 'ਊਨੀ ਧਾਗਾ',
    '🪢' => 'ਗੰਢ',
    '👓' => 'عینک',
    '🕶' => 'دھوپ آلیاں عینکاں',
    '🥽' => 'ਧੁੱਪ ਤੋਂ ਐਨਕਾਂ',
    '🥼' => 'ਲੈਬ ਵਿੱਚ ਪਹਿਨਣ ਵਾਲਾ ਕੋਟ',
    '🦺' => 'ਸੁਰੱਖਿਆ ਪੁਸ਼ਾਕ',
    '👔' => 'ٹائی',
    '👕' => 'ٹی ـ شرٹ',
    '👖' => 'جینز',
    '🧣' => 'سکاف',
    '🧤' => 'دستانے',
    '🧥' => 'کوٹ',
    '🧦' => 'جراباں',
    '👗' => 'لباس',
    '👘' => 'کُھلا لباس',
    '🥻' => 'ਸਾੜੀ',
    '🩱' => 'ਇੱਕ-ਪੀਸ ਵਾਲਾ ਸਵਿਮ ਸੂਟ',
    '🩲' => 'ਕੱਛੇ',
    '🩳' => 'ਨਿੱਕਰਾਂ',
    '👙' => 'بکنی',
    '👚' => 'زنانیاں دے کپڑے',
    '🪭' => 'ਤਹਿ ਹੋਣ ਵਾਲਾ ਹੱਥ ਪੱਖਾ',
    '👛' => 'پرس',
    '👜' => 'دستی-بیگ',
    '👝' => 'ہتھ وچ پھڑن آلا بیگ',
    '🛍' => 'خریداری آلے تھیلے',
    '🎒' => 'سکول دے سامان نال سفر',
    '🩴' => 'ਚੱਪਲ',
    '👞' => 'مردانہ جوتی',
    '👟' => 'نٹھن آلی جوتی',
    '🥾' => 'ਹਾਈਕਿੰਗ ਬੂਟ',
    '🥿' => 'ਫਲੈਟ ਜੁੱਤੇ',
    '👠' => 'اُوچی اڈی آلی جوتی',
    '👡' => 'زنانیاں دے سینڈل',
    '🩰' => 'ਬੈਲੇ ਲਈ ਜੁੱਤੇ',
    '👢' => 'زنانیاں دے بوٹ',
    '🪮' => 'ਵਾਲਾਂ ਦੀ ਕੰਘੀ',
    '👑' => 'تاج',
    '👒' => 'زنانیاں دا ہیٹ',
    '🎩' => 'اُوتلا ہیٹ',
    '🎓' => 'گریجویشن دی ٹوپی',
    '🧢' => 'چونج آلی ٹوپی',
    '🪖' => 'ਮਿਲਟਰੀ ਹੈਲਮਟ',
    '⛑' => 'امدادی کارکناں دا ہیلمٹ',
    '📿' => 'تسبیح',
    '💄' => 'سُرخی',
    '💍' => 'مُندری',
    '💎' => 'نایاب پتھر',
    '🔇' => 'خاموش کیتا سپیکر',
    '🔈' => 'ہولی واج آلا اسپیکر',
    '🔉' => 'درمیانی واج آلا اسپیکر',
    '🔊' => 'اُوچے واج آلا اسپیکر',
    '📢' => 'لاؤڈ سپیکر',
    '📣' => 'میگافون',
    '📯' => 'ڈاک دا بگل',
    '🔔' => 'گھنٹی',
    '🔕' => 'چابک نال گھنٹی',
    '🎼' => 'موسیقی دا سکور',
    '🎵' => 'موسیقی دا نوٹ',
    '🎶' => 'موسیقی دے نوٹس',
    '🎙' => 'سٹوڈیو مائیکروفون',
    '🎚' => 'لیول سلائیڈر',
    '🎛' => 'کنٹرول کرن آلے نابز',
    '🎤' => 'مائیکروفون',
    '🎧' => 'ہیڈفون',
    '📻' => 'ريڈيو',
    '🎷' => 'سیکسو فون',
    '🎺' => 'شہناہی',
    '🪊' => 'ਟ੍ਰੋਂਬੋਨ',
    '🪗' => 'ਅਕਾਰਡੀਅਨ',
    '🎸' => 'گٹار',
    '🎹' => 'موسیقی دا کلیدی تختہ',
    '🎻' => 'وائلن',
    '🪕' => 'ਬੈਂਜੋ',
    '🥁' => 'ڈھول',
    '🪘' => 'ਲੰਬਾ ਢੋਲ',
    '🪇' => 'ਮਰੈਕਜ਼',
    '🪈' => 'ਬੰਸਰੀ',
    '🪉' => 'ਹਾਰਪ',
    '📱' => 'موبائل فون',
    '📲' => 'تیر نال موبائل فون',
    '☎' => 'ٹیلی فون',
    '📞' => 'ٹیلی فون دا ریسیور',
    '📟' => 'پيجر',
    '📠' => 'فیکس مشین',
    '🔋' => 'بیٹری',
    '🪫' => 'ਘੱਟ ਬੈਟਰੀ',
    '🔌' => 'بجلی دا پلگ',
    '💻' => 'کمپیوٹر لیپ ٹاپ',
    '🖥' => 'ڈیسک ٹاپ کمپیوٹر',
    '🖨' => 'پرنٹر',
    '⌨' => 'کلیدی تختہ',
    '🖱' => 'کمپیوٹر دا ماؤس',
    '🖲' => 'ٹریک بال',
    '💽' => 'کمپیوٹر ڈسک',
    '💾' => 'فلاپی ڈسک',
    '💿' => 'آپٹیکل ڈسک',
    '📀' => 'dvd',
    '🧮' => 'ਐਬਾਕਸ',
    '🎥' => 'مووی کیمرہ',
    '🎞' => 'فلم نوں بنانا',
    '📽' => 'فلم پروجیکٹر',
    '🎬' => 'کلیپر بورڈ',
    '📺' => 'ٹیلی وژن',
    '📷' => 'کیمرہ',
    '📸' => 'فلیشن نال کیمرہ',
    '📹' => 'ویڈیو کیمرہ',
    '📼' => 'ویڈیو کیسٹ',
    '🔍' => 'کھبے ـ اشارہ کردا وڈا کرن آلا شیشہ',
    '🔎' => 'سجے ـ اشارہ کردا وڈا کرن آلا شیشہ',
    '🕯' => 'موم بتی',
    '💡' => 'بتی آلا بلب',
    '🔦' => 'ٹارچ',
    '🏮' => 'لال کاغذی لالٹین',
    '🪔' => 'ਦੀਵਾ',
    '📔' => 'آرائشی پنّے نال نوٹ بک',
    '📕' => 'بند کیتی کتاب',
    '📖' => 'کھلی کتاب',
    '📗' => 'سبز کتاب',
    '📘' => 'نیلی کتاب',
    '📙' => 'نارنگی کتاب',
    '📚' => 'کتاباں',
    '📓' => 'نوٹ بک',
    '📒' => 'لیجر',
    '📃' => 'خم نال صفحہ',
    '📜' => 'سکرول',
    '📄' => 'اوتلا سامنا کردا صفحہ',
    '📰' => 'اخبار',
    '🗞' => 'لویٹیا ہوئیا اخبار',
    '📑' => 'بک مارک ٹیبز',
    '🔖' => 'بک مارک',
    '🏷' => 'سرنامہ',
    '🪙' => 'ਸਿੱਕਾ',
    '💰' => 'پیسیاں آلا بستہ',
    '🪎' => 'ਖਜਾਨਾ',
    '💴' => 'ین بینک نوٹ',
    '💵' => 'ڈالر بینک نوٹ',
    '💶' => 'یورو بینک نوٹ',
    '💷' => 'پاؤنڈ بینک نوٹ',
    '💸' => 'پیسیاں نال پر',
    '💳' => 'کریڈٹ کارڈ',
    '🧾' => 'ਰਸੀਦ',
    '💹' => 'ین نال ودھدا ہوئیا چارٹ',
    '✉' => 'لفافہ',
    '📧' => 'ای-میل',
    '📨' => 'آن آلا لفافہ',
    '📩' => 'تیر نال لفافہ',
    '📤' => 'آؤٹ باکس ٹرے',
    '📥' => 'ان باکس ٹرے',
    '📦' => 'کھلی ہوئی پیکنگ',
    '📫' => 'ابھرے ہوئے جھنڈے نال بند کیتا گیا میل باکس',
    '📪' => 'ہیٹھلے جھنڈے نال بند کیتا گیا میل باکس',
    '📬' => 'اُبھرے ہوئے جھنڈے نال کھلا میل باکس',
    '📭' => 'ہیٹھلے جھنڈے نال کھلا میل باکس',
    '📮' => 'پوسٹ باکس',
    '🗳' => 'بیلٹ نال بیلٹ باکس',
    '✏' => 'پینسل',
    '✒' => 'کالی نوک',
    '🖋' => 'فاؤنٹین پین',
    '🖊' => 'قلم',
    '🖌' => 'پینٹ برش',
    '🖍' => 'کریون',
    '📝' => 'میمو',
    '💼' => 'بریف کیس',
    '📁' => 'فائل دا فولڈر',
    '📂' => 'فائل دا فولڈر کھولو',
    '🗂' => 'کارڈ انڈیکس دا تقسیم کنندہ',
    '📅' => 'کیلنڈر',
    '📆' => 'کیلنڈر پاڑو',
    '🗒' => 'سپائرل نوٹ پیڈ',
    '🗓' => 'سپائرل کیلنڈر',
    '📇' => 'انڈیکس کارڈ',
    '📈' => 'چارٹ ودھ رہیا اے',
    '📉' => 'چارٹ گھٹ رہیا اے',
    '📊' => 'بار چارٹ',
    '📋' => 'کلپ بورڈ',
    '📌' => 'پش پن',
    '📍' => 'گول پش پن',
    '📎' => 'کاغذ دا کلپ',
    '🖇' => 'ربط آؒلے پیپر کلپ',
    '📏' => 'سیدھا پیمانہ',
    '📐' => 'تکونی پیمانہ',
    '✂' => 'قینچی',
    '🗃' => 'کارڈ دی فائل باکس',
    '🗄' => 'فائل کیبنٹ',
    '🗑' => 'کوڑی دی ٹوکری',
    '🔒' => 'مقفل',
    '🔓' => 'غير مقفل شدہ',
    '🔏' => 'پین نال مقفل',
    '🔐' => 'کلید نال مقفل',
    '🔑' => 'کلید',
    '🗝' => 'پرانی کنجی',
    '🔨' => 'تھوڑی',
    '🪓' => 'ਕੁਹਾੜੀ',
    '⛏' => 'چُننا',
    '⚒' => 'ہتھوڑی اتے کدالی',
    '🛠' => 'ہتھوڑی اتے موچ',
    '🗡' => 'خنجر',
    '⚔' => 'ٹکراندیاں تلواراں',
    '💣' => 'بمب',
    '🪃' => 'ਬੂਮਰੈਂਗ',
    '🏹' => 'تیر اتے کمان',
    '🛡' => 'ڈھال',
    '🪚' => 'ਆਰੀ',
    '🔧' => 'مروڑنا',
    '🪛' => 'ਪੇਚਕਸ',
    '🔩' => 'کنڈی اتے میخ',
    '⚙' => 'گئیر',
    '🗜' => 'ڈھیر لانا',
    '⚖' => 'متوازن پیمانہ',
    '🦯' => 'ਟਟੋਲਣ ਲਈ ਸੋਟੀ',
    '🔗' => 'ربط کرو',
    '⛓' => 'زنجیراں',
    '🪝' => 'ਘੁੰਡੀ',
    '🧰' => 'ਐਜ਼ਾਰਾਂ ਦਾ ਬਕਸਾ',
    '🧲' => 'ਚੁੰਬਕ',
    '🪜' => 'ਪੌੜੀ',
    '🪏' => 'ਬੇਲਚਾ',
    '⚗' => 'قَرنبیق',
    '🧪' => 'ਜਾਂਚ ਨਲੀ',
    '🧫' => 'ਪੈਟਰੀ ਡਿਸ਼',
    '🧬' => 'ਡੀਐਨਏ',
    '🔬' => 'خورد بین',
    '🔭' => 'دوربین',
    '📡' => 'سیٹلائٹ انٹینا',
    '💉' => 'ٹیکا',
    '🩸' => 'ਖੂਨਦਾਨ',
    '💊' => 'گولی',
    '🩹' => 'ਚਿਪਕਣ ਵਾਲੀ ਪੱਟੀ',
    '🩼' => 'ਕਰੱਚ',
    '🩺' => 'ਸਟੇਥੋਸਕੋਪ',
    '🩻' => 'ਐਕਸ-ਰੇ',
    '🚪' => 'بوا',
    '🛗' => 'ਲਿਫਟ',
    '🪞' => 'ਸ਼ੀਸ਼ਾ',
    '🪟' => 'ਖਿੜਕੀ',
    '🛏' => 'بیڈ',
    '🛋' => 'صوفہ اتے چراغ',
    '🪑' => 'ਕੁਰਸੀ',
    '🚽' => 'بیت الخلا',
    '🪠' => 'ਪਲੰਜਰ',
    '🚿' => 'غسل',
    '🛁' => 'باتھ-ٹب',
    '🪤' => 'ਚੂਹੇਦਾਨੀ',
    '🪒' => 'ਉਸਤਰਾ',
    '🧴' => 'ਲੋਸ਼ਣ ਵਾਲੀ ਬੋਤਲ',
    '🧷' => 'ਸੇਫ਼ਟੀ ਪਿੰਨ',
    '🧹' => 'ਝਾੜੂ',
    '🧺' => 'ਟੋਕਰੀ',
    '🧻' => 'ਕਾਗਜ਼ ਦਾ ਰੋਲ',
    '🪣' => 'ਬਾਲਟੀ',
    '🧼' => 'ਸਾਬਣ',
    '🫧' => 'ਬੁਲਬੁਲੇ',
    '🪥' => 'ਦੰਦ ਬੁਰਸ਼',
    '🧽' => 'ਸਪੰਜ',
    '🧯' => 'ਅੱਗ ਬੁਝਾਉਣ ਵਾਲਾ ਯੰਤਰ',
    '🛒' => 'خریداری کرن آلی ٹوکری',
    '🚬' => 'سیگٹ',
    '⚰' => 'تابوت',
    '🪦' => 'ਕਬਰ ਦਾ ਪੱਥਰ',
    '⚱' => 'جنازہ کلش',
    '🧿' => 'ਨਜ਼ਰ ਤੋਂ ਤਵੀਤ',
    '🪬' => 'ਹਮਸਾ',
    '🗿' => 'موای',
    '🪧' => 'ਪਲੈਕਾਰਡ',
    '🪪' => 'ਸ਼ਨਾਖਤੀ ਕਾਰਡ',
    '🏧' => 'ATM دی علامت',
    '🚮' => 'کوڑا ٹوکری وچ سُٹن دی علامت',
    '🚰' => 'پین دے قابل پانی',
    '♿' => 'وئیل چئیر دی علامت',
    '🚹' => 'بندیاں دا کمرہ',
    '🚺' => 'زنانیاں دا کمرہ',
    '🚻' => 'لیٹرین',
    '🚼' => 'بال دی علامت',
    '🚾' => 'پانی آلا بیت الخلاء',
    '🛂' => 'پاسپورٹ کنٹرول',
    '🛃' => 'رسومات',
    '🛄' => 'سازو سامان دا دعویٰ',
    '🛅' => 'کھبا سفری سامان',
    '⚠' => 'انتباہ',
    '🚸' => 'لنگدے ہوئے بال',
    '⛔' => 'داخلہ نہیں',
    '🚫' => 'ممنوع کیتا',
    '🚳' => 'سائیکل نہیں',
    '🚭' => 'سگریٹ نوشی نہیں',
    '🚯' => 'کوڑا نا سُٹو',
    '🚱' => 'پین آلا پانی نہیں',
    '🚷' => 'کوئی پیدل ٹُرن آلے نہیں',
    '📵' => 'موبائل فون نہیں',
    '🔞' => 'اٹھاراں سالاں تُوں گھٹ کوئی وی نہیں',
    '☢' => 'تابکار',
    '☣' => 'حیاتیاتی',
    '⬆' => 'اُوتلا تیر',
    '↗' => 'اُوتلا-سجا تیر',
    '➡' => 'سجا تیر',
    '↘' => 'ہیٹھلا-سجا تیر',
    '⬇' => 'ہیٹھلا تیر',
    '↙' => 'ہیٹھلا-کھبا تیر',
    '⬅' => 'کھبا تیر',
    '↖' => 'اُوتلا-کھبا تیر',
    '↕' => 'اُوتلا-ہیٹھلا تیر',
    '↔' => 'کھبا-سجا تیر',
    '↩' => 'سجا تیر کھبے مڑدیاں ہوئیاں',
    '↪' => 'کھبا تیر سجے مڑدیاں ہوئیاں',
    '⤴' => 'سجا تیر اُوتے مڑدیاں ہوئیاں',
    '⤵' => 'سجا تیر ہیٹھاں مڑدیاں ہوئیاں',
    '🔃' => 'گھڑی وار عمودی تیر',
    '🔄' => 'مخالف گھڑی وار تیراں دا بٹن',
    '🔙' => 'پیچھے دا تیر',
    '🔚' => 'آخر دا تیر',
    '🔛' => 'چلان دا تیر',
    '🔜' => 'چھیتی دا تیر',
    '🔝' => 'اوتلا تیر',
    '🛐' => 'عبادت دی تھاں',
    '⚛' => 'ایٹم دی علامت',
    '🕉' => 'ہندو مذہب دا راہنما',
    '✡' => 'داؤد دا ستارہ',
    '☸' => 'ویل آف درھما',
    '☯' => 'یِن یانگ',
    '✝' => 'لاطینی صلیب',
    '☦' => 'اورتھوڈکس کراس',
    '☪' => 'ستارہ اتے ہلال',
    '☮' => 'امن دی علامت',
    '🕎' => 'نو باوواں آلا شمع دان',
    '🔯' => 'نقطہ لگے چھے ـ نوکدار ستارے',
    '🪯' => 'ਖੰਡਾ',
    '♈' => 'بُرج حَمَل',
    '♉' => 'بُرج ثور',
    '♊' => 'بُرجِ جوزا',
    '♋' => 'بُرج سرطان',
    '♌' => 'بُرج اسد',
    '♍' => 'بُرج سنبلہ',
    '♎' => 'بُرج میزان',
    '♏' => 'بُرج عقرب',
    '♐' => 'بُرج قَوس',
    '♑' => 'بُرج مکر راس',
    '♒' => 'برج دلو',
    '♓' => 'بُرج حوت',
    '⛎' => 'علم النجوم',
    '🔀' => 'ٹریک بٹن نوں شفل کرو',
    '🔁' => 'دوہران دا بٹن',
    '🔂' => 'کلا دوہران دا بٹن',
    '▶' => 'کھیڈ دا بٹن',
    '⏩' => 'چھیتی اگے کرن آلا بٹن',
    '⏭' => 'اگلے راہ دا بٹن',
    '⏯' => 'کھیڈن یا توقف دا بٹن',
    '◀' => 'پچھے کرن دا بٹن',
    '⏪' => 'چھیتی پیچھے کرن آلا بتن',
    '⏮' => 'آخری ٹریک دا بٹن',
    '🔼' => 'اوتے دا بٹن',
    '⏫' => 'چھیتی کرن دا بٹن',
    '🔽' => 'گھٹ کرن دا بٹن',
    '⏬' => 'چھیتی گھٹ کرن دا بٹن',
    '⏸' => 'توقف دا بٹن',
    '⏹' => 'روکن دا بٹن',
    '⏺' => 'ریکارڈ کرن دا بٹن',
    '⏏' => 'باہر کڈن دا بٹن',
    '🎦' => 'سینما',
    '🔅' => 'دھندلا بٹن',
    '🔆' => 'روشن بٹن',
    '📶' => 'انٹینا بارز',
    '🛜' => 'ਵਾਇਰਲੈੱਸ',
    '📳' => 'تھرتھراہٹ آلا موڈ',
    '📴' => 'موبائل فون بند',
    '♀' => 'زنانی دی علامت',
    '♂' => 'مرد دی علامت',
    '⚧' => 'ਟਰਾਂਸਜੈਂਡਰ ਪ੍ਰਤੀਕ',
    '✖' => 'وڈی ضرب x',
    '➕' => 'وڈی جمع دی علامت',
    '➖' => 'وڈی منفی دی علامت',
    '➗' => 'وڈی تقسیم دی علامت',
    '🟰' => 'ਬਰਾਬਰ ਦਾ ਚਿੰਨ੍ਹ',
    '♾' => 'ਅਨੰਤਤਾ',
    '‼' => 'دوپرا فجائی نشان',
    '⁉' => 'فجائیہ سوالیہ نشان',
    '❓' => 'سوالیہ نشان',
    '❔' => 'چٹّا سوالیہ نشان',
    '❕' => 'چٹّا فجائی نشان',
    '❗' => 'پُٹھا فجائی نشان',
    '〰' => 'لہراندی ڈیش',
    '💱' => 'کرنسی دا تبادلہ',
    '💲' => 'واوا ڈالر دی علامت',
    '⚕' => 'طبی علامت',
    '♻' => 'فیر کار آمد بنان دی علامت',
    '⚜' => 'فرانس دا شاہی نشان',
    '🔱' => 'تَرشُول دا نشان',
    '📛' => 'ناں دا بیج',
    '🔰' => 'شروع کرن آلیاں لئی جاپانی علامت',
    '⭕' => 'وڈا بھارا دائرہ',
    '✅' => 'چیٹّا بوجھل پڑتال دا نشان',
    '☑' => 'پڑتال نال بیلٹ باکس',
    '✔' => 'وڈا پڑتال دا نشان',
    '❌' => 'کراس دا نشان',
    '❎' => 'کراس دے نشان دا بٹن',
    '➰' => 'خم دار رسی',
    '➿' => 'دوہری خم دار رسی',
    '〽' => 'حصّے دی ادلی بدلی دا نشان',
    '✳' => 'آٹھ-بولیاں گئیاں نشانیاں',
    '✴' => 'آٹھ-اشارہ کیتے ستارے',
    '❇' => 'جگ مگ کرنا',
    '™' => 'تجارت دا نشان',
    '🫟' => 'ਛਪਾਕਾ',
    '🔠' => 'وڈے رومی حرف ان پٹ کرو',
    '🔡' => 'نیکے رومی حروف ان پٹ کرو',
    '🔢' => 'نمبرز ان پٹ کرو',
    '🔣' => 'علامتاں ان پٹ کرو',
    '🔤' => 'رومی حرف ان پٹ کرو',
    '🅰' => 'A دا بٹن (خون دی قسم)',
    '🆎' => 'AB بٹن (خون دی قسم)',
    '🅱' => 'B دا بٹن (خون دی قسم)',
    '🆑' => 'CL بٹن',
    '🆒' => 'چنگا بٹن',
    '🆓' => 'آزاد بٹن',
    'ℹ' => 'معلومات',
    '🆔' => 'ID بٹن',
    'Ⓜ' => 'دائرہ شُدہ M',
    '🆕' => 'نواں بٹن',
    '🆖' => 'NG بٹن',
    '🅾' => 'O دا بٹن (خون دی قسم)',
    '🆗' => 'ٹھیک اے بٹن',
    '🅿' => 'P دا بٹن',
    '🆘' => 'SOS بٹن',
    '🆙' => 'ਉੱਤੇ! ਬਟਨ',
    '🆚' => 'VS بٹن',
    '🈁' => 'جاپانی ’ ایتھے اے’ دا بٹن',
    '🈂' => 'جاپانی “خدمت دا معاوضہ” دا بٹن',
    '🈷' => 'جاپانی “ماہانہ رقم” دا بٹن',
    '🈶' => 'جاپانی “ادائیگی تُوں بغیر نہیں” دا بٹن',
    '🈯' => 'جاپانی “مخصوص کیتا” دا بٹن',
    '🉐' => 'جاپانی “سودا بازی” دا بٹن',
    '🈹' => 'جاپانی “رعائیت” دا بٹن',
    '🈚' => 'جاپانی “ادائیگی تُوں بغیر” دا بٹن',
    '🈲' => 'جاپانی “ممنوع” دا بٹن',
    '🉑' => 'جاپانی “قابلِ قبول” دا بٹن',
    '🈸' => 'جاپانی “درخواست” دا بٹن',
    '🈴' => 'جاپانی “پاس ہون دے درجے” دا بٹن',
    '🈳' => 'جاپانی “آسامی” دا بٹن',
    '㊗' => 'جاپانی “مبارک باد” دا بٹن',
    '㊙' => 'جاپانی “راز” دا بٹن',
    '🈺' => 'جاپانی “کاروبار لئی کھلا” دا بٹن',
    '🈵' => 'جاپانی “کوئی آسامی نہیں” دا بٹن',
    '🔴' => 'لال چکر',
    '🟠' => 'ਸੰਤਰੀ ਗੋਲਾ',
    '🟡' => 'ਪੀਲਾ ਗੋਲਾ',
    '🟢' => 'ਹਰਾ ਗੋਲਾ',
    '🔵' => 'نیلا چکر',
    '🟣' => 'ਜਾਮਣੀ ਗੋਲਾ',
    '🟤' => 'ਭੂਰਾ ਗੋਲਾ',
    '⚫' => 'کالا چکر',
    '⚪' => 'چٹّا چکر',
    '🟥' => 'ਲਾਲ ਵਰਗ',
    '🟧' => 'ਸੰਤਰੀ ਵਰਗ',
    '🟨' => 'ਪੀਲਾ ਵਰਗ',
    '🟩' => 'ਹਰਾ ਵਰਗ',
    '🟦' => 'ਨੀਲਾ ਵਰਗ',
    '🟪' => 'ਜਾਮਣੀ ਵਰਗ',
    '🟫' => 'ਭੂਰੇ ਰੰਗ ਦਾ ਵਰਗ',
    '⬛' => 'کالا وڈھا مربع',
    '⬜' => 'چٹّا وڈھا مربع',
    '◼' => 'کالا درمیانہ مربع',
    '◻' => 'چِیٹا درمیانہ مربع',
    '◾' => 'کالا درمیانہ ـ نیکا مربع',
    '◽' => 'چٹّا درمیانہ ـ نیکا مربع',
    '▪' => 'کالا نیکّا مربع',
    '▫' => 'چِیٹا نیکّا مربع',
    '🔶' => 'وڈھا نارنگی ہیرا',
    '🔷' => 'وڈھا نیلا ہیرا',
    '🔸' => 'نیکا نارنگی ہیرا',
    '🔹' => 'نیکا نیلا ہیرا',
    '🔺' => 'لال تکون اُوتے اشارہ کردی ہوئی',
    '🔻' => 'لال تکون ہیٹھاں اشارہ کردی ہوئی',
    '💠' => 'اک نقطے نال ہیرا',
    '🔘' => 'ریڈیو بٹن',
    '🔳' => 'چٹا مربعی بٹن',
    '🔲' => 'کالا مربعی بٹن',
    '🏁' => 'بساطی جھنڈا',
    '🚩' => 'تکونی جھنڈا',
    '🎌' => 'آرپار جھنڈے',
    '🏴' => 'کالا جھنڈا',
    '🏳' => 'چِیٹا جھنڈا',
];
