<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'чоловік і жінка, що цілуються: людина, людина, світлий тон шкіри і помірно світлий тон шкіри',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'чоловік і жінка, що цілуються: людина, людина, світлий тон шкіри і помірний тон шкіри',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'чоловік і жінка, що цілуються: людина, людина, світлий тон шкіри і помірно темний тон шкіри',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'чоловік і жінка, що цілуються: людина, людина, світлий тон шкіри і темний тон шкіри',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'чоловік і жінка, що цілуються: людина, людина, помірно світлий тон шкіри і світлий тон шкіри',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'чоловік і жінка, що цілуються: людина, людина, помірно світлий тон шкіри і помірний тон шкіри',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'чоловік і жінка, що цілуються: людина, людина, помірно світлий тон шкіри і помірно темний тон шкіри',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'чоловік і жінка, що цілуються: людина, людина, помірно світлий тон шкіри і темний тон шкіри',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'чоловік і жінка, що цілуються: людина, людина, помірний тон шкіри і світлий тон шкіри',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'чоловік і жінка, що цілуються: людина, людина, помірний тон шкіри і помірно світлий тон шкіри',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'чоловік і жінка, що цілуються: людина, людина, помірний тон шкіри і помірно темний тон шкіри',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'чоловік і жінка, що цілуються: людина, людина, помірний тон шкіри і темний тон шкіри',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'чоловік і жінка, що цілуються: людина, людина, помірно темний тон шкіри і світлий тон шкіри',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'чоловік і жінка, що цілуються: людина, людина, помірно темний тон шкіри і помірно світлий тон шкіри',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'чоловік і жінка, що цілуються: людина, людина, помірно темний тон шкіри і помірний тон шкіри',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'чоловік і жінка, що цілуються: людина, людина, помірно темний тон шкіри і темний тон шкіри',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'чоловік і жінка, що цілуються: людина, людина, темний тон шкіри і світлий тон шкіри',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'чоловік і жінка, що цілуються: людина, людина, темний тон шкіри і помірно світлий тон шкіри',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'чоловік і жінка, що цілуються: людина, людина, темний тон шкіри і помірний тон шкіри',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'чоловік і жінка, що цілуються: людина, людина, темний тон шкіри і помірно темний тон шкіри',
    '👨🏻‍❤‍💋‍👨🏻' => 'чоловік і жінка, що цілуються: чоловік, чоловік і світлий тон шкіри',
    '👨🏻‍❤‍💋‍👨🏼' => 'чоловік і жінка, що цілуються: чоловік, чоловік, світлий тон шкіри і помірно світлий тон шкіри',
    '👨🏻‍❤‍💋‍👨🏽' => 'чоловік і жінка, що цілуються: чоловік, чоловік, світлий тон шкіри і помірний тон шкіри',
    '👨🏻‍❤‍💋‍👨🏾' => 'чоловік і жінка, що цілуються: чоловік, чоловік, світлий тон шкіри і помірно темний тон шкіри',
    '👨🏻‍❤‍💋‍👨🏿' => 'чоловік і жінка, що цілуються: чоловік, чоловік, світлий тон шкіри і темний тон шкіри',
    '👨🏼‍❤‍💋‍👨🏻' => 'чоловік і жінка, що цілуються: чоловік, чоловік, помірно світлий тон шкіри і світлий тон шкіри',
    '👨🏼‍❤‍💋‍👨🏼' => 'чоловік і жінка, що цілуються: чоловік, чоловік і помірно світлий тон шкіри',
    '👨🏼‍❤‍💋‍👨🏽' => 'чоловік і жінка, що цілуються: чоловік, чоловік, помірно світлий тон шкіри і помірний тон шкіри',
    '👨🏼‍❤‍💋‍👨🏾' => 'чоловік і жінка, що цілуються: чоловік, чоловік, помірно світлий тон шкіри і помірно темний тон шкіри',
    '👨🏼‍❤‍💋‍👨🏿' => 'чоловік і жінка, що цілуються: чоловік, чоловік, помірно світлий тон шкіри і темний тон шкіри',
    '👨🏽‍❤‍💋‍👨🏻' => 'чоловік і жінка, що цілуються: чоловік, чоловік, помірний тон шкіри і світлий тон шкіри',
    '👨🏽‍❤‍💋‍👨🏼' => 'чоловік і жінка, що цілуються: чоловік, чоловік, помірний тон шкіри і помірно світлий тон шкіри',
    '👨🏽‍❤‍💋‍👨🏽' => 'чоловік і жінка, що цілуються: чоловік, чоловік і помірний тон шкіри',
    '👨🏽‍❤‍💋‍👨🏾' => 'чоловік і жінка, що цілуються: чоловік, чоловік, помірний тон шкіри і помірно темний тон шкіри',
    '👨🏽‍❤‍💋‍👨🏿' => 'чоловік і жінка, що цілуються: чоловік, чоловік, помірний тон шкіри і темний тон шкіри',
    '👨🏾‍❤‍💋‍👨🏻' => 'чоловік і жінка, що цілуються: чоловік, чоловік, помірно темний тон шкіри і світлий тон шкіри',
    '👨🏾‍❤‍💋‍👨🏼' => 'чоловік і жінка, що цілуються: чоловік, чоловік, помірно темний тон шкіри і помірно світлий тон шкіри',
    '👨🏾‍❤‍💋‍👨🏽' => 'чоловік і жінка, що цілуються: чоловік, чоловік, помірно темний тон шкіри і помірний тон шкіри',
    '👨🏾‍❤‍💋‍👨🏾' => 'чоловік і жінка, що цілуються: чоловік, чоловік і помірно темний тон шкіри',
    '👨🏾‍❤‍💋‍👨🏿' => 'чоловік і жінка, що цілуються: чоловік, чоловік, помірно темний тон шкіри і темний тон шкіри',
    '👨🏿‍❤‍💋‍👨🏻' => 'чоловік і жінка, що цілуються: чоловік, чоловік, темний тон шкіри і світлий тон шкіри',
    '👨🏿‍❤‍💋‍👨🏼' => 'чоловік і жінка, що цілуються: чоловік, чоловік, темний тон шкіри і помірно світлий тон шкіри',
    '👨🏿‍❤‍💋‍👨🏽' => 'чоловік і жінка, що цілуються: чоловік, чоловік, темний тон шкіри і помірний тон шкіри',
    '👨🏿‍❤‍💋‍👨🏾' => 'чоловік і жінка, що цілуються: чоловік, чоловік, темний тон шкіри і помірно темний тон шкіри',
    '👨🏿‍❤‍💋‍👨🏿' => 'чоловік і жінка, що цілуються: чоловік, чоловік і темний тон шкіри',
    '👩🏻‍❤‍💋‍👨🏻' => 'чоловік і жінка, що цілуються: жінка, чоловік і світлий тон шкіри',
    '👩🏻‍❤‍💋‍👨🏼' => 'чоловік і жінка, що цілуються: жінка, чоловік, світлий тон шкіри і помірно світлий тон шкіри',
    '👩🏻‍❤‍💋‍👨🏽' => 'чоловік і жінка, що цілуються: жінка, чоловік, світлий тон шкіри і помірний тон шкіри',
    '👩🏻‍❤‍💋‍👨🏾' => 'чоловік і жінка, що цілуються: жінка, чоловік, світлий тон шкіри і помірно темний тон шкіри',
    '👩🏻‍❤‍💋‍👨🏿' => 'чоловік і жінка, що цілуються: жінка, чоловік, світлий тон шкіри і темний тон шкіри',
    '👩🏼‍❤‍💋‍👨🏻' => 'чоловік і жінка, що цілуються: жінка, чоловік, помірно світлий тон шкіри і світлий тон шкіри',
    '👩🏼‍❤‍💋‍👨🏼' => 'чоловік і жінка, що цілуються: жінка, чоловік і помірно світлий тон шкіри',
    '👩🏼‍❤‍💋‍👨🏽' => 'чоловік і жінка, що цілуються: жінка, чоловік, помірно світлий тон шкіри і помірний тон шкіри',
    '👩🏼‍❤‍💋‍👨🏾' => 'чоловік і жінка, що цілуються: жінка, чоловік, помірно світлий тон шкіри і помірно темний тон шкіри',
    '👩🏼‍❤‍💋‍👨🏿' => 'чоловік і жінка, що цілуються: жінка, чоловік, помірно світлий тон шкіри і темний тон шкіри',
    '👩🏽‍❤‍💋‍👨🏻' => 'чоловік і жінка, що цілуються: жінка, чоловік, помірний тон шкіри і світлий тон шкіри',
    '👩🏽‍❤‍💋‍👨🏼' => 'чоловік і жінка, що цілуються: жінка, чоловік, помірний тон шкіри і помірно світлий тон шкіри',
    '👩🏽‍❤‍💋‍👨🏽' => 'чоловік і жінка, що цілуються: жінка, чоловік і помірний тон шкіри',
    '👩🏽‍❤‍💋‍👨🏾' => 'чоловік і жінка, що цілуються: жінка, чоловік, помірний тон шкіри і помірно темний тон шкіри',
    '👩🏽‍❤‍💋‍👨🏿' => 'чоловік і жінка, що цілуються: жінка, чоловік, помірний тон шкіри і темний тон шкіри',
    '👩🏾‍❤‍💋‍👨🏻' => 'чоловік і жінка, що цілуються: жінка, чоловік, помірно темний тон шкіри і світлий тон шкіри',
    '👩🏾‍❤‍💋‍👨🏼' => 'чоловік і жінка, що цілуються: жінка, чоловік, помірно темний тон шкіри і помірно світлий тон шкіри',
    '👩🏾‍❤‍💋‍👨🏽' => 'чоловік і жінка, що цілуються: жінка, чоловік, помірно темний тон шкіри і помірний тон шкіри',
    '👩🏾‍❤‍💋‍👨🏾' => 'чоловік і жінка, що цілуються: жінка, чоловік і помірно темний тон шкіри',
    '👩🏾‍❤‍💋‍👨🏿' => 'чоловік і жінка, що цілуються: жінка, чоловік, помірно темний тон шкіри і темний тон шкіри',
    '👩🏿‍❤‍💋‍👨🏻' => 'чоловік і жінка, що цілуються: жінка, чоловік, темний тон шкіри і світлий тон шкіри',
    '👩🏿‍❤‍💋‍👨🏼' => 'чоловік і жінка, що цілуються: жінка, чоловік, темний тон шкіри і помірно світлий тон шкіри',
    '👩🏿‍❤‍💋‍👨🏽' => 'чоловік і жінка, що цілуються: жінка, чоловік, темний тон шкіри і помірний тон шкіри',
    '👩🏿‍❤‍💋‍👨🏾' => 'чоловік і жінка, що цілуються: жінка, чоловік, темний тон шкіри і помірно темний тон шкіри',
    '👩🏿‍❤‍💋‍👨🏿' => 'чоловік і жінка, що цілуються: жінка, чоловік і темний тон шкіри',
    '👩🏻‍❤‍💋‍👩🏻' => 'чоловік і жінка, що цілуються: жінка, жінка і світлий тон шкіри',
    '👩🏻‍❤‍💋‍👩🏼' => 'чоловік і жінка, що цілуються: жінка, жінка, світлий тон шкіри і помірно світлий тон шкіри',
    '👩🏻‍❤‍💋‍👩🏽' => 'чоловік і жінка, що цілуються: жінка, жінка, світлий тон шкіри і помірний тон шкіри',
    '👩🏻‍❤‍💋‍👩🏾' => 'чоловік і жінка, що цілуються: жінка, жінка, світлий тон шкіри і помірно темний тон шкіри',
    '👩🏻‍❤‍💋‍👩🏿' => 'чоловік і жінка, що цілуються: жінка, жінка, світлий тон шкіри і темний тон шкіри',
    '👩🏼‍❤‍💋‍👩🏻' => 'чоловік і жінка, що цілуються: жінка, жінка, помірно світлий тон шкіри і світлий тон шкіри',
    '👩🏼‍❤‍💋‍👩🏼' => 'чоловік і жінка, що цілуються: жінка, жінка і помірно світлий тон шкіри',
    '👩🏼‍❤‍💋‍👩🏽' => 'чоловік і жінка, що цілуються: жінка, жінка, помірно світлий тон шкіри і помірний тон шкіри',
    '👩🏼‍❤‍💋‍👩🏾' => 'чоловік і жінка, що цілуються: жінка, жінка, помірно світлий тон шкіри і помірно темний тон шкіри',
    '👩🏼‍❤‍💋‍👩🏿' => 'чоловік і жінка, що цілуються: жінка, жінка, помірно світлий тон шкіри і темний тон шкіри',
    '👩🏽‍❤‍💋‍👩🏻' => 'чоловік і жінка, що цілуються: жінка, жінка, помірний тон шкіри і світлий тон шкіри',
    '👩🏽‍❤‍💋‍👩🏼' => 'чоловік і жінка, що цілуються: жінка, жінка, помірний тон шкіри і помірно світлий тон шкіри',
    '👩🏽‍❤‍💋‍👩🏽' => 'чоловік і жінка, що цілуються: жінка, жінка і помірний тон шкіри',
    '👩🏽‍❤‍💋‍👩🏾' => 'чоловік і жінка, що цілуються: жінка, жінка, помірний тон шкіри і помірно темний тон шкіри',
    '👩🏽‍❤‍💋‍👩🏿' => 'чоловік і жінка, що цілуються: жінка, жінка, помірний тон шкіри і темний тон шкіри',
    '👩🏾‍❤‍💋‍👩🏻' => 'чоловік і жінка, що цілуються: жінка, жінка, помірно темний тон шкіри і світлий тон шкіри',
    '👩🏾‍❤‍💋‍👩🏼' => 'чоловік і жінка, що цілуються: жінка, жінка, помірно темний тон шкіри і помірно світлий тон шкіри',
    '👩🏾‍❤‍💋‍👩🏽' => 'чоловік і жінка, що цілуються: жінка, жінка, помірно темний тон шкіри і помірний тон шкіри',
    '👩🏾‍❤‍💋‍👩🏾' => 'чоловік і жінка, що цілуються: жінка, жінка і помірно темний тон шкіри',
    '👩🏾‍❤‍💋‍👩🏿' => 'чоловік і жінка, що цілуються: жінка, жінка, помірно темний тон шкіри і темний тон шкіри',
    '👩🏿‍❤‍💋‍👩🏻' => 'чоловік і жінка, що цілуються: жінка, жінка, темний тон шкіри і світлий тон шкіри',
    '👩🏿‍❤‍💋‍👩🏼' => 'чоловік і жінка, що цілуються: жінка, жінка, темний тон шкіри і помірно світлий тон шкіри',
    '👩🏿‍❤‍💋‍👩🏽' => 'чоловік і жінка, що цілуються: жінка, жінка, темний тон шкіри і помірний тон шкіри',
    '👩🏿‍❤‍💋‍👩🏾' => 'чоловік і жінка, що цілуються: жінка, жінка, темний тон шкіри і помірно темний тон шкіри',
    '👩🏿‍❤‍💋‍👩🏿' => 'чоловік і жінка, що цілуються: жінка, жінка і темний тон шкіри',
    '🧑🏻‍🫯‍🧑🏼' => 'борці: світлий тон шкіри і помірно світлий тон шкіри',
    '🧑🏻‍🫯‍🧑🏽' => 'борці: світлий тон шкіри і помірний тон шкіри',
    '🧑🏻‍🫯‍🧑🏾' => 'борці: світлий тон шкіри і помірно темний тон шкіри',
    '🧑🏻‍🫯‍🧑🏿' => 'борці: світлий тон шкіри і темний тон шкіри',
    '🧑🏼‍🫯‍🧑🏻' => 'борці: помірно світлий тон шкіри і світлий тон шкіри',
    '🧑🏼‍🫯‍🧑🏽' => 'борці: помірно світлий тон шкіри і помірний тон шкіри',
    '🧑🏼‍🫯‍🧑🏾' => 'борці: помірно світлий тон шкіри і помірно темний тон шкіри',
    '🧑🏼‍🫯‍🧑🏿' => 'борці: помірно світлий тон шкіри і темний тон шкіри',
    '🧑🏽‍🫯‍🧑🏻' => 'борці: помірний тон шкіри і світлий тон шкіри',
    '🧑🏽‍🫯‍🧑🏼' => 'борці: помірний тон шкіри і помірно світлий тон шкіри',
    '🧑🏽‍🫯‍🧑🏾' => 'борці: помірний тон шкіри і помірно темний тон шкіри',
    '🧑🏽‍🫯‍🧑🏿' => 'борці: помірний тон шкіри і темний тон шкіри',
    '🧑🏾‍🫯‍🧑🏻' => 'борці: помірно темний тон шкіри і світлий тон шкіри',
    '🧑🏾‍🫯‍🧑🏼' => 'борці: помірно темний тон шкіри і помірно світлий тон шкіри',
    '🧑🏾‍🫯‍🧑🏽' => 'борці: помірно темний тон шкіри і помірний тон шкіри',
    '🧑🏾‍🫯‍🧑🏿' => 'борці: помірно темний тон шкіри і темний тон шкіри',
    '🧑🏿‍🫯‍🧑🏻' => 'борці: темний тон шкіри і світлий тон шкіри',
    '🧑🏿‍🫯‍🧑🏼' => 'борці: темний тон шкіри і помірно світлий тон шкіри',
    '🧑🏿‍🫯‍🧑🏽' => 'борці: темний тон шкіри і помірний тон шкіри',
    '🧑🏿‍🫯‍🧑🏾' => 'борці: темний тон шкіри і помірно темний тон шкіри',
    '🧑🏻‍❤‍🧑🏼' => 'чоловік і жінка із серцем між ними: людина, людина, світлий тон шкіри і помірно світлий тон шкіри',
    '🧑🏻‍❤‍🧑🏽' => 'чоловік і жінка із серцем між ними: людина, людина, світлий тон шкіри і помірний тон шкіри',
    '🧑🏻‍❤‍🧑🏾' => 'чоловік і жінка із серцем між ними: людина, людина, світлий тон шкіри і помірно темний тон шкіри',
    '🧑🏻‍❤‍🧑🏿' => 'чоловік і жінка із серцем між ними: людина, людина, світлий тон шкіри і темний тон шкіри',
    '🧑🏼‍❤‍🧑🏻' => 'чоловік і жінка із серцем між ними: людина, людина, помірно світлий тон шкіри і світлий тон шкіри',
    '🧑🏼‍❤‍🧑🏽' => 'чоловік і жінка із серцем між ними: людина, людина, помірно світлий тон шкіри і помірний тон шкіри',
    '🧑🏼‍❤‍🧑🏾' => 'чоловік і жінка із серцем між ними: людина, людина, помірно світлий тон шкіри і помірно темний тон шкіри',
    '🧑🏼‍❤‍🧑🏿' => 'чоловік і жінка із серцем між ними: людина, людина, помірно світлий тон шкіри і темний тон шкіри',
    '🧑🏽‍❤‍🧑🏻' => 'чоловік і жінка із серцем між ними: людина, людина, помірний тон шкіри і світлий тон шкіри',
    '🧑🏽‍❤‍🧑🏼' => 'чоловік і жінка із серцем між ними: людина, людина, помірний тон шкіри і помірно світлий тон шкіри',
    '🧑🏽‍❤‍🧑🏾' => 'чоловік і жінка із серцем між ними: людина, людина, помірний тон шкіри і помірно темний тон шкіри',
    '🧑🏽‍❤‍🧑🏿' => 'чоловік і жінка із серцем між ними: людина, людина, помірний тон шкіри і темний тон шкіри',
    '🧑🏾‍❤‍🧑🏻' => 'чоловік і жінка із серцем між ними: людина, людина, помірно темний тон шкіри і світлий тон шкіри',
    '🧑🏾‍❤‍🧑🏼' => 'чоловік і жінка із серцем між ними: людина, людина, помірно темний тон шкіри і помірно світлий тон шкіри',
    '🧑🏾‍❤‍🧑🏽' => 'чоловік і жінка із серцем між ними: людина, людина, помірно темний тон шкіри і помірний тон шкіри',
    '🧑🏾‍❤‍🧑🏿' => 'чоловік і жінка із серцем між ними: людина, людина, помірно темний тон шкіри і темний тон шкіри',
    '🧑🏿‍❤‍🧑🏻' => 'чоловік і жінка із серцем між ними: людина, людина, темний тон шкіри і світлий тон шкіри',
    '🧑🏿‍❤‍🧑🏼' => 'чоловік і жінка із серцем між ними: людина, людина, темний тон шкіри і помірно світлий тон шкіри',
    '🧑🏿‍❤‍🧑🏽' => 'чоловік і жінка із серцем між ними: людина, людина, темний тон шкіри і помірний тон шкіри',
    '🧑🏿‍❤‍🧑🏾' => 'чоловік і жінка із серцем між ними: людина, людина, темний тон шкіри і помірно темний тон шкіри',
    '🧑🏻‍🐰‍🧑🏼' => 'люди з кролячими вухами: світлий тон шкіри і помірно світлий тон шкіри',
    '🧑🏻‍🐰‍🧑🏽' => 'люди з кролячими вухами: світлий тон шкіри і помірний тон шкіри',
    '🧑🏻‍🐰‍🧑🏾' => 'люди з кролячими вухами: світлий тон шкіри і помірно темний тон шкіри',
    '🧑🏻‍🐰‍🧑🏿' => 'люди з кролячими вухами: світлий тон шкіри і темний тон шкіри',
    '🧑🏼‍🐰‍🧑🏻' => 'люди з кролячими вухами: помірно світлий тон шкіри і світлий тон шкіри',
    '🧑🏼‍🐰‍🧑🏽' => 'люди з кролячими вухами: помірно світлий тон шкіри і помірний тон шкіри',
    '🧑🏼‍🐰‍🧑🏾' => 'люди з кролячими вухами: помірно світлий тон шкіри і помірно темний тон шкіри',
    '🧑🏼‍🐰‍🧑🏿' => 'люди з кролячими вухами: помірно світлий тон шкіри і темний тон шкіри',
    '🧑🏽‍🐰‍🧑🏻' => 'люди з кролячими вухами: помірний тон шкіри і світлий тон шкіри',
    '🧑🏽‍🐰‍🧑🏼' => 'люди з кролячими вухами: помірний тон шкіри і помірно світлий тон шкіри',
    '🧑🏽‍🐰‍🧑🏾' => 'люди з кролячими вухами: помірний тон шкіри і помірно темний тон шкіри',
    '🧑🏽‍🐰‍🧑🏿' => 'люди з кролячими вухами: помірний тон шкіри і темний тон шкіри',
    '🧑🏾‍🐰‍🧑🏻' => 'люди з кролячими вухами: помірно темний тон шкіри і світлий тон шкіри',
    '🧑🏾‍🐰‍🧑🏼' => 'люди з кролячими вухами: помірно темний тон шкіри і помірно світлий тон шкіри',
    '🧑🏾‍🐰‍🧑🏽' => 'люди з кролячими вухами: помірно темний тон шкіри і помірний тон шкіри',
    '🧑🏾‍🐰‍🧑🏿' => 'люди з кролячими вухами: помірно темний тон шкіри і темний тон шкіри',
    '🧑🏿‍🐰‍🧑🏻' => 'люди з кролячими вухами: темний тон шкіри і світлий тон шкіри',
    '🧑🏿‍🐰‍🧑🏼' => 'люди з кролячими вухами: темний тон шкіри і помірно світлий тон шкіри',
    '🧑🏿‍🐰‍🧑🏽' => 'люди з кролячими вухами: темний тон шкіри і помірний тон шкіри',
    '🧑🏿‍🐰‍🧑🏾' => 'люди з кролячими вухами: темний тон шкіри і помірно темний тон шкіри',
    '👨🏻‍🫯‍👨🏼' => 'борець: світлий тон шкіри і помірно світлий тон шкіри',
    '👨🏻‍🫯‍👨🏽' => 'борець: світлий тон шкіри і помірний тон шкіри',
    '👨🏻‍🫯‍👨🏾' => 'борець: світлий тон шкіри і помірно темний тон шкіри',
    '👨🏻‍🫯‍👨🏿' => 'борець: світлий тон шкіри і темний тон шкіри',
    '👨🏼‍🫯‍👨🏻' => 'борець: помірно світлий тон шкіри і світлий тон шкіри',
    '👨🏼‍🫯‍👨🏽' => 'борець: помірно світлий тон шкіри і помірний тон шкіри',
    '👨🏼‍🫯‍👨🏾' => 'борець: помірно світлий тон шкіри і помірно темний тон шкіри',
    '👨🏼‍🫯‍👨🏿' => 'борець: помірно світлий тон шкіри і темний тон шкіри',
    '👨🏽‍🫯‍👨🏻' => 'борець: помірний тон шкіри і світлий тон шкіри',
    '👨🏽‍🫯‍👨🏼' => 'борець: помірний тон шкіри і помірно світлий тон шкіри',
    '👨🏽‍🫯‍👨🏾' => 'борець: помірний тон шкіри і помірно темний тон шкіри',
    '👨🏽‍🫯‍👨🏿' => 'борець: помірний тон шкіри і темний тон шкіри',
    '👨🏾‍🫯‍👨🏻' => 'борець: помірно темний тон шкіри і світлий тон шкіри',
    '👨🏾‍🫯‍👨🏼' => 'борець: помірно темний тон шкіри і помірно світлий тон шкіри',
    '👨🏾‍🫯‍👨🏽' => 'борець: помірно темний тон шкіри і помірний тон шкіри',
    '👨🏾‍🫯‍👨🏿' => 'борець: помірно темний тон шкіри і темний тон шкіри',
    '👨🏿‍🫯‍👨🏻' => 'борець: темний тон шкіри і світлий тон шкіри',
    '👨🏿‍🫯‍👨🏼' => 'борець: темний тон шкіри і помірно світлий тон шкіри',
    '👨🏿‍🫯‍👨🏽' => 'борець: темний тон шкіри і помірний тон шкіри',
    '👨🏿‍🫯‍👨🏾' => 'борець: темний тон шкіри і помірно темний тон шкіри',
    '👨🏻‍❤‍👨🏻' => 'чоловік і жінка із серцем між ними: чоловік, чоловік і світлий тон шкіри',
    '👨🏻‍❤‍👨🏼' => 'чоловік і жінка із серцем між ними: чоловік, чоловік, світлий тон шкіри і помірно світлий тон шкіри',
    '👨🏻‍❤‍👨🏽' => 'чоловік і жінка із серцем між ними: чоловік, чоловік, світлий тон шкіри і помірний тон шкіри',
    '👨🏻‍❤‍👨🏾' => 'чоловік і жінка із серцем між ними: чоловік, чоловік, світлий тон шкіри і помірно темний тон шкіри',
    '👨🏻‍❤‍👨🏿' => 'чоловік і жінка із серцем між ними: чоловік, чоловік, світлий тон шкіри і темний тон шкіри',
    '👨🏼‍❤‍👨🏻' => 'чоловік і жінка із серцем між ними: чоловік, чоловік, помірно світлий тон шкіри і світлий тон шкіри',
    '👨🏼‍❤‍👨🏼' => 'чоловік і жінка із серцем між ними: чоловік, чоловік і помірно світлий тон шкіри',
    '👨🏼‍❤‍👨🏽' => 'чоловік і жінка із серцем між ними: чоловік, чоловік, помірно світлий тон шкіри і помірний тон шкіри',
    '👨🏼‍❤‍👨🏾' => 'чоловік і жінка із серцем між ними: чоловік, чоловік, помірно світлий тон шкіри і помірно темний тон шкіри',
    '👨🏼‍❤‍👨🏿' => 'чоловік і жінка із серцем між ними: чоловік, чоловік, помірно світлий тон шкіри і темний тон шкіри',
    '👨🏽‍❤‍👨🏻' => 'чоловік і жінка із серцем між ними: чоловік, чоловік, помірний тон шкіри і світлий тон шкіри',
    '👨🏽‍❤‍👨🏼' => 'чоловік і жінка із серцем між ними: чоловік, чоловік, помірний тон шкіри і помірно світлий тон шкіри',
    '👨🏽‍❤‍👨🏽' => 'чоловік і жінка із серцем між ними: чоловік, чоловік і помірний тон шкіри',
    '👨🏽‍❤‍👨🏾' => 'чоловік і жінка із серцем між ними: чоловік, чоловік, помірний тон шкіри і помірно темний тон шкіри',
    '👨🏽‍❤‍👨🏿' => 'чоловік і жінка із серцем між ними: чоловік, чоловік, помірний тон шкіри і темний тон шкіри',
    '👨🏾‍❤‍👨🏻' => 'чоловік і жінка із серцем між ними: чоловік, чоловік, помірно темний тон шкіри і світлий тон шкіри',
    '👨🏾‍❤‍👨🏼' => 'чоловік і жінка із серцем між ними: чоловік, чоловік, помірно темний тон шкіри і помірно світлий тон шкіри',
    '👨🏾‍❤‍👨🏽' => 'чоловік і жінка із серцем між ними: чоловік, чоловік, помірно темний тон шкіри і помірний тон шкіри',
    '👨🏾‍❤‍👨🏾' => 'чоловік і жінка із серцем між ними: чоловік, чоловік і помірно темний тон шкіри',
    '👨🏾‍❤‍👨🏿' => 'чоловік і жінка із серцем між ними: чоловік, чоловік, помірно темний тон шкіри і темний тон шкіри',
    '👨🏿‍❤‍👨🏻' => 'чоловік і жінка із серцем між ними: чоловік, чоловік, темний тон шкіри і світлий тон шкіри',
    '👨🏿‍❤‍👨🏼' => 'чоловік і жінка із серцем між ними: чоловік, чоловік, темний тон шкіри і помірно світлий тон шкіри',
    '👨🏿‍❤‍👨🏽' => 'чоловік і жінка із серцем між ними: чоловік, чоловік, темний тон шкіри і помірний тон шкіри',
    '👨🏿‍❤‍👨🏾' => 'чоловік і жінка із серцем між ними: чоловік, чоловік, темний тон шкіри і помірно темний тон шкіри',
    '👨🏿‍❤‍👨🏿' => 'чоловік і жінка із серцем між ними: чоловік, чоловік і темний тон шкіри',
    '👨🏻‍🐰‍👨🏼' => 'чоловіки з кролячими вухами: світлий тон шкіри і помірно світлий тон шкіри',
    '👨🏻‍🐰‍👨🏽' => 'чоловіки з кролячими вухами: світлий тон шкіри і помірний тон шкіри',
    '👨🏻‍🐰‍👨🏾' => 'чоловіки з кролячими вухами: світлий тон шкіри і помірно темний тон шкіри',
    '👨🏻‍🐰‍👨🏿' => 'чоловіки з кролячими вухами: світлий тон шкіри і темний тон шкіри',
    '👨🏼‍🐰‍👨🏻' => 'чоловіки з кролячими вухами: помірно світлий тон шкіри і світлий тон шкіри',
    '👨🏼‍🐰‍👨🏽' => 'чоловіки з кролячими вухами: помірно світлий тон шкіри і помірний тон шкіри',
    '👨🏼‍🐰‍👨🏾' => 'чоловіки з кролячими вухами: помірно світлий тон шкіри і помірно темний тон шкіри',
    '👨🏼‍🐰‍👨🏿' => 'чоловіки з кролячими вухами: помірно світлий тон шкіри і темний тон шкіри',
    '👨🏽‍🐰‍👨🏻' => 'чоловіки з кролячими вухами: помірний тон шкіри і світлий тон шкіри',
    '👨🏽‍🐰‍👨🏼' => 'чоловіки з кролячими вухами: помірний тон шкіри і помірно світлий тон шкіри',
    '👨🏽‍🐰‍👨🏾' => 'чоловіки з кролячими вухами: помірний тон шкіри і помірно темний тон шкіри',
    '👨🏽‍🐰‍👨🏿' => 'чоловіки з кролячими вухами: помірний тон шкіри і темний тон шкіри',
    '👨🏾‍🐰‍👨🏻' => 'чоловіки з кролячими вухами: помірно темний тон шкіри і світлий тон шкіри',
    '👨🏾‍🐰‍👨🏼' => 'чоловіки з кролячими вухами: помірно темний тон шкіри і помірно світлий тон шкіри',
    '👨🏾‍🐰‍👨🏽' => 'чоловіки з кролячими вухами: помірно темний тон шкіри і помірний тон шкіри',
    '👨🏾‍🐰‍👨🏿' => 'чоловіки з кролячими вухами: помірно темний тон шкіри і темний тон шкіри',
    '👨🏿‍🐰‍👨🏻' => 'чоловіки з кролячими вухами: темний тон шкіри і світлий тон шкіри',
    '👨🏿‍🐰‍👨🏼' => 'чоловіки з кролячими вухами: темний тон шкіри і помірно світлий тон шкіри',
    '👨🏿‍🐰‍👨🏽' => 'чоловіки з кролячими вухами: темний тон шкіри і помірний тон шкіри',
    '👨🏿‍🐰‍👨🏾' => 'чоловіки з кролячими вухами: темний тон шкіри і помірно темний тон шкіри',
    '👩🏻‍🫯‍👩🏼' => 'борчиня: світлий тон шкіри і помірно світлий тон шкіри',
    '👩🏻‍🫯‍👩🏽' => 'борчиня: світлий тон шкіри і помірний тон шкіри',
    '👩🏻‍🫯‍👩🏾' => 'борчиня: світлий тон шкіри і помірно темний тон шкіри',
    '👩🏻‍🫯‍👩🏿' => 'борчиня: світлий тон шкіри і темний тон шкіри',
    '👩🏼‍🫯‍👩🏻' => 'борчиня: помірно світлий тон шкіри і світлий тон шкіри',
    '👩🏼‍🫯‍👩🏽' => 'борчиня: помірно світлий тон шкіри і помірний тон шкіри',
    '👩🏼‍🫯‍👩🏾' => 'борчиня: помірно світлий тон шкіри і помірно темний тон шкіри',
    '👩🏼‍🫯‍👩🏿' => 'борчиня: помірно світлий тон шкіри і темний тон шкіри',
    '👩🏽‍🫯‍👩🏻' => 'борчиня: помірний тон шкіри і світлий тон шкіри',
    '👩🏽‍🫯‍👩🏼' => 'борчиня: помірний тон шкіри і помірно світлий тон шкіри',
    '👩🏽‍🫯‍👩🏾' => 'борчиня: помірний тон шкіри і помірно темний тон шкіри',
    '👩🏽‍🫯‍👩🏿' => 'борчиня: помірний тон шкіри і темний тон шкіри',
    '👩🏾‍🫯‍👩🏻' => 'борчиня: помірно темний тон шкіри і світлий тон шкіри',
    '👩🏾‍🫯‍👩🏼' => 'борчиня: помірно темний тон шкіри і помірно світлий тон шкіри',
    '👩🏾‍🫯‍👩🏽' => 'борчиня: помірно темний тон шкіри і помірний тон шкіри',
    '👩🏾‍🫯‍👩🏿' => 'борчиня: помірно темний тон шкіри і темний тон шкіри',
    '👩🏿‍🫯‍👩🏻' => 'борчиня: темний тон шкіри і світлий тон шкіри',
    '👩🏿‍🫯‍👩🏼' => 'борчиня: темний тон шкіри і помірно світлий тон шкіри',
    '👩🏿‍🫯‍👩🏽' => 'борчиня: темний тон шкіри і помірний тон шкіри',
    '👩🏿‍🫯‍👩🏾' => 'борчиня: темний тон шкіри і помірно темний тон шкіри',
    '👩🏻‍❤‍👨🏻' => 'чоловік і жінка із серцем між ними: жінка, чоловік і світлий тон шкіри',
    '👩🏻‍❤‍👨🏼' => 'чоловік і жінка із серцем між ними: жінка, чоловік, світлий тон шкіри і помірно світлий тон шкіри',
    '👩🏻‍❤‍👨🏽' => 'чоловік і жінка із серцем між ними: жінка, чоловік, світлий тон шкіри і помірний тон шкіри',
    '👩🏻‍❤‍👨🏾' => 'чоловік і жінка із серцем між ними: жінка, чоловік, світлий тон шкіри і помірно темний тон шкіри',
    '👩🏻‍❤‍👨🏿' => 'чоловік і жінка із серцем між ними: жінка, чоловік, світлий тон шкіри і темний тон шкіри',
    '👩🏼‍❤‍👨🏻' => 'чоловік і жінка із серцем між ними: жінка, чоловік, помірно світлий тон шкіри і світлий тон шкіри',
    '👩🏼‍❤‍👨🏼' => 'чоловік і жінка із серцем між ними: жінка, чоловік і помірно світлий тон шкіри',
    '👩🏼‍❤‍👨🏽' => 'чоловік і жінка із серцем між ними: жінка, чоловік, помірно світлий тон шкіри і помірний тон шкіри',
    '👩🏼‍❤‍👨🏾' => 'чоловік і жінка із серцем між ними: жінка, чоловік, помірно світлий тон шкіри і помірно темний тон шкіри',
    '👩🏼‍❤‍👨🏿' => 'чоловік і жінка із серцем між ними: жінка, чоловік, помірно світлий тон шкіри і темний тон шкіри',
    '👩🏽‍❤‍👨🏻' => 'чоловік і жінка із серцем між ними: жінка, чоловік, помірний тон шкіри і світлий тон шкіри',
    '👩🏽‍❤‍👨🏼' => 'чоловік і жінка із серцем між ними: жінка, чоловік, помірний тон шкіри і помірно світлий тон шкіри',
    '👩🏽‍❤‍👨🏽' => 'чоловік і жінка із серцем між ними: жінка, чоловік і помірний тон шкіри',
    '👩🏽‍❤‍👨🏾' => 'чоловік і жінка із серцем між ними: жінка, чоловік, помірний тон шкіри і помірно темний тон шкіри',
    '👩🏽‍❤‍👨🏿' => 'чоловік і жінка із серцем між ними: жінка, чоловік, помірний тон шкіри і темний тон шкіри',
    '👩🏾‍❤‍👨🏻' => 'чоловік і жінка із серцем між ними: жінка, чоловік, помірно темний тон шкіри і світлий тон шкіри',
    '👩🏾‍❤‍👨🏼' => 'чоловік і жінка із серцем між ними: жінка, чоловік, помірно темний тон шкіри і помірно світлий тон шкіри',
    '👩🏾‍❤‍👨🏽' => 'чоловік і жінка із серцем між ними: жінка, чоловік, помірно темний тон шкіри і помірний тон шкіри',
    '👩🏾‍❤‍👨🏾' => 'чоловік і жінка із серцем між ними: жінка, чоловік і помірно темний тон шкіри',
    '👩🏾‍❤‍👨🏿' => 'чоловік і жінка із серцем між ними: жінка, чоловік, помірно темний тон шкіри і темний тон шкіри',
    '👩🏿‍❤‍👨🏻' => 'чоловік і жінка із серцем між ними: жінка, чоловік, темний тон шкіри і світлий тон шкіри',
    '👩🏿‍❤‍👨🏼' => 'чоловік і жінка із серцем між ними: жінка, чоловік, темний тон шкіри і помірно світлий тон шкіри',
    '👩🏿‍❤‍👨🏽' => 'чоловік і жінка із серцем між ними: жінка, чоловік, темний тон шкіри і помірний тон шкіри',
    '👩🏿‍❤‍👨🏾' => 'чоловік і жінка із серцем між ними: жінка, чоловік, темний тон шкіри і помірно темний тон шкіри',
    '👩🏿‍❤‍👨🏿' => 'чоловік і жінка із серцем між ними: жінка, чоловік і темний тон шкіри',
    '👩🏻‍❤‍👩🏻' => 'чоловік і жінка із серцем між ними: жінка, жінка і світлий тон шкіри',
    '👩🏻‍❤‍👩🏼' => 'чоловік і жінка із серцем між ними: жінка, жінка, світлий тон шкіри і помірно світлий тон шкіри',
    '👩🏻‍❤‍👩🏽' => 'чоловік і жінка із серцем між ними: жінка, жінка, світлий тон шкіри і помірний тон шкіри',
    '👩🏻‍❤‍👩🏾' => 'чоловік і жінка із серцем між ними: жінка, жінка, світлий тон шкіри і помірно темний тон шкіри',
    '👩🏻‍❤‍👩🏿' => 'чоловік і жінка із серцем між ними: жінка, жінка, світлий тон шкіри і темний тон шкіри',
    '👩🏼‍❤‍👩🏻' => 'чоловік і жінка із серцем між ними: жінка, жінка, помірно світлий тон шкіри і світлий тон шкіри',
    '👩🏼‍❤‍👩🏼' => 'чоловік і жінка із серцем між ними: жінка, жінка і помірно світлий тон шкіри',
    '👩🏼‍❤‍👩🏽' => 'чоловік і жінка із серцем між ними: жінка, жінка, помірно світлий тон шкіри і помірний тон шкіри',
    '👩🏼‍❤‍👩🏾' => 'чоловік і жінка із серцем між ними: жінка, жінка, помірно світлий тон шкіри і помірно темний тон шкіри',
    '👩🏼‍❤‍👩🏿' => 'чоловік і жінка із серцем між ними: жінка, жінка, помірно світлий тон шкіри і темний тон шкіри',
    '👩🏽‍❤‍👩🏻' => 'чоловік і жінка із серцем між ними: жінка, жінка, помірний тон шкіри і світлий тон шкіри',
    '👩🏽‍❤‍👩🏼' => 'чоловік і жінка із серцем між ними: жінка, жінка, помірний тон шкіри і помірно світлий тон шкіри',
    '👩🏽‍❤‍👩🏽' => 'чоловік і жінка із серцем між ними: жінка, жінка і помірний тон шкіри',
    '👩🏽‍❤‍👩🏾' => 'чоловік і жінка із серцем між ними: жінка, жінка, помірний тон шкіри і помірно темний тон шкіри',
    '👩🏽‍❤‍👩🏿' => 'чоловік і жінка із серцем між ними: жінка, жінка, помірний тон шкіри і темний тон шкіри',
    '👩🏾‍❤‍👩🏻' => 'чоловік і жінка із серцем між ними: жінка, жінка, помірно темний тон шкіри і світлий тон шкіри',
    '👩🏾‍❤‍👩🏼' => 'чоловік і жінка із серцем між ними: жінка, жінка, помірно темний тон шкіри і помірно світлий тон шкіри',
    '👩🏾‍❤‍👩🏽' => 'чоловік і жінка із серцем між ними: жінка, жінка, помірно темний тон шкіри і помірний тон шкіри',
    '👩🏾‍❤‍👩🏾' => 'чоловік і жінка із серцем між ними: жінка, жінка і помірно темний тон шкіри',
    '👩🏾‍❤‍👩🏿' => 'чоловік і жінка із серцем між ними: жінка, жінка, помірно темний тон шкіри і темний тон шкіри',
    '👩🏿‍❤‍👩🏻' => 'чоловік і жінка із серцем між ними: жінка, жінка, темний тон шкіри і світлий тон шкіри',
    '👩🏿‍❤‍👩🏼' => 'чоловік і жінка із серцем між ними: жінка, жінка, темний тон шкіри і помірно світлий тон шкіри',
    '👩🏿‍❤‍👩🏽' => 'чоловік і жінка із серцем між ними: жінка, жінка, темний тон шкіри і помірний тон шкіри',
    '👩🏿‍❤‍👩🏾' => 'чоловік і жінка із серцем між ними: жінка, жінка, темний тон шкіри і помірно темний тон шкіри',
    '👩🏿‍❤‍👩🏿' => 'чоловік і жінка із серцем між ними: жінка, жінка і темний тон шкіри',
    '👩🏻‍🐰‍👩🏼' => 'жінки з кролячими вухами: світлий тон шкіри і помірно світлий тон шкіри',
    '👩🏻‍🐰‍👩🏽' => 'жінки з кролячими вухами: світлий тон шкіри і помірний тон шкіри',
    '👩🏻‍🐰‍👩🏾' => 'жінки з кролячими вухами: світлий тон шкіри і помірно темний тон шкіри',
    '👩🏻‍🐰‍👩🏿' => 'жінки з кролячими вухами: світлий тон шкіри і темний тон шкіри',
    '👩🏼‍🐰‍👩🏻' => 'жінки з кролячими вухами: помірно світлий тон шкіри і світлий тон шкіри',
    '👩🏼‍🐰‍👩🏽' => 'жінки з кролячими вухами: помірно світлий тон шкіри і помірний тон шкіри',
    '👩🏼‍🐰‍👩🏾' => 'жінки з кролячими вухами: помірно світлий тон шкіри і помірно темний тон шкіри',
    '👩🏼‍🐰‍👩🏿' => 'жінки з кролячими вухами: помірно світлий тон шкіри і темний тон шкіри',
    '👩🏽‍🐰‍👩🏻' => 'жінки з кролячими вухами: помірний тон шкіри і світлий тон шкіри',
    '👩🏽‍🐰‍👩🏼' => 'жінки з кролячими вухами: помірний тон шкіри і помірно світлий тон шкіри',
    '👩🏽‍🐰‍👩🏾' => 'жінки з кролячими вухами: помірний тон шкіри і помірно темний тон шкіри',
    '👩🏽‍🐰‍👩🏿' => 'жінки з кролячими вухами: помірний тон шкіри і темний тон шкіри',
    '👩🏾‍🐰‍👩🏻' => 'жінки з кролячими вухами: помірно темний тон шкіри і світлий тон шкіри',
    '👩🏾‍🐰‍👩🏼' => 'жінки з кролячими вухами: помірно темний тон шкіри і помірно світлий тон шкіри',
    '👩🏾‍🐰‍👩🏽' => 'жінки з кролячими вухами: помірно темний тон шкіри і помірний тон шкіри',
    '👩🏾‍🐰‍👩🏿' => 'жінки з кролячими вухами: помірно темний тон шкіри і темний тон шкіри',
    '👩🏿‍🐰‍👩🏻' => 'жінки з кролячими вухами: темний тон шкіри і світлий тон шкіри',
    '👩🏿‍🐰‍👩🏼' => 'жінки з кролячими вухами: темний тон шкіри і помірно світлий тон шкіри',
    '👩🏿‍🐰‍👩🏽' => 'жінки з кролячими вухами: темний тон шкіри і помірний тон шкіри',
    '👩🏿‍🐰‍👩🏾' => 'жінки з кролячими вухами: темний тон шкіри і помірно темний тон шкіри',
    '🧑🏻‍🤝‍🧑🏻' => 'люди, що тримаються за руки: світлий тон шкіри',
    '🧑🏻‍🤝‍🧑🏼' => 'люди, що тримаються за руки: світлий тон шкіри і помірно світлий тон шкіри',
    '🧑🏻‍🤝‍🧑🏽' => 'люди, що тримаються за руки: світлий тон шкіри і помірний тон шкіри',
    '🧑🏻‍🤝‍🧑🏾' => 'люди, що тримаються за руки: світлий тон шкіри і помірно темний тон шкіри',
    '🧑🏻‍🤝‍🧑🏿' => 'люди, що тримаються за руки: світлий тон шкіри і темний тон шкіри',
    '🧑🏼‍🤝‍🧑🏻' => 'люди, що тримаються за руки: помірно світлий тон шкіри і світлий тон шкіри',
    '🧑🏼‍🤝‍🧑🏼' => 'люди, що тримаються за руки: помірно світлий тон шкіри',
    '🧑🏼‍🤝‍🧑🏽' => 'люди, що тримаються за руки: помірно світлий тон шкіри і помірний тон шкіри',
    '🧑🏼‍🤝‍🧑🏾' => 'люди, що тримаються за руки: помірно світлий тон шкіри і помірно темний тон шкіри',
    '🧑🏼‍🤝‍🧑🏿' => 'люди, що тримаються за руки: помірно світлий тон шкіри і темний тон шкіри',
    '🧑🏽‍🤝‍🧑🏻' => 'люди, що тримаються за руки: помірний тон шкіри і світлий тон шкіри',
    '🧑🏽‍🤝‍🧑🏼' => 'люди, що тримаються за руки: помірний тон шкіри і помірно світлий тон шкіри',
    '🧑🏽‍🤝‍🧑🏽' => 'люди, що тримаються за руки: помірний тон шкіри',
    '🧑🏽‍🤝‍🧑🏾' => 'люди, що тримаються за руки: помірний тон шкіри і помірно темний тон шкіри',
    '🧑🏽‍🤝‍🧑🏿' => 'люди, що тримаються за руки: помірний тон шкіри і темний тон шкіри',
    '🧑🏾‍🤝‍🧑🏻' => 'люди, що тримаються за руки: помірно темний тон шкіри і світлий тон шкіри',
    '🧑🏾‍🤝‍🧑🏼' => 'люди, що тримаються за руки: помірно темний тон шкіри і помірно світлий тон шкіри',
    '🧑🏾‍🤝‍🧑🏽' => 'люди, що тримаються за руки: помірно темний тон шкіри і помірний тон шкіри',
    '🧑🏾‍🤝‍🧑🏾' => 'люди, що тримаються за руки: помірно темний тон шкіри',
    '🧑🏾‍🤝‍🧑🏿' => 'люди, що тримаються за руки: помірно темний тон шкіри і темний тон шкіри',
    '🧑🏿‍🤝‍🧑🏻' => 'люди, що тримаються за руки: темний тон шкіри і світлий тон шкіри',
    '🧑🏿‍🤝‍🧑🏼' => 'люди, що тримаються за руки: темний тон шкіри і помірно світлий тон шкіри',
    '🧑🏿‍🤝‍🧑🏽' => 'люди, що тримаються за руки: темний тон шкіри і помірний тон шкіри',
    '🧑🏿‍🤝‍🧑🏾' => 'люди, що тримаються за руки: темний тон шкіри і помірно темний тон шкіри',
    '🧑🏿‍🤝‍🧑🏿' => 'люди, що тримаються за руки: темний тон шкіри',
    '👩🏻‍🤝‍👩🏼' => 'жінки, що тримаються за руки: світлий тон шкіри і помірно світлий тон шкіри',
    '👩🏻‍🤝‍👩🏽' => 'жінки, що тримаються за руки: світлий тон шкіри і помірний тон шкіри',
    '👩🏻‍🤝‍👩🏾' => 'жінки, що тримаються за руки: світлий тон шкіри і помірно темний тон шкіри',
    '👩🏻‍🤝‍👩🏿' => 'жінки, що тримаються за руки: світлий тон шкіри і темний тон шкіри',
    '👩🏼‍🤝‍👩🏻' => 'жінки, що тримаються за руки: помірно світлий тон шкіри і світлий тон шкіри',
    '👩🏼‍🤝‍👩🏽' => 'жінки, що тримаються за руки: помірно світлий тон шкіри і помірний тон шкіри',
    '👩🏼‍🤝‍👩🏾' => 'жінки, що тримаються за руки: помірно світлий тон шкіри і помірно темний тон шкіри',
    '👩🏼‍🤝‍👩🏿' => 'жінки, що тримаються за руки: помірно світлий тон шкіри і темний тон шкіри',
    '👩🏽‍🤝‍👩🏻' => 'жінки, що тримаються за руки: помірний тон шкіри і світлий тон шкіри',
    '👩🏽‍🤝‍👩🏼' => 'жінки, що тримаються за руки: помірний тон шкіри і помірно світлий тон шкіри',
    '👩🏽‍🤝‍👩🏾' => 'жінки, що тримаються за руки: помірний тон шкіри і помірно темний тон шкіри',
    '👩🏽‍🤝‍👩🏿' => 'жінки, що тримаються за руки: помірний тон шкіри і темний тон шкіри',
    '👩🏾‍🤝‍👩🏻' => 'жінки, що тримаються за руки: помірно темний тон шкіри і світлий тон шкіри',
    '👩🏾‍🤝‍👩🏼' => 'жінки, що тримаються за руки: помірно темний тон шкіри і помірно світлий тон шкіри',
    '👩🏾‍🤝‍👩🏽' => 'жінки, що тримаються за руки: помірно темний тон шкіри і помірний тон шкіри',
    '👩🏾‍🤝‍👩🏿' => 'жінки, що тримаються за руки: помірно темний тон шкіри і темний тон шкіри',
    '👩🏿‍🤝‍👩🏻' => 'жінки, що тримаються за руки: темний тон шкіри і світлий тон шкіри',
    '👩🏿‍🤝‍👩🏼' => 'жінки, що тримаються за руки: темний тон шкіри і помірно світлий тон шкіри',
    '👩🏿‍🤝‍👩🏽' => 'жінки, що тримаються за руки: темний тон шкіри і помірний тон шкіри',
    '👩🏿‍🤝‍👩🏾' => 'жінки, що тримаються за руки: темний тон шкіри і помірно темний тон шкіри',
    '👩🏻‍🤝‍👨🏼' => 'жінка й чоловік, що тримаються за руки: світлий тон шкіри і помірно світлий тон шкіри',
    '👩🏻‍🤝‍👨🏽' => 'жінка й чоловік, що тримаються за руки: світлий тон шкіри і помірний тон шкіри',
    '👩🏻‍🤝‍👨🏾' => 'жінка й чоловік, що тримаються за руки: світлий тон шкіри і помірно темний тон шкіри',
    '👩🏻‍🤝‍👨🏿' => 'жінка й чоловік, що тримаються за руки: світлий тон шкіри і темний тон шкіри',
    '👩🏼‍🤝‍👨🏻' => 'жінка й чоловік, що тримаються за руки: помірно світлий тон шкіри і світлий тон шкіри',
    '👩🏼‍🤝‍👨🏽' => 'жінка й чоловік, що тримаються за руки: помірно світлий тон шкіри і помірний тон шкіри',
    '👩🏼‍🤝‍👨🏾' => 'жінка й чоловік, що тримаються за руки: помірно світлий тон шкіри і помірно темний тон шкіри',
    '👩🏼‍🤝‍👨🏿' => 'жінка й чоловік, що тримаються за руки: помірно світлий тон шкіри і темний тон шкіри',
    '👩🏽‍🤝‍👨🏻' => 'жінка й чоловік, що тримаються за руки: помірний тон шкіри і світлий тон шкіри',
    '👩🏽‍🤝‍👨🏼' => 'жінка й чоловік, що тримаються за руки: помірний тон шкіри і помірно світлий тон шкіри',
    '👩🏽‍🤝‍👨🏾' => 'жінка й чоловік, що тримаються за руки: помірний тон шкіри і помірно темний тон шкіри',
    '👩🏽‍🤝‍👨🏿' => 'жінка й чоловік, що тримаються за руки: помірний тон шкіри і темний тон шкіри',
    '👩🏾‍🤝‍👨🏻' => 'жінка й чоловік, що тримаються за руки: помірно темний тон шкіри і світлий тон шкіри',
    '👩🏾‍🤝‍👨🏼' => 'жінка й чоловік, що тримаються за руки: помірно темний тон шкіри і помірно світлий тон шкіри',
    '👩🏾‍🤝‍👨🏽' => 'жінка й чоловік, що тримаються за руки: помірно темний тон шкіри і помірний тон шкіри',
    '👩🏾‍🤝‍👨🏿' => 'жінка й чоловік, що тримаються за руки: помірно темний тон шкіри і темний тон шкіри',
    '👩🏿‍🤝‍👨🏻' => 'жінка й чоловік, що тримаються за руки: темний тон шкіри і світлий тон шкіри',
    '👩🏿‍🤝‍👨🏼' => 'жінка й чоловік, що тримаються за руки: темний тон шкіри і помірно світлий тон шкіри',
    '👩🏿‍🤝‍👨🏽' => 'жінка й чоловік, що тримаються за руки: темний тон шкіри і помірний тон шкіри',
    '👩🏿‍🤝‍👨🏾' => 'жінка й чоловік, що тримаються за руки: темний тон шкіри і помірно темний тон шкіри',
    '👨🏻‍🤝‍👨🏼' => 'чоловіки, що тримаються за руки: світлий тон шкіри і помірно світлий тон шкіри',
    '👨🏻‍🤝‍👨🏽' => 'чоловіки, що тримаються за руки: світлий тон шкіри і помірний тон шкіри',
    '👨🏻‍🤝‍👨🏾' => 'чоловіки, що тримаються за руки: світлий тон шкіри і помірно темний тон шкіри',
    '👨🏻‍🤝‍👨🏿' => 'чоловіки, що тримаються за руки: світлий тон шкіри і темний тон шкіри',
    '👨🏼‍🤝‍👨🏻' => 'чоловіки, що тримаються за руки: помірно світлий тон шкіри і світлий тон шкіри',
    '👨🏼‍🤝‍👨🏽' => 'чоловіки, що тримаються за руки: помірно світлий тон шкіри і помірний тон шкіри',
    '👨🏼‍🤝‍👨🏾' => 'чоловіки, що тримаються за руки: помірно світлий тон шкіри і помірно темний тон шкіри',
    '👨🏼‍🤝‍👨🏿' => 'чоловіки, що тримаються за руки: помірно світлий тон шкіри і темний тон шкіри',
    '👨🏽‍🤝‍👨🏻' => 'чоловіки, що тримаються за руки: помірний тон шкіри і світлий тон шкіри',
    '👨🏽‍🤝‍👨🏼' => 'чоловіки, що тримаються за руки: помірний тон шкіри і помірно світлий тон шкіри',
    '👨🏽‍🤝‍👨🏾' => 'чоловіки, що тримаються за руки: помірний тон шкіри і помірно темний тон шкіри',
    '👨🏽‍🤝‍👨🏿' => 'чоловіки, що тримаються за руки: помірний тон шкіри і темний тон шкіри',
    '👨🏾‍🤝‍👨🏻' => 'чоловіки, що тримаються за руки: помірно темний тон шкіри і світлий тон шкіри',
    '👨🏾‍🤝‍👨🏼' => 'чоловіки, що тримаються за руки: помірно темний тон шкіри і помірно світлий тон шкіри',
    '👨🏾‍🤝‍👨🏽' => 'чоловіки, що тримаються за руки: помірно темний тон шкіри і помірний тон шкіри',
    '👨🏾‍🤝‍👨🏿' => 'чоловіки, що тримаються за руки: помірно темний тон шкіри і темний тон шкіри',
    '👨🏿‍🤝‍👨🏻' => 'чоловіки, що тримаються за руки: темний тон шкіри і світлий тон шкіри',
    '👨🏿‍🤝‍👨🏼' => 'чоловіки, що тримаються за руки: темний тон шкіри і помірно світлий тон шкіри',
    '👨🏿‍🤝‍👨🏽' => 'чоловіки, що тримаються за руки: темний тон шкіри і помірний тон шкіри',
    '👨🏿‍🤝‍👨🏾' => 'чоловіки, що тримаються за руки: темний тон шкіри і помірно темний тон шкіри',
    '👩‍❤‍💋‍👨' => 'чоловік і жінка, що цілуються: жінка і чоловік',
    '👨‍❤‍💋‍👨' => 'чоловік і жінка, що цілуються: чоловік і чоловік',
    '👩‍❤‍💋‍👩' => 'чоловік і жінка, що цілуються: жінка і жінка',
    '👨‍👩‍👧‍👦' => 'родина: чоловік, жінка, дівчинка і хлопчик',
    '👨‍👩‍👦‍👦' => 'родина: чоловік, жінка, хлопчик і хлопчик',
    '👨‍👩‍👧‍👧' => 'родина: чоловік, жінка, дівчинка і дівчинка',
    '👨‍👨‍👧‍👦' => 'родина: чоловік, чоловік, дівчинка і хлопчик',
    '👨‍👨‍👦‍👦' => 'родина: чоловік, чоловік, хлопчик і хлопчик',
    '👨‍👨‍👧‍👧' => 'родина: чоловік, чоловік, дівчинка і дівчинка',
    '👩‍👩‍👧‍👦' => 'родина: жінка, жінка, дівчинка і хлопчик',
    '👩‍👩‍👦‍👦' => 'родина: жінка, жінка, хлопчик і хлопчик',
    '👩‍👩‍👧‍👧' => 'родина: жінка, жінка, дівчинка і дівчинка',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'прапор: Англія',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'прапор: Шотландія',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'прапор: Уельс',
    '🧑‍🧑‍🧒‍🧒' => 'родина: двоє дорослих і двоє дітей',
    '🚶🏻‍♀‍➡' => 'жінка, що йде пішки: світлий тон шкіри і правий профіль:',
    '🚶🏼‍♀‍➡' => 'жінка, що йде пішки: помірно світлий тон шкіри і правий профіль:',
    '🚶🏽‍♀‍➡' => 'жінка, що йде пішки: помірний тон шкіри і правий профіль:',
    '🚶🏾‍♀‍➡' => 'жінка, що йде пішки: помірно темний тон шкіри і правий профіль:',
    '🚶🏿‍♀‍➡' => 'жінка, що йде пішки: темний тон шкіри і правий профіль:',
    '🚶🏻‍♂‍➡' => 'чоловік, що йде пішки: світлий тон шкіри і правий профіль:',
    '🚶🏼‍♂‍➡' => 'чоловік, що йде пішки: помірно світлий тон шкіри і правий профіль:',
    '🚶🏽‍♂‍➡' => 'чоловік, що йде пішки: помірний тон шкіри і правий профіль:',
    '🚶🏾‍♂‍➡' => 'чоловік, що йде пішки: помірно темний тон шкіри і правий профіль:',
    '🚶🏿‍♂‍➡' => 'чоловік, що йде пішки: темний тон шкіри і правий профіль:',
    '🧎🏻‍♀‍➡' => 'жінка навколішках: світлий тон шкіри і правий профіль:',
    '🧎🏼‍♀‍➡' => 'жінка навколішках: помірно світлий тон шкіри і правий профіль:',
    '🧎🏽‍♀‍➡' => 'жінка навколішках: помірний тон шкіри і правий профіль:',
    '🧎🏾‍♀‍➡' => 'жінка навколішках: помірно темний тон шкіри і правий профіль:',
    '🧎🏿‍♀‍➡' => 'жінка навколішках: темний тон шкіри і правий профіль:',
    '🧎🏻‍♂‍➡' => 'чоловік навколішках: світлий тон шкіри і правий профіль:',
    '🧎🏼‍♂‍➡' => 'чоловік навколішках: помірно світлий тон шкіри і правий профіль:',
    '🧎🏽‍♂‍➡' => 'чоловік навколішках: помірний тон шкіри і правий профіль:',
    '🧎🏾‍♂‍➡' => 'чоловік навколішках: помірно темний тон шкіри і правий профіль:',
    '🧎🏿‍♂‍➡' => 'чоловік навколішках: темний тон шкіри і правий профіль:',
    '🧑🏻‍🦯‍➡' => 'людина з тактильним ціпком: світлий тон шкіри і правий профіль:',
    '🧑🏼‍🦯‍➡' => 'людина з тактильним ціпком: помірно світлий тон шкіри і правий профіль:',
    '🧑🏽‍🦯‍➡' => 'людина з тактильним ціпком: помірний тон шкіри і правий профіль:',
    '🧑🏾‍🦯‍➡' => 'людина з тактильним ціпком: помірно темний тон шкіри і правий профіль:',
    '🧑🏿‍🦯‍➡' => 'людина з тактильним ціпком: темний тон шкіри і правий профіль:',
    '👨🏻‍🦯‍➡' => 'чоловік із тактильною тростиною: світлий тон шкіри і правий профіль:',
    '👨🏼‍🦯‍➡' => 'чоловік із тактильною тростиною: помірно світлий тон шкіри і правий профіль:',
    '👨🏽‍🦯‍➡' => 'чоловік із тактильною тростиною: помірний тон шкіри і правий профіль:',
    '👨🏾‍🦯‍➡' => 'чоловік із тактильною тростиною: помірно темний тон шкіри і правий профіль:',
    '👨🏿‍🦯‍➡' => 'чоловік із тактильною тростиною: темний тон шкіри і правий профіль:',
    '👩🏻‍🦯‍➡' => 'жінка з тактильною тростиною: світлий тон шкіри і правий профіль:',
    '👩🏼‍🦯‍➡' => 'жінка з тактильною тростиною: помірно світлий тон шкіри і правий профіль:',
    '👩🏽‍🦯‍➡' => 'жінка з тактильною тростиною: помірний тон шкіри і правий профіль:',
    '👩🏾‍🦯‍➡' => 'жінка з тактильною тростиною: помірно темний тон шкіри і правий профіль:',
    '👩🏿‍🦯‍➡' => 'жінка з тактильною тростиною: темний тон шкіри і правий профіль:',
    '🧑🏻‍🦼‍➡' => 'людина на моторизованому візку: світлий тон шкіри і правий профіль:',
    '🧑🏼‍🦼‍➡' => 'людина на моторизованому візку: помірно світлий тон шкіри і правий профіль:',
    '🧑🏽‍🦼‍➡' => 'людина на моторизованому візку: помірний тон шкіри і правий профіль:',
    '🧑🏾‍🦼‍➡' => 'людина на моторизованому візку: помірно темний тон шкіри і правий профіль:',
    '🧑🏿‍🦼‍➡' => 'людина на моторизованому візку: темний тон шкіри і правий профіль:',
    '👨🏻‍🦼‍➡' => 'чоловік у візку з електроприводом: світлий тон шкіри і правий профіль:',
    '👨🏼‍🦼‍➡' => 'чоловік у візку з електроприводом: помірно світлий тон шкіри і правий профіль:',
    '👨🏽‍🦼‍➡' => 'чоловік у візку з електроприводом: помірний тон шкіри і правий профіль:',
    '👨🏾‍🦼‍➡' => 'чоловік у візку з електроприводом: помірно темний тон шкіри і правий профіль:',
    '👨🏿‍🦼‍➡' => 'чоловік у візку з електроприводом: темний тон шкіри і правий профіль:',
    '👩🏻‍🦼‍➡' => 'жінка у візку з електроприводом: світлий тон шкіри і правий профіль:',
    '👩🏼‍🦼‍➡' => 'жінка у візку з електроприводом: помірно світлий тон шкіри і правий профіль:',
    '👩🏽‍🦼‍➡' => 'жінка у візку з електроприводом: помірний тон шкіри і правий профіль:',
    '👩🏾‍🦼‍➡' => 'жінка у візку з електроприводом: помірно темний тон шкіри і правий профіль:',
    '👩🏿‍🦼‍➡' => 'жінка у візку з електроприводом: темний тон шкіри і правий профіль:',
    '🧑🏻‍🦽‍➡' => 'людина у візку з ручним керуванням: світлий тон шкіри і правий профіль:',
    '🧑🏼‍🦽‍➡' => 'людина у візку з ручним керуванням: помірно світлий тон шкіри і правий профіль:',
    '🧑🏽‍🦽‍➡' => 'людина у візку з ручним керуванням: помірний тон шкіри і правий профіль:',
    '🧑🏾‍🦽‍➡' => 'людина у візку з ручним керуванням: помірно темний тон шкіри і правий профіль:',
    '🧑🏿‍🦽‍➡' => 'людина у візку з ручним керуванням: темний тон шкіри і правий профіль:',
    '👨🏻‍🦽‍➡' => 'чоловік у візку з ручним приводом: світлий тон шкіри і правий профіль:',
    '👨🏼‍🦽‍➡' => 'чоловік у візку з ручним приводом: помірно світлий тон шкіри і правий профіль:',
    '👨🏽‍🦽‍➡' => 'чоловік у візку з ручним приводом: помірний тон шкіри і правий профіль:',
    '👨🏾‍🦽‍➡' => 'чоловік у візку з ручним приводом: помірно темний тон шкіри і правий профіль:',
    '👨🏿‍🦽‍➡' => 'чоловік у візку з ручним приводом: темний тон шкіри і правий профіль:',
    '👩🏻‍🦽‍➡' => 'жінка у візку з ручним приводом: світлий тон шкіри і правий профіль:',
    '👩🏼‍🦽‍➡' => 'жінка у візку з ручним приводом: помірно світлий тон шкіри і правий профіль:',
    '👩🏽‍🦽‍➡' => 'жінка у візку з ручним приводом: помірний тон шкіри і правий профіль:',
    '👩🏾‍🦽‍➡' => 'жінка у візку з ручним приводом: помірно темний тон шкіри і правий профіль:',
    '👩🏿‍🦽‍➡' => 'жінка у візку з ручним приводом: темний тон шкіри і правий профіль:',
    '🏃🏻‍♀‍➡' => 'жінка, що біжить: світлий тон шкіри і правий профіль:',
    '🏃🏼‍♀‍➡' => 'жінка, що біжить: помірно світлий тон шкіри і правий профіль:',
    '🏃🏽‍♀‍➡' => 'жінка, що біжить: помірний тон шкіри і правий профіль:',
    '🏃🏾‍♀‍➡' => 'жінка, що біжить: помірно темний тон шкіри і правий профіль:',
    '🏃🏿‍♀‍➡' => 'жінка, що біжить: темний тон шкіри і правий профіль:',
    '🏃🏻‍♂‍➡' => 'чоловік, що біжить: світлий тон шкіри і правий профіль:',
    '🏃🏼‍♂‍➡' => 'чоловік, що біжить: помірно світлий тон шкіри і правий профіль:',
    '🏃🏽‍♂‍➡' => 'чоловік, що біжить: помірний тон шкіри і правий профіль:',
    '🏃🏾‍♂‍➡' => 'чоловік, що біжить: помірно темний тон шкіри і правий профіль:',
    '🏃🏿‍♂‍➡' => 'чоловік, що біжить: темний тон шкіри і правий профіль:',
    '🫱🏻‍🫲🏼' => 'рукостискання: світлий тон шкіри і помірно світлий тон шкіри',
    '🫱🏻‍🫲🏽' => 'рукостискання: світлий тон шкіри і помірний тон шкіри',
    '🫱🏻‍🫲🏾' => 'рукостискання: світлий тон шкіри і помірно темний тон шкіри',
    '🫱🏻‍🫲🏿' => 'рукостискання: світлий тон шкіри і темний тон шкіри',
    '🫱🏼‍🫲🏻' => 'рукостискання: помірно світлий тон шкіри і світлий тон шкіри',
    '🫱🏼‍🫲🏽' => 'рукостискання: помірно світлий тон шкіри і помірний тон шкіри',
    '🫱🏼‍🫲🏾' => 'рукостискання: помірно світлий тон шкіри і помірно темний тон шкіри',
    '🫱🏼‍🫲🏿' => 'рукостискання: помірно світлий тон шкіри і темний тон шкіри',
    '🫱🏽‍🫲🏻' => 'рукостискання: помірний тон шкіри і світлий тон шкіри',
    '🫱🏽‍🫲🏼' => 'рукостискання: помірний тон шкіри і помірно світлий тон шкіри',
    '🫱🏽‍🫲🏾' => 'рукостискання: помірний тон шкіри і помірно темний тон шкіри',
    '🫱🏽‍🫲🏿' => 'рукостискання: помірний тон шкіри і темний тон шкіри',
    '🫱🏾‍🫲🏻' => 'рукостискання: помірно темний тон шкіри і світлий тон шкіри',
    '🫱🏾‍🫲🏼' => 'рукостискання: помірно темний тон шкіри і помірно світлий тон шкіри',
    '🫱🏾‍🫲🏽' => 'рукостискання: помірно темний тон шкіри і помірний тон шкіри',
    '🫱🏾‍🫲🏿' => 'рукостискання: помірно темний тон шкіри і темний тон шкіри',
    '🫱🏿‍🫲🏻' => 'рукостискання: темний тон шкіри і світлий тон шкіри',
    '🫱🏿‍🫲🏼' => 'рукостискання: темний тон шкіри і помірно світлий тон шкіри',
    '🫱🏿‍🫲🏽' => 'рукостискання: темний тон шкіри і помірний тон шкіри',
    '🫱🏿‍🫲🏾' => 'рукостискання: темний тон шкіри і помірно темний тон шкіри',
    '🚶‍♀‍➡' => 'жінка, що йде пішки: правий профіль:',
    '🚶‍♂‍➡' => 'чоловік, що йде пішки: правий профіль:',
    '🧎‍♀‍➡' => 'жінка навколішках: правий профіль:',
    '🧎‍♂‍➡' => 'чоловік навколішках: правий профіль:',
    '🧑‍🦯‍➡' => 'людина з тактильним ціпком: правий профіль:',
    '👨‍🦯‍➡' => 'чоловік із тактильною тростиною: правий профіль:',
    '👩‍🦯‍➡' => 'жінка з тактильною тростиною: правий профіль:',
    '🧑‍🦼‍➡' => 'людина на моторизованому візку: правий профіль:',
    '👨‍🦼‍➡' => 'чоловік у візку з електроприводом: правий профіль:',
    '👩‍🦼‍➡' => 'жінка у візку з електроприводом: правий профіль:',
    '🧑‍🦽‍➡' => 'людина у візку з ручним керуванням: правий профіль:',
    '👨‍🦽‍➡' => 'чоловік у візку з ручним приводом: правий профіль:',
    '👩‍🦽‍➡' => 'жінка у візку з ручним приводом: правий профіль:',
    '🏃‍♀‍➡' => 'жінка, що біжить: правий профіль:',
    '🏃‍♂‍➡' => 'чоловік, що біжить: правий профіль:',
    '👩‍❤‍👨' => 'чоловік і жінка із серцем між ними: жінка і чоловік',
    '👨‍❤‍👨' => 'чоловік і жінка із серцем між ними: чоловік і чоловік',
    '👩‍❤‍👩' => 'чоловік і жінка із серцем між ними: жінка і жінка',
    '👨‍👩‍👦' => 'родина: чоловік, жінка і хлопчик',
    '👨‍👩‍👧' => 'родина: чоловік, жінка і дівчинка',
    '👨‍👨‍👦' => 'родина: чоловік, чоловік і хлопчик',
    '👨‍👨‍👧' => 'родина: чоловік, чоловік і дівчинка',
    '👩‍👩‍👦' => 'родина: жінка, жінка і хлопчик',
    '👩‍👩‍👧' => 'родина: жінка, жінка і дівчинка',
    '👨‍👦‍👦' => 'родина: чоловік, хлопчик і хлопчик',
    '👨‍👧‍👦' => 'родина: чоловік, дівчинка і хлопчик',
    '👨‍👧‍👧' => 'родина: чоловік, дівчинка і дівчинка',
    '👩‍👦‍👦' => 'родина: жінка, хлопчик і хлопчик',
    '👩‍👧‍👦' => 'родина: жінка, дівчинка і хлопчик',
    '👩‍👧‍👧' => 'родина: жінка, дівчинка і дівчинка',
    '🧑‍🤝‍🧑' => 'люди, що тримаються за руки',
    '🧑‍🧑‍🧒' => 'родина: дорослий, дорослий, дитина',
    '🧑‍🧒‍🧒' => 'родина: дорослий і діти',
    '🧑🏻‍🦰' => 'людина: світлий тон шкіри і руде волосся',
    '🧑🏼‍🦰' => 'людина: помірно світлий тон шкіри і руде волосся',
    '🧑🏽‍🦰' => 'людина: помірний тон шкіри і руде волосся',
    '🧑🏾‍🦰' => 'людина: помірно темний тон шкіри і руде волосся',
    '🧑🏿‍🦰' => 'людина: темний тон шкіри і руде волосся',
    '🧑🏻‍🦱' => 'людина: світлий тон шкіри і кучеряве волосся',
    '🧑🏼‍🦱' => 'людина: помірно світлий тон шкіри і кучеряве волосся',
    '🧑🏽‍🦱' => 'людина: помірний тон шкіри і кучеряве волосся',
    '🧑🏾‍🦱' => 'людина: помірно темний тон шкіри і кучеряве волосся',
    '🧑🏿‍🦱' => 'людина: темний тон шкіри і кучеряве волосся',
    '🧑🏻‍🦳' => 'людина: світлий тон шкіри і сиве волосся',
    '🧑🏼‍🦳' => 'людина: помірно світлий тон шкіри і сиве волосся',
    '🧑🏽‍🦳' => 'людина: помірний тон шкіри і сиве волосся',
    '🧑🏾‍🦳' => 'людина: помірно темний тон шкіри і сиве волосся',
    '🧑🏿‍🦳' => 'людина: темний тон шкіри і сиве волосся',
    '🧑🏻‍🦲' => 'людина: світлий тон шкіри і лисина',
    '🧑🏼‍🦲' => 'людина: помірно світлий тон шкіри і лисина',
    '🧑🏽‍🦲' => 'людина: помірний тон шкіри і лисина',
    '🧑🏾‍🦲' => 'людина: помірно темний тон шкіри і лисина',
    '🧑🏿‍🦲' => 'людина: темний тон шкіри і лисина',
    '🧑🏻‍🩰' => 'танцівник балету: світлий тон шкіри',
    '🧑🏼‍🩰' => 'танцівник балету: помірно світлий тон шкіри',
    '🧑🏽‍🩰' => 'танцівник балету: помірний тон шкіри',
    '🧑🏾‍🩰' => 'танцівник балету: помірно темний тон шкіри',
    '🧑🏿‍🩰' => 'танцівник балету: темний тон шкіри',
    '🧔🏻‍♂' => 'чоловік із бородою: світлий тон шкіри',
    '🧔🏼‍♂' => 'чоловік із бородою: помірно світлий тон шкіри',
    '🧔🏽‍♂' => 'чоловік із бородою: помірний тон шкіри',
    '🧔🏾‍♂' => 'чоловік із бородою: помірно темний тон шкіри',
    '🧔🏿‍♂' => 'чоловік із бородою: темний тон шкіри',
    '👱🏻‍♂' => 'чоловік із білявим волоссям: світлий тон шкіри',
    '👱🏼‍♂' => 'чоловік із білявим волоссям: помірно світлий тон шкіри',
    '👱🏽‍♂' => 'чоловік із білявим волоссям: помірний тон шкіри',
    '👱🏾‍♂' => 'чоловік із білявим волоссям: помірно темний тон шкіри',
    '👱🏿‍♂' => 'чоловік із білявим волоссям: темний тон шкіри',
    '👨🏻‍🦰' => 'чоловік: світлий тон шкіри і руде волосся',
    '👨🏼‍🦰' => 'чоловік: помірно світлий тон шкіри і руде волосся',
    '👨🏽‍🦰' => 'чоловік: помірний тон шкіри і руде волосся',
    '👨🏾‍🦰' => 'чоловік: помірно темний тон шкіри і руде волосся',
    '👨🏿‍🦰' => 'чоловік: темний тон шкіри і руде волосся',
    '👨🏻‍🦱' => 'чоловік: світлий тон шкіри і кучеряве волосся',
    '👨🏼‍🦱' => 'чоловік: помірно світлий тон шкіри і кучеряве волосся',
    '👨🏽‍🦱' => 'чоловік: помірний тон шкіри і кучеряве волосся',
    '👨🏾‍🦱' => 'чоловік: помірно темний тон шкіри і кучеряве волосся',
    '👨🏿‍🦱' => 'чоловік: темний тон шкіри і кучеряве волосся',
    '👨🏻‍🦳' => 'чоловік: світлий тон шкіри і сиве волосся',
    '👨🏼‍🦳' => 'чоловік: помірно світлий тон шкіри і сиве волосся',
    '👨🏽‍🦳' => 'чоловік: помірний тон шкіри і сиве волосся',
    '👨🏾‍🦳' => 'чоловік: помірно темний тон шкіри і сиве волосся',
    '👨🏿‍🦳' => 'чоловік: темний тон шкіри і сиве волосся',
    '👨🏻‍🦲' => 'чоловік: світлий тон шкіри і лисина',
    '👨🏼‍🦲' => 'чоловік: помірно світлий тон шкіри і лисина',
    '👨🏽‍🦲' => 'чоловік: помірний тон шкіри і лисина',
    '👨🏾‍🦲' => 'чоловік: помірно темний тон шкіри і лисина',
    '👨🏿‍🦲' => 'чоловік: темний тон шкіри і лисина',
    '🧔🏻‍♀' => 'жінка з бородою: світлий тон шкіри',
    '🧔🏼‍♀' => 'жінка з бородою: помірно світлий тон шкіри',
    '🧔🏽‍♀' => 'жінка з бородою: помірний тон шкіри',
    '🧔🏾‍♀' => 'жінка з бородою: помірно темний тон шкіри',
    '🧔🏿‍♀' => 'жінка з бородою: темний тон шкіри',
    '👱🏻‍♀' => 'жінка з білявим волоссям: світлий тон шкіри',
    '👱🏼‍♀' => 'жінка з білявим волоссям: помірно світлий тон шкіри',
    '👱🏽‍♀' => 'жінка з білявим волоссям: помірний тон шкіри',
    '👱🏾‍♀' => 'жінка з білявим волоссям: помірно темний тон шкіри',
    '👱🏿‍♀' => 'жінка з білявим волоссям: темний тон шкіри',
    '👩🏻‍🦰' => 'жінка: світлий тон шкіри і руде волосся',
    '👩🏼‍🦰' => 'жінка: помірно світлий тон шкіри і руде волосся',
    '👩🏽‍🦰' => 'жінка: помірний тон шкіри і руде волосся',
    '👩🏾‍🦰' => 'жінка: помірно темний тон шкіри і руде волосся',
    '👩🏿‍🦰' => 'жінка: темний тон шкіри і руде волосся',
    '👩🏻‍🦱' => 'жінка: світлий тон шкіри і кучеряве волосся',
    '👩🏼‍🦱' => 'жінка: помірно світлий тон шкіри і кучеряве волосся',
    '👩🏽‍🦱' => 'жінка: помірний тон шкіри і кучеряве волосся',
    '👩🏾‍🦱' => 'жінка: помірно темний тон шкіри і кучеряве волосся',
    '👩🏿‍🦱' => 'жінка: темний тон шкіри і кучеряве волосся',
    '👩🏻‍🦳' => 'жінка: світлий тон шкіри і сиве волосся',
    '👩🏼‍🦳' => 'жінка: помірно світлий тон шкіри і сиве волосся',
    '👩🏽‍🦳' => 'жінка: помірний тон шкіри і сиве волосся',
    '👩🏾‍🦳' => 'жінка: помірно темний тон шкіри і сиве волосся',
    '👩🏿‍🦳' => 'жінка: темний тон шкіри і сиве волосся',
    '👩🏻‍🦲' => 'жінка: світлий тон шкіри і лисина',
    '👩🏼‍🦲' => 'жінка: помірно світлий тон шкіри і лисина',
    '👩🏽‍🦲' => 'жінка: помірний тон шкіри і лисина',
    '👩🏾‍🦲' => 'жінка: помірно темний тон шкіри і лисина',
    '👩🏿‍🦲' => 'жінка: темний тон шкіри і лисина',
    '🙍🏻‍♂' => 'похмурий чоловік: світлий тон шкіри',
    '🙍🏼‍♂' => 'похмурий чоловік: помірно світлий тон шкіри',
    '🙍🏽‍♂' => 'похмурий чоловік: помірний тон шкіри',
    '🙍🏾‍♂' => 'похмурий чоловік: помірно темний тон шкіри',
    '🙍🏿‍♂' => 'похмурий чоловік: темний тон шкіри',
    '🙍🏻‍♀' => 'похмура жінка: світлий тон шкіри',
    '🙍🏼‍♀' => 'похмура жінка: помірно світлий тон шкіри',
    '🙍🏽‍♀' => 'похмура жінка: помірний тон шкіри',
    '🙍🏾‍♀' => 'похмура жінка: помірно темний тон шкіри',
    '🙍🏿‍♀' => 'похмура жінка: темний тон шкіри',
    '🙎🏻‍♂' => 'чоловік, що дується: світлий тон шкіри',
    '🙎🏼‍♂' => 'чоловік, що дується: помірно світлий тон шкіри',
    '🙎🏽‍♂' => 'чоловік, що дується: помірний тон шкіри',
    '🙎🏾‍♂' => 'чоловік, що дується: помірно темний тон шкіри',
    '🙎🏿‍♂' => 'чоловік, що дується: темний тон шкіри',
    '🙎🏻‍♀' => 'жінка, що дується: світлий тон шкіри',
    '🙎🏼‍♀' => 'жінка, що дується: помірно світлий тон шкіри',
    '🙎🏽‍♀' => 'жінка, що дується: помірний тон шкіри',
    '🙎🏾‍♀' => 'жінка, що дується: помірно темний тон шкіри',
    '🙎🏿‍♀' => 'жінка, що дується: темний тон шкіри',
    '🙅🏻‍♂' => 'чоловік, що жестом показує «ні»: світлий тон шкіри',
    '🙅🏼‍♂' => 'чоловік, що жестом показує «ні»: помірно світлий тон шкіри',
    '🙅🏽‍♂' => 'чоловік, що жестом показує «ні»: помірний тон шкіри',
    '🙅🏾‍♂' => 'чоловік, що жестом показує «ні»: помірно темний тон шкіри',
    '🙅🏿‍♂' => 'чоловік, що жестом показує «ні»: темний тон шкіри',
    '🙅🏻‍♀' => 'жінка, що жестом показує «ні»: світлий тон шкіри',
    '🙅🏼‍♀' => 'жінка, що жестом показує «ні»: помірно світлий тон шкіри',
    '🙅🏽‍♀' => 'жінка, що жестом показує «ні»: помірний тон шкіри',
    '🙅🏾‍♀' => 'жінка, що жестом показує «ні»: помірно темний тон шкіри',
    '🙅🏿‍♀' => 'жінка, що жестом показує «ні»: темний тон шкіри',
    '🙆🏻‍♂' => 'чоловік, що жестом показує «окей»: світлий тон шкіри',
    '🙆🏼‍♂' => 'чоловік, що жестом показує «окей»: помірно світлий тон шкіри',
    '🙆🏽‍♂' => 'чоловік, що жестом показує «окей»: помірний тон шкіри',
    '🙆🏾‍♂' => 'чоловік, що жестом показує «окей»: помірно темний тон шкіри',
    '🙆🏿‍♂' => 'чоловік, що жестом показує «окей»: темний тон шкіри',
    '🙆🏻‍♀' => 'жінка, що жестом показує «окей»: світлий тон шкіри',
    '🙆🏼‍♀' => 'жінка, що жестом показує «окей»: помірно світлий тон шкіри',
    '🙆🏽‍♀' => 'жінка, що жестом показує «окей»: помірний тон шкіри',
    '🙆🏾‍♀' => 'жінка, що жестом показує «окей»: помірно темний тон шкіри',
    '🙆🏿‍♀' => 'жінка, що жестом показує «окей»: темний тон шкіри',
    '💁🏻‍♂' => 'чоловік, що простягає руку допомоги: світлий тон шкіри',
    '💁🏼‍♂' => 'чоловік, що простягає руку допомоги: помірно світлий тон шкіри',
    '💁🏽‍♂' => 'чоловік, що простягає руку допомоги: помірний тон шкіри',
    '💁🏾‍♂' => 'чоловік, що простягає руку допомоги: помірно темний тон шкіри',
    '💁🏿‍♂' => 'чоловік, що простягає руку допомоги: темний тон шкіри',
    '💁🏻‍♀' => 'жінка, що простягає руку допомоги: світлий тон шкіри',
    '💁🏼‍♀' => 'жінка, що простягає руку допомоги: помірно світлий тон шкіри',
    '💁🏽‍♀' => 'жінка, що простягає руку допомоги: помірний тон шкіри',
    '💁🏾‍♀' => 'жінка, що простягає руку допомоги: помірно темний тон шкіри',
    '💁🏿‍♀' => 'жінка, що простягає руку допомоги: темний тон шкіри',
    '🙋🏻‍♂' => 'чоловік із піднятою рукою: світлий тон шкіри',
    '🙋🏼‍♂' => 'чоловік із піднятою рукою: помірно світлий тон шкіри',
    '🙋🏽‍♂' => 'чоловік із піднятою рукою: помірний тон шкіри',
    '🙋🏾‍♂' => 'чоловік із піднятою рукою: помірно темний тон шкіри',
    '🙋🏿‍♂' => 'чоловік із піднятою рукою: темний тон шкіри',
    '🙋🏻‍♀' => 'жінка з піднятою рукою: світлий тон шкіри',
    '🙋🏼‍♀' => 'жінка з піднятою рукою: помірно світлий тон шкіри',
    '🙋🏽‍♀' => 'жінка з піднятою рукою: помірний тон шкіри',
    '🙋🏾‍♀' => 'жінка з піднятою рукою: помірно темний тон шкіри',
    '🙋🏿‍♀' => 'жінка з піднятою рукою: темний тон шкіри',
    '🧏🏻‍♂' => 'чоловік із порушенням слуху: світлий тон шкіри',
    '🧏🏼‍♂' => 'чоловік із порушенням слуху: помірно світлий тон шкіри',
    '🧏🏽‍♂' => 'чоловік із порушенням слуху: помірний тон шкіри',
    '🧏🏾‍♂' => 'чоловік із порушенням слуху: помірно темний тон шкіри',
    '🧏🏿‍♂' => 'чоловік із порушенням слуху: темний тон шкіри',
    '🧏🏻‍♀' => 'жінка з порушенням слуху: світлий тон шкіри',
    '🧏🏼‍♀' => 'жінка з порушенням слуху: помірно світлий тон шкіри',
    '🧏🏽‍♀' => 'жінка з порушенням слуху: помірний тон шкіри',
    '🧏🏾‍♀' => 'жінка з порушенням слуху: помірно темний тон шкіри',
    '🧏🏿‍♀' => 'жінка з порушенням слуху: темний тон шкіри',
    '🙇🏻‍♂' => 'чоловік, що вклоняється: світлий тон шкіри',
    '🙇🏼‍♂' => 'чоловік, що вклоняється: помірно світлий тон шкіри',
    '🙇🏽‍♂' => 'чоловік, що вклоняється: помірний тон шкіри',
    '🙇🏾‍♂' => 'чоловік, що вклоняється: помірно темний тон шкіри',
    '🙇🏿‍♂' => 'чоловік, що вклоняється: темний тон шкіри',
    '🙇🏻‍♀' => 'жінка, що вклоняється: світлий тон шкіри',
    '🙇🏼‍♀' => 'жінка, що вклоняється: помірно світлий тон шкіри',
    '🙇🏽‍♀' => 'жінка, що вклоняється: помірний тон шкіри',
    '🙇🏾‍♀' => 'жінка, що вклоняється: помірно темний тон шкіри',
    '🙇🏿‍♀' => 'жінка, що вклоняється: темний тон шкіри',
    '🤦🏻‍♂' => 'чоловік із долонею до обличчя: світлий тон шкіри',
    '🤦🏼‍♂' => 'чоловік із долонею до обличчя: помірно світлий тон шкіри',
    '🤦🏽‍♂' => 'чоловік із долонею до обличчя: помірний тон шкіри',
    '🤦🏾‍♂' => 'чоловік із долонею до обличчя: помірно темний тон шкіри',
    '🤦🏿‍♂' => 'чоловік із долонею до обличчя: темний тон шкіри',
    '🤦🏻‍♀' => 'жінка, що підносить долоню до обличчя: світлий тон шкіри',
    '🤦🏼‍♀' => 'жінка, що підносить долоню до обличчя: помірно світлий тон шкіри',
    '🤦🏽‍♀' => 'жінка, що підносить долоню до обличчя: помірний тон шкіри',
    '🤦🏾‍♀' => 'жінка, що підносить долоню до обличчя: помірно темний тон шкіри',
    '🤦🏿‍♀' => 'жінка, що підносить долоню до обличчя: темний тон шкіри',
    '🤷🏻‍♂' => 'чоловік, що знизує плечима: світлий тон шкіри',
    '🤷🏼‍♂' => 'чоловік, що знизує плечима: помірно світлий тон шкіри',
    '🤷🏽‍♂' => 'чоловік, що знизує плечима: помірний тон шкіри',
    '🤷🏾‍♂' => 'чоловік, що знизує плечима: помірно темний тон шкіри',
    '🤷🏿‍♂' => 'чоловік, що знизує плечима: темний тон шкіри',
    '🤷🏻‍♀' => 'жінка, що знизує плечима: світлий тон шкіри',
    '🤷🏼‍♀' => 'жінка, що знизує плечима: помірно світлий тон шкіри',
    '🤷🏽‍♀' => 'жінка, що знизує плечима: помірний тон шкіри',
    '🤷🏾‍♀' => 'жінка, що знизує плечима: помірно темний тон шкіри',
    '🤷🏿‍♀' => 'жінка, що знизує плечима: темний тон шкіри',
    '🧑🏻‍⚕' => 'медик: світлий тон шкіри',
    '🧑🏼‍⚕' => 'медик: помірно світлий тон шкіри',
    '🧑🏽‍⚕' => 'медик: помірний тон шкіри',
    '🧑🏾‍⚕' => 'медик: помірно темний тон шкіри',
    '🧑🏿‍⚕' => 'медик: темний тон шкіри',
    '👨🏻‍⚕' => 'медичний працівник: світлий тон шкіри',
    '👨🏼‍⚕' => 'медичний працівник: помірно світлий тон шкіри',
    '👨🏽‍⚕' => 'медичний працівник: помірний тон шкіри',
    '👨🏾‍⚕' => 'медичний працівник: помірно темний тон шкіри',
    '👨🏿‍⚕' => 'медичний працівник: темний тон шкіри',
    '👩🏻‍⚕' => 'медична працівниця: світлий тон шкіри',
    '👩🏼‍⚕' => 'медична працівниця: помірно світлий тон шкіри',
    '👩🏽‍⚕' => 'медична працівниця: помірний тон шкіри',
    '👩🏾‍⚕' => 'медична працівниця: помірно темний тон шкіри',
    '👩🏿‍⚕' => 'медична працівниця: темний тон шкіри',
    '🧑🏻‍🎓' => 'слухач: світлий тон шкіри',
    '🧑🏼‍🎓' => 'слухач: помірно світлий тон шкіри',
    '🧑🏽‍🎓' => 'слухач: помірний тон шкіри',
    '🧑🏾‍🎓' => 'слухач: помірно темний тон шкіри',
    '🧑🏿‍🎓' => 'слухач: темний тон шкіри',
    '👨🏻‍🎓' => 'студент: світлий тон шкіри',
    '👨🏼‍🎓' => 'студент: помірно світлий тон шкіри',
    '👨🏽‍🎓' => 'студент: помірний тон шкіри',
    '👨🏾‍🎓' => 'студент: помірно темний тон шкіри',
    '👨🏿‍🎓' => 'студент: темний тон шкіри',
    '👩🏻‍🎓' => 'студентка: світлий тон шкіри',
    '👩🏼‍🎓' => 'студентка: помірно світлий тон шкіри',
    '👩🏽‍🎓' => 'студентка: помірний тон шкіри',
    '👩🏾‍🎓' => 'студентка: помірно темний тон шкіри',
    '👩🏿‍🎓' => 'студентка: темний тон шкіри',
    '🧑🏻‍🏫' => 'освітянин: світлий тон шкіри',
    '🧑🏼‍🏫' => 'освітянин: помірно світлий тон шкіри',
    '🧑🏽‍🏫' => 'освітянин: помірний тон шкіри',
    '🧑🏾‍🏫' => 'освітянин: помірно темний тон шкіри',
    '🧑🏿‍🏫' => 'освітянин: темний тон шкіри',
    '👨🏻‍🏫' => 'учитель: світлий тон шкіри',
    '👨🏼‍🏫' => 'учитель: помірно світлий тон шкіри',
    '👨🏽‍🏫' => 'учитель: помірний тон шкіри',
    '👨🏾‍🏫' => 'учитель: помірно темний тон шкіри',
    '👨🏿‍🏫' => 'учитель: темний тон шкіри',
    '👩🏻‍🏫' => 'учителька: світлий тон шкіри',
    '👩🏼‍🏫' => 'учителька: помірно світлий тон шкіри',
    '👩🏽‍🏫' => 'учителька: помірний тон шкіри',
    '👩🏾‍🏫' => 'учителька: помірно темний тон шкіри',
    '👩🏿‍🏫' => 'учителька: темний тон шкіри',
    '🧑🏻‍⚖' => 'суддя: світлий тон шкіри',
    '🧑🏼‍⚖' => 'суддя: помірно світлий тон шкіри',
    '🧑🏽‍⚖' => 'суддя: помірний тон шкіри',
    '🧑🏾‍⚖' => 'суддя: помірно темний тон шкіри',
    '🧑🏿‍⚖' => 'суддя: темний тон шкіри',
    '👨🏻‍⚖' => 'суддя-чоловік: світлий тон шкіри',
    '👨🏼‍⚖' => 'суддя-чоловік: помірно світлий тон шкіри',
    '👨🏽‍⚖' => 'суддя-чоловік: помірний тон шкіри',
    '👨🏾‍⚖' => 'суддя-чоловік: помірно темний тон шкіри',
    '👨🏿‍⚖' => 'суддя-чоловік: темний тон шкіри',
    '👩🏻‍⚖' => 'жінка-суддя: світлий тон шкіри',
    '👩🏼‍⚖' => 'жінка-суддя: помірно світлий тон шкіри',
    '👩🏽‍⚖' => 'жінка-суддя: помірний тон шкіри',
    '👩🏾‍⚖' => 'жінка-суддя: помірно темний тон шкіри',
    '👩🏿‍⚖' => 'жінка-суддя: темний тон шкіри',
    '🧑🏻‍🌾' => 'селянин: світлий тон шкіри',
    '🧑🏼‍🌾' => 'селянин: помірно світлий тон шкіри',
    '🧑🏽‍🌾' => 'селянин: помірний тон шкіри',
    '🧑🏾‍🌾' => 'селянин: помірно темний тон шкіри',
    '🧑🏿‍🌾' => 'селянин: темний тон шкіри',
    '👨🏻‍🌾' => 'фермер: світлий тон шкіри',
    '👨🏼‍🌾' => 'фермер: помірно світлий тон шкіри',
    '👨🏽‍🌾' => 'фермер: помірний тон шкіри',
    '👨🏾‍🌾' => 'фермер: помірно темний тон шкіри',
    '👨🏿‍🌾' => 'фермер: темний тон шкіри',
    '👩🏻‍🌾' => 'фермерка: світлий тон шкіри',
    '👩🏼‍🌾' => 'фермерка: помірно світлий тон шкіри',
    '👩🏽‍🌾' => 'фермерка: помірний тон шкіри',
    '👩🏾‍🌾' => 'фермерка: помірно темний тон шкіри',
    '👩🏿‍🌾' => 'фермерка: темний тон шкіри',
    '🧑🏻‍🍳' => 'куховар: світлий тон шкіри',
    '🧑🏼‍🍳' => 'куховар: помірно світлий тон шкіри',
    '🧑🏽‍🍳' => 'куховар: помірний тон шкіри',
    '🧑🏾‍🍳' => 'куховар: помірно темний тон шкіри',
    '🧑🏿‍🍳' => 'куховар: темний тон шкіри',
    '👨🏻‍🍳' => 'кухар: світлий тон шкіри',
    '👨🏼‍🍳' => 'кухар: помірно світлий тон шкіри',
    '👨🏽‍🍳' => 'кухар: помірний тон шкіри',
    '👨🏾‍🍳' => 'кухар: помірно темний тон шкіри',
    '👨🏿‍🍳' => 'кухар: темний тон шкіри',
    '👩🏻‍🍳' => 'кухарка: світлий тон шкіри',
    '👩🏼‍🍳' => 'кухарка: помірно світлий тон шкіри',
    '👩🏽‍🍳' => 'кухарка: помірний тон шкіри',
    '👩🏾‍🍳' => 'кухарка: помірно темний тон шкіри',
    '👩🏿‍🍳' => 'кухарка: темний тон шкіри',
    '🧑🏻‍🔧' => 'фахівець із механіки: світлий тон шкіри',
    '🧑🏼‍🔧' => 'фахівець із механіки: помірно світлий тон шкіри',
    '🧑🏽‍🔧' => 'фахівець із механіки: помірний тон шкіри',
    '🧑🏾‍🔧' => 'фахівець із механіки: помірно темний тон шкіри',
    '🧑🏿‍🔧' => 'фахівець із механіки: темний тон шкіри',
    '👨🏻‍🔧' => 'механік: світлий тон шкіри',
    '👨🏼‍🔧' => 'механік: помірно світлий тон шкіри',
    '👨🏽‍🔧' => 'механік: помірний тон шкіри',
    '👨🏾‍🔧' => 'механік: помірно темний тон шкіри',
    '👨🏿‍🔧' => 'механік: темний тон шкіри',
    '👩🏻‍🔧' => 'жінка-механік: світлий тон шкіри',
    '👩🏼‍🔧' => 'жінка-механік: помірно світлий тон шкіри',
    '👩🏽‍🔧' => 'жінка-механік: помірний тон шкіри',
    '👩🏾‍🔧' => 'жінка-механік: помірно темний тон шкіри',
    '👩🏿‍🔧' => 'жінка-механік: темний тон шкіри',
    '🧑🏻‍🏭' => 'фабричний працівник: світлий тон шкіри',
    '🧑🏼‍🏭' => 'фабричний працівник: помірно світлий тон шкіри',
    '🧑🏽‍🏭' => 'фабричний працівник: помірний тон шкіри',
    '🧑🏾‍🏭' => 'фабричний працівник: помірно темний тон шкіри',
    '🧑🏿‍🏭' => 'фабричний працівник: темний тон шкіри',
    '👨🏻‍🏭' => 'робітник: світлий тон шкіри',
    '👨🏼‍🏭' => 'робітник: помірно світлий тон шкіри',
    '👨🏽‍🏭' => 'робітник: помірний тон шкіри',
    '👨🏾‍🏭' => 'робітник: помірно темний тон шкіри',
    '👨🏿‍🏭' => 'робітник: темний тон шкіри',
    '👩🏻‍🏭' => 'робітниця: світлий тон шкіри',
    '👩🏼‍🏭' => 'робітниця: помірно світлий тон шкіри',
    '👩🏽‍🏭' => 'робітниця: помірний тон шкіри',
    '👩🏾‍🏭' => 'робітниця: помірно темний тон шкіри',
    '👩🏿‍🏭' => 'робітниця: темний тон шкіри',
    '🧑🏻‍💼' => 'офісний працівник: світлий тон шкіри',
    '🧑🏼‍💼' => 'офісний працівник: помірно світлий тон шкіри',
    '🧑🏽‍💼' => 'офісний працівник: помірний тон шкіри',
    '🧑🏾‍💼' => 'офісний працівник: помірно темний тон шкіри',
    '🧑🏿‍💼' => 'офісний працівник: темний тон шкіри',
    '👨🏻‍💼' => 'службовець: світлий тон шкіри',
    '👨🏼‍💼' => 'службовець: помірно світлий тон шкіри',
    '👨🏽‍💼' => 'службовець: помірний тон шкіри',
    '👨🏾‍💼' => 'службовець: помірно темний тон шкіри',
    '👨🏿‍💼' => 'службовець: темний тон шкіри',
    '👩🏻‍💼' => 'службовка: світлий тон шкіри',
    '👩🏼‍💼' => 'службовка: помірно світлий тон шкіри',
    '👩🏽‍💼' => 'службовка: помірний тон шкіри',
    '👩🏾‍💼' => 'службовка: помірно темний тон шкіри',
    '👩🏿‍💼' => 'службовка: темний тон шкіри',
    '🧑🏻‍🔬' => 'науковий працівник: світлий тон шкіри',
    '🧑🏼‍🔬' => 'науковий працівник: помірно світлий тон шкіри',
    '🧑🏽‍🔬' => 'науковий працівник: помірний тон шкіри',
    '🧑🏾‍🔬' => 'науковий працівник: помірно темний тон шкіри',
    '🧑🏿‍🔬' => 'науковий працівник: темний тон шкіри',
    '👨🏻‍🔬' => 'науковець: світлий тон шкіри',
    '👨🏼‍🔬' => 'науковець: помірно світлий тон шкіри',
    '👨🏽‍🔬' => 'науковець: помірний тон шкіри',
    '👨🏾‍🔬' => 'науковець: помірно темний тон шкіри',
    '👨🏿‍🔬' => 'науковець: темний тон шкіри',
    '👩🏻‍🔬' => 'жінка-науковець: світлий тон шкіри',
    '👩🏼‍🔬' => 'жінка-науковець: помірно світлий тон шкіри',
    '👩🏽‍🔬' => 'жінка-науковець: помірний тон шкіри',
    '👩🏾‍🔬' => 'жінка-науковець: помірно темний тон шкіри',
    '👩🏿‍🔬' => 'жінка-науковець: темний тон шкіри',
    '🧑🏻‍💻' => 'технічний працівник: світлий тон шкіри',
    '🧑🏼‍💻' => 'технічний працівник: помірно світлий тон шкіри',
    '🧑🏽‍💻' => 'технічний працівник: помірний тон шкіри',
    '🧑🏾‍💻' => 'технічний працівник: помірно темний тон шкіри',
    '🧑🏿‍💻' => 'технічний працівник: темний тон шкіри',
    '👨🏻‍💻' => 'технолог: світлий тон шкіри',
    '👨🏼‍💻' => 'технолог: помірно світлий тон шкіри',
    '👨🏽‍💻' => 'технолог: помірний тон шкіри',
    '👨🏾‍💻' => 'технолог: помірно темний тон шкіри',
    '👨🏿‍💻' => 'технолог: темний тон шкіри',
    '👩🏻‍💻' => 'жінка-технолог: світлий тон шкіри',
    '👩🏼‍💻' => 'жінка-технолог: помірно світлий тон шкіри',
    '👩🏽‍💻' => 'жінка-технолог: помірний тон шкіри',
    '👩🏾‍💻' => 'жінка-технолог: помірно темний тон шкіри',
    '👩🏿‍💻' => 'жінка-технолог: темний тон шкіри',
    '🧑🏻‍🎤' => 'вокаліст: світлий тон шкіри',
    '🧑🏼‍🎤' => 'вокаліст: помірно світлий тон шкіри',
    '🧑🏽‍🎤' => 'вокаліст: помірний тон шкіри',
    '🧑🏾‍🎤' => 'вокаліст: помірно темний тон шкіри',
    '🧑🏿‍🎤' => 'вокаліст: темний тон шкіри',
    '👨🏻‍🎤' => 'співак: світлий тон шкіри',
    '👨🏼‍🎤' => 'співак: помірно світлий тон шкіри',
    '👨🏽‍🎤' => 'співак: помірний тон шкіри',
    '👨🏾‍🎤' => 'співак: помірно темний тон шкіри',
    '👨🏿‍🎤' => 'співак: темний тон шкіри',
    '👩🏻‍🎤' => 'співачка: світлий тон шкіри',
    '👩🏼‍🎤' => 'співачка: помірно світлий тон шкіри',
    '👩🏽‍🎤' => 'співачка: помірний тон шкіри',
    '👩🏾‍🎤' => 'співачка: помірно темний тон шкіри',
    '👩🏿‍🎤' => 'співачка: темний тон шкіри',
    '🧑🏻‍🎨' => 'художник: світлий тон шкіри',
    '🧑🏼‍🎨' => 'художник: помірно світлий тон шкіри',
    '🧑🏽‍🎨' => 'художник: помірний тон шкіри',
    '🧑🏾‍🎨' => 'художник: помірно темний тон шкіри',
    '🧑🏿‍🎨' => 'художник: темний тон шкіри',
    '👨🏻‍🎨' => 'чоловік-художник: світлий тон шкіри',
    '👨🏼‍🎨' => 'чоловік-художник: помірно світлий тон шкіри',
    '👨🏽‍🎨' => 'чоловік-художник: помірний тон шкіри',
    '👨🏾‍🎨' => 'чоловік-художник: помірно темний тон шкіри',
    '👨🏿‍🎨' => 'чоловік-художник: темний тон шкіри',
    '👩🏻‍🎨' => 'художниця: світлий тон шкіри',
    '👩🏼‍🎨' => 'художниця: помірно світлий тон шкіри',
    '👩🏽‍🎨' => 'художниця: помірний тон шкіри',
    '👩🏾‍🎨' => 'художниця: помірно темний тон шкіри',
    '👩🏿‍🎨' => 'художниця: темний тон шкіри',
    '🧑🏻‍✈' => 'авіапілот: світлий тон шкіри',
    '🧑🏼‍✈' => 'авіапілот: помірно світлий тон шкіри',
    '🧑🏽‍✈' => 'авіапілот: помірний тон шкіри',
    '🧑🏾‍✈' => 'авіапілот: помірно темний тон шкіри',
    '🧑🏿‍✈' => 'авіапілот: темний тон шкіри',
    '👨🏻‍✈' => 'пілот: світлий тон шкіри',
    '👨🏼‍✈' => 'пілот: помірно світлий тон шкіри',
    '👨🏽‍✈' => 'пілот: помірний тон шкіри',
    '👨🏾‍✈' => 'пілот: помірно темний тон шкіри',
    '👨🏿‍✈' => 'пілот: темний тон шкіри',
    '👩🏻‍✈' => 'жінка-пілот: світлий тон шкіри',
    '👩🏼‍✈' => 'жінка-пілот: помірно світлий тон шкіри',
    '👩🏽‍✈' => 'жінка-пілот: помірний тон шкіри',
    '👩🏾‍✈' => 'жінка-пілот: помірно темний тон шкіри',
    '👩🏿‍✈' => 'жінка-пілот: темний тон шкіри',
    '🧑🏻‍🚀' => 'космонавт: світлий тон шкіри',
    '🧑🏼‍🚀' => 'космонавт: помірно світлий тон шкіри',
    '🧑🏽‍🚀' => 'космонавт: помірний тон шкіри',
    '🧑🏾‍🚀' => 'космонавт: помірно темний тон шкіри',
    '🧑🏿‍🚀' => 'космонавт: темний тон шкіри',
    '👨🏻‍🚀' => 'астронавт: світлий тон шкіри',
    '👨🏼‍🚀' => 'астронавт: помірно світлий тон шкіри',
    '👨🏽‍🚀' => 'астронавт: помірний тон шкіри',
    '👨🏾‍🚀' => 'астронавт: помірно темний тон шкіри',
    '👨🏿‍🚀' => 'астронавт: темний тон шкіри',
    '👩🏻‍🚀' => 'астронавтка: світлий тон шкіри',
    '👩🏼‍🚀' => 'астронавтка: помірно світлий тон шкіри',
    '👩🏽‍🚀' => 'астронавтка: помірний тон шкіри',
    '👩🏾‍🚀' => 'астронавтка: помірно темний тон шкіри',
    '👩🏿‍🚀' => 'астронавтка: темний тон шкіри',
    '🧑🏻‍🚒' => 'вогнеборець: світлий тон шкіри',
    '🧑🏼‍🚒' => 'вогнеборець: помірно світлий тон шкіри',
    '🧑🏽‍🚒' => 'вогнеборець: помірний тон шкіри',
    '🧑🏾‍🚒' => 'вогнеборець: помірно темний тон шкіри',
    '🧑🏿‍🚒' => 'вогнеборець: темний тон шкіри',
    '👨🏻‍🚒' => 'пожежник: світлий тон шкіри',
    '👨🏼‍🚒' => 'пожежник: помірно світлий тон шкіри',
    '👨🏽‍🚒' => 'пожежник: помірний тон шкіри',
    '👨🏾‍🚒' => 'пожежник: помірно темний тон шкіри',
    '👨🏿‍🚒' => 'пожежник: темний тон шкіри',
    '👩🏻‍🚒' => 'жінка-пожежник: світлий тон шкіри',
    '👩🏼‍🚒' => 'жінка-пожежник: помірно світлий тон шкіри',
    '👩🏽‍🚒' => 'жінка-пожежник: помірний тон шкіри',
    '👩🏾‍🚒' => 'жінка-пожежник: помірно темний тон шкіри',
    '👩🏿‍🚒' => 'жінка-пожежник: темний тон шкіри',
    '👮🏻‍♂' => 'поліцейський: світлий тон шкіри',
    '👮🏼‍♂' => 'поліцейський: помірно світлий тон шкіри',
    '👮🏽‍♂' => 'поліцейський: помірний тон шкіри',
    '👮🏾‍♂' => 'поліцейський: помірно темний тон шкіри',
    '👮🏿‍♂' => 'поліцейський: темний тон шкіри',
    '👮🏻‍♀' => 'жінка-поліцейський: світлий тон шкіри',
    '👮🏼‍♀' => 'жінка-поліцейський: помірно світлий тон шкіри',
    '👮🏽‍♀' => 'жінка-поліцейський: помірний тон шкіри',
    '👮🏾‍♀' => 'жінка-поліцейський: помірно темний тон шкіри',
    '👮🏿‍♀' => 'жінка-поліцейський: темний тон шкіри',
    '🕵🏻‍♂' => 'чоловік-детектив: світлий тон шкіри',
    '🕵🏼‍♂' => 'чоловік-детектив: помірно світлий тон шкіри',
    '🕵🏽‍♂' => 'чоловік-детектив: помірний тон шкіри',
    '🕵🏾‍♂' => 'чоловік-детектив: помірно темний тон шкіри',
    '🕵🏿‍♂' => 'чоловік-детектив: темний тон шкіри',
    '🕵🏻‍♀' => 'жінка-детектив: світлий тон шкіри',
    '🕵🏼‍♀' => 'жінка-детектив: помірно світлий тон шкіри',
    '🕵🏽‍♀' => 'жінка-детектив: помірний тон шкіри',
    '🕵🏾‍♀' => 'жінка-детектив: помірно темний тон шкіри',
    '🕵🏿‍♀' => 'жінка-детектив: темний тон шкіри',
    '💂🏻‍♂' => 'вартовий: світлий тон шкіри',
    '💂🏼‍♂' => 'вартовий: помірно світлий тон шкіри',
    '💂🏽‍♂' => 'вартовий: помірний тон шкіри',
    '💂🏾‍♂' => 'вартовий: помірно темний тон шкіри',
    '💂🏿‍♂' => 'вартовий: темний тон шкіри',
    '💂🏻‍♀' => 'вартова: світлий тон шкіри',
    '💂🏼‍♀' => 'вартова: помірно світлий тон шкіри',
    '💂🏽‍♀' => 'вартова: помірний тон шкіри',
    '💂🏾‍♀' => 'вартова: помірно темний тон шкіри',
    '💂🏿‍♀' => 'вартова: темний тон шкіри',
    '👷🏻‍♂' => 'чоловік-будівельник: світлий тон шкіри',
    '👷🏼‍♂' => 'чоловік-будівельник: помірно світлий тон шкіри',
    '👷🏽‍♂' => 'чоловік-будівельник: помірний тон шкіри',
    '👷🏾‍♂' => 'чоловік-будівельник: помірно темний тон шкіри',
    '👷🏿‍♂' => 'чоловік-будівельник: темний тон шкіри',
    '👷🏻‍♀' => 'жінка-будівельник: світлий тон шкіри',
    '👷🏼‍♀' => 'жінка-будівельник: помірно світлий тон шкіри',
    '👷🏽‍♀' => 'жінка-будівельник: помірний тон шкіри',
    '👷🏾‍♀' => 'жінка-будівельник: помірно темний тон шкіри',
    '👷🏿‍♀' => 'жінка-будівельник: темний тон шкіри',
    '👳🏻‍♂' => 'чоловік у тюрбані: світлий тон шкіри',
    '👳🏼‍♂' => 'чоловік у тюрбані: помірно світлий тон шкіри',
    '👳🏽‍♂' => 'чоловік у тюрбані: помірний тон шкіри',
    '👳🏾‍♂' => 'чоловік у тюрбані: помірно темний тон шкіри',
    '👳🏿‍♂' => 'чоловік у тюрбані: темний тон шкіри',
    '👳🏻‍♀' => 'жінка в тюрбані: світлий тон шкіри',
    '👳🏼‍♀' => 'жінка в тюрбані: помірно світлий тон шкіри',
    '👳🏽‍♀' => 'жінка в тюрбані: помірний тон шкіри',
    '👳🏾‍♀' => 'жінка в тюрбані: помірно темний тон шкіри',
    '👳🏿‍♀' => 'жінка в тюрбані: темний тон шкіри',
    '🤵🏻‍♂' => 'чоловік у смокінгу: світлий тон шкіри',
    '🤵🏼‍♂' => 'чоловік у смокінгу: помірно світлий тон шкіри',
    '🤵🏽‍♂' => 'чоловік у смокінгу: помірний тон шкіри',
    '🤵🏾‍♂' => 'чоловік у смокінгу: помірно темний тон шкіри',
    '🤵🏿‍♂' => 'чоловік у смокінгу: темний тон шкіри',
    '🤵🏻‍♀' => 'жінка в смокінгу: світлий тон шкіри',
    '🤵🏼‍♀' => 'жінка в смокінгу: помірно світлий тон шкіри',
    '🤵🏽‍♀' => 'жінка в смокінгу: помірний тон шкіри',
    '🤵🏾‍♀' => 'жінка в смокінгу: помірно темний тон шкіри',
    '🤵🏿‍♀' => 'жінка в смокінгу: темний тон шкіри',
    '👰🏻‍♂' => 'чоловік у фаті: світлий тон шкіри',
    '👰🏼‍♂' => 'чоловік у фаті: помірно світлий тон шкіри',
    '👰🏽‍♂' => 'чоловік у фаті: помірний тон шкіри',
    '👰🏾‍♂' => 'чоловік у фаті: помірно темний тон шкіри',
    '👰🏿‍♂' => 'чоловік у фаті: темний тон шкіри',
    '👰🏻‍♀' => 'жінка у фаті: світлий тон шкіри',
    '👰🏼‍♀' => 'жінка у фаті: помірно світлий тон шкіри',
    '👰🏽‍♀' => 'жінка у фаті: помірний тон шкіри',
    '👰🏾‍♀' => 'жінка у фаті: помірно темний тон шкіри',
    '👰🏿‍♀' => 'жінка у фаті: темний тон шкіри',
    '👩🏻‍🍼' => 'жінка годує дитину: світлий тон шкіри',
    '👩🏼‍🍼' => 'жінка годує дитину: помірно світлий тон шкіри',
    '👩🏽‍🍼' => 'жінка годує дитину: помірний тон шкіри',
    '👩🏾‍🍼' => 'жінка годує дитину: помірно темний тон шкіри',
    '👩🏿‍🍼' => 'жінка годує дитину: темний тон шкіри',
    '👨🏻‍🍼' => 'чоловік годує дитину: світлий тон шкіри',
    '👨🏼‍🍼' => 'чоловік годує дитину: помірно світлий тон шкіри',
    '👨🏽‍🍼' => 'чоловік годує дитину: помірний тон шкіри',
    '👨🏾‍🍼' => 'чоловік годує дитину: помірно темний тон шкіри',
    '👨🏿‍🍼' => 'чоловік годує дитину: темний тон шкіри',
    '🧑🏻‍🍼' => 'людина годує дитину: світлий тон шкіри',
    '🧑🏼‍🍼' => 'людина годує дитину: помірно світлий тон шкіри',
    '🧑🏽‍🍼' => 'людина годує дитину: помірний тон шкіри',
    '🧑🏾‍🍼' => 'людина годує дитину: помірно темний тон шкіри',
    '🧑🏿‍🍼' => 'людина годує дитину: темний тон шкіри',
    '🧑🏻‍🎄' => 'Мікс Клаус: світлий тон шкіри',
    '🧑🏼‍🎄' => 'Мікс Клаус: помірно світлий тон шкіри',
    '🧑🏽‍🎄' => 'Мікс Клаус: помірний тон шкіри',
    '🧑🏾‍🎄' => 'Мікс Клаус: помірно темний тон шкіри',
    '🧑🏿‍🎄' => 'Мікс Клаус: темний тон шкіри',
    '🦸🏻‍♂' => 'чоловік-супергерой: світлий тон шкіри',
    '🦸🏼‍♂' => 'чоловік-супергерой: помірно світлий тон шкіри',
    '🦸🏽‍♂' => 'чоловік-супергерой: помірний тон шкіри',
    '🦸🏾‍♂' => 'чоловік-супергерой: помірно темний тон шкіри',
    '🦸🏿‍♂' => 'чоловік-супергерой: темний тон шкіри',
    '🦸🏻‍♀' => 'жінка-супергерой: світлий тон шкіри',
    '🦸🏼‍♀' => 'жінка-супергерой: помірно світлий тон шкіри',
    '🦸🏽‍♀' => 'жінка-супергерой: помірний тон шкіри',
    '🦸🏾‍♀' => 'жінка-супергерой: помірно темний тон шкіри',
    '🦸🏿‍♀' => 'жінка-супергерой: темний тон шкіри',
    '🦹🏻‍♂' => 'суперлиходій: світлий тон шкіри',
    '🦹🏼‍♂' => 'суперлиходій: помірно світлий тон шкіри',
    '🦹🏽‍♂' => 'суперлиходій: помірний тон шкіри',
    '🦹🏾‍♂' => 'суперлиходій: помірно темний тон шкіри',
    '🦹🏿‍♂' => 'суперлиходій: темний тон шкіри',
    '🦹🏻‍♀' => 'суперлиходійка: світлий тон шкіри',
    '🦹🏼‍♀' => 'суперлиходійка: помірно світлий тон шкіри',
    '🦹🏽‍♀' => 'суперлиходійка: помірний тон шкіри',
    '🦹🏾‍♀' => 'суперлиходійка: помірно темний тон шкіри',
    '🦹🏿‍♀' => 'суперлиходійка: темний тон шкіри',
    '🧙🏻‍♂' => 'чаклун: світлий тон шкіри',
    '🧙🏼‍♂' => 'чаклун: помірно світлий тон шкіри',
    '🧙🏽‍♂' => 'чаклун: помірний тон шкіри',
    '🧙🏾‍♂' => 'чаклун: помірно темний тон шкіри',
    '🧙🏿‍♂' => 'чаклун: темний тон шкіри',
    '🧙🏻‍♀' => 'чаклунка: світлий тон шкіри',
    '🧙🏼‍♀' => 'чаклунка: помірно світлий тон шкіри',
    '🧙🏽‍♀' => 'чаклунка: помірний тон шкіри',
    '🧙🏾‍♀' => 'чаклунка: помірно темний тон шкіри',
    '🧙🏿‍♀' => 'чаклунка: темний тон шкіри',
    '🧚🏻‍♂' => 'чоловік-фея: світлий тон шкіри',
    '🧚🏼‍♂' => 'чоловік-фея: помірно світлий тон шкіри',
    '🧚🏽‍♂' => 'чоловік-фея: помірний тон шкіри',
    '🧚🏾‍♂' => 'чоловік-фея: помірно темний тон шкіри',
    '🧚🏿‍♂' => 'чоловік-фея: темний тон шкіри',
    '🧚🏻‍♀' => 'жінка-фея: світлий тон шкіри',
    '🧚🏼‍♀' => 'жінка-фея: помірно світлий тон шкіри',
    '🧚🏽‍♀' => 'жінка-фея: помірний тон шкіри',
    '🧚🏾‍♀' => 'жінка-фея: помірно темний тон шкіри',
    '🧚🏿‍♀' => 'жінка-фея: темний тон шкіри',
    '🧛🏻‍♂' => 'чоловік-вампір: світлий тон шкіри',
    '🧛🏼‍♂' => 'чоловік-вампір: помірно світлий тон шкіри',
    '🧛🏽‍♂' => 'чоловік-вампір: помірний тон шкіри',
    '🧛🏾‍♂' => 'чоловік-вампір: помірно темний тон шкіри',
    '🧛🏿‍♂' => 'чоловік-вампір: темний тон шкіри',
    '🧛🏻‍♀' => 'жінка-вампір: світлий тон шкіри',
    '🧛🏼‍♀' => 'жінка-вампір: помірно світлий тон шкіри',
    '🧛🏽‍♀' => 'жінка-вампір: помірний тон шкіри',
    '🧛🏾‍♀' => 'жінка-вампір: помірно темний тон шкіри',
    '🧛🏿‍♀' => 'жінка-вампір: темний тон шкіри',
    '🧜🏻‍♂' => 'чоловік-русалка: світлий тон шкіри',
    '🧜🏼‍♂' => 'чоловік-русалка: помірно світлий тон шкіри',
    '🧜🏽‍♂' => 'чоловік-русалка: помірний тон шкіри',
    '🧜🏾‍♂' => 'чоловік-русалка: помірно темний тон шкіри',
    '🧜🏿‍♂' => 'чоловік-русалка: темний тон шкіри',
    '🧜🏻‍♀' => 'русалка: світлий тон шкіри',
    '🧜🏼‍♀' => 'русалка: помірно світлий тон шкіри',
    '🧜🏽‍♀' => 'русалка: помірний тон шкіри',
    '🧜🏾‍♀' => 'русалка: помірно темний тон шкіри',
    '🧜🏿‍♀' => 'русалка: темний тон шкіри',
    '🧝🏻‍♂' => 'чоловік-ельф: світлий тон шкіри',
    '🧝🏼‍♂' => 'чоловік-ельф: помірно світлий тон шкіри',
    '🧝🏽‍♂' => 'чоловік-ельф: помірний тон шкіри',
    '🧝🏾‍♂' => 'чоловік-ельф: помірно темний тон шкіри',
    '🧝🏿‍♂' => 'чоловік-ельф: темний тон шкіри',
    '🧝🏻‍♀' => 'жінка-ельф: світлий тон шкіри',
    '🧝🏼‍♀' => 'жінка-ельф: помірно світлий тон шкіри',
    '🧝🏽‍♀' => 'жінка-ельф: помірний тон шкіри',
    '🧝🏾‍♀' => 'жінка-ельф: помірно темний тон шкіри',
    '🧝🏿‍♀' => 'жінка-ельф: темний тон шкіри',
    '💆🏻‍♂' => 'чоловік, якому роблять масаж голови: світлий тон шкіри',
    '💆🏼‍♂' => 'чоловік, якому роблять масаж голови: помірно світлий тон шкіри',
    '💆🏽‍♂' => 'чоловік, якому роблять масаж голови: помірний тон шкіри',
    '💆🏾‍♂' => 'чоловік, якому роблять масаж голови: помірно темний тон шкіри',
    '💆🏿‍♂' => 'чоловік, якому роблять масаж голови: темний тон шкіри',
    '💆🏻‍♀' => 'жінка, якій роблять масаж голови: світлий тон шкіри',
    '💆🏼‍♀' => 'жінка, якій роблять масаж голови: помірно світлий тон шкіри',
    '💆🏽‍♀' => 'жінка, якій роблять масаж голови: помірний тон шкіри',
    '💆🏾‍♀' => 'жінка, якій роблять масаж голови: помірно темний тон шкіри',
    '💆🏿‍♀' => 'жінка, якій роблять масаж голови: темний тон шкіри',
    '💇🏻‍♂' => 'чоловік, якому роблять стрижку: світлий тон шкіри',
    '💇🏼‍♂' => 'чоловік, якому роблять стрижку: помірно світлий тон шкіри',
    '💇🏽‍♂' => 'чоловік, якому роблять стрижку: помірний тон шкіри',
    '💇🏾‍♂' => 'чоловік, якому роблять стрижку: помірно темний тон шкіри',
    '💇🏿‍♂' => 'чоловік, якому роблять стрижку: темний тон шкіри',
    '💇🏻‍♀' => 'жінка, якій роблять стрижку: світлий тон шкіри',
    '💇🏼‍♀' => 'жінка, якій роблять стрижку: помірно світлий тон шкіри',
    '💇🏽‍♀' => 'жінка, якій роблять стрижку: помірний тон шкіри',
    '💇🏾‍♀' => 'жінка, якій роблять стрижку: помірно темний тон шкіри',
    '💇🏿‍♀' => 'жінка, якій роблять стрижку: темний тон шкіри',
    '🚶🏻‍♂' => 'чоловік, що йде пішки: світлий тон шкіри',
    '🚶🏼‍♂' => 'чоловік, що йде пішки: помірно світлий тон шкіри',
    '🚶🏽‍♂' => 'чоловік, що йде пішки: помірний тон шкіри',
    '🚶🏾‍♂' => 'чоловік, що йде пішки: помірно темний тон шкіри',
    '🚶🏿‍♂' => 'чоловік, що йде пішки: темний тон шкіри',
    '🚶🏻‍♀' => 'жінка, що йде пішки: світлий тон шкіри',
    '🚶🏼‍♀' => 'жінка, що йде пішки: помірно світлий тон шкіри',
    '🚶🏽‍♀' => 'жінка, що йде пішки: помірний тон шкіри',
    '🚶🏾‍♀' => 'жінка, що йде пішки: помірно темний тон шкіри',
    '🚶🏿‍♀' => 'жінка, що йде пішки: темний тон шкіри',
    '🚶🏻‍➡' => 'людина, що йде пішки: світлий тон шкіри і правий профіль:',
    '🚶🏼‍➡' => 'людина, що йде пішки: помірно світлий тон шкіри і правий профіль:',
    '🚶🏽‍➡' => 'людина, що йде пішки: помірний тон шкіри і правий профіль:',
    '🚶🏾‍➡' => 'людина, що йде пішки: помірно темний тон шкіри і правий профіль:',
    '🚶🏿‍➡' => 'людина, що йде пішки: темний тон шкіри і правий профіль:',
    '🧍🏻‍♂' => 'чоловік, що стоїть: світлий тон шкіри',
    '🧍🏼‍♂' => 'чоловік, що стоїть: помірно світлий тон шкіри',
    '🧍🏽‍♂' => 'чоловік, що стоїть: помірний тон шкіри',
    '🧍🏾‍♂' => 'чоловік, що стоїть: помірно темний тон шкіри',
    '🧍🏿‍♂' => 'чоловік, що стоїть: темний тон шкіри',
    '🧍🏻‍♀' => 'жінка, що стоїть: світлий тон шкіри',
    '🧍🏼‍♀' => 'жінка, що стоїть: помірно світлий тон шкіри',
    '🧍🏽‍♀' => 'жінка, що стоїть: помірний тон шкіри',
    '🧍🏾‍♀' => 'жінка, що стоїть: помірно темний тон шкіри',
    '🧍🏿‍♀' => 'жінка, що стоїть: темний тон шкіри',
    '🧎🏻‍♂' => 'чоловік навколішках: світлий тон шкіри',
    '🧎🏼‍♂' => 'чоловік навколішках: помірно світлий тон шкіри',
    '🧎🏽‍♂' => 'чоловік навколішках: помірний тон шкіри',
    '🧎🏾‍♂' => 'чоловік навколішках: помірно темний тон шкіри',
    '🧎🏿‍♂' => 'чоловік навколішках: темний тон шкіри',
    '🧎🏻‍♀' => 'жінка навколішках: світлий тон шкіри',
    '🧎🏼‍♀' => 'жінка навколішках: помірно світлий тон шкіри',
    '🧎🏽‍♀' => 'жінка навколішках: помірний тон шкіри',
    '🧎🏾‍♀' => 'жінка навколішках: помірно темний тон шкіри',
    '🧎🏿‍♀' => 'жінка навколішках: темний тон шкіри',
    '🧎🏻‍➡' => 'людина навколішках: світлий тон шкіри і правий профіль:',
    '🧎🏼‍➡' => 'людина навколішках: помірно світлий тон шкіри і правий профіль:',
    '🧎🏽‍➡' => 'людина навколішках: помірний тон шкіри і правий профіль:',
    '🧎🏾‍➡' => 'людина навколішках: помірно темний тон шкіри і правий профіль:',
    '🧎🏿‍➡' => 'людина навколішках: темний тон шкіри і правий профіль:',
    '🧑🏻‍🦯' => 'людина з тактильним ціпком: світлий тон шкіри',
    '🧑🏼‍🦯' => 'людина з тактильним ціпком: помірно світлий тон шкіри',
    '🧑🏽‍🦯' => 'людина з тактильним ціпком: помірний тон шкіри',
    '🧑🏾‍🦯' => 'людина з тактильним ціпком: помірно темний тон шкіри',
    '🧑🏿‍🦯' => 'людина з тактильним ціпком: темний тон шкіри',
    '👨🏻‍🦯' => 'чоловік із тактильною тростиною: світлий тон шкіри',
    '👨🏼‍🦯' => 'чоловік із тактильною тростиною: помірно світлий тон шкіри',
    '👨🏽‍🦯' => 'чоловік із тактильною тростиною: помірний тон шкіри',
    '👨🏾‍🦯' => 'чоловік із тактильною тростиною: помірно темний тон шкіри',
    '👨🏿‍🦯' => 'чоловік із тактильною тростиною: темний тон шкіри',
    '👩🏻‍🦯' => 'жінка з тактильною тростиною: світлий тон шкіри',
    '👩🏼‍🦯' => 'жінка з тактильною тростиною: помірно світлий тон шкіри',
    '👩🏽‍🦯' => 'жінка з тактильною тростиною: помірний тон шкіри',
    '👩🏾‍🦯' => 'жінка з тактильною тростиною: помірно темний тон шкіри',
    '👩🏿‍🦯' => 'жінка з тактильною тростиною: темний тон шкіри',
    '🧑🏻‍🦼' => 'людина на моторизованому візку: світлий тон шкіри',
    '🧑🏼‍🦼' => 'людина на моторизованому візку: помірно світлий тон шкіри',
    '🧑🏽‍🦼' => 'людина на моторизованому візку: помірний тон шкіри',
    '🧑🏾‍🦼' => 'людина на моторизованому візку: помірно темний тон шкіри',
    '🧑🏿‍🦼' => 'людина на моторизованому візку: темний тон шкіри',
    '👨🏻‍🦼' => 'чоловік у візку з електроприводом: світлий тон шкіри',
    '👨🏼‍🦼' => 'чоловік у візку з електроприводом: помірно світлий тон шкіри',
    '👨🏽‍🦼' => 'чоловік у візку з електроприводом: помірний тон шкіри',
    '👨🏾‍🦼' => 'чоловік у візку з електроприводом: помірно темний тон шкіри',
    '👨🏿‍🦼' => 'чоловік у візку з електроприводом: темний тон шкіри',
    '👩🏻‍🦼' => 'жінка у візку з електроприводом: світлий тон шкіри',
    '👩🏼‍🦼' => 'жінка у візку з електроприводом: помірно світлий тон шкіри',
    '👩🏽‍🦼' => 'жінка у візку з електроприводом: помірний тон шкіри',
    '👩🏾‍🦼' => 'жінка у візку з електроприводом: помірно темний тон шкіри',
    '👩🏿‍🦼' => 'жінка у візку з електроприводом: темний тон шкіри',
    '🧑🏻‍🦽' => 'людина у візку з ручним керуванням: світлий тон шкіри',
    '🧑🏼‍🦽' => 'людина у візку з ручним керуванням: помірно світлий тон шкіри',
    '🧑🏽‍🦽' => 'людина у візку з ручним керуванням: помірний тон шкіри',
    '🧑🏾‍🦽' => 'людина у візку з ручним керуванням: помірно темний тон шкіри',
    '🧑🏿‍🦽' => 'людина у візку з ручним керуванням: темний тон шкіри',
    '👨🏻‍🦽' => 'чоловік у візку з ручним приводом: світлий тон шкіри',
    '👨🏼‍🦽' => 'чоловік у візку з ручним приводом: помірно світлий тон шкіри',
    '👨🏽‍🦽' => 'чоловік у візку з ручним приводом: помірний тон шкіри',
    '👨🏾‍🦽' => 'чоловік у візку з ручним приводом: помірно темний тон шкіри',
    '👨🏿‍🦽' => 'чоловік у візку з ручним приводом: темний тон шкіри',
    '👩🏻‍🦽' => 'жінка у візку з ручним приводом: світлий тон шкіри',
    '👩🏼‍🦽' => 'жінка у візку з ручним приводом: помірно світлий тон шкіри',
    '👩🏽‍🦽' => 'жінка у візку з ручним приводом: помірний тон шкіри',
    '👩🏾‍🦽' => 'жінка у візку з ручним приводом: помірно темний тон шкіри',
    '👩🏿‍🦽' => 'жінка у візку з ручним приводом: темний тон шкіри',
    '🏃🏻‍♂' => 'чоловік, що біжить: світлий тон шкіри',
    '🏃🏼‍♂' => 'чоловік, що біжить: помірно світлий тон шкіри',
    '🏃🏽‍♂' => 'чоловік, що біжить: помірний тон шкіри',
    '🏃🏾‍♂' => 'чоловік, що біжить: помірно темний тон шкіри',
    '🏃🏿‍♂' => 'чоловік, що біжить: темний тон шкіри',
    '🏃🏻‍♀' => 'жінка, що біжить: світлий тон шкіри',
    '🏃🏼‍♀' => 'жінка, що біжить: помірно світлий тон шкіри',
    '🏃🏽‍♀' => 'жінка, що біжить: помірний тон шкіри',
    '🏃🏾‍♀' => 'жінка, що біжить: помірно темний тон шкіри',
    '🏃🏿‍♀' => 'жінка, що біжить: темний тон шкіри',
    '🏃🏻‍➡' => 'людина, що біжить: світлий тон шкіри і правий профіль:',
    '🏃🏼‍➡' => 'людина, що біжить: помірно світлий тон шкіри і правий профіль:',
    '🏃🏽‍➡' => 'людина, що біжить: помірний тон шкіри і правий профіль:',
    '🏃🏾‍➡' => 'людина, що біжить: помірно темний тон шкіри і правий профіль:',
    '🏃🏿‍➡' => 'людина, що біжить: темний тон шкіри і правий профіль:',
    '👯🏻‍♀' => 'жінки з кролячими вухами: світлий тон шкіри',
    '👯🏼‍♀' => 'жінки з кролячими вухами: помірно світлий тон шкіри',
    '👯🏽‍♀' => 'жінки з кролячими вухами: помірний тон шкіри',
    '👯🏾‍♀' => 'жінки з кролячими вухами: помірно темний тон шкіри',
    '👯🏿‍♀' => 'жінки з кролячими вухами: темний тон шкіри',
    '👯🏻‍♂' => 'чоловіки з кролячими вухами: світлий тон шкіри',
    '👯🏼‍♂' => 'чоловіки з кролячими вухами: помірно світлий тон шкіри',
    '👯🏽‍♂' => 'чоловіки з кролячими вухами: помірний тон шкіри',
    '👯🏾‍♂' => 'чоловіки з кролячими вухами: помірно темний тон шкіри',
    '👯🏿‍♂' => 'чоловіки з кролячими вухами: темний тон шкіри',
    '🧖🏻‍♂' => 'чоловік у паркому приміщенні: світлий тон шкіри',
    '🧖🏼‍♂' => 'чоловік у паркому приміщенні: помірно світлий тон шкіри',
    '🧖🏽‍♂' => 'чоловік у паркому приміщенні: помірний тон шкіри',
    '🧖🏾‍♂' => 'чоловік у паркому приміщенні: помірно темний тон шкіри',
    '🧖🏿‍♂' => 'чоловік у паркому приміщенні: темний тон шкіри',
    '🧖🏻‍♀' => 'жінка в паркому приміщенні: світлий тон шкіри',
    '🧖🏼‍♀' => 'жінка в паркому приміщенні: помірно світлий тон шкіри',
    '🧖🏽‍♀' => 'жінка в паркому приміщенні: помірний тон шкіри',
    '🧖🏾‍♀' => 'жінка в паркому приміщенні: помірно темний тон шкіри',
    '🧖🏿‍♀' => 'жінка в паркому приміщенні: темний тон шкіри',
    '🧗🏻‍♂' => 'чоловік-скелелаз: світлий тон шкіри',
    '🧗🏼‍♂' => 'чоловік-скелелаз: помірно світлий тон шкіри',
    '🧗🏽‍♂' => 'чоловік-скелелаз: помірний тон шкіри',
    '🧗🏾‍♂' => 'чоловік-скелелаз: помірно темний тон шкіри',
    '🧗🏿‍♂' => 'чоловік-скелелаз: темний тон шкіри',
    '🧗🏻‍♀' => 'жінка-скелелаз: світлий тон шкіри',
    '🧗🏼‍♀' => 'жінка-скелелаз: помірно світлий тон шкіри',
    '🧗🏽‍♀' => 'жінка-скелелаз: помірний тон шкіри',
    '🧗🏾‍♀' => 'жінка-скелелаз: помірно темний тон шкіри',
    '🧗🏿‍♀' => 'жінка-скелелаз: темний тон шкіри',
    '🏌🏻‍♂' => 'гольфіст: світлий тон шкіри',
    '🏌🏼‍♂' => 'гольфіст: помірно світлий тон шкіри',
    '🏌🏽‍♂' => 'гольфіст: помірний тон шкіри',
    '🏌🏾‍♂' => 'гольфіст: помірно темний тон шкіри',
    '🏌🏿‍♂' => 'гольфіст: темний тон шкіри',
    '🏌🏻‍♀' => 'гольфістка: світлий тон шкіри',
    '🏌🏼‍♀' => 'гольфістка: помірно світлий тон шкіри',
    '🏌🏽‍♀' => 'гольфістка: помірний тон шкіри',
    '🏌🏾‍♀' => 'гольфістка: помірно темний тон шкіри',
    '🏌🏿‍♀' => 'гольфістка: темний тон шкіри',
    '🏄🏻‍♂' => 'серфінгіст: світлий тон шкіри',
    '🏄🏼‍♂' => 'серфінгіст: помірно світлий тон шкіри',
    '🏄🏽‍♂' => 'серфінгіст: помірний тон шкіри',
    '🏄🏾‍♂' => 'серфінгіст: помірно темний тон шкіри',
    '🏄🏿‍♂' => 'серфінгіст: темний тон шкіри',
    '🏄🏻‍♀' => 'серфінгістка: світлий тон шкіри',
    '🏄🏼‍♀' => 'серфінгістка: помірно світлий тон шкіри',
    '🏄🏽‍♀' => 'серфінгістка: помірний тон шкіри',
    '🏄🏾‍♀' => 'серфінгістка: помірно темний тон шкіри',
    '🏄🏿‍♀' => 'серфінгістка: темний тон шкіри',
    '🚣🏻‍♂' => 'чоловік, що веслує на човні: світлий тон шкіри',
    '🚣🏼‍♂' => 'чоловік, що веслує на човні: помірно світлий тон шкіри',
    '🚣🏽‍♂' => 'чоловік, що веслує на човні: помірний тон шкіри',
    '🚣🏾‍♂' => 'чоловік, що веслує на човні: помірно темний тон шкіри',
    '🚣🏿‍♂' => 'чоловік, що веслує на човні: темний тон шкіри',
    '🚣🏻‍♀' => 'жінка, що веслує на човні: світлий тон шкіри',
    '🚣🏼‍♀' => 'жінка, що веслує на човні: помірно світлий тон шкіри',
    '🚣🏽‍♀' => 'жінка, що веслує на човні: помірний тон шкіри',
    '🚣🏾‍♀' => 'жінка, що веслує на човні: помірно темний тон шкіри',
    '🚣🏿‍♀' => 'жінка, що веслує на човні: темний тон шкіри',
    '🏊🏻‍♂' => 'плавець: світлий тон шкіри',
    '🏊🏼‍♂' => 'плавець: помірно світлий тон шкіри',
    '🏊🏽‍♂' => 'плавець: помірний тон шкіри',
    '🏊🏾‍♂' => 'плавець: помірно темний тон шкіри',
    '🏊🏿‍♂' => 'плавець: темний тон шкіри',
    '🏊🏻‍♀' => 'плавчиня: світлий тон шкіри',
    '🏊🏼‍♀' => 'плавчиня: помірно світлий тон шкіри',
    '🏊🏽‍♀' => 'плавчиня: помірний тон шкіри',
    '🏊🏾‍♀' => 'плавчиня: помірно темний тон шкіри',
    '🏊🏿‍♀' => 'плавчиня: темний тон шкіри',
    '⛹🏻‍♂' => 'чоловік, що веде мʼяч: світлий тон шкіри',
    '⛹🏼‍♂' => 'чоловік, що веде мʼяч: помірно світлий тон шкіри',
    '⛹🏽‍♂' => 'чоловік, що веде мʼяч: помірний тон шкіри',
    '⛹🏾‍♂' => 'чоловік, що веде мʼяч: помірно темний тон шкіри',
    '⛹🏿‍♂' => 'чоловік, що веде мʼяч: темний тон шкіри',
    '⛹🏻‍♀' => 'жінка, що веде мʼяч: світлий тон шкіри',
    '⛹🏼‍♀' => 'жінка, що веде мʼяч: помірно світлий тон шкіри',
    '⛹🏽‍♀' => 'жінка, що веде мʼяч: помірний тон шкіри',
    '⛹🏾‍♀' => 'жінка, що веде мʼяч: помірно темний тон шкіри',
    '⛹🏿‍♀' => 'жінка, що веде мʼяч: темний тон шкіри',
    '🏋🏻‍♂' => 'штангіст: світлий тон шкіри',
    '🏋🏼‍♂' => 'штангіст: помірно світлий тон шкіри',
    '🏋🏽‍♂' => 'штангіст: помірний тон шкіри',
    '🏋🏾‍♂' => 'штангіст: помірно темний тон шкіри',
    '🏋🏿‍♂' => 'штангіст: темний тон шкіри',
    '🏋🏻‍♀' => 'штангістка: світлий тон шкіри',
    '🏋🏼‍♀' => 'штангістка: помірно світлий тон шкіри',
    '🏋🏽‍♀' => 'штангістка: помірний тон шкіри',
    '🏋🏾‍♀' => 'штангістка: помірно темний тон шкіри',
    '🏋🏿‍♀' => 'штангістка: темний тон шкіри',
    '🚴🏻‍♂' => 'велосипедист: світлий тон шкіри',
    '🚴🏼‍♂' => 'велосипедист: помірно світлий тон шкіри',
    '🚴🏽‍♂' => 'велосипедист: помірний тон шкіри',
    '🚴🏾‍♂' => 'велосипедист: помірно темний тон шкіри',
    '🚴🏿‍♂' => 'велосипедист: темний тон шкіри',
    '🚴🏻‍♀' => 'велосипедистка: світлий тон шкіри',
    '🚴🏼‍♀' => 'велосипедистка: помірно світлий тон шкіри',
    '🚴🏽‍♀' => 'велосипедистка: помірний тон шкіри',
    '🚴🏾‍♀' => 'велосипедистка: помірно темний тон шкіри',
    '🚴🏿‍♀' => 'велосипедистка: темний тон шкіри',
    '🚵🏻‍♂' => 'гірський велосипедист: світлий тон шкіри',
    '🚵🏼‍♂' => 'гірський велосипедист: помірно світлий тон шкіри',
    '🚵🏽‍♂' => 'гірський велосипедист: помірний тон шкіри',
    '🚵🏾‍♂' => 'гірський велосипедист: помірно темний тон шкіри',
    '🚵🏿‍♂' => 'гірський велосипедист: темний тон шкіри',
    '🚵🏻‍♀' => 'гірська велосипедистка: світлий тон шкіри',
    '🚵🏼‍♀' => 'гірська велосипедистка: помірно світлий тон шкіри',
    '🚵🏽‍♀' => 'гірська велосипедистка: помірний тон шкіри',
    '🚵🏾‍♀' => 'гірська велосипедистка: помірно темний тон шкіри',
    '🚵🏿‍♀' => 'гірська велосипедистка: темний тон шкіри',
    '🤸🏻‍♂' => 'чоловік, що перевертається «колесом»: світлий тон шкіри',
    '🤸🏼‍♂' => 'чоловік, що перевертається «колесом»: помірно світлий тон шкіри',
    '🤸🏽‍♂' => 'чоловік, що перевертається «колесом»: помірний тон шкіри',
    '🤸🏾‍♂' => 'чоловік, що перевертається «колесом»: помірно темний тон шкіри',
    '🤸🏿‍♂' => 'чоловік, що перевертається «колесом»: темний тон шкіри',
    '🤸🏻‍♀' => 'жінка, що перевертається «колесом»: світлий тон шкіри',
    '🤸🏼‍♀' => 'жінка, що перевертається «колесом»: помірно світлий тон шкіри',
    '🤸🏽‍♀' => 'жінка, що перевертається «колесом»: помірний тон шкіри',
    '🤸🏾‍♀' => 'жінка, що перевертається «колесом»: помірно темний тон шкіри',
    '🤸🏿‍♀' => 'жінка, що перевертається «колесом»: темний тон шкіри',
    '🤼🏻‍♀' => 'борчиня: світлий тон шкіри',
    '🤼🏼‍♀' => 'борчиня: помірно світлий тон шкіри',
    '🤼🏽‍♀' => 'борчиня: помірний тон шкіри',
    '🤼🏾‍♀' => 'борчиня: помірно темний тон шкіри',
    '🤼🏿‍♀' => 'борчиня: темний тон шкіри',
    '🤼🏻‍♂' => 'борець: світлий тон шкіри',
    '🤼🏼‍♂' => 'борець: помірно світлий тон шкіри',
    '🤼🏽‍♂' => 'борець: помірний тон шкіри',
    '🤼🏾‍♂' => 'борець: помірно темний тон шкіри',
    '🤼🏿‍♂' => 'борець: темний тон шкіри',
    '🤽🏻‍♂' => 'ватерполіст: світлий тон шкіри',
    '🤽🏼‍♂' => 'ватерполіст: помірно світлий тон шкіри',
    '🤽🏽‍♂' => 'ватерполіст: помірний тон шкіри',
    '🤽🏾‍♂' => 'ватерполіст: помірно темний тон шкіри',
    '🤽🏿‍♂' => 'ватерполіст: темний тон шкіри',
    '🤽🏻‍♀' => 'ватерполістка: світлий тон шкіри',
    '🤽🏼‍♀' => 'ватерполістка: помірно світлий тон шкіри',
    '🤽🏽‍♀' => 'ватерполістка: помірний тон шкіри',
    '🤽🏾‍♀' => 'ватерполістка: помірно темний тон шкіри',
    '🤽🏿‍♀' => 'ватерполістка: темний тон шкіри',
    '🤾🏻‍♂' => 'гандболіст: світлий тон шкіри',
    '🤾🏼‍♂' => 'гандболіст: помірно світлий тон шкіри',
    '🤾🏽‍♂' => 'гандболіст: помірний тон шкіри',
    '🤾🏾‍♂' => 'гандболіст: помірно темний тон шкіри',
    '🤾🏿‍♂' => 'гандболіст: темний тон шкіри',
    '🤾🏻‍♀' => 'гандболістка: світлий тон шкіри',
    '🤾🏼‍♀' => 'гандболістка: помірно світлий тон шкіри',
    '🤾🏽‍♀' => 'гандболістка: помірний тон шкіри',
    '🤾🏾‍♀' => 'гандболістка: помірно темний тон шкіри',
    '🤾🏿‍♀' => 'гандболістка: темний тон шкіри',
    '🤹🏻‍♂' => 'жонглер: світлий тон шкіри',
    '🤹🏼‍♂' => 'жонглер: помірно світлий тон шкіри',
    '🤹🏽‍♂' => 'жонглер: помірний тон шкіри',
    '🤹🏾‍♂' => 'жонглер: помірно темний тон шкіри',
    '🤹🏿‍♂' => 'жонглер: темний тон шкіри',
    '🤹🏻‍♀' => 'жонглерка: світлий тон шкіри',
    '🤹🏼‍♀' => 'жонглерка: помірно світлий тон шкіри',
    '🤹🏽‍♀' => 'жонглерка: помірний тон шкіри',
    '🤹🏾‍♀' => 'жонглерка: помірно темний тон шкіри',
    '🤹🏿‍♀' => 'жонглерка: темний тон шкіри',
    '🧘🏻‍♂' => 'чоловік у позі лотоса: світлий тон шкіри',
    '🧘🏼‍♂' => 'чоловік у позі лотоса: помірно світлий тон шкіри',
    '🧘🏽‍♂' => 'чоловік у позі лотоса: помірний тон шкіри',
    '🧘🏾‍♂' => 'чоловік у позі лотоса: помірно темний тон шкіри',
    '🧘🏿‍♂' => 'чоловік у позі лотоса: темний тон шкіри',
    '🧘🏻‍♀' => 'жінка в позі лотоса: світлий тон шкіри',
    '🧘🏼‍♀' => 'жінка в позі лотоса: помірно світлий тон шкіри',
    '🧘🏽‍♀' => 'жінка в позі лотоса: помірний тон шкіри',
    '🧘🏾‍♀' => 'жінка в позі лотоса: помірно темний тон шкіри',
    '🧘🏿‍♀' => 'жінка в позі лотоса: темний тон шкіри',
    '🧑‍🦰' => 'людина: руде волосся',
    '🧑‍🦱' => 'людина: кучеряве волосся',
    '🧑‍🦳' => 'людина: сиве волосся',
    '🧑‍🦲' => 'людина: лисина',
    '👨‍🦰' => 'чоловік: руде волосся',
    '👨‍🦱' => 'чоловік: кучеряве волосся',
    '👨‍🦳' => 'чоловік: сиве волосся',
    '👨‍🦲' => 'чоловік: лисина',
    '👩‍🦰' => 'жінка: руде волосся',
    '👩‍🦱' => 'жінка: кучеряве волосся',
    '👩‍🦳' => 'жінка: сиве волосся',
    '👩‍🦲' => 'жінка: лисина',
    '🚶‍➡' => 'людина, що йде пішки: правий профіль:',
    '🧎‍➡' => 'людина навколішках: правий профіль:',
    '🏃‍➡' => 'людина, що біжить: правий профіль:',
    '👨‍👦' => 'родина: чоловік і хлопчик',
    '👨‍👧' => 'родина: чоловік і дівчинка',
    '👩‍👦' => 'родина: жінка і хлопчик',
    '👩‍👧' => 'родина: жінка і дівчинка',
    '😶‍🌫' => 'обличчя в хмарах',
    '😮‍💨' => 'обличчя, що видихає',
    '🙂‍↕' => 'кивання головою',
    '😵‍💫' => 'очі-спіралі',
    '❤‍🔥' => 'палке серце',
    '❤‍🩹' => 'серце, що заживає',
    '👁‍🗨' => 'око в текстовій бульці',
    '🧔‍♂' => 'чоловік із бородою',
    '👱‍♂' => 'чоловік із білявим волоссям',
    '🧔‍♀' => 'жінка з бородою',
    '👱‍♀' => 'жінка з білявим волоссям',
    '🙍‍♂' => 'похмурий чоловік',
    '🙍‍♀' => 'похмура жінка',
    '🙎‍♂' => 'чоловік, що дується',
    '🙎‍♀' => 'жінка, що дується',
    '🙅‍♂' => 'чоловік, що жестом показує «ні»',
    '🙅‍♀' => 'жінка, що жестом показує «ні»',
    '🙆‍♂' => 'чоловік, що жестом показує «окей»',
    '🙆‍♀' => 'жінка, що жестом показує «окей»',
    '💁‍♂' => 'чоловік, що простягає руку допомоги',
    '💁‍♀' => 'жінка, що простягає руку допомоги',
    '🙋‍♂' => 'чоловік із піднятою рукою',
    '🙋‍♀' => 'жінка з піднятою рукою',
    '🧏‍♂' => 'чоловік із порушенням слуху',
    '🧏‍♀' => 'жінка з порушенням слуху',
    '🙇‍♂' => 'чоловік, що вклоняється',
    '🙇‍♀' => 'жінка, що вклоняється',
    '🤦‍♂' => 'чоловік із долонею до обличчя',
    '🤦‍♀' => 'жінка, що підносить долоню до обличчя',
    '🤷‍♂' => 'чоловік, що знизує плечима',
    '🤷‍♀' => 'жінка, що знизує плечима',
    '🧑‍⚕' => 'медик',
    '👨‍⚕' => 'медичний працівник',
    '👩‍⚕' => 'медична працівниця',
    '🧑‍🎓' => 'слухач',
    '👨‍🎓' => 'студент',
    '👩‍🎓' => 'студентка',
    '🧑‍🏫' => 'освітянин',
    '👨‍🏫' => 'учитель',
    '👩‍🏫' => 'учителька',
    '🧑‍⚖' => 'суддя',
    '👨‍⚖' => 'суддя-чоловік',
    '👩‍⚖' => 'жінка-суддя',
    '🧑‍🌾' => 'селянин',
    '👨‍🌾' => 'фермер',
    '👩‍🌾' => 'фермерка',
    '🧑‍🍳' => 'куховар',
    '👨‍🍳' => 'кухар',
    '👩‍🍳' => 'кухарка',
    '🧑‍🔧' => 'фахівець із механіки',
    '👨‍🔧' => 'механік',
    '👩‍🔧' => 'жінка-механік',
    '🧑‍🏭' => 'фабричний працівник',
    '👨‍🏭' => 'робітник',
    '👩‍🏭' => 'робітниця',
    '🧑‍💼' => 'офісний працівник',
    '👨‍💼' => 'службовець',
    '👩‍💼' => 'службовка',
    '🧑‍🔬' => 'науковий працівник',
    '👨‍🔬' => 'науковець',
    '👩‍🔬' => 'жінка-науковець',
    '🧑‍💻' => 'технічний працівник',
    '👨‍💻' => 'технолог',
    '👩‍💻' => 'жінка-технолог',
    '🧑‍🎤' => 'вокаліст',
    '👨‍🎤' => 'співак',
    '👩‍🎤' => 'співачка',
    '🧑‍🎨' => 'художник',
    '👨‍🎨' => 'чоловік-художник',
    '👩‍🎨' => 'художниця',
    '🧑‍✈' => 'авіапілот',
    '👨‍✈' => 'пілот',
    '👩‍✈' => 'жінка-пілот',
    '🧑‍🚀' => 'космонавт',
    '👨‍🚀' => 'астронавт',
    '👩‍🚀' => 'астронавтка',
    '🧑‍🚒' => 'вогнеборець',
    '👨‍🚒' => 'пожежник',
    '👩‍🚒' => 'жінка-пожежник',
    '👮‍♂' => 'поліцейський',
    '👮‍♀' => 'жінка-поліцейський',
    '🕵‍♂' => 'чоловік-детектив',
    '🕵‍♀' => 'жінка-детектив',
    '💂‍♂' => 'вартовий',
    '💂‍♀' => 'вартова',
    '👷‍♂' => 'чоловік-будівельник',
    '👷‍♀' => 'жінка-будівельник',
    '👳‍♂' => 'чоловік у тюрбані',
    '👳‍♀' => 'жінка в тюрбані',
    '🤵‍♂' => 'чоловік у смокінгу',
    '🤵‍♀' => 'жінка в смокінгу',
    '👰‍♂' => 'чоловік у фаті',
    '👰‍♀' => 'жінка у фаті',
    '👩‍🍼' => 'жінка годує дитину',
    '👨‍🍼' => 'чоловік годує дитину',
    '🧑‍🍼' => 'людина годує дитину',
    '🧑‍🎄' => 'Мікс Клаус',
    '🦸‍♂' => 'чоловік-супергерой',
    '🦸‍♀' => 'жінка-супергерой',
    '🦹‍♂' => 'суперлиходій',
    '🦹‍♀' => 'суперлиходійка',
    '🧙‍♂' => 'чаклун',
    '🧙‍♀' => 'чаклунка',
    '🧚‍♂' => 'чоловік-фея',
    '🧚‍♀' => 'жінка-фея',
    '🧛‍♂' => 'чоловік-вампір',
    '🧛‍♀' => 'жінка-вампір',
    '🧜‍♂' => 'чоловік-русалка',
    '🧜‍♀' => 'русалка',
    '🧝‍♂' => 'чоловік-ельф',
    '🧝‍♀' => 'жінка-ельф',
    '🧞‍♂' => 'чоловік-джин',
    '🧞‍♀' => 'жінка-джин',
    '🧟‍♂' => 'чоловік-зомбі',
    '🧟‍♀' => 'жінка-зомбі',
    '💆‍♂' => 'чоловік, якому роблять масаж голови',
    '💆‍♀' => 'жінка, якій роблять масаж голови',
    '💇‍♂' => 'чоловік, якому роблять стрижку',
    '💇‍♀' => 'жінка, якій роблять стрижку',
    '🚶‍♂' => 'чоловік, що йде пішки',
    '🚶‍♀' => 'жінка, що йде пішки',
    '🧍‍♂' => 'чоловік, що стоїть',
    '🧍‍♀' => 'жінка, що стоїть',
    '🧎‍♂' => 'чоловік навколішках',
    '🧎‍♀' => 'жінка навколішках',
    '🧑‍🦯' => 'людина з тактильним ціпком',
    '👨‍🦯' => 'чоловік із тактильною тростиною',
    '👩‍🦯' => 'жінка з тактильною тростиною',
    '🧑‍🦼' => 'людина на моторизованому візку',
    '👨‍🦼' => 'чоловік у візку з електроприводом',
    '👩‍🦼' => 'жінка у візку з електроприводом',
    '🧑‍🦽' => 'людина у візку з ручним керуванням',
    '👨‍🦽' => 'чоловік у візку з ручним приводом',
    '👩‍🦽' => 'жінка у візку з ручним приводом',
    '🏃‍♂' => 'чоловік, що біжить',
    '🏃‍♀' => 'жінка, що біжить',
    '🧑‍🩰' => 'танцівник балету',
    '👯‍♂' => 'чоловіки з кролячими вухами',
    '👯‍♀' => 'жінки з кролячими вухами',
    '🧖‍♂' => 'чоловік у паркому приміщенні',
    '🧖‍♀' => 'жінка в паркому приміщенні',
    '🧗‍♂' => 'чоловік-скелелаз',
    '🧗‍♀' => 'жінка-скелелаз',
    '🏌‍♂' => 'гольфіст',
    '🏌‍♀' => 'гольфістка',
    '🏄‍♂' => 'серфінгіст',
    '🏄‍♀' => 'серфінгістка',
    '🚣‍♂' => 'чоловік, що веслує на човні',
    '🚣‍♀' => 'жінка, що веслує на човні',
    '🏊‍♂' => 'плавець',
    '🏊‍♀' => 'плавчиня',
    '⛹‍♂' => 'чоловік, що веде мʼяч',
    '⛹‍♀' => 'жінка, що веде мʼяч',
    '🏋‍♂' => 'штангіст',
    '🏋‍♀' => 'штангістка',
    '🚴‍♂' => 'велосипедист',
    '🚴‍♀' => 'велосипедистка',
    '🚵‍♂' => 'гірський велосипедист',
    '🚵‍♀' => 'гірська велосипедистка',
    '🤸‍♂' => 'чоловік, що перевертається «колесом»',
    '🤸‍♀' => 'жінка, що перевертається «колесом»',
    '🤼‍♂' => 'борець',
    '🤼‍♀' => 'борчиня',
    '🤽‍♂' => 'ватерполіст',
    '🤽‍♀' => 'ватерполістка',
    '🤾‍♂' => 'гандболіст',
    '🤾‍♀' => 'гандболістка',
    '🤹‍♂' => 'жонглер',
    '🤹‍♀' => 'жонглерка',
    '🧘‍♂' => 'чоловік у позі лотоса',
    '🧘‍♀' => 'жінка в позі лотоса',
    '🧑‍🧒' => 'родина: дорослий і дитина',
    '🐕‍🦺' => 'службовий собака',
    '🐈‍⬛' => 'чорний кіт',
    '🐻‍❄' => 'полярний ведмідь',
    '🐦‍⬛' => 'чорний птах',
    '🐦‍🔥' => 'фенікс',
    '🍋‍🟩' => 'лайм',
    '🍄‍🟫' => 'коричневий гриб',
    '⛓‍💥' => 'розірваний ланцюг',
    '🏳‍🌈' => 'веселковий прапор',
    '🏳‍⚧' => 'прапор трансгендерів',
    '🏴‍☠' => 'піратський прапор',
    '👋🏻' => 'рука махає: світлий тон шкіри',
    '👋🏼' => 'рука махає: помірно світлий тон шкіри',
    '👋🏽' => 'рука махає: помірний тон шкіри',
    '👋🏾' => 'рука махає: помірно темний тон шкіри',
    '👋🏿' => 'рука махає: темний тон шкіри',
    '🤚🏻' => 'піднята рука тильною стороною: світлий тон шкіри',
    '🤚🏼' => 'піднята рука тильною стороною: помірно світлий тон шкіри',
    '🤚🏽' => 'піднята рука тильною стороною: помірний тон шкіри',
    '🤚🏾' => 'піднята рука тильною стороною: помірно темний тон шкіри',
    '🤚🏿' => 'піднята рука тильною стороною: темний тон шкіри',
    '🖐🏻' => 'піднята рука з розведеними пальцями: світлий тон шкіри',
    '🖐🏼' => 'піднята рука з розведеними пальцями: помірно світлий тон шкіри',
    '🖐🏽' => 'піднята рука з розведеними пальцями: помірний тон шкіри',
    '🖐🏾' => 'піднята рука з розведеними пальцями: помірно темний тон шкіри',
    '🖐🏿' => 'піднята рука з розведеними пальцями: темний тон шкіри',
    '✋🏻' => 'піднята рука: світлий тон шкіри',
    '✋🏼' => 'піднята рука: помірно світлий тон шкіри',
    '✋🏽' => 'піднята рука: помірний тон шкіри',
    '✋🏾' => 'піднята рука: помірно темний тон шкіри',
    '✋🏿' => 'піднята рука: темний тон шкіри',
    '🖖🏻' => 'вулканське вітання: світлий тон шкіри',
    '🖖🏼' => 'вулканське вітання: помірно світлий тон шкіри',
    '🖖🏽' => 'вулканське вітання: помірний тон шкіри',
    '🖖🏾' => 'вулканське вітання: помірно темний тон шкіри',
    '🖖🏿' => 'вулканське вітання: темний тон шкіри',
    '🫱🏻' => 'долоня вправо: світлий тон шкіри',
    '🫱🏼' => 'долоня вправо: помірно світлий тон шкіри',
    '🫱🏽' => 'долоня вправо: помірний тон шкіри',
    '🫱🏾' => 'долоня вправо: помірно темний тон шкіри',
    '🫱🏿' => 'долоня вправо: темний тон шкіри',
    '🫲🏻' => 'долоня вліво: світлий тон шкіри',
    '🫲🏼' => 'долоня вліво: помірно світлий тон шкіри',
    '🫲🏽' => 'долоня вліво: помірний тон шкіри',
    '🫲🏾' => 'долоня вліво: помірно темний тон шкіри',
    '🫲🏿' => 'долоня вліво: темний тон шкіри',
    '🫳🏻' => 'рука долонею вниз: світлий тон шкіри',
    '🫳🏼' => 'рука долонею вниз: помірно світлий тон шкіри',
    '🫳🏽' => 'рука долонею вниз: помірний тон шкіри',
    '🫳🏾' => 'рука долонею вниз: помірно темний тон шкіри',
    '🫳🏿' => 'рука долонею вниз: темний тон шкіри',
    '🫴🏻' => 'рука долонею вгору: світлий тон шкіри',
    '🫴🏼' => 'рука долонею вгору: помірно світлий тон шкіри',
    '🫴🏽' => 'рука долонею вгору: помірний тон шкіри',
    '🫴🏾' => 'рука долонею вгору: помірно темний тон шкіри',
    '🫴🏿' => 'рука долонею вгору: темний тон шкіри',
    '🫷🏻' => 'долоня штовхає вліво: світлий тон шкіри',
    '🫷🏼' => 'долоня штовхає вліво: помірно світлий тон шкіри',
    '🫷🏽' => 'долоня штовхає вліво: помірний тон шкіри',
    '🫷🏾' => 'долоня штовхає вліво: помірно темний тон шкіри',
    '🫷🏿' => 'долоня штовхає вліво: темний тон шкіри',
    '🫸🏻' => 'долоня штовхає вправо: світлий тон шкіри',
    '🫸🏼' => 'долоня штовхає вправо: помірно світлий тон шкіри',
    '🫸🏽' => 'долоня штовхає вправо: помірний тон шкіри',
    '🫸🏾' => 'долоня штовхає вправо: помірно темний тон шкіри',
    '🫸🏿' => 'долоня штовхає вправо: темний тон шкіри',
    '👌🏻' => 'жест «окей»: світлий тон шкіри',
    '👌🏼' => 'жест «окей»: помірно світлий тон шкіри',
    '👌🏽' => 'жест «окей»: помірний тон шкіри',
    '👌🏾' => 'жест «окей»: помірно темний тон шкіри',
    '👌🏿' => 'жест «окей»: темний тон шкіри',
    '🤌🏻' => 'зведені пальці: світлий тон шкіри',
    '🤌🏼' => 'зведені пальці: помірно світлий тон шкіри',
    '🤌🏽' => 'зведені пальці: помірний тон шкіри',
    '🤌🏾' => 'зведені пальці: помірно темний тон шкіри',
    '🤌🏿' => 'зведені пальці: темний тон шкіри',
    '🤏🏻' => 'жест «мало»: світлий тон шкіри',
    '🤏🏼' => 'жест «мало»: помірно світлий тон шкіри',
    '🤏🏽' => 'жест «мало»: помірний тон шкіри',
    '🤏🏾' => 'жест «мало»: помірно темний тон шкіри',
    '🤏🏿' => 'жест «мало»: темний тон шкіри',
    '✌🏻' => 'жест перемоги: світлий тон шкіри',
    '✌🏼' => 'жест перемоги: помірно світлий тон шкіри',
    '✌🏽' => 'жест перемоги: помірний тон шкіри',
    '✌🏾' => 'жест перемоги: помірно темний тон шкіри',
    '✌🏿' => 'жест перемоги: темний тон шкіри',
    '🤞🏻' => 'схрещені пальці: світлий тон шкіри',
    '🤞🏼' => 'схрещені пальці: помірно світлий тон шкіри',
    '🤞🏽' => 'схрещені пальці: помірний тон шкіри',
    '🤞🏾' => 'схрещені пальці: помірно темний тон шкіри',
    '🤞🏿' => 'схрещені пальці: темний тон шкіри',
    '🫰🏻' => 'клацання пальцями: світлий тон шкіри',
    '🫰🏼' => 'клацання пальцями: помірно світлий тон шкіри',
    '🫰🏽' => 'клацання пальцями: помірний тон шкіри',
    '🫰🏾' => 'клацання пальцями: помірно темний тон шкіри',
    '🫰🏿' => 'клацання пальцями: темний тон шкіри',
    '🤟🏻' => 'жест «кохаю тебе»: світлий тон шкіри',
    '🤟🏼' => 'жест «кохаю тебе»: помірно світлий тон шкіри',
    '🤟🏽' => 'жест «кохаю тебе»: помірний тон шкіри',
    '🤟🏾' => 'жест «кохаю тебе»: помірно темний тон шкіри',
    '🤟🏿' => 'жест «кохаю тебе»: темний тон шкіри',
    '🤘🏻' => 'жест «роги»: світлий тон шкіри',
    '🤘🏼' => 'жест «роги»: помірно світлий тон шкіри',
    '🤘🏽' => 'жест «роги»: помірний тон шкіри',
    '🤘🏾' => 'жест «роги»: помірно темний тон шкіри',
    '🤘🏿' => 'жест «роги»: темний тон шкіри',
    '🤙🏻' => 'жест «подзвони мені»: світлий тон шкіри',
    '🤙🏼' => 'жест «подзвони мені»: помірно світлий тон шкіри',
    '🤙🏽' => 'жест «подзвони мені»: помірний тон шкіри',
    '🤙🏾' => 'жест «подзвони мені»: помірно темний тон шкіри',
    '🤙🏿' => 'жест «подзвони мені»: темний тон шкіри',
    '👈🏻' => 'палець тильним боком, що вказує вліво: світлий тон шкіри',
    '👈🏼' => 'палець тильним боком, що вказує вліво: помірно світлий тон шкіри',
    '👈🏽' => 'палець тильним боком, що вказує вліво: помірний тон шкіри',
    '👈🏾' => 'палець тильним боком, що вказує вліво: помірно темний тон шкіри',
    '👈🏿' => 'палець тильним боком, що вказує вліво: темний тон шкіри',
    '👉🏻' => 'палець тильним боком, що вказує вправо: світлий тон шкіри',
    '👉🏼' => 'палець тильним боком, що вказує вправо: помірно світлий тон шкіри',
    '👉🏽' => 'палець тильним боком, що вказує вправо: помірний тон шкіри',
    '👉🏾' => 'палець тильним боком, що вказує вправо: помірно темний тон шкіри',
    '👉🏿' => 'палець тильним боком, що вказує вправо: темний тон шкіри',
    '👆🏻' => 'палець тильним боком, що вказує вгору: світлий тон шкіри',
    '👆🏼' => 'палець тильним боком, що вказує вгору: помірно світлий тон шкіри',
    '👆🏽' => 'палець тильним боком, що вказує вгору: помірний тон шкіри',
    '👆🏾' => 'палець тильним боком, що вказує вгору: помірно темний тон шкіри',
    '👆🏿' => 'палець тильним боком, що вказує вгору: темний тон шкіри',
    '🖕🏻' => 'середній палець: світлий тон шкіри',
    '🖕🏼' => 'середній палець: помірно світлий тон шкіри',
    '🖕🏽' => 'середній палець: помірний тон шкіри',
    '🖕🏾' => 'середній палець: помірно темний тон шкіри',
    '🖕🏿' => 'середній палець: темний тон шкіри',
    '👇🏻' => 'палець тильним боком, що вказує вниз: світлий тон шкіри',
    '👇🏼' => 'палець тильним боком, що вказує вниз: помірно світлий тон шкіри',
    '👇🏽' => 'палець тильним боком, що вказує вниз: помірний тон шкіри',
    '👇🏾' => 'палець тильним боком, що вказує вниз: помірно темний тон шкіри',
    '👇🏿' => 'палець тильним боком, що вказує вниз: темний тон шкіри',
    '☝🏻' => 'вказівний палець, що вказує вгору: світлий тон шкіри',
    '☝🏼' => 'вказівний палець, що вказує вгору: помірно світлий тон шкіри',
    '☝🏽' => 'вказівний палець, що вказує вгору: помірний тон шкіри',
    '☝🏾' => 'вказівний палець, що вказує вгору: помірно темний тон шкіри',
    '☝🏿' => 'вказівний палець, що вказує вгору: темний тон шкіри',
    '🫵🏻' => 'вказівний палець, що вказує на глядача: світлий тон шкіри',
    '🫵🏼' => 'вказівний палець, що вказує на глядача: помірно світлий тон шкіри',
    '🫵🏽' => 'вказівний палець, що вказує на глядача: помірний тон шкіри',
    '🫵🏾' => 'вказівний палець, що вказує на глядача: помірно темний тон шкіри',
    '🫵🏿' => 'вказівний палець, що вказує на глядача: темний тон шкіри',
    '👍🏻' => 'великі пальці вгору: світлий тон шкіри',
    '👍🏼' => 'великі пальці вгору: помірно світлий тон шкіри',
    '👍🏽' => 'великі пальці вгору: помірний тон шкіри',
    '👍🏾' => 'великі пальці вгору: помірно темний тон шкіри',
    '👍🏿' => 'великі пальці вгору: темний тон шкіри',
    '👎🏻' => 'великі пальці вниз: світлий тон шкіри',
    '👎🏼' => 'великі пальці вниз: помірно світлий тон шкіри',
    '👎🏽' => 'великі пальці вниз: помірний тон шкіри',
    '👎🏾' => 'великі пальці вниз: помірно темний тон шкіри',
    '👎🏿' => 'великі пальці вниз: темний тон шкіри',
    '✊🏻' => 'піднятий кулак: світлий тон шкіри',
    '✊🏼' => 'піднятий кулак: помірно світлий тон шкіри',
    '✊🏽' => 'піднятий кулак: помірний тон шкіри',
    '✊🏾' => 'піднятий кулак: помірно темний тон шкіри',
    '✊🏿' => 'піднятий кулак: темний тон шкіри',
    '👊🏻' => 'кулак, що насувається: світлий тон шкіри',
    '👊🏼' => 'кулак, що насувається: помірно світлий тон шкіри',
    '👊🏽' => 'кулак, що насувається: помірний тон шкіри',
    '👊🏾' => 'кулак, що насувається: помірно темний тон шкіри',
    '👊🏿' => 'кулак, що насувається: темний тон шкіри',
    '🤛🏻' => 'кулак уліво: світлий тон шкіри',
    '🤛🏼' => 'кулак уліво: помірно світлий тон шкіри',
    '🤛🏽' => 'кулак уліво: помірний тон шкіри',
    '🤛🏾' => 'кулак уліво: помірно темний тон шкіри',
    '🤛🏿' => 'кулак уліво: темний тон шкіри',
    '🤜🏻' => 'кулак управо: світлий тон шкіри',
    '🤜🏼' => 'кулак управо: помірно світлий тон шкіри',
    '🤜🏽' => 'кулак управо: помірний тон шкіри',
    '🤜🏾' => 'кулак управо: помірно темний тон шкіри',
    '🤜🏿' => 'кулак управо: темний тон шкіри',
    '👏🏻' => 'руки, що аплодують: світлий тон шкіри',
    '👏🏼' => 'руки, що аплодують: помірно світлий тон шкіри',
    '👏🏽' => 'руки, що аплодують: помірний тон шкіри',
    '👏🏾' => 'руки, що аплодують: помірно темний тон шкіри',
    '👏🏿' => 'руки, що аплодують: темний тон шкіри',
    '🙌🏻' => 'руки, підняті для святкування: світлий тон шкіри',
    '🙌🏼' => 'руки, підняті для святкування: помірно світлий тон шкіри',
    '🙌🏽' => 'руки, підняті для святкування: помірний тон шкіри',
    '🙌🏾' => 'руки, підняті для святкування: помірно темний тон шкіри',
    '🙌🏿' => 'руки, підняті для святкування: темний тон шкіри',
    '🫶🏻' => 'жест «серце»: світлий тон шкіри',
    '🫶🏼' => 'жест «серце»: помірно світлий тон шкіри',
    '🫶🏽' => 'жест «серце»: помірний тон шкіри',
    '🫶🏾' => 'жест «серце»: помірно темний тон шкіри',
    '🫶🏿' => 'жест «серце»: темний тон шкіри',
    '👐🏻' => 'відкриті долоні: світлий тон шкіри',
    '👐🏼' => 'відкриті долоні: помірно світлий тон шкіри',
    '👐🏽' => 'відкриті долоні: помірний тон шкіри',
    '👐🏾' => 'відкриті долоні: помірно темний тон шкіри',
    '👐🏿' => 'відкриті долоні: темний тон шкіри',
    '🤲🏻' => 'долоні, підняті разом: світлий тон шкіри',
    '🤲🏼' => 'долоні, підняті разом: помірно світлий тон шкіри',
    '🤲🏽' => 'долоні, підняті разом: помірний тон шкіри',
    '🤲🏾' => 'долоні, підняті разом: помірно темний тон шкіри',
    '🤲🏿' => 'долоні, підняті разом: темний тон шкіри',
    '🤝🏻' => 'рукостискання: світлий тон шкіри',
    '🤝🏼' => 'рукостискання: помірно світлий тон шкіри',
    '🤝🏽' => 'рукостискання: помірний тон шкіри',
    '🤝🏾' => 'рукостискання: помірно темний тон шкіри',
    '🤝🏿' => 'рукостискання: темний тон шкіри',
    '🙏🏻' => 'руки, стиснуті разом: світлий тон шкіри',
    '🙏🏼' => 'руки, стиснуті разом: помірно світлий тон шкіри',
    '🙏🏽' => 'руки, стиснуті разом: помірний тон шкіри',
    '🙏🏾' => 'руки, стиснуті разом: помірно темний тон шкіри',
    '🙏🏿' => 'руки, стиснуті разом: темний тон шкіри',
    '✍🏻' => 'рука, що пише: світлий тон шкіри',
    '✍🏼' => 'рука, що пише: помірно світлий тон шкіри',
    '✍🏽' => 'рука, що пише: помірний тон шкіри',
    '✍🏾' => 'рука, що пише: помірно темний тон шкіри',
    '✍🏿' => 'рука, що пише: темний тон шкіри',
    '💅🏻' => 'лак для нігтів: світлий тон шкіри',
    '💅🏼' => 'лак для нігтів: помірно світлий тон шкіри',
    '💅🏽' => 'лак для нігтів: помірний тон шкіри',
    '💅🏾' => 'лак для нігтів: помірно темний тон шкіри',
    '💅🏿' => 'лак для нігтів: темний тон шкіри',
    '🤳🏻' => 'селфі: світлий тон шкіри',
    '🤳🏼' => 'селфі: помірно світлий тон шкіри',
    '🤳🏽' => 'селфі: помірний тон шкіри',
    '🤳🏾' => 'селфі: помірно темний тон шкіри',
    '🤳🏿' => 'селфі: темний тон шкіри',
    '💪🏻' => 'напружений біцепс: світлий тон шкіри',
    '💪🏼' => 'напружений біцепс: помірно світлий тон шкіри',
    '💪🏽' => 'напружений біцепс: помірний тон шкіри',
    '💪🏾' => 'напружений біцепс: помірно темний тон шкіри',
    '💪🏿' => 'напружений біцепс: темний тон шкіри',
    '🦵🏻' => 'нога: світлий тон шкіри',
    '🦵🏼' => 'нога: помірно світлий тон шкіри',
    '🦵🏽' => 'нога: помірний тон шкіри',
    '🦵🏾' => 'нога: помірно темний тон шкіри',
    '🦵🏿' => 'нога: темний тон шкіри',
    '🦶🏻' => 'ступня: світлий тон шкіри',
    '🦶🏼' => 'ступня: помірно світлий тон шкіри',
    '🦶🏽' => 'ступня: помірний тон шкіри',
    '🦶🏾' => 'ступня: помірно темний тон шкіри',
    '🦶🏿' => 'ступня: темний тон шкіри',
    '👂🏻' => 'вухо: світлий тон шкіри',
    '👂🏼' => 'вухо: помірно світлий тон шкіри',
    '👂🏽' => 'вухо: помірний тон шкіри',
    '👂🏾' => 'вухо: помірно темний тон шкіри',
    '👂🏿' => 'вухо: темний тон шкіри',
    '🦻🏻' => 'вухо зі слуховим апаратом: світлий тон шкіри',
    '🦻🏼' => 'вухо зі слуховим апаратом: помірно світлий тон шкіри',
    '🦻🏽' => 'вухо зі слуховим апаратом: помірний тон шкіри',
    '🦻🏾' => 'вухо зі слуховим апаратом: помірно темний тон шкіри',
    '🦻🏿' => 'вухо зі слуховим апаратом: темний тон шкіри',
    '👃🏻' => 'ніс: світлий тон шкіри',
    '👃🏼' => 'ніс: помірно світлий тон шкіри',
    '👃🏽' => 'ніс: помірний тон шкіри',
    '👃🏾' => 'ніс: помірно темний тон шкіри',
    '👃🏿' => 'ніс: темний тон шкіри',
    '👶🏻' => 'немовля: світлий тон шкіри',
    '👶🏼' => 'немовля: помірно світлий тон шкіри',
    '👶🏽' => 'немовля: помірний тон шкіри',
    '👶🏾' => 'немовля: помірно темний тон шкіри',
    '👶🏿' => 'немовля: темний тон шкіри',
    '🧒🏻' => 'дитина: світлий тон шкіри',
    '🧒🏼' => 'дитина: помірно світлий тон шкіри',
    '🧒🏽' => 'дитина: помірний тон шкіри',
    '🧒🏾' => 'дитина: помірно темний тон шкіри',
    '🧒🏿' => 'дитина: темний тон шкіри',
    '👦🏻' => 'хлопчик: світлий тон шкіри',
    '👦🏼' => 'хлопчик: помірно світлий тон шкіри',
    '👦🏽' => 'хлопчик: помірний тон шкіри',
    '👦🏾' => 'хлопчик: помірно темний тон шкіри',
    '👦🏿' => 'хлопчик: темний тон шкіри',
    '👧🏻' => 'дівчинка: світлий тон шкіри',
    '👧🏼' => 'дівчинка: помірно світлий тон шкіри',
    '👧🏽' => 'дівчинка: помірний тон шкіри',
    '👧🏾' => 'дівчинка: помірно темний тон шкіри',
    '👧🏿' => 'дівчинка: темний тон шкіри',
    '🧑🏻' => 'людина: світлий тон шкіри',
    '🧑🏼' => 'людина: помірно світлий тон шкіри',
    '🧑🏽' => 'людина: помірний тон шкіри',
    '🧑🏾' => 'людина: помірно темний тон шкіри',
    '🧑🏿' => 'людина: темний тон шкіри',
    '👱🏻' => 'людина з білявим волоссям: світлий тон шкіри',
    '👱🏼' => 'людина з білявим волоссям: помірно світлий тон шкіри',
    '👱🏽' => 'людина з білявим волоссям: помірний тон шкіри',
    '👱🏾' => 'людина з білявим волоссям: помірно темний тон шкіри',
    '👱🏿' => 'людина з білявим волоссям: темний тон шкіри',
    '👨🏻' => 'чоловік: світлий тон шкіри',
    '👨🏼' => 'чоловік: помірно світлий тон шкіри',
    '👨🏽' => 'чоловік: помірний тон шкіри',
    '👨🏾' => 'чоловік: помірно темний тон шкіри',
    '👨🏿' => 'чоловік: темний тон шкіри',
    '🧔🏻' => 'людина з бородою: світлий тон шкіри',
    '🧔🏼' => 'людина з бородою: помірно світлий тон шкіри',
    '🧔🏽' => 'людина з бородою: помірний тон шкіри',
    '🧔🏾' => 'людина з бородою: помірно темний тон шкіри',
    '🧔🏿' => 'людина з бородою: темний тон шкіри',
    '👩🏻' => 'жінка: світлий тон шкіри',
    '👩🏼' => 'жінка: помірно світлий тон шкіри',
    '👩🏽' => 'жінка: помірний тон шкіри',
    '👩🏾' => 'жінка: помірно темний тон шкіри',
    '👩🏿' => 'жінка: темний тон шкіри',
    '🧓🏻' => 'літня людина: світлий тон шкіри',
    '🧓🏼' => 'літня людина: помірно світлий тон шкіри',
    '🧓🏽' => 'літня людина: помірний тон шкіри',
    '🧓🏾' => 'літня людина: помірно темний тон шкіри',
    '🧓🏿' => 'літня людина: темний тон шкіри',
    '👴🏻' => 'літній чоловік: світлий тон шкіри',
    '👴🏼' => 'літній чоловік: помірно світлий тон шкіри',
    '👴🏽' => 'літній чоловік: помірний тон шкіри',
    '👴🏾' => 'літній чоловік: помірно темний тон шкіри',
    '👴🏿' => 'літній чоловік: темний тон шкіри',
    '👵🏻' => 'літня жінка: світлий тон шкіри',
    '👵🏼' => 'літня жінка: помірно світлий тон шкіри',
    '👵🏽' => 'літня жінка: помірний тон шкіри',
    '👵🏾' => 'літня жінка: помірно темний тон шкіри',
    '👵🏿' => 'літня жінка: темний тон шкіри',
    '🙍🏻' => 'похмура людина: світлий тон шкіри',
    '🙍🏼' => 'похмура людина: помірно світлий тон шкіри',
    '🙍🏽' => 'похмура людина: помірний тон шкіри',
    '🙍🏾' => 'похмура людина: помірно темний тон шкіри',
    '🙍🏿' => 'похмура людина: темний тон шкіри',
    '🙎🏻' => 'людина, що дується: світлий тон шкіри',
    '🙎🏼' => 'людина, що дується: помірно світлий тон шкіри',
    '🙎🏽' => 'людина, що дується: помірний тон шкіри',
    '🙎🏾' => 'людина, що дується: помірно темний тон шкіри',
    '🙎🏿' => 'людина, що дується: темний тон шкіри',
    '🙅🏻' => 'людина, що жестом показує «ні»: світлий тон шкіри',
    '🙅🏼' => 'людина, що жестом показує «ні»: помірно світлий тон шкіри',
    '🙅🏽' => 'людина, що жестом показує «ні»: помірний тон шкіри',
    '🙅🏾' => 'людина, що жестом показує «ні»: помірно темний тон шкіри',
    '🙅🏿' => 'людина, що жестом показує «ні»: темний тон шкіри',
    '🙆🏻' => 'людина, що жестом показує «окей»: світлий тон шкіри',
    '🙆🏼' => 'людина, що жестом показує «окей»: помірно світлий тон шкіри',
    '🙆🏽' => 'людина, що жестом показує «окей»: помірний тон шкіри',
    '🙆🏾' => 'людина, що жестом показує «окей»: помірно темний тон шкіри',
    '🙆🏿' => 'людина, що жестом показує «окей»: темний тон шкіри',
    '💁🏻' => 'людина, що простягає руку допомоги: світлий тон шкіри',
    '💁🏼' => 'людина, що простягає руку допомоги: помірно світлий тон шкіри',
    '💁🏽' => 'людина, що простягає руку допомоги: помірний тон шкіри',
    '💁🏾' => 'людина, що простягає руку допомоги: помірно темний тон шкіри',
    '💁🏿' => 'людина, що простягає руку допомоги: темний тон шкіри',
    '🙋🏻' => 'людина з піднятою рукою: світлий тон шкіри',
    '🙋🏼' => 'людина з піднятою рукою: помірно світлий тон шкіри',
    '🙋🏽' => 'людина з піднятою рукою: помірний тон шкіри',
    '🙋🏾' => 'людина з піднятою рукою: помірно темний тон шкіри',
    '🙋🏿' => 'людина з піднятою рукою: темний тон шкіри',
    '🧏🏻' => 'людина з порушенням слуху: світлий тон шкіри',
    '🧏🏼' => 'людина з порушенням слуху: помірно світлий тон шкіри',
    '🧏🏽' => 'людина з порушенням слуху: помірний тон шкіри',
    '🧏🏾' => 'людина з порушенням слуху: помірно темний тон шкіри',
    '🧏🏿' => 'людина з порушенням слуху: темний тон шкіри',
    '🙇🏻' => 'людина, що вклоняється: світлий тон шкіри',
    '🙇🏼' => 'людина, що вклоняється: помірно світлий тон шкіри',
    '🙇🏽' => 'людина, що вклоняється: помірний тон шкіри',
    '🙇🏾' => 'людина, що вклоняється: помірно темний тон шкіри',
    '🙇🏿' => 'людина, що вклоняється: темний тон шкіри',
    '🤦🏻' => 'людина з долонею до обличчя: світлий тон шкіри',
    '🤦🏼' => 'людина з долонею до обличчя: помірно світлий тон шкіри',
    '🤦🏽' => 'людина з долонею до обличчя: помірний тон шкіри',
    '🤦🏾' => 'людина з долонею до обличчя: помірно темний тон шкіри',
    '🤦🏿' => 'людина з долонею до обличчя: темний тон шкіри',
    '🤷🏻' => 'людина, що знизує плечима: світлий тон шкіри',
    '🤷🏼' => 'людина, що знизує плечима: помірно світлий тон шкіри',
    '🤷🏽' => 'людина, що знизує плечима: помірний тон шкіри',
    '🤷🏾' => 'людина, що знизує плечима: помірно темний тон шкіри',
    '🤷🏿' => 'людина, що знизує плечима: темний тон шкіри',
    '👮🏻' => 'працівник поліції: світлий тон шкіри',
    '👮🏼' => 'працівник поліції: помірно світлий тон шкіри',
    '👮🏽' => 'працівник поліції: помірний тон шкіри',
    '👮🏾' => 'працівник поліції: помірно темний тон шкіри',
    '👮🏿' => 'працівник поліції: темний тон шкіри',
    '🕵🏻' => 'детектив: світлий тон шкіри',
    '🕵🏼' => 'детектив: помірно світлий тон шкіри',
    '🕵🏽' => 'детектив: помірний тон шкіри',
    '🕵🏾' => 'детектив: помірно темний тон шкіри',
    '🕵🏿' => 'детектив: темний тон шкіри',
    '💂🏻' => 'варта: світлий тон шкіри',
    '💂🏼' => 'варта: помірно світлий тон шкіри',
    '💂🏽' => 'варта: помірний тон шкіри',
    '💂🏾' => 'варта: помірно темний тон шкіри',
    '💂🏿' => 'варта: темний тон шкіри',
    '🥷🏻' => 'ніндзя: світлий тон шкіри',
    '🥷🏼' => 'ніндзя: помірно світлий тон шкіри',
    '🥷🏽' => 'ніндзя: помірний тон шкіри',
    '🥷🏾' => 'ніндзя: помірно темний тон шкіри',
    '🥷🏿' => 'ніндзя: темний тон шкіри',
    '👷🏻' => 'будівельник: світлий тон шкіри',
    '👷🏼' => 'будівельник: помірно світлий тон шкіри',
    '👷🏽' => 'будівельник: помірний тон шкіри',
    '👷🏾' => 'будівельник: помірно темний тон шкіри',
    '👷🏿' => 'будівельник: темний тон шкіри',
    '🫅🏻' => 'людина з короною на голові: світлий тон шкіри',
    '🫅🏼' => 'людина з короною на голові: помірно світлий тон шкіри',
    '🫅🏽' => 'людина з короною на голові: помірний тон шкіри',
    '🫅🏾' => 'людина з короною на голові: помірно темний тон шкіри',
    '🫅🏿' => 'людина з короною на голові: темний тон шкіри',
    '🤴🏻' => 'принц: світлий тон шкіри',
    '🤴🏼' => 'принц: помірно світлий тон шкіри',
    '🤴🏽' => 'принц: помірний тон шкіри',
    '🤴🏾' => 'принц: помірно темний тон шкіри',
    '🤴🏿' => 'принц: темний тон шкіри',
    '👸🏻' => 'принцеса: світлий тон шкіри',
    '👸🏼' => 'принцеса: помірно світлий тон шкіри',
    '👸🏽' => 'принцеса: помірний тон шкіри',
    '👸🏾' => 'принцеса: помірно темний тон шкіри',
    '👸🏿' => 'принцеса: темний тон шкіри',
    '👳🏻' => 'людина в тюрбані: світлий тон шкіри',
    '👳🏼' => 'людина в тюрбані: помірно світлий тон шкіри',
    '👳🏽' => 'людина в тюрбані: помірний тон шкіри',
    '👳🏾' => 'людина в тюрбані: помірно темний тон шкіри',
    '👳🏿' => 'людина в тюрбані: темний тон шкіри',
    '👲🏻' => 'чоловік у китайській шапці: світлий тон шкіри',
    '👲🏼' => 'чоловік у китайській шапці: помірно світлий тон шкіри',
    '👲🏽' => 'чоловік у китайській шапці: помірний тон шкіри',
    '👲🏾' => 'чоловік у китайській шапці: помірно темний тон шкіри',
    '👲🏿' => 'чоловік у китайській шапці: темний тон шкіри',
    '🧕🏻' => 'жінка в хустині: світлий тон шкіри',
    '🧕🏼' => 'жінка в хустині: помірно світлий тон шкіри',
    '🧕🏽' => 'жінка в хустині: помірний тон шкіри',
    '🧕🏾' => 'жінка в хустині: помірно темний тон шкіри',
    '🧕🏿' => 'жінка в хустині: темний тон шкіри',
    '🤵🏻' => 'людина в смокінгу: світлий тон шкіри',
    '🤵🏼' => 'людина в смокінгу: помірно світлий тон шкіри',
    '🤵🏽' => 'людина в смокінгу: помірний тон шкіри',
    '🤵🏾' => 'людина в смокінгу: помірно темний тон шкіри',
    '🤵🏿' => 'людина в смокінгу: темний тон шкіри',
    '👰🏻' => 'людина у фаті: світлий тон шкіри',
    '👰🏼' => 'людина у фаті: помірно світлий тон шкіри',
    '👰🏽' => 'людина у фаті: помірний тон шкіри',
    '👰🏾' => 'людина у фаті: помірно темний тон шкіри',
    '👰🏿' => 'людина у фаті: темний тон шкіри',
    '🤰🏻' => 'вагітна жінка: світлий тон шкіри',
    '🤰🏼' => 'вагітна жінка: помірно світлий тон шкіри',
    '🤰🏽' => 'вагітна жінка: помірний тон шкіри',
    '🤰🏾' => 'вагітна жінка: помірно темний тон шкіри',
    '🤰🏿' => 'вагітна жінка: темний тон шкіри',
    '🫃🏻' => 'чоловік із «вагітним» животом: світлий тон шкіри',
    '🫃🏼' => 'чоловік із «вагітним» животом: помірно світлий тон шкіри',
    '🫃🏽' => 'чоловік із «вагітним» животом: помірний тон шкіри',
    '🫃🏾' => 'чоловік із «вагітним» животом: помірно темний тон шкіри',
    '🫃🏿' => 'чоловік із «вагітним» животом: темний тон шкіри',
    '🫄🏻' => 'вагітна людина: світлий тон шкіри',
    '🫄🏼' => 'вагітна людина: помірно світлий тон шкіри',
    '🫄🏽' => 'вагітна людина: помірний тон шкіри',
    '🫄🏾' => 'вагітна людина: помірно темний тон шкіри',
    '🫄🏿' => 'вагітна людина: темний тон шкіри',
    '🤱🏻' => 'грудне вигодовування: світлий тон шкіри',
    '🤱🏼' => 'грудне вигодовування: помірно світлий тон шкіри',
    '🤱🏽' => 'грудне вигодовування: помірний тон шкіри',
    '🤱🏾' => 'грудне вигодовування: помірно темний тон шкіри',
    '🤱🏿' => 'грудне вигодовування: темний тон шкіри',
    '👼🏻' => 'янголятко: світлий тон шкіри',
    '👼🏼' => 'янголятко: помірно світлий тон шкіри',
    '👼🏽' => 'янголятко: помірний тон шкіри',
    '👼🏾' => 'янголятко: помірно темний тон шкіри',
    '👼🏿' => 'янголятко: темний тон шкіри',
    '🎅🏻' => 'Санта Клаус: світлий тон шкіри',
    '🎅🏼' => 'Санта Клаус: помірно світлий тон шкіри',
    '🎅🏽' => 'Санта Клаус: помірний тон шкіри',
    '🎅🏾' => 'Санта Клаус: помірно темний тон шкіри',
    '🎅🏿' => 'Санта Клаус: темний тон шкіри',
    '🤶🏻' => 'Пані Клаус: світлий тон шкіри',
    '🤶🏼' => 'Пані Клаус: помірно світлий тон шкіри',
    '🤶🏽' => 'Пані Клаус: помірний тон шкіри',
    '🤶🏾' => 'Пані Клаус: помірно темний тон шкіри',
    '🤶🏿' => 'Пані Клаус: темний тон шкіри',
    '🦸🏻' => 'супергерой: світлий тон шкіри',
    '🦸🏼' => 'супергерой: помірно світлий тон шкіри',
    '🦸🏽' => 'супергерой: помірний тон шкіри',
    '🦸🏾' => 'супергерой: помірно темний тон шкіри',
    '🦸🏿' => 'супергерой: темний тон шкіри',
    '🦹🏻' => 'суперзлодій: світлий тон шкіри',
    '🦹🏼' => 'суперзлодій: помірно світлий тон шкіри',
    '🦹🏽' => 'суперзлодій: помірний тон шкіри',
    '🦹🏾' => 'суперзлодій: помірно темний тон шкіри',
    '🦹🏿' => 'суперзлодій: темний тон шкіри',
    '🧙🏻' => 'маг: світлий тон шкіри',
    '🧙🏼' => 'маг: помірно світлий тон шкіри',
    '🧙🏽' => 'маг: помірний тон шкіри',
    '🧙🏾' => 'маг: помірно темний тон шкіри',
    '🧙🏿' => 'маг: темний тон шкіри',
    '🧚🏻' => 'фея: світлий тон шкіри',
    '🧚🏼' => 'фея: помірно світлий тон шкіри',
    '🧚🏽' => 'фея: помірний тон шкіри',
    '🧚🏾' => 'фея: помірно темний тон шкіри',
    '🧚🏿' => 'фея: темний тон шкіри',
    '🧛🏻' => 'вампір: світлий тон шкіри',
    '🧛🏼' => 'вампір: помірно світлий тон шкіри',
    '🧛🏽' => 'вампір: помірний тон шкіри',
    '🧛🏾' => 'вампір: помірно темний тон шкіри',
    '🧛🏿' => 'вампір: темний тон шкіри',
    '🧜🏻' => 'казкова водяна істота: світлий тон шкіри',
    '🧜🏼' => 'казкова водяна істота: помірно світлий тон шкіри',
    '🧜🏽' => 'казкова водяна істота: помірний тон шкіри',
    '🧜🏾' => 'казкова водяна істота: помірно темний тон шкіри',
    '🧜🏿' => 'казкова водяна істота: темний тон шкіри',
    '🧝🏻' => 'ельф: світлий тон шкіри',
    '🧝🏼' => 'ельф: помірно світлий тон шкіри',
    '🧝🏽' => 'ельф: помірний тон шкіри',
    '🧝🏾' => 'ельф: помірно темний тон шкіри',
    '🧝🏿' => 'ельф: темний тон шкіри',
    '💆🏻' => 'людина, якій роблять масаж голови: світлий тон шкіри',
    '💆🏼' => 'людина, якій роблять масаж голови: помірно світлий тон шкіри',
    '💆🏽' => 'людина, якій роблять масаж голови: помірний тон шкіри',
    '💆🏾' => 'людина, якій роблять масаж голови: помірно темний тон шкіри',
    '💆🏿' => 'людина, якій роблять масаж голови: темний тон шкіри',
    '💇🏻' => 'людина, якій роблять стрижку: світлий тон шкіри',
    '💇🏼' => 'людина, якій роблять стрижку: помірно світлий тон шкіри',
    '💇🏽' => 'людина, якій роблять стрижку: помірний тон шкіри',
    '💇🏾' => 'людина, якій роблять стрижку: помірно темний тон шкіри',
    '💇🏿' => 'людина, якій роблять стрижку: темний тон шкіри',
    '🚶🏻' => 'людина, що йде пішки: світлий тон шкіри',
    '🚶🏼' => 'людина, що йде пішки: помірно світлий тон шкіри',
    '🚶🏽' => 'людина, що йде пішки: помірний тон шкіри',
    '🚶🏾' => 'людина, що йде пішки: помірно темний тон шкіри',
    '🚶🏿' => 'людина, що йде пішки: темний тон шкіри',
    '🧍🏻' => 'людина, що стоїть: світлий тон шкіри',
    '🧍🏼' => 'людина, що стоїть: помірно світлий тон шкіри',
    '🧍🏽' => 'людина, що стоїть: помірний тон шкіри',
    '🧍🏾' => 'людина, що стоїть: помірно темний тон шкіри',
    '🧍🏿' => 'людина, що стоїть: темний тон шкіри',
    '🧎🏻' => 'людина навколішках: світлий тон шкіри',
    '🧎🏼' => 'людина навколішках: помірно світлий тон шкіри',
    '🧎🏽' => 'людина навколішках: помірний тон шкіри',
    '🧎🏾' => 'людина навколішках: помірно темний тон шкіри',
    '🧎🏿' => 'людина навколішках: темний тон шкіри',
    '🏃🏻' => 'людина, що біжить: світлий тон шкіри',
    '🏃🏼' => 'людина, що біжить: помірно світлий тон шкіри',
    '🏃🏽' => 'людина, що біжить: помірний тон шкіри',
    '🏃🏾' => 'людина, що біжить: помірно темний тон шкіри',
    '🏃🏿' => 'людина, що біжить: темний тон шкіри',
    '💃🏻' => 'жінка, що танцює: світлий тон шкіри',
    '💃🏼' => 'жінка, що танцює: помірно світлий тон шкіри',
    '💃🏽' => 'жінка, що танцює: помірний тон шкіри',
    '💃🏾' => 'жінка, що танцює: помірно темний тон шкіри',
    '💃🏿' => 'жінка, що танцює: темний тон шкіри',
    '🕺🏻' => 'чоловік, що танцює: світлий тон шкіри',
    '🕺🏼' => 'чоловік, що танцює: помірно світлий тон шкіри',
    '🕺🏽' => 'чоловік, що танцює: помірний тон шкіри',
    '🕺🏾' => 'чоловік, що танцює: помірно темний тон шкіри',
    '🕺🏿' => 'чоловік, що танцює: темний тон шкіри',
    '🕴🏻' => 'чоловік у діловому костюмі, що левітує: світлий тон шкіри',
    '🕴🏼' => 'чоловік у діловому костюмі, що левітує: помірно світлий тон шкіри',
    '🕴🏽' => 'чоловік у діловому костюмі, що левітує: помірний тон шкіри',
    '🕴🏾' => 'чоловік у діловому костюмі, що левітує: помірно темний тон шкіри',
    '🕴🏿' => 'чоловік у діловому костюмі, що левітує: темний тон шкіри',
    '👯🏻' => 'люди з кролячими вухами: світлий тон шкіри',
    '👯🏼' => 'люди з кролячими вухами: помірно світлий тон шкіри',
    '👯🏽' => 'люди з кролячими вухами: помірний тон шкіри',
    '👯🏾' => 'люди з кролячими вухами: помірно темний тон шкіри',
    '👯🏿' => 'люди з кролячими вухами: темний тон шкіри',
    '🧖🏻' => 'людина в паркому приміщенні: світлий тон шкіри',
    '🧖🏼' => 'людина в паркому приміщенні: помірно світлий тон шкіри',
    '🧖🏽' => 'людина в паркому приміщенні: помірний тон шкіри',
    '🧖🏾' => 'людина в паркому приміщенні: помірно темний тон шкіри',
    '🧖🏿' => 'людина в паркому приміщенні: темний тон шкіри',
    '🧗🏻' => 'людина, що лізе скелею: світлий тон шкіри',
    '🧗🏼' => 'людина, що лізе скелею: помірно світлий тон шкіри',
    '🧗🏽' => 'людина, що лізе скелею: помірний тон шкіри',
    '🧗🏾' => 'людина, що лізе скелею: помірно темний тон шкіри',
    '🧗🏿' => 'людина, що лізе скелею: темний тон шкіри',
    '🏇🏻' => 'кінні перегони: світлий тон шкіри',
    '🏇🏼' => 'кінні перегони: помірно світлий тон шкіри',
    '🏇🏽' => 'кінні перегони: помірний тон шкіри',
    '🏇🏾' => 'кінні перегони: помірно темний тон шкіри',
    '🏇🏿' => 'кінні перегони: темний тон шкіри',
    '🏂🏻' => 'сноубордист: світлий тон шкіри',
    '🏂🏼' => 'сноубордист: помірно світлий тон шкіри',
    '🏂🏽' => 'сноубордист: помірний тон шкіри',
    '🏂🏾' => 'сноубордист: помірно темний тон шкіри',
    '🏂🏿' => 'сноубордист: темний тон шкіри',
    '🏌🏻' => 'людина, що грає в гольф: світлий тон шкіри',
    '🏌🏼' => 'людина, що грає в гольф: помірно світлий тон шкіри',
    '🏌🏽' => 'людина, що грає в гольф: помірний тон шкіри',
    '🏌🏾' => 'людина, що грає в гольф: помірно темний тон шкіри',
    '🏌🏿' => 'людина, що грає в гольф: темний тон шкіри',
    '🏄🏻' => 'людина, що займається серфінгом: світлий тон шкіри',
    '🏄🏼' => 'людина, що займається серфінгом: помірно світлий тон шкіри',
    '🏄🏽' => 'людина, що займається серфінгом: помірний тон шкіри',
    '🏄🏾' => 'людина, що займається серфінгом: помірно темний тон шкіри',
    '🏄🏿' => 'людина, що займається серфінгом: темний тон шкіри',
    '🚣🏻' => 'людина, що веслує на човні: світлий тон шкіри',
    '🚣🏼' => 'людина, що веслує на човні: помірно світлий тон шкіри',
    '🚣🏽' => 'людина, що веслує на човні: помірний тон шкіри',
    '🚣🏾' => 'людина, що веслує на човні: помірно темний тон шкіри',
    '🚣🏿' => 'людина, що веслує на човні: темний тон шкіри',
    '🏊🏻' => 'людина, що пливе: світлий тон шкіри',
    '🏊🏼' => 'людина, що пливе: помірно світлий тон шкіри',
    '🏊🏽' => 'людина, що пливе: помірний тон шкіри',
    '🏊🏾' => 'людина, що пливе: помірно темний тон шкіри',
    '🏊🏿' => 'людина, що пливе: темний тон шкіри',
    '⛹🏻' => 'людина, що веде мʼяч: світлий тон шкіри',
    '⛹🏼' => 'людина, що веде мʼяч: помірно світлий тон шкіри',
    '⛹🏽' => 'людина, що веде мʼяч: помірний тон шкіри',
    '⛹🏾' => 'людина, що веде мʼяч: помірно темний тон шкіри',
    '⛹🏿' => 'людина, що веде мʼяч: темний тон шкіри',
    '🏋🏻' => 'важкоатлет: світлий тон шкіри',
    '🏋🏼' => 'важкоатлет: помірно світлий тон шкіри',
    '🏋🏽' => 'важкоатлет: помірний тон шкіри',
    '🏋🏾' => 'важкоатлет: помірно темний тон шкіри',
    '🏋🏿' => 'важкоатлет: темний тон шкіри',
    '🚴🏻' => 'людина, що їде на велосипеді: світлий тон шкіри',
    '🚴🏼' => 'людина, що їде на велосипеді: помірно світлий тон шкіри',
    '🚴🏽' => 'людина, що їде на велосипеді: помірний тон шкіри',
    '🚴🏾' => 'людина, що їде на велосипеді: помірно темний тон шкіри',
    '🚴🏿' => 'людина, що їде на велосипеді: темний тон шкіри',
    '🚵🏻' => 'людина, що їде на гірському велосипеді: світлий тон шкіри',
    '🚵🏼' => 'людина, що їде на гірському велосипеді: помірно світлий тон шкіри',
    '🚵🏽' => 'людина, що їде на гірському велосипеді: помірний тон шкіри',
    '🚵🏾' => 'людина, що їде на гірському велосипеді: помірно темний тон шкіри',
    '🚵🏿' => 'людина, що їде на гірському велосипеді: темний тон шкіри',
    '🤸🏻' => 'людина, що перевертається «колесом»: світлий тон шкіри',
    '🤸🏼' => 'людина, що перевертається «колесом»: помірно світлий тон шкіри',
    '🤸🏽' => 'людина, що перевертається «колесом»: помірний тон шкіри',
    '🤸🏾' => 'людина, що перевертається «колесом»: помірно темний тон шкіри',
    '🤸🏿' => 'людина, що перевертається «колесом»: темний тон шкіри',
    '🤼🏻' => 'борці: світлий тон шкіри',
    '🤼🏼' => 'борці: помірно світлий тон шкіри',
    '🤼🏽' => 'борці: помірний тон шкіри',
    '🤼🏾' => 'борці: помірно темний тон шкіри',
    '🤼🏿' => 'борці: темний тон шкіри',
    '🤽🏻' => 'людина, що грає у ватерполо: світлий тон шкіри',
    '🤽🏼' => 'людина, що грає у ватерполо: помірно світлий тон шкіри',
    '🤽🏽' => 'людина, що грає у ватерполо: помірний тон шкіри',
    '🤽🏾' => 'людина, що грає у ватерполо: помірно темний тон шкіри',
    '🤽🏿' => 'людина, що грає у ватерполо: темний тон шкіри',
    '🤾🏻' => 'людина, що грає у гандбол: світлий тон шкіри',
    '🤾🏼' => 'людина, що грає у гандбол: помірно світлий тон шкіри',
    '🤾🏽' => 'людина, що грає у гандбол: помірний тон шкіри',
    '🤾🏾' => 'людина, що грає у гандбол: помірно темний тон шкіри',
    '🤾🏿' => 'людина, що грає у гандбол: темний тон шкіри',
    '🤹🏻' => 'людина, що жонглює: світлий тон шкіри',
    '🤹🏼' => 'людина, що жонглює: помірно світлий тон шкіри',
    '🤹🏽' => 'людина, що жонглює: помірний тон шкіри',
    '🤹🏾' => 'людина, що жонглює: помірно темний тон шкіри',
    '🤹🏿' => 'людина, що жонглює: темний тон шкіри',
    '🧘🏻' => 'людина в позі лотоса: світлий тон шкіри',
    '🧘🏼' => 'людина в позі лотоса: помірно світлий тон шкіри',
    '🧘🏽' => 'людина в позі лотоса: помірний тон шкіри',
    '🧘🏾' => 'людина в позі лотоса: помірно темний тон шкіри',
    '🧘🏿' => 'людина в позі лотоса: темний тон шкіри',
    '🛀🏻' => 'людина, що приймає ванну: світлий тон шкіри',
    '🛀🏼' => 'людина, що приймає ванну: помірно світлий тон шкіри',
    '🛀🏽' => 'людина, що приймає ванну: помірний тон шкіри',
    '🛀🏾' => 'людина, що приймає ванну: помірно темний тон шкіри',
    '🛀🏿' => 'людина, що приймає ванну: темний тон шкіри',
    '🛌🏻' => 'людина в ліжку: світлий тон шкіри',
    '🛌🏼' => 'людина в ліжку: помірно світлий тон шкіри',
    '🛌🏽' => 'людина в ліжку: помірний тон шкіри',
    '🛌🏾' => 'людина в ліжку: помірно темний тон шкіри',
    '🛌🏿' => 'людина в ліжку: темний тон шкіри',
    '👭🏻' => 'жінки, що тримаються за руки: світлий тон шкіри',
    '👭🏼' => 'жінки, що тримаються за руки: помірно світлий тон шкіри',
    '👭🏽' => 'жінки, що тримаються за руки: помірний тон шкіри',
    '👭🏾' => 'жінки, що тримаються за руки: помірно темний тон шкіри',
    '👭🏿' => 'жінки, що тримаються за руки: темний тон шкіри',
    '👫🏻' => 'жінка й чоловік, що тримаються за руки: світлий тон шкіри',
    '👫🏼' => 'жінка й чоловік, що тримаються за руки: помірно світлий тон шкіри',
    '👫🏽' => 'жінка й чоловік, що тримаються за руки: помірний тон шкіри',
    '👫🏾' => 'жінка й чоловік, що тримаються за руки: помірно темний тон шкіри',
    '👫🏿' => 'жінка й чоловік, що тримаються за руки: темний тон шкіри',
    '👬🏻' => 'чоловіки, що тримаються за руки: світлий тон шкіри',
    '👬🏼' => 'чоловіки, що тримаються за руки: помірно світлий тон шкіри',
    '👬🏽' => 'чоловіки, що тримаються за руки: помірний тон шкіри',
    '👬🏾' => 'чоловіки, що тримаються за руки: помірно темний тон шкіри',
    '👬🏿' => 'чоловіки, що тримаються за руки: темний тон шкіри',
    '💏🏻' => 'чоловік і жінка, що цілуються: світлий тон шкіри',
    '💏🏼' => 'чоловік і жінка, що цілуються: помірно світлий тон шкіри',
    '💏🏽' => 'чоловік і жінка, що цілуються: помірний тон шкіри',
    '💏🏾' => 'чоловік і жінка, що цілуються: помірно темний тон шкіри',
    '💏🏿' => 'чоловік і жінка, що цілуються: темний тон шкіри',
    '💑🏻' => 'чоловік і жінка із серцем між ними: світлий тон шкіри',
    '💑🏼' => 'чоловік і жінка із серцем між ними: помірно світлий тон шкіри',
    '💑🏽' => 'чоловік і жінка із серцем між ними: помірний тон шкіри',
    '💑🏾' => 'чоловік і жінка із серцем між ними: помірно темний тон шкіри',
    '💑🏿' => 'чоловік і жінка із серцем між ними: темний тон шкіри',
    '🇦🇨' => 'прапор: Острів Вознесіння',
    '🇦🇩' => 'прапор: Андорра',
    '🇦🇪' => 'прапор: Обʼєднані Арабські Емірати',
    '🇦🇫' => 'прапор: Афганістан',
    '🇦🇬' => 'прапор: Антигуа і Барбуда',
    '🇦🇮' => 'прапор: Ангілья',
    '🇦🇱' => 'прапор: Албанія',
    '🇦🇲' => 'прапор: Вірменія',
    '🇦🇴' => 'прапор: Ангола',
    '🇦🇶' => 'прапор: Антарктика',
    '🇦🇷' => 'прапор: Аргентина',
    '🇦🇸' => 'прапор: Американське Самоа',
    '🇦🇹' => 'прапор: Австрія',
    '🇦🇺' => 'прапор: Австралія',
    '🇦🇼' => 'прапор: Аруба',
    '🇦🇽' => 'прапор: Аландські Острови',
    '🇦🇿' => 'прапор: Азербайджан',
    '🇧🇦' => 'прапор: Боснія і Герцеговина',
    '🇧🇧' => 'прапор: Барбадос',
    '🇧🇩' => 'прапор: Бангладеш',
    '🇧🇪' => 'прапор: Бельгія',
    '🇧🇫' => 'прапор: Буркіна-Фасо',
    '🇧🇬' => 'прапор: Болгарія',
    '🇧🇭' => 'прапор: Бахрейн',
    '🇧🇮' => 'прапор: Бурунді',
    '🇧🇯' => 'прапор: Бенін',
    '🇧🇱' => 'прапор: Сен-Бартелемі',
    '🇧🇲' => 'прапор: Бермудські Острови',
    '🇧🇳' => 'прапор: Бруней',
    '🇧🇴' => 'прапор: Болівія',
    '🇧🇶' => 'прапор: Карибські Нідерланди',
    '🇧🇷' => 'прапор: Бразилія',
    '🇧🇸' => 'прапор: Багамські Острови',
    '🇧🇹' => 'прапор: Бутан',
    '🇧🇻' => 'прапор: Острів Буве',
    '🇧🇼' => 'прапор: Ботсвана',
    '🇧🇾' => 'прапор: Білорусь',
    '🇧🇿' => 'прапор: Беліз',
    '🇨🇦' => 'прапор: Канада',
    '🇨🇨' => 'прапор: Кокосові (Кілінг) Острови',
    '🇨🇩' => 'прапор: Конго – Кіншаса',
    '🇨🇫' => 'прапор: Центральноафриканська Республіка',
    '🇨🇬' => 'прапор: Конго – Браззавіль',
    '🇨🇭' => 'прапор: Швейцарія',
    '🇨🇮' => 'прапор: Кот-дʼІвуар',
    '🇨🇰' => 'прапор: Острови Кука',
    '🇨🇱' => 'прапор: Чилі',
    '🇨🇲' => 'прапор: Камерун',
    '🇨🇳' => 'прапор: Китай',
    '🇨🇴' => 'прапор: Колумбія',
    '🇨🇵' => 'прапор: Острів Кліппертон',
    '🇨🇶' => 'прапор: Сарк',
    '🇨🇷' => 'прапор: Коста-Рика',
    '🇨🇺' => 'прапор: Куба',
    '🇨🇻' => 'прапор: Кабо-Верде',
    '🇨🇼' => 'прапор: Кюрасао',
    '🇨🇽' => 'прапор: Острів Різдва',
    '🇨🇾' => 'прапор: Кіпр',
    '🇨🇿' => 'прапор: Чехія',
    '🇩🇪' => 'прапор: Німеччина',
    '🇩🇬' => 'прапор: Дієго-Гарсія',
    '🇩🇯' => 'прапор: Джибуті',
    '🇩🇰' => 'прапор: Данія',
    '🇩🇲' => 'прапор: Домініка',
    '🇩🇴' => 'прапор: Домініканська Республіка',
    '🇩🇿' => 'прапор: Алжир',
    '🇪🇦' => 'прапор: Сеута і Мелілья',
    '🇪🇨' => 'прапор: Еквадор',
    '🇪🇪' => 'прапор: Естонія',
    '🇪🇬' => 'прапор: Єгипет',
    '🇪🇭' => 'прапор: Західна Сахара',
    '🇪🇷' => 'прапор: Еритрея',
    '🇪🇸' => 'прапор: Іспанія',
    '🇪🇹' => 'прапор: Ефіопія',
    '🇪🇺' => 'прапор: Європейський Союз',
    '🇫🇮' => 'прапор: Фінляндія',
    '🇫🇯' => 'прапор: Фіджі',
    '🇫🇰' => 'прапор: Фолклендські Острови',
    '🇫🇲' => 'прапор: Мікронезія',
    '🇫🇴' => 'прапор: Фарерські Острови',
    '🇫🇷' => 'прапор: Франція',
    '🇬🇦' => 'прапор: Габон',
    '🇬🇧' => 'прапор: Велика Британія',
    '🇬🇩' => 'прапор: Гренада',
    '🇬🇪' => 'прапор: Грузія',
    '🇬🇫' => 'прапор: Французька Гвіана',
    '🇬🇬' => 'прапор: Гернсі',
    '🇬🇭' => 'прапор: Гана',
    '🇬🇮' => 'прапор: Гібралтар',
    '🇬🇱' => 'прапор: Гренландія',
    '🇬🇲' => 'прапор: Гамбія',
    '🇬🇳' => 'прапор: Гвінея',
    '🇬🇵' => 'прапор: Гваделупа',
    '🇬🇶' => 'прапор: Екваторіальна Гвінея',
    '🇬🇷' => 'прапор: Греція',
    '🇬🇸' => 'прапор: Південна Джорджія та Південні Сандвічеві Острови',
    '🇬🇹' => 'прапор: Гватемала',
    '🇬🇺' => 'прапор: Гуам',
    '🇬🇼' => 'прапор: Гвінея-Бісау',
    '🇬🇾' => 'прапор: Гаяна',
    '🇭🇰' => 'прапор: Гонконг, ОАР Китаю',
    '🇭🇲' => 'прапор: Острови Герд і Макдоналд',
    '🇭🇳' => 'прапор: Гондурас',
    '🇭🇷' => 'прапор: Хорватія',
    '🇭🇹' => 'прапор: Гаїті',
    '🇭🇺' => 'прапор: Угорщина',
    '🇮🇨' => 'прапор: Канарські Острови',
    '🇮🇩' => 'прапор: Індонезія',
    '🇮🇪' => 'прапор: Ірландія',
    '🇮🇱' => 'прапор: Ізраїль',
    '🇮🇲' => 'прапор: Острів Мен',
    '🇮🇳' => 'прапор: Індія',
    '🇮🇴' => 'прапор: Британська територія в Індійському океані',
    '🇮🇶' => 'прапор: Ірак',
    '🇮🇷' => 'прапор: Іран',
    '🇮🇸' => 'прапор: Ісландія',
    '🇮🇹' => 'прапор: Італія',
    '🇯🇪' => 'прапор: Джерсі',
    '🇯🇲' => 'прапор: Ямайка',
    '🇯🇴' => 'прапор: Йорданія',
    '🇯🇵' => 'прапор: Японія',
    '🇰🇪' => 'прапор: Кенія',
    '🇰🇬' => 'прапор: Киргизстан',
    '🇰🇭' => 'прапор: Камбоджа',
    '🇰🇮' => 'прапор: Кірибаті',
    '🇰🇲' => 'прапор: Комори',
    '🇰🇳' => 'прапор: Сент-Кітс і Невіс',
    '🇰🇵' => 'прапор: Північна Корея',
    '🇰🇷' => 'прапор: Південна Корея',
    '🇰🇼' => 'прапор: Кувейт',
    '🇰🇾' => 'прапор: Кайманові Острови',
    '🇰🇿' => 'прапор: Казахстан',
    '🇱🇦' => 'прапор: Лаос',
    '🇱🇧' => 'прапор: Ліван',
    '🇱🇨' => 'прапор: Сент-Люсія',
    '🇱🇮' => 'прапор: Ліхтенштейн',
    '🇱🇰' => 'прапор: Шрі-Ланка',
    '🇱🇷' => 'прапор: Ліберія',
    '🇱🇸' => 'прапор: Лесото',
    '🇱🇹' => 'прапор: Литва',
    '🇱🇺' => 'прапор: Люксембург',
    '🇱🇻' => 'прапор: Латвія',
    '🇱🇾' => 'прапор: Лівія',
    '🇲🇦' => 'прапор: Марокко',
    '🇲🇨' => 'прапор: Монако',
    '🇲🇩' => 'прапор: Молдова',
    '🇲🇪' => 'прапор: Чорногорія',
    '🇲🇫' => 'прапор: Сен-Мартен',
    '🇲🇬' => 'прапор: Мадагаскар',
    '🇲🇭' => 'прапор: Маршаллові Острови',
    '🇲🇰' => 'прапор: Північна Македонія',
    '🇲🇱' => 'прапор: Малі',
    '🇲🇲' => 'прапор: Мʼянма (Бірма)',
    '🇲🇳' => 'прапор: Монголія',
    '🇲🇴' => 'прапор: Макао, ОАР Китаю',
    '🇲🇵' => 'прапор: Північні Маріанські Острови',
    '🇲🇶' => 'прапор: Мартиніка',
    '🇲🇷' => 'прапор: Мавританія',
    '🇲🇸' => 'прапор: Монтсеррат',
    '🇲🇹' => 'прапор: Мальта',
    '🇲🇺' => 'прапор: Маврикій',
    '🇲🇻' => 'прапор: Мальдіви',
    '🇲🇼' => 'прапор: Малаві',
    '🇲🇽' => 'прапор: Мексика',
    '🇲🇾' => 'прапор: Малайзія',
    '🇲🇿' => 'прапор: Мозамбік',
    '🇳🇦' => 'прапор: Намібія',
    '🇳🇨' => 'прапор: Нова Каледонія',
    '🇳🇪' => 'прапор: Нігер',
    '🇳🇫' => 'прапор: Острів Норфолк',
    '🇳🇬' => 'прапор: Нігерія',
    '🇳🇮' => 'прапор: Нікарагуа',
    '🇳🇱' => 'прапор: Нідерланди',
    '🇳🇴' => 'прапор: Норвегія',
    '🇳🇵' => 'прапор: Непал',
    '🇳🇷' => 'прапор: Науру',
    '🇳🇺' => 'прапор: Ніуе',
    '🇳🇿' => 'прапор: Нова Зеландія',
    '🇴🇲' => 'прапор: Оман',
    '🇵🇦' => 'прапор: Панама',
    '🇵🇪' => 'прапор: Перу',
    '🇵🇫' => 'прапор: Французька Полінезія',
    '🇵🇬' => 'прапор: Папуа-Нова Гвінея',
    '🇵🇭' => 'прапор: Філіппіни',
    '🇵🇰' => 'прапор: Пакистан',
    '🇵🇱' => 'прапор: Польща',
    '🇵🇲' => 'прапор: Сен-Пʼєр і Мікелон',
    '🇵🇳' => 'прапор: Острови Піткерн',
    '🇵🇷' => 'прапор: Пуерто-Рико',
    '🇵🇸' => 'прапор: Палестинські території',
    '🇵🇹' => 'прапор: Португалія',
    '🇵🇼' => 'прапор: Палау',
    '🇵🇾' => 'прапор: Парагвай',
    '🇶🇦' => 'прапор: Катар',
    '🇷🇪' => 'прапор: Реюньйон',
    '🇷🇴' => 'прапор: Румунія',
    '🇷🇸' => 'прапор: Сербія',
    '🇷🇺' => 'прапор: Росія',
    '🇷🇼' => 'прапор: Руанда',
    '🇸🇦' => 'прапор: Саудівська Аравія',
    '🇸🇧' => 'прапор: Соломонові Острови',
    '🇸🇨' => 'прапор: Сейшельські Острови',
    '🇸🇩' => 'прапор: Судан',
    '🇸🇪' => 'прапор: Швеція',
    '🇸🇬' => 'прапор: Сінгапур',
    '🇸🇭' => 'прапор: Острів Святої Єлени',
    '🇸🇮' => 'прапор: Словенія',
    '🇸🇯' => 'прапор: Шпіцберген та Ян-Маєн',
    '🇸🇰' => 'прапор: Словаччина',
    '🇸🇱' => 'прапор: Сьєрра-Леоне',
    '🇸🇲' => 'прапор: Сан-Марино',
    '🇸🇳' => 'прапор: Сенегал',
    '🇸🇴' => 'прапор: Сомалі',
    '🇸🇷' => 'прапор: Суринам',
    '🇸🇸' => 'прапор: Південний Судан',
    '🇸🇹' => 'прапор: Сан-Томе і Принсіпі',
    '🇸🇻' => 'прапор: Сальвадор',
    '🇸🇽' => 'прапор: Сінт-Мартен',
    '🇸🇾' => 'прапор: Сирія',
    '🇸🇿' => 'прапор: Есватіні',
    '🇹🇦' => 'прапор: Трістан-да-Кунья',
    '🇹🇨' => 'прапор: Острови Теркс і Кайкос',
    '🇹🇩' => 'прапор: Чад',
    '🇹🇫' => 'прапор: Французькі Південні Території',
    '🇹🇬' => 'прапор: Того',
    '🇹🇭' => 'прапор: Таїланд',
    '🇹🇯' => 'прапор: Таджикистан',
    '🇹🇰' => 'прапор: Токелау',
    '🇹🇱' => 'прапор: Тимор-Лешті',
    '🇹🇲' => 'прапор: Туркменістан',
    '🇹🇳' => 'прапор: Туніс',
    '🇹🇴' => 'прапор: Тонга',
    '🇹🇷' => 'прапор: Туреччина',
    '🇹🇹' => 'прапор: Тринідад і Тобаго',
    '🇹🇻' => 'прапор: Тувалу',
    '🇹🇼' => 'прапор: Тайвань',
    '🇹🇿' => 'прапор: Танзанія',
    '🇺🇦' => 'прапор: Україна',
    '🇺🇬' => 'прапор: Уганда',
    '🇺🇲' => 'прапор: Віддалені острови США',
    '🇺🇳' => 'прапор: Організація Об’єднаних Націй',
    '🇺🇸' => 'прапор: Сполучені Штати',
    '🇺🇾' => 'прапор: Уругвай',
    '🇺🇿' => 'прапор: Узбекистан',
    '🇻🇦' => 'прапор: Ватикан',
    '🇻🇨' => 'прапор: Сент-Вінсент і Гренадіни',
    '🇻🇪' => 'прапор: Венесуела',
    '🇻🇬' => 'прапор: Британські Віргінські острови',
    '🇻🇮' => 'прапор: Віргінські Острови (США)',
    '🇻🇳' => 'прапор: Вʼєтнам',
    '🇻🇺' => 'прапор: Вануату',
    '🇼🇫' => 'прапор: Уолліс і Футуна',
    '🇼🇸' => 'прапор: Самоа',
    '🇽🇰' => 'прапор: Косово',
    '🇾🇪' => 'прапор: Ємен',
    '🇾🇹' => 'прапор: Майотта',
    '🇿🇦' => 'прапор: Південно-Африканська Республіка',
    '🇿🇲' => 'прапор: Замбія',
    '🇿🇼' => 'прапор: Зімбабве',
    '🔟' => 'клавіша: 10',
    '🏻' => 'світлий тон шкіри',
    '🏼' => 'помірно світлий тон шкіри',
    '🏽' => 'помірний тон шкіри',
    '🏾' => 'помірно темний тон шкіри',
    '🏿' => 'темний тон шкіри',
    '😀' => 'широко всміхнене обличчя',
    '😃' => 'широко всміхнене обличчя з очищами',
    '😄' => 'широко всміхнене обличчя з примруженими очима',
    '😁' => 'осяйно всміхнене обличчя й очі',
    '😆' => 'обличчя із широкою посмішкою й замруженими очима',
    '😅' => 'широко всміхнене обличчя з потом',
    '🤣' => 'качається від сміху',
    '😂' => 'обличчя в сльозах радості',
    '🙂' => 'трохи всміхнене обличчя',
    '🙃' => 'обличчя догори дриґом',
    '🫠' => 'розплавлене обличчя',
    '😉' => 'обличчя, що підморгує',
    '😊' => 'усміхнене обличчя й очі',
    '😇' => 'усміхнене обличчя з німбом',
    '🥰' => 'усміхнене обличчя із сердечками',
    '😍' => 'усміхнене обличчя з очима-серцями',
    '🤩' => 'очі-зірочки',
    '😘' => 'обличчя, що надсилає цілунок',
    '😗' => 'обличчя, що цілує',
    '☺' => 'усміхнене обличчя',
    '😚' => 'обличчя із заплющеними очима, що цілує',
    '😙' => 'обличчя з примруженими очима, що цілує',
    '🥲' => 'усмішка в сльозах',
    '😋' => 'усміхнене обличчя, що облизує губи',
    '😛' => 'обличчя з висунутим язиком',
    '😜' => 'обличчя, що підморгує і показує язика',
    '🤪' => 'божевільне обличчя',
    '😝' => 'обличчя з висунутим язиком і заплющеними очима',
    '🤑' => 'обличчя з грішми замість очей та язика',
    '🤗' => 'щасливе обличчя з руками, що обіймають',
    '🤭' => 'обличчя, що прикриває рота рукою',
    '🫢' => 'обличчя з розплющеними очима і рукою на роті',
    '🫣' => 'обличчя, що підглядає одним оком',
    '🤫' => 'обличчя, що цикає',
    '🤔' => 'обличчя в роздумах',
    '🫡' => 'обличчя, що козиряє',
    '🤐' => 'обличчя із застібкою замість рота',
    '🤨' => 'обличчя з піднятими бровами',
    '😐' => 'обличчя з нейтральним виразом',
    '😑' => 'обличчя без емоцій',
    '😶' => 'обличчя без рота',
    '🫥' => 'обличчя пунктиром',
    '😏' => 'самовдоволене обличчя',
    '😒' => 'невдоволене обличчя',
    '🙄' => 'обличчя із закоченими очима',
    '😬' => 'обличчя з гримасою',
    '🤥' => 'обличчя, що бреше',
    '🫨' => 'тремтливе обличчя',
    '😌' => 'заспокоєне обличчя',
    '😔' => 'замислене обличчя',
    '😪' => 'заспане обличчя',
    '🤤' => 'обличчя, що пускає слину',
    '😴' => 'обличчя, що спить',
    '🫩' => 'невиспане обличчя',
    '😷' => 'обличчя в медичній масці',
    '🤒' => 'обличчя з термометром',
    '🤕' => 'обличчя з головною повʼязкою',
    '🤢' => 'обличчя, яке нудить',
    '🤮' => 'обличчя, що блює',
    '🤧' => 'обличчя, що чхає',
    '🥵' => 'розпашіле обличчя',
    '🥶' => 'замерзле обличчя',
    '🥴' => 'очманіле обличчя',
    '😵' => 'запаморочене обличчя',
    '🤯' => 'голова, що вибухає',
    '🤠' => 'обличчя у ковбойському капелюсі',
    '🥳' => 'святкове обличчя',
    '🥸' => 'замасковане обличчя',
    '😎' => 'усміхнене обличчя в темних окулярах',
    '🤓' => 'обличчя всезнайка',
    '🧐' => 'обличчя в моноклі',
    '😕' => 'спантеличене обличчя',
    '🫤' => 'обличчя з ротом навскіс',
    '😟' => 'стурбоване обличчя',
    '🙁' => 'трохи похмуре обличчя',
    '☹' => 'похмуре обличчя',
    '😮' => 'обличчя з відкритим ротом',
    '😯' => 'здивоване і збентежене обличчя з бровами',
    '😲' => 'вражене обличчя',
    '😳' => 'зашаріле обличчя',
    '🫪' => 'спотворене обличчя',
    '🥺' => 'благальне обличчя',
    '🥹' => 'обличчя, що ледве стримує сльози',
    '😦' => 'похмуре обличчя з відкритим ротом',
    '😧' => 'стражденне обличчя',
    '😨' => 'налякане обличчя',
    '😰' => 'занепокоєне обличчя з потом',
    '😥' => 'cумне, але втішене обличчя',
    '😢' => 'обличчя, що плаче',
    '😭' => 'обличчя, що гучно ридає',
    '😱' => 'обличчя, що кричить із переляку',
    '😖' => 'збентежене обличчя',
    '😣' => 'невідступне обличчя',
    '😞' => 'розчароване обличчя',
    '😓' => 'понурене обличчя в поту',
    '😩' => 'замучене обличчя',
    '😫' => 'стомлене обличчя',
    '🥱' => 'обличчя, що позіхає',
    '😤' => 'обличчя, що сердито видихає',
    '😡' => 'обличчя, що дується',
    '😠' => 'сердите обличчя',
    '🤬' => 'обличчя із символами в роті',
    '😈' => 'усміхнене обличчя з рогами',
    '👿' => 'сердите обличчя з рогами',
    '💀' => 'череп',
    '☠' => 'череп і кістки',
    '💩' => 'усміхнена купа лайна',
    '🤡' => 'обличчя клоуна',
    '👹' => 'велетень-людожер',
    '👺' => 'гоблін',
    '👻' => 'привид',
    '👽' => 'прибулець',
    '👾' => 'іншопланетний монстр',
    '🤖' => 'робот',
    '😺' => 'широко всміхнений кіт',
    '😸' => 'широко всміхнений кіт з усміхом в очах',
    '😹' => 'кіт зі сльозами радості',
    '😻' => 'усміхнений кіт з очима як серця',
    '😼' => 'кіт із кривою посмішкою',
    '😽' => 'кіт, що цілує',
    '🙀' => 'шокований кіт',
    '😿' => 'кіт, що плаче',
    '😾' => 'сердитий кіт',
    '🙈' => 'мавпа, що не бачить',
    '🙉' => 'мавпа, що не чує',
    '🙊' => 'мавпа, що не говорить',
    '💌' => 'любовний лист',
    '💘' => 'серце, пробите стрілою',
    '💝' => 'серце зі стрічкою',
    '💖' => 'серце, що виблискує',
    '💗' => 'серце, що зростає',
    '💓' => 'серце, що бʼється',
    '💞' => 'серця, що обертаються',
    '💕' => 'два серця',
    '💟' => 'прикраса із серцем',
    '❣' => 'знак оклику у формі серця',
    '💔' => 'розбите серце',
    '❤' => 'червоне серце',
    '🩷' => 'рожеве серце',
    '🧡' => 'оранжеве серце',
    '💛' => 'жовте серце',
    '💚' => 'зелене серце',
    '💙' => 'синє серце',
    '🩵' => 'блакитне серце',
    '💜' => 'пурпурове серце',
    '🤎' => 'коричневе серце',
    '🖤' => 'чорне серце',
    '🩶' => 'сіре серце',
    '🤍' => 'біле серце',
    '💋' => 'слід цілунку',
    '💯' => 'cто балів',
    '💢' => 'символ гніву',
    '🫯' => 'бійка в хмарі',
    '💥' => 'зіткнення',
    '💫' => 'символ запаморочення',
    '💦' => 'краплі поту',
    '💨' => 'порив вітру',
    '🕳' => 'лунка',
    '💬' => 'текстова булька',
    '🗨' => 'хмаринка з текстом зліва',
    '🗯' => 'булька із сердитою реплікою',
    '💭' => 'булька роздумів',
    '💤' => 'умовне позначення сну',
    '👋' => 'рука махає',
    '🤚' => 'піднята рука тильною стороною',
    '🖐' => 'піднята рука з розведеними пальцями',
    '✋' => 'піднята рука',
    '🖖' => 'вулканське вітання',
    '🫱' => 'долоня вправо',
    '🫲' => 'долоня вліво',
    '🫳' => 'рука долонею вниз',
    '🫴' => 'рука долонею вгору',
    '🫷' => 'долоня штовхає вліво',
    '🫸' => 'долоня штовхає вправо',
    '👌' => 'жест «окей»',
    '🤌' => 'зведені пальці',
    '🤏' => 'жест «мало»',
    '✌' => 'жест перемоги',
    '🤞' => 'схрещені пальці',
    '🫰' => 'клацання пальцями',
    '🤟' => 'жест «кохаю тебе»',
    '🤘' => 'жест «роги»',
    '🤙' => 'жест «подзвони мені»',
    '👈' => 'палець тильним боком, що вказує вліво',
    '👉' => 'палець тильним боком, що вказує вправо',
    '👆' => 'палець тильним боком, що вказує вгору',
    '🖕' => 'середній палець',
    '👇' => 'палець тильним боком, що вказує вниз',
    '☝' => 'вказівний палець, що вказує вгору',
    '🫵' => 'вказівний палець, що вказує на глядача',
    '👍' => 'великі пальці вгору',
    '👎' => 'великі пальці вниз',
    '✊' => 'піднятий кулак',
    '👊' => 'кулак, що насувається',
    '🤛' => 'кулак уліво',
    '🤜' => 'кулак управо',
    '👏' => 'руки, що аплодують',
    '🙌' => 'руки, підняті для святкування',
    '🫶' => 'жест «серце»',
    '👐' => 'відкриті долоні',
    '🤲' => 'долоні, підняті разом',
    '🤝' => 'рукостискання',
    '🙏' => 'руки, стиснуті разом',
    '✍' => 'рука, що пише',
    '💅' => 'лак для нігтів',
    '🤳' => 'селфі',
    '💪' => 'напружений біцепс',
    '🦾' => 'механічна рука',
    '🦿' => 'механічна нога',
    '🦵' => 'нога',
    '🦶' => 'ступня',
    '👂' => 'вухо',
    '🦻' => 'вухо зі слуховим апаратом',
    '👃' => 'ніс',
    '🧠' => 'мозок',
    '🫀' => 'серце',
    '🫁' => 'легені',
    '🦷' => 'зуб',
    '🦴' => 'кістка',
    '👀' => 'очі',
    '👁' => 'око',
    '👅' => 'язик',
    '👄' => 'рот',
    '🫦' => 'закушена нижня губа',
    '👶' => 'немовля',
    '🧒' => 'дитина',
    '👦' => 'хлопчик',
    '👧' => 'дівчинка',
    '🧑' => 'людина',
    '👱' => 'людина з білявим волоссям',
    '👨' => 'чоловік',
    '🧔' => 'людина з бородою',
    '👩' => 'жінка',
    '🧓' => 'літня людина',
    '👴' => 'літній чоловік',
    '👵' => 'літня жінка',
    '🙍' => 'похмура людина',
    '🙎' => 'людина, що дується',
    '🙅' => 'людина, що жестом показує «ні»',
    '🙆' => 'людина, що жестом показує «окей»',
    '💁' => 'людина, що простягає руку допомоги',
    '🙋' => 'людина з піднятою рукою',
    '🧏' => 'людина з порушенням слуху',
    '🙇' => 'людина, що вклоняється',
    '🤦' => 'людина з долонею до обличчя',
    '🤷' => 'людина, що знизує плечима',
    '👮' => 'працівник поліції',
    '🕵' => 'детектив',
    '💂' => 'варта',
    '🥷' => 'ніндзя',
    '👷' => 'будівельник',
    '🫅' => 'людина з короною на голові',
    '🤴' => 'принц',
    '👸' => 'принцеса',
    '👳' => 'людина в тюрбані',
    '👲' => 'чоловік у китайській шапці',
    '🧕' => 'жінка в хустині',
    '🤵' => 'людина в смокінгу',
    '👰' => 'людина у фаті',
    '🤰' => 'вагітна жінка',
    '🫃' => 'чоловік із «вагітним» животом',
    '🫄' => 'вагітна людина',
    '🤱' => 'грудне вигодовування',
    '👼' => 'янголятко',
    '🎅' => 'Санта Клаус',
    '🤶' => 'Пані Клаус',
    '🦸' => 'супергерой',
    '🦹' => 'суперзлодій',
    '🧙' => 'маг',
    '🧚' => 'фея',
    '🧛' => 'вампір',
    '🧜' => 'казкова водяна істота',
    '🧝' => 'ельф',
    '🧞' => 'джин',
    '🧟' => 'зомбі',
    '🧌' => 'троль',
    '🫈' => 'волохата істота',
    '💆' => 'людина, якій роблять масаж голови',
    '💇' => 'людина, якій роблять стрижку',
    '🚶' => 'людина, що йде пішки',
    '🧍' => 'людина, що стоїть',
    '🧎' => 'людина навколішках',
    '🏃' => 'людина, що біжить',
    '💃' => 'жінка, що танцює',
    '🕺' => 'чоловік, що танцює',
    '🕴' => 'чоловік у діловому костюмі, що левітує',
    '👯' => 'люди з кролячими вухами',
    '🧖' => 'людина в паркому приміщенні',
    '🧗' => 'людина, що лізе скелею',
    '🤺' => 'фехтувальник',
    '🏇' => 'кінні перегони',
    '⛷' => 'лижник',
    '🏂' => 'сноубордист',
    '🏌' => 'людина, що грає в гольф',
    '🏄' => 'людина, що займається серфінгом',
    '🚣' => 'людина, що веслує на човні',
    '🏊' => 'людина, що пливе',
    '⛹' => 'людина, що веде мʼяч',
    '🏋' => 'важкоатлет',
    '🚴' => 'людина, що їде на велосипеді',
    '🚵' => 'людина, що їде на гірському велосипеді',
    '🤸' => 'людина, що перевертається «колесом»',
    '🤼' => 'борці',
    '🤽' => 'людина, що грає у ватерполо',
    '🤾' => 'людина, що грає у гандбол',
    '🤹' => 'людина, що жонглює',
    '🧘' => 'людина в позі лотоса',
    '🛀' => 'людина, що приймає ванну',
    '🛌' => 'людина в ліжку',
    '👭' => 'жінки, що тримаються за руки',
    '👫' => 'жінка й чоловік, що тримаються за руки',
    '👬' => 'чоловіки, що тримаються за руки',
    '💏' => 'чоловік і жінка, що цілуються',
    '💑' => 'чоловік і жінка із серцем між ними',
    '🗣' => 'голова, що говорить',
    '👤' => 'силует бюсту людини',
    '👥' => 'силуети двох людських бюстів',
    '🫂' => 'люди обіймаються',
    '👪' => 'родина',
    '👣' => 'сліди ніг',
    '🫆' => 'відбиток пальця',
    '🦰' => 'руде волосся',
    '🦱' => 'кучеряве волосся',
    '🦳' => 'сиве волосся',
    '🦲' => 'лисина',
    '🐵' => 'морда мавпи',
    '🐒' => 'мавпа',
    '🦍' => 'горила',
    '🦧' => 'орангутанг',
    '🐶' => 'морда собаки',
    '🐕' => 'собака',
    '🦮' => 'собака-поводир',
    '🐩' => 'пудель',
    '🐺' => 'вовк',
    '🦊' => 'лис',
    '🦝' => 'єнот',
    '🐱' => 'морда кота',
    '🐈' => 'кіт',
    '🦁' => 'лев',
    '🐯' => 'морда тигра',
    '🐅' => 'тигр',
    '🐆' => 'леопард',
    '🐴' => 'голова коня',
    '🫎' => 'лось',
    '🫏' => 'віслюк',
    '🐎' => 'кінь',
    '🦄' => 'єдиноріг',
    '🦓' => 'зебра',
    '🦌' => 'олень',
    '🦬' => 'бізон',
    '🐮' => 'морда корови',
    '🐂' => 'бик',
    '🐃' => 'буйвіл',
    '🐄' => 'корова',
    '🐷' => 'рило свині',
    '🐖' => 'свиня',
    '🐗' => 'вепр',
    '🐽' => 'свинячий пʼятак',
    '🐏' => 'баран',
    '🐑' => 'вівця',
    '🐐' => 'цап',
    '🐪' => 'одногорбий верблюд',
    '🐫' => 'двогорбий верблюд',
    '🦙' => 'лама',
    '🦒' => 'жирафа',
    '🐘' => 'слон',
    '🦣' => 'мамонт',
    '🦏' => 'носоріг',
    '🦛' => 'бегемот',
    '🐭' => 'морда миші',
    '🐁' => 'миша',
    '🐀' => 'щур',
    '🐹' => 'хомʼяк',
    '🐰' => 'морда кроля',
    '🐇' => 'кролик',
    '🐿' => 'бурундук',
    '🦫' => 'бобер',
    '🦔' => 'їжак',
    '🦇' => 'кажан',
    '🐻' => 'ведмідь',
    '🐨' => 'коала',
    '🐼' => 'панда',
    '🦥' => 'лінивець',
    '🦦' => 'видра',
    '🦨' => 'скунс',
    '🦘' => 'кенгуру',
    '🦡' => 'борсук',
    '🐾' => 'сліди лап',
    '🦃' => 'індик',
    '🐔' => 'курка',
    '🐓' => 'півень',
    '🐣' => 'курча, що вилуплюється',
    '🐤' => 'мале курча',
    '🐥' => 'курча, що стоїть',
    '🐦' => 'птах',
    '🐧' => 'пінгвін',
    '🕊' => 'голуб',
    '🦅' => 'орел',
    '🦆' => 'качка',
    '🦢' => 'лебідь',
    '🦉' => 'сова',
    '🦤' => 'дронт',
    '🪶' => 'пір’їна',
    '🦩' => 'фламінго',
    '🦚' => 'павич',
    '🦜' => 'папуга',
    '🪽' => 'крило',
    '🪿' => 'гусак',
    '🐸' => 'жаба',
    '🐊' => 'крокодил',
    '🐢' => 'черепаха',
    '🦎' => 'ящірка',
    '🐍' => 'змія',
    '🐲' => 'голова дракона',
    '🐉' => 'дракон',
    '🦕' => 'завропод',
    '🦖' => 'тиранозавр',
    '🐳' => 'кит, що пускає фонтан',
    '🐋' => 'кит',
    '🐬' => 'дельфін',
    '🫍' => 'косатка',
    '🦭' => 'тюлень',
    '🐟' => 'риба',
    '🐠' => 'тропічна риба',
    '🐡' => 'риба-куля',
    '🦈' => 'акула',
    '🐙' => 'восьминіг',
    '🐚' => 'морська мушля',
    '🪸' => 'корал',
    '🪼' => 'медуза',
    '🦀' => 'краб',
    '🦞' => 'омар',
    '🦐' => 'креветка',
    '🦑' => 'кальмар',
    '🦪' => 'устриця',
    '🐌' => 'равлик',
    '🦋' => 'метелик',
    '🐛' => 'комаха',
    '🐜' => 'мураха',
    '🐝' => 'бджола',
    '🪲' => 'жук',
    '🐞' => 'сонечко',
    '🦗' => 'цвіркун',
    '🪳' => 'тарган',
    '🕷' => 'павук',
    '🕸' => 'павутиння',
    '🦂' => 'скорпіон',
    '🦟' => 'комар',
    '🪰' => 'муха',
    '🪱' => 'хробак',
    '🦠' => 'мікроб',
    '💐' => 'букет',
    '🌸' => 'вишневий цвіт',
    '💮' => 'біла квітка',
    '🪷' => 'лотос',
    '🏵' => 'розета',
    '🌹' => 'троянда',
    '🥀' => 'привʼяла троянда',
    '🌺' => 'гібіскус',
    '🌻' => 'соняшник',
    '🌼' => 'жовта квітка',
    '🌷' => 'тюльпан',
    '🪻' => 'гіацинт',
    '🌱' => 'сіянець',
    '🪴' => 'рослина в горщику',
    '🌲' => 'вічнозелене дерево',
    '🌳' => 'листяне дерево',
    '🌴' => 'пальма',
    '🌵' => 'кактус',
    '🌾' => 'сніпок рису',
    '🌿' => 'лікарська рослина',
    '☘' => 'трилисник',
    '🍀' => 'чотирилисткова конюшина',
    '🍁' => 'кленовий листок',
    '🍂' => 'опале листя',
    '🍃' => 'листя, що кружляє за вітром',
    '🪹' => 'порожнє гніздо',
    '🪺' => 'гніздо з пташиними яйцями',
    '🍄' => 'гриб',
    '🪾' => 'сухе дерево',
    '🍇' => 'виноград',
    '🍈' => 'диня',
    '🍉' => 'кавун',
    '🍊' => 'танжерин',
    '🍋' => 'лимон',
    '🍌' => 'банан',
    '🍍' => 'ананас',
    '🥭' => 'манго',
    '🍎' => 'червоне яблуко',
    '🍏' => 'зелене яблуко',
    '🍐' => 'груша',
    '🍑' => 'персик',
    '🍒' => 'вишні',
    '🍓' => 'полуниця',
    '🫐' => 'лохина',
    '🥝' => 'ківі',
    '🍅' => 'томат',
    '🫒' => 'оливка',
    '🥥' => 'кокос',
    '🥑' => 'авокадо',
    '🍆' => 'баклажан',
    '🥔' => 'картопля',
    '🥕' => 'морква',
    '🌽' => 'качан кукурудзи',
    '🌶' => 'гострий перець',
    '🫑' => 'солодкий перець',
    '🥒' => 'огірок',
    '🥬' => 'листя салату',
    '🥦' => 'броколі',
    '🧄' => 'часник',
    '🧅' => 'цибуля',
    '🥜' => 'арахіс',
    '🫘' => 'квасоля',
    '🌰' => 'каштан',
    '🫚' => 'імбир',
    '🫛' => 'стручок гороху',
    '🫜' => 'коренеплід',
    '🍞' => 'хліб',
    '🥐' => 'круасан',
    '🥖' => 'багет',
    '🫓' => 'корж',
    '🥨' => 'крендель',
    '🥯' => 'бейгл',
    '🥞' => 'млинці',
    '🧇' => 'вафля',
    '🧀' => 'кусень сиру',
    '🍖' => 'м’ясо на кістці',
    '🍗' => 'ніжка свійської птиці',
    '🥩' => 'мʼясний філей',
    '🥓' => 'бекон',
    '🍔' => 'гамбургер',
    '🍟' => 'картопля фрі',
    '🍕' => 'піца',
    '🌭' => 'хот-дог',
    '🥪' => 'сандвіч',
    '🌮' => 'тако',
    '🌯' => 'буріто',
    '🫔' => 'тамале',
    '🥙' => 'піта',
    '🧆' => 'фалафель',
    '🥚' => 'яйце',
    '🍳' => 'готування їжі',
    '🥘' => 'каструля з їжею',
    '🍲' => 'горщик з їжею',
    '🫕' => 'фондю',
    '🥣' => 'миска з ложкою',
    '🥗' => 'зелений салат',
    '🍿' => 'попкорн',
    '🧈' => 'масло',
    '🧂' => 'сіль',
    '🥫' => 'консерви',
    '🍱' => 'обід у коробці',
    '🍘' => 'рисовий крекер',
    '🍙' => 'рисова кулька',
    '🍚' => 'приготований рис',
    '🍛' => 'рис із карі',
    '🍜' => 'миска, з якої піднімається пара',
    '🍝' => 'спагеті',
    '🍠' => 'печений батат',
    '🍢' => 'оден',
    '🍣' => 'суші',
    '🍤' => 'смажена креветка',
    '🍥' => 'рибний рулет зі спіральним візерунком',
    '🥮' => 'мункейк',
    '🍡' => 'рисові кульки на шпажці',
    '🥟' => 'вареник',
    '🥠' => 'печиво з передбаченням',
    '🥡' => 'коробка з їжею на винос',
    '🍦' => 'морозиво в ріжку',
    '🍧' => 'льодова стружка',
    '🍨' => 'морозиво',
    '🍩' => 'пончик',
    '🍪' => 'печиво',
    '🎂' => 'торт на день народження',
    '🍰' => 'тістечко',
    '🧁' => 'капкейк',
    '🥧' => 'пиріг',
    '🍫' => 'плитка шоколаду',
    '🍬' => 'цукерка',
    '🍭' => 'льодяник',
    '🍮' => 'заварний крем',
    '🍯' => 'горщик із медом',
    '🍼' => 'пляшечка для немовляти',
    '🥛' => 'склянка молока',
    '☕' => 'гарячий напій',
    '🫖' => 'чайник',
    '🍵' => 'чайна чашка без вушка',
    '🍶' => 'саке',
    '🍾' => 'пляшка з корком, що вилітає',
    '🍷' => 'келих для вина',
    '🍸' => 'бокал для коктейлю',
    '🍹' => 'тропічний напій',
    '🍺' => 'кухоль із пивом',
    '🍻' => 'кухлі з пивом, що цокаються',
    '🥂' => 'дзвін бокалів',
    '🥃' => 'бокал віскі',
    '🫗' => 'склянка, з якої виливається рідина',
    '🥤' => 'стакан із соломинкою',
    '🧋' => 'бульбашковий чай',
    '🧃' => 'пакетик із напоєм',
    '🧉' => 'мате',
    '🧊' => 'кубик льоду',
    '🥢' => 'палички для їжі',
    '🍽' => 'виделка, ніж і тарілка',
    '🍴' => 'виделка та ніж',
    '🥄' => 'ложка',
    '🔪' => 'кухонний ніж',
    '🫙' => 'банка',
    '🏺' => 'амфора',
    '🌍' => 'глобус, що показує Європу й Африку',
    '🌎' => 'глобус, що показує Америки',
    '🌏' => 'глобус, що показує Азію і Австралію',
    '🌐' => 'земна куля з меридіанами',
    '🗺' => 'карта світу',
    '🗾' => 'карта Японії',
    '🧭' => 'компас',
    '🏔' => 'гора із засніженою верхівкою',
    '⛰' => 'гора',
    '🛘' => 'зсув',
    '🌋' => 'вулкан',
    '🗻' => 'гора Фудзі',
    '🏕' => 'кемпінг',
    '🏖' => 'пляж і парасолька',
    '🏜' => 'пустеля',
    '🏝' => 'безлюдний острів',
    '🏞' => 'національний парк',
    '🏟' => 'стадіон',
    '🏛' => 'антична будівля',
    '🏗' => 'спорудження будівлі',
    '🧱' => 'цегла',
    '🪨' => 'камінь',
    '🪵' => 'деревина',
    '🛖' => 'хижа',
    '🏘' => 'група будинків',
    '🏚' => 'занедбаний будинок',
    '🏠' => 'будинок',
    '🏡' => 'будинок із садом',
    '🏢' => 'офісна будівля',
    '🏣' => 'японське поштове відділення',
    '🏤' => 'поштове відділення',
    '🏥' => 'лікарня',
    '🏦' => 'банк',
    '🏨' => 'готель',
    '🏩' => 'готель кохання',
    '🏪' => 'цілодобовий магазин',
    '🏫' => 'школа',
    '🏬' => 'універмаг',
    '🏭' => 'фабрика',
    '🏯' => 'японський замок',
    '🏰' => 'замок',
    '💒' => 'весілля',
    '🗼' => 'Токійська вежа',
    '🗽' => 'Статуя Свободи',
    '⛪' => 'церква',
    '🕌' => 'мечеть',
    '🛕' => 'індуїстський храм',
    '🕍' => 'синагога',
    '⛩' => 'синтоїстський храм',
    '🕋' => 'Кааба',
    '⛲' => 'фонтан',
    '⛺' => 'намет',
    '🌁' => 'туманно',
    '🌃' => 'зоряна ніч',
    '🏙' => 'міський краєвид',
    '🌄' => 'схід сонця над горами',
    '🌅' => 'схід сонця',
    '🌆' => 'місто в сутінках',
    '🌇' => 'захід сонця',
    '🌉' => 'міст уночі',
    '♨' => 'гарячі джерела',
    '🎠' => 'коник на каруселі',
    '🛝' => 'дитяча гірка',
    '🎡' => 'чортове колесо',
    '🎢' => 'американські гірки',
    '💈' => 'вивіска перукаря (смугастий стовп)',
    '🎪' => 'циркове шатро',
    '🚂' => 'паровий локомотив',
    '🚃' => 'вагон',
    '🚄' => 'швидкісний потяг',
    '🚅' => 'швидкісний потяг з округлим носом',
    '🚆' => 'потяг',
    '🚇' => 'метро',
    '🚈' => 'швидкісний трамвай',
    '🚉' => 'станція',
    '🚊' => 'трамвай',
    '🚝' => 'монорейка',
    '🚞' => 'залізниця в горах',
    '🚋' => 'вагон трамвая',
    '🚌' => 'автобус',
    '🚍' => 'автобус, що наближається',
    '🚎' => 'тролейбус',
    '🚐' => 'мікроавтобус',
    '🚑' => 'автомобіль швидкої допомоги',
    '🚒' => 'пожежна машина',
    '🚓' => 'поліцейська машина',
    '🚔' => 'поліцейська машина, що наближається',
    '🚕' => 'таксі',
    '🚖' => 'таксі, що наближається',
    '🚗' => 'автомобіль',
    '🚘' => 'автомобіль, що наближається',
    '🚙' => 'позашляховик',
    '🛻' => 'автомобіль-пікап',
    '🚚' => 'вантажівка для доставки',
    '🚛' => 'вантажівка з причепом',
    '🚜' => 'трактор',
    '🏎' => 'cпортивний автомобіль',
    '🏍' => 'мотоцикл',
    '🛵' => 'мопед',
    '🦽' => 'колісний візок із ручним приводом',
    '🦼' => 'колісний візок з електроприводом',
    '🛺' => 'авторикша',
    '🚲' => 'велосипед',
    '🛴' => 'самокат',
    '🛹' => 'скейтборд',
    '🛼' => 'роликовий ковзан',
    '🚏' => 'автобусна зупинка',
    '🛣' => 'автомагістраль',
    '🛤' => 'залізнична колія',
    '🛢' => 'бочка для нафти',
    '⛽' => 'бензоколонка',
    '🛞' => 'колесо',
    '🚨' => 'проблисковий маячок',
    '🚥' => 'горизонтальний світлофор',
    '🚦' => 'вертикальний світлофор',
    '🛑' => 'восьмикутний червоний знак',
    '🚧' => 'знак ремонтних робіт',
    '⚓' => 'якір',
    '🛟' => 'рятівний круг',
    '⛵' => 'вітрильник',
    '🛶' => 'каное',
    '🚤' => 'швидкохідний катер',
    '🛳' => 'пасажирський корабель',
    '⛴' => 'пором',
    '🛥' => 'моторний човен',
    '🚢' => 'корабель',
    '✈' => 'літак',
    '🛩' => 'малий літак',
    '🛫' => 'літак злітає',
    '🛬' => 'літак сідає',
    '🪂' => 'парашут',
    '💺' => 'сидіння',
    '🚁' => 'гелікоптер',
    '🚟' => 'підвісна монорейка',
    '🚠' => 'канатна дорога в горах',
    '🚡' => 'канатна дорога',
    '🛰' => 'супутник',
    '🚀' => 'ракета',
    '🛸' => 'летюча тарілка',
    '🛎' => 'готельний дзвоник',
    '🧳' => 'багаж',
    '⌛' => 'пісковий годинник',
    '⏳' => 'пісковий годинник із піском, який сиплеться',
    '⌚' => 'наручний годинник',
    '⏰' => 'будильник',
    '⏱' => 'секундомір',
    '⏲' => 'таймер',
    '🕰' => 'камінний годинник',
    '🕛' => 'дванадцята година',
    '🕧' => 'пів на першу',
    '🕐' => 'перша година',
    '🕜' => 'пів на другу',
    '🕑' => 'друга година',
    '🕝' => 'пів на третю',
    '🕒' => 'третя година',
    '🕞' => 'пів на четверту',
    '🕓' => 'четверта година',
    '🕟' => 'пів на п’яту',
    '🕔' => 'п’ята година',
    '🕠' => 'пів на шосту',
    '🕕' => 'шоста година',
    '🕡' => 'пів на сьому',
    '🕖' => 'сьома година',
    '🕢' => 'пів на восьму',
    '🕗' => 'восьма година',
    '🕣' => 'пів на дев’яту',
    '🕘' => 'дев’ята година',
    '🕤' => 'пів на десяту',
    '🕙' => 'десята година',
    '🕥' => 'пів на одинадцяту',
    '🕚' => 'одинадцята година',
    '🕦' => 'пів на дванадцяту',
    '🌑' => 'молодий місяць',
    '🌒' => 'місяць у першій чверті',
    '🌓' => 'перша чверть місяця',
    '🌔' => 'місяць у другій чверті',
    '🌕' => 'повний місяць',
    '🌖' => 'місяць у третій чверті',
    '🌗' => 'остання чверть місяця',
    '🌘' => 'місяць у четвертій чверті',
    '🌙' => 'серп місяця',
    '🌚' => 'молодий місяць з обличчям',
    '🌛' => 'перша чверть місяця з обличчям',
    '🌜' => 'остання чверть місяця з обличчям',
    '🌡' => 'термометр',
    '☀' => 'сонце',
    '🌝' => 'повний місяць з обличчям',
    '🌞' => 'сонце з обличчям',
    '🪐' => 'планета з кільцем',
    '⭐' => 'зірка',
    '🌟' => 'сяйна зірка',
    '🌠' => 'метеор',
    '🌌' => 'Чумацький шлях',
    '☁' => 'хмара',
    '⛅' => 'сонце за хмарою',
    '⛈' => 'хмара з блискавкою та дощем',
    '🌤' => 'сонце за хмаркою',
    '🌥' => 'сонце за хмариною',
    '🌦' => 'сонце за дощовою хмарою',
    '🌧' => 'хмара з дощем',
    '🌨' => 'хмара зі снігом',
    '🌩' => 'хмара з блискавкою',
    '🌪' => 'торнадо',
    '🌫' => 'туман',
    '🌬' => 'обличчя, що дме',
    '🌀' => 'циклон',
    '🌈' => 'веселка',
    '🌂' => 'складена парасолька',
    '☂' => 'парасолька',
    '☔' => 'парасолька з краплями дощу',
    '⛱' => 'пляжна парасолька',
    '⚡' => 'висока напруга',
    '❄' => 'сніжинка',
    '☃' => 'сніговик',
    '⛄' => 'сніговик без снігу',
    '☄' => 'комета',
    '🔥' => 'вогонь',
    '💧' => 'крапля',
    '🌊' => 'хвиля',
    '🎃' => 'ліхтар-гарбуз',
    '🎄' => 'різдвяна ялинка',
    '🎆' => 'феєрверки',
    '🎇' => 'бенгальський вогонь',
    '🧨' => 'петарда',
    '✨' => 'блискітки',
    '🎈' => 'повітряна кулька',
    '🎉' => 'хлопавка',
    '🎊' => 'кулька з конфеті',
    '🎋' => 'танабата, гілка тандзаку',
    '🎍' => 'прикраси на ялинку',
    '🎎' => 'японські ляльки',
    '🎏' => 'вітровказ у формі коропів',
    '🎐' => 'китайські дзвіночки',
    '🎑' => 'церемонія вшанування місяця',
    '🧧' => 'червоний конверт',
    '🎀' => 'бант зі стрічки',
    '🎁' => 'подарунок',
    '🎗' => 'стрічка на згадку',
    '🎟' => 'вхідні квитки',
    '🎫' => 'квиток',
    '🎖' => 'військова медаль',
    '🏆' => 'приз',
    '🏅' => 'спортивна медаль',
    '🥇' => 'золота медаль',
    '🥈' => 'срібна медаль',
    '🥉' => 'бронзова медаль',
    '⚽' => 'футбольний м’яч',
    '⚾' => 'бейсбольний м’яч',
    '🥎' => 'софтбольний мʼяч',
    '🏀' => 'баскетбольний м’яч',
    '🏐' => 'волейбольний м’яч',
    '🏈' => 'мʼяч для американського футболу',
    '🏉' => 'мʼяч для регбі',
    '🎾' => 'тенісний м’яч',
    '🥏' => 'літаючий диск',
    '🎳' => 'куля і кеглі для боулінгу',
    '🏏' => 'бита і мʼяч для крикету',
    '🏑' => 'ключка і мʼяч для хокею на траві',
    '🏒' => 'ключка і шайба для хокею',
    '🥍' => 'стік для лакросу',
    '🏓' => 'ракетка і кулька для пінг-понгу',
    '🏸' => 'ракетка і волан для бадмінтону',
    '🥊' => 'боксерська рукавичка',
    '🥋' => 'одяг для єдиноборств',
    '🥅' => 'сітка воріт',
    '⛳' => 'лунка для гольфу з прапорцем',
    '⛸' => 'ковзан',
    '🎣' => 'рибацька вудка',
    '🤿' => 'маска з трубкою',
    '🎽' => 'бігова теніска',
    '🎿' => 'лижі',
    '🛷' => 'сани',
    '🥌' => 'камʼяна шайба для керлінгу',
    '🎯' => 'мішень із прямим влученням',
    '🪀' => 'йо-йо',
    '🪁' => 'повітряний змій',
    '🔫' => 'водяний пістолет',
    '🎱' => 'більярдна куля 8',
    '🔮' => 'кришталева куля',
    '🪄' => 'чарівна паличка',
    '🎮' => 'ігровий контролер',
    '🕹' => 'джойстик',
    '🎰' => 'гральний автомат',
    '🎲' => 'гральна кість',
    '🧩' => 'елемент пазла',
    '🧸' => 'ведмедик',
    '🪅' => 'піньята',
    '🪩' => 'дзеркальна куля',
    '🪆' => 'ляльки-матрьошки',
    '♠' => 'піка',
    '♥' => 'чирва',
    '♦' => 'бубна',
    '♣' => 'трефа',
    '♟' => 'пішак',
    '🃏' => 'джокер',
    '🀄' => 'фішка маджонгу «червоний дракон»',
    '🎴' => 'гральні карти з квітами (ханафуда)',
    '🎭' => 'театральне мистецтво',
    '🖼' => 'картина в рамці',
    '🎨' => 'палітра художника',
    '🧵' => 'нитка',
    '🪡' => 'швацька голка',
    '🧶' => 'пряжа',
    '🪢' => 'вузол',
    '👓' => 'окуляри',
    '🕶' => 'сонцезахисні окуляри',
    '🥽' => 'захисні окуляри',
    '🥼' => 'лабораторний халат',
    '🦺' => 'сигнальний жилет',
    '👔' => 'краватка',
    '👕' => 'теніска поло',
    '👖' => 'джинси',
    '🧣' => 'шарф',
    '🧤' => 'рукавички',
    '🧥' => 'пальто',
    '🧦' => 'шкарпетки',
    '👗' => 'сукня',
    '👘' => 'кімоно',
    '🥻' => 'сарі',
    '🩱' => 'суцільний купальник',
    '🩲' => 'плавки',
    '🩳' => 'шорти',
    '👙' => 'бікіні',
    '👚' => 'жіночий одяг',
    '🪭' => 'складане віяло',
    '👛' => 'гаманець',
    '👜' => 'сумка',
    '👝' => 'клатч',
    '🛍' => 'сумки для покупок',
    '🎒' => 'шкільний рюкзак',
    '🩴' => 'в’єтнамки',
    '👞' => 'чоловіча туфля',
    '👟' => 'кросівка',
    '🥾' => 'похідні черевики',
    '🥿' => 'туфлі без підборів',
    '👠' => 'туфля на високому підборі',
    '👡' => 'жіноча сандалія з підбором',
    '🩰' => 'балетні туфлі',
    '👢' => 'жіночий чобіт',
    '🪮' => 'гребінь',
    '👑' => 'корона',
    '👒' => 'жіночий капелюшок',
    '🎩' => 'циліндр (капелюх)',
    '🎓' => 'квадратна академічна шапочка',
    '🧢' => 'бейсболка',
    '🪖' => 'військовий шолом',
    '⛑' => 'каска рятувальника',
    '📿' => 'молитовні чотки',
    '💄' => 'помада',
    '💍' => 'каблучка',
    '💎' => 'коштовний камінь',
    '🔇' => 'заглушений динамік',
    '🔈' => 'низька гучність динаміка',
    '🔉' => 'середня гучність динаміка',
    '🔊' => 'високий рівень гучності динаміка',
    '📢' => 'гучномовець',
    '📣' => 'мегафон',
    '📯' => 'поштовий ріжок',
    '🔔' => 'дзвінок',
    '🔕' => 'заглушений дзвінок',
    '🎼' => 'партитура',
    '🎵' => 'музична нота',
    '🎶' => 'музичні ноти',
    '🎙' => 'студійний мікрофон',
    '🎚' => 'повзунок рівня',
    '🎛' => 'обертові регулятори',
    '🎤' => 'мікрофон',
    '🎧' => 'навушники',
    '📻' => 'радіоприймач',
    '🎷' => 'саксофон',
    '🎺' => 'труба',
    '🪊' => 'тромбон',
    '🪗' => 'акордеон',
    '🎸' => 'гітара',
    '🎹' => 'музична клавіатура',
    '🎻' => 'скрипка',
    '🪕' => 'банджо',
    '🥁' => 'барабан',
    '🪘' => 'циліндричний барабан',
    '🪇' => 'маракас',
    '🪈' => 'флейта',
    '🪉' => 'арфа',
    '📱' => 'мобільний телефон',
    '📲' => 'мобільний телефон зі стрілкою',
    '☎' => 'телефон',
    '📞' => 'телефонна слухавка',
    '📟' => 'пейджер',
    '📠' => 'факс',
    '🔋' => 'батарея',
    '🪫' => 'низький заряд батареї',
    '🔌' => 'штепсель',
    '💻' => 'ноутбук',
    '🖥' => 'комп’ютер',
    '🖨' => 'принтер',
    '⌨' => 'клавіатура',
    '🖱' => 'комп’ютерна миша',
    '🖲' => 'трекбол',
    '💽' => 'компʼютерний диск',
    '💾' => 'дискета',
    '💿' => 'компакт-диск',
    '📀' => '[DVD]-диск',
    '🧮' => 'рахівниця',
    '🎥' => 'кінокамера',
    '🎞' => 'кадри кіноплівки',
    '📽' => 'кінопроектор',
    '🎬' => 'кінохлопавка',
    '📺' => 'телевізор',
    '📷' => 'фотоапарат',
    '📸' => 'фотоапарат зі спалахом',
    '📹' => 'відеокамера',
    '📼' => 'відеокасета',
    '🔍' => 'збільшувальне скло з нахилом уліво',
    '🔎' => 'збільшувальне скло з нахилом управо',
    '🕯' => 'свічка',
    '💡' => 'лампочка',
    '🔦' => 'ліхтарик',
    '🏮' => 'червоний паперовий ліхтар',
    '🪔' => 'каганець',
    '📔' => 'записник у декоративній обкладинці',
    '📕' => 'закрита книга',
    '📖' => 'відкрита книга',
    '📗' => 'зелений підручник',
    '📘' => 'синій підручник',
    '📙' => 'оранжевий підручник',
    '📚' => 'книги',
    '📓' => 'зошит для творів',
    '📒' => 'гросбух',
    '📃' => 'сторінка із завитком',
    '📜' => 'сувій',
    '📄' => 'сторінка лицевою стороною',
    '📰' => 'газета',
    '🗞' => 'скручена газета',
    '📑' => 'мітки закладок',
    '🔖' => 'закладка',
    '🏷' => 'бирка',
    '🪙' => 'монета',
    '💰' => 'мішок грошей',
    '🪎' => 'скриня скарбів',
    '💴' => 'єнові банкноти',
    '💵' => 'доларові банкноти',
    '💶' => 'єврові банкноти',
    '💷' => 'фунтові банкноти',
    '💸' => 'гроші з крилами',
    '💳' => 'кредитна картка',
    '🧾' => 'квитанція',
    '💹' => 'графік зростання і знак єни',
    '✉' => 'конверт',
    '📧' => 'електронний лист',
    '📨' => 'конверт вхідного листа',
    '📩' => 'конверт зі стрілкою',
    '📤' => 'лоток вихідної скриньки',
    '📥' => 'лоток вхідної скриньки',
    '📦' => 'пакунок',
    '📫' => 'закрита поштова скринька з піднятим прапорцем',
    '📪' => 'закрита поштова скринька з опущеним прапорцем',
    '📬' => 'відкрита поштова скринька з піднятим прапорцем',
    '📭' => 'відкрита поштова скринька з опущеним прапорцем',
    '📮' => 'поштова скринька',
    '🗳' => 'урна для голосування і бюлетень',
    '✏' => 'олівець',
    '✒' => 'кінчик чорнильного пера',
    '🖋' => 'чорнильна ручка',
    '🖊' => 'кулькова ручка',
    '🖌' => 'пензель',
    '🖍' => 'пастель',
    '📝' => 'памʼятка',
    '💼' => 'кейс',
    '📁' => 'папка для файлів',
    '📂' => 'відкрита папка для файлів',
    '🗂' => 'роздільники в картотеці',
    '📅' => 'календар',
    '📆' => 'відривний календар',
    '🗒' => 'блокнот на спіралі',
    '🗓' => 'календар на спіралі',
    '📇' => 'картотека',
    '📈' => 'висхідний графік',
    '📉' => 'низхідний графік',
    '📊' => 'гістограма',
    '📋' => 'планшет для аркушів',
    '📌' => 'канцелярська кнопка',
    '📍' => 'шпилька з круглою голівкою',
    '📎' => 'скріпка',
    '🖇' => 'зчеплені скріпки',
    '📏' => 'пряма лінійка',
    '📐' => 'трикутна лінійка',
    '✂' => 'ножиці',
    '🗃' => 'скринька для карток',
    '🗄' => 'шафа для документів',
    '🗑' => 'сміттєвий кошик',
    '🔒' => 'замкнений замок',
    '🔓' => 'відімкнений замок',
    '🔏' => 'замок і чорнильна ручка',
    '🔐' => 'замкнений замок із ключем',
    '🔑' => 'ключ',
    '🗝' => 'старовинний ключ',
    '🔨' => 'молоток',
    '🪓' => 'сокира',
    '⛏' => 'кирка',
    '⚒' => 'молоток і кирка',
    '🛠' => 'молоток і гайковий ключ',
    '🗡' => 'кинджал',
    '⚔' => 'схрещені мечі',
    '💣' => 'бомба',
    '🪃' => 'бумеранг',
    '🏹' => 'лук і стріла',
    '🛡' => 'щит',
    '🪚' => 'теслярська пила',
    '🔧' => 'гайковий ключ',
    '🪛' => 'викрутка',
    '🔩' => 'гайка та болт',
    '⚙' => 'шестірня',
    '🗜' => 'затискач',
    '⚖' => 'ваги',
    '🦯' => 'тактильна тростина',
    '🔗' => 'символ зʼєднання ланок',
    '⛓' => 'ланцюги',
    '🪝' => 'гачок',
    '🧰' => 'скриня для інструментів',
    '🧲' => 'магніт',
    '🪜' => 'драбина',
    '🪏' => 'лопата',
    '⚗' => 'перегінний куб',
    '🧪' => 'пробірка',
    '🧫' => 'чашка Петрі',
    '🧬' => 'ДНК',
    '🔬' => 'мікроскоп',
    '🔭' => 'телескоп',
    '📡' => 'супутникова антена',
    '💉' => 'шприц',
    '🩸' => 'крапля крові',
    '💊' => 'пігулка',
    '🩹' => 'пластир',
    '🩼' => 'милиця',
    '🩺' => 'стетоскоп',
    '🩻' => 'рентген',
    '🚪' => 'двері',
    '🛗' => 'ліфт',
    '🪞' => 'дзеркало',
    '🪟' => 'вікно',
    '🛏' => 'ліжко',
    '🛋' => 'канапа й торшер',
    '🪑' => 'стілець',
    '🚽' => 'унітаз',
    '🪠' => 'вантуз',
    '🚿' => 'душ',
    '🛁' => 'ванна',
    '🪤' => 'мишоловка',
    '🪒' => 'бритва',
    '🧴' => 'лосьйон',
    '🧷' => 'англійська шпилька',
    '🧹' => 'мітла',
    '🧺' => 'кошик',
    '🧻' => 'рулон паперу',
    '🪣' => 'відро',
    '🧼' => 'мило',
    '🫧' => 'бульбашки',
    '🪥' => 'зубна щітка',
    '🧽' => 'губка',
    '🧯' => 'вогнегасник',
    '🛒' => 'магазинний візок',
    '🚬' => 'сигарета',
    '⚰' => 'труна',
    '🪦' => 'надгробок',
    '⚱' => 'урна для тліну',
    '🧿' => 'Око Фатіми',
    '🪬' => 'хамса',
    '🗿' => 'статуя з Острова Пасхи',
    '🪧' => 'плакат',
    '🪪' => 'посвідчення',
    '🏧' => 'символ банкомата',
    '🚮' => 'знак кидати сміття в урну',
    '🚰' => 'питна вода',
    '♿' => 'символ крісла-візка',
    '🚹' => 'чоловіча вбиральня',
    '🚺' => 'жіноча вбиральня',
    '🚻' => 'громадський туалет',
    '🚼' => 'символ немовляти',
    '🚾' => 'символ убиральні [WC]',
    '🛂' => 'паспортний контроль',
    '🛃' => 'митниця',
    '🛄' => 'видача багажу',
    '🛅' => 'камера схову',
    '⚠' => 'попередження',
    '🚸' => 'попереджувальний знак «Діти»',
    '⛔' => 'вʼїзд заборонено',
    '🚫' => 'заборонено',
    '🚳' => 'велосипеди заборонено',
    '🚭' => 'палити заборонено',
    '🚯' => 'смітити заборонено',
    '🚱' => 'непридатна для пиття вода',
    '🚷' => 'пішохідний рух заборонено',
    '📵' => 'мобільні телефони заборонено',
    '🔞' => 'вхід особам до 18 років заборонений',
    '☢' => 'радіаційна небезпека',
    '☣' => 'біологічна загроза',
    '⬆' => 'стрілка вгору',
    '↗' => 'стрілка вгору вправо',
    '➡' => 'стрілка вправо',
    '↘' => 'стрілка вниз управо',
    '⬇' => 'стрілка вниз',
    '↙' => 'стрілка вниз уліво',
    '⬅' => 'стрілка вліво',
    '↖' => 'стрілка вгору вліво',
    '↕' => 'стрілка вгору-вниз',
    '↔' => 'стрілка вліво-вправо',
    '↩' => 'стрілка вправо з вигином уліво',
    '↪' => 'стрілка вліво з вигином управо',
    '⤴' => 'стрілка вправо з вигином угору',
    '⤵' => 'стрілка вправо з вигином униз',
    '🔃' => 'вертикальні стрілки за ходом годинника',
    '🔄' => 'кнопка стрілок проти ходу годинника',
    '🔙' => 'стрілка назад [BACK]',
    '🔚' => 'стрілка [END]',
    '🔛' => 'стрілка [ON!]',
    '🔜' => 'стрілка [SOON]',
    '🔝' => 'стрілка [TOP]',
    '🛐' => 'культова споруда',
    '⚛' => 'символ атома',
    '🕉' => 'звук ом',
    '✡' => 'зірка Давида',
    '☸' => 'колесо дхарми',
    '☯' => 'інь-ян',
    '✝' => 'латинський хрест',
    '☦' => 'православний хрест',
    '☪' => 'зірка і півмісяць',
    '☮' => 'символ миру',
    '🕎' => 'менора',
    '🔯' => 'шестикутна зірка з крапкою',
    '🪯' => 'кханда',
    '♈' => 'Овен',
    '♉' => 'Телець',
    '♊' => 'Близнюки',
    '♋' => 'Рак',
    '♌' => 'Лев (знак зодіаку)',
    '♍' => 'Діва',
    '♎' => 'Терези',
    '♏' => 'Скорпіон (знак зодіаку)',
    '♐' => 'Стрілець',
    '♑' => 'Козоріг',
    '♒' => 'Водолій',
    '♓' => 'Риби',
    '⛎' => 'Змієносець',
    '🔀' => 'кнопка тасування композицій',
    '🔁' => 'кнопка повтору',
    '🔂' => 'кнопка одноразового повтору',
    '▶' => 'кнопка відтворення',
    '⏩' => 'кнопка перемотування вперед',
    '⏭' => 'кнопка наступної композиції',
    '⏯' => 'кнопка «Відтворити або призупинити»',
    '◀' => 'кнопка реверсу',
    '⏪' => 'кнопка перемотування назад',
    '⏮' => 'кнопка повернення до попередньої композиції',
    '🔼' => 'кнопка догори',
    '⏫' => 'кнопка мотання вгору',
    '🔽' => 'кнопка донизу',
    '⏬' => 'кнопка мотання вниз',
    '⏸' => 'кнопка паузи',
    '⏹' => 'кнопка стоп',
    '⏺' => 'кнопка запису',
    '⏏' => 'кнопка витягання',
    '🎦' => 'кінематограф',
    '🔅' => 'кнопка зменшення яскравості',
    '🔆' => 'кнопка збільшення яскравості',
    '📶' => 'рівень сигналу',
    '🛜' => 'бездротовий',
    '📳' => 'віброрежим',
    '📴' => 'мобільний телефон вимкнено',
    '♀' => 'символ жінки',
    '♂' => 'символ чоловіка',
    '⚧' => 'трансгендерний символ',
    '✖' => 'множення',
    '➕' => 'плюс',
    '➖' => 'мінус',
    '➗' => 'ділення',
    '🟰' => 'знак точної рівності',
    '♾' => 'нескінченність',
    '‼' => 'подвійний знак оклику',
    '⁉' => 'знак оклику і питання',
    '❓' => 'червоний знак питання',
    '❔' => 'білий знак питання',
    '❕' => 'білий знак оклику',
    '❗' => 'червоний знак оклику',
    '〰' => 'хвилясте тире',
    '💱' => 'обмін валют',
    '💲' => 'знак долара',
    '⚕' => 'символ медицини',
    '♻' => 'символ утилізації',
    '⚜' => 'геральдична лілія',
    '🔱' => 'тризуб',
    '📛' => 'бейдж з іменем',
    '🔰' => 'японський символ «початківець»',
    '⭕' => 'порожнисте червоне коло',
    '✅' => 'кнопка з галочкою',
    '☑' => 'клітинка з галочкою',
    '✔' => 'галочка',
    '❌' => 'хрестик',
    '❎' => 'кнопка з хрестиком',
    '➰' => 'закручена петля',
    '➿' => 'подвійна закручена петля',
    '〽' => 'японський знак початку частини пісні',
    '✳' => 'восьмикутний астериск',
    '✴' => 'восьмикінцева зірка',
    '❇' => 'блискітка',
    '™' => 'торговельна марка',
    '🫟' => 'ляпка',
    '🔠' => 'введення великими латинськими літерами',
    '🔡' => 'введення малими латинськими літерами',
    '🔢' => 'введення цифрами',
    '🔣' => 'введення символів',
    '🔤' => 'введення латинськими літерами',
    '🅰' => 'кнопка A (IІ група крові)',
    '🆎' => 'кнопка AB (IV група крові)',
    '🅱' => 'кнопка B (III група крові)',
    '🆑' => 'кнопка «очистити»',
    '🆒' => 'кнопка «COOL»',
    '🆓' => 'кнопка «FREE»',
    'ℹ' => 'джерело інформації',
    '🆔' => 'кнопка "ID"',
    'Ⓜ' => 'коло з літерою «м»',
    '🆕' => 'кнопка "NEW"',
    '🆖' => 'кнопка "NG"',
    '🅾' => 'кнопка O (І група крові)',
    '🆗' => 'кнопка «ОК»',
    '🅿' => 'кнопка «паркування»',
    '🆘' => 'кнопка "SOS"',
    '🆙' => 'кнопка "UP!"',
    '🆚' => 'кнопка "VS"',
    '🈁' => 'кнопка "тут" японською',
    '🈂' => 'кнопка "сервісний збір" японською',
    '🈷' => 'кнопка "щомісяця" японською',
    '🈶' => 'кнопка "не безкоштовно" японською',
    '🈯' => 'кнопка "зарезервовано" японською',
    '🉐' => 'кнопка "угода" японською',
    '🈹' => 'кнопка "знижка" японською',
    '🈚' => 'кнопка "безкоштовно" японською',
    '🈲' => 'кнопка "заборонено" японською',
    '🉑' => 'кнопка "прийнятно" японською',
    '🈸' => 'кнопка "заявка" японською',
    '🈴' => 'кнопка "достатня оцінка" японською',
    '🈳' => 'кнопка "вільно" японською',
    '㊗' => 'кнопка "вітання" японською',
    '㊙' => 'кнопка "секрет" японською',
    '🈺' => 'кнопка "робота" японською',
    '🈵' => 'кнопка "місць немає" японською',
    '🔴' => 'червоний круг',
    '🟠' => 'оранжевий круг',
    '🟡' => 'жовтий круг',
    '🟢' => 'зелений круг',
    '🔵' => 'cиній круг',
    '🟣' => 'фіолетовий круг',
    '🟤' => 'коричневий круг',
    '⚫' => 'чорний круг',
    '⚪' => 'білий круг',
    '🟥' => 'червоний квадрат',
    '🟧' => 'оранжевий квадрат',
    '🟨' => 'жовтий квадрат',
    '🟩' => 'зелений квадрат',
    '🟦' => 'синій квадрат',
    '🟪' => 'фіолетовий квадрат',
    '🟫' => 'коричневий квадрат',
    '⬛' => 'великий чорний квадрат',
    '⬜' => 'великий білий квадрат',
    '◼' => 'середній чорний квадрат',
    '◻' => 'середній білий квадрат',
    '◾' => 'менший за середній чорний квадрат',
    '◽' => 'менший за середній білий квадрат',
    '▪' => 'малий чорний квадрат',
    '▫' => 'малий білий квадрат',
    '🔶' => 'великий оранжевий ромб',
    '🔷' => 'великий синій ромб',
    '🔸' => 'малий оранжевий ромб',
    '🔹' => 'малий синій ромб',
    '🔺' => 'червоний трикутник, направлений угору',
    '🔻' => 'червоний трикутник, направлений униз',
    '💠' => 'ромб із крапкою',
    '🔘' => 'перемикач',
    '🔳' => 'квадратна кнопка з білою рамкою',
    '🔲' => 'квадратна кнопка з чорною рамкою',
    '🏁' => 'картатий прапор',
    '🚩' => 'трикутний прапор',
    '🎌' => 'схрещені прапори',
    '🏴' => 'чорний прапор',
    '🏳' => 'білий прапор',
];
