<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'pocałunek: dorosły, dorosły, karnacja jasna i karnacja średnio jasna',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'pocałunek: dorosły, dorosły, karnacja jasna i karnacja średnia',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'pocałunek: dorosły, dorosły, karnacja jasna i karnacja średnio ciemna',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'pocałunek: dorosły, dorosły, karnacja jasna i karnacja ciemna',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'pocałunek: dorosły, dorosły, karnacja średnio jasna i karnacja jasna',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'pocałunek: dorosły, dorosły, karnacja średnio jasna i karnacja średnia',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'pocałunek: dorosły, dorosły, karnacja średnio jasna i karnacja średnio ciemna',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'pocałunek: dorosły, dorosły, karnacja średnio jasna i karnacja ciemna',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'pocałunek: dorosły, dorosły, karnacja średnia i karnacja jasna',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'pocałunek: dorosły, dorosły, karnacja średnia i karnacja średnio jasna',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'pocałunek: dorosły, dorosły, karnacja średnia i karnacja średnio ciemna',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'pocałunek: dorosły, dorosły, karnacja średnia i karnacja ciemna',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'pocałunek: dorosły, dorosły, karnacja średnio ciemna i karnacja jasna',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'pocałunek: dorosły, dorosły, karnacja średnio ciemna i karnacja średnio jasna',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'pocałunek: dorosły, dorosły, karnacja średnio ciemna i karnacja średnia',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'pocałunek: dorosły, dorosły, karnacja średnio ciemna i karnacja ciemna',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'pocałunek: dorosły, dorosły, karnacja ciemna i karnacja jasna',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'pocałunek: dorosły, dorosły, karnacja ciemna i karnacja średnio jasna',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'pocałunek: dorosły, dorosły, karnacja ciemna i karnacja średnia',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'pocałunek: dorosły, dorosły, karnacja ciemna i karnacja średnio ciemna',
    '👨🏻‍❤‍💋‍👨🏻' => 'pocałunek: mężczyzna, mężczyzna i karnacja jasna',
    '👨🏻‍❤‍💋‍👨🏼' => 'pocałunek: mężczyzna, mężczyzna, karnacja jasna i karnacja średnio jasna',
    '👨🏻‍❤‍💋‍👨🏽' => 'pocałunek: mężczyzna, mężczyzna, karnacja jasna i karnacja średnia',
    '👨🏻‍❤‍💋‍👨🏾' => 'pocałunek: mężczyzna, mężczyzna, karnacja jasna i karnacja średnio ciemna',
    '👨🏻‍❤‍💋‍👨🏿' => 'pocałunek: mężczyzna, mężczyzna, karnacja jasna i karnacja ciemna',
    '👨🏼‍❤‍💋‍👨🏻' => 'pocałunek: mężczyzna, mężczyzna, karnacja średnio jasna i karnacja jasna',
    '👨🏼‍❤‍💋‍👨🏼' => 'pocałunek: mężczyzna, mężczyzna i karnacja średnio jasna',
    '👨🏼‍❤‍💋‍👨🏽' => 'pocałunek: mężczyzna, mężczyzna, karnacja średnio jasna i karnacja średnia',
    '👨🏼‍❤‍💋‍👨🏾' => 'pocałunek: mężczyzna, mężczyzna, karnacja średnio jasna i karnacja średnio ciemna',
    '👨🏼‍❤‍💋‍👨🏿' => 'pocałunek: mężczyzna, mężczyzna, karnacja średnio jasna i karnacja ciemna',
    '👨🏽‍❤‍💋‍👨🏻' => 'pocałunek: mężczyzna, mężczyzna, karnacja średnia i karnacja jasna',
    '👨🏽‍❤‍💋‍👨🏼' => 'pocałunek: mężczyzna, mężczyzna, karnacja średnia i karnacja średnio jasna',
    '👨🏽‍❤‍💋‍👨🏽' => 'pocałunek: mężczyzna, mężczyzna i karnacja średnia',
    '👨🏽‍❤‍💋‍👨🏾' => 'pocałunek: mężczyzna, mężczyzna, karnacja średnia i karnacja średnio ciemna',
    '👨🏽‍❤‍💋‍👨🏿' => 'pocałunek: mężczyzna, mężczyzna, karnacja średnia i karnacja ciemna',
    '👨🏾‍❤‍💋‍👨🏻' => 'pocałunek: mężczyzna, mężczyzna, karnacja średnio ciemna i karnacja jasna',
    '👨🏾‍❤‍💋‍👨🏼' => 'pocałunek: mężczyzna, mężczyzna, karnacja średnio ciemna i karnacja średnio jasna',
    '👨🏾‍❤‍💋‍👨🏽' => 'pocałunek: mężczyzna, mężczyzna, karnacja średnio ciemna i karnacja średnia',
    '👨🏾‍❤‍💋‍👨🏾' => 'pocałunek: mężczyzna, mężczyzna i karnacja średnio ciemna',
    '👨🏾‍❤‍💋‍👨🏿' => 'pocałunek: mężczyzna, mężczyzna, karnacja średnio ciemna i karnacja ciemna',
    '👨🏿‍❤‍💋‍👨🏻' => 'pocałunek: mężczyzna, mężczyzna, karnacja ciemna i karnacja jasna',
    '👨🏿‍❤‍💋‍👨🏼' => 'pocałunek: mężczyzna, mężczyzna, karnacja ciemna i karnacja średnio jasna',
    '👨🏿‍❤‍💋‍👨🏽' => 'pocałunek: mężczyzna, mężczyzna, karnacja ciemna i karnacja średnia',
    '👨🏿‍❤‍💋‍👨🏾' => 'pocałunek: mężczyzna, mężczyzna, karnacja ciemna i karnacja średnio ciemna',
    '👨🏿‍❤‍💋‍👨🏿' => 'pocałunek: mężczyzna, mężczyzna i karnacja ciemna',
    '👩🏻‍❤‍💋‍👨🏻' => 'pocałunek: kobieta, mężczyzna i karnacja jasna',
    '👩🏻‍❤‍💋‍👨🏼' => 'pocałunek: kobieta, mężczyzna, karnacja jasna i karnacja średnio jasna',
    '👩🏻‍❤‍💋‍👨🏽' => 'pocałunek: kobieta, mężczyzna, karnacja jasna i karnacja średnia',
    '👩🏻‍❤‍💋‍👨🏾' => 'pocałunek: kobieta, mężczyzna, karnacja jasna i karnacja średnio ciemna',
    '👩🏻‍❤‍💋‍👨🏿' => 'pocałunek: kobieta, mężczyzna, karnacja jasna i karnacja ciemna',
    '👩🏼‍❤‍💋‍👨🏻' => 'pocałunek: kobieta, mężczyzna, karnacja średnio jasna i karnacja jasna',
    '👩🏼‍❤‍💋‍👨🏼' => 'pocałunek: kobieta, mężczyzna i karnacja średnio jasna',
    '👩🏼‍❤‍💋‍👨🏽' => 'pocałunek: kobieta, mężczyzna, karnacja średnio jasna i karnacja średnia',
    '👩🏼‍❤‍💋‍👨🏾' => 'pocałunek: kobieta, mężczyzna, karnacja średnio jasna i karnacja średnio ciemna',
    '👩🏼‍❤‍💋‍👨🏿' => 'pocałunek: kobieta, mężczyzna, karnacja średnio jasna i karnacja ciemna',
    '👩🏽‍❤‍💋‍👨🏻' => 'pocałunek: kobieta, mężczyzna, karnacja średnia i karnacja jasna',
    '👩🏽‍❤‍💋‍👨🏼' => 'pocałunek: kobieta, mężczyzna, karnacja średnia i karnacja średnio jasna',
    '👩🏽‍❤‍💋‍👨🏽' => 'pocałunek: kobieta, mężczyzna i karnacja średnia',
    '👩🏽‍❤‍💋‍👨🏾' => 'pocałunek: kobieta, mężczyzna, karnacja średnia i karnacja średnio ciemna',
    '👩🏽‍❤‍💋‍👨🏿' => 'pocałunek: kobieta, mężczyzna, karnacja średnia i karnacja ciemna',
    '👩🏾‍❤‍💋‍👨🏻' => 'pocałunek: kobieta, mężczyzna, karnacja średnio ciemna i karnacja jasna',
    '👩🏾‍❤‍💋‍👨🏼' => 'pocałunek: kobieta, mężczyzna, karnacja średnio ciemna i karnacja średnio jasna',
    '👩🏾‍❤‍💋‍👨🏽' => 'pocałunek: kobieta, mężczyzna, karnacja średnio ciemna i karnacja średnia',
    '👩🏾‍❤‍💋‍👨🏾' => 'pocałunek: kobieta, mężczyzna i karnacja średnio ciemna',
    '👩🏾‍❤‍💋‍👨🏿' => 'pocałunek: kobieta, mężczyzna, karnacja średnio ciemna i karnacja ciemna',
    '👩🏿‍❤‍💋‍👨🏻' => 'pocałunek: kobieta, mężczyzna, karnacja ciemna i karnacja jasna',
    '👩🏿‍❤‍💋‍👨🏼' => 'pocałunek: kobieta, mężczyzna, karnacja ciemna i karnacja średnio jasna',
    '👩🏿‍❤‍💋‍👨🏽' => 'pocałunek: kobieta, mężczyzna, karnacja ciemna i karnacja średnia',
    '👩🏿‍❤‍💋‍👨🏾' => 'pocałunek: kobieta, mężczyzna, karnacja ciemna i karnacja średnio ciemna',
    '👩🏿‍❤‍💋‍👨🏿' => 'pocałunek: kobieta, mężczyzna i karnacja ciemna',
    '👩🏻‍❤‍💋‍👩🏻' => 'pocałunek: kobieta, kobieta i karnacja jasna',
    '👩🏻‍❤‍💋‍👩🏼' => 'pocałunek: kobieta, kobieta, karnacja jasna i karnacja średnio jasna',
    '👩🏻‍❤‍💋‍👩🏽' => 'pocałunek: kobieta, kobieta, karnacja jasna i karnacja średnia',
    '👩🏻‍❤‍💋‍👩🏾' => 'pocałunek: kobieta, kobieta, karnacja jasna i karnacja średnio ciemna',
    '👩🏻‍❤‍💋‍👩🏿' => 'pocałunek: kobieta, kobieta, karnacja jasna i karnacja ciemna',
    '👩🏼‍❤‍💋‍👩🏻' => 'pocałunek: kobieta, kobieta, karnacja średnio jasna i karnacja jasna',
    '👩🏼‍❤‍💋‍👩🏼' => 'pocałunek: kobieta, kobieta i karnacja średnio jasna',
    '👩🏼‍❤‍💋‍👩🏽' => 'pocałunek: kobieta, kobieta, karnacja średnio jasna i karnacja średnia',
    '👩🏼‍❤‍💋‍👩🏾' => 'pocałunek: kobieta, kobieta, karnacja średnio jasna i karnacja średnio ciemna',
    '👩🏼‍❤‍💋‍👩🏿' => 'pocałunek: kobieta, kobieta, karnacja średnio jasna i karnacja ciemna',
    '👩🏽‍❤‍💋‍👩🏻' => 'pocałunek: kobieta, kobieta, karnacja średnia i karnacja jasna',
    '👩🏽‍❤‍💋‍👩🏼' => 'pocałunek: kobieta, kobieta, karnacja średnia i karnacja średnio jasna',
    '👩🏽‍❤‍💋‍👩🏽' => 'pocałunek: kobieta, kobieta i karnacja średnia',
    '👩🏽‍❤‍💋‍👩🏾' => 'pocałunek: kobieta, kobieta, karnacja średnia i karnacja średnio ciemna',
    '👩🏽‍❤‍💋‍👩🏿' => 'pocałunek: kobieta, kobieta, karnacja średnia i karnacja ciemna',
    '👩🏾‍❤‍💋‍👩🏻' => 'pocałunek: kobieta, kobieta, karnacja średnio ciemna i karnacja jasna',
    '👩🏾‍❤‍💋‍👩🏼' => 'pocałunek: kobieta, kobieta, karnacja średnio ciemna i karnacja średnio jasna',
    '👩🏾‍❤‍💋‍👩🏽' => 'pocałunek: kobieta, kobieta, karnacja średnio ciemna i karnacja średnia',
    '👩🏾‍❤‍💋‍👩🏾' => 'pocałunek: kobieta, kobieta i karnacja średnio ciemna',
    '👩🏾‍❤‍💋‍👩🏿' => 'pocałunek: kobieta, kobieta, karnacja średnio ciemna i karnacja ciemna',
    '👩🏿‍❤‍💋‍👩🏻' => 'pocałunek: kobieta, kobieta, karnacja ciemna i karnacja jasna',
    '👩🏿‍❤‍💋‍👩🏼' => 'pocałunek: kobieta, kobieta, karnacja ciemna i karnacja średnio jasna',
    '👩🏿‍❤‍💋‍👩🏽' => 'pocałunek: kobieta, kobieta, karnacja ciemna i karnacja średnia',
    '👩🏿‍❤‍💋‍👩🏾' => 'pocałunek: kobieta, kobieta, karnacja ciemna i karnacja średnio ciemna',
    '👩🏿‍❤‍💋‍👩🏿' => 'pocałunek: kobieta, kobieta i karnacja ciemna',
    '🧑🏻‍🫯‍🧑🏼' => 'osoby uprawiające zapasy: karnacja jasna i karnacja średnio jasna',
    '🧑🏻‍🫯‍🧑🏽' => 'osoby uprawiające zapasy: karnacja jasna i karnacja średnia',
    '🧑🏻‍🫯‍🧑🏾' => 'osoby uprawiające zapasy: karnacja jasna i karnacja średnio ciemna',
    '🧑🏻‍🫯‍🧑🏿' => 'osoby uprawiające zapasy: karnacja jasna i karnacja ciemna',
    '🧑🏼‍🫯‍🧑🏻' => 'osoby uprawiające zapasy: karnacja średnio jasna i karnacja jasna',
    '🧑🏼‍🫯‍🧑🏽' => 'osoby uprawiające zapasy: karnacja średnio jasna i karnacja średnia',
    '🧑🏼‍🫯‍🧑🏾' => 'osoby uprawiające zapasy: karnacja średnio jasna i karnacja średnio ciemna',
    '🧑🏼‍🫯‍🧑🏿' => 'osoby uprawiające zapasy: karnacja średnio jasna i karnacja ciemna',
    '🧑🏽‍🫯‍🧑🏻' => 'osoby uprawiające zapasy: karnacja średnia i karnacja jasna',
    '🧑🏽‍🫯‍🧑🏼' => 'osoby uprawiające zapasy: karnacja średnia i karnacja średnio jasna',
    '🧑🏽‍🫯‍🧑🏾' => 'osoby uprawiające zapasy: karnacja średnia i karnacja średnio ciemna',
    '🧑🏽‍🫯‍🧑🏿' => 'osoby uprawiające zapasy: karnacja średnia i karnacja ciemna',
    '🧑🏾‍🫯‍🧑🏻' => 'osoby uprawiające zapasy: karnacja średnio ciemna i karnacja jasna',
    '🧑🏾‍🫯‍🧑🏼' => 'osoby uprawiające zapasy: karnacja średnio ciemna i karnacja średnio jasna',
    '🧑🏾‍🫯‍🧑🏽' => 'osoby uprawiające zapasy: karnacja średnio ciemna i karnacja średnia',
    '🧑🏾‍🫯‍🧑🏿' => 'osoby uprawiające zapasy: karnacja średnio ciemna i karnacja ciemna',
    '🧑🏿‍🫯‍🧑🏻' => 'osoby uprawiające zapasy: karnacja ciemna i karnacja jasna',
    '🧑🏿‍🫯‍🧑🏼' => 'osoby uprawiające zapasy: karnacja ciemna i karnacja średnio jasna',
    '🧑🏿‍🫯‍🧑🏽' => 'osoby uprawiające zapasy: karnacja ciemna i karnacja średnia',
    '🧑🏿‍🫯‍🧑🏾' => 'osoby uprawiające zapasy: karnacja ciemna i karnacja średnio ciemna',
    '🧑🏻‍❤‍🧑🏼' => 'para z sercem: dorosły, dorosły, karnacja jasna i karnacja średnio jasna',
    '🧑🏻‍❤‍🧑🏽' => 'para z sercem: dorosły, dorosły, karnacja jasna i karnacja średnia',
    '🧑🏻‍❤‍🧑🏾' => 'para z sercem: dorosły, dorosły, karnacja jasna i karnacja średnio ciemna',
    '🧑🏻‍❤‍🧑🏿' => 'para z sercem: dorosły, dorosły, karnacja jasna i karnacja ciemna',
    '🧑🏼‍❤‍🧑🏻' => 'para z sercem: dorosły, dorosły, karnacja średnio jasna i karnacja jasna',
    '🧑🏼‍❤‍🧑🏽' => 'para z sercem: dorosły, dorosły, karnacja średnio jasna i karnacja średnia',
    '🧑🏼‍❤‍🧑🏾' => 'para z sercem: dorosły, dorosły, karnacja średnio jasna i karnacja średnio ciemna',
    '🧑🏼‍❤‍🧑🏿' => 'para z sercem: dorosły, dorosły, karnacja średnio jasna i karnacja ciemna',
    '🧑🏽‍❤‍🧑🏻' => 'para z sercem: dorosły, dorosły, karnacja średnia i karnacja jasna',
    '🧑🏽‍❤‍🧑🏼' => 'para z sercem: dorosły, dorosły, karnacja średnia i karnacja średnio jasna',
    '🧑🏽‍❤‍🧑🏾' => 'para z sercem: dorosły, dorosły, karnacja średnia i karnacja średnio ciemna',
    '🧑🏽‍❤‍🧑🏿' => 'para z sercem: dorosły, dorosły, karnacja średnia i karnacja ciemna',
    '🧑🏾‍❤‍🧑🏻' => 'para z sercem: dorosły, dorosły, karnacja średnio ciemna i karnacja jasna',
    '🧑🏾‍❤‍🧑🏼' => 'para z sercem: dorosły, dorosły, karnacja średnio ciemna i karnacja średnio jasna',
    '🧑🏾‍❤‍🧑🏽' => 'para z sercem: dorosły, dorosły, karnacja średnio ciemna i karnacja średnia',
    '🧑🏾‍❤‍🧑🏿' => 'para z sercem: dorosły, dorosły, karnacja średnio ciemna i karnacja ciemna',
    '🧑🏿‍❤‍🧑🏻' => 'para z sercem: dorosły, dorosły, karnacja ciemna i karnacja jasna',
    '🧑🏿‍❤‍🧑🏼' => 'para z sercem: dorosły, dorosły, karnacja ciemna i karnacja średnio jasna',
    '🧑🏿‍❤‍🧑🏽' => 'para z sercem: dorosły, dorosły, karnacja ciemna i karnacja średnia',
    '🧑🏿‍❤‍🧑🏾' => 'para z sercem: dorosły, dorosły, karnacja ciemna i karnacja średnio ciemna',
    '🧑🏻‍🐰‍🧑🏼' => 'osoby z uszami królika na przyjęciu: karnacja jasna i karnacja średnio jasna',
    '🧑🏻‍🐰‍🧑🏽' => 'osoby z uszami królika na przyjęciu: karnacja jasna i karnacja średnia',
    '🧑🏻‍🐰‍🧑🏾' => 'osoby z uszami królika na przyjęciu: karnacja jasna i karnacja średnio ciemna',
    '🧑🏻‍🐰‍🧑🏿' => 'osoby z uszami królika na przyjęciu: karnacja jasna i karnacja ciemna',
    '🧑🏼‍🐰‍🧑🏻' => 'osoby z uszami królika na przyjęciu: karnacja średnio jasna i karnacja jasna',
    '🧑🏼‍🐰‍🧑🏽' => 'osoby z uszami królika na przyjęciu: karnacja średnio jasna i karnacja średnia',
    '🧑🏼‍🐰‍🧑🏾' => 'osoby z uszami królika na przyjęciu: karnacja średnio jasna i karnacja średnio ciemna',
    '🧑🏼‍🐰‍🧑🏿' => 'osoby z uszami królika na przyjęciu: karnacja średnio jasna i karnacja ciemna',
    '🧑🏽‍🐰‍🧑🏻' => 'osoby z uszami królika na przyjęciu: karnacja średnia i karnacja jasna',
    '🧑🏽‍🐰‍🧑🏼' => 'osoby z uszami królika na przyjęciu: karnacja średnia i karnacja średnio jasna',
    '🧑🏽‍🐰‍🧑🏾' => 'osoby z uszami królika na przyjęciu: karnacja średnia i karnacja średnio ciemna',
    '🧑🏽‍🐰‍🧑🏿' => 'osoby z uszami królika na przyjęciu: karnacja średnia i karnacja ciemna',
    '🧑🏾‍🐰‍🧑🏻' => 'osoby z uszami królika na przyjęciu: karnacja średnio ciemna i karnacja jasna',
    '🧑🏾‍🐰‍🧑🏼' => 'osoby z uszami królika na przyjęciu: karnacja średnio ciemna i karnacja średnio jasna',
    '🧑🏾‍🐰‍🧑🏽' => 'osoby z uszami królika na przyjęciu: karnacja średnio ciemna i karnacja średnia',
    '🧑🏾‍🐰‍🧑🏿' => 'osoby z uszami królika na przyjęciu: karnacja średnio ciemna i karnacja ciemna',
    '🧑🏿‍🐰‍🧑🏻' => 'osoby z uszami królika na przyjęciu: karnacja ciemna i karnacja jasna',
    '🧑🏿‍🐰‍🧑🏼' => 'osoby z uszami królika na przyjęciu: karnacja ciemna i karnacja średnio jasna',
    '🧑🏿‍🐰‍🧑🏽' => 'osoby z uszami królika na przyjęciu: karnacja ciemna i karnacja średnia',
    '🧑🏿‍🐰‍🧑🏾' => 'osoby z uszami królika na przyjęciu: karnacja ciemna i karnacja średnio ciemna',
    '👨🏻‍🫯‍👨🏼' => 'mężczyźni uprawiający zapasy: karnacja jasna i karnacja średnio jasna',
    '👨🏻‍🫯‍👨🏽' => 'mężczyźni uprawiający zapasy: karnacja jasna i karnacja średnia',
    '👨🏻‍🫯‍👨🏾' => 'mężczyźni uprawiający zapasy: karnacja jasna i karnacja średnio ciemna',
    '👨🏻‍🫯‍👨🏿' => 'mężczyźni uprawiający zapasy: karnacja jasna i karnacja ciemna',
    '👨🏼‍🫯‍👨🏻' => 'mężczyźni uprawiający zapasy: karnacja średnio jasna i karnacja jasna',
    '👨🏼‍🫯‍👨🏽' => 'mężczyźni uprawiający zapasy: karnacja średnio jasna i karnacja średnia',
    '👨🏼‍🫯‍👨🏾' => 'mężczyźni uprawiający zapasy: karnacja średnio jasna i karnacja średnio ciemna',
    '👨🏼‍🫯‍👨🏿' => 'mężczyźni uprawiający zapasy: karnacja średnio jasna i karnacja ciemna',
    '👨🏽‍🫯‍👨🏻' => 'mężczyźni uprawiający zapasy: karnacja średnia i karnacja jasna',
    '👨🏽‍🫯‍👨🏼' => 'mężczyźni uprawiający zapasy: karnacja średnia i karnacja średnio jasna',
    '👨🏽‍🫯‍👨🏾' => 'mężczyźni uprawiający zapasy: karnacja średnia i karnacja średnio ciemna',
    '👨🏽‍🫯‍👨🏿' => 'mężczyźni uprawiający zapasy: karnacja średnia i karnacja ciemna',
    '👨🏾‍🫯‍👨🏻' => 'mężczyźni uprawiający zapasy: karnacja średnio ciemna i karnacja jasna',
    '👨🏾‍🫯‍👨🏼' => 'mężczyźni uprawiający zapasy: karnacja średnio ciemna i karnacja średnio jasna',
    '👨🏾‍🫯‍👨🏽' => 'mężczyźni uprawiający zapasy: karnacja średnio ciemna i karnacja średnia',
    '👨🏾‍🫯‍👨🏿' => 'mężczyźni uprawiający zapasy: karnacja średnio ciemna i karnacja ciemna',
    '👨🏿‍🫯‍👨🏻' => 'mężczyźni uprawiający zapasy: karnacja ciemna i karnacja jasna',
    '👨🏿‍🫯‍👨🏼' => 'mężczyźni uprawiający zapasy: karnacja ciemna i karnacja średnio jasna',
    '👨🏿‍🫯‍👨🏽' => 'mężczyźni uprawiający zapasy: karnacja ciemna i karnacja średnia',
    '👨🏿‍🫯‍👨🏾' => 'mężczyźni uprawiający zapasy: karnacja ciemna i karnacja średnio ciemna',
    '👨🏻‍❤‍👨🏻' => 'para z sercem: mężczyzna, mężczyzna i karnacja jasna',
    '👨🏻‍❤‍👨🏼' => 'para z sercem: mężczyzna, mężczyzna, karnacja jasna i karnacja średnio jasna',
    '👨🏻‍❤‍👨🏽' => 'para z sercem: mężczyzna, mężczyzna, karnacja jasna i karnacja średnia',
    '👨🏻‍❤‍👨🏾' => 'para z sercem: mężczyzna, mężczyzna, karnacja jasna i karnacja średnio ciemna',
    '👨🏻‍❤‍👨🏿' => 'para z sercem: mężczyzna, mężczyzna, karnacja jasna i karnacja ciemna',
    '👨🏼‍❤‍👨🏻' => 'para z sercem: mężczyzna, mężczyzna, karnacja średnio jasna i karnacja jasna',
    '👨🏼‍❤‍👨🏼' => 'para z sercem: mężczyzna, mężczyzna i karnacja średnio jasna',
    '👨🏼‍❤‍👨🏽' => 'para z sercem: mężczyzna, mężczyzna, karnacja średnio jasna i karnacja średnia',
    '👨🏼‍❤‍👨🏾' => 'para z sercem: mężczyzna, mężczyzna, karnacja średnio jasna i karnacja średnio ciemna',
    '👨🏼‍❤‍👨🏿' => 'para z sercem: mężczyzna, mężczyzna, karnacja średnio jasna i karnacja ciemna',
    '👨🏽‍❤‍👨🏻' => 'para z sercem: mężczyzna, mężczyzna, karnacja średnia i karnacja jasna',
    '👨🏽‍❤‍👨🏼' => 'para z sercem: mężczyzna, mężczyzna, karnacja średnia i karnacja średnio jasna',
    '👨🏽‍❤‍👨🏽' => 'para z sercem: mężczyzna, mężczyzna i karnacja średnia',
    '👨🏽‍❤‍👨🏾' => 'para z sercem: mężczyzna, mężczyzna, karnacja średnia i karnacja średnio ciemna',
    '👨🏽‍❤‍👨🏿' => 'para z sercem: mężczyzna, mężczyzna, karnacja średnia i karnacja ciemna',
    '👨🏾‍❤‍👨🏻' => 'para z sercem: mężczyzna, mężczyzna, karnacja średnio ciemna i karnacja jasna',
    '👨🏾‍❤‍👨🏼' => 'para z sercem: mężczyzna, mężczyzna, karnacja średnio ciemna i karnacja średnio jasna',
    '👨🏾‍❤‍👨🏽' => 'para z sercem: mężczyzna, mężczyzna, karnacja średnio ciemna i karnacja średnia',
    '👨🏾‍❤‍👨🏾' => 'para z sercem: mężczyzna, mężczyzna i karnacja średnio ciemna',
    '👨🏾‍❤‍👨🏿' => 'para z sercem: mężczyzna, mężczyzna, karnacja średnio ciemna i karnacja ciemna',
    '👨🏿‍❤‍👨🏻' => 'para z sercem: mężczyzna, mężczyzna, karnacja ciemna i karnacja jasna',
    '👨🏿‍❤‍👨🏼' => 'para z sercem: mężczyzna, mężczyzna, karnacja ciemna i karnacja średnio jasna',
    '👨🏿‍❤‍👨🏽' => 'para z sercem: mężczyzna, mężczyzna, karnacja ciemna i karnacja średnia',
    '👨🏿‍❤‍👨🏾' => 'para z sercem: mężczyzna, mężczyzna, karnacja ciemna i karnacja średnio ciemna',
    '👨🏿‍❤‍👨🏿' => 'para z sercem: mężczyzna, mężczyzna i karnacja ciemna',
    '👨🏻‍🐰‍👨🏼' => 'mężczyźni z uszami królika na przyjęciu: karnacja jasna i karnacja średnio jasna',
    '👨🏻‍🐰‍👨🏽' => 'mężczyźni z uszami królika na przyjęciu: karnacja jasna i karnacja średnia',
    '👨🏻‍🐰‍👨🏾' => 'mężczyźni z uszami królika na przyjęciu: karnacja jasna i karnacja średnio ciemna',
    '👨🏻‍🐰‍👨🏿' => 'mężczyźni z uszami królika na przyjęciu: karnacja jasna i karnacja ciemna',
    '👨🏼‍🐰‍👨🏻' => 'mężczyźni z uszami królika na przyjęciu: karnacja średnio jasna i karnacja jasna',
    '👨🏼‍🐰‍👨🏽' => 'mężczyźni z uszami królika na przyjęciu: karnacja średnio jasna i karnacja średnia',
    '👨🏼‍🐰‍👨🏾' => 'mężczyźni z uszami królika na przyjęciu: karnacja średnio jasna i karnacja średnio ciemna',
    '👨🏼‍🐰‍👨🏿' => 'mężczyźni z uszami królika na przyjęciu: karnacja średnio jasna i karnacja ciemna',
    '👨🏽‍🐰‍👨🏻' => 'mężczyźni z uszami królika na przyjęciu: karnacja średnia i karnacja jasna',
    '👨🏽‍🐰‍👨🏼' => 'mężczyźni z uszami królika na przyjęciu: karnacja średnia i karnacja średnio jasna',
    '👨🏽‍🐰‍👨🏾' => 'mężczyźni z uszami królika na przyjęciu: karnacja średnia i karnacja średnio ciemna',
    '👨🏽‍🐰‍👨🏿' => 'mężczyźni z uszami królika na przyjęciu: karnacja średnia i karnacja ciemna',
    '👨🏾‍🐰‍👨🏻' => 'mężczyźni z uszami królika na przyjęciu: karnacja średnio ciemna i karnacja jasna',
    '👨🏾‍🐰‍👨🏼' => 'mężczyźni z uszami królika na przyjęciu: karnacja średnio ciemna i karnacja średnio jasna',
    '👨🏾‍🐰‍👨🏽' => 'mężczyźni z uszami królika na przyjęciu: karnacja średnio ciemna i karnacja średnia',
    '👨🏾‍🐰‍👨🏿' => 'mężczyźni z uszami królika na przyjęciu: karnacja średnio ciemna i karnacja ciemna',
    '👨🏿‍🐰‍👨🏻' => 'mężczyźni z uszami królika na przyjęciu: karnacja ciemna i karnacja jasna',
    '👨🏿‍🐰‍👨🏼' => 'mężczyźni z uszami królika na przyjęciu: karnacja ciemna i karnacja średnio jasna',
    '👨🏿‍🐰‍👨🏽' => 'mężczyźni z uszami królika na przyjęciu: karnacja ciemna i karnacja średnia',
    '👨🏿‍🐰‍👨🏾' => 'mężczyźni z uszami królika na przyjęciu: karnacja ciemna i karnacja średnio ciemna',
    '👩🏻‍🫯‍👩🏼' => 'kobiety uprawiające zapasy: karnacja jasna i karnacja średnio jasna',
    '👩🏻‍🫯‍👩🏽' => 'kobiety uprawiające zapasy: karnacja jasna i karnacja średnia',
    '👩🏻‍🫯‍👩🏾' => 'kobiety uprawiające zapasy: karnacja jasna i karnacja średnio ciemna',
    '👩🏻‍🫯‍👩🏿' => 'kobiety uprawiające zapasy: karnacja jasna i karnacja ciemna',
    '👩🏼‍🫯‍👩🏻' => 'kobiety uprawiające zapasy: karnacja średnio jasna i karnacja jasna',
    '👩🏼‍🫯‍👩🏽' => 'kobiety uprawiające zapasy: karnacja średnio jasna i karnacja średnia',
    '👩🏼‍🫯‍👩🏾' => 'kobiety uprawiające zapasy: karnacja średnio jasna i karnacja średnio ciemna',
    '👩🏼‍🫯‍👩🏿' => 'kobiety uprawiające zapasy: karnacja średnio jasna i karnacja ciemna',
    '👩🏽‍🫯‍👩🏻' => 'kobiety uprawiające zapasy: karnacja średnia i karnacja jasna',
    '👩🏽‍🫯‍👩🏼' => 'kobiety uprawiające zapasy: karnacja średnia i karnacja średnio jasna',
    '👩🏽‍🫯‍👩🏾' => 'kobiety uprawiające zapasy: karnacja średnia i karnacja średnio ciemna',
    '👩🏽‍🫯‍👩🏿' => 'kobiety uprawiające zapasy: karnacja średnia i karnacja ciemna',
    '👩🏾‍🫯‍👩🏻' => 'kobiety uprawiające zapasy: karnacja średnio ciemna i karnacja jasna',
    '👩🏾‍🫯‍👩🏼' => 'kobiety uprawiające zapasy: karnacja średnio ciemna i karnacja średnio jasna',
    '👩🏾‍🫯‍👩🏽' => 'kobiety uprawiające zapasy: karnacja średnio ciemna i karnacja średnia',
    '👩🏾‍🫯‍👩🏿' => 'kobiety uprawiające zapasy: karnacja średnio ciemna i karnacja ciemna',
    '👩🏿‍🫯‍👩🏻' => 'kobiety uprawiające zapasy: karnacja ciemna i karnacja jasna',
    '👩🏿‍🫯‍👩🏼' => 'kobiety uprawiające zapasy: karnacja ciemna i karnacja średnio jasna',
    '👩🏿‍🫯‍👩🏽' => 'kobiety uprawiające zapasy: karnacja ciemna i karnacja średnia',
    '👩🏿‍🫯‍👩🏾' => 'kobiety uprawiające zapasy: karnacja ciemna i karnacja średnio ciemna',
    '👩🏻‍❤‍👨🏻' => 'para z sercem: kobieta, mężczyzna i karnacja jasna',
    '👩🏻‍❤‍👨🏼' => 'para z sercem: kobieta, mężczyzna, karnacja jasna i karnacja średnio jasna',
    '👩🏻‍❤‍👨🏽' => 'para z sercem: kobieta, mężczyzna, karnacja jasna i karnacja średnia',
    '👩🏻‍❤‍👨🏾' => 'para z sercem: kobieta, mężczyzna, karnacja jasna i karnacja średnio ciemna',
    '👩🏻‍❤‍👨🏿' => 'para z sercem: kobieta, mężczyzna, karnacja jasna i karnacja ciemna',
    '👩🏼‍❤‍👨🏻' => 'para z sercem: kobieta, mężczyzna, karnacja średnio jasna i karnacja jasna',
    '👩🏼‍❤‍👨🏼' => 'para z sercem: kobieta, mężczyzna i karnacja średnio jasna',
    '👩🏼‍❤‍👨🏽' => 'para z sercem: kobieta, mężczyzna, karnacja średnio jasna i karnacja średnia',
    '👩🏼‍❤‍👨🏾' => 'para z sercem: kobieta, mężczyzna, karnacja średnio jasna i karnacja średnio ciemna',
    '👩🏼‍❤‍👨🏿' => 'para z sercem: kobieta, mężczyzna, karnacja średnio jasna i karnacja ciemna',
    '👩🏽‍❤‍👨🏻' => 'para z sercem: kobieta, mężczyzna, karnacja średnia i karnacja jasna',
    '👩🏽‍❤‍👨🏼' => 'para z sercem: kobieta, mężczyzna, karnacja średnia i karnacja średnio jasna',
    '👩🏽‍❤‍👨🏽' => 'para z sercem: kobieta, mężczyzna i karnacja średnia',
    '👩🏽‍❤‍👨🏾' => 'para z sercem: kobieta, mężczyzna, karnacja średnia i karnacja średnio ciemna',
    '👩🏽‍❤‍👨🏿' => 'para z sercem: kobieta, mężczyzna, karnacja średnia i karnacja ciemna',
    '👩🏾‍❤‍👨🏻' => 'para z sercem: kobieta, mężczyzna, karnacja średnio ciemna i karnacja jasna',
    '👩🏾‍❤‍👨🏼' => 'para z sercem: kobieta, mężczyzna, karnacja średnio ciemna i karnacja średnio jasna',
    '👩🏾‍❤‍👨🏽' => 'para z sercem: kobieta, mężczyzna, karnacja średnio ciemna i karnacja średnia',
    '👩🏾‍❤‍👨🏾' => 'para z sercem: kobieta, mężczyzna i karnacja średnio ciemna',
    '👩🏾‍❤‍👨🏿' => 'para z sercem: kobieta, mężczyzna, karnacja średnio ciemna i karnacja ciemna',
    '👩🏿‍❤‍👨🏻' => 'para z sercem: kobieta, mężczyzna, karnacja ciemna i karnacja jasna',
    '👩🏿‍❤‍👨🏼' => 'para z sercem: kobieta, mężczyzna, karnacja ciemna i karnacja średnio jasna',
    '👩🏿‍❤‍👨🏽' => 'para z sercem: kobieta, mężczyzna, karnacja ciemna i karnacja średnia',
    '👩🏿‍❤‍👨🏾' => 'para z sercem: kobieta, mężczyzna, karnacja ciemna i karnacja średnio ciemna',
    '👩🏿‍❤‍👨🏿' => 'para z sercem: kobieta, mężczyzna i karnacja ciemna',
    '👩🏻‍❤‍👩🏻' => 'para z sercem: kobieta, kobieta i karnacja jasna',
    '👩🏻‍❤‍👩🏼' => 'para z sercem: kobieta, kobieta, karnacja jasna i karnacja średnio jasna',
    '👩🏻‍❤‍👩🏽' => 'para z sercem: kobieta, kobieta, karnacja jasna i karnacja średnia',
    '👩🏻‍❤‍👩🏾' => 'para z sercem: kobieta, kobieta, karnacja jasna i karnacja średnio ciemna',
    '👩🏻‍❤‍👩🏿' => 'para z sercem: kobieta, kobieta, karnacja jasna i karnacja ciemna',
    '👩🏼‍❤‍👩🏻' => 'para z sercem: kobieta, kobieta, karnacja średnio jasna i karnacja jasna',
    '👩🏼‍❤‍👩🏼' => 'para z sercem: kobieta, kobieta i karnacja średnio jasna',
    '👩🏼‍❤‍👩🏽' => 'para z sercem: kobieta, kobieta, karnacja średnio jasna i karnacja średnia',
    '👩🏼‍❤‍👩🏾' => 'para z sercem: kobieta, kobieta, karnacja średnio jasna i karnacja średnio ciemna',
    '👩🏼‍❤‍👩🏿' => 'para z sercem: kobieta, kobieta, karnacja średnio jasna i karnacja ciemna',
    '👩🏽‍❤‍👩🏻' => 'para z sercem: kobieta, kobieta, karnacja średnia i karnacja jasna',
    '👩🏽‍❤‍👩🏼' => 'para z sercem: kobieta, kobieta, karnacja średnia i karnacja średnio jasna',
    '👩🏽‍❤‍👩🏽' => 'para z sercem: kobieta, kobieta i karnacja średnia',
    '👩🏽‍❤‍👩🏾' => 'para z sercem: kobieta, kobieta, karnacja średnia i karnacja średnio ciemna',
    '👩🏽‍❤‍👩🏿' => 'para z sercem: kobieta, kobieta, karnacja średnia i karnacja ciemna',
    '👩🏾‍❤‍👩🏻' => 'para z sercem: kobieta, kobieta, karnacja średnio ciemna i karnacja jasna',
    '👩🏾‍❤‍👩🏼' => 'para z sercem: kobieta, kobieta, karnacja średnio ciemna i karnacja średnio jasna',
    '👩🏾‍❤‍👩🏽' => 'para z sercem: kobieta, kobieta, karnacja średnio ciemna i karnacja średnia',
    '👩🏾‍❤‍👩🏾' => 'para z sercem: kobieta, kobieta i karnacja średnio ciemna',
    '👩🏾‍❤‍👩🏿' => 'para z sercem: kobieta, kobieta, karnacja średnio ciemna i karnacja ciemna',
    '👩🏿‍❤‍👩🏻' => 'para z sercem: kobieta, kobieta, karnacja ciemna i karnacja jasna',
    '👩🏿‍❤‍👩🏼' => 'para z sercem: kobieta, kobieta, karnacja ciemna i karnacja średnio jasna',
    '👩🏿‍❤‍👩🏽' => 'para z sercem: kobieta, kobieta, karnacja ciemna i karnacja średnia',
    '👩🏿‍❤‍👩🏾' => 'para z sercem: kobieta, kobieta, karnacja ciemna i karnacja średnio ciemna',
    '👩🏿‍❤‍👩🏿' => 'para z sercem: kobieta, kobieta i karnacja ciemna',
    '👩🏻‍🐰‍👩🏼' => 'kobiety z uszami królika na przyjęciu: karnacja jasna i karnacja średnio jasna',
    '👩🏻‍🐰‍👩🏽' => 'kobiety z uszami królika na przyjęciu: karnacja jasna i karnacja średnia',
    '👩🏻‍🐰‍👩🏾' => 'kobiety z uszami królika na przyjęciu: karnacja jasna i karnacja średnio ciemna',
    '👩🏻‍🐰‍👩🏿' => 'kobiety z uszami królika na przyjęciu: karnacja jasna i karnacja ciemna',
    '👩🏼‍🐰‍👩🏻' => 'kobiety z uszami królika na przyjęciu: karnacja średnio jasna i karnacja jasna',
    '👩🏼‍🐰‍👩🏽' => 'kobiety z uszami królika na przyjęciu: karnacja średnio jasna i karnacja średnia',
    '👩🏼‍🐰‍👩🏾' => 'kobiety z uszami królika na przyjęciu: karnacja średnio jasna i karnacja średnio ciemna',
    '👩🏼‍🐰‍👩🏿' => 'kobiety z uszami królika na przyjęciu: karnacja średnio jasna i karnacja ciemna',
    '👩🏽‍🐰‍👩🏻' => 'kobiety z uszami królika na przyjęciu: karnacja średnia i karnacja jasna',
    '👩🏽‍🐰‍👩🏼' => 'kobiety z uszami królika na przyjęciu: karnacja średnia i karnacja średnio jasna',
    '👩🏽‍🐰‍👩🏾' => 'kobiety z uszami królika na przyjęciu: karnacja średnia i karnacja średnio ciemna',
    '👩🏽‍🐰‍👩🏿' => 'kobiety z uszami królika na przyjęciu: karnacja średnia i karnacja ciemna',
    '👩🏾‍🐰‍👩🏻' => 'kobiety z uszami królika na przyjęciu: karnacja średnio ciemna i karnacja jasna',
    '👩🏾‍🐰‍👩🏼' => 'kobiety z uszami królika na przyjęciu: karnacja średnio ciemna i karnacja średnio jasna',
    '👩🏾‍🐰‍👩🏽' => 'kobiety z uszami królika na przyjęciu: karnacja średnio ciemna i karnacja średnia',
    '👩🏾‍🐰‍👩🏿' => 'kobiety z uszami królika na przyjęciu: karnacja średnio ciemna i karnacja ciemna',
    '👩🏿‍🐰‍👩🏻' => 'kobiety z uszami królika na przyjęciu: karnacja ciemna i karnacja jasna',
    '👩🏿‍🐰‍👩🏼' => 'kobiety z uszami królika na przyjęciu: karnacja ciemna i karnacja średnio jasna',
    '👩🏿‍🐰‍👩🏽' => 'kobiety z uszami królika na przyjęciu: karnacja ciemna i karnacja średnia',
    '👩🏿‍🐰‍👩🏾' => 'kobiety z uszami królika na przyjęciu: karnacja ciemna i karnacja średnio ciemna',
    '🧑🏻‍🤝‍🧑🏻' => 'osoby trzymające się za ręce: karnacja jasna',
    '🧑🏻‍🤝‍🧑🏼' => 'osoby trzymające się za ręce: karnacja jasna i karnacja średnio jasna',
    '🧑🏻‍🤝‍🧑🏽' => 'osoby trzymające się za ręce: karnacja jasna i karnacja średnia',
    '🧑🏻‍🤝‍🧑🏾' => 'osoby trzymające się za ręce: karnacja jasna i karnacja średnio ciemna',
    '🧑🏻‍🤝‍🧑🏿' => 'osoby trzymające się za ręce: karnacja jasna i karnacja ciemna',
    '🧑🏼‍🤝‍🧑🏻' => 'osoby trzymające się za ręce: karnacja średnio jasna i karnacja jasna',
    '🧑🏼‍🤝‍🧑🏼' => 'osoby trzymające się za ręce: karnacja średnio jasna',
    '🧑🏼‍🤝‍🧑🏽' => 'osoby trzymające się za ręce: karnacja średnio jasna i karnacja średnia',
    '🧑🏼‍🤝‍🧑🏾' => 'osoby trzymające się za ręce: karnacja średnio jasna i karnacja średnio ciemna',
    '🧑🏼‍🤝‍🧑🏿' => 'osoby trzymające się za ręce: karnacja średnio jasna i karnacja ciemna',
    '🧑🏽‍🤝‍🧑🏻' => 'osoby trzymające się za ręce: karnacja średnia i karnacja jasna',
    '🧑🏽‍🤝‍🧑🏼' => 'osoby trzymające się za ręce: karnacja średnia i karnacja średnio jasna',
    '🧑🏽‍🤝‍🧑🏽' => 'osoby trzymające się za ręce: karnacja średnia',
    '🧑🏽‍🤝‍🧑🏾' => 'osoby trzymające się za ręce: karnacja średnia i karnacja średnio ciemna',
    '🧑🏽‍🤝‍🧑🏿' => 'osoby trzymające się za ręce: karnacja średnia i karnacja ciemna',
    '🧑🏾‍🤝‍🧑🏻' => 'osoby trzymające się za ręce: karnacja średnio ciemna i karnacja jasna',
    '🧑🏾‍🤝‍🧑🏼' => 'osoby trzymające się za ręce: karnacja średnio ciemna i karnacja średnio jasna',
    '🧑🏾‍🤝‍🧑🏽' => 'osoby trzymające się za ręce: karnacja średnio ciemna i karnacja średnia',
    '🧑🏾‍🤝‍🧑🏾' => 'osoby trzymające się za ręce: karnacja średnio ciemna',
    '🧑🏾‍🤝‍🧑🏿' => 'osoby trzymające się za ręce: karnacja średnio ciemna i karnacja ciemna',
    '🧑🏿‍🤝‍🧑🏻' => 'osoby trzymające się za ręce: karnacja ciemna i karnacja jasna',
    '🧑🏿‍🤝‍🧑🏼' => 'osoby trzymające się za ręce: karnacja ciemna i karnacja średnio jasna',
    '🧑🏿‍🤝‍🧑🏽' => 'osoby trzymające się za ręce: karnacja ciemna i karnacja średnia',
    '🧑🏿‍🤝‍🧑🏾' => 'osoby trzymające się za ręce: karnacja ciemna i karnacja średnio ciemna',
    '🧑🏿‍🤝‍🧑🏿' => 'osoby trzymające się za ręce: karnacja ciemna',
    '👩🏻‍🤝‍👩🏼' => 'kobiety trzymające się za ręce: karnacja jasna i karnacja średnio jasna',
    '👩🏻‍🤝‍👩🏽' => 'kobiety trzymające się za ręce: karnacja jasna i karnacja średnia',
    '👩🏻‍🤝‍👩🏾' => 'kobiety trzymające się za ręce: karnacja jasna i karnacja średnio ciemna',
    '👩🏻‍🤝‍👩🏿' => 'kobiety trzymające się za ręce: karnacja jasna i karnacja ciemna',
    '👩🏼‍🤝‍👩🏻' => 'kobiety trzymające się za ręce: karnacja średnio jasna i karnacja jasna',
    '👩🏼‍🤝‍👩🏽' => 'kobiety trzymające się za ręce: karnacja średnio jasna i karnacja średnia',
    '👩🏼‍🤝‍👩🏾' => 'kobiety trzymające się za ręce: karnacja średnio jasna i karnacja średnio ciemna',
    '👩🏼‍🤝‍👩🏿' => 'kobiety trzymające się za ręce: karnacja średnio jasna i karnacja ciemna',
    '👩🏽‍🤝‍👩🏻' => 'kobiety trzymające się za ręce: karnacja średnia i karnacja jasna',
    '👩🏽‍🤝‍👩🏼' => 'kobiety trzymające się za ręce: karnacja średnia i karnacja średnio jasna',
    '👩🏽‍🤝‍👩🏾' => 'kobiety trzymające się za ręce: karnacja średnia i karnacja średnio ciemna',
    '👩🏽‍🤝‍👩🏿' => 'kobiety trzymające się za ręce: karnacja średnia i karnacja ciemna',
    '👩🏾‍🤝‍👩🏻' => 'kobiety trzymające się za ręce: karnacja średnio ciemna i karnacja jasna',
    '👩🏾‍🤝‍👩🏼' => 'kobiety trzymające się za ręce: karnacja średnio ciemna i karnacja średnio jasna',
    '👩🏾‍🤝‍👩🏽' => 'kobiety trzymające się za ręce: karnacja średnio ciemna i karnacja średnia',
    '👩🏾‍🤝‍👩🏿' => 'kobiety trzymające się za ręce: karnacja średnio ciemna i karnacja ciemna',
    '👩🏿‍🤝‍👩🏻' => 'kobiety trzymające się za ręce: karnacja ciemna i karnacja jasna',
    '👩🏿‍🤝‍👩🏼' => 'kobiety trzymające się za ręce: karnacja ciemna i karnacja średnio jasna',
    '👩🏿‍🤝‍👩🏽' => 'kobiety trzymające się za ręce: karnacja ciemna i karnacja średnia',
    '👩🏿‍🤝‍👩🏾' => 'kobiety trzymające się za ręce: karnacja ciemna i karnacja średnio ciemna',
    '👩🏻‍🤝‍👨🏼' => 'mężczyzna i kobieta trzymający się za ręce: karnacja jasna i karnacja średnio jasna',
    '👩🏻‍🤝‍👨🏽' => 'mężczyzna i kobieta trzymający się za ręce: karnacja jasna i karnacja średnia',
    '👩🏻‍🤝‍👨🏾' => 'mężczyzna i kobieta trzymający się za ręce: karnacja jasna i karnacja średnio ciemna',
    '👩🏻‍🤝‍👨🏿' => 'mężczyzna i kobieta trzymający się za ręce: karnacja jasna i karnacja ciemna',
    '👩🏼‍🤝‍👨🏻' => 'mężczyzna i kobieta trzymający się za ręce: karnacja średnio jasna i karnacja jasna',
    '👩🏼‍🤝‍👨🏽' => 'mężczyzna i kobieta trzymający się za ręce: karnacja średnio jasna i karnacja średnia',
    '👩🏼‍🤝‍👨🏾' => 'mężczyzna i kobieta trzymający się za ręce: karnacja średnio jasna i karnacja średnio ciemna',
    '👩🏼‍🤝‍👨🏿' => 'mężczyzna i kobieta trzymający się za ręce: karnacja średnio jasna i karnacja ciemna',
    '👩🏽‍🤝‍👨🏻' => 'mężczyzna i kobieta trzymający się za ręce: karnacja średnia i karnacja jasna',
    '👩🏽‍🤝‍👨🏼' => 'mężczyzna i kobieta trzymający się za ręce: karnacja średnia i karnacja średnio jasna',
    '👩🏽‍🤝‍👨🏾' => 'mężczyzna i kobieta trzymający się za ręce: karnacja średnia i karnacja średnio ciemna',
    '👩🏽‍🤝‍👨🏿' => 'mężczyzna i kobieta trzymający się za ręce: karnacja średnia i karnacja ciemna',
    '👩🏾‍🤝‍👨🏻' => 'mężczyzna i kobieta trzymający się za ręce: karnacja średnio ciemna i karnacja jasna',
    '👩🏾‍🤝‍👨🏼' => 'mężczyzna i kobieta trzymający się za ręce: karnacja średnio ciemna i karnacja średnio jasna',
    '👩🏾‍🤝‍👨🏽' => 'mężczyzna i kobieta trzymający się za ręce: karnacja średnio ciemna i karnacja średnia',
    '👩🏾‍🤝‍👨🏿' => 'mężczyzna i kobieta trzymający się za ręce: karnacja średnio ciemna i karnacja ciemna',
    '👩🏿‍🤝‍👨🏻' => 'mężczyzna i kobieta trzymający się za ręce: karnacja ciemna i karnacja jasna',
    '👩🏿‍🤝‍👨🏼' => 'mężczyzna i kobieta trzymający się za ręce: karnacja ciemna i karnacja średnio jasna',
    '👩🏿‍🤝‍👨🏽' => 'mężczyzna i kobieta trzymający się za ręce: karnacja ciemna i karnacja średnia',
    '👩🏿‍🤝‍👨🏾' => 'mężczyzna i kobieta trzymający się za ręce: karnacja ciemna i karnacja średnio ciemna',
    '👨🏻‍🤝‍👨🏼' => 'dwóch mężczyzn trzymających się za ręce: karnacja jasna i karnacja średnio jasna',
    '👨🏻‍🤝‍👨🏽' => 'dwóch mężczyzn trzymających się za ręce: karnacja jasna i karnacja średnia',
    '👨🏻‍🤝‍👨🏾' => 'dwóch mężczyzn trzymających się za ręce: karnacja jasna i karnacja średnio ciemna',
    '👨🏻‍🤝‍👨🏿' => 'dwóch mężczyzn trzymających się za ręce: karnacja jasna i karnacja ciemna',
    '👨🏼‍🤝‍👨🏻' => 'dwóch mężczyzn trzymających się za ręce: karnacja średnio jasna i karnacja jasna',
    '👨🏼‍🤝‍👨🏽' => 'dwóch mężczyzn trzymających się za ręce: karnacja średnio jasna i karnacja średnia',
    '👨🏼‍🤝‍👨🏾' => 'dwóch mężczyzn trzymających się za ręce: karnacja średnio jasna i karnacja średnio ciemna',
    '👨🏼‍🤝‍👨🏿' => 'dwóch mężczyzn trzymających się za ręce: karnacja średnio jasna i karnacja ciemna',
    '👨🏽‍🤝‍👨🏻' => 'dwóch mężczyzn trzymających się za ręce: karnacja średnia i karnacja jasna',
    '👨🏽‍🤝‍👨🏼' => 'dwóch mężczyzn trzymających się za ręce: karnacja średnia i karnacja średnio jasna',
    '👨🏽‍🤝‍👨🏾' => 'dwóch mężczyzn trzymających się za ręce: karnacja średnia i karnacja średnio ciemna',
    '👨🏽‍🤝‍👨🏿' => 'dwóch mężczyzn trzymających się za ręce: karnacja średnia i karnacja ciemna',
    '👨🏾‍🤝‍👨🏻' => 'dwóch mężczyzn trzymających się za ręce: karnacja średnio ciemna i karnacja jasna',
    '👨🏾‍🤝‍👨🏼' => 'dwóch mężczyzn trzymających się za ręce: karnacja średnio ciemna i karnacja średnio jasna',
    '👨🏾‍🤝‍👨🏽' => 'dwóch mężczyzn trzymających się za ręce: karnacja średnio ciemna i karnacja średnia',
    '👨🏾‍🤝‍👨🏿' => 'dwóch mężczyzn trzymających się za ręce: karnacja średnio ciemna i karnacja ciemna',
    '👨🏿‍🤝‍👨🏻' => 'dwóch mężczyzn trzymających się za ręce: karnacja ciemna i karnacja jasna',
    '👨🏿‍🤝‍👨🏼' => 'dwóch mężczyzn trzymających się za ręce: karnacja ciemna i karnacja średnio jasna',
    '👨🏿‍🤝‍👨🏽' => 'dwóch mężczyzn trzymających się za ręce: karnacja ciemna i karnacja średnia',
    '👨🏿‍🤝‍👨🏾' => 'dwóch mężczyzn trzymających się za ręce: karnacja ciemna i karnacja średnio ciemna',
    '👩‍❤‍💋‍👨' => 'pocałunek: kobieta i mężczyzna',
    '👨‍❤‍💋‍👨' => 'pocałunek: mężczyzna i mężczyzna',
    '👩‍❤‍💋‍👩' => 'pocałunek: kobieta i kobieta',
    '👨‍👩‍👧‍👦' => 'rodzina: mężczyzna, kobieta, dziewczynka i chłopiec',
    '👨‍👩‍👦‍👦' => 'rodzina: mężczyzna, kobieta, chłopiec i chłopiec',
    '👨‍👩‍👧‍👧' => 'rodzina: mężczyzna, kobieta, dziewczynka i dziewczynka',
    '👨‍👨‍👧‍👦' => 'rodzina: mężczyzna, mężczyzna, dziewczynka i chłopiec',
    '👨‍👨‍👦‍👦' => 'rodzina: mężczyzna, mężczyzna, chłopiec i chłopiec',
    '👨‍👨‍👧‍👧' => 'rodzina: mężczyzna, mężczyzna, dziewczynka i dziewczynka',
    '👩‍👩‍👧‍👦' => 'rodzina: kobieta, kobieta, dziewczynka i chłopiec',
    '👩‍👩‍👦‍👦' => 'rodzina: kobieta, kobieta, chłopiec i chłopiec',
    '👩‍👩‍👧‍👧' => 'rodzina: kobieta, kobieta, dziewczynka i dziewczynka',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'flaga: Anglia',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'flaga: Szkocja',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'flaga: Walia',
    '🧑‍🧑‍🧒‍🧒' => 'rodzina: dorosły, dorosły, dziecko, dziecko',
    '🚶🏻‍♀‍➡' => 'idąca kobieta: karnacja jasna i zwrócony w prawo',
    '🚶🏼‍♀‍➡' => 'idąca kobieta: karnacja średnio jasna i zwrócony w prawo',
    '🚶🏽‍♀‍➡' => 'idąca kobieta: karnacja średnia i zwrócony w prawo',
    '🚶🏾‍♀‍➡' => 'idąca kobieta: karnacja średnio ciemna i zwrócony w prawo',
    '🚶🏿‍♀‍➡' => 'idąca kobieta: karnacja ciemna i zwrócony w prawo',
    '🚶🏻‍♂‍➡' => 'idący mężczyzna: karnacja jasna i zwrócony w prawo',
    '🚶🏼‍♂‍➡' => 'idący mężczyzna: karnacja średnio jasna i zwrócony w prawo',
    '🚶🏽‍♂‍➡' => 'idący mężczyzna: karnacja średnia i zwrócony w prawo',
    '🚶🏾‍♂‍➡' => 'idący mężczyzna: karnacja średnio ciemna i zwrócony w prawo',
    '🚶🏿‍♂‍➡' => 'idący mężczyzna: karnacja ciemna i zwrócony w prawo',
    '🧎🏻‍♀‍➡' => 'klęcząca kobieta: karnacja jasna i zwrócony w prawo',
    '🧎🏼‍♀‍➡' => 'klęcząca kobieta: karnacja średnio jasna i zwrócony w prawo',
    '🧎🏽‍♀‍➡' => 'klęcząca kobieta: karnacja średnia i zwrócony w prawo',
    '🧎🏾‍♀‍➡' => 'klęcząca kobieta: karnacja średnio ciemna i zwrócony w prawo',
    '🧎🏿‍♀‍➡' => 'klęcząca kobieta: karnacja ciemna i zwrócony w prawo',
    '🧎🏻‍♂‍➡' => 'klęczący mężczyzna: karnacja jasna i zwrócony w prawo',
    '🧎🏼‍♂‍➡' => 'klęczący mężczyzna: karnacja średnio jasna i zwrócony w prawo',
    '🧎🏽‍♂‍➡' => 'klęczący mężczyzna: karnacja średnia i zwrócony w prawo',
    '🧎🏾‍♂‍➡' => 'klęczący mężczyzna: karnacja średnio ciemna i zwrócony w prawo',
    '🧎🏿‍♂‍➡' => 'klęczący mężczyzna: karnacja ciemna i zwrócony w prawo',
    '🧑🏻‍🦯‍➡' => 'osoba z białą laską: karnacja jasna i zwrócony w prawo',
    '🧑🏼‍🦯‍➡' => 'osoba z białą laską: karnacja średnio jasna i zwrócony w prawo',
    '🧑🏽‍🦯‍➡' => 'osoba z białą laską: karnacja średnia i zwrócony w prawo',
    '🧑🏾‍🦯‍➡' => 'osoba z białą laską: karnacja średnio ciemna i zwrócony w prawo',
    '🧑🏿‍🦯‍➡' => 'osoba z białą laską: karnacja ciemna i zwrócony w prawo',
    '👨🏻‍🦯‍➡' => 'mężczyzna z białą laską: karnacja jasna i zwrócony w prawo',
    '👨🏼‍🦯‍➡' => 'mężczyzna z białą laską: karnacja średnio jasna i zwrócony w prawo',
    '👨🏽‍🦯‍➡' => 'mężczyzna z białą laską: karnacja średnia i zwrócony w prawo',
    '👨🏾‍🦯‍➡' => 'mężczyzna z białą laską: karnacja średnio ciemna i zwrócony w prawo',
    '👨🏿‍🦯‍➡' => 'mężczyzna z białą laską: karnacja ciemna i zwrócony w prawo',
    '👩🏻‍🦯‍➡' => 'kobieta z białą laską: karnacja jasna i zwrócony w prawo',
    '👩🏼‍🦯‍➡' => 'kobieta z białą laską: karnacja średnio jasna i zwrócony w prawo',
    '👩🏽‍🦯‍➡' => 'kobieta z białą laską: karnacja średnia i zwrócony w prawo',
    '👩🏾‍🦯‍➡' => 'kobieta z białą laską: karnacja średnio ciemna i zwrócony w prawo',
    '👩🏿‍🦯‍➡' => 'kobieta z białą laską: karnacja ciemna i zwrócony w prawo',
    '🧑🏻‍🦼‍➡' => 'osoba na elektrycznym wózku inwalidzkim: karnacja jasna i zwrócony w prawo',
    '🧑🏼‍🦼‍➡' => 'osoba na elektrycznym wózku inwalidzkim: karnacja średnio jasna i zwrócony w prawo',
    '🧑🏽‍🦼‍➡' => 'osoba na elektrycznym wózku inwalidzkim: karnacja średnia i zwrócony w prawo',
    '🧑🏾‍🦼‍➡' => 'osoba na elektrycznym wózku inwalidzkim: karnacja średnio ciemna i zwrócony w prawo',
    '🧑🏿‍🦼‍➡' => 'osoba na elektrycznym wózku inwalidzkim: karnacja ciemna i zwrócony w prawo',
    '👨🏻‍🦼‍➡' => 'mężczyzna na elektrycznym wózku inwalidzkim: karnacja jasna i zwrócony w prawo',
    '👨🏼‍🦼‍➡' => 'mężczyzna na elektrycznym wózku inwalidzkim: karnacja średnio jasna i zwrócony w prawo',
    '👨🏽‍🦼‍➡' => 'mężczyzna na elektrycznym wózku inwalidzkim: karnacja średnia i zwrócony w prawo',
    '👨🏾‍🦼‍➡' => 'mężczyzna na elektrycznym wózku inwalidzkim: karnacja średnio ciemna i zwrócony w prawo',
    '👨🏿‍🦼‍➡' => 'mężczyzna na elektrycznym wózku inwalidzkim: karnacja ciemna i zwrócony w prawo',
    '👩🏻‍🦼‍➡' => 'kobieta na elektrycznym wózku inwalidzkim: karnacja jasna i zwrócony w prawo',
    '👩🏼‍🦼‍➡' => 'kobieta na elektrycznym wózku inwalidzkim: karnacja średnio jasna i zwrócony w prawo',
    '👩🏽‍🦼‍➡' => 'kobieta na elektrycznym wózku inwalidzkim: karnacja średnia i zwrócony w prawo',
    '👩🏾‍🦼‍➡' => 'kobieta na elektrycznym wózku inwalidzkim: karnacja średnio ciemna i zwrócony w prawo',
    '👩🏿‍🦼‍➡' => 'kobieta na elektrycznym wózku inwalidzkim: karnacja ciemna i zwrócony w prawo',
    '🧑🏻‍🦽‍➡' => 'osoba na wózku inwalidzkim: karnacja jasna i zwrócony w prawo',
    '🧑🏼‍🦽‍➡' => 'osoba na wózku inwalidzkim: karnacja średnio jasna i zwrócony w prawo',
    '🧑🏽‍🦽‍➡' => 'osoba na wózku inwalidzkim: karnacja średnia i zwrócony w prawo',
    '🧑🏾‍🦽‍➡' => 'osoba na wózku inwalidzkim: karnacja średnio ciemna i zwrócony w prawo',
    '🧑🏿‍🦽‍➡' => 'osoba na wózku inwalidzkim: karnacja ciemna i zwrócony w prawo',
    '👨🏻‍🦽‍➡' => 'mężczyzna na wózku inwalidzkim: karnacja jasna i zwrócony w prawo',
    '👨🏼‍🦽‍➡' => 'mężczyzna na wózku inwalidzkim: karnacja średnio jasna i zwrócony w prawo',
    '👨🏽‍🦽‍➡' => 'mężczyzna na wózku inwalidzkim: karnacja średnia i zwrócony w prawo',
    '👨🏾‍🦽‍➡' => 'mężczyzna na wózku inwalidzkim: karnacja średnio ciemna i zwrócony w prawo',
    '👨🏿‍🦽‍➡' => 'mężczyzna na wózku inwalidzkim: karnacja ciemna i zwrócony w prawo',
    '👩🏻‍🦽‍➡' => 'kobieta na wózku inwalidzkim: karnacja jasna i zwrócony w prawo',
    '👩🏼‍🦽‍➡' => 'kobieta na wózku inwalidzkim: karnacja średnio jasna i zwrócony w prawo',
    '👩🏽‍🦽‍➡' => 'kobieta na wózku inwalidzkim: karnacja średnia i zwrócony w prawo',
    '👩🏾‍🦽‍➡' => 'kobieta na wózku inwalidzkim: karnacja średnio ciemna i zwrócony w prawo',
    '👩🏿‍🦽‍➡' => 'kobieta na wózku inwalidzkim: karnacja ciemna i zwrócony w prawo',
    '🏃🏻‍♀‍➡' => 'biegnąca kobieta: karnacja jasna i zwrócony w prawo',
    '🏃🏼‍♀‍➡' => 'biegnąca kobieta: karnacja średnio jasna i zwrócony w prawo',
    '🏃🏽‍♀‍➡' => 'biegnąca kobieta: karnacja średnia i zwrócony w prawo',
    '🏃🏾‍♀‍➡' => 'biegnąca kobieta: karnacja średnio ciemna i zwrócony w prawo',
    '🏃🏿‍♀‍➡' => 'biegnąca kobieta: karnacja ciemna i zwrócony w prawo',
    '🏃🏻‍♂‍➡' => 'biegnący mężczyzna: karnacja jasna i zwrócony w prawo',
    '🏃🏼‍♂‍➡' => 'biegnący mężczyzna: karnacja średnio jasna i zwrócony w prawo',
    '🏃🏽‍♂‍➡' => 'biegnący mężczyzna: karnacja średnia i zwrócony w prawo',
    '🏃🏾‍♂‍➡' => 'biegnący mężczyzna: karnacja średnio ciemna i zwrócony w prawo',
    '🏃🏿‍♂‍➡' => 'biegnący mężczyzna: karnacja ciemna i zwrócony w prawo',
    '🫱🏻‍🫲🏼' => 'uścisk dłoni: karnacja jasna i karnacja średnio jasna',
    '🫱🏻‍🫲🏽' => 'uścisk dłoni: karnacja jasna i karnacja średnia',
    '🫱🏻‍🫲🏾' => 'uścisk dłoni: karnacja jasna i karnacja średnio ciemna',
    '🫱🏻‍🫲🏿' => 'uścisk dłoni: karnacja jasna i karnacja ciemna',
    '🫱🏼‍🫲🏻' => 'uścisk dłoni: karnacja średnio jasna i karnacja jasna',
    '🫱🏼‍🫲🏽' => 'uścisk dłoni: karnacja średnio jasna i karnacja średnia',
    '🫱🏼‍🫲🏾' => 'uścisk dłoni: karnacja średnio jasna i karnacja średnio ciemna',
    '🫱🏼‍🫲🏿' => 'uścisk dłoni: karnacja średnio jasna i karnacja ciemna',
    '🫱🏽‍🫲🏻' => 'uścisk dłoni: karnacja średnia i karnacja jasna',
    '🫱🏽‍🫲🏼' => 'uścisk dłoni: karnacja średnia i karnacja średnio jasna',
    '🫱🏽‍🫲🏾' => 'uścisk dłoni: karnacja średnia i karnacja średnio ciemna',
    '🫱🏽‍🫲🏿' => 'uścisk dłoni: karnacja średnia i karnacja ciemna',
    '🫱🏾‍🫲🏻' => 'uścisk dłoni: karnacja średnio ciemna i karnacja jasna',
    '🫱🏾‍🫲🏼' => 'uścisk dłoni: karnacja średnio ciemna i karnacja średnio jasna',
    '🫱🏾‍🫲🏽' => 'uścisk dłoni: karnacja średnio ciemna i karnacja średnia',
    '🫱🏾‍🫲🏿' => 'uścisk dłoni: karnacja średnio ciemna i karnacja ciemna',
    '🫱🏿‍🫲🏻' => 'uścisk dłoni: karnacja ciemna i karnacja jasna',
    '🫱🏿‍🫲🏼' => 'uścisk dłoni: karnacja ciemna i karnacja średnio jasna',
    '🫱🏿‍🫲🏽' => 'uścisk dłoni: karnacja ciemna i karnacja średnia',
    '🫱🏿‍🫲🏾' => 'uścisk dłoni: karnacja ciemna i karnacja średnio ciemna',
    '🚶‍♀‍➡' => 'idąca kobieta: zwrócony w prawo',
    '🚶‍♂‍➡' => 'idący mężczyzna: zwrócony w prawo',
    '🧎‍♀‍➡' => 'klęcząca kobieta: zwrócony w prawo',
    '🧎‍♂‍➡' => 'klęczący mężczyzna: zwrócony w prawo',
    '🧑‍🦯‍➡' => 'osoba z białą laską: zwrócony w prawo',
    '👨‍🦯‍➡' => 'mężczyzna z białą laską: zwrócony w prawo',
    '👩‍🦯‍➡' => 'kobieta z białą laską: zwrócony w prawo',
    '🧑‍🦼‍➡' => 'osoba na elektrycznym wózku inwalidzkim: zwrócony w prawo',
    '👨‍🦼‍➡' => 'mężczyzna na elektrycznym wózku inwalidzkim: zwrócony w prawo',
    '👩‍🦼‍➡' => 'kobieta na elektrycznym wózku inwalidzkim: zwrócony w prawo',
    '🧑‍🦽‍➡' => 'osoba na wózku inwalidzkim: zwrócony w prawo',
    '👨‍🦽‍➡' => 'mężczyzna na wózku inwalidzkim: zwrócony w prawo',
    '👩‍🦽‍➡' => 'kobieta na wózku inwalidzkim: zwrócony w prawo',
    '🏃‍♀‍➡' => 'biegnąca kobieta: zwrócony w prawo',
    '🏃‍♂‍➡' => 'biegnący mężczyzna: zwrócony w prawo',
    '👩‍❤‍👨' => 'para z sercem: kobieta i mężczyzna',
    '👨‍❤‍👨' => 'para z sercem: mężczyzna i mężczyzna',
    '👩‍❤‍👩' => 'para z sercem: kobieta i kobieta',
    '👨‍👩‍👦' => 'rodzina: mężczyzna, kobieta i chłopiec',
    '👨‍👩‍👧' => 'rodzina: mężczyzna, kobieta i dziewczynka',
    '👨‍👨‍👦' => 'rodzina: mężczyzna, mężczyzna i chłopiec',
    '👨‍👨‍👧' => 'rodzina: mężczyzna, mężczyzna i dziewczynka',
    '👩‍👩‍👦' => 'rodzina: kobieta, kobieta i chłopiec',
    '👩‍👩‍👧' => 'rodzina: kobieta, kobieta i dziewczynka',
    '👨‍👦‍👦' => 'rodzina: mężczyzna, chłopiec i chłopiec',
    '👨‍👧‍👦' => 'rodzina: mężczyzna, dziewczynka i chłopiec',
    '👨‍👧‍👧' => 'rodzina: mężczyzna, dziewczynka i dziewczynka',
    '👩‍👦‍👦' => 'rodzina: kobieta, chłopiec i chłopiec',
    '👩‍👧‍👦' => 'rodzina: kobieta, dziewczynka i chłopiec',
    '👩‍👧‍👧' => 'rodzina: kobieta, dziewczynka i dziewczynka',
    '🧑‍🤝‍🧑' => 'osoby trzymające się za ręce',
    '🧑‍🧑‍🧒' => 'rodzina: dorosły, dorosły, dziecko',
    '🧑‍🧒‍🧒' => 'rodzina: dorosły, dziecko, dziecko',
    '🧑🏻‍🦰' => 'dorosły: karnacja jasna i rude włosy',
    '🧑🏼‍🦰' => 'dorosły: karnacja średnio jasna i rude włosy',
    '🧑🏽‍🦰' => 'dorosły: karnacja średnia i rude włosy',
    '🧑🏾‍🦰' => 'dorosły: karnacja średnio ciemna i rude włosy',
    '🧑🏿‍🦰' => 'dorosły: karnacja ciemna i rude włosy',
    '🧑🏻‍🦱' => 'dorosły: karnacja jasna i kręcone włosy',
    '🧑🏼‍🦱' => 'dorosły: karnacja średnio jasna i kręcone włosy',
    '🧑🏽‍🦱' => 'dorosły: karnacja średnia i kręcone włosy',
    '🧑🏾‍🦱' => 'dorosły: karnacja średnio ciemna i kręcone włosy',
    '🧑🏿‍🦱' => 'dorosły: karnacja ciemna i kręcone włosy',
    '🧑🏻‍🦳' => 'dorosły: karnacja jasna i białe włosy',
    '🧑🏼‍🦳' => 'dorosły: karnacja średnio jasna i białe włosy',
    '🧑🏽‍🦳' => 'dorosły: karnacja średnia i białe włosy',
    '🧑🏾‍🦳' => 'dorosły: karnacja średnio ciemna i białe włosy',
    '🧑🏿‍🦳' => 'dorosły: karnacja ciemna i białe włosy',
    '🧑🏻‍🦲' => 'dorosły: karnacja jasna i łysy',
    '🧑🏼‍🦲' => 'dorosły: karnacja średnio jasna i łysy',
    '🧑🏽‍🦲' => 'dorosły: karnacja średnia i łysy',
    '🧑🏾‍🦲' => 'dorosły: karnacja średnio ciemna i łysy',
    '🧑🏿‍🦲' => 'dorosły: karnacja ciemna i łysy',
    '🧑🏻‍🩰' => 'baletnica: karnacja jasna',
    '🧑🏼‍🩰' => 'baletnica: karnacja średnio jasna',
    '🧑🏽‍🩰' => 'baletnica: karnacja średnia',
    '🧑🏾‍🩰' => 'baletnica: karnacja średnio ciemna',
    '🧑🏿‍🩰' => 'baletnica: karnacja ciemna',
    '🧔🏻‍♂' => 'mężczyzna z brodą: karnacja jasna',
    '🧔🏼‍♂' => 'mężczyzna z brodą: karnacja średnio jasna',
    '🧔🏽‍♂' => 'mężczyzna z brodą: karnacja średnia',
    '🧔🏾‍♂' => 'mężczyzna z brodą: karnacja średnio ciemna',
    '🧔🏿‍♂' => 'mężczyzna z brodą: karnacja ciemna',
    '👱🏻‍♂' => 'blondyn: karnacja jasna',
    '👱🏼‍♂' => 'blondyn: karnacja średnio jasna',
    '👱🏽‍♂' => 'blondyn: karnacja średnia',
    '👱🏾‍♂' => 'blondyn: karnacja średnio ciemna',
    '👱🏿‍♂' => 'blondyn: karnacja ciemna',
    '👨🏻‍🦰' => 'mężczyzna: karnacja jasna i rude włosy',
    '👨🏼‍🦰' => 'mężczyzna: karnacja średnio jasna i rude włosy',
    '👨🏽‍🦰' => 'mężczyzna: karnacja średnia i rude włosy',
    '👨🏾‍🦰' => 'mężczyzna: karnacja średnio ciemna i rude włosy',
    '👨🏿‍🦰' => 'mężczyzna: karnacja ciemna i rude włosy',
    '👨🏻‍🦱' => 'mężczyzna: karnacja jasna i kręcone włosy',
    '👨🏼‍🦱' => 'mężczyzna: karnacja średnio jasna i kręcone włosy',
    '👨🏽‍🦱' => 'mężczyzna: karnacja średnia i kręcone włosy',
    '👨🏾‍🦱' => 'mężczyzna: karnacja średnio ciemna i kręcone włosy',
    '👨🏿‍🦱' => 'mężczyzna: karnacja ciemna i kręcone włosy',
    '👨🏻‍🦳' => 'mężczyzna: karnacja jasna i białe włosy',
    '👨🏼‍🦳' => 'mężczyzna: karnacja średnio jasna i białe włosy',
    '👨🏽‍🦳' => 'mężczyzna: karnacja średnia i białe włosy',
    '👨🏾‍🦳' => 'mężczyzna: karnacja średnio ciemna i białe włosy',
    '👨🏿‍🦳' => 'mężczyzna: karnacja ciemna i białe włosy',
    '👨🏻‍🦲' => 'mężczyzna: karnacja jasna i łysy',
    '👨🏼‍🦲' => 'mężczyzna: karnacja średnio jasna i łysy',
    '👨🏽‍🦲' => 'mężczyzna: karnacja średnia i łysy',
    '👨🏾‍🦲' => 'mężczyzna: karnacja średnio ciemna i łysy',
    '👨🏿‍🦲' => 'mężczyzna: karnacja ciemna i łysy',
    '🧔🏻‍♀' => 'kobieta z brodą: karnacja jasna',
    '🧔🏼‍♀' => 'kobieta z brodą: karnacja średnio jasna',
    '🧔🏽‍♀' => 'kobieta z brodą: karnacja średnia',
    '🧔🏾‍♀' => 'kobieta z brodą: karnacja średnio ciemna',
    '🧔🏿‍♀' => 'kobieta z brodą: karnacja ciemna',
    '👱🏻‍♀' => 'blondynka: karnacja jasna',
    '👱🏼‍♀' => 'blondynka: karnacja średnio jasna',
    '👱🏽‍♀' => 'blondynka: karnacja średnia',
    '👱🏾‍♀' => 'blondynka: karnacja średnio ciemna',
    '👱🏿‍♀' => 'blondynka: karnacja ciemna',
    '👩🏻‍🦰' => 'kobieta: karnacja jasna i rude włosy',
    '👩🏼‍🦰' => 'kobieta: karnacja średnio jasna i rude włosy',
    '👩🏽‍🦰' => 'kobieta: karnacja średnia i rude włosy',
    '👩🏾‍🦰' => 'kobieta: karnacja średnio ciemna i rude włosy',
    '👩🏿‍🦰' => 'kobieta: karnacja ciemna i rude włosy',
    '👩🏻‍🦱' => 'kobieta: karnacja jasna i kręcone włosy',
    '👩🏼‍🦱' => 'kobieta: karnacja średnio jasna i kręcone włosy',
    '👩🏽‍🦱' => 'kobieta: karnacja średnia i kręcone włosy',
    '👩🏾‍🦱' => 'kobieta: karnacja średnio ciemna i kręcone włosy',
    '👩🏿‍🦱' => 'kobieta: karnacja ciemna i kręcone włosy',
    '👩🏻‍🦳' => 'kobieta: karnacja jasna i białe włosy',
    '👩🏼‍🦳' => 'kobieta: karnacja średnio jasna i białe włosy',
    '👩🏽‍🦳' => 'kobieta: karnacja średnia i białe włosy',
    '👩🏾‍🦳' => 'kobieta: karnacja średnio ciemna i białe włosy',
    '👩🏿‍🦳' => 'kobieta: karnacja ciemna i białe włosy',
    '👩🏻‍🦲' => 'kobieta: karnacja jasna i łysy',
    '👩🏼‍🦲' => 'kobieta: karnacja średnio jasna i łysy',
    '👩🏽‍🦲' => 'kobieta: karnacja średnia i łysy',
    '👩🏾‍🦲' => 'kobieta: karnacja średnio ciemna i łysy',
    '👩🏿‍🦲' => 'kobieta: karnacja ciemna i łysy',
    '🙍🏻‍♂' => 'zachmurzony mężczyzna: karnacja jasna',
    '🙍🏼‍♂' => 'zachmurzony mężczyzna: karnacja średnio jasna',
    '🙍🏽‍♂' => 'zachmurzony mężczyzna: karnacja średnia',
    '🙍🏾‍♂' => 'zachmurzony mężczyzna: karnacja średnio ciemna',
    '🙍🏿‍♂' => 'zachmurzony mężczyzna: karnacja ciemna',
    '🙍🏻‍♀' => 'zachmurzona kobieta: karnacja jasna',
    '🙍🏼‍♀' => 'zachmurzona kobieta: karnacja średnio jasna',
    '🙍🏽‍♀' => 'zachmurzona kobieta: karnacja średnia',
    '🙍🏾‍♀' => 'zachmurzona kobieta: karnacja średnio ciemna',
    '🙍🏿‍♀' => 'zachmurzona kobieta: karnacja ciemna',
    '🙎🏻‍♂' => 'nadąsany mężczyzna: karnacja jasna',
    '🙎🏼‍♂' => 'nadąsany mężczyzna: karnacja średnio jasna',
    '🙎🏽‍♂' => 'nadąsany mężczyzna: karnacja średnia',
    '🙎🏾‍♂' => 'nadąsany mężczyzna: karnacja średnio ciemna',
    '🙎🏿‍♂' => 'nadąsany mężczyzna: karnacja ciemna',
    '🙎🏻‍♀' => 'nadąsana kobieta: karnacja jasna',
    '🙎🏼‍♀' => 'nadąsana kobieta: karnacja średnio jasna',
    '🙎🏽‍♀' => 'nadąsana kobieta: karnacja średnia',
    '🙎🏾‍♀' => 'nadąsana kobieta: karnacja średnio ciemna',
    '🙎🏿‍♀' => 'nadąsana kobieta: karnacja ciemna',
    '🙅🏻‍♂' => 'mężczyzna pokazujący gest NIE: karnacja jasna',
    '🙅🏼‍♂' => 'mężczyzna pokazujący gest NIE: karnacja średnio jasna',
    '🙅🏽‍♂' => 'mężczyzna pokazujący gest NIE: karnacja średnia',
    '🙅🏾‍♂' => 'mężczyzna pokazujący gest NIE: karnacja średnio ciemna',
    '🙅🏿‍♂' => 'mężczyzna pokazujący gest NIE: karnacja ciemna',
    '🙅🏻‍♀' => 'kobieta pokazująca gest NIE: karnacja jasna',
    '🙅🏼‍♀' => 'kobieta pokazująca gest NIE: karnacja średnio jasna',
    '🙅🏽‍♀' => 'kobieta pokazująca gest NIE: karnacja średnia',
    '🙅🏾‍♀' => 'kobieta pokazująca gest NIE: karnacja średnio ciemna',
    '🙅🏿‍♀' => 'kobieta pokazująca gest NIE: karnacja ciemna',
    '🙆🏻‍♂' => 'mężczyzna pokazujący gest OK: karnacja jasna',
    '🙆🏼‍♂' => 'mężczyzna pokazujący gest OK: karnacja średnio jasna',
    '🙆🏽‍♂' => 'mężczyzna pokazujący gest OK: karnacja średnia',
    '🙆🏾‍♂' => 'mężczyzna pokazujący gest OK: karnacja średnio ciemna',
    '🙆🏿‍♂' => 'mężczyzna pokazujący gest OK: karnacja ciemna',
    '🙆🏻‍♀' => 'kobieta pokazująca gest OK: karnacja jasna',
    '🙆🏼‍♀' => 'kobieta pokazująca gest OK: karnacja średnio jasna',
    '🙆🏽‍♀' => 'kobieta pokazująca gest OK: karnacja średnia',
    '🙆🏾‍♀' => 'kobieta pokazująca gest OK: karnacja średnio ciemna',
    '🙆🏿‍♀' => 'kobieta pokazująca gest OK: karnacja ciemna',
    '💁🏻‍♂' => 'mężczyzna z wystawioną dłonią: karnacja jasna',
    '💁🏼‍♂' => 'mężczyzna z wystawioną dłonią: karnacja średnio jasna',
    '💁🏽‍♂' => 'mężczyzna z wystawioną dłonią: karnacja średnia',
    '💁🏾‍♂' => 'mężczyzna z wystawioną dłonią: karnacja średnio ciemna',
    '💁🏿‍♂' => 'mężczyzna z wystawioną dłonią: karnacja ciemna',
    '💁🏻‍♀' => 'kobieta z wystawioną dłonią: karnacja jasna',
    '💁🏼‍♀' => 'kobieta z wystawioną dłonią: karnacja średnio jasna',
    '💁🏽‍♀' => 'kobieta z wystawioną dłonią: karnacja średnia',
    '💁🏾‍♀' => 'kobieta z wystawioną dłonią: karnacja średnio ciemna',
    '💁🏿‍♀' => 'kobieta z wystawioną dłonią: karnacja ciemna',
    '🙋🏻‍♂' => 'mężczyzna podnoszący rękę: karnacja jasna',
    '🙋🏼‍♂' => 'mężczyzna podnoszący rękę: karnacja średnio jasna',
    '🙋🏽‍♂' => 'mężczyzna podnoszący rękę: karnacja średnia',
    '🙋🏾‍♂' => 'mężczyzna podnoszący rękę: karnacja średnio ciemna',
    '🙋🏿‍♂' => 'mężczyzna podnoszący rękę: karnacja ciemna',
    '🙋🏻‍♀' => 'kobieta podnosząca rękę: karnacja jasna',
    '🙋🏼‍♀' => 'kobieta podnosząca rękę: karnacja średnio jasna',
    '🙋🏽‍♀' => 'kobieta podnosząca rękę: karnacja średnia',
    '🙋🏾‍♀' => 'kobieta podnosząca rękę: karnacja średnio ciemna',
    '🙋🏿‍♀' => 'kobieta podnosząca rękę: karnacja ciemna',
    '🧏🏻‍♂' => 'głuchy mężczyzna: karnacja jasna',
    '🧏🏼‍♂' => 'głuchy mężczyzna: karnacja średnio jasna',
    '🧏🏽‍♂' => 'głuchy mężczyzna: karnacja średnia',
    '🧏🏾‍♂' => 'głuchy mężczyzna: karnacja średnio ciemna',
    '🧏🏿‍♂' => 'głuchy mężczyzna: karnacja ciemna',
    '🧏🏻‍♀' => 'głucha kobieta: karnacja jasna',
    '🧏🏼‍♀' => 'głucha kobieta: karnacja średnio jasna',
    '🧏🏽‍♀' => 'głucha kobieta: karnacja średnia',
    '🧏🏾‍♀' => 'głucha kobieta: karnacja średnio ciemna',
    '🧏🏿‍♀' => 'głucha kobieta: karnacja ciemna',
    '🙇🏻‍♂' => 'mężczyzna w ukłonie: karnacja jasna',
    '🙇🏼‍♂' => 'mężczyzna w ukłonie: karnacja średnio jasna',
    '🙇🏽‍♂' => 'mężczyzna w ukłonie: karnacja średnia',
    '🙇🏾‍♂' => 'mężczyzna w ukłonie: karnacja średnio ciemna',
    '🙇🏿‍♂' => 'mężczyzna w ukłonie: karnacja ciemna',
    '🙇🏻‍♀' => 'kobieta w ukłonie: karnacja jasna',
    '🙇🏼‍♀' => 'kobieta w ukłonie: karnacja średnio jasna',
    '🙇🏽‍♀' => 'kobieta w ukłonie: karnacja średnia',
    '🙇🏾‍♀' => 'kobieta w ukłonie: karnacja średnio ciemna',
    '🙇🏿‍♀' => 'kobieta w ukłonie: karnacja ciemna',
    '🤦🏻‍♂' => 'mężczyzna trzymający się za czoło: karnacja jasna',
    '🤦🏼‍♂' => 'mężczyzna trzymający się za czoło: karnacja średnio jasna',
    '🤦🏽‍♂' => 'mężczyzna trzymający się za czoło: karnacja średnia',
    '🤦🏾‍♂' => 'mężczyzna trzymający się za czoło: karnacja średnio ciemna',
    '🤦🏿‍♂' => 'mężczyzna trzymający się za czoło: karnacja ciemna',
    '🤦🏻‍♀' => 'kobieta trzymająca się za czoło: karnacja jasna',
    '🤦🏼‍♀' => 'kobieta trzymająca się za czoło: karnacja średnio jasna',
    '🤦🏽‍♀' => 'kobieta trzymająca się za czoło: karnacja średnia',
    '🤦🏾‍♀' => 'kobieta trzymająca się za czoło: karnacja średnio ciemna',
    '🤦🏿‍♀' => 'kobieta trzymająca się za czoło: karnacja ciemna',
    '🤷🏻‍♂' => 'mężczyzna wzruszający ramionami: karnacja jasna',
    '🤷🏼‍♂' => 'mężczyzna wzruszający ramionami: karnacja średnio jasna',
    '🤷🏽‍♂' => 'mężczyzna wzruszający ramionami: karnacja średnia',
    '🤷🏾‍♂' => 'mężczyzna wzruszający ramionami: karnacja średnio ciemna',
    '🤷🏿‍♂' => 'mężczyzna wzruszający ramionami: karnacja ciemna',
    '🤷🏻‍♀' => 'kobieta wzruszająca ramionami: karnacja jasna',
    '🤷🏼‍♀' => 'kobieta wzruszająca ramionami: karnacja średnio jasna',
    '🤷🏽‍♀' => 'kobieta wzruszająca ramionami: karnacja średnia',
    '🤷🏾‍♀' => 'kobieta wzruszająca ramionami: karnacja średnio ciemna',
    '🤷🏿‍♀' => 'kobieta wzruszająca ramionami: karnacja ciemna',
    '🧑🏻‍⚕' => 'pracownik służby zdrowia: karnacja jasna',
    '🧑🏼‍⚕' => 'pracownik służby zdrowia: karnacja średnio jasna',
    '🧑🏽‍⚕' => 'pracownik służby zdrowia: karnacja średnia',
    '🧑🏾‍⚕' => 'pracownik służby zdrowia: karnacja średnio ciemna',
    '🧑🏿‍⚕' => 'pracownik służby zdrowia: karnacja ciemna',
    '👨🏻‍⚕' => 'lekarz: karnacja jasna',
    '👨🏼‍⚕' => 'lekarz: karnacja średnio jasna',
    '👨🏽‍⚕' => 'lekarz: karnacja średnia',
    '👨🏾‍⚕' => 'lekarz: karnacja średnio ciemna',
    '👨🏿‍⚕' => 'lekarz: karnacja ciemna',
    '👩🏻‍⚕' => 'lekarka: karnacja jasna',
    '👩🏼‍⚕' => 'lekarka: karnacja średnio jasna',
    '👩🏽‍⚕' => 'lekarka: karnacja średnia',
    '👩🏾‍⚕' => 'lekarka: karnacja średnio ciemna',
    '👩🏿‍⚕' => 'lekarka: karnacja ciemna',
    '🧑🏻‍🎓' => 'student: karnacja jasna',
    '🧑🏼‍🎓' => 'student: karnacja średnio jasna',
    '🧑🏽‍🎓' => 'student: karnacja średnia',
    '🧑🏾‍🎓' => 'student: karnacja średnio ciemna',
    '🧑🏿‍🎓' => 'student: karnacja ciemna',
    '👨🏻‍🎓' => 'mężczyzna student: karnacja jasna',
    '👨🏼‍🎓' => 'mężczyzna student: karnacja średnio jasna',
    '👨🏽‍🎓' => 'mężczyzna student: karnacja średnia',
    '👨🏾‍🎓' => 'mężczyzna student: karnacja średnio ciemna',
    '👨🏿‍🎓' => 'mężczyzna student: karnacja ciemna',
    '👩🏻‍🎓' => 'studentka: karnacja jasna',
    '👩🏼‍🎓' => 'studentka: karnacja średnio jasna',
    '👩🏽‍🎓' => 'studentka: karnacja średnia',
    '👩🏾‍🎓' => 'studentka: karnacja średnio ciemna',
    '👩🏿‍🎓' => 'studentka: karnacja ciemna',
    '🧑🏻‍🏫' => 'nauczyciel: karnacja jasna',
    '🧑🏼‍🏫' => 'nauczyciel: karnacja średnio jasna',
    '🧑🏽‍🏫' => 'nauczyciel: karnacja średnia',
    '🧑🏾‍🏫' => 'nauczyciel: karnacja średnio ciemna',
    '🧑🏿‍🏫' => 'nauczyciel: karnacja ciemna',
    '👨🏻‍🏫' => 'mężczyzna nauczyciel: karnacja jasna',
    '👨🏼‍🏫' => 'mężczyzna nauczyciel: karnacja średnio jasna',
    '👨🏽‍🏫' => 'mężczyzna nauczyciel: karnacja średnia',
    '👨🏾‍🏫' => 'mężczyzna nauczyciel: karnacja średnio ciemna',
    '👨🏿‍🏫' => 'mężczyzna nauczyciel: karnacja ciemna',
    '👩🏻‍🏫' => 'nauczycielka: karnacja jasna',
    '👩🏼‍🏫' => 'nauczycielka: karnacja średnio jasna',
    '👩🏽‍🏫' => 'nauczycielka: karnacja średnia',
    '👩🏾‍🏫' => 'nauczycielka: karnacja średnio ciemna',
    '👩🏿‍🏫' => 'nauczycielka: karnacja ciemna',
    '🧑🏻‍⚖' => 'sędzia: karnacja jasna',
    '🧑🏼‍⚖' => 'sędzia: karnacja średnio jasna',
    '🧑🏽‍⚖' => 'sędzia: karnacja średnia',
    '🧑🏾‍⚖' => 'sędzia: karnacja średnio ciemna',
    '🧑🏿‍⚖' => 'sędzia: karnacja ciemna',
    '👨🏻‍⚖' => 'mężczyzna sędzia: karnacja jasna',
    '👨🏼‍⚖' => 'mężczyzna sędzia: karnacja średnio jasna',
    '👨🏽‍⚖' => 'mężczyzna sędzia: karnacja średnia',
    '👨🏾‍⚖' => 'mężczyzna sędzia: karnacja średnio ciemna',
    '👨🏿‍⚖' => 'mężczyzna sędzia: karnacja ciemna',
    '👩🏻‍⚖' => 'kobieta sędzia: karnacja jasna',
    '👩🏼‍⚖' => 'kobieta sędzia: karnacja średnio jasna',
    '👩🏽‍⚖' => 'kobieta sędzia: karnacja średnia',
    '👩🏾‍⚖' => 'kobieta sędzia: karnacja średnio ciemna',
    '👩🏿‍⚖' => 'kobieta sędzia: karnacja ciemna',
    '🧑🏻‍🌾' => 'rolnik: karnacja jasna',
    '🧑🏼‍🌾' => 'rolnik: karnacja średnio jasna',
    '🧑🏽‍🌾' => 'rolnik: karnacja średnia',
    '🧑🏾‍🌾' => 'rolnik: karnacja średnio ciemna',
    '🧑🏿‍🌾' => 'rolnik: karnacja ciemna',
    '👨🏻‍🌾' => 'mężczyzna rolnik: karnacja jasna',
    '👨🏼‍🌾' => 'mężczyzna rolnik: karnacja średnio jasna',
    '👨🏽‍🌾' => 'mężczyzna rolnik: karnacja średnia',
    '👨🏾‍🌾' => 'mężczyzna rolnik: karnacja średnio ciemna',
    '👨🏿‍🌾' => 'mężczyzna rolnik: karnacja ciemna',
    '👩🏻‍🌾' => 'rolniczka: karnacja jasna',
    '👩🏼‍🌾' => 'rolniczka: karnacja średnio jasna',
    '👩🏽‍🌾' => 'rolniczka: karnacja średnia',
    '👩🏾‍🌾' => 'rolniczka: karnacja średnio ciemna',
    '👩🏿‍🌾' => 'rolniczka: karnacja ciemna',
    '🧑🏻‍🍳' => 'kucharz: karnacja jasna',
    '🧑🏼‍🍳' => 'kucharz: karnacja średnio jasna',
    '🧑🏽‍🍳' => 'kucharz: karnacja średnia',
    '🧑🏾‍🍳' => 'kucharz: karnacja średnio ciemna',
    '🧑🏿‍🍳' => 'kucharz: karnacja ciemna',
    '👨🏻‍🍳' => 'mężczyzna kucharz: karnacja jasna',
    '👨🏼‍🍳' => 'mężczyzna kucharz: karnacja średnio jasna',
    '👨🏽‍🍳' => 'mężczyzna kucharz: karnacja średnia',
    '👨🏾‍🍳' => 'mężczyzna kucharz: karnacja średnio ciemna',
    '👨🏿‍🍳' => 'mężczyzna kucharz: karnacja ciemna',
    '👩🏻‍🍳' => 'kucharka: karnacja jasna',
    '👩🏼‍🍳' => 'kucharka: karnacja średnio jasna',
    '👩🏽‍🍳' => 'kucharka: karnacja średnia',
    '👩🏾‍🍳' => 'kucharka: karnacja średnio ciemna',
    '👩🏿‍🍳' => 'kucharka: karnacja ciemna',
    '🧑🏻‍🔧' => 'mechanik: karnacja jasna',
    '🧑🏼‍🔧' => 'mechanik: karnacja średnio jasna',
    '🧑🏽‍🔧' => 'mechanik: karnacja średnia',
    '🧑🏾‍🔧' => 'mechanik: karnacja średnio ciemna',
    '🧑🏿‍🔧' => 'mechanik: karnacja ciemna',
    '👨🏻‍🔧' => 'mężczyzna elektryk: karnacja jasna',
    '👨🏼‍🔧' => 'mężczyzna elektryk: karnacja średnio jasna',
    '👨🏽‍🔧' => 'mężczyzna elektryk: karnacja średnia',
    '👨🏾‍🔧' => 'mężczyzna elektryk: karnacja średnio ciemna',
    '👨🏿‍🔧' => 'mężczyzna elektryk: karnacja ciemna',
    '👩🏻‍🔧' => 'kobieta elektryk: karnacja jasna',
    '👩🏼‍🔧' => 'kobieta elektryk: karnacja średnio jasna',
    '👩🏽‍🔧' => 'kobieta elektryk: karnacja średnia',
    '👩🏾‍🔧' => 'kobieta elektryk: karnacja średnio ciemna',
    '👩🏿‍🔧' => 'kobieta elektryk: karnacja ciemna',
    '🧑🏻‍🏭' => 'pracownik fabryki: karnacja jasna',
    '🧑🏼‍🏭' => 'pracownik fabryki: karnacja średnio jasna',
    '🧑🏽‍🏭' => 'pracownik fabryki: karnacja średnia',
    '🧑🏾‍🏭' => 'pracownik fabryki: karnacja średnio ciemna',
    '🧑🏿‍🏭' => 'pracownik fabryki: karnacja ciemna',
    '👨🏻‍🏭' => 'mężczyzna pracownik fabryki: karnacja jasna',
    '👨🏼‍🏭' => 'mężczyzna pracownik fabryki: karnacja średnio jasna',
    '👨🏽‍🏭' => 'mężczyzna pracownik fabryki: karnacja średnia',
    '👨🏾‍🏭' => 'mężczyzna pracownik fabryki: karnacja średnio ciemna',
    '👨🏿‍🏭' => 'mężczyzna pracownik fabryki: karnacja ciemna',
    '👩🏻‍🏭' => 'pracownica fabryki: karnacja jasna',
    '👩🏼‍🏭' => 'pracownica fabryki: karnacja średnio jasna',
    '👩🏽‍🏭' => 'pracownica fabryki: karnacja średnia',
    '👩🏾‍🏭' => 'pracownica fabryki: karnacja średnio ciemna',
    '👩🏿‍🏭' => 'pracownica fabryki: karnacja ciemna',
    '🧑🏻‍💼' => 'pracownik biurowy: karnacja jasna',
    '🧑🏼‍💼' => 'pracownik biurowy: karnacja średnio jasna',
    '🧑🏽‍💼' => 'pracownik biurowy: karnacja średnia',
    '🧑🏾‍💼' => 'pracownik biurowy: karnacja średnio ciemna',
    '🧑🏿‍💼' => 'pracownik biurowy: karnacja ciemna',
    '👨🏻‍💼' => 'mężczyzna pracownik biurowy: karnacja jasna',
    '👨🏼‍💼' => 'mężczyzna pracownik biurowy: karnacja średnio jasna',
    '👨🏽‍💼' => 'mężczyzna pracownik biurowy: karnacja średnia',
    '👨🏾‍💼' => 'mężczyzna pracownik biurowy: karnacja średnio ciemna',
    '👨🏿‍💼' => 'mężczyzna pracownik biurowy: karnacja ciemna',
    '👩🏻‍💼' => 'pracownica biurowa: karnacja jasna',
    '👩🏼‍💼' => 'pracownica biurowa: karnacja średnio jasna',
    '👩🏽‍💼' => 'pracownica biurowa: karnacja średnia',
    '👩🏾‍💼' => 'pracownica biurowa: karnacja średnio ciemna',
    '👩🏿‍💼' => 'pracownica biurowa: karnacja ciemna',
    '🧑🏻‍🔬' => 'naukowiec: karnacja jasna',
    '🧑🏼‍🔬' => 'naukowiec: karnacja średnio jasna',
    '🧑🏽‍🔬' => 'naukowiec: karnacja średnia',
    '🧑🏾‍🔬' => 'naukowiec: karnacja średnio ciemna',
    '🧑🏿‍🔬' => 'naukowiec: karnacja ciemna',
    '👨🏻‍🔬' => 'mężczyzna naukowiec: karnacja jasna',
    '👨🏼‍🔬' => 'mężczyzna naukowiec: karnacja średnio jasna',
    '👨🏽‍🔬' => 'mężczyzna naukowiec: karnacja średnia',
    '👨🏾‍🔬' => 'mężczyzna naukowiec: karnacja średnio ciemna',
    '👨🏿‍🔬' => 'mężczyzna naukowiec: karnacja ciemna',
    '👩🏻‍🔬' => 'kobieta naukowiec: karnacja jasna',
    '👩🏼‍🔬' => 'kobieta naukowiec: karnacja średnio jasna',
    '👩🏽‍🔬' => 'kobieta naukowiec: karnacja średnia',
    '👩🏾‍🔬' => 'kobieta naukowiec: karnacja średnio ciemna',
    '👩🏿‍🔬' => 'kobieta naukowiec: karnacja ciemna',
    '🧑🏻‍💻' => 'technolog: karnacja jasna',
    '🧑🏼‍💻' => 'technolog: karnacja średnio jasna',
    '🧑🏽‍💻' => 'technolog: karnacja średnia',
    '🧑🏾‍💻' => 'technolog: karnacja średnio ciemna',
    '🧑🏿‍💻' => 'technolog: karnacja ciemna',
    '👨🏻‍💻' => 'mężczyzna technolog: karnacja jasna',
    '👨🏼‍💻' => 'mężczyzna technolog: karnacja średnio jasna',
    '👨🏽‍💻' => 'mężczyzna technolog: karnacja średnia',
    '👨🏾‍💻' => 'mężczyzna technolog: karnacja średnio ciemna',
    '👨🏿‍💻' => 'mężczyzna technolog: karnacja ciemna',
    '👩🏻‍💻' => 'kobieta technolog: karnacja jasna',
    '👩🏼‍💻' => 'kobieta technolog: karnacja średnio jasna',
    '👩🏽‍💻' => 'kobieta technolog: karnacja średnia',
    '👩🏾‍💻' => 'kobieta technolog: karnacja średnio ciemna',
    '👩🏿‍💻' => 'kobieta technolog: karnacja ciemna',
    '🧑🏻‍🎤' => 'piosenkarz: karnacja jasna',
    '🧑🏼‍🎤' => 'piosenkarz: karnacja średnio jasna',
    '🧑🏽‍🎤' => 'piosenkarz: karnacja średnia',
    '🧑🏾‍🎤' => 'piosenkarz: karnacja średnio ciemna',
    '🧑🏿‍🎤' => 'piosenkarz: karnacja ciemna',
    '👨🏻‍🎤' => 'mężczyzna piosenkarz: karnacja jasna',
    '👨🏼‍🎤' => 'mężczyzna piosenkarz: karnacja średnio jasna',
    '👨🏽‍🎤' => 'mężczyzna piosenkarz: karnacja średnia',
    '👨🏾‍🎤' => 'mężczyzna piosenkarz: karnacja średnio ciemna',
    '👨🏿‍🎤' => 'mężczyzna piosenkarz: karnacja ciemna',
    '👩🏻‍🎤' => 'piosenkarka: karnacja jasna',
    '👩🏼‍🎤' => 'piosenkarka: karnacja średnio jasna',
    '👩🏽‍🎤' => 'piosenkarka: karnacja średnia',
    '👩🏾‍🎤' => 'piosenkarka: karnacja średnio ciemna',
    '👩🏿‍🎤' => 'piosenkarka: karnacja ciemna',
    '🧑🏻‍🎨' => 'artysta: karnacja jasna',
    '🧑🏼‍🎨' => 'artysta: karnacja średnio jasna',
    '🧑🏽‍🎨' => 'artysta: karnacja średnia',
    '🧑🏾‍🎨' => 'artysta: karnacja średnio ciemna',
    '🧑🏿‍🎨' => 'artysta: karnacja ciemna',
    '👨🏻‍🎨' => 'mężczyzna artysta: karnacja jasna',
    '👨🏼‍🎨' => 'mężczyzna artysta: karnacja średnio jasna',
    '👨🏽‍🎨' => 'mężczyzna artysta: karnacja średnia',
    '👨🏾‍🎨' => 'mężczyzna artysta: karnacja średnio ciemna',
    '👨🏿‍🎨' => 'mężczyzna artysta: karnacja ciemna',
    '👩🏻‍🎨' => 'artystka: karnacja jasna',
    '👩🏼‍🎨' => 'artystka: karnacja średnio jasna',
    '👩🏽‍🎨' => 'artystka: karnacja średnia',
    '👩🏾‍🎨' => 'artystka: karnacja średnio ciemna',
    '👩🏿‍🎨' => 'artystka: karnacja ciemna',
    '🧑🏻‍✈' => 'pilot: karnacja jasna',
    '🧑🏼‍✈' => 'pilot: karnacja średnio jasna',
    '🧑🏽‍✈' => 'pilot: karnacja średnia',
    '🧑🏾‍✈' => 'pilot: karnacja średnio ciemna',
    '🧑🏿‍✈' => 'pilot: karnacja ciemna',
    '👨🏻‍✈' => 'mężczyzna pilot: karnacja jasna',
    '👨🏼‍✈' => 'mężczyzna pilot: karnacja średnio jasna',
    '👨🏽‍✈' => 'mężczyzna pilot: karnacja średnia',
    '👨🏾‍✈' => 'mężczyzna pilot: karnacja średnio ciemna',
    '👨🏿‍✈' => 'mężczyzna pilot: karnacja ciemna',
    '👩🏻‍✈' => 'kobieta pilot: karnacja jasna',
    '👩🏼‍✈' => 'kobieta pilot: karnacja średnio jasna',
    '👩🏽‍✈' => 'kobieta pilot: karnacja średnia',
    '👩🏾‍✈' => 'kobieta pilot: karnacja średnio ciemna',
    '👩🏿‍✈' => 'kobieta pilot: karnacja ciemna',
    '🧑🏻‍🚀' => 'astronauta: karnacja jasna',
    '🧑🏼‍🚀' => 'astronauta: karnacja średnio jasna',
    '🧑🏽‍🚀' => 'astronauta: karnacja średnia',
    '🧑🏾‍🚀' => 'astronauta: karnacja średnio ciemna',
    '🧑🏿‍🚀' => 'astronauta: karnacja ciemna',
    '👨🏻‍🚀' => 'mężczyzna astronauta: karnacja jasna',
    '👨🏼‍🚀' => 'mężczyzna astronauta: karnacja średnio jasna',
    '👨🏽‍🚀' => 'mężczyzna astronauta: karnacja średnia',
    '👨🏾‍🚀' => 'mężczyzna astronauta: karnacja średnio ciemna',
    '👨🏿‍🚀' => 'mężczyzna astronauta: karnacja ciemna',
    '👩🏻‍🚀' => 'astronautka: karnacja jasna',
    '👩🏼‍🚀' => 'astronautka: karnacja średnio jasna',
    '👩🏽‍🚀' => 'astronautka: karnacja średnia',
    '👩🏾‍🚀' => 'astronautka: karnacja średnio ciemna',
    '👩🏿‍🚀' => 'astronautka: karnacja ciemna',
    '🧑🏻‍🚒' => 'strażak: karnacja jasna',
    '🧑🏼‍🚒' => 'strażak: karnacja średnio jasna',
    '🧑🏽‍🚒' => 'strażak: karnacja średnia',
    '🧑🏾‍🚒' => 'strażak: karnacja średnio ciemna',
    '🧑🏿‍🚒' => 'strażak: karnacja ciemna',
    '👨🏻‍🚒' => 'mężczyzna strażak: karnacja jasna',
    '👨🏼‍🚒' => 'mężczyzna strażak: karnacja średnio jasna',
    '👨🏽‍🚒' => 'mężczyzna strażak: karnacja średnia',
    '👨🏾‍🚒' => 'mężczyzna strażak: karnacja średnio ciemna',
    '👨🏿‍🚒' => 'mężczyzna strażak: karnacja ciemna',
    '👩🏻‍🚒' => 'kobieta strażak: karnacja jasna',
    '👩🏼‍🚒' => 'kobieta strażak: karnacja średnio jasna',
    '👩🏽‍🚒' => 'kobieta strażak: karnacja średnia',
    '👩🏾‍🚒' => 'kobieta strażak: karnacja średnio ciemna',
    '👩🏿‍🚒' => 'kobieta strażak: karnacja ciemna',
    '👮🏻‍♂' => 'mężczyzna policjant: karnacja jasna',
    '👮🏼‍♂' => 'mężczyzna policjant: karnacja średnio jasna',
    '👮🏽‍♂' => 'mężczyzna policjant: karnacja średnia',
    '👮🏾‍♂' => 'mężczyzna policjant: karnacja średnio ciemna',
    '👮🏿‍♂' => 'mężczyzna policjant: karnacja ciemna',
    '👮🏻‍♀' => 'kobieta policjant: karnacja jasna',
    '👮🏼‍♀' => 'kobieta policjant: karnacja średnio jasna',
    '👮🏽‍♀' => 'kobieta policjant: karnacja średnia',
    '👮🏾‍♀' => 'kobieta policjant: karnacja średnio ciemna',
    '👮🏿‍♀' => 'kobieta policjant: karnacja ciemna',
    '🕵🏻‍♂' => 'mężczyzna detektyw: karnacja jasna',
    '🕵🏼‍♂' => 'mężczyzna detektyw: karnacja średnio jasna',
    '🕵🏽‍♂' => 'mężczyzna detektyw: karnacja średnia',
    '🕵🏾‍♂' => 'mężczyzna detektyw: karnacja średnio ciemna',
    '🕵🏿‍♂' => 'mężczyzna detektyw: karnacja ciemna',
    '🕵🏻‍♀' => 'kobieta detektyw: karnacja jasna',
    '🕵🏼‍♀' => 'kobieta detektyw: karnacja średnio jasna',
    '🕵🏽‍♀' => 'kobieta detektyw: karnacja średnia',
    '🕵🏾‍♀' => 'kobieta detektyw: karnacja średnio ciemna',
    '🕵🏿‍♀' => 'kobieta detektyw: karnacja ciemna',
    '💂🏻‍♂' => 'mężczyzna gwardzista: karnacja jasna',
    '💂🏼‍♂' => 'mężczyzna gwardzista: karnacja średnio jasna',
    '💂🏽‍♂' => 'mężczyzna gwardzista: karnacja średnia',
    '💂🏾‍♂' => 'mężczyzna gwardzista: karnacja średnio ciemna',
    '💂🏿‍♂' => 'mężczyzna gwardzista: karnacja ciemna',
    '💂🏻‍♀' => 'kobieta gwardzista: karnacja jasna',
    '💂🏼‍♀' => 'kobieta gwardzista: karnacja średnio jasna',
    '💂🏽‍♀' => 'kobieta gwardzista: karnacja średnia',
    '💂🏾‍♀' => 'kobieta gwardzista: karnacja średnio ciemna',
    '💂🏿‍♀' => 'kobieta gwardzista: karnacja ciemna',
    '👷🏻‍♂' => 'mężczyzna budowlaniec: karnacja jasna',
    '👷🏼‍♂' => 'mężczyzna budowlaniec: karnacja średnio jasna',
    '👷🏽‍♂' => 'mężczyzna budowlaniec: karnacja średnia',
    '👷🏾‍♂' => 'mężczyzna budowlaniec: karnacja średnio ciemna',
    '👷🏿‍♂' => 'mężczyzna budowlaniec: karnacja ciemna',
    '👷🏻‍♀' => 'kobieta budowlaniec: karnacja jasna',
    '👷🏼‍♀' => 'kobieta budowlaniec: karnacja średnio jasna',
    '👷🏽‍♀' => 'kobieta budowlaniec: karnacja średnia',
    '👷🏾‍♀' => 'kobieta budowlaniec: karnacja średnio ciemna',
    '👷🏿‍♀' => 'kobieta budowlaniec: karnacja ciemna',
    '👳🏻‍♂' => 'mężczyzna w turbanie: karnacja jasna',
    '👳🏼‍♂' => 'mężczyzna w turbanie: karnacja średnio jasna',
    '👳🏽‍♂' => 'mężczyzna w turbanie: karnacja średnia',
    '👳🏾‍♂' => 'mężczyzna w turbanie: karnacja średnio ciemna',
    '👳🏿‍♂' => 'mężczyzna w turbanie: karnacja ciemna',
    '👳🏻‍♀' => 'kobieta w turbanie: karnacja jasna',
    '👳🏼‍♀' => 'kobieta w turbanie: karnacja średnio jasna',
    '👳🏽‍♀' => 'kobieta w turbanie: karnacja średnia',
    '👳🏾‍♀' => 'kobieta w turbanie: karnacja średnio ciemna',
    '👳🏿‍♀' => 'kobieta w turbanie: karnacja ciemna',
    '🤵🏻‍♂' => 'mężczyzna w smokingu: karnacja jasna',
    '🤵🏼‍♂' => 'mężczyzna w smokingu: karnacja średnio jasna',
    '🤵🏽‍♂' => 'mężczyzna w smokingu: karnacja średnia',
    '🤵🏾‍♂' => 'mężczyzna w smokingu: karnacja średnio ciemna',
    '🤵🏿‍♂' => 'mężczyzna w smokingu: karnacja ciemna',
    '🤵🏻‍♀' => 'kobieta w smokingu: karnacja jasna',
    '🤵🏼‍♀' => 'kobieta w smokingu: karnacja średnio jasna',
    '🤵🏽‍♀' => 'kobieta w smokingu: karnacja średnia',
    '🤵🏾‍♀' => 'kobieta w smokingu: karnacja średnio ciemna',
    '🤵🏿‍♀' => 'kobieta w smokingu: karnacja ciemna',
    '👰🏻‍♂' => 'mężczyzna w welonie: karnacja jasna',
    '👰🏼‍♂' => 'mężczyzna w welonie: karnacja średnio jasna',
    '👰🏽‍♂' => 'mężczyzna w welonie: karnacja średnia',
    '👰🏾‍♂' => 'mężczyzna w welonie: karnacja średnio ciemna',
    '👰🏿‍♂' => 'mężczyzna w welonie: karnacja ciemna',
    '👰🏻‍♀' => 'kobieta w welonie: karnacja jasna',
    '👰🏼‍♀' => 'kobieta w welonie: karnacja średnio jasna',
    '👰🏽‍♀' => 'kobieta w welonie: karnacja średnia',
    '👰🏾‍♀' => 'kobieta w welonie: karnacja średnio ciemna',
    '👰🏿‍♀' => 'kobieta w welonie: karnacja ciemna',
    '👩🏻‍🍼' => 'kobieta karmiąca niemowlę: karnacja jasna',
    '👩🏼‍🍼' => 'kobieta karmiąca niemowlę: karnacja średnio jasna',
    '👩🏽‍🍼' => 'kobieta karmiąca niemowlę: karnacja średnia',
    '👩🏾‍🍼' => 'kobieta karmiąca niemowlę: karnacja średnio ciemna',
    '👩🏿‍🍼' => 'kobieta karmiąca niemowlę: karnacja ciemna',
    '👨🏻‍🍼' => 'mężczyzna karmiący niemowlę: karnacja jasna',
    '👨🏼‍🍼' => 'mężczyzna karmiący niemowlę: karnacja średnio jasna',
    '👨🏽‍🍼' => 'mężczyzna karmiący niemowlę: karnacja średnia',
    '👨🏾‍🍼' => 'mężczyzna karmiący niemowlę: karnacja średnio ciemna',
    '👨🏿‍🍼' => 'mężczyzna karmiący niemowlę: karnacja ciemna',
    '🧑🏻‍🍼' => 'osoba karmiąca niemowlę: karnacja jasna',
    '🧑🏼‍🍼' => 'osoba karmiąca niemowlę: karnacja średnio jasna',
    '🧑🏽‍🍼' => 'osoba karmiąca niemowlę: karnacja średnia',
    '🧑🏾‍🍼' => 'osoba karmiąca niemowlę: karnacja średnio ciemna',
    '🧑🏿‍🍼' => 'osoba karmiąca niemowlę: karnacja ciemna',
    '🧑🏻‍🎄' => 'Mikołajka: karnacja jasna',
    '🧑🏼‍🎄' => 'Mikołajka: karnacja średnio jasna',
    '🧑🏽‍🎄' => 'Mikołajka: karnacja średnia',
    '🧑🏾‍🎄' => 'Mikołajka: karnacja średnio ciemna',
    '🧑🏿‍🎄' => 'Mikołajka: karnacja ciemna',
    '🦸🏻‍♂' => 'mężczyzna superbohater: karnacja jasna',
    '🦸🏼‍♂' => 'mężczyzna superbohater: karnacja średnio jasna',
    '🦸🏽‍♂' => 'mężczyzna superbohater: karnacja średnia',
    '🦸🏾‍♂' => 'mężczyzna superbohater: karnacja średnio ciemna',
    '🦸🏿‍♂' => 'mężczyzna superbohater: karnacja ciemna',
    '🦸🏻‍♀' => 'kobieta superbohater: karnacja jasna',
    '🦸🏼‍♀' => 'kobieta superbohater: karnacja średnio jasna',
    '🦸🏽‍♀' => 'kobieta superbohater: karnacja średnia',
    '🦸🏾‍♀' => 'kobieta superbohater: karnacja średnio ciemna',
    '🦸🏿‍♀' => 'kobieta superbohater: karnacja ciemna',
    '🦹🏻‍♂' => 'mężczyzna superłotr: karnacja jasna',
    '🦹🏼‍♂' => 'mężczyzna superłotr: karnacja średnio jasna',
    '🦹🏽‍♂' => 'mężczyzna superłotr: karnacja średnia',
    '🦹🏾‍♂' => 'mężczyzna superłotr: karnacja średnio ciemna',
    '🦹🏿‍♂' => 'mężczyzna superłotr: karnacja ciemna',
    '🦹🏻‍♀' => 'kobieta superłotr: karnacja jasna',
    '🦹🏼‍♀' => 'kobieta superłotr: karnacja średnio jasna',
    '🦹🏽‍♀' => 'kobieta superłotr: karnacja średnia',
    '🦹🏾‍♀' => 'kobieta superłotr: karnacja średnio ciemna',
    '🦹🏿‍♀' => 'kobieta superłotr: karnacja ciemna',
    '🧙🏻‍♂' => 'mężczyzna mag: karnacja jasna',
    '🧙🏼‍♂' => 'mężczyzna mag: karnacja średnio jasna',
    '🧙🏽‍♂' => 'mężczyzna mag: karnacja średnia',
    '🧙🏾‍♂' => 'mężczyzna mag: karnacja średnio ciemna',
    '🧙🏿‍♂' => 'mężczyzna mag: karnacja ciemna',
    '🧙🏻‍♀' => 'kobieta mag: karnacja jasna',
    '🧙🏼‍♀' => 'kobieta mag: karnacja średnio jasna',
    '🧙🏽‍♀' => 'kobieta mag: karnacja średnia',
    '🧙🏾‍♀' => 'kobieta mag: karnacja średnio ciemna',
    '🧙🏿‍♀' => 'kobieta mag: karnacja ciemna',
    '🧚🏻‍♂' => 'mężczyzna wróżka: karnacja jasna',
    '🧚🏼‍♂' => 'mężczyzna wróżka: karnacja średnio jasna',
    '🧚🏽‍♂' => 'mężczyzna wróżka: karnacja średnia',
    '🧚🏾‍♂' => 'mężczyzna wróżka: karnacja średnio ciemna',
    '🧚🏿‍♂' => 'mężczyzna wróżka: karnacja ciemna',
    '🧚🏻‍♀' => 'kobieta wróżka: karnacja jasna',
    '🧚🏼‍♀' => 'kobieta wróżka: karnacja średnio jasna',
    '🧚🏽‍♀' => 'kobieta wróżka: karnacja średnia',
    '🧚🏾‍♀' => 'kobieta wróżka: karnacja średnio ciemna',
    '🧚🏿‍♀' => 'kobieta wróżka: karnacja ciemna',
    '🧛🏻‍♂' => 'mężczyzna wampir: karnacja jasna',
    '🧛🏼‍♂' => 'mężczyzna wampir: karnacja średnio jasna',
    '🧛🏽‍♂' => 'mężczyzna wampir: karnacja średnia',
    '🧛🏾‍♂' => 'mężczyzna wampir: karnacja średnio ciemna',
    '🧛🏿‍♂' => 'mężczyzna wampir: karnacja ciemna',
    '🧛🏻‍♀' => 'kobieta wampir: karnacja jasna',
    '🧛🏼‍♀' => 'kobieta wampir: karnacja średnio jasna',
    '🧛🏽‍♀' => 'kobieta wampir: karnacja średnia',
    '🧛🏾‍♀' => 'kobieta wampir: karnacja średnio ciemna',
    '🧛🏿‍♀' => 'kobieta wampir: karnacja ciemna',
    '🧜🏻‍♂' => 'mężczyzna syrena: karnacja jasna',
    '🧜🏼‍♂' => 'mężczyzna syrena: karnacja średnio jasna',
    '🧜🏽‍♂' => 'mężczyzna syrena: karnacja średnia',
    '🧜🏾‍♂' => 'mężczyzna syrena: karnacja średnio ciemna',
    '🧜🏿‍♂' => 'mężczyzna syrena: karnacja ciemna',
    '🧜🏻‍♀' => 'kobieta syrena: karnacja jasna',
    '🧜🏼‍♀' => 'kobieta syrena: karnacja średnio jasna',
    '🧜🏽‍♀' => 'kobieta syrena: karnacja średnia',
    '🧜🏾‍♀' => 'kobieta syrena: karnacja średnio ciemna',
    '🧜🏿‍♀' => 'kobieta syrena: karnacja ciemna',
    '🧝🏻‍♂' => 'mężczyzna elf: karnacja jasna',
    '🧝🏼‍♂' => 'mężczyzna elf: karnacja średnio jasna',
    '🧝🏽‍♂' => 'mężczyzna elf: karnacja średnia',
    '🧝🏾‍♂' => 'mężczyzna elf: karnacja średnio ciemna',
    '🧝🏿‍♂' => 'mężczyzna elf: karnacja ciemna',
    '🧝🏻‍♀' => 'kobieta elf: karnacja jasna',
    '🧝🏼‍♀' => 'kobieta elf: karnacja średnio jasna',
    '🧝🏽‍♀' => 'kobieta elf: karnacja średnia',
    '🧝🏾‍♀' => 'kobieta elf: karnacja średnio ciemna',
    '🧝🏿‍♀' => 'kobieta elf: karnacja ciemna',
    '💆🏻‍♂' => 'mężczyzna podczas masażu: karnacja jasna',
    '💆🏼‍♂' => 'mężczyzna podczas masażu: karnacja średnio jasna',
    '💆🏽‍♂' => 'mężczyzna podczas masażu: karnacja średnia',
    '💆🏾‍♂' => 'mężczyzna podczas masażu: karnacja średnio ciemna',
    '💆🏿‍♂' => 'mężczyzna podczas masażu: karnacja ciemna',
    '💆🏻‍♀' => 'kobieta podczas masażu: karnacja jasna',
    '💆🏼‍♀' => 'kobieta podczas masażu: karnacja średnio jasna',
    '💆🏽‍♀' => 'kobieta podczas masażu: karnacja średnia',
    '💆🏾‍♀' => 'kobieta podczas masażu: karnacja średnio ciemna',
    '💆🏿‍♀' => 'kobieta podczas masażu: karnacja ciemna',
    '💇🏻‍♂' => 'mężczyzna podczas strzyżenia: karnacja jasna',
    '💇🏼‍♂' => 'mężczyzna podczas strzyżenia: karnacja średnio jasna',
    '💇🏽‍♂' => 'mężczyzna podczas strzyżenia: karnacja średnia',
    '💇🏾‍♂' => 'mężczyzna podczas strzyżenia: karnacja średnio ciemna',
    '💇🏿‍♂' => 'mężczyzna podczas strzyżenia: karnacja ciemna',
    '💇🏻‍♀' => 'kobieta podczas strzyżenia: karnacja jasna',
    '💇🏼‍♀' => 'kobieta podczas strzyżenia: karnacja średnio jasna',
    '💇🏽‍♀' => 'kobieta podczas strzyżenia: karnacja średnia',
    '💇🏾‍♀' => 'kobieta podczas strzyżenia: karnacja średnio ciemna',
    '💇🏿‍♀' => 'kobieta podczas strzyżenia: karnacja ciemna',
    '🚶🏻‍♂' => 'idący mężczyzna: karnacja jasna',
    '🚶🏼‍♂' => 'idący mężczyzna: karnacja średnio jasna',
    '🚶🏽‍♂' => 'idący mężczyzna: karnacja średnia',
    '🚶🏾‍♂' => 'idący mężczyzna: karnacja średnio ciemna',
    '🚶🏿‍♂' => 'idący mężczyzna: karnacja ciemna',
    '🚶🏻‍♀' => 'idąca kobieta: karnacja jasna',
    '🚶🏼‍♀' => 'idąca kobieta: karnacja średnio jasna',
    '🚶🏽‍♀' => 'idąca kobieta: karnacja średnia',
    '🚶🏾‍♀' => 'idąca kobieta: karnacja średnio ciemna',
    '🚶🏿‍♀' => 'idąca kobieta: karnacja ciemna',
    '🚶🏻‍➡' => 'idąca osoba: karnacja jasna i zwrócony w prawo',
    '🚶🏼‍➡' => 'idąca osoba: karnacja średnio jasna i zwrócony w prawo',
    '🚶🏽‍➡' => 'idąca osoba: karnacja średnia i zwrócony w prawo',
    '🚶🏾‍➡' => 'idąca osoba: karnacja średnio ciemna i zwrócony w prawo',
    '🚶🏿‍➡' => 'idąca osoba: karnacja ciemna i zwrócony w prawo',
    '🧍🏻‍♂' => 'stojący mężczyzna: karnacja jasna',
    '🧍🏼‍♂' => 'stojący mężczyzna: karnacja średnio jasna',
    '🧍🏽‍♂' => 'stojący mężczyzna: karnacja średnia',
    '🧍🏾‍♂' => 'stojący mężczyzna: karnacja średnio ciemna',
    '🧍🏿‍♂' => 'stojący mężczyzna: karnacja ciemna',
    '🧍🏻‍♀' => 'stojąca kobieta: karnacja jasna',
    '🧍🏼‍♀' => 'stojąca kobieta: karnacja średnio jasna',
    '🧍🏽‍♀' => 'stojąca kobieta: karnacja średnia',
    '🧍🏾‍♀' => 'stojąca kobieta: karnacja średnio ciemna',
    '🧍🏿‍♀' => 'stojąca kobieta: karnacja ciemna',
    '🧎🏻‍♂' => 'klęczący mężczyzna: karnacja jasna',
    '🧎🏼‍♂' => 'klęczący mężczyzna: karnacja średnio jasna',
    '🧎🏽‍♂' => 'klęczący mężczyzna: karnacja średnia',
    '🧎🏾‍♂' => 'klęczący mężczyzna: karnacja średnio ciemna',
    '🧎🏿‍♂' => 'klęczący mężczyzna: karnacja ciemna',
    '🧎🏻‍♀' => 'klęcząca kobieta: karnacja jasna',
    '🧎🏼‍♀' => 'klęcząca kobieta: karnacja średnio jasna',
    '🧎🏽‍♀' => 'klęcząca kobieta: karnacja średnia',
    '🧎🏾‍♀' => 'klęcząca kobieta: karnacja średnio ciemna',
    '🧎🏿‍♀' => 'klęcząca kobieta: karnacja ciemna',
    '🧎🏻‍➡' => 'klęcząca osoba: karnacja jasna i zwrócony w prawo',
    '🧎🏼‍➡' => 'klęcząca osoba: karnacja średnio jasna i zwrócony w prawo',
    '🧎🏽‍➡' => 'klęcząca osoba: karnacja średnia i zwrócony w prawo',
    '🧎🏾‍➡' => 'klęcząca osoba: karnacja średnio ciemna i zwrócony w prawo',
    '🧎🏿‍➡' => 'klęcząca osoba: karnacja ciemna i zwrócony w prawo',
    '🧑🏻‍🦯' => 'osoba z białą laską: karnacja jasna',
    '🧑🏼‍🦯' => 'osoba z białą laską: karnacja średnio jasna',
    '🧑🏽‍🦯' => 'osoba z białą laską: karnacja średnia',
    '🧑🏾‍🦯' => 'osoba z białą laską: karnacja średnio ciemna',
    '🧑🏿‍🦯' => 'osoba z białą laską: karnacja ciemna',
    '👨🏻‍🦯' => 'mężczyzna z białą laską: karnacja jasna',
    '👨🏼‍🦯' => 'mężczyzna z białą laską: karnacja średnio jasna',
    '👨🏽‍🦯' => 'mężczyzna z białą laską: karnacja średnia',
    '👨🏾‍🦯' => 'mężczyzna z białą laską: karnacja średnio ciemna',
    '👨🏿‍🦯' => 'mężczyzna z białą laską: karnacja ciemna',
    '👩🏻‍🦯' => 'kobieta z białą laską: karnacja jasna',
    '👩🏼‍🦯' => 'kobieta z białą laską: karnacja średnio jasna',
    '👩🏽‍🦯' => 'kobieta z białą laską: karnacja średnia',
    '👩🏾‍🦯' => 'kobieta z białą laską: karnacja średnio ciemna',
    '👩🏿‍🦯' => 'kobieta z białą laską: karnacja ciemna',
    '🧑🏻‍🦼' => 'osoba na elektrycznym wózku inwalidzkim: karnacja jasna',
    '🧑🏼‍🦼' => 'osoba na elektrycznym wózku inwalidzkim: karnacja średnio jasna',
    '🧑🏽‍🦼' => 'osoba na elektrycznym wózku inwalidzkim: karnacja średnia',
    '🧑🏾‍🦼' => 'osoba na elektrycznym wózku inwalidzkim: karnacja średnio ciemna',
    '🧑🏿‍🦼' => 'osoba na elektrycznym wózku inwalidzkim: karnacja ciemna',
    '👨🏻‍🦼' => 'mężczyzna na elektrycznym wózku inwalidzkim: karnacja jasna',
    '👨🏼‍🦼' => 'mężczyzna na elektrycznym wózku inwalidzkim: karnacja średnio jasna',
    '👨🏽‍🦼' => 'mężczyzna na elektrycznym wózku inwalidzkim: karnacja średnia',
    '👨🏾‍🦼' => 'mężczyzna na elektrycznym wózku inwalidzkim: karnacja średnio ciemna',
    '👨🏿‍🦼' => 'mężczyzna na elektrycznym wózku inwalidzkim: karnacja ciemna',
    '👩🏻‍🦼' => 'kobieta na elektrycznym wózku inwalidzkim: karnacja jasna',
    '👩🏼‍🦼' => 'kobieta na elektrycznym wózku inwalidzkim: karnacja średnio jasna',
    '👩🏽‍🦼' => 'kobieta na elektrycznym wózku inwalidzkim: karnacja średnia',
    '👩🏾‍🦼' => 'kobieta na elektrycznym wózku inwalidzkim: karnacja średnio ciemna',
    '👩🏿‍🦼' => 'kobieta na elektrycznym wózku inwalidzkim: karnacja ciemna',
    '🧑🏻‍🦽' => 'osoba na wózku inwalidzkim: karnacja jasna',
    '🧑🏼‍🦽' => 'osoba na wózku inwalidzkim: karnacja średnio jasna',
    '🧑🏽‍🦽' => 'osoba na wózku inwalidzkim: karnacja średnia',
    '🧑🏾‍🦽' => 'osoba na wózku inwalidzkim: karnacja średnio ciemna',
    '🧑🏿‍🦽' => 'osoba na wózku inwalidzkim: karnacja ciemna',
    '👨🏻‍🦽' => 'mężczyzna na wózku inwalidzkim: karnacja jasna',
    '👨🏼‍🦽' => 'mężczyzna na wózku inwalidzkim: karnacja średnio jasna',
    '👨🏽‍🦽' => 'mężczyzna na wózku inwalidzkim: karnacja średnia',
    '👨🏾‍🦽' => 'mężczyzna na wózku inwalidzkim: karnacja średnio ciemna',
    '👨🏿‍🦽' => 'mężczyzna na wózku inwalidzkim: karnacja ciemna',
    '👩🏻‍🦽' => 'kobieta na wózku inwalidzkim: karnacja jasna',
    '👩🏼‍🦽' => 'kobieta na wózku inwalidzkim: karnacja średnio jasna',
    '👩🏽‍🦽' => 'kobieta na wózku inwalidzkim: karnacja średnia',
    '👩🏾‍🦽' => 'kobieta na wózku inwalidzkim: karnacja średnio ciemna',
    '👩🏿‍🦽' => 'kobieta na wózku inwalidzkim: karnacja ciemna',
    '🏃🏻‍♂' => 'biegnący mężczyzna: karnacja jasna',
    '🏃🏼‍♂' => 'biegnący mężczyzna: karnacja średnio jasna',
    '🏃🏽‍♂' => 'biegnący mężczyzna: karnacja średnia',
    '🏃🏾‍♂' => 'biegnący mężczyzna: karnacja średnio ciemna',
    '🏃🏿‍♂' => 'biegnący mężczyzna: karnacja ciemna',
    '🏃🏻‍♀' => 'biegnąca kobieta: karnacja jasna',
    '🏃🏼‍♀' => 'biegnąca kobieta: karnacja średnio jasna',
    '🏃🏽‍♀' => 'biegnąca kobieta: karnacja średnia',
    '🏃🏾‍♀' => 'biegnąca kobieta: karnacja średnio ciemna',
    '🏃🏿‍♀' => 'biegnąca kobieta: karnacja ciemna',
    '🏃🏻‍➡' => 'biegnąca osoba: karnacja jasna i zwrócony w prawo',
    '🏃🏼‍➡' => 'biegnąca osoba: karnacja średnio jasna i zwrócony w prawo',
    '🏃🏽‍➡' => 'biegnąca osoba: karnacja średnia i zwrócony w prawo',
    '🏃🏾‍➡' => 'biegnąca osoba: karnacja średnio ciemna i zwrócony w prawo',
    '🏃🏿‍➡' => 'biegnąca osoba: karnacja ciemna i zwrócony w prawo',
    '👯🏻‍♀' => 'kobiety z uszami królika na przyjęciu: karnacja jasna',
    '👯🏼‍♀' => 'kobiety z uszami królika na przyjęciu: karnacja średnio jasna',
    '👯🏽‍♀' => 'kobiety z uszami królika na przyjęciu: karnacja średnia',
    '👯🏾‍♀' => 'kobiety z uszami królika na przyjęciu: karnacja średnio ciemna',
    '👯🏿‍♀' => 'kobiety z uszami królika na przyjęciu: karnacja ciemna',
    '👯🏻‍♂' => 'mężczyźni z uszami królika na przyjęciu: karnacja jasna',
    '👯🏼‍♂' => 'mężczyźni z uszami królika na przyjęciu: karnacja średnio jasna',
    '👯🏽‍♂' => 'mężczyźni z uszami królika na przyjęciu: karnacja średnia',
    '👯🏾‍♂' => 'mężczyźni z uszami królika na przyjęciu: karnacja średnio ciemna',
    '👯🏿‍♂' => 'mężczyźni z uszami królika na przyjęciu: karnacja ciemna',
    '🧖🏻‍♂' => 'mężczyzna w zaparowanym pomieszczeniu: karnacja jasna',
    '🧖🏼‍♂' => 'mężczyzna w zaparowanym pomieszczeniu: karnacja średnio jasna',
    '🧖🏽‍♂' => 'mężczyzna w zaparowanym pomieszczeniu: karnacja średnia',
    '🧖🏾‍♂' => 'mężczyzna w zaparowanym pomieszczeniu: karnacja średnio ciemna',
    '🧖🏿‍♂' => 'mężczyzna w zaparowanym pomieszczeniu: karnacja ciemna',
    '🧖🏻‍♀' => 'kobieta w zaparowanym pomieszczeniu: karnacja jasna',
    '🧖🏼‍♀' => 'kobieta w zaparowanym pomieszczeniu: karnacja średnio jasna',
    '🧖🏽‍♀' => 'kobieta w zaparowanym pomieszczeniu: karnacja średnia',
    '🧖🏾‍♀' => 'kobieta w zaparowanym pomieszczeniu: karnacja średnio ciemna',
    '🧖🏿‍♀' => 'kobieta w zaparowanym pomieszczeniu: karnacja ciemna',
    '🧗🏻‍♂' => 'mężczyzna wspinający się: karnacja jasna',
    '🧗🏼‍♂' => 'mężczyzna wspinający się: karnacja średnio jasna',
    '🧗🏽‍♂' => 'mężczyzna wspinający się: karnacja średnia',
    '🧗🏾‍♂' => 'mężczyzna wspinający się: karnacja średnio ciemna',
    '🧗🏿‍♂' => 'mężczyzna wspinający się: karnacja ciemna',
    '🧗🏻‍♀' => 'kobieta wspinająca się: karnacja jasna',
    '🧗🏼‍♀' => 'kobieta wspinająca się: karnacja średnio jasna',
    '🧗🏽‍♀' => 'kobieta wspinająca się: karnacja średnia',
    '🧗🏾‍♀' => 'kobieta wspinająca się: karnacja średnio ciemna',
    '🧗🏿‍♀' => 'kobieta wspinająca się: karnacja ciemna',
    '🏌🏻‍♂' => 'mężczyzna grający w golfa: karnacja jasna',
    '🏌🏼‍♂' => 'mężczyzna grający w golfa: karnacja średnio jasna',
    '🏌🏽‍♂' => 'mężczyzna grający w golfa: karnacja średnia',
    '🏌🏾‍♂' => 'mężczyzna grający w golfa: karnacja średnio ciemna',
    '🏌🏿‍♂' => 'mężczyzna grający w golfa: karnacja ciemna',
    '🏌🏻‍♀' => 'kobieta grająca w golfa: karnacja jasna',
    '🏌🏼‍♀' => 'kobieta grająca w golfa: karnacja średnio jasna',
    '🏌🏽‍♀' => 'kobieta grająca w golfa: karnacja średnia',
    '🏌🏾‍♀' => 'kobieta grająca w golfa: karnacja średnio ciemna',
    '🏌🏿‍♀' => 'kobieta grająca w golfa: karnacja ciemna',
    '🏄🏻‍♂' => 'surfujący mężczyzna: karnacja jasna',
    '🏄🏼‍♂' => 'surfujący mężczyzna: karnacja średnio jasna',
    '🏄🏽‍♂' => 'surfujący mężczyzna: karnacja średnia',
    '🏄🏾‍♂' => 'surfujący mężczyzna: karnacja średnio ciemna',
    '🏄🏿‍♂' => 'surfujący mężczyzna: karnacja ciemna',
    '🏄🏻‍♀' => 'surfująca kobieta: karnacja jasna',
    '🏄🏼‍♀' => 'surfująca kobieta: karnacja średnio jasna',
    '🏄🏽‍♀' => 'surfująca kobieta: karnacja średnia',
    '🏄🏾‍♀' => 'surfująca kobieta: karnacja średnio ciemna',
    '🏄🏿‍♀' => 'surfująca kobieta: karnacja ciemna',
    '🚣🏻‍♂' => 'mężczyzna wiosłujący w łodzi: karnacja jasna',
    '🚣🏼‍♂' => 'mężczyzna wiosłujący w łodzi: karnacja średnio jasna',
    '🚣🏽‍♂' => 'mężczyzna wiosłujący w łodzi: karnacja średnia',
    '🚣🏾‍♂' => 'mężczyzna wiosłujący w łodzi: karnacja średnio ciemna',
    '🚣🏿‍♂' => 'mężczyzna wiosłujący w łodzi: karnacja ciemna',
    '🚣🏻‍♀' => 'kobieta wiosłująca w łodzi: karnacja jasna',
    '🚣🏼‍♀' => 'kobieta wiosłująca w łodzi: karnacja średnio jasna',
    '🚣🏽‍♀' => 'kobieta wiosłująca w łodzi: karnacja średnia',
    '🚣🏾‍♀' => 'kobieta wiosłująca w łodzi: karnacja średnio ciemna',
    '🚣🏿‍♀' => 'kobieta wiosłująca w łodzi: karnacja ciemna',
    '🏊🏻‍♂' => 'pływający mężczyzna: karnacja jasna',
    '🏊🏼‍♂' => 'pływający mężczyzna: karnacja średnio jasna',
    '🏊🏽‍♂' => 'pływający mężczyzna: karnacja średnia',
    '🏊🏾‍♂' => 'pływający mężczyzna: karnacja średnio ciemna',
    '🏊🏿‍♂' => 'pływający mężczyzna: karnacja ciemna',
    '🏊🏻‍♀' => 'pływająca kobieta: karnacja jasna',
    '🏊🏼‍♀' => 'pływająca kobieta: karnacja średnio jasna',
    '🏊🏽‍♀' => 'pływająca kobieta: karnacja średnia',
    '🏊🏾‍♀' => 'pływająca kobieta: karnacja średnio ciemna',
    '🏊🏿‍♀' => 'pływająca kobieta: karnacja ciemna',
    '⛹🏻‍♂' => 'mężczyzna kozłujący piłkę: karnacja jasna',
    '⛹🏼‍♂' => 'mężczyzna kozłujący piłkę: karnacja średnio jasna',
    '⛹🏽‍♂' => 'mężczyzna kozłujący piłkę: karnacja średnia',
    '⛹🏾‍♂' => 'mężczyzna kozłujący piłkę: karnacja średnio ciemna',
    '⛹🏿‍♂' => 'mężczyzna kozłujący piłkę: karnacja ciemna',
    '⛹🏻‍♀' => 'kobieta kozłująca piłkę: karnacja jasna',
    '⛹🏼‍♀' => 'kobieta kozłująca piłkę: karnacja średnio jasna',
    '⛹🏽‍♀' => 'kobieta kozłująca piłkę: karnacja średnia',
    '⛹🏾‍♀' => 'kobieta kozłująca piłkę: karnacja średnio ciemna',
    '⛹🏿‍♀' => 'kobieta kozłująca piłkę: karnacja ciemna',
    '🏋🏻‍♂' => 'mężczyzna podnoszący ciężary: karnacja jasna',
    '🏋🏼‍♂' => 'mężczyzna podnoszący ciężary: karnacja średnio jasna',
    '🏋🏽‍♂' => 'mężczyzna podnoszący ciężary: karnacja średnia',
    '🏋🏾‍♂' => 'mężczyzna podnoszący ciężary: karnacja średnio ciemna',
    '🏋🏿‍♂' => 'mężczyzna podnoszący ciężary: karnacja ciemna',
    '🏋🏻‍♀' => 'kobieta podnosząca ciężary: karnacja jasna',
    '🏋🏼‍♀' => 'kobieta podnosząca ciężary: karnacja średnio jasna',
    '🏋🏽‍♀' => 'kobieta podnosząca ciężary: karnacja średnia',
    '🏋🏾‍♀' => 'kobieta podnosząca ciężary: karnacja średnio ciemna',
    '🏋🏿‍♀' => 'kobieta podnosząca ciężary: karnacja ciemna',
    '🚴🏻‍♂' => 'mężczyzna na rowerze: karnacja jasna',
    '🚴🏼‍♂' => 'mężczyzna na rowerze: karnacja średnio jasna',
    '🚴🏽‍♂' => 'mężczyzna na rowerze: karnacja średnia',
    '🚴🏾‍♂' => 'mężczyzna na rowerze: karnacja średnio ciemna',
    '🚴🏿‍♂' => 'mężczyzna na rowerze: karnacja ciemna',
    '🚴🏻‍♀' => 'kobieta na rowerze: karnacja jasna',
    '🚴🏼‍♀' => 'kobieta na rowerze: karnacja średnio jasna',
    '🚴🏽‍♀' => 'kobieta na rowerze: karnacja średnia',
    '🚴🏾‍♀' => 'kobieta na rowerze: karnacja średnio ciemna',
    '🚴🏿‍♀' => 'kobieta na rowerze: karnacja ciemna',
    '🚵🏻‍♂' => 'mężczyzna na rowerze górskim: karnacja jasna',
    '🚵🏼‍♂' => 'mężczyzna na rowerze górskim: karnacja średnio jasna',
    '🚵🏽‍♂' => 'mężczyzna na rowerze górskim: karnacja średnia',
    '🚵🏾‍♂' => 'mężczyzna na rowerze górskim: karnacja średnio ciemna',
    '🚵🏿‍♂' => 'mężczyzna na rowerze górskim: karnacja ciemna',
    '🚵🏻‍♀' => 'kobieta na rowerze górskim: karnacja jasna',
    '🚵🏼‍♀' => 'kobieta na rowerze górskim: karnacja średnio jasna',
    '🚵🏽‍♀' => 'kobieta na rowerze górskim: karnacja średnia',
    '🚵🏾‍♀' => 'kobieta na rowerze górskim: karnacja średnio ciemna',
    '🚵🏿‍♀' => 'kobieta na rowerze górskim: karnacja ciemna',
    '🤸🏻‍♂' => 'mężczyzna robiący gwiazdę: karnacja jasna',
    '🤸🏼‍♂' => 'mężczyzna robiący gwiazdę: karnacja średnio jasna',
    '🤸🏽‍♂' => 'mężczyzna robiący gwiazdę: karnacja średnia',
    '🤸🏾‍♂' => 'mężczyzna robiący gwiazdę: karnacja średnio ciemna',
    '🤸🏿‍♂' => 'mężczyzna robiący gwiazdę: karnacja ciemna',
    '🤸🏻‍♀' => 'kobieta robiąca gwiazdę: karnacja jasna',
    '🤸🏼‍♀' => 'kobieta robiąca gwiazdę: karnacja średnio jasna',
    '🤸🏽‍♀' => 'kobieta robiąca gwiazdę: karnacja średnia',
    '🤸🏾‍♀' => 'kobieta robiąca gwiazdę: karnacja średnio ciemna',
    '🤸🏿‍♀' => 'kobieta robiąca gwiazdę: karnacja ciemna',
    '🤼🏻‍♀' => 'kobiety uprawiające zapasy: karnacja jasna',
    '🤼🏼‍♀' => 'kobiety uprawiające zapasy: karnacja średnio jasna',
    '🤼🏽‍♀' => 'kobiety uprawiające zapasy: karnacja średnia',
    '🤼🏾‍♀' => 'kobiety uprawiające zapasy: karnacja średnio ciemna',
    '🤼🏿‍♀' => 'kobiety uprawiające zapasy: karnacja ciemna',
    '🤼🏻‍♂' => 'mężczyźni uprawiający zapasy: karnacja jasna',
    '🤼🏼‍♂' => 'mężczyźni uprawiający zapasy: karnacja średnio jasna',
    '🤼🏽‍♂' => 'mężczyźni uprawiający zapasy: karnacja średnia',
    '🤼🏾‍♂' => 'mężczyźni uprawiający zapasy: karnacja średnio ciemna',
    '🤼🏿‍♂' => 'mężczyźni uprawiający zapasy: karnacja ciemna',
    '🤽🏻‍♂' => 'mężczyzna grający w piłkę wodną: karnacja jasna',
    '🤽🏼‍♂' => 'mężczyzna grający w piłkę wodną: karnacja średnio jasna',
    '🤽🏽‍♂' => 'mężczyzna grający w piłkę wodną: karnacja średnia',
    '🤽🏾‍♂' => 'mężczyzna grający w piłkę wodną: karnacja średnio ciemna',
    '🤽🏿‍♂' => 'mężczyzna grający w piłkę wodną: karnacja ciemna',
    '🤽🏻‍♀' => 'kobieta grająca w piłkę wodną: karnacja jasna',
    '🤽🏼‍♀' => 'kobieta grająca w piłkę wodną: karnacja średnio jasna',
    '🤽🏽‍♀' => 'kobieta grająca w piłkę wodną: karnacja średnia',
    '🤽🏾‍♀' => 'kobieta grająca w piłkę wodną: karnacja średnio ciemna',
    '🤽🏿‍♀' => 'kobieta grająca w piłkę wodną: karnacja ciemna',
    '🤾🏻‍♂' => 'mężczyzna grający w piłkę ręczną: karnacja jasna',
    '🤾🏼‍♂' => 'mężczyzna grający w piłkę ręczną: karnacja średnio jasna',
    '🤾🏽‍♂' => 'mężczyzna grający w piłkę ręczną: karnacja średnia',
    '🤾🏾‍♂' => 'mężczyzna grający w piłkę ręczną: karnacja średnio ciemna',
    '🤾🏿‍♂' => 'mężczyzna grający w piłkę ręczną: karnacja ciemna',
    '🤾🏻‍♀' => 'kobieta grająca w piłkę ręczną: karnacja jasna',
    '🤾🏼‍♀' => 'kobieta grająca w piłkę ręczną: karnacja średnio jasna',
    '🤾🏽‍♀' => 'kobieta grająca w piłkę ręczną: karnacja średnia',
    '🤾🏾‍♀' => 'kobieta grająca w piłkę ręczną: karnacja średnio ciemna',
    '🤾🏿‍♀' => 'kobieta grająca w piłkę ręczną: karnacja ciemna',
    '🤹🏻‍♂' => 'żonglujący mężczyzna: karnacja jasna',
    '🤹🏼‍♂' => 'żonglujący mężczyzna: karnacja średnio jasna',
    '🤹🏽‍♂' => 'żonglujący mężczyzna: karnacja średnia',
    '🤹🏾‍♂' => 'żonglujący mężczyzna: karnacja średnio ciemna',
    '🤹🏿‍♂' => 'żonglujący mężczyzna: karnacja ciemna',
    '🤹🏻‍♀' => 'żonglująca kobieta: karnacja jasna',
    '🤹🏼‍♀' => 'żonglująca kobieta: karnacja średnio jasna',
    '🤹🏽‍♀' => 'żonglująca kobieta: karnacja średnia',
    '🤹🏾‍♀' => 'żonglująca kobieta: karnacja średnio ciemna',
    '🤹🏿‍♀' => 'żonglująca kobieta: karnacja ciemna',
    '🧘🏻‍♂' => 'mężczyzna w pozycji lotosu: karnacja jasna',
    '🧘🏼‍♂' => 'mężczyzna w pozycji lotosu: karnacja średnio jasna',
    '🧘🏽‍♂' => 'mężczyzna w pozycji lotosu: karnacja średnia',
    '🧘🏾‍♂' => 'mężczyzna w pozycji lotosu: karnacja średnio ciemna',
    '🧘🏿‍♂' => 'mężczyzna w pozycji lotosu: karnacja ciemna',
    '🧘🏻‍♀' => 'kobieta w pozycji lotosu: karnacja jasna',
    '🧘🏼‍♀' => 'kobieta w pozycji lotosu: karnacja średnio jasna',
    '🧘🏽‍♀' => 'kobieta w pozycji lotosu: karnacja średnia',
    '🧘🏾‍♀' => 'kobieta w pozycji lotosu: karnacja średnio ciemna',
    '🧘🏿‍♀' => 'kobieta w pozycji lotosu: karnacja ciemna',
    '🧑‍🦰' => 'dorosły: rude włosy',
    '🧑‍🦱' => 'dorosły: kręcone włosy',
    '🧑‍🦳' => 'dorosły: białe włosy',
    '🧑‍🦲' => 'dorosły: łysy',
    '👨‍🦰' => 'mężczyzna: rude włosy',
    '👨‍🦱' => 'mężczyzna: kręcone włosy',
    '👨‍🦳' => 'mężczyzna: białe włosy',
    '👨‍🦲' => 'mężczyzna: łysy',
    '👩‍🦰' => 'kobieta: rude włosy',
    '👩‍🦱' => 'kobieta: kręcone włosy',
    '👩‍🦳' => 'kobieta: białe włosy',
    '👩‍🦲' => 'kobieta: łysy',
    '🚶‍➡' => 'idąca osoba: zwrócony w prawo',
    '🧎‍➡' => 'klęcząca osoba: zwrócony w prawo',
    '🏃‍➡' => 'biegnąca osoba: zwrócony w prawo',
    '👨‍👦' => 'rodzina: mężczyzna i chłopiec',
    '👨‍👧' => 'rodzina: mężczyzna i dziewczynka',
    '👩‍👦' => 'rodzina: kobieta i chłopiec',
    '👩‍👧' => 'rodzina: kobieta i dziewczynka',
    '😶‍🌫' => 'twarz w chmurach',
    '😮‍💨' => 'twarz wypuszczająca powietrze',
    '🙂‍↕' => 'głowa kiwająca się pionowo',
    '😵‍💫' => 'twarz ze spiralnymi oczami',
    '❤‍🔥' => 'serce w płomieniach',
    '❤‍🩹' => 'uleczone serce',
    '👁‍🗨' => 'oko w dymku',
    '🧔‍♂' => 'mężczyzna z brodą',
    '👱‍♂' => 'blondyn',
    '🧔‍♀' => 'kobieta z brodą',
    '👱‍♀' => 'blondynka',
    '🙍‍♂' => 'zachmurzony mężczyzna',
    '🙍‍♀' => 'zachmurzona kobieta',
    '🙎‍♂' => 'nadąsany mężczyzna',
    '🙎‍♀' => 'nadąsana kobieta',
    '🙅‍♂' => 'mężczyzna pokazujący gest NIE',
    '🙅‍♀' => 'kobieta pokazująca gest NIE',
    '🙆‍♂' => 'mężczyzna pokazujący gest OK',
    '🙆‍♀' => 'kobieta pokazująca gest OK',
    '💁‍♂' => 'mężczyzna z wystawioną dłonią',
    '💁‍♀' => 'kobieta z wystawioną dłonią',
    '🙋‍♂' => 'mężczyzna podnoszący rękę',
    '🙋‍♀' => 'kobieta podnosząca rękę',
    '🧏‍♂' => 'głuchy mężczyzna',
    '🧏‍♀' => 'głucha kobieta',
    '🙇‍♂' => 'mężczyzna w ukłonie',
    '🙇‍♀' => 'kobieta w ukłonie',
    '🤦‍♂' => 'mężczyzna trzymający się za czoło',
    '🤦‍♀' => 'kobieta trzymająca się za czoło',
    '🤷‍♂' => 'mężczyzna wzruszający ramionami',
    '🤷‍♀' => 'kobieta wzruszająca ramionami',
    '🧑‍⚕' => 'pracownik służby zdrowia',
    '👨‍⚕' => 'lekarz',
    '👩‍⚕' => 'lekarka',
    '🧑‍🎓' => 'student',
    '👨‍🎓' => 'mężczyzna student',
    '👩‍🎓' => 'studentka',
    '🧑‍🏫' => 'nauczyciel',
    '👨‍🏫' => 'mężczyzna nauczyciel',
    '👩‍🏫' => 'nauczycielka',
    '🧑‍⚖' => 'sędzia',
    '👨‍⚖' => 'mężczyzna sędzia',
    '👩‍⚖' => 'kobieta sędzia',
    '🧑‍🌾' => 'rolnik',
    '👨‍🌾' => 'mężczyzna rolnik',
    '👩‍🌾' => 'rolniczka',
    '🧑‍🍳' => 'kucharz',
    '👨‍🍳' => 'mężczyzna kucharz',
    '👩‍🍳' => 'kucharka',
    '🧑‍🔧' => 'mechanik',
    '👨‍🔧' => 'mężczyzna elektryk',
    '👩‍🔧' => 'kobieta elektryk',
    '🧑‍🏭' => 'pracownik fabryki',
    '👨‍🏭' => 'mężczyzna pracownik fabryki',
    '👩‍🏭' => 'pracownica fabryki',
    '🧑‍💼' => 'pracownik biurowy',
    '👨‍💼' => 'mężczyzna pracownik biurowy',
    '👩‍💼' => 'pracownica biurowa',
    '🧑‍🔬' => 'naukowiec',
    '👨‍🔬' => 'mężczyzna naukowiec',
    '👩‍🔬' => 'kobieta naukowiec',
    '🧑‍💻' => 'technolog',
    '👨‍💻' => 'mężczyzna technolog',
    '👩‍💻' => 'kobieta technolog',
    '🧑‍🎤' => 'piosenkarz',
    '👨‍🎤' => 'mężczyzna piosenkarz',
    '👩‍🎤' => 'piosenkarka',
    '🧑‍🎨' => 'artysta',
    '👨‍🎨' => 'mężczyzna artysta',
    '👩‍🎨' => 'artystka',
    '🧑‍✈' => 'pilot',
    '👨‍✈' => 'mężczyzna pilot',
    '👩‍✈' => 'kobieta pilot',
    '🧑‍🚀' => 'astronauta',
    '👨‍🚀' => 'mężczyzna astronauta',
    '👩‍🚀' => 'astronautka',
    '🧑‍🚒' => 'strażak',
    '👨‍🚒' => 'mężczyzna strażak',
    '👩‍🚒' => 'kobieta strażak',
    '👮‍♂' => 'mężczyzna policjant',
    '👮‍♀' => 'kobieta policjant',
    '🕵‍♂' => 'mężczyzna detektyw',
    '🕵‍♀' => 'kobieta detektyw',
    '💂‍♂' => 'mężczyzna gwardzista',
    '💂‍♀' => 'kobieta gwardzista',
    '👷‍♂' => 'mężczyzna budowlaniec',
    '👷‍♀' => 'kobieta budowlaniec',
    '👳‍♂' => 'mężczyzna w turbanie',
    '👳‍♀' => 'kobieta w turbanie',
    '🤵‍♂' => 'mężczyzna w smokingu',
    '🤵‍♀' => 'kobieta w smokingu',
    '👰‍♂' => 'mężczyzna w welonie',
    '👰‍♀' => 'kobieta w welonie',
    '👩‍🍼' => 'kobieta karmiąca niemowlę',
    '👨‍🍼' => 'mężczyzna karmiący niemowlę',
    '🧑‍🍼' => 'osoba karmiąca niemowlę',
    '🧑‍🎄' => 'Mikołajka',
    '🦸‍♂' => 'mężczyzna superbohater',
    '🦸‍♀' => 'kobieta superbohater',
    '🦹‍♂' => 'mężczyzna superłotr',
    '🦹‍♀' => 'kobieta superłotr',
    '🧙‍♂' => 'mężczyzna mag',
    '🧙‍♀' => 'kobieta mag',
    '🧚‍♂' => 'mężczyzna wróżka',
    '🧚‍♀' => 'kobieta wróżka',
    '🧛‍♂' => 'mężczyzna wampir',
    '🧛‍♀' => 'kobieta wampir',
    '🧜‍♂' => 'mężczyzna syrena',
    '🧜‍♀' => 'kobieta syrena',
    '🧝‍♂' => 'mężczyzna elf',
    '🧝‍♀' => 'kobieta elf',
    '🧞‍♂' => 'mężczyzna dżin',
    '🧞‍♀' => 'kobieta dżin',
    '🧟‍♂' => 'mężczyzna zombie',
    '🧟‍♀' => 'kobieta zombie',
    '💆‍♂' => 'mężczyzna podczas masażu',
    '💆‍♀' => 'kobieta podczas masażu',
    '💇‍♂' => 'mężczyzna podczas strzyżenia',
    '💇‍♀' => 'kobieta podczas strzyżenia',
    '🚶‍♂' => 'idący mężczyzna',
    '🚶‍♀' => 'idąca kobieta',
    '🧍‍♂' => 'stojący mężczyzna',
    '🧍‍♀' => 'stojąca kobieta',
    '🧎‍♂' => 'klęczący mężczyzna',
    '🧎‍♀' => 'klęcząca kobieta',
    '🧑‍🦯' => 'osoba z białą laską',
    '👨‍🦯' => 'mężczyzna z białą laską',
    '👩‍🦯' => 'kobieta z białą laską',
    '🧑‍🦼' => 'osoba na elektrycznym wózku inwalidzkim',
    '👨‍🦼' => 'mężczyzna na elektrycznym wózku inwalidzkim',
    '👩‍🦼' => 'kobieta na elektrycznym wózku inwalidzkim',
    '🧑‍🦽' => 'osoba na wózku inwalidzkim',
    '👨‍🦽' => 'mężczyzna na wózku inwalidzkim',
    '👩‍🦽' => 'kobieta na wózku inwalidzkim',
    '🏃‍♂' => 'biegnący mężczyzna',
    '🏃‍♀' => 'biegnąca kobieta',
    '🧑‍🩰' => 'baletnica',
    '👯‍♂' => 'mężczyźni z uszami królika na przyjęciu',
    '👯‍♀' => 'kobiety z uszami królika na przyjęciu',
    '🧖‍♂' => 'mężczyzna w zaparowanym pomieszczeniu',
    '🧖‍♀' => 'kobieta w zaparowanym pomieszczeniu',
    '🧗‍♂' => 'mężczyzna wspinający się',
    '🧗‍♀' => 'kobieta wspinająca się',
    '🏌‍♂' => 'mężczyzna grający w golfa',
    '🏌‍♀' => 'kobieta grająca w golfa',
    '🏄‍♂' => 'surfujący mężczyzna',
    '🏄‍♀' => 'surfująca kobieta',
    '🚣‍♂' => 'mężczyzna wiosłujący w łodzi',
    '🚣‍♀' => 'kobieta wiosłująca w łodzi',
    '🏊‍♂' => 'pływający mężczyzna',
    '🏊‍♀' => 'pływająca kobieta',
    '⛹‍♂' => 'mężczyzna kozłujący piłkę',
    '⛹‍♀' => 'kobieta kozłująca piłkę',
    '🏋‍♂' => 'mężczyzna podnoszący ciężary',
    '🏋‍♀' => 'kobieta podnosząca ciężary',
    '🚴‍♂' => 'mężczyzna na rowerze',
    '🚴‍♀' => 'kobieta na rowerze',
    '🚵‍♂' => 'mężczyzna na rowerze górskim',
    '🚵‍♀' => 'kobieta na rowerze górskim',
    '🤸‍♂' => 'mężczyzna robiący gwiazdę',
    '🤸‍♀' => 'kobieta robiąca gwiazdę',
    '🤼‍♂' => 'mężczyźni uprawiający zapasy',
    '🤼‍♀' => 'kobiety uprawiające zapasy',
    '🤽‍♂' => 'mężczyzna grający w piłkę wodną',
    '🤽‍♀' => 'kobieta grająca w piłkę wodną',
    '🤾‍♂' => 'mężczyzna grający w piłkę ręczną',
    '🤾‍♀' => 'kobieta grająca w piłkę ręczną',
    '🤹‍♂' => 'żonglujący mężczyzna',
    '🤹‍♀' => 'żonglująca kobieta',
    '🧘‍♂' => 'mężczyzna w pozycji lotosu',
    '🧘‍♀' => 'kobieta w pozycji lotosu',
    '🧑‍🧒' => 'rodzina: dorosły, dziecko',
    '🐕‍🦺' => 'pies pomocnik',
    '🐈‍⬛' => 'czarny kot',
    '🐻‍❄' => 'niedźwiedź polarny',
    '🐦‍⬛' => 'czarny ptak',
    '🐦‍🔥' => 'feniks',
    '🍋‍🟩' => 'limonka',
    '🍄‍🟫' => 'brązowy grzyb',
    '⛓‍💥' => 'zerwany łańcuch',
    '🏳‍🌈' => 'tęczowa flaga',
    '🏳‍⚧' => 'flaga osób transpłciowych',
    '🏴‍☠' => 'piracka flaga',
    '👋🏻' => 'machająca dłoń: karnacja jasna',
    '👋🏼' => 'machająca dłoń: karnacja średnio jasna',
    '👋🏽' => 'machająca dłoń: karnacja średnia',
    '👋🏾' => 'machająca dłoń: karnacja średnio ciemna',
    '👋🏿' => 'machająca dłoń: karnacja ciemna',
    '🤚🏻' => 'wzniesiony grzbiet dłoni: karnacja jasna',
    '🤚🏼' => 'wzniesiony grzbiet dłoni: karnacja średnio jasna',
    '🤚🏽' => 'wzniesiony grzbiet dłoni: karnacja średnia',
    '🤚🏾' => 'wzniesiony grzbiet dłoni: karnacja średnio ciemna',
    '🤚🏿' => 'wzniesiony grzbiet dłoni: karnacja ciemna',
    '🖐🏻' => 'uniesiona otwarta dłoń: karnacja jasna',
    '🖐🏼' => 'uniesiona otwarta dłoń: karnacja średnio jasna',
    '🖐🏽' => 'uniesiona otwarta dłoń: karnacja średnia',
    '🖐🏾' => 'uniesiona otwarta dłoń: karnacja średnio ciemna',
    '🖐🏿' => 'uniesiona otwarta dłoń: karnacja ciemna',
    '✋🏻' => 'wzniesiona dłoń: karnacja jasna',
    '✋🏼' => 'wzniesiona dłoń: karnacja średnio jasna',
    '✋🏽' => 'wzniesiona dłoń: karnacja średnia',
    '✋🏾' => 'wzniesiona dłoń: karnacja średnio ciemna',
    '✋🏿' => 'wzniesiona dłoń: karnacja ciemna',
    '🖖🏻' => 'salut wolkański: karnacja jasna',
    '🖖🏼' => 'salut wolkański: karnacja średnio jasna',
    '🖖🏽' => 'salut wolkański: karnacja średnia',
    '🖖🏾' => 'salut wolkański: karnacja średnio ciemna',
    '🖖🏿' => 'salut wolkański: karnacja ciemna',
    '🫱🏻' => 'dłoń skierowana w prawo: karnacja jasna',
    '🫱🏼' => 'dłoń skierowana w prawo: karnacja średnio jasna',
    '🫱🏽' => 'dłoń skierowana w prawo: karnacja średnia',
    '🫱🏾' => 'dłoń skierowana w prawo: karnacja średnio ciemna',
    '🫱🏿' => 'dłoń skierowana w prawo: karnacja ciemna',
    '🫲🏻' => 'dłoń skierowana w lewo: karnacja jasna',
    '🫲🏼' => 'dłoń skierowana w lewo: karnacja średnio jasna',
    '🫲🏽' => 'dłoń skierowana w lewo: karnacja średnia',
    '🫲🏾' => 'dłoń skierowana w lewo: karnacja średnio ciemna',
    '🫲🏿' => 'dłoń skierowana w lewo: karnacja ciemna',
    '🫳🏻' => 'dłoń skierowana w dół: karnacja jasna',
    '🫳🏼' => 'dłoń skierowana w dół: karnacja średnio jasna',
    '🫳🏽' => 'dłoń skierowana w dół: karnacja średnia',
    '🫳🏾' => 'dłoń skierowana w dół: karnacja średnio ciemna',
    '🫳🏿' => 'dłoń skierowana w dół: karnacja ciemna',
    '🫴🏻' => 'dłoń skierowana w górę: karnacja jasna',
    '🫴🏼' => 'dłoń skierowana w górę: karnacja średnio jasna',
    '🫴🏽' => 'dłoń skierowana w górę: karnacja średnia',
    '🫴🏾' => 'dłoń skierowana w górę: karnacja średnio ciemna',
    '🫴🏿' => 'dłoń skierowana w górę: karnacja ciemna',
    '🫷🏻' => 'dłoń pchająca w lewo: karnacja jasna',
    '🫷🏼' => 'dłoń pchająca w lewo: karnacja średnio jasna',
    '🫷🏽' => 'dłoń pchająca w lewo: karnacja średnia',
    '🫷🏾' => 'dłoń pchająca w lewo: karnacja średnio ciemna',
    '🫷🏿' => 'dłoń pchająca w lewo: karnacja ciemna',
    '🫸🏻' => 'dłoń pchająca w prawo: karnacja jasna',
    '🫸🏼' => 'dłoń pchająca w prawo: karnacja średnio jasna',
    '🫸🏽' => 'dłoń pchająca w prawo: karnacja średnia',
    '🫸🏾' => 'dłoń pchająca w prawo: karnacja średnio ciemna',
    '🫸🏿' => 'dłoń pchająca w prawo: karnacja ciemna',
    '👌🏻' => 'dłoń z gestem OK: karnacja jasna',
    '👌🏼' => 'dłoń z gestem OK: karnacja średnio jasna',
    '👌🏽' => 'dłoń z gestem OK: karnacja średnia',
    '👌🏾' => 'dłoń z gestem OK: karnacja średnio ciemna',
    '👌🏿' => 'dłoń z gestem OK: karnacja ciemna',
    '🤌🏻' => 'złączone palce: karnacja jasna',
    '🤌🏼' => 'złączone palce: karnacja średnio jasna',
    '🤌🏽' => 'złączone palce: karnacja średnia',
    '🤌🏾' => 'złączone palce: karnacja średnio ciemna',
    '🤌🏿' => 'złączone palce: karnacja ciemna',
    '🤏🏻' => 'dłoń z gestem „trochę”: karnacja jasna',
    '🤏🏼' => 'dłoń z gestem „trochę”: karnacja średnio jasna',
    '🤏🏽' => 'dłoń z gestem „trochę”: karnacja średnia',
    '🤏🏾' => 'dłoń z gestem „trochę”: karnacja średnio ciemna',
    '🤏🏿' => 'dłoń z gestem „trochę”: karnacja ciemna',
    '✌🏻' => 'gest V: karnacja jasna',
    '✌🏼' => 'gest V: karnacja średnio jasna',
    '✌🏽' => 'gest V: karnacja średnia',
    '✌🏾' => 'gest V: karnacja średnio ciemna',
    '✌🏿' => 'gest V: karnacja ciemna',
    '🤞🏻' => 'skrzyżowane palce: karnacja jasna',
    '🤞🏼' => 'skrzyżowane palce: karnacja średnio jasna',
    '🤞🏽' => 'skrzyżowane palce: karnacja średnia',
    '🤞🏾' => 'skrzyżowane palce: karnacja średnio ciemna',
    '🤞🏿' => 'skrzyżowane palce: karnacja ciemna',
    '🫰🏻' => 'dłoń ze skrzyżowanym palcem wskazującym i kciukiem: karnacja jasna',
    '🫰🏼' => 'dłoń ze skrzyżowanym palcem wskazującym i kciukiem: karnacja średnio jasna',
    '🫰🏽' => 'dłoń ze skrzyżowanym palcem wskazującym i kciukiem: karnacja średnia',
    '🫰🏾' => 'dłoń ze skrzyżowanym palcem wskazującym i kciukiem: karnacja średnio ciemna',
    '🫰🏿' => 'dłoń ze skrzyżowanym palcem wskazującym i kciukiem: karnacja ciemna',
    '🤟🏻' => 'gest Kocham cię: karnacja jasna',
    '🤟🏼' => 'gest Kocham cię: karnacja średnio jasna',
    '🤟🏽' => 'gest Kocham cię: karnacja średnia',
    '🤟🏾' => 'gest Kocham cię: karnacja średnio ciemna',
    '🤟🏿' => 'gest Kocham cię: karnacja ciemna',
    '🤘🏻' => 'gest rogów: karnacja jasna',
    '🤘🏼' => 'gest rogów: karnacja średnio jasna',
    '🤘🏽' => 'gest rogów: karnacja średnia',
    '🤘🏾' => 'gest rogów: karnacja średnio ciemna',
    '🤘🏿' => 'gest rogów: karnacja ciemna',
    '🤙🏻' => 'dłoń w geście „Zadzwoń do mnie”: karnacja jasna',
    '🤙🏼' => 'dłoń w geście „Zadzwoń do mnie”: karnacja średnio jasna',
    '🤙🏽' => 'dłoń w geście „Zadzwoń do mnie”: karnacja średnia',
    '🤙🏾' => 'dłoń w geście „Zadzwoń do mnie”: karnacja średnio ciemna',
    '🤙🏿' => 'dłoń w geście „Zadzwoń do mnie”: karnacja ciemna',
    '👈🏻' => 'dłoń z palcem wskazującym w lewo: karnacja jasna',
    '👈🏼' => 'dłoń z palcem wskazującym w lewo: karnacja średnio jasna',
    '👈🏽' => 'dłoń z palcem wskazującym w lewo: karnacja średnia',
    '👈🏾' => 'dłoń z palcem wskazującym w lewo: karnacja średnio ciemna',
    '👈🏿' => 'dłoń z palcem wskazującym w lewo: karnacja ciemna',
    '👉🏻' => 'dłoń z palcem wskazującym w prawo: karnacja jasna',
    '👉🏼' => 'dłoń z palcem wskazującym w prawo: karnacja średnio jasna',
    '👉🏽' => 'dłoń z palcem wskazującym w prawo: karnacja średnia',
    '👉🏾' => 'dłoń z palcem wskazującym w prawo: karnacja średnio ciemna',
    '👉🏿' => 'dłoń z palcem wskazującym w prawo: karnacja ciemna',
    '👆🏻' => 'dłoń z palcem wskazującym w górę: karnacja jasna',
    '👆🏼' => 'dłoń z palcem wskazującym w górę: karnacja średnio jasna',
    '👆🏽' => 'dłoń z palcem wskazującym w górę: karnacja średnia',
    '👆🏾' => 'dłoń z palcem wskazującym w górę: karnacja średnio ciemna',
    '👆🏿' => 'dłoń z palcem wskazującym w górę: karnacja ciemna',
    '🖕🏻' => 'środkowy palec: karnacja jasna',
    '🖕🏼' => 'środkowy palec: karnacja średnio jasna',
    '🖕🏽' => 'środkowy palec: karnacja średnia',
    '🖕🏾' => 'środkowy palec: karnacja średnio ciemna',
    '🖕🏿' => 'środkowy palec: karnacja ciemna',
    '👇🏻' => 'dłoń z palcem wskazującym w dół: karnacja jasna',
    '👇🏼' => 'dłoń z palcem wskazującym w dół: karnacja średnio jasna',
    '👇🏽' => 'dłoń z palcem wskazującym w dół: karnacja średnia',
    '👇🏾' => 'dłoń z palcem wskazującym w dół: karnacja średnio ciemna',
    '👇🏿' => 'dłoń z palcem wskazującym w dół: karnacja ciemna',
    '☝🏻' => 'palec wskazujący w górę: karnacja jasna',
    '☝🏼' => 'palec wskazujący w górę: karnacja średnio jasna',
    '☝🏽' => 'palec wskazujący w górę: karnacja średnia',
    '☝🏾' => 'palec wskazujący w górę: karnacja średnio ciemna',
    '☝🏿' => 'palec wskazujący w górę: karnacja ciemna',
    '🫵🏻' => 'palec wskazujący skierowany na patrzącego: karnacja jasna',
    '🫵🏼' => 'palec wskazujący skierowany na patrzącego: karnacja średnio jasna',
    '🫵🏽' => 'palec wskazujący skierowany na patrzącego: karnacja średnia',
    '🫵🏾' => 'palec wskazujący skierowany na patrzącego: karnacja średnio ciemna',
    '🫵🏿' => 'palec wskazujący skierowany na patrzącego: karnacja ciemna',
    '👍🏻' => 'kciuk w górę: karnacja jasna',
    '👍🏼' => 'kciuk w górę: karnacja średnio jasna',
    '👍🏽' => 'kciuk w górę: karnacja średnia',
    '👍🏾' => 'kciuk w górę: karnacja średnio ciemna',
    '👍🏿' => 'kciuk w górę: karnacja ciemna',
    '👎🏻' => 'kciuk w dół: karnacja jasna',
    '👎🏼' => 'kciuk w dół: karnacja średnio jasna',
    '👎🏽' => 'kciuk w dół: karnacja średnia',
    '👎🏾' => 'kciuk w dół: karnacja średnio ciemna',
    '👎🏿' => 'kciuk w dół: karnacja ciemna',
    '✊🏻' => 'wzniesiona pięść: karnacja jasna',
    '✊🏼' => 'wzniesiona pięść: karnacja średnio jasna',
    '✊🏽' => 'wzniesiona pięść: karnacja średnia',
    '✊🏾' => 'wzniesiona pięść: karnacja średnio ciemna',
    '✊🏿' => 'wzniesiona pięść: karnacja ciemna',
    '👊🏻' => 'pięść od przodu: karnacja jasna',
    '👊🏼' => 'pięść od przodu: karnacja średnio jasna',
    '👊🏽' => 'pięść od przodu: karnacja średnia',
    '👊🏾' => 'pięść od przodu: karnacja średnio ciemna',
    '👊🏿' => 'pięść od przodu: karnacja ciemna',
    '🤛🏻' => 'pięść skierowana w lewo: karnacja jasna',
    '🤛🏼' => 'pięść skierowana w lewo: karnacja średnio jasna',
    '🤛🏽' => 'pięść skierowana w lewo: karnacja średnia',
    '🤛🏾' => 'pięść skierowana w lewo: karnacja średnio ciemna',
    '🤛🏿' => 'pięść skierowana w lewo: karnacja ciemna',
    '🤜🏻' => 'pięść skierowana w prawo: karnacja jasna',
    '🤜🏼' => 'pięść skierowana w prawo: karnacja średnio jasna',
    '🤜🏽' => 'pięść skierowana w prawo: karnacja średnia',
    '🤜🏾' => 'pięść skierowana w prawo: karnacja średnio ciemna',
    '🤜🏿' => 'pięść skierowana w prawo: karnacja ciemna',
    '👏🏻' => 'klaskanie: karnacja jasna',
    '👏🏼' => 'klaskanie: karnacja średnio jasna',
    '👏🏽' => 'klaskanie: karnacja średnia',
    '👏🏾' => 'klaskanie: karnacja średnio ciemna',
    '👏🏿' => 'klaskanie: karnacja ciemna',
    '🙌🏻' => 'wzniesione ręce: karnacja jasna',
    '🙌🏼' => 'wzniesione ręce: karnacja średnio jasna',
    '🙌🏽' => 'wzniesione ręce: karnacja średnia',
    '🙌🏾' => 'wzniesione ręce: karnacja średnio ciemna',
    '🙌🏿' => 'wzniesione ręce: karnacja ciemna',
    '🫶🏻' => 'dłonie tworzące serce: karnacja jasna',
    '🫶🏼' => 'dłonie tworzące serce: karnacja średnio jasna',
    '🫶🏽' => 'dłonie tworzące serce: karnacja średnia',
    '🫶🏾' => 'dłonie tworzące serce: karnacja średnio ciemna',
    '🫶🏿' => 'dłonie tworzące serce: karnacja ciemna',
    '👐🏻' => 'otwarte dłonie: karnacja jasna',
    '👐🏼' => 'otwarte dłonie: karnacja średnio jasna',
    '👐🏽' => 'otwarte dłonie: karnacja średnia',
    '👐🏾' => 'otwarte dłonie: karnacja średnio ciemna',
    '👐🏿' => 'otwarte dłonie: karnacja ciemna',
    '🤲🏻' => 'dłonie do góry razem: karnacja jasna',
    '🤲🏼' => 'dłonie do góry razem: karnacja średnio jasna',
    '🤲🏽' => 'dłonie do góry razem: karnacja średnia',
    '🤲🏾' => 'dłonie do góry razem: karnacja średnio ciemna',
    '🤲🏿' => 'dłonie do góry razem: karnacja ciemna',
    '🤝🏻' => 'uścisk dłoni: karnacja jasna',
    '🤝🏼' => 'uścisk dłoni: karnacja średnio jasna',
    '🤝🏽' => 'uścisk dłoni: karnacja średnia',
    '🤝🏾' => 'uścisk dłoni: karnacja średnio ciemna',
    '🤝🏿' => 'uścisk dłoni: karnacja ciemna',
    '🙏🏻' => 'złożone ręce: karnacja jasna',
    '🙏🏼' => 'złożone ręce: karnacja średnio jasna',
    '🙏🏽' => 'złożone ręce: karnacja średnia',
    '🙏🏾' => 'złożone ręce: karnacja średnio ciemna',
    '🙏🏿' => 'złożone ręce: karnacja ciemna',
    '✍🏻' => 'pisząca dłoń: karnacja jasna',
    '✍🏼' => 'pisząca dłoń: karnacja średnio jasna',
    '✍🏽' => 'pisząca dłoń: karnacja średnia',
    '✍🏾' => 'pisząca dłoń: karnacja średnio ciemna',
    '✍🏿' => 'pisząca dłoń: karnacja ciemna',
    '💅🏻' => 'lakier do paznokci: karnacja jasna',
    '💅🏼' => 'lakier do paznokci: karnacja średnio jasna',
    '💅🏽' => 'lakier do paznokci: karnacja średnia',
    '💅🏾' => 'lakier do paznokci: karnacja średnio ciemna',
    '💅🏿' => 'lakier do paznokci: karnacja ciemna',
    '🤳🏻' => 'selfie: karnacja jasna',
    '🤳🏼' => 'selfie: karnacja średnio jasna',
    '🤳🏽' => 'selfie: karnacja średnia',
    '🤳🏾' => 'selfie: karnacja średnio ciemna',
    '🤳🏿' => 'selfie: karnacja ciemna',
    '💪🏻' => 'napięty biceps: karnacja jasna',
    '💪🏼' => 'napięty biceps: karnacja średnio jasna',
    '💪🏽' => 'napięty biceps: karnacja średnia',
    '💪🏾' => 'napięty biceps: karnacja średnio ciemna',
    '💪🏿' => 'napięty biceps: karnacja ciemna',
    '🦵🏻' => 'noga: karnacja jasna',
    '🦵🏼' => 'noga: karnacja średnio jasna',
    '🦵🏽' => 'noga: karnacja średnia',
    '🦵🏾' => 'noga: karnacja średnio ciemna',
    '🦵🏿' => 'noga: karnacja ciemna',
    '🦶🏻' => 'stopa: karnacja jasna',
    '🦶🏼' => 'stopa: karnacja średnio jasna',
    '🦶🏽' => 'stopa: karnacja średnia',
    '🦶🏾' => 'stopa: karnacja średnio ciemna',
    '🦶🏿' => 'stopa: karnacja ciemna',
    '👂🏻' => 'ucho: karnacja jasna',
    '👂🏼' => 'ucho: karnacja średnio jasna',
    '👂🏽' => 'ucho: karnacja średnia',
    '👂🏾' => 'ucho: karnacja średnio ciemna',
    '👂🏿' => 'ucho: karnacja ciemna',
    '🦻🏻' => 'ucho z aparatem słuchowym: karnacja jasna',
    '🦻🏼' => 'ucho z aparatem słuchowym: karnacja średnio jasna',
    '🦻🏽' => 'ucho z aparatem słuchowym: karnacja średnia',
    '🦻🏾' => 'ucho z aparatem słuchowym: karnacja średnio ciemna',
    '🦻🏿' => 'ucho z aparatem słuchowym: karnacja ciemna',
    '👃🏻' => 'nos: karnacja jasna',
    '👃🏼' => 'nos: karnacja średnio jasna',
    '👃🏽' => 'nos: karnacja średnia',
    '👃🏾' => 'nos: karnacja średnio ciemna',
    '👃🏿' => 'nos: karnacja ciemna',
    '👶🏻' => 'niemowlę: karnacja jasna',
    '👶🏼' => 'niemowlę: karnacja średnio jasna',
    '👶🏽' => 'niemowlę: karnacja średnia',
    '👶🏾' => 'niemowlę: karnacja średnio ciemna',
    '👶🏿' => 'niemowlę: karnacja ciemna',
    '🧒🏻' => 'dziecko: karnacja jasna',
    '🧒🏼' => 'dziecko: karnacja średnio jasna',
    '🧒🏽' => 'dziecko: karnacja średnia',
    '🧒🏾' => 'dziecko: karnacja średnio ciemna',
    '🧒🏿' => 'dziecko: karnacja ciemna',
    '👦🏻' => 'chłopiec: karnacja jasna',
    '👦🏼' => 'chłopiec: karnacja średnio jasna',
    '👦🏽' => 'chłopiec: karnacja średnia',
    '👦🏾' => 'chłopiec: karnacja średnio ciemna',
    '👦🏿' => 'chłopiec: karnacja ciemna',
    '👧🏻' => 'dziewczynka: karnacja jasna',
    '👧🏼' => 'dziewczynka: karnacja średnio jasna',
    '👧🏽' => 'dziewczynka: karnacja średnia',
    '👧🏾' => 'dziewczynka: karnacja średnio ciemna',
    '👧🏿' => 'dziewczynka: karnacja ciemna',
    '🧑🏻' => 'dorosły: karnacja jasna',
    '🧑🏼' => 'dorosły: karnacja średnio jasna',
    '🧑🏽' => 'dorosły: karnacja średnia',
    '🧑🏾' => 'dorosły: karnacja średnio ciemna',
    '🧑🏿' => 'dorosły: karnacja ciemna',
    '👱🏻' => 'osoba z włosami blond: karnacja jasna',
    '👱🏼' => 'osoba z włosami blond: karnacja średnio jasna',
    '👱🏽' => 'osoba z włosami blond: karnacja średnia',
    '👱🏾' => 'osoba z włosami blond: karnacja średnio ciemna',
    '👱🏿' => 'osoba z włosami blond: karnacja ciemna',
    '👨🏻' => 'mężczyzna: karnacja jasna',
    '👨🏼' => 'mężczyzna: karnacja średnio jasna',
    '👨🏽' => 'mężczyzna: karnacja średnia',
    '👨🏾' => 'mężczyzna: karnacja średnio ciemna',
    '👨🏿' => 'mężczyzna: karnacja ciemna',
    '🧔🏻' => 'osoba z brodą: karnacja jasna',
    '🧔🏼' => 'osoba z brodą: karnacja średnio jasna',
    '🧔🏽' => 'osoba z brodą: karnacja średnia',
    '🧔🏾' => 'osoba z brodą: karnacja średnio ciemna',
    '🧔🏿' => 'osoba z brodą: karnacja ciemna',
    '👩🏻' => 'kobieta: karnacja jasna',
    '👩🏼' => 'kobieta: karnacja średnio jasna',
    '👩🏽' => 'kobieta: karnacja średnia',
    '👩🏾' => 'kobieta: karnacja średnio ciemna',
    '👩🏿' => 'kobieta: karnacja ciemna',
    '🧓🏻' => 'starsza osoba: karnacja jasna',
    '🧓🏼' => 'starsza osoba: karnacja średnio jasna',
    '🧓🏽' => 'starsza osoba: karnacja średnia',
    '🧓🏾' => 'starsza osoba: karnacja średnio ciemna',
    '🧓🏿' => 'starsza osoba: karnacja ciemna',
    '👴🏻' => 'starszy mężczyzna: karnacja jasna',
    '👴🏼' => 'starszy mężczyzna: karnacja średnio jasna',
    '👴🏽' => 'starszy mężczyzna: karnacja średnia',
    '👴🏾' => 'starszy mężczyzna: karnacja średnio ciemna',
    '👴🏿' => 'starszy mężczyzna: karnacja ciemna',
    '👵🏻' => 'starsza kobieta: karnacja jasna',
    '👵🏼' => 'starsza kobieta: karnacja średnio jasna',
    '👵🏽' => 'starsza kobieta: karnacja średnia',
    '👵🏾' => 'starsza kobieta: karnacja średnio ciemna',
    '👵🏿' => 'starsza kobieta: karnacja ciemna',
    '🙍🏻' => 'zachmurzona osoba: karnacja jasna',
    '🙍🏼' => 'zachmurzona osoba: karnacja średnio jasna',
    '🙍🏽' => 'zachmurzona osoba: karnacja średnia',
    '🙍🏾' => 'zachmurzona osoba: karnacja średnio ciemna',
    '🙍🏿' => 'zachmurzona osoba: karnacja ciemna',
    '🙎🏻' => 'nadąsana osoba: karnacja jasna',
    '🙎🏼' => 'nadąsana osoba: karnacja średnio jasna',
    '🙎🏽' => 'nadąsana osoba: karnacja średnia',
    '🙎🏾' => 'nadąsana osoba: karnacja średnio ciemna',
    '🙎🏿' => 'nadąsana osoba: karnacja ciemna',
    '🙅🏻' => 'osoba pokazująca gest NIE: karnacja jasna',
    '🙅🏼' => 'osoba pokazująca gest NIE: karnacja średnio jasna',
    '🙅🏽' => 'osoba pokazująca gest NIE: karnacja średnia',
    '🙅🏾' => 'osoba pokazująca gest NIE: karnacja średnio ciemna',
    '🙅🏿' => 'osoba pokazująca gest NIE: karnacja ciemna',
    '🙆🏻' => 'osoba pokazująca gest OK: karnacja jasna',
    '🙆🏼' => 'osoba pokazująca gest OK: karnacja średnio jasna',
    '🙆🏽' => 'osoba pokazująca gest OK: karnacja średnia',
    '🙆🏾' => 'osoba pokazująca gest OK: karnacja średnio ciemna',
    '🙆🏿' => 'osoba pokazująca gest OK: karnacja ciemna',
    '💁🏻' => 'osoba z wystawioną dłonią: karnacja jasna',
    '💁🏼' => 'osoba z wystawioną dłonią: karnacja średnio jasna',
    '💁🏽' => 'osoba z wystawioną dłonią: karnacja średnia',
    '💁🏾' => 'osoba z wystawioną dłonią: karnacja średnio ciemna',
    '💁🏿' => 'osoba z wystawioną dłonią: karnacja ciemna',
    '🙋🏻' => 'osoba podnosząca rękę: karnacja jasna',
    '🙋🏼' => 'osoba podnosząca rękę: karnacja średnio jasna',
    '🙋🏽' => 'osoba podnosząca rękę: karnacja średnia',
    '🙋🏾' => 'osoba podnosząca rękę: karnacja średnio ciemna',
    '🙋🏿' => 'osoba podnosząca rękę: karnacja ciemna',
    '🧏🏻' => 'osoba głucha: karnacja jasna',
    '🧏🏼' => 'osoba głucha: karnacja średnio jasna',
    '🧏🏽' => 'osoba głucha: karnacja średnia',
    '🧏🏾' => 'osoba głucha: karnacja średnio ciemna',
    '🧏🏿' => 'osoba głucha: karnacja ciemna',
    '🙇🏻' => 'osoba w ukłonie: karnacja jasna',
    '🙇🏼' => 'osoba w ukłonie: karnacja średnio jasna',
    '🙇🏽' => 'osoba w ukłonie: karnacja średnia',
    '🙇🏾' => 'osoba w ukłonie: karnacja średnio ciemna',
    '🙇🏿' => 'osoba w ukłonie: karnacja ciemna',
    '🤦🏻' => 'osoba trzymająca się za czoło: karnacja jasna',
    '🤦🏼' => 'osoba trzymająca się za czoło: karnacja średnio jasna',
    '🤦🏽' => 'osoba trzymająca się za czoło: karnacja średnia',
    '🤦🏾' => 'osoba trzymająca się za czoło: karnacja średnio ciemna',
    '🤦🏿' => 'osoba trzymająca się za czoło: karnacja ciemna',
    '🤷🏻' => 'osoba wzruszająca ramionami: karnacja jasna',
    '🤷🏼' => 'osoba wzruszająca ramionami: karnacja średnio jasna',
    '🤷🏽' => 'osoba wzruszająca ramionami: karnacja średnia',
    '🤷🏾' => 'osoba wzruszająca ramionami: karnacja średnio ciemna',
    '🤷🏿' => 'osoba wzruszająca ramionami: karnacja ciemna',
    '👮🏻' => 'policjant: karnacja jasna',
    '👮🏼' => 'policjant: karnacja średnio jasna',
    '👮🏽' => 'policjant: karnacja średnia',
    '👮🏾' => 'policjant: karnacja średnio ciemna',
    '👮🏿' => 'policjant: karnacja ciemna',
    '🕵🏻' => 'detektyw: karnacja jasna',
    '🕵🏼' => 'detektyw: karnacja średnio jasna',
    '🕵🏽' => 'detektyw: karnacja średnia',
    '🕵🏾' => 'detektyw: karnacja średnio ciemna',
    '🕵🏿' => 'detektyw: karnacja ciemna',
    '💂🏻' => 'gwardzista: karnacja jasna',
    '💂🏼' => 'gwardzista: karnacja średnio jasna',
    '💂🏽' => 'gwardzista: karnacja średnia',
    '💂🏾' => 'gwardzista: karnacja średnio ciemna',
    '💂🏿' => 'gwardzista: karnacja ciemna',
    '🥷🏻' => 'ninja: karnacja jasna',
    '🥷🏼' => 'ninja: karnacja średnio jasna',
    '🥷🏽' => 'ninja: karnacja średnia',
    '🥷🏾' => 'ninja: karnacja średnio ciemna',
    '🥷🏿' => 'ninja: karnacja ciemna',
    '👷🏻' => 'budowlaniec: karnacja jasna',
    '👷🏼' => 'budowlaniec: karnacja średnio jasna',
    '👷🏽' => 'budowlaniec: karnacja średnia',
    '👷🏾' => 'budowlaniec: karnacja średnio ciemna',
    '👷🏿' => 'budowlaniec: karnacja ciemna',
    '🫅🏻' => 'osoba w koronie: karnacja jasna',
    '🫅🏼' => 'osoba w koronie: karnacja średnio jasna',
    '🫅🏽' => 'osoba w koronie: karnacja średnia',
    '🫅🏾' => 'osoba w koronie: karnacja średnio ciemna',
    '🫅🏿' => 'osoba w koronie: karnacja ciemna',
    '🤴🏻' => 'książę: karnacja jasna',
    '🤴🏼' => 'książę: karnacja średnio jasna',
    '🤴🏽' => 'książę: karnacja średnia',
    '🤴🏾' => 'książę: karnacja średnio ciemna',
    '🤴🏿' => 'książę: karnacja ciemna',
    '👸🏻' => 'księżniczka: karnacja jasna',
    '👸🏼' => 'księżniczka: karnacja średnio jasna',
    '👸🏽' => 'księżniczka: karnacja średnia',
    '👸🏾' => 'księżniczka: karnacja średnio ciemna',
    '👸🏿' => 'księżniczka: karnacja ciemna',
    '👳🏻' => 'osoba w turbanie: karnacja jasna',
    '👳🏼' => 'osoba w turbanie: karnacja średnio jasna',
    '👳🏽' => 'osoba w turbanie: karnacja średnia',
    '👳🏾' => 'osoba w turbanie: karnacja średnio ciemna',
    '👳🏿' => 'osoba w turbanie: karnacja ciemna',
    '👲🏻' => 'osoba w chińskiej czapce: karnacja jasna',
    '👲🏼' => 'osoba w chińskiej czapce: karnacja średnio jasna',
    '👲🏽' => 'osoba w chińskiej czapce: karnacja średnia',
    '👲🏾' => 'osoba w chińskiej czapce: karnacja średnio ciemna',
    '👲🏿' => 'osoba w chińskiej czapce: karnacja ciemna',
    '🧕🏻' => 'kobieta w chuście: karnacja jasna',
    '🧕🏼' => 'kobieta w chuście: karnacja średnio jasna',
    '🧕🏽' => 'kobieta w chuście: karnacja średnia',
    '🧕🏾' => 'kobieta w chuście: karnacja średnio ciemna',
    '🧕🏿' => 'kobieta w chuście: karnacja ciemna',
    '🤵🏻' => 'osoba w smokingu: karnacja jasna',
    '🤵🏼' => 'osoba w smokingu: karnacja średnio jasna',
    '🤵🏽' => 'osoba w smokingu: karnacja średnia',
    '🤵🏾' => 'osoba w smokingu: karnacja średnio ciemna',
    '🤵🏿' => 'osoba w smokingu: karnacja ciemna',
    '👰🏻' => 'osoba w welonie: karnacja jasna',
    '👰🏼' => 'osoba w welonie: karnacja średnio jasna',
    '👰🏽' => 'osoba w welonie: karnacja średnia',
    '👰🏾' => 'osoba w welonie: karnacja średnio ciemna',
    '👰🏿' => 'osoba w welonie: karnacja ciemna',
    '🤰🏻' => 'kobieta w ciąży: karnacja jasna',
    '🤰🏼' => 'kobieta w ciąży: karnacja średnio jasna',
    '🤰🏽' => 'kobieta w ciąży: karnacja średnia',
    '🤰🏾' => 'kobieta w ciąży: karnacja średnio ciemna',
    '🤰🏿' => 'kobieta w ciąży: karnacja ciemna',
    '🫃🏻' => 'mężczyzna w ciąży: karnacja jasna',
    '🫃🏼' => 'mężczyzna w ciąży: karnacja średnio jasna',
    '🫃🏽' => 'mężczyzna w ciąży: karnacja średnia',
    '🫃🏾' => 'mężczyzna w ciąży: karnacja średnio ciemna',
    '🫃🏿' => 'mężczyzna w ciąży: karnacja ciemna',
    '🫄🏻' => 'osoba w ciąży: karnacja jasna',
    '🫄🏼' => 'osoba w ciąży: karnacja średnio jasna',
    '🫄🏽' => 'osoba w ciąży: karnacja średnia',
    '🫄🏾' => 'osoba w ciąży: karnacja średnio ciemna',
    '🫄🏿' => 'osoba w ciąży: karnacja ciemna',
    '🤱🏻' => 'karmienie piersią: karnacja jasna',
    '🤱🏼' => 'karmienie piersią: karnacja średnio jasna',
    '🤱🏽' => 'karmienie piersią: karnacja średnia',
    '🤱🏾' => 'karmienie piersią: karnacja średnio ciemna',
    '🤱🏿' => 'karmienie piersią: karnacja ciemna',
    '👼🏻' => 'aniołek: karnacja jasna',
    '👼🏼' => 'aniołek: karnacja średnio jasna',
    '👼🏽' => 'aniołek: karnacja średnia',
    '👼🏾' => 'aniołek: karnacja średnio ciemna',
    '👼🏿' => 'aniołek: karnacja ciemna',
    '🎅🏻' => 'Święty Mikołaj: karnacja jasna',
    '🎅🏼' => 'Święty Mikołaj: karnacja średnio jasna',
    '🎅🏽' => 'Święty Mikołaj: karnacja średnia',
    '🎅🏾' => 'Święty Mikołaj: karnacja średnio ciemna',
    '🎅🏿' => 'Święty Mikołaj: karnacja ciemna',
    '🤶🏻' => 'żona św. Mikołaja: karnacja jasna',
    '🤶🏼' => 'żona św. Mikołaja: karnacja średnio jasna',
    '🤶🏽' => 'żona św. Mikołaja: karnacja średnia',
    '🤶🏾' => 'żona św. Mikołaja: karnacja średnio ciemna',
    '🤶🏿' => 'żona św. Mikołaja: karnacja ciemna',
    '🦸🏻' => 'superbohater: karnacja jasna',
    '🦸🏼' => 'superbohater: karnacja średnio jasna',
    '🦸🏽' => 'superbohater: karnacja średnia',
    '🦸🏾' => 'superbohater: karnacja średnio ciemna',
    '🦸🏿' => 'superbohater: karnacja ciemna',
    '🦹🏻' => 'superłotr: karnacja jasna',
    '🦹🏼' => 'superłotr: karnacja średnio jasna',
    '🦹🏽' => 'superłotr: karnacja średnia',
    '🦹🏾' => 'superłotr: karnacja średnio ciemna',
    '🦹🏿' => 'superłotr: karnacja ciemna',
    '🧙🏻' => 'mag: karnacja jasna',
    '🧙🏼' => 'mag: karnacja średnio jasna',
    '🧙🏽' => 'mag: karnacja średnia',
    '🧙🏾' => 'mag: karnacja średnio ciemna',
    '🧙🏿' => 'mag: karnacja ciemna',
    '🧚🏻' => 'wróżka: karnacja jasna',
    '🧚🏼' => 'wróżka: karnacja średnio jasna',
    '🧚🏽' => 'wróżka: karnacja średnia',
    '🧚🏾' => 'wróżka: karnacja średnio ciemna',
    '🧚🏿' => 'wróżka: karnacja ciemna',
    '🧛🏻' => 'wampir: karnacja jasna',
    '🧛🏼' => 'wampir: karnacja średnio jasna',
    '🧛🏽' => 'wampir: karnacja średnia',
    '🧛🏾' => 'wampir: karnacja średnio ciemna',
    '🧛🏿' => 'wampir: karnacja ciemna',
    '🧜🏻' => 'syrena: karnacja jasna',
    '🧜🏼' => 'syrena: karnacja średnio jasna',
    '🧜🏽' => 'syrena: karnacja średnia',
    '🧜🏾' => 'syrena: karnacja średnio ciemna',
    '🧜🏿' => 'syrena: karnacja ciemna',
    '🧝🏻' => 'elf: karnacja jasna',
    '🧝🏼' => 'elf: karnacja średnio jasna',
    '🧝🏽' => 'elf: karnacja średnia',
    '🧝🏾' => 'elf: karnacja średnio ciemna',
    '🧝🏿' => 'elf: karnacja ciemna',
    '💆🏻' => 'osoba podczas masażu: karnacja jasna',
    '💆🏼' => 'osoba podczas masażu: karnacja średnio jasna',
    '💆🏽' => 'osoba podczas masażu: karnacja średnia',
    '💆🏾' => 'osoba podczas masażu: karnacja średnio ciemna',
    '💆🏿' => 'osoba podczas masażu: karnacja ciemna',
    '💇🏻' => 'osoba podczas strzyżenia: karnacja jasna',
    '💇🏼' => 'osoba podczas strzyżenia: karnacja średnio jasna',
    '💇🏽' => 'osoba podczas strzyżenia: karnacja średnia',
    '💇🏾' => 'osoba podczas strzyżenia: karnacja średnio ciemna',
    '💇🏿' => 'osoba podczas strzyżenia: karnacja ciemna',
    '🚶🏻' => 'idąca osoba: karnacja jasna',
    '🚶🏼' => 'idąca osoba: karnacja średnio jasna',
    '🚶🏽' => 'idąca osoba: karnacja średnia',
    '🚶🏾' => 'idąca osoba: karnacja średnio ciemna',
    '🚶🏿' => 'idąca osoba: karnacja ciemna',
    '🧍🏻' => 'stojąca osoba: karnacja jasna',
    '🧍🏼' => 'stojąca osoba: karnacja średnio jasna',
    '🧍🏽' => 'stojąca osoba: karnacja średnia',
    '🧍🏾' => 'stojąca osoba: karnacja średnio ciemna',
    '🧍🏿' => 'stojąca osoba: karnacja ciemna',
    '🧎🏻' => 'klęcząca osoba: karnacja jasna',
    '🧎🏼' => 'klęcząca osoba: karnacja średnio jasna',
    '🧎🏽' => 'klęcząca osoba: karnacja średnia',
    '🧎🏾' => 'klęcząca osoba: karnacja średnio ciemna',
    '🧎🏿' => 'klęcząca osoba: karnacja ciemna',
    '🏃🏻' => 'biegnąca osoba: karnacja jasna',
    '🏃🏼' => 'biegnąca osoba: karnacja średnio jasna',
    '🏃🏽' => 'biegnąca osoba: karnacja średnia',
    '🏃🏾' => 'biegnąca osoba: karnacja średnio ciemna',
    '🏃🏿' => 'biegnąca osoba: karnacja ciemna',
    '💃🏻' => 'tańcząca kobieta: karnacja jasna',
    '💃🏼' => 'tańcząca kobieta: karnacja średnio jasna',
    '💃🏽' => 'tańcząca kobieta: karnacja średnia',
    '💃🏾' => 'tańcząca kobieta: karnacja średnio ciemna',
    '💃🏿' => 'tańcząca kobieta: karnacja ciemna',
    '🕺🏻' => 'tańczący mężczyzna: karnacja jasna',
    '🕺🏼' => 'tańczący mężczyzna: karnacja średnio jasna',
    '🕺🏽' => 'tańczący mężczyzna: karnacja średnia',
    '🕺🏾' => 'tańczący mężczyzna: karnacja średnio ciemna',
    '🕺🏿' => 'tańczący mężczyzna: karnacja ciemna',
    '🕴🏻' => 'lewitujący mężczyzna w garniturze: karnacja jasna',
    '🕴🏼' => 'lewitujący mężczyzna w garniturze: karnacja średnio jasna',
    '🕴🏽' => 'lewitujący mężczyzna w garniturze: karnacja średnia',
    '🕴🏾' => 'lewitujący mężczyzna w garniturze: karnacja średnio ciemna',
    '🕴🏿' => 'lewitujący mężczyzna w garniturze: karnacja ciemna',
    '👯🏻' => 'osoby z uszami królika na przyjęciu: karnacja jasna',
    '👯🏼' => 'osoby z uszami królika na przyjęciu: karnacja średnio jasna',
    '👯🏽' => 'osoby z uszami królika na przyjęciu: karnacja średnia',
    '👯🏾' => 'osoby z uszami królika na przyjęciu: karnacja średnio ciemna',
    '👯🏿' => 'osoby z uszami królika na przyjęciu: karnacja ciemna',
    '🧖🏻' => 'osoba w zaparowanym pomieszczeniu: karnacja jasna',
    '🧖🏼' => 'osoba w zaparowanym pomieszczeniu: karnacja średnio jasna',
    '🧖🏽' => 'osoba w zaparowanym pomieszczeniu: karnacja średnia',
    '🧖🏾' => 'osoba w zaparowanym pomieszczeniu: karnacja średnio ciemna',
    '🧖🏿' => 'osoba w zaparowanym pomieszczeniu: karnacja ciemna',
    '🧗🏻' => 'osoba wspinająca się: karnacja jasna',
    '🧗🏼' => 'osoba wspinająca się: karnacja średnio jasna',
    '🧗🏽' => 'osoba wspinająca się: karnacja średnia',
    '🧗🏾' => 'osoba wspinająca się: karnacja średnio ciemna',
    '🧗🏿' => 'osoba wspinająca się: karnacja ciemna',
    '🏇🏻' => 'wyścigi konne: karnacja jasna',
    '🏇🏼' => 'wyścigi konne: karnacja średnio jasna',
    '🏇🏽' => 'wyścigi konne: karnacja średnia',
    '🏇🏾' => 'wyścigi konne: karnacja średnio ciemna',
    '🏇🏿' => 'wyścigi konne: karnacja ciemna',
    '🏂🏻' => 'snowboardzista: karnacja jasna',
    '🏂🏼' => 'snowboardzista: karnacja średnio jasna',
    '🏂🏽' => 'snowboardzista: karnacja średnia',
    '🏂🏾' => 'snowboardzista: karnacja średnio ciemna',
    '🏂🏿' => 'snowboardzista: karnacja ciemna',
    '🏌🏻' => 'osoba grająca w golfa: karnacja jasna',
    '🏌🏼' => 'osoba grająca w golfa: karnacja średnio jasna',
    '🏌🏽' => 'osoba grająca w golfa: karnacja średnia',
    '🏌🏾' => 'osoba grająca w golfa: karnacja średnio ciemna',
    '🏌🏿' => 'osoba grająca w golfa: karnacja ciemna',
    '🏄🏻' => 'surfująca osoba: karnacja jasna',
    '🏄🏼' => 'surfująca osoba: karnacja średnio jasna',
    '🏄🏽' => 'surfująca osoba: karnacja średnia',
    '🏄🏾' => 'surfująca osoba: karnacja średnio ciemna',
    '🏄🏿' => 'surfująca osoba: karnacja ciemna',
    '🚣🏻' => 'osoba wiosłująca w łodzi: karnacja jasna',
    '🚣🏼' => 'osoba wiosłująca w łodzi: karnacja średnio jasna',
    '🚣🏽' => 'osoba wiosłująca w łodzi: karnacja średnia',
    '🚣🏾' => 'osoba wiosłująca w łodzi: karnacja średnio ciemna',
    '🚣🏿' => 'osoba wiosłująca w łodzi: karnacja ciemna',
    '🏊🏻' => 'pływająca osoba: karnacja jasna',
    '🏊🏼' => 'pływająca osoba: karnacja średnio jasna',
    '🏊🏽' => 'pływająca osoba: karnacja średnia',
    '🏊🏾' => 'pływająca osoba: karnacja średnio ciemna',
    '🏊🏿' => 'pływająca osoba: karnacja ciemna',
    '⛹🏻' => 'osoba kozłująca piłkę: karnacja jasna',
    '⛹🏼' => 'osoba kozłująca piłkę: karnacja średnio jasna',
    '⛹🏽' => 'osoba kozłująca piłkę: karnacja średnia',
    '⛹🏾' => 'osoba kozłująca piłkę: karnacja średnio ciemna',
    '⛹🏿' => 'osoba kozłująca piłkę: karnacja ciemna',
    '🏋🏻' => 'osoba podnosząca ciężary: karnacja jasna',
    '🏋🏼' => 'osoba podnosząca ciężary: karnacja średnio jasna',
    '🏋🏽' => 'osoba podnosząca ciężary: karnacja średnia',
    '🏋🏾' => 'osoba podnosząca ciężary: karnacja średnio ciemna',
    '🏋🏿' => 'osoba podnosząca ciężary: karnacja ciemna',
    '🚴🏻' => 'osoba na rowerze: karnacja jasna',
    '🚴🏼' => 'osoba na rowerze: karnacja średnio jasna',
    '🚴🏽' => 'osoba na rowerze: karnacja średnia',
    '🚴🏾' => 'osoba na rowerze: karnacja średnio ciemna',
    '🚴🏿' => 'osoba na rowerze: karnacja ciemna',
    '🚵🏻' => 'osoba na rowerze górskim: karnacja jasna',
    '🚵🏼' => 'osoba na rowerze górskim: karnacja średnio jasna',
    '🚵🏽' => 'osoba na rowerze górskim: karnacja średnia',
    '🚵🏾' => 'osoba na rowerze górskim: karnacja średnio ciemna',
    '🚵🏿' => 'osoba na rowerze górskim: karnacja ciemna',
    '🤸🏻' => 'osoba robiąca gwiazdę: karnacja jasna',
    '🤸🏼' => 'osoba robiąca gwiazdę: karnacja średnio jasna',
    '🤸🏽' => 'osoba robiąca gwiazdę: karnacja średnia',
    '🤸🏾' => 'osoba robiąca gwiazdę: karnacja średnio ciemna',
    '🤸🏿' => 'osoba robiąca gwiazdę: karnacja ciemna',
    '🤼🏻' => 'osoby uprawiające zapasy: karnacja jasna',
    '🤼🏼' => 'osoby uprawiające zapasy: karnacja średnio jasna',
    '🤼🏽' => 'osoby uprawiające zapasy: karnacja średnia',
    '🤼🏾' => 'osoby uprawiające zapasy: karnacja średnio ciemna',
    '🤼🏿' => 'osoby uprawiające zapasy: karnacja ciemna',
    '🤽🏻' => 'osoba grająca w piłkę wodną: karnacja jasna',
    '🤽🏼' => 'osoba grająca w piłkę wodną: karnacja średnio jasna',
    '🤽🏽' => 'osoba grająca w piłkę wodną: karnacja średnia',
    '🤽🏾' => 'osoba grająca w piłkę wodną: karnacja średnio ciemna',
    '🤽🏿' => 'osoba grająca w piłkę wodną: karnacja ciemna',
    '🤾🏻' => 'osoba grająca w piłkę ręczną: karnacja jasna',
    '🤾🏼' => 'osoba grająca w piłkę ręczną: karnacja średnio jasna',
    '🤾🏽' => 'osoba grająca w piłkę ręczną: karnacja średnia',
    '🤾🏾' => 'osoba grająca w piłkę ręczną: karnacja średnio ciemna',
    '🤾🏿' => 'osoba grająca w piłkę ręczną: karnacja ciemna',
    '🤹🏻' => 'żonglująca osoba: karnacja jasna',
    '🤹🏼' => 'żonglująca osoba: karnacja średnio jasna',
    '🤹🏽' => 'żonglująca osoba: karnacja średnia',
    '🤹🏾' => 'żonglująca osoba: karnacja średnio ciemna',
    '🤹🏿' => 'żonglująca osoba: karnacja ciemna',
    '🧘🏻' => 'osoba w pozycji lotosu: karnacja jasna',
    '🧘🏼' => 'osoba w pozycji lotosu: karnacja średnio jasna',
    '🧘🏽' => 'osoba w pozycji lotosu: karnacja średnia',
    '🧘🏾' => 'osoba w pozycji lotosu: karnacja średnio ciemna',
    '🧘🏿' => 'osoba w pozycji lotosu: karnacja ciemna',
    '🛀🏻' => 'osoba biorąca kąpiel: karnacja jasna',
    '🛀🏼' => 'osoba biorąca kąpiel: karnacja średnio jasna',
    '🛀🏽' => 'osoba biorąca kąpiel: karnacja średnia',
    '🛀🏾' => 'osoba biorąca kąpiel: karnacja średnio ciemna',
    '🛀🏿' => 'osoba biorąca kąpiel: karnacja ciemna',
    '🛌🏻' => 'osoba w łóżku: karnacja jasna',
    '🛌🏼' => 'osoba w łóżku: karnacja średnio jasna',
    '🛌🏽' => 'osoba w łóżku: karnacja średnia',
    '🛌🏾' => 'osoba w łóżku: karnacja średnio ciemna',
    '🛌🏿' => 'osoba w łóżku: karnacja ciemna',
    '👭🏻' => 'kobiety trzymające się za ręce: karnacja jasna',
    '👭🏼' => 'kobiety trzymające się za ręce: karnacja średnio jasna',
    '👭🏽' => 'kobiety trzymające się za ręce: karnacja średnia',
    '👭🏾' => 'kobiety trzymające się za ręce: karnacja średnio ciemna',
    '👭🏿' => 'kobiety trzymające się za ręce: karnacja ciemna',
    '👫🏻' => 'mężczyzna i kobieta trzymający się za ręce: karnacja jasna',
    '👫🏼' => 'mężczyzna i kobieta trzymający się za ręce: karnacja średnio jasna',
    '👫🏽' => 'mężczyzna i kobieta trzymający się za ręce: karnacja średnia',
    '👫🏾' => 'mężczyzna i kobieta trzymający się za ręce: karnacja średnio ciemna',
    '👫🏿' => 'mężczyzna i kobieta trzymający się za ręce: karnacja ciemna',
    '👬🏻' => 'dwóch mężczyzn trzymających się za ręce: karnacja jasna',
    '👬🏼' => 'dwóch mężczyzn trzymających się za ręce: karnacja średnio jasna',
    '👬🏽' => 'dwóch mężczyzn trzymających się za ręce: karnacja średnia',
    '👬🏾' => 'dwóch mężczyzn trzymających się za ręce: karnacja średnio ciemna',
    '👬🏿' => 'dwóch mężczyzn trzymających się za ręce: karnacja ciemna',
    '💏🏻' => 'pocałunek: karnacja jasna',
    '💏🏼' => 'pocałunek: karnacja średnio jasna',
    '💏🏽' => 'pocałunek: karnacja średnia',
    '💏🏾' => 'pocałunek: karnacja średnio ciemna',
    '💏🏿' => 'pocałunek: karnacja ciemna',
    '💑🏻' => 'para z sercem: karnacja jasna',
    '💑🏼' => 'para z sercem: karnacja średnio jasna',
    '💑🏽' => 'para z sercem: karnacja średnia',
    '💑🏾' => 'para z sercem: karnacja średnio ciemna',
    '💑🏿' => 'para z sercem: karnacja ciemna',
    '🇦🇨' => 'flaga: Wyspa Wniebowstąpienia',
    '🇦🇩' => 'flaga: Andora',
    '🇦🇪' => 'flaga: Zjednoczone Emiraty Arabskie',
    '🇦🇫' => 'flaga: Afganistan',
    '🇦🇬' => 'flaga: Antigua i Barbuda',
    '🇦🇮' => 'flaga: Anguilla',
    '🇦🇱' => 'flaga: Albania',
    '🇦🇲' => 'flaga: Armenia',
    '🇦🇴' => 'flaga: Angola',
    '🇦🇶' => 'flaga: Antarktyda',
    '🇦🇷' => 'flaga: Argentyna',
    '🇦🇸' => 'flaga: Samoa Amerykańskie',
    '🇦🇹' => 'flaga: Austria',
    '🇦🇺' => 'flaga: Australia',
    '🇦🇼' => 'flaga: Aruba',
    '🇦🇽' => 'flaga: Wyspy Alandzkie',
    '🇦🇿' => 'flaga: Azerbejdżan',
    '🇧🇦' => 'flaga: Bośnia i Hercegowina',
    '🇧🇧' => 'flaga: Barbados',
    '🇧🇩' => 'flaga: Bangladesz',
    '🇧🇪' => 'flaga: Belgia',
    '🇧🇫' => 'flaga: Burkina Faso',
    '🇧🇬' => 'flaga: Bułgaria',
    '🇧🇭' => 'flaga: Bahrajn',
    '🇧🇮' => 'flaga: Burundi',
    '🇧🇯' => 'flaga: Benin',
    '🇧🇱' => 'flaga: Saint-Barthélemy',
    '🇧🇲' => 'flaga: Bermudy',
    '🇧🇳' => 'flaga: Brunei',
    '🇧🇴' => 'flaga: Boliwia',
    '🇧🇶' => 'flaga: Niderlandy Karaibskie',
    '🇧🇷' => 'flaga: Brazylia',
    '🇧🇸' => 'flaga: Bahamy',
    '🇧🇹' => 'flaga: Bhutan',
    '🇧🇻' => 'flaga: Wyspa Bouveta',
    '🇧🇼' => 'flaga: Botswana',
    '🇧🇾' => 'flaga: Białoruś',
    '🇧🇿' => 'flaga: Belize',
    '🇨🇦' => 'flaga: Kanada',
    '🇨🇨' => 'flaga: Wyspy Kokosowe',
    '🇨🇩' => 'flaga: Demokratyczna Republika Konga',
    '🇨🇫' => 'flaga: Republika Środkowoafrykańska',
    '🇨🇬' => 'flaga: Kongo',
    '🇨🇭' => 'flaga: Szwajcaria',
    '🇨🇮' => 'flaga: Côte d’Ivoire',
    '🇨🇰' => 'flaga: Wyspy Cooka',
    '🇨🇱' => 'flaga: Chile',
    '🇨🇲' => 'flaga: Kamerun',
    '🇨🇳' => 'flaga: Chiny',
    '🇨🇴' => 'flaga: Kolumbia',
    '🇨🇵' => 'flaga: Wyspa Clippertona',
    '🇨🇶' => 'flaga: Sark',
    '🇨🇷' => 'flaga: Kostaryka',
    '🇨🇺' => 'flaga: Kuba',
    '🇨🇻' => 'flaga: Republika Zielonego Przylądka',
    '🇨🇼' => 'flaga: Curaçao',
    '🇨🇽' => 'flaga: Wyspa Bożego Narodzenia',
    '🇨🇾' => 'flaga: Cypr',
    '🇨🇿' => 'flaga: Czechy',
    '🇩🇪' => 'flaga: Niemcy',
    '🇩🇬' => 'flaga: Diego Garcia',
    '🇩🇯' => 'flaga: Dżibuti',
    '🇩🇰' => 'flaga: Dania',
    '🇩🇲' => 'flaga: Dominika',
    '🇩🇴' => 'flaga: Dominikana',
    '🇩🇿' => 'flaga: Algieria',
    '🇪🇦' => 'flaga: Ceuta i Melilla',
    '🇪🇨' => 'flaga: Ekwador',
    '🇪🇪' => 'flaga: Estonia',
    '🇪🇬' => 'flaga: Egipt',
    '🇪🇭' => 'flaga: Sahara Zachodnia',
    '🇪🇷' => 'flaga: Erytrea',
    '🇪🇸' => 'flaga: Hiszpania',
    '🇪🇹' => 'flaga: Etiopia',
    '🇪🇺' => 'flaga: Unia Europejska',
    '🇫🇮' => 'flaga: Finlandia',
    '🇫🇯' => 'flaga: Fidżi',
    '🇫🇰' => 'flaga: Falklandy',
    '🇫🇲' => 'flaga: Mikronezja',
    '🇫🇴' => 'flaga: Wyspy Owcze',
    '🇫🇷' => 'flaga: Francja',
    '🇬🇦' => 'flaga: Gabon',
    '🇬🇧' => 'flaga: Wielka Brytania',
    '🇬🇩' => 'flaga: Grenada',
    '🇬🇪' => 'flaga: Gruzja',
    '🇬🇫' => 'flaga: Gujana Francuska',
    '🇬🇬' => 'flaga: Guernsey',
    '🇬🇭' => 'flaga: Ghana',
    '🇬🇮' => 'flaga: Gibraltar',
    '🇬🇱' => 'flaga: Grenlandia',
    '🇬🇲' => 'flaga: Gambia',
    '🇬🇳' => 'flaga: Gwinea',
    '🇬🇵' => 'flaga: Gwadelupa',
    '🇬🇶' => 'flaga: Gwinea Równikowa',
    '🇬🇷' => 'flaga: Grecja',
    '🇬🇸' => 'flaga: Georgia Południowa i Sandwich Południowy',
    '🇬🇹' => 'flaga: Gwatemala',
    '🇬🇺' => 'flaga: Guam',
    '🇬🇼' => 'flaga: Gwinea Bissau',
    '🇬🇾' => 'flaga: Gujana',
    '🇭🇰' => 'flaga: SRA Hongkong (Chiny)',
    '🇭🇲' => 'flaga: Wyspy Heard i McDonalda',
    '🇭🇳' => 'flaga: Honduras',
    '🇭🇷' => 'flaga: Chorwacja',
    '🇭🇹' => 'flaga: Haiti',
    '🇭🇺' => 'flaga: Węgry',
    '🇮🇨' => 'flaga: Wyspy Kanaryjskie',
    '🇮🇩' => 'flaga: Indonezja',
    '🇮🇪' => 'flaga: Irlandia',
    '🇮🇱' => 'flaga: Izrael',
    '🇮🇲' => 'flaga: Wyspa Man',
    '🇮🇳' => 'flaga: Indie',
    '🇮🇴' => 'flaga: Brytyjskie Terytorium Oceanu Indyjskiego',
    '🇮🇶' => 'flaga: Irak',
    '🇮🇷' => 'flaga: Iran',
    '🇮🇸' => 'flaga: Islandia',
    '🇮🇹' => 'flaga: Włochy',
    '🇯🇪' => 'flaga: Jersey',
    '🇯🇲' => 'flaga: Jamajka',
    '🇯🇴' => 'flaga: Jordania',
    '🇯🇵' => 'flaga: Japonia',
    '🇰🇪' => 'flaga: Kenia',
    '🇰🇬' => 'flaga: Kirgistan',
    '🇰🇭' => 'flaga: Kambodża',
    '🇰🇮' => 'flaga: Kiribati',
    '🇰🇲' => 'flaga: Komory',
    '🇰🇳' => 'flaga: Saint Kitts i Nevis',
    '🇰🇵' => 'flaga: Korea Północna',
    '🇰🇷' => 'flaga: Korea Południowa',
    '🇰🇼' => 'flaga: Kuwejt',
    '🇰🇾' => 'flaga: Kajmany',
    '🇰🇿' => 'flaga: Kazachstan',
    '🇱🇦' => 'flaga: Laos',
    '🇱🇧' => 'flaga: Liban',
    '🇱🇨' => 'flaga: Saint Lucia',
    '🇱🇮' => 'flaga: Liechtenstein',
    '🇱🇰' => 'flaga: Sri Lanka',
    '🇱🇷' => 'flaga: Liberia',
    '🇱🇸' => 'flaga: Lesotho',
    '🇱🇹' => 'flaga: Litwa',
    '🇱🇺' => 'flaga: Luksemburg',
    '🇱🇻' => 'flaga: Łotwa',
    '🇱🇾' => 'flaga: Libia',
    '🇲🇦' => 'flaga: Maroko',
    '🇲🇨' => 'flaga: Monako',
    '🇲🇩' => 'flaga: Mołdawia',
    '🇲🇪' => 'flaga: Czarnogóra',
    '🇲🇫' => 'flaga: Saint-Martin',
    '🇲🇬' => 'flaga: Madagaskar',
    '🇲🇭' => 'flaga: Wyspy Marshalla',
    '🇲🇰' => 'flaga: Macedonia Północna',
    '🇲🇱' => 'flaga: Mali',
    '🇲🇲' => 'flaga: Mjanma (Birma)',
    '🇲🇳' => 'flaga: Mongolia',
    '🇲🇴' => 'flaga: SRA Makau (Chiny)',
    '🇲🇵' => 'flaga: Mariany Północne',
    '🇲🇶' => 'flaga: Martynika',
    '🇲🇷' => 'flaga: Mauretania',
    '🇲🇸' => 'flaga: Montserrat',
    '🇲🇹' => 'flaga: Malta',
    '🇲🇺' => 'flaga: Mauritius',
    '🇲🇻' => 'flaga: Malediwy',
    '🇲🇼' => 'flaga: Malawi',
    '🇲🇽' => 'flaga: Meksyk',
    '🇲🇾' => 'flaga: Malezja',
    '🇲🇿' => 'flaga: Mozambik',
    '🇳🇦' => 'flaga: Namibia',
    '🇳🇨' => 'flaga: Nowa Kaledonia',
    '🇳🇪' => 'flaga: Niger',
    '🇳🇫' => 'flaga: Norfolk',
    '🇳🇬' => 'flaga: Nigeria',
    '🇳🇮' => 'flaga: Nikaragua',
    '🇳🇱' => 'flaga: Holandia',
    '🇳🇴' => 'flaga: Norwegia',
    '🇳🇵' => 'flaga: Nepal',
    '🇳🇷' => 'flaga: Nauru',
    '🇳🇺' => 'flaga: Niue',
    '🇳🇿' => 'flaga: Nowa Zelandia',
    '🇴🇲' => 'flaga: Oman',
    '🇵🇦' => 'flaga: Panama',
    '🇵🇪' => 'flaga: Peru',
    '🇵🇫' => 'flaga: Polinezja Francuska',
    '🇵🇬' => 'flaga: Papua-Nowa Gwinea',
    '🇵🇭' => 'flaga: Filipiny',
    '🇵🇰' => 'flaga: Pakistan',
    '🇵🇱' => 'flaga: Polska',
    '🇵🇲' => 'flaga: Saint-Pierre i Miquelon',
    '🇵🇳' => 'flaga: Pitcairn',
    '🇵🇷' => 'flaga: Portoryko',
    '🇵🇸' => 'flaga: Terytoria Palestyńskie',
    '🇵🇹' => 'flaga: Portugalia',
    '🇵🇼' => 'flaga: Palau',
    '🇵🇾' => 'flaga: Paragwaj',
    '🇶🇦' => 'flaga: Katar',
    '🇷🇪' => 'flaga: Reunion',
    '🇷🇴' => 'flaga: Rumunia',
    '🇷🇸' => 'flaga: Serbia',
    '🇷🇺' => 'flaga: Rosja',
    '🇷🇼' => 'flaga: Rwanda',
    '🇸🇦' => 'flaga: Arabia Saudyjska',
    '🇸🇧' => 'flaga: Wyspy Salomona',
    '🇸🇨' => 'flaga: Seszele',
    '🇸🇩' => 'flaga: Sudan',
    '🇸🇪' => 'flaga: Szwecja',
    '🇸🇬' => 'flaga: Singapur',
    '🇸🇭' => 'flaga: Wyspa Świętej Heleny',
    '🇸🇮' => 'flaga: Słowenia',
    '🇸🇯' => 'flaga: Svalbard i Jan Mayen',
    '🇸🇰' => 'flaga: Słowacja',
    '🇸🇱' => 'flaga: Sierra Leone',
    '🇸🇲' => 'flaga: San Marino',
    '🇸🇳' => 'flaga: Senegal',
    '🇸🇴' => 'flaga: Somalia',
    '🇸🇷' => 'flaga: Surinam',
    '🇸🇸' => 'flaga: Sudan Południowy',
    '🇸🇹' => 'flaga: Wyspy Świętego Tomasza i Książęca',
    '🇸🇻' => 'flaga: Salwador',
    '🇸🇽' => 'flaga: Sint Maarten',
    '🇸🇾' => 'flaga: Syria',
    '🇸🇿' => 'flaga: Eswatini',
    '🇹🇦' => 'flaga: Tristan da Cunha',
    '🇹🇨' => 'flaga: Turks i Caicos',
    '🇹🇩' => 'flaga: Czad',
    '🇹🇫' => 'flaga: Francuskie Terytoria Południowe i Antarktyczne',
    '🇹🇬' => 'flaga: Togo',
    '🇹🇭' => 'flaga: Tajlandia',
    '🇹🇯' => 'flaga: Tadżykistan',
    '🇹🇰' => 'flaga: Tokelau',
    '🇹🇱' => 'flaga: Timor Wschodni',
    '🇹🇲' => 'flaga: Turkmenistan',
    '🇹🇳' => 'flaga: Tunezja',
    '🇹🇴' => 'flaga: Tonga',
    '🇹🇷' => 'flaga: Turcja',
    '🇹🇹' => 'flaga: Trynidad i Tobago',
    '🇹🇻' => 'flaga: Tuvalu',
    '🇹🇼' => 'flaga: Tajwan',
    '🇹🇿' => 'flaga: Tanzania',
    '🇺🇦' => 'flaga: Ukraina',
    '🇺🇬' => 'flaga: Uganda',
    '🇺🇲' => 'flaga: Dalekie Wyspy Mniejsze Stanów Zjednoczonych',
    '🇺🇳' => 'flaga: Organizacja Narodów Zjednoczonych',
    '🇺🇸' => 'flaga: Stany Zjednoczone',
    '🇺🇾' => 'flaga: Urugwaj',
    '🇺🇿' => 'flaga: Uzbekistan',
    '🇻🇦' => 'flaga: Watykan',
    '🇻🇨' => 'flaga: Saint Vincent i Grenadyny',
    '🇻🇪' => 'flaga: Wenezuela',
    '🇻🇬' => 'flaga: Brytyjskie Wyspy Dziewicze',
    '🇻🇮' => 'flaga: Wyspy Dziewicze Stanów Zjednoczonych',
    '🇻🇳' => 'flaga: Wietnam',
    '🇻🇺' => 'flaga: Vanuatu',
    '🇼🇫' => 'flaga: Wallis i Futuna',
    '🇼🇸' => 'flaga: Samoa',
    '🇽🇰' => 'flaga: Kosowo',
    '🇾🇪' => 'flaga: Jemen',
    '🇾🇹' => 'flaga: Majotta',
    '🇿🇦' => 'flaga: Republika Południowej Afryki',
    '🇿🇲' => 'flaga: Zambia',
    '🇿🇼' => 'flaga: Zimbabwe',
    '🔟' => 'klawisz: 10',
    '🏻' => 'karnacja jasna',
    '🏼' => 'karnacja średnio jasna',
    '🏽' => 'karnacja średnia',
    '🏾' => 'karnacja średnio ciemna',
    '🏿' => 'karnacja ciemna',
    '😀' => 'szeroko uśmiechnięta twarz',
    '😃' => 'uśmiechnięta twarz z otwartymi ustami',
    '😄' => 'uśmiechnięta twarz z otwartymi ustami i roześmianymi oczami',
    '😁' => 'szeroko uśmiechnięta twarz o roześmianych oczach',
    '😆' => 'uśmiechnięta twarz z przymrużonymi oczami',
    '😅' => 'uśmiechnięta twarz z otwartymi ustami, oblana zimnym potem',
    '🤣' => 'tarza się ze śmiechu',
    '😂' => 'twarz ze łzami radości',
    '🙂' => 'lekko uśmiechnięta twarz',
    '🙃' => 'odwrócona twarz',
    '🫠' => 'roztapiająca się twarz',
    '😉' => 'twarz puszczająca oko',
    '😊' => 'uśmiechnięta twarz o roześmianych oczach',
    '😇' => 'uśmiechnięta twarz z aureolą',
    '🥰' => 'uśmiechnięta buźka z sercami',
    '😍' => 'uśmiechnięta twarz z oczami w kształcie serca',
    '🤩' => 'zafascynowany',
    '😘' => 'twarz przesyłająca całusa',
    '😗' => 'całująca twarz',
    '☺' => 'uśmiechnięta twarz',
    '😚' => 'całująca twarz z zamkniętymi oczami',
    '😙' => 'całująca twarz o roześmianych oczach',
    '🥲' => 'uśmiechnięta buźka ze łzą',
    '😋' => 'twarz delektująca się pysznym jedzeniem',
    '😛' => 'twarz wystawiająca język',
    '😜' => 'twarz wystawiająca język i puszczająca oko',
    '🤪' => 'szalona twarz',
    '😝' => 'twarz ze zmrużonymi oczami wystawiająca język',
    '🤑' => 'twarz z pieniędzmi na ustach',
    '🤗' => 'twarz z gestem przytulania',
    '🤭' => 'twarz z ręką na ustach',
    '🫢' => 'twarz z otwartymi oczami i ręką na ustach',
    '🫣' => 'twarz z podglądającym okiem',
    '🤫' => 'uciszająca twarz',
    '🤔' => 'myśląca twarz',
    '🫡' => 'salutująca twarz',
    '🤐' => 'twarz z zamkiem błyskawicznym na ustach',
    '🤨' => 'twarz z podniesioną brwią',
    '😐' => 'neutralna twarz',
    '😑' => 'twarz bez wyrazu',
    '😶' => 'twarz bez ust',
    '🫥' => 'twarz otoczona linią przerywaną',
    '😏' => 'twarz z uśmieszkiem',
    '😒' => 'niezadowolona twarz',
    '🙄' => 'twarz przewracająca oczami',
    '😬' => 'twarz z grymasem',
    '🤥' => 'twarz kłamcy',
    '🫨' => 'wstrząśnięta twarz',
    '😌' => 'twarz z wyrazem ulgi',
    '😔' => 'zamyślona twarz',
    '😪' => 'senna twarz',
    '🤤' => 'śliniąca się twarz',
    '😴' => 'śpiąca twarz',
    '🫩' => 'twarz z workami pod oczami',
    '😷' => 'twarz w masce medycznej',
    '🤒' => 'twarz z termometrem',
    '🤕' => 'twarz z bandażem',
    '🤢' => 'twarz z mdłościami',
    '🤮' => 'wymiotująca twarz',
    '🤧' => 'kichająca twarz',
    '🥵' => 'rozgrzana twarz',
    '🥶' => 'zmarznięta twarz',
    '🥴' => 'zamroczona twarz',
    '😵' => 'oszołomiona twarz',
    '🤯' => 'eksplodująca głowa',
    '🤠' => 'głowa w kapeluszu kowbojskim',
    '🥳' => 'świętująca twarz',
    '🥸' => 'buźka w przebraniu',
    '😎' => 'uśmiechnięta twarz w okularach przeciwsłonecznych',
    '🤓' => 'kujon',
    '🧐' => 'twarz z monoklem',
    '😕' => 'zdezorientowana twarz',
    '🫤' => 'twarz z ukośnymi ustami',
    '😟' => 'zmartwiona twarz',
    '🙁' => 'lekko zachmurzona twarz',
    '☹' => 'zachmurzona twarz',
    '😮' => 'twarz z otwartymi ustami',
    '😯' => 'zdumiona twarz',
    '😲' => 'zadziwiona twarz',
    '😳' => 'twarz z rumieńcami',
    '🫪' => 'wykrzywiona twarz',
    '🥺' => 'błagająca twarz',
    '🥹' => 'twarz powstrzymująca łzy',
    '😦' => 'zachmurzona twarz z otwartymi ustami',
    '😧' => 'udręczona twarz',
    '😨' => 'przestraszona twarz',
    '😰' => 'zaniepokojona twarz oblana potem',
    '😥' => 'smutna twarz z wyrazem ulgi',
    '😢' => 'płacząca twarz',
    '😭' => 'głośno płacząca twarz',
    '😱' => 'twarz krzycząca ze strachu',
    '😖' => 'zakłopotana twarz',
    '😣' => 'uparta twarz',
    '😞' => 'rozczarowana twarz',
    '😓' => 'twarz ze spuszczonymi oczami oblana potem',
    '😩' => 'znużona twarz',
    '😫' => 'zmęczona twarz',
    '🥱' => 'ziewająca twarz',
    '😤' => 'prychająca twarz',
    '😡' => 'nadąsana twarz',
    '😠' => 'zagniewana twarz',
    '🤬' => 'twarz z symbolami na ustach',
    '😈' => 'uśmiechnięta twarz z rogami',
    '👿' => 'zagniewana twarz z rogami',
    '💀' => 'czaszka',
    '☠' => 'czaszka z piszczelami',
    '💩' => 'kupa',
    '🤡' => 'twarz klauna',
    '👹' => 'ogr',
    '👺' => 'goblin',
    '👻' => 'duch',
    '👽' => 'ufoludek',
    '👾' => 'kosmiczny potwór',
    '🤖' => 'głowa robota',
    '😺' => 'uśmiechnięty kot',
    '😸' => 'uśmiechnięty kot o wesołych oczach',
    '😹' => 'kot ze łzami radości',
    '😻' => 'uśmiechnięty kot z oczami w kształcie serca',
    '😼' => 'kot z drwiącym uśmiechem',
    '😽' => 'kot przesyłający całusa',
    '🙀' => 'przestraszony kot',
    '😿' => 'płaczący kot',
    '😾' => 'nadąsany kot',
    '🙈' => 'małpa zasłaniająca oczy',
    '🙉' => 'małpa zasłaniająca uszy',
    '🙊' => 'małpa zasłaniająca pyszczek',
    '💌' => 'list miłosny',
    '💘' => 'serce przebite strzałą',
    '💝' => 'serce ze wstążką',
    '💖' => 'migoczące serce',
    '💗' => 'rosnące serce',
    '💓' => 'bijące serce',
    '💞' => 'wirujące serca',
    '💕' => 'dwa serca',
    '💟' => 'dekoracja z sercem',
    '❣' => 'wykrzyknik w kształcie serca',
    '💔' => 'złamane serce',
    '❤' => 'czerwone serce',
    '🩷' => 'różowe serce',
    '🧡' => 'pomarańczowe serce',
    '💛' => 'żółte serce',
    '💚' => 'zielone serce',
    '💙' => 'niebieskie serce',
    '🩵' => 'jasnoniebieskie serce',
    '💜' => 'purpurowe serce',
    '🤎' => 'brązowe serce',
    '🖤' => 'czarne serce',
    '🩶' => 'szare serce',
    '🤍' => 'białe serce',
    '💋' => 'ślad po pocałunku',
    '💯' => 'sto punktów',
    '💢' => 'symbol gniewu',
    '🫯' => 'chmura walki',
    '💥' => 'kolizja',
    '💫' => 'zawroty głowy',
    '💦' => 'krople potu',
    '💨' => 'szybkie poruszanie się',
    '🕳' => 'otwór',
    '💬' => 'dymek',
    '🗨' => 'lewostronny dymek',
    '🗯' => 'prawostronny dymek złości',
    '💭' => 'dymek myśli',
    '💤' => 'chrapanie',
    '👋' => 'machająca dłoń',
    '🤚' => 'wzniesiony grzbiet dłoni',
    '🖐' => 'uniesiona otwarta dłoń',
    '✋' => 'wzniesiona dłoń',
    '🖖' => 'salut wolkański',
    '🫱' => 'dłoń skierowana w prawo',
    '🫲' => 'dłoń skierowana w lewo',
    '🫳' => 'dłoń skierowana w dół',
    '🫴' => 'dłoń skierowana w górę',
    '🫷' => 'dłoń pchająca w lewo',
    '🫸' => 'dłoń pchająca w prawo',
    '👌' => 'dłoń z gestem OK',
    '🤌' => 'złączone palce',
    '🤏' => 'dłoń z gestem „trochę”',
    '✌' => 'gest V',
    '🤞' => 'skrzyżowane palce',
    '🫰' => 'dłoń ze skrzyżowanym palcem wskazującym i kciukiem',
    '🤟' => 'gest Kocham cię',
    '🤘' => 'gest rogów',
    '🤙' => 'dłoń w geście „Zadzwoń do mnie”',
    '👈' => 'dłoń z palcem wskazującym w lewo',
    '👉' => 'dłoń z palcem wskazującym w prawo',
    '👆' => 'dłoń z palcem wskazującym w górę',
    '🖕' => 'środkowy palec',
    '👇' => 'dłoń z palcem wskazującym w dół',
    '☝' => 'palec wskazujący w górę',
    '🫵' => 'palec wskazujący skierowany na patrzącego',
    '👍' => 'kciuk w górę',
    '👎' => 'kciuk w dół',
    '✊' => 'wzniesiona pięść',
    '👊' => 'pięść od przodu',
    '🤛' => 'pięść skierowana w lewo',
    '🤜' => 'pięść skierowana w prawo',
    '👏' => 'klaskanie',
    '🙌' => 'wzniesione ręce',
    '🫶' => 'dłonie tworzące serce',
    '👐' => 'otwarte dłonie',
    '🤲' => 'dłonie do góry razem',
    '🤝' => 'uścisk dłoni',
    '🙏' => 'złożone ręce',
    '✍' => 'pisząca dłoń',
    '💅' => 'lakier do paznokci',
    '🤳' => 'selfie',
    '💪' => 'napięty biceps',
    '🦾' => 'mechaniczne ramię',
    '🦿' => 'proteza nogi',
    '🦵' => 'noga',
    '🦶' => 'stopa',
    '👂' => 'ucho',
    '🦻' => 'ucho z aparatem słuchowym',
    '👃' => 'nos',
    '🧠' => 'mózg',
    '🫀' => 'serce',
    '🫁' => 'płuca',
    '🦷' => 'ząb',
    '🦴' => 'kość',
    '👀' => 'oczy',
    '👁' => 'oko',
    '👅' => 'język',
    '👄' => 'usta',
    '🫦' => 'przygryzanie wargi',
    '👶' => 'niemowlę',
    '🧒' => 'dziecko',
    '👦' => 'chłopiec',
    '👧' => 'dziewczynka',
    '🧑' => 'dorosły',
    '👱' => 'osoba z włosami blond',
    '👨' => 'mężczyzna',
    '🧔' => 'osoba z brodą',
    '👩' => 'kobieta',
    '🧓' => 'starsza osoba',
    '👴' => 'starszy mężczyzna',
    '👵' => 'starsza kobieta',
    '🙍' => 'zachmurzona osoba',
    '🙎' => 'nadąsana osoba',
    '🙅' => 'osoba pokazująca gest NIE',
    '🙆' => 'osoba pokazująca gest OK',
    '💁' => 'osoba z wystawioną dłonią',
    '🙋' => 'osoba podnosząca rękę',
    '🧏' => 'osoba głucha',
    '🙇' => 'osoba w ukłonie',
    '🤦' => 'osoba trzymająca się za czoło',
    '🤷' => 'osoba wzruszająca ramionami',
    '👮' => 'policjant',
    '🕵' => 'detektyw',
    '💂' => 'gwardzista',
    '🥷' => 'ninja',
    '👷' => 'budowlaniec',
    '🫅' => 'osoba w koronie',
    '🤴' => 'książę',
    '👸' => 'księżniczka',
    '👳' => 'osoba w turbanie',
    '👲' => 'osoba w chińskiej czapce',
    '🧕' => 'kobieta w chuście',
    '🤵' => 'osoba w smokingu',
    '👰' => 'osoba w welonie',
    '🤰' => 'kobieta w ciąży',
    '🫃' => 'mężczyzna w ciąży',
    '🫄' => 'osoba w ciąży',
    '🤱' => 'karmienie piersią',
    '👼' => 'aniołek',
    '🎅' => 'Święty Mikołaj',
    '🤶' => 'żona św. Mikołaja',
    '🦸' => 'superbohater',
    '🦹' => 'superłotr',
    '🧙' => 'mag',
    '🧚' => 'wróżka',
    '🧛' => 'wampir',
    '🧜' => 'syrena',
    '🧝' => 'elf',
    '🧞' => 'dżin',
    '🧟' => 'zombie',
    '🧌' => 'troll',
    '🫈' => 'włochate stworzenie',
    '💆' => 'osoba podczas masażu',
    '💇' => 'osoba podczas strzyżenia',
    '🚶' => 'idąca osoba',
    '🧍' => 'stojąca osoba',
    '🧎' => 'klęcząca osoba',
    '🏃' => 'biegnąca osoba',
    '💃' => 'tańcząca kobieta',
    '🕺' => 'tańczący mężczyzna',
    '🕴' => 'lewitujący mężczyzna w garniturze',
    '👯' => 'osoby z uszami królika na przyjęciu',
    '🧖' => 'osoba w zaparowanym pomieszczeniu',
    '🧗' => 'osoba wspinająca się',
    '🤺' => 'osoba uprawiająca szermierkę',
    '🏇' => 'wyścigi konne',
    '⛷' => 'narciarz',
    '🏂' => 'snowboardzista',
    '🏌' => 'osoba grająca w golfa',
    '🏄' => 'surfująca osoba',
    '🚣' => 'osoba wiosłująca w łodzi',
    '🏊' => 'pływająca osoba',
    '⛹' => 'osoba kozłująca piłkę',
    '🏋' => 'osoba podnosząca ciężary',
    '🚴' => 'osoba na rowerze',
    '🚵' => 'osoba na rowerze górskim',
    '🤸' => 'osoba robiąca gwiazdę',
    '🤼' => 'osoby uprawiające zapasy',
    '🤽' => 'osoba grająca w piłkę wodną',
    '🤾' => 'osoba grająca w piłkę ręczną',
    '🤹' => 'żonglująca osoba',
    '🧘' => 'osoba w pozycji lotosu',
    '🛀' => 'osoba biorąca kąpiel',
    '🛌' => 'osoba w łóżku',
    '👭' => 'kobiety trzymające się za ręce',
    '👫' => 'mężczyzna i kobieta trzymający się za ręce',
    '👬' => 'dwóch mężczyzn trzymających się za ręce',
    '💏' => 'pocałunek',
    '💑' => 'para z sercem',
    '🗣' => 'mówiąca głowa',
    '👤' => 'sylwetka popiersia',
    '👥' => 'sylwetki popiersi',
    '🫂' => 'obejmujące się osoby',
    '👪' => 'rodzina',
    '👣' => 'ślady stóp',
    '🫆' => 'odcisk palca',
    '🦰' => 'rude włosy',
    '🦱' => 'kręcone włosy',
    '🦳' => 'białe włosy',
    '🦲' => 'łysy',
    '🐵' => 'głowa małpy',
    '🐒' => 'małpa',
    '🦍' => 'goryl',
    '🦧' => 'orangutan',
    '🐶' => 'głowa psa',
    '🐕' => 'pies',
    '🦮' => 'pies przewodnik',
    '🐩' => 'pudel',
    '🐺' => 'głowa wilka',
    '🦊' => 'głowa lisa',
    '🦝' => 'szop',
    '🐱' => 'głowa kota',
    '🐈' => 'kot',
    '🦁' => 'głowa lwa',
    '🐯' => 'głowa tygrysa',
    '🐅' => 'tygrys',
    '🐆' => 'lampart',
    '🐴' => 'głowa konia',
    '🫎' => 'łoś',
    '🫏' => 'osioł',
    '🐎' => 'koń',
    '🦄' => 'głowa jednorożca',
    '🦓' => 'zebra',
    '🦌' => 'jeleń',
    '🦬' => 'żubr',
    '🐮' => 'głowa krowy',
    '🐂' => 'wół',
    '🐃' => 'wół domowy',
    '🐄' => 'krowa',
    '🐷' => 'głowa świni',
    '🐖' => 'świnia',
    '🐗' => 'dzik',
    '🐽' => 'ryj świni',
    '🐏' => 'biały baran',
    '🐑' => 'owca',
    '🐐' => 'koza',
    '🐪' => 'wielbłąd',
    '🐫' => 'wielbłąd dwugarbny',
    '🦙' => 'lama',
    '🦒' => 'żyrafa',
    '🐘' => 'słoń',
    '🦣' => 'mamut',
    '🦏' => 'nosorożec',
    '🦛' => 'hipopotam',
    '🐭' => 'głowa myszy',
    '🐁' => 'mysz',
    '🐀' => 'szczur',
    '🐹' => 'głowa chomika',
    '🐰' => 'głowa królika',
    '🐇' => 'królik',
    '🐿' => 'pręgowiec',
    '🦫' => 'bóbr',
    '🦔' => 'jeż',
    '🦇' => 'nietoperz',
    '🐻' => 'głowa niedźwiedzia',
    '🐨' => 'koala',
    '🐼' => 'głowa pandy',
    '🦥' => 'leniwiec',
    '🦦' => 'wydra',
    '🦨' => 'skunks',
    '🦘' => 'kangur',
    '🦡' => 'borsuk',
    '🐾' => 'ślady łap',
    '🦃' => 'indyk',
    '🐔' => 'kura',
    '🐓' => 'kogut',
    '🐣' => 'wykluwające się kurczątko',
    '🐤' => 'kurczątko',
    '🐥' => 'kurczątko od przodu',
    '🐦' => 'ptak',
    '🐧' => 'pingwin',
    '🕊' => 'gołąb',
    '🦅' => 'orzeł',
    '🦆' => 'kaczka',
    '🦢' => 'łabędź',
    '🦉' => 'sowa',
    '🦤' => 'dodo',
    '🪶' => 'pióro',
    '🦩' => 'flaming',
    '🦚' => 'paw',
    '🦜' => 'papuga',
    '🪽' => 'skrzydło',
    '🪿' => 'gęś',
    '🐸' => 'głowa żaby',
    '🐊' => 'krokodyl',
    '🐢' => 'żółw',
    '🦎' => 'jaszczurka',
    '🐍' => 'wąż',
    '🐲' => 'głowa smoka',
    '🐉' => 'smok',
    '🦕' => 'zauropod',
    '🦖' => 't-rex',
    '🐳' => 'wieloryb tryskający wodą',
    '🐋' => 'wieloryb',
    '🐬' => 'delfin',
    '🫍' => 'orka',
    '🦭' => 'foka',
    '🐟' => 'ryba',
    '🐠' => 'ryba tropikalna',
    '🐡' => 'ryba rozdymka',
    '🦈' => 'rekin',
    '🐙' => 'ośmiornica',
    '🐚' => 'muszla spiralna',
    '🪸' => 'koralowiec',
    '🪼' => 'meduza',
    '🦀' => 'krab',
    '🦞' => 'homar',
    '🦐' => 'krewetka',
    '🦑' => 'kałamarnica',
    '🦪' => 'ostryga',
    '🐌' => 'ślimak',
    '🦋' => 'motyl',
    '🐛' => 'gąsienica',
    '🐜' => 'mrówka',
    '🐝' => 'pszczoła',
    '🪲' => 'chrząszcz',
    '🐞' => 'biedronka',
    '🦗' => 'świerszcz',
    '🪳' => 'karaluch',
    '🕷' => 'pająk',
    '🕸' => 'pajęczyna',
    '🦂' => 'brązowy skorpion',
    '🦟' => 'komar',
    '🪰' => 'mucha',
    '🪱' => 'robak',
    '🦠' => 'zarazek',
    '💐' => 'bukiet kwiatów',
    '🌸' => 'kwiat wiśni',
    '💮' => 'biały kwiat',
    '🪷' => 'lotos',
    '🏵' => 'rozeta',
    '🌹' => 'róża',
    '🥀' => 'zwiędły kwiat',
    '🌺' => 'kwiat hibiskusa',
    '🌻' => 'słonecznik',
    '🌼' => 'kwiat',
    '🌷' => 'tulipan',
    '🪻' => 'hiacynt',
    '🌱' => 'sadzonka',
    '🪴' => 'roślina doniczkowa',
    '🌲' => 'wiecznie zielone drzewo',
    '🌳' => 'drzewo liściaste',
    '🌴' => 'palma',
    '🌵' => 'kaktus',
    '🌾' => 'pędy ryżu',
    '🌿' => 'zioło',
    '☘' => 'koniczyna',
    '🍀' => 'czterolistna koniczyna',
    '🍁' => 'liść klonowy',
    '🍂' => 'spadające liście',
    '🍃' => 'liście na wietrze',
    '🪹' => 'puste gniazdo',
    '🪺' => 'gniazdo z jajkami',
    '🍄' => 'grzyb',
    '🪾' => 'drzewo bez liści',
    '🍇' => 'winogrona',
    '🍈' => 'melon',
    '🍉' => 'arbuz',
    '🍊' => 'mandarynka',
    '🍋' => 'cytryna',
    '🍌' => 'banan',
    '🍍' => 'ananas',
    '🥭' => 'mango',
    '🍎' => 'czerwone jabłko',
    '🍏' => 'zielone jabłko',
    '🍐' => 'gruszka',
    '🍑' => 'brzoskwinia',
    '🍒' => 'wiśnie',
    '🍓' => 'truskawka',
    '🫐' => 'borówka amerykańska',
    '🥝' => 'owoc kiwi',
    '🍅' => 'pomidor',
    '🫒' => 'oliwka',
    '🥥' => 'kokos',
    '🥑' => 'awokado',
    '🍆' => 'bakłażan',
    '🥔' => 'ziemniak',
    '🥕' => 'marchew',
    '🌽' => 'kolba kukurydzy',
    '🌶' => 'ostra papryka',
    '🫑' => 'papryka',
    '🥒' => 'ogórek',
    '🥬' => 'warzywo liściaste',
    '🥦' => 'brokuł',
    '🧄' => 'czosnek',
    '🧅' => 'cebula',
    '🥜' => 'orzeszki ziemne',
    '🫘' => 'fasola',
    '🌰' => 'kasztan',
    '🫚' => 'korzeń imbiru',
    '🫛' => 'strąk grochu',
    '🫜' => 'warzywo korzeniowe',
    '🍞' => 'chleb',
    '🥐' => 'rogalik',
    '🥖' => 'bagietka',
    '🫓' => 'pita',
    '🥨' => 'precel',
    '🥯' => 'bajgiel',
    '🥞' => 'naleśniki',
    '🧇' => 'gofr',
    '🧀' => 'kawałek sera',
    '🍖' => 'mięso z kością',
    '🍗' => 'udko kurczaka',
    '🥩' => 'kawałek mięsa',
    '🥓' => 'boczek',
    '🍔' => 'hamburger',
    '🍟' => 'frytki',
    '🍕' => 'pizza',
    '🌭' => 'hot dog',
    '🥪' => 'kanapka',
    '🌮' => 'taco',
    '🌯' => 'burrito',
    '🫔' => 'tamales',
    '🥙' => 'wrap',
    '🧆' => 'falafel',
    '🥚' => 'jajko',
    '🍳' => 'gotowanie',
    '🥘' => 'danie z patelni',
    '🍲' => 'garnek z jedzeniem',
    '🫕' => 'fondue',
    '🥣' => 'miska z łyżką',
    '🥗' => 'sałatka',
    '🍿' => 'popcorn',
    '🧈' => 'masło',
    '🧂' => 'sól',
    '🥫' => 'jedzenie w puszce',
    '🍱' => 'pudełko bento',
    '🍘' => 'krakers ryżowy',
    '🍙' => 'kulka ryżowa',
    '🍚' => 'gotowany ryż',
    '🍛' => 'ryż curry',
    '🍜' => 'miska parującego jedzenia',
    '🍝' => 'spaghetti',
    '🍠' => 'pieczony batat',
    '🍢' => 'oden',
    '🍣' => 'sushi',
    '🍤' => 'smażona krewetka',
    '🍥' => 'ciastko rybne',
    '🥮' => 'ciasteczko księżycowe',
    '🍡' => 'dango',
    '🥟' => 'pieróg',
    '🥠' => 'ciastko z wróżbą',
    '🥡' => 'pudełko na wynos',
    '🍦' => 'lody włoskie',
    '🍧' => 'lody hawajskie',
    '🍨' => 'lody',
    '🍩' => 'pączek z dziurką',
    '🍪' => 'ciastko',
    '🎂' => 'tort urodzinowy',
    '🍰' => 'tort',
    '🧁' => 'babeczka',
    '🥧' => 'ciasto',
    '🍫' => 'tabliczka czekolady',
    '🍬' => 'cukierek',
    '🍭' => 'lizak',
    '🍮' => 'deser typu krem angielski',
    '🍯' => 'garnek miodu',
    '🍼' => 'butelka ze smoczkiem',
    '🥛' => 'szklanka mleka',
    '☕' => 'gorący napój',
    '🫖' => 'czajniczek',
    '🍵' => 'filiżanka bez uszka',
    '🍶' => 'sake',
    '🍾' => 'butelka z wystrzelającym korkiem',
    '🍷' => 'kieliszek wina',
    '🍸' => 'kieliszek z koktajlem',
    '🍹' => 'drink tropikalny',
    '🍺' => 'kufel piwa',
    '🍻' => 'stukające się kufle piwa',
    '🥂' => 'stukające się kieliszki',
    '🥃' => 'szklanka z grubym dnem',
    '🫗' => 'nalewanie płynu',
    '🥤' => 'szklanka ze słomką',
    '🧋' => 'napój bubble tea',
    '🧃' => 'napój w kartoniku',
    '🧉' => 'yerba mate',
    '🧊' => 'kostka lodu',
    '🥢' => 'pałeczki',
    '🍽' => 'talerz z nożem i widelcem',
    '🍴' => 'widelec i nóż',
    '🥄' => 'łyżka',
    '🔪' => 'nóż kuchenny',
    '🫙' => 'słoik',
    '🏺' => 'amfora',
    '🌍' => 'kula ziemska przedstawiająca Europę i Afrykę',
    '🌎' => 'kula ziemska przedstawiająca Ameryki',
    '🌏' => 'kula ziemska przedstawiająca Azję i Australię',
    '🌐' => 'kula ziemska z południkami',
    '🗺' => 'mapa świata',
    '🗾' => 'mapa Japonii',
    '🧭' => 'kompas',
    '🏔' => 'góra z czapą lodową',
    '⛰' => 'góra',
    '🛘' => 'osuwisko',
    '🌋' => 'wulkan',
    '🗻' => 'góra Fudżi',
    '🏕' => 'kemping',
    '🏖' => 'parasol na plaży',
    '🏜' => 'pustynia',
    '🏝' => 'bezludna wyspa',
    '🏞' => 'park narodowy',
    '🏟' => 'stadion',
    '🏛' => 'klasyczna budowla',
    '🏗' => 'dźwig budowlany',
    '🧱' => 'cegła',
    '🪨' => 'skała',
    '🪵' => 'drewno',
    '🛖' => 'chata',
    '🏘' => 'domki',
    '🏚' => 'stary dom',
    '🏠' => 'dom',
    '🏡' => 'dom z ogrodem',
    '🏢' => 'biurowiec',
    '🏣' => 'japońska poczta',
    '🏤' => 'urząd pocztowy',
    '🏥' => 'szpital',
    '🏦' => 'bank',
    '🏨' => 'hotel',
    '🏩' => 'hotel miłości',
    '🏪' => 'sklep całodobowy',
    '🏫' => 'szkoła',
    '🏬' => 'dom towarowy',
    '🏭' => 'fabryka',
    '🏯' => 'japoński zamek',
    '🏰' => 'zamek',
    '💒' => 'ślub',
    '🗼' => 'Tokyo Tower',
    '🗽' => 'Statua Wolności',
    '⛪' => 'kościół',
    '🕌' => 'meczet',
    '🛕' => 'świątynia hinduistyczna',
    '🕍' => 'synagoga',
    '⛩' => 'świątynia shinto',
    '🕋' => 'kaaba',
    '⛲' => 'fontanna',
    '⛺' => 'namiot',
    '🌁' => 'zamglenie',
    '🌃' => 'noc z gwiazdami',
    '🏙' => 'drapacze chmur',
    '🌄' => 'wschód słońca zza gór',
    '🌅' => 'wschód słońca',
    '🌆' => 'miasto o zmierzchu',
    '🌇' => 'zachód słońca',
    '🌉' => 'most nocą',
    '♨' => 'gorące źródła',
    '🎠' => 'koń z karuzeli',
    '🛝' => 'zjeżdżalnia',
    '🎡' => 'diabelski młyn',
    '🎢' => 'kolejka górska',
    '💈' => 'słup fryzjerski',
    '🎪' => 'namiot cyrkowy',
    '🚂' => 'lokomotywa',
    '🚃' => 'wagon kolejowy',
    '🚄' => 'szybki pociąg',
    '🚅' => 'szybki pociąg z zaokrąglonym przodem',
    '🚆' => 'pociąg',
    '🚇' => 'metro',
    '🚈' => 'kolej miejska',
    '🚉' => 'stacja',
    '🚊' => 'tramwaj',
    '🚝' => 'kolej jednoszynowa',
    '🚞' => 'kolej górska',
    '🚋' => 'wagon tramwajowy',
    '🚌' => 'autobus',
    '🚍' => 'nadjeżdżający autobus',
    '🚎' => 'trolejbus',
    '🚐' => 'minibus',
    '🚑' => 'karetka pogotowia',
    '🚒' => 'samochód strażacki',
    '🚓' => 'samochód policyjny',
    '🚔' => 'nadjeżdżający radiowóz',
    '🚕' => 'taksówka',
    '🚖' => 'nadjeżdżająca taksówka',
    '🚗' => 'samochód',
    '🚘' => 'nadjeżdżający samochód',
    '🚙' => 'samochód SUV',
    '🛻' => 'pick-up',
    '🚚' => 'samochód dostawczy',
    '🚛' => 'samochód ciężarowy',
    '🚜' => 'ciągnik',
    '🏎' => 'samochód wyścigowy',
    '🏍' => 'motocykl',
    '🛵' => 'skuter',
    '🦽' => 'wózek inwalidzki ręczny',
    '🦼' => 'wózek inwalidzki elektryczny',
    '🛺' => 'autoriksza',
    '🚲' => 'rower',
    '🛴' => 'hulajnoga',
    '🛹' => 'deskorolka',
    '🛼' => 'wrotka',
    '🚏' => 'przystanek autobusowy',
    '🛣' => 'autostrada',
    '🛤' => 'tor kolejowy',
    '🛢' => 'beczka oleju',
    '⛽' => 'dystrybutor paliwa',
    '🛞' => 'koło pojazdu',
    '🚨' => 'kogut policyjny',
    '🚥' => 'pozioma sygnalizacja uliczna',
    '🚦' => 'pionowa sygnalizacja uliczna',
    '🛑' => 'znak stopu',
    '🚧' => 'prace drogowe',
    '⚓' => 'kotwica',
    '🛟' => 'koło ratunkowe',
    '⛵' => 'żaglówka',
    '🛶' => 'kajak',
    '🚤' => 'ścigacz wodny',
    '🛳' => 'statek pasażerski',
    '⛴' => 'prom',
    '🛥' => 'motorówka',
    '🚢' => 'statek',
    '✈' => 'samolot',
    '🛩' => 'mały samolot',
    '🛫' => 'odlot samolotu',
    '🛬' => 'przylot samolotu',
    '🪂' => 'spadochron',
    '💺' => 'fotel',
    '🚁' => 'helikopter',
    '🚟' => 'kolej podwieszana',
    '🚠' => 'górska kolej linowa',
    '🚡' => 'kolej linowa',
    '🛰' => 'satelita',
    '🚀' => 'rakieta',
    '🛸' => 'latający talerz',
    '🛎' => 'dzwonek w recepcji',
    '🧳' => 'bagaż',
    '⌛' => 'klepsydra',
    '⏳' => 'klepsydra z przesypującym się piaskiem',
    '⌚' => 'zegarek',
    '⏰' => 'budzik',
    '⏱' => 'stoper',
    '⏲' => 'minutnik',
    '🕰' => 'zegar kominkowy',
    '🕛' => 'godzina 12:00',
    '🕧' => 'godzina 12:30',
    '🕐' => 'godzina 1:00',
    '🕜' => 'godzina 1:30',
    '🕑' => 'godzina 2:00',
    '🕝' => 'godzina 2:30',
    '🕒' => 'godzina 3:00',
    '🕞' => 'godzina 3:30',
    '🕓' => 'godzina 4:00',
    '🕟' => 'godzina 4:30',
    '🕔' => 'godzina 5:00',
    '🕠' => 'godzina 5:30',
    '🕕' => 'godzina 6:00',
    '🕡' => 'godzina 6:30',
    '🕖' => 'godzina 7:00',
    '🕢' => 'godzina 7:30',
    '🕗' => 'godzina 8:00',
    '🕣' => 'godzina 8:30',
    '🕘' => 'godzina 9:00',
    '🕤' => 'godzina 9:30',
    '🕙' => 'godzina 10:00',
    '🕥' => 'godzina 10:30',
    '🕚' => 'godzina 11:00',
    '🕦' => 'godzina 11:30',
    '🌑' => 'nów',
    '🌒' => 'narastający półksiężyc',
    '🌓' => 'pierwsza kwadra księżyca',
    '🌔' => 'narastający księżyc między pierwszą kwadrą a pełnią',
    '🌕' => 'pełnia',
    '🌖' => 'zanikający księżyc między pełnią a ostatnią kwadrą',
    '🌗' => 'ostatnia kwadra księżyca',
    '🌘' => 'zanikający półksiężyc',
    '🌙' => 'półksiężyc',
    '🌚' => 'nów z twarzą',
    '🌛' => 'pierwsza kwadra księżyca z twarzą',
    '🌜' => 'ostatnia kwadra księżyca z twarzą',
    '🌡' => 'termometr',
    '☀' => 'słońce',
    '🌝' => 'pełnia z twarzą',
    '🌞' => 'słońce z twarzą',
    '🪐' => 'planeta z pierścieniami',
    '⭐' => 'gwiazda',
    '🌟' => 'błyszcząca gwiazda',
    '🌠' => 'spadająca gwiazda',
    '🌌' => 'Droga Mleczna',
    '☁' => 'chmura',
    '⛅' => 'słońce zza chmury',
    '⛈' => 'chmura z piorunem i deszczem',
    '🌤' => 'słońce za chmurką',
    '🌥' => 'słońce za chmurą',
    '🌦' => 'słońce za chmurą i deszcz',
    '🌧' => 'chmura i deszcz',
    '🌨' => 'chmura i śnieg',
    '🌩' => 'chmura i piorun',
    '🌪' => 'tornado',
    '🌫' => 'mgła',
    '🌬' => 'dmuchająca twarz wiatru',
    '🌀' => 'cyklon',
    '🌈' => 'tęcza',
    '🌂' => 'złożony parasol',
    '☂' => 'parasol',
    '☔' => 'parasol z kroplami deszczu',
    '⛱' => 'parasol plażowy wbity w ziemię',
    '⚡' => 'wysokie napięcie',
    '❄' => 'płatek śniegu',
    '☃' => 'bałwanek i płatki śniegu',
    '⛄' => 'bałwanek bez śniegu',
    '☄' => 'kometa',
    '🔥' => 'ogień',
    '💧' => 'kropla',
    '🌊' => 'fala',
    '🎃' => 'dynia na halloween',
    '🎄' => 'choinka bożonarodzeniowa',
    '🎆' => 'fajerwerki',
    '🎇' => 'zimne ognie',
    '🧨' => 'petarda',
    '✨' => 'gwiazdki',
    '🎈' => 'balon',
    '🎉' => 'tuba z konfetti',
    '🎊' => 'kula z konfetti',
    '🎋' => 'drzewko na Tanabata',
    '🎍' => 'japońska dekoracja kadomatsu',
    '🎎' => 'japońskie lalki',
    '🎏' => 'flaga w kształcie karpia',
    '🎐' => 'dzwonek wietrzny',
    '🎑' => 'ceremonia oglądania księżyca',
    '🧧' => 'czerwona koperta',
    '🎀' => 'wstążka',
    '🎁' => 'zapakowany prezent',
    '🎗' => 'wstążka pamięci',
    '🎟' => 'bilety wstępu',
    '🎫' => 'bilet',
    '🎖' => 'order wojskowy',
    '🏆' => 'puchar',
    '🏅' => 'medal sportowy',
    '🥇' => 'medal za 1. miejsce',
    '🥈' => 'medal za 2. miejsce',
    '🥉' => 'medal za 3. miejsce',
    '⚽' => 'piłka nożna',
    '⚾' => 'baseball',
    '🥎' => 'softball',
    '🏀' => 'koszykówka',
    '🏐' => 'siatkówka',
    '🏈' => 'futbol amerykański',
    '🏉' => 'piłka do rugby',
    '🎾' => 'tenis',
    '🥏' => 'frisbee',
    '🎳' => 'kręgle',
    '🏏' => 'krykiet',
    '🏑' => 'hokej na trawie',
    '🏒' => 'hokej na lodzie',
    '🥍' => 'lacrosse',
    '🏓' => 'tenis stołowy',
    '🏸' => 'badminton',
    '🥊' => 'rękawica bokserska',
    '🥋' => 'strój do sztuk walki',
    '🥅' => 'bramka',
    '⛳' => 'flaga w dołku',
    '⛸' => 'but z łyżwą',
    '🎣' => 'wędka',
    '🤿' => 'maska do nurkowania',
    '🎽' => 'koszulka do biegania',
    '🎿' => 'narty',
    '🛷' => 'sanie',
    '🥌' => 'kamień do curlingu',
    '🎯' => 'strzał w 10',
    '🪀' => 'jojo',
    '🪁' => 'latawiec',
    '🔫' => 'pistolet na wodę',
    '🎱' => 'bila 8',
    '🔮' => 'kryształowa kula',
    '🪄' => 'czarodziejska różdżka',
    '🎮' => 'gra wideo',
    '🕹' => 'dżojstik',
    '🎰' => 'automat do gier',
    '🎲' => 'kostka do gry',
    '🧩' => 'element układanki',
    '🧸' => 'miś pluszowy',
    '🪅' => 'piniata',
    '🪩' => 'kula dyskotekowa',
    '🪆' => 'matrioszki',
    '♠' => 'pik',
    '♥' => 'kier',
    '♦' => 'karo',
    '♣' => 'trefl',
    '♟' => 'pionek',
    '🃏' => 'dżoker',
    '🀄' => 'madżong: czerwony smok',
    '🎴' => 'gra karciana hanafuda',
    '🎭' => 'maski teatralne',
    '🖼' => 'obrazek w ramce',
    '🎨' => 'paleta malarska',
    '🧵' => 'nić',
    '🪡' => 'igła krawiecka',
    '🧶' => 'włóczka',
    '🪢' => 'węzeł',
    '👓' => 'okulary',
    '🕶' => 'okulary słoneczne',
    '🥽' => 'okulary ochronne',
    '🥼' => 'biały fartuch',
    '🦺' => 'kamizelka ratunkowa',
    '👔' => 'krawat',
    '👕' => 'koszulka',
    '👖' => 'dżinsy',
    '🧣' => 'szalik',
    '🧤' => 'rękawiczki',
    '🧥' => 'płaszcz',
    '🧦' => 'skarpetki',
    '👗' => 'sukienka',
    '👘' => 'kimono',
    '🥻' => 'sari',
    '🩱' => 'strój kąpielowy jednoczęściowy',
    '🩲' => 'kąpielówki',
    '🩳' => 'szorty',
    '👙' => 'bikini',
    '👚' => 'ubranie damskie',
    '🪭' => 'wachlarz',
    '👛' => 'portmonetka',
    '👜' => 'torebka',
    '👝' => 'saszetka',
    '🛍' => 'torby na zakupy',
    '🎒' => 'tornister',
    '🩴' => 'japonka',
    '👞' => 'but męski',
    '👟' => 'but do biegania',
    '🥾' => 'but turystyczny',
    '🥿' => 'baleriny',
    '👠' => 'but na wysokim obcasie',
    '👡' => 'sandał damski',
    '🩰' => 'baletki',
    '👢' => 'kozak damski',
    '🪮' => 'grzebień fryzjerski',
    '👑' => 'korona',
    '👒' => 'kapelusz damski',
    '🎩' => 'cylinder',
    '🎓' => 'biret',
    '🧢' => 'bejsbolówka',
    '🪖' => 'hełm wojskowy',
    '⛑' => 'kask z krzyżykiem',
    '📿' => 'sznur modlitewny',
    '💄' => 'szminka',
    '💍' => 'pierścionek',
    '💎' => 'kamień szlachetny',
    '🔇' => 'wyciszony głośnik',
    '🔈' => 'niska głośność głośnika',
    '🔉' => 'średnia głośność głośnika',
    '🔊' => 'wysoka głośność głośnika',
    '📢' => 'głośnik',
    '📣' => 'megafon',
    '📯' => 'trąbka pocztowa',
    '🔔' => 'dzwonek',
    '🔕' => 'przekreślony dzwonek',
    '🎼' => 'partytura',
    '🎵' => 'nuta',
    '🎶' => 'nuty',
    '🎙' => 'mikrofon studyjny',
    '🎚' => 'suwak miksera dźwięku',
    '🎛' => 'pokrętła',
    '🎤' => 'mikrofon',
    '🎧' => 'słuchawki',
    '📻' => 'radio',
    '🎷' => 'saksofon',
    '🎺' => 'trąbka',
    '🪊' => 'puzon',
    '🪗' => 'akordeon',
    '🎸' => 'gitara',
    '🎹' => 'klawisze',
    '🎻' => 'skrzypce',
    '🪕' => 'banjo',
    '🥁' => 'bęben',
    '🪘' => 'konga',
    '🪇' => 'marakasy',
    '🪈' => 'flet',
    '🪉' => 'harfa',
    '📱' => 'telefon komórkowy',
    '📲' => 'telefon komórkowy ze strzałką',
    '☎' => 'telefon',
    '📞' => 'słuchawka telefoniczna',
    '📟' => 'pager',
    '📠' => 'faks',
    '🔋' => 'bateria',
    '🪫' => 'słaba bateria',
    '🔌' => 'wtyczka elektryczna',
    '💻' => 'laptop',
    '🖥' => 'komputer',
    '🖨' => 'drukarka',
    '⌨' => 'klawiatura',
    '🖱' => 'mysz komputerowa',
    '🖲' => 'trackball',
    '💽' => 'dysk komputerowy',
    '💾' => 'dyskietka',
    '💿' => 'dysk optyczny',
    '📀' => 'DVD',
    '🧮' => 'liczydło',
    '🎥' => 'kamera filmowa',
    '🎞' => 'taśma filmowa',
    '📽' => 'projektor filmowy',
    '🎬' => 'klaps',
    '📺' => 'telewizja',
    '📷' => 'aparat fotograficzny',
    '📸' => 'aparat fotograficzny z lampą błyskową',
    '📹' => 'kamera wideo',
    '📼' => 'kaseta wideo',
    '🔍' => 'lupa pochylona w lewo',
    '🔎' => 'lupa pochylona w prawo',
    '🕯' => 'świeca',
    '💡' => 'żarówka',
    '🔦' => 'latarka',
    '🏮' => 'czerwony lampion',
    '🪔' => 'dipa',
    '📔' => 'notes z dekoracyjną okładką',
    '📕' => 'zamknięta książka',
    '📖' => 'otwarta książka',
    '📗' => 'zielona książka',
    '📘' => 'niebieska książka',
    '📙' => 'pomarańczowa książka',
    '📚' => 'książki',
    '📓' => 'notes',
    '📒' => 'skoroszyt',
    '📃' => 'zawinięta strona',
    '📜' => 'zwój',
    '📄' => 'strona',
    '📰' => 'gazeta',
    '🗞' => 'zwinięta gazeta',
    '📑' => 'karty zakładek',
    '🔖' => 'zakładka',
    '🏷' => 'przywieszka do kluczy',
    '🪙' => 'moneta',
    '💰' => 'worek z pieniędzmi',
    '🪎' => 'skrzynia skarbów',
    '💴' => 'banknot jena',
    '💵' => 'banknot dolara',
    '💶' => 'banknot euro',
    '💷' => 'banknot funta',
    '💸' => 'uskrzydlone pieniądze',
    '💳' => 'karta kredytowa',
    '🧾' => 'paragon',
    '💹' => 'wykres wzrostu z symbolem jena',
    '✉' => 'koperta',
    '📧' => 'e-mail',
    '📨' => 'koperta przychodząca',
    '📩' => 'koperta ze strzałką',
    '📤' => 'skrzynka nadawcza',
    '📥' => 'skrzynka odbiorcza',
    '📦' => 'paczka',
    '📫' => 'zamknięta skrzynka pocztowa z podniesioną flagą',
    '📪' => 'zamknięta skrzynka pocztowa z opuszczoną flagą',
    '📬' => 'otwarta skrzynka pocztowa z podniesioną flagą',
    '📭' => 'otwarta skrzynka pocztowa z opuszczoną flagą',
    '📮' => 'skrzynka na listy',
    '🗳' => 'urna wyborcza z głosem',
    '✏' => 'ołówek',
    '✒' => 'pióro z czarną stalówką',
    '🖋' => 'wieczne pióro',
    '🖊' => 'długopis',
    '🖌' => 'pędzel',
    '🖍' => 'kredka',
    '📝' => 'notatka',
    '💼' => 'teczka',
    '📁' => 'folder',
    '📂' => 'otwarty folder',
    '🗂' => 'rozdzielacze kartoteki',
    '📅' => 'kalendarz',
    '📆' => 'kalendarz z wyrywanymi kartkami',
    '🗒' => 'kołonotatnik',
    '🗓' => 'kalendarz na spirali',
    '📇' => 'wizytownik',
    '📈' => 'wykres wzrostu',
    '📉' => 'wykres spadku',
    '📊' => 'wykres słupkowy',
    '📋' => 'podkładka do pisania',
    '📌' => 'pinezka',
    '📍' => 'okrągła pinezka',
    '📎' => 'spinacz',
    '🖇' => 'złączone spinacze',
    '📏' => 'linijka',
    '📐' => 'ekierka',
    '✂' => 'nożyczki',
    '🗃' => 'pudełko-kartoteka',
    '🗄' => 'szafka-kartoteka',
    '🗑' => 'kosz na śmieci',
    '🔒' => 'zamknięta kłódka',
    '🔓' => 'otwarta kłódka',
    '🔏' => 'zamknięta kłódka z piórem',
    '🔐' => 'zamknięta kłódka z kluczem',
    '🔑' => 'klucz',
    '🗝' => 'staroświecki klucz',
    '🔨' => 'młotek',
    '🪓' => 'siekiera',
    '⛏' => 'kilof',
    '⚒' => 'młoty',
    '🛠' => 'młot i klucz',
    '🗡' => 'sztylet',
    '⚔' => 'skrzyżowane miecze',
    '💣' => 'bomba',
    '🪃' => 'bumerang',
    '🏹' => 'łuk i strzała',
    '🛡' => 'tarcza',
    '🪚' => 'piła do drewna',
    '🔧' => 'klucz warsztatowy',
    '🪛' => 'śrubokręt',
    '🔩' => 'śruba i nakrętka',
    '⚙' => 'koło zębate',
    '🗜' => 'ścisk',
    '⚖' => 'waga szalkowa',
    '🦯' => 'biała laska',
    '🔗' => 'ogniwa',
    '⛓' => 'łańcuchy',
    '🪝' => 'hak',
    '🧰' => 'skrzynka na narzędzia',
    '🧲' => 'magnes',
    '🪜' => 'drabina',
    '🪏' => 'łopata',
    '⚗' => 'alembik',
    '🧪' => 'probówka',
    '🧫' => 'płytka Petriego',
    '🧬' => 'dna',
    '🔬' => 'mikroskop',
    '🔭' => 'teleskop',
    '📡' => 'antena satelitarna',
    '💉' => 'strzykawka',
    '🩸' => 'kropla krwi',
    '💊' => 'kapsułka',
    '🩹' => 'plaster',
    '🩼' => 'kula',
    '🩺' => 'stetoskop',
    '🩻' => 'zdjęcie rentgenowskie',
    '🚪' => 'drzwi',
    '🛗' => 'winda',
    '🪞' => 'lustro',
    '🪟' => 'okno',
    '🛏' => 'łóżko',
    '🛋' => 'kanapa i lampa',
    '🪑' => 'krzesło',
    '🚽' => 'muszla klozetowa',
    '🪠' => 'przepychacz',
    '🚿' => 'prysznic',
    '🛁' => 'wanna',
    '🪤' => 'pułapka na myszy',
    '🪒' => 'brzytwa',
    '🧴' => 'butelka z płynem',
    '🧷' => 'agrafka',
    '🧹' => 'miotła',
    '🧺' => 'kosz',
    '🧻' => 'rolka papieru',
    '🪣' => 'wiadro',
    '🧼' => 'mydło',
    '🫧' => 'bąbelki',
    '🪥' => 'szczoteczka do zębów',
    '🧽' => 'gąbka',
    '🧯' => 'gaśnica',
    '🛒' => 'wózek sklepowy',
    '🚬' => 'papieros',
    '⚰' => 'trumna',
    '🪦' => 'nagrobek',
    '⚱' => 'urna na prochy',
    '🧿' => 'amulet nazar',
    '🪬' => 'chamsa',
    '🗿' => 'moai',
    '🪧' => 'tabliczka',
    '🪪' => 'dowód tożsamości',
    '🏧' => 'znak bankomatu',
    '🚮' => 'znak kosza na śmieci',
    '🚰' => 'woda pitna',
    '♿' => 'symbol wózka inwalidzkiego',
    '🚹' => 'toaleta męska',
    '🚺' => 'toaleta damska',
    '🚻' => 'toalety',
    '🚼' => 'symbol niemowlęcia',
    '🚾' => 'WC',
    '🛂' => 'kontrola paszportowa',
    '🛃' => 'kontrola celna',
    '🛄' => 'odbiór bagażu',
    '🛅' => 'przechowalnia bagażu',
    '⚠' => 'ostrzeżenie',
    '🚸' => 'dzieci przechodzące przez jezdnię',
    '⛔' => 'zakaz wjazdu',
    '🚫' => 'zakaz',
    '🚳' => 'zakaz wjazdu rowerów',
    '🚭' => 'zakaz palenia',
    '🚯' => 'zakaz śmiecenia',
    '🚱' => 'woda niezdatna do picia',
    '🚷' => 'zakaz ruchu pieszych',
    '📵' => 'zakaz korzystania z telefonów komórkowych',
    '🔞' => 'zakaz poniżej osiemnastego roku życia',
    '☢' => 'promieniowanie radioaktywne',
    '☣' => 'zagrożenie ze strony organizmów żywych',
    '⬆' => 'strzałka w górę',
    '↗' => 'strzałka w górę w prawo',
    '➡' => 'strzałka w prawo',
    '↘' => 'strzałka w dół w prawo',
    '⬇' => 'strzałka w dół',
    '↙' => 'strzałka w dół w lewo',
    '⬅' => 'strzałka w lewo',
    '↖' => 'strzałka w górę w lewo',
    '↕' => 'strzałka w górę i w dół',
    '↔' => 'strzałka w lewo i w prawo',
    '↩' => 'strzałka zakręcona w lewo',
    '↪' => 'strzałka zakręcona w prawo',
    '⤴' => 'strzałka w prawo skręcająca w górę',
    '⤵' => 'strzałka w prawo skręcająca w dół',
    '🔃' => 'pionowe strzałki zgodne z ruchem wskazówek zegara',
    '🔄' => 'przycisk ze strzałkami przeciwnie do ruchu wskazówek zegara',
    '🔙' => 'strzałka z napisem BACK',
    '🔚' => 'strzałka z napisem END',
    '🔛' => 'strzałka z napisem ON!',
    '🔜' => 'strzałka z napisem SOON',
    '🔝' => 'strzałka z napisem TOP',
    '🛐' => 'miejsce kultu',
    '⚛' => 'symbol atomu',
    '🕉' => 'om',
    '✡' => 'gwiazda Dawida',
    '☸' => 'koło dharmy',
    '☯' => 'yin-yang',
    '✝' => 'krzyż łaciński',
    '☦' => 'krzyż prawosławny',
    '☪' => 'gwiazda i półksiężyc',
    '☮' => 'symbol pokoju',
    '🕎' => 'menora',
    '🔯' => 'gwiazda sześcioramienna z kropką',
    '🪯' => 'khanda',
    '♈' => 'Baran',
    '♉' => 'Byk',
    '♊' => 'Bliźnięta',
    '♋' => 'Rak',
    '♌' => 'Lew',
    '♍' => 'Panna',
    '♎' => 'Waga',
    '♏' => 'Skorpion',
    '♐' => 'Strzelec',
    '♑' => 'Koziorożec',
    '♒' => 'Wodnik',
    '♓' => 'Ryby',
    '⛎' => 'Wężownik',
    '🔀' => 'przycisk losowego odtwarzania utworów',
    '🔁' => 'przycisk powtarzania',
    '🔂' => 'przycisk powtarzania jednokrotnego',
    '▶' => 'odtwórz',
    '⏩' => 'przycisk szybkiego przewijania do przodu',
    '⏭' => 'następny utwór',
    '⏯' => 'odtwórz lub wstrzymaj',
    '◀' => 'wstecz',
    '⏪' => 'przycisk szybkiego przewijania do tyłu',
    '⏮' => 'poprzedni utwór',
    '🔼' => 'przycisk „w górę”',
    '⏫' => 'przycisk „szybko w górę”',
    '🔽' => 'przycisk „w dół”',
    '⏬' => 'przycisk „szybko w dół”',
    '⏸' => 'pauza',
    '⏹' => 'zatrzymaj',
    '⏺' => 'nagraj',
    '⏏' => 'wysuń',
    '🎦' => 'kino',
    '🔅' => 'przycisk małej jasności',
    '🔆' => 'przycisk dużej jasności',
    '📶' => 'siła sygnału',
    '🛜' => 'bezprzewodowy',
    '📳' => 'tryb wibracji',
    '📴' => 'wyłączony telefon komórkowy',
    '♀' => 'znak kobiety',
    '♂' => 'znak mężczyzny',
    '⚧' => 'symbol transpłciowości',
    '✖' => 'znak mnożenia',
    '➕' => 'znak plus',
    '➖' => 'znak minus',
    '➗' => 'znak dzielenia',
    '🟰' => 'gruby znak równości',
    '♾' => 'nieskończoność',
    '‼' => 'podwójny wykrzyknik',
    '⁉' => 'wykrzyknik ze znakiem zapytania',
    '❓' => 'czerwony znak zapytania',
    '❔' => 'biały znak zapytania',
    '❕' => 'biały wykrzyknik',
    '❗' => 'czerwony wykrzyknik',
    '〰' => 'falista kreska',
    '💱' => 'wymiana walut',
    '💲' => 'gruby symbol dolara',
    '⚕' => 'symbol medycyny',
    '♻' => 'recykling',
    '⚜' => 'lilijka',
    '🔱' => 'emblemat z trójzębem',
    '📛' => 'plakietka',
    '🔰' => 'japoński symbol początkującego kierowcy',
    '⭕' => 'gruby czerwony okrąg',
    '✅' => 'przycisk ze znacznikiem wyboru',
    '☑' => 'pole ze znacznikiem wyboru',
    '✔' => 'znacznik wyboru',
    '❌' => 'znak krzyżyka',
    '❎' => 'przycisk z krzyżykiem',
    '➰' => 'pętla',
    '➿' => 'podwójna pętla',
    '〽' => 'początek partii wokalnej',
    '✳' => 'gwiazdka ośmioramienna',
    '✴' => 'gwiazda ośmioramienna',
    '❇' => 'iskra',
    '™' => 'znak towarowy',
    '🫟' => 'rozbryzg',
    '🔠' => 'wielkie litery (alfabet łaciński)',
    '🔡' => 'małe litery (alfabet łaciński)',
    '🔢' => 'cyfry',
    '🔣' => 'symbole',
    '🔤' => 'litery (alfabet łaciński)',
    '🅰' => 'grupa krwi A',
    '🆎' => 'grupa krwi AB',
    '🅱' => 'grupa krwi B',
    '🆑' => 'przycisk CL',
    '🆒' => 'przycisk COOL',
    '🆓' => 'przycisk FREE',
    'ℹ' => 'informacja',
    '🆔' => 'przycisk ID',
    'Ⓜ' => 'koło z literą M',
    '🆕' => 'przycisk NEW',
    '🆖' => 'przycisk NG',
    '🅾' => 'grupa krwi 0',
    '🆗' => 'przycisk OK',
    '🅿' => 'parking',
    '🆘' => 'przycisk SOS',
    '🆙' => 'przycisk UP!',
    '🆚' => 'przycisk VS',
    '🈁' => 'japoński przycisk „tutaj”',
    '🈂' => 'japoński przycisk „usługa”',
    '🈷' => 'ideogram księżyca',
    '🈶' => 'japoński przycisk „płatne”',
    '🈯' => 'japoński przycisk „zarezerwowane”',
    '🉐' => 'japoński przycisk „okazja”',
    '🈹' => 'japoński przycisk „rabat”',
    '🈚' => 'japoński przycisk „bezpłatne”',
    '🈲' => 'japoński przycisk „zabronione”',
    '🉑' => 'japoński przycisk „dozwolone”',
    '🈸' => 'japoński przycisk „wniosek”',
    '🈴' => 'japoński przycisk „ocena pozytywna”',
    '🈳' => 'japoński przycisk „wolne miejsce”',
    '㊗' => 'japoński przycisk „gratulacje”',
    '㊙' => 'japoński przycisk „tajemnica”',
    '🈺' => 'japoński przycisk „czynne”',
    '🈵' => 'japoński przycisk „brak wolnych miejsc”',
    '🔴' => 'czerwone koło',
    '🟠' => 'pomarańczowe koło',
    '🟡' => 'żółte koło',
    '🟢' => 'zielone koło',
    '🔵' => 'niebieskie koło',
    '🟣' => 'fioletowe koło',
    '🟤' => 'brązowe koło',
    '⚫' => 'czarne koło',
    '⚪' => 'białe koło',
    '🟥' => 'czerwony kwadrat',
    '🟧' => 'pomarańczowy kwadrat',
    '🟨' => 'żółty kwadrat',
    '🟩' => 'zielony kwadrat',
    '🟦' => 'niebieski kwadrat',
    '🟪' => 'fioletowy kwadrat',
    '🟫' => 'brązowy kwadrat',
    '⬛' => 'duży czarny kwadrat',
    '⬜' => 'duży biały kwadrat',
    '◼' => 'średni czarny kwadrat',
    '◻' => 'średni biały kwadrat',
    '◾' => 'mały/średni czarny kwadrat',
    '◽' => 'mały/średni biały kwadrat',
    '▪' => 'mały czarny kwadrat',
    '▫' => 'mały biały kwadrat',
    '🔶' => 'duży pomarańczowy romb',
    '🔷' => 'duży niebieski romb',
    '🔸' => 'mały pomarańczowy romb',
    '🔹' => 'mały niebieski romb',
    '🔺' => 'czerwony trójkąt skierowany w górę',
    '🔻' => 'czerwony trójkąt skierowany w dół',
    '💠' => 'romb z kropką',
    '🔘' => 'przycisk radiowy',
    '🔳' => 'biały kwadratowy przycisk',
    '🔲' => 'czarny kwadratowy przycisk',
    '🏁' => 'flaga w szachownicę',
    '🚩' => 'flaga trójkątna',
    '🎌' => 'skrzyżowane flagi',
    '🏴' => 'czarna flaga',
    '🏳' => 'biała flaga',
];
