<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎤᏔᎾ, ᎤᏔᎾ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎤᏔᎾ, ᎤᏔᎾ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎤᏔᎾ, ᎤᏔᎾ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎤᏔᎾ, ᎤᏔᎾ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎤᏔᎾ, ᎤᏔᎾ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎤᏔᎾ, ᎤᏔᎾ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎤᏔᎾ, ᎤᏔᎾ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎤᏔᎾ, ᎤᏔᎾ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎤᏔᎾ, ᎤᏔᎾ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎤᏔᎾ, ᎤᏔᎾ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎤᏔᎾ, ᎤᏔᎾ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎤᏔᎾ, ᎤᏔᎾ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎤᏔᎾ, ᎤᏔᎾ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎤᏔᎾ, ᎤᏔᎾ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎤᏔᎾ, ᎤᏔᎾ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎤᏔᎾ, ᎤᏔᎾ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎤᏔᎾ, ᎤᏔᎾ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎤᏔᎾ, ᎤᏔᎾ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎤᏔᎾ, ᎤᏔᎾ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎤᏔᎾ, ᎤᏔᎾ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏻‍❤‍💋‍👨🏻' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👨🏻‍❤‍💋‍👨🏼' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👨🏻‍❤‍💋‍👨🏽' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏻‍❤‍💋‍👨🏾' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏻‍❤‍💋‍👨🏿' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏼‍❤‍💋‍👨🏻' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👨🏼‍❤‍💋‍👨🏼' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👨🏼‍❤‍💋‍👨🏽' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏼‍❤‍💋‍👨🏾' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏼‍❤‍💋‍👨🏿' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏽‍❤‍💋‍👨🏻' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👨🏽‍❤‍💋‍👨🏼' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👨🏽‍❤‍💋‍👨🏽' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏽‍❤‍💋‍👨🏾' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏽‍❤‍💋‍👨🏿' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏾‍❤‍💋‍👨🏻' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👨🏾‍❤‍💋‍👨🏼' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👨🏾‍❤‍💋‍👨🏽' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏾‍❤‍💋‍👨🏾' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏾‍❤‍💋‍👨🏿' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏿‍❤‍💋‍👨🏻' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👨🏿‍❤‍💋‍👨🏼' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👨🏿‍❤‍💋‍👨🏽' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏿‍❤‍💋‍👨🏾' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏿‍❤‍💋‍👨🏿' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏻‍❤‍💋‍👨🏻' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏻‍❤‍💋‍👨🏼' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏻‍❤‍💋‍👨🏽' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏻‍❤‍💋‍👨🏾' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏻‍❤‍💋‍👨🏿' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏼‍❤‍💋‍👨🏻' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏼‍❤‍💋‍👨🏼' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏼‍❤‍💋‍👨🏽' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏼‍❤‍💋‍👨🏾' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏼‍❤‍💋‍👨🏿' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏽‍❤‍💋‍👨🏻' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏽‍❤‍💋‍👨🏼' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏽‍❤‍💋‍👨🏽' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏽‍❤‍💋‍👨🏾' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏽‍❤‍💋‍👨🏿' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏾‍❤‍💋‍👨🏻' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏾‍❤‍💋‍👨🏼' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏾‍❤‍💋‍👨🏽' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏾‍❤‍💋‍👨🏾' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏾‍❤‍💋‍👨🏿' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏿‍❤‍💋‍👨🏻' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏿‍❤‍💋‍👨🏼' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏿‍❤‍💋‍👨🏽' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏿‍❤‍💋‍👨🏾' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏿‍❤‍💋‍👨🏿' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏻‍❤‍💋‍👩🏻' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᎨᏯ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏻‍❤‍💋‍👩🏼' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᎨᏯ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏻‍❤‍💋‍👩🏽' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᎨᏯ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏻‍❤‍💋‍👩🏾' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᎨᏯ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏻‍❤‍💋‍👩🏿' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᎨᏯ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏼‍❤‍💋‍👩🏻' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᎨᏯ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏼‍❤‍💋‍👩🏼' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᎨᏯ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏼‍❤‍💋‍👩🏽' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᎨᏯ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏼‍❤‍💋‍👩🏾' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᎨᏯ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏼‍❤‍💋‍👩🏿' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᎨᏯ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏽‍❤‍💋‍👩🏻' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᎨᏯ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏽‍❤‍💋‍👩🏼' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᎨᏯ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏽‍❤‍💋‍👩🏽' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᎨᏯ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏽‍❤‍💋‍👩🏾' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᎨᏯ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏽‍❤‍💋‍👩🏿' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᎨᏯ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏾‍❤‍💋‍👩🏻' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᎨᏯ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏾‍❤‍💋‍👩🏼' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᎨᏯ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏾‍❤‍💋‍👩🏽' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᎨᏯ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏾‍❤‍💋‍👩🏾' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᎨᏯ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏾‍❤‍💋‍👩🏿' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᎨᏯ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏿‍❤‍💋‍👩🏻' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᎨᏯ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏿‍❤‍💋‍👩🏼' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᎨᏯ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏿‍❤‍💋‍👩🏽' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᎨᏯ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏿‍❤‍💋‍👩🏾' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᎨᏯ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏿‍❤‍💋‍👩🏿' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᎨᏯ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏻‍🫯‍🧑🏼' => 'ᎠᏂᏴᏫ ᏓᏁᎯᎲ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧑🏻‍🫯‍🧑🏽' => 'ᎠᏂᏴᏫ ᏓᏁᎯᎲ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏻‍🫯‍🧑🏾' => 'ᎠᏂᏴᏫ ᏓᏁᎯᎲ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏻‍🫯‍🧑🏿' => 'ᎠᏂᏴᏫ ᏓᏁᎯᎲ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏼‍🫯‍🧑🏻' => 'ᎠᏂᏴᏫ ᏓᏁᎯᎲ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧑🏼‍🫯‍🧑🏽' => 'ᎠᏂᏴᏫ ᏓᏁᎯᎲ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏼‍🫯‍🧑🏾' => 'ᎠᏂᏴᏫ ᏓᏁᎯᎲ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏼‍🫯‍🧑🏿' => 'ᎠᏂᏴᏫ ᏓᏁᎯᎲ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏽‍🫯‍🧑🏻' => 'ᎠᏂᏴᏫ ᏓᏁᎯᎲ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧑🏽‍🫯‍🧑🏼' => 'ᎠᏂᏴᏫ ᏓᏁᎯᎲ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧑🏽‍🫯‍🧑🏾' => 'ᎠᏂᏴᏫ ᏓᏁᎯᎲ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏽‍🫯‍🧑🏿' => 'ᎠᏂᏴᏫ ᏓᏁᎯᎲ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏾‍🫯‍🧑🏻' => 'ᎠᏂᏴᏫ ᏓᏁᎯᎲ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧑🏾‍🫯‍🧑🏼' => 'ᎠᏂᏴᏫ ᏓᏁᎯᎲ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧑🏾‍🫯‍🧑🏽' => 'ᎠᏂᏴᏫ ᏓᏁᎯᎲ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏾‍🫯‍🧑🏿' => 'ᎠᏂᏴᏫ ᏓᏁᎯᎲ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏿‍🫯‍🧑🏻' => 'ᎠᏂᏴᏫ ᏓᏁᎯᎲ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧑🏿‍🫯‍🧑🏼' => 'ᎠᏂᏴᏫ ᏓᏁᎯᎲ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧑🏿‍🫯‍🧑🏽' => 'ᎠᏂᏴᏫ ᏓᏁᎯᎲ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏿‍🫯‍🧑🏾' => 'ᎠᏂᏴᏫ ᏓᏁᎯᎲ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏻‍❤‍🧑🏼' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎤᏔᎾ, ᎤᏔᎾ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧑🏻‍❤‍🧑🏽' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎤᏔᎾ, ᎤᏔᎾ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏻‍❤‍🧑🏾' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎤᏔᎾ, ᎤᏔᎾ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏻‍❤‍🧑🏿' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎤᏔᎾ, ᎤᏔᎾ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏼‍❤‍🧑🏻' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎤᏔᎾ, ᎤᏔᎾ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧑🏼‍❤‍🧑🏽' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎤᏔᎾ, ᎤᏔᎾ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏼‍❤‍🧑🏾' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎤᏔᎾ, ᎤᏔᎾ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏼‍❤‍🧑🏿' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎤᏔᎾ, ᎤᏔᎾ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏽‍❤‍🧑🏻' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎤᏔᎾ, ᎤᏔᎾ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧑🏽‍❤‍🧑🏼' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎤᏔᎾ, ᎤᏔᎾ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧑🏽‍❤‍🧑🏾' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎤᏔᎾ, ᎤᏔᎾ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏽‍❤‍🧑🏿' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎤᏔᎾ, ᎤᏔᎾ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏾‍❤‍🧑🏻' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎤᏔᎾ, ᎤᏔᎾ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧑🏾‍❤‍🧑🏼' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎤᏔᎾ, ᎤᏔᎾ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧑🏾‍❤‍🧑🏽' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎤᏔᎾ, ᎤᏔᎾ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏾‍❤‍🧑🏿' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎤᏔᎾ, ᎤᏔᎾ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏿‍❤‍🧑🏻' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎤᏔᎾ, ᎤᏔᎾ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧑🏿‍❤‍🧑🏼' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎤᏔᎾ, ᎤᏔᎾ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧑🏿‍❤‍🧑🏽' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎤᏔᎾ, ᎤᏔᎾ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏿‍❤‍🧑🏾' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎤᏔᎾ, ᎤᏔᎾ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏻‍🐰‍🧑🏼' => 'ᏴᏫ ᏥᏍᏚ ᏗᎦᎴ ᎤᏂᏍᏆᎸᎡᎲᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧑🏻‍🐰‍🧑🏽' => 'ᏴᏫ ᏥᏍᏚ ᏗᎦᎴ ᎤᏂᏍᏆᎸᎡᎲᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏻‍🐰‍🧑🏾' => 'ᏴᏫ ᏥᏍᏚ ᏗᎦᎴ ᎤᏂᏍᏆᎸᎡᎲᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏻‍🐰‍🧑🏿' => 'ᏴᏫ ᏥᏍᏚ ᏗᎦᎴ ᎤᏂᏍᏆᎸᎡᎲᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏼‍🐰‍🧑🏻' => 'ᏴᏫ ᏥᏍᏚ ᏗᎦᎴ ᎤᏂᏍᏆᎸᎡᎲᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧑🏼‍🐰‍🧑🏽' => 'ᏴᏫ ᏥᏍᏚ ᏗᎦᎴ ᎤᏂᏍᏆᎸᎡᎲᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏼‍🐰‍🧑🏾' => 'ᏴᏫ ᏥᏍᏚ ᏗᎦᎴ ᎤᏂᏍᏆᎸᎡᎲᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏼‍🐰‍🧑🏿' => 'ᏴᏫ ᏥᏍᏚ ᏗᎦᎴ ᎤᏂᏍᏆᎸᎡᎲᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏽‍🐰‍🧑🏻' => 'ᏴᏫ ᏥᏍᏚ ᏗᎦᎴ ᎤᏂᏍᏆᎸᎡᎲᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧑🏽‍🐰‍🧑🏼' => 'ᏴᏫ ᏥᏍᏚ ᏗᎦᎴ ᎤᏂᏍᏆᎸᎡᎲᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧑🏽‍🐰‍🧑🏾' => 'ᏴᏫ ᏥᏍᏚ ᏗᎦᎴ ᎤᏂᏍᏆᎸᎡᎲᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏽‍🐰‍🧑🏿' => 'ᏴᏫ ᏥᏍᏚ ᏗᎦᎴ ᎤᏂᏍᏆᎸᎡᎲᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏾‍🐰‍🧑🏻' => 'ᏴᏫ ᏥᏍᏚ ᏗᎦᎴ ᎤᏂᏍᏆᎸᎡᎲᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧑🏾‍🐰‍🧑🏼' => 'ᏴᏫ ᏥᏍᏚ ᏗᎦᎴ ᎤᏂᏍᏆᎸᎡᎲᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧑🏾‍🐰‍🧑🏽' => 'ᏴᏫ ᏥᏍᏚ ᏗᎦᎴ ᎤᏂᏍᏆᎸᎡᎲᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏾‍🐰‍🧑🏿' => 'ᏴᏫ ᏥᏍᏚ ᏗᎦᎴ ᎤᏂᏍᏆᎸᎡᎲᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏿‍🐰‍🧑🏻' => 'ᏴᏫ ᏥᏍᏚ ᏗᎦᎴ ᎤᏂᏍᏆᎸᎡᎲᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧑🏿‍🐰‍🧑🏼' => 'ᏴᏫ ᏥᏍᏚ ᏗᎦᎴ ᎤᏂᏍᏆᎸᎡᎲᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧑🏿‍🐰‍🧑🏽' => 'ᏴᏫ ᏥᏍᏚ ᏗᎦᎴ ᎤᏂᏍᏆᎸᎡᎲᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏿‍🐰‍🧑🏾' => 'ᏴᏫ ᏥᏍᏚ ᏗᎦᎴ ᎤᏂᏍᏆᎸᎡᎲᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏻‍🫯‍👨🏼' => 'ᎠᏂᏍᎦᏯ ᏓᏁᎯᎲ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👨🏻‍🫯‍👨🏽' => 'ᎠᏂᏍᎦᏯ ᏓᏁᎯᎲ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏻‍🫯‍👨🏾' => 'ᎠᏂᏍᎦᏯ ᏓᏁᎯᎲ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏻‍🫯‍👨🏿' => 'ᎠᏂᏍᎦᏯ ᏓᏁᎯᎲ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏼‍🫯‍👨🏻' => 'ᎠᏂᏍᎦᏯ ᏓᏁᎯᎲ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👨🏼‍🫯‍👨🏽' => 'ᎠᏂᏍᎦᏯ ᏓᏁᎯᎲ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏼‍🫯‍👨🏾' => 'ᎠᏂᏍᎦᏯ ᏓᏁᎯᎲ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏼‍🫯‍👨🏿' => 'ᎠᏂᏍᎦᏯ ᏓᏁᎯᎲ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏽‍🫯‍👨🏻' => 'ᎠᏂᏍᎦᏯ ᏓᏁᎯᎲ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👨🏽‍🫯‍👨🏼' => 'ᎠᏂᏍᎦᏯ ᏓᏁᎯᎲ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👨🏽‍🫯‍👨🏾' => 'ᎠᏂᏍᎦᏯ ᏓᏁᎯᎲ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏽‍🫯‍👨🏿' => 'ᎠᏂᏍᎦᏯ ᏓᏁᎯᎲ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏾‍🫯‍👨🏻' => 'ᎠᏂᏍᎦᏯ ᏓᏁᎯᎲ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👨🏾‍🫯‍👨🏼' => 'ᎠᏂᏍᎦᏯ ᏓᏁᎯᎲ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👨🏾‍🫯‍👨🏽' => 'ᎠᏂᏍᎦᏯ ᏓᏁᎯᎲ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏾‍🫯‍👨🏿' => 'ᎠᏂᏍᎦᏯ ᏓᏁᎯᎲ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏿‍🫯‍👨🏻' => 'ᎠᏂᏍᎦᏯ ᏓᏁᎯᎲ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👨🏿‍🫯‍👨🏼' => 'ᎠᏂᏍᎦᏯ ᏓᏁᎯᎲ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👨🏿‍🫯‍👨🏽' => 'ᎠᏂᏍᎦᏯ ᏓᏁᎯᎲ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏿‍🫯‍👨🏾' => 'ᎠᏂᏍᎦᏯ ᏓᏁᎯᎲ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏻‍❤‍👨🏻' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👨🏻‍❤‍👨🏼' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👨🏻‍❤‍👨🏽' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏻‍❤‍👨🏾' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏻‍❤‍👨🏿' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏼‍❤‍👨🏻' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👨🏼‍❤‍👨🏼' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👨🏼‍❤‍👨🏽' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏼‍❤‍👨🏾' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏼‍❤‍👨🏿' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏽‍❤‍👨🏻' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👨🏽‍❤‍👨🏼' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👨🏽‍❤‍👨🏽' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏽‍❤‍👨🏾' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏽‍❤‍👨🏿' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏾‍❤‍👨🏻' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👨🏾‍❤‍👨🏼' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👨🏾‍❤‍👨🏽' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏾‍❤‍👨🏾' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏾‍❤‍👨🏿' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏿‍❤‍👨🏻' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👨🏿‍❤‍👨🏼' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👨🏿‍❤‍👨🏽' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏿‍❤‍👨🏾' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏿‍❤‍👨🏿' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏻‍🐰‍👨🏼' => 'ᎠᏍᎦᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👨🏻‍🐰‍👨🏽' => 'ᎠᏍᎦᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏻‍🐰‍👨🏾' => 'ᎠᏍᎦᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏻‍🐰‍👨🏿' => 'ᎠᏍᎦᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏼‍🐰‍👨🏻' => 'ᎠᏍᎦᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👨🏼‍🐰‍👨🏽' => 'ᎠᏍᎦᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏼‍🐰‍👨🏾' => 'ᎠᏍᎦᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏼‍🐰‍👨🏿' => 'ᎠᏍᎦᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏽‍🐰‍👨🏻' => 'ᎠᏍᎦᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👨🏽‍🐰‍👨🏼' => 'ᎠᏍᎦᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👨🏽‍🐰‍👨🏾' => 'ᎠᏍᎦᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏽‍🐰‍👨🏿' => 'ᎠᏍᎦᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏾‍🐰‍👨🏻' => 'ᎠᏍᎦᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👨🏾‍🐰‍👨🏼' => 'ᎠᏍᎦᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👨🏾‍🐰‍👨🏽' => 'ᎠᏍᎦᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏾‍🐰‍👨🏿' => 'ᎠᏍᎦᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏿‍🐰‍👨🏻' => 'ᎠᏍᎦᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👨🏿‍🐰‍👨🏼' => 'ᎠᏍᎦᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👨🏿‍🐰‍👨🏽' => 'ᎠᏍᎦᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏿‍🐰‍👨🏾' => 'ᎠᏍᎦᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏻‍🫯‍👩🏼' => 'ᎠᎨᏯ ᏓᏁᎯᎲ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏻‍🫯‍👩🏽' => 'ᎠᎨᏯ ᏓᏁᎯᎲ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏻‍🫯‍👩🏾' => 'ᎠᎨᏯ ᏓᏁᎯᎲ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏻‍🫯‍👩🏿' => 'ᎠᎨᏯ ᏓᏁᎯᎲ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏼‍🫯‍👩🏻' => 'ᎠᎨᏯ ᏓᏁᎯᎲ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏼‍🫯‍👩🏽' => 'ᎠᎨᏯ ᏓᏁᎯᎲ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏼‍🫯‍👩🏾' => 'ᎠᎨᏯ ᏓᏁᎯᎲ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏼‍🫯‍👩🏿' => 'ᎠᎨᏯ ᏓᏁᎯᎲ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏽‍🫯‍👩🏻' => 'ᎠᎨᏯ ᏓᏁᎯᎲ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏽‍🫯‍👩🏼' => 'ᎠᎨᏯ ᏓᏁᎯᎲ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏽‍🫯‍👩🏾' => 'ᎠᎨᏯ ᏓᏁᎯᎲ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏽‍🫯‍👩🏿' => 'ᎠᎨᏯ ᏓᏁᎯᎲ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏾‍🫯‍👩🏻' => 'ᎠᎨᏯ ᏓᏁᎯᎲ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏾‍🫯‍👩🏼' => 'ᎠᎨᏯ ᏓᏁᎯᎲ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏾‍🫯‍👩🏽' => 'ᎠᎨᏯ ᏓᏁᎯᎲ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏾‍🫯‍👩🏿' => 'ᎠᎨᏯ ᏓᏁᎯᎲ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏿‍🫯‍👩🏻' => 'ᎠᎨᏯ ᏓᏁᎯᎲ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏿‍🫯‍👩🏼' => 'ᎠᎨᏯ ᏓᏁᎯᎲ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏿‍🫯‍👩🏽' => 'ᎠᎨᏯ ᏓᏁᎯᎲ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏿‍🫯‍👩🏾' => 'ᎠᎨᏯ ᏓᏁᎯᎲ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏻‍❤‍👨🏻' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏻‍❤‍👨🏼' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏻‍❤‍👨🏽' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏻‍❤‍👨🏾' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏻‍❤‍👨🏿' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏼‍❤‍👨🏻' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏼‍❤‍👨🏼' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏼‍❤‍👨🏽' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏼‍❤‍👨🏾' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏼‍❤‍👨🏿' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏽‍❤‍👨🏻' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏽‍❤‍👨🏼' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏽‍❤‍👨🏽' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏽‍❤‍👨🏾' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏽‍❤‍👨🏿' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏾‍❤‍👨🏻' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏾‍❤‍👨🏼' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏾‍❤‍👨🏽' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏾‍❤‍👨🏾' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏾‍❤‍👨🏿' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏿‍❤‍👨🏻' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏿‍❤‍👨🏼' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏿‍❤‍👨🏽' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏿‍❤‍👨🏾' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏿‍❤‍👨🏿' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᏍᎦᏯ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏻‍❤‍👩🏻' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᎨᏯ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏻‍❤‍👩🏼' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᎨᏯ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏻‍❤‍👩🏽' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᎨᏯ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏻‍❤‍👩🏾' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᎨᏯ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏻‍❤‍👩🏿' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᎨᏯ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏼‍❤‍👩🏻' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᎨᏯ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏼‍❤‍👩🏼' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᎨᏯ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏼‍❤‍👩🏽' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᎨᏯ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏼‍❤‍👩🏾' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᎨᏯ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏼‍❤‍👩🏿' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᎨᏯ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏽‍❤‍👩🏻' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᎨᏯ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏽‍❤‍👩🏼' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᎨᏯ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏽‍❤‍👩🏽' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᎨᏯ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏽‍❤‍👩🏾' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᎨᏯ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏽‍❤‍👩🏿' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᎨᏯ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏾‍❤‍👩🏻' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᎨᏯ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏾‍❤‍👩🏼' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᎨᏯ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏾‍❤‍👩🏽' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᎨᏯ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏾‍❤‍👩🏾' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᎨᏯ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏾‍❤‍👩🏿' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᎨᏯ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏿‍❤‍👩🏻' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᎨᏯ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏿‍❤‍👩🏼' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᎨᏯ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏿‍❤‍👩🏽' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᎨᏯ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏿‍❤‍👩🏾' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᎨᏯ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏿‍❤‍👩🏿' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᎨᏯ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏻‍🐰‍👩🏼' => 'ᎠᎨᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏻‍🐰‍👩🏽' => 'ᎠᎨᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏻‍🐰‍👩🏾' => 'ᎠᎨᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏻‍🐰‍👩🏿' => 'ᎠᎨᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏼‍🐰‍👩🏻' => 'ᎠᎨᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏼‍🐰‍👩🏽' => 'ᎠᎨᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏼‍🐰‍👩🏾' => 'ᎠᎨᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏼‍🐰‍👩🏿' => 'ᎠᎨᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏽‍🐰‍👩🏻' => 'ᎠᎨᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏽‍🐰‍👩🏼' => 'ᎠᎨᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏽‍🐰‍👩🏾' => 'ᎠᎨᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏽‍🐰‍👩🏿' => 'ᎠᎨᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏾‍🐰‍👩🏻' => 'ᎠᎨᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏾‍🐰‍👩🏼' => 'ᎠᎨᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏾‍🐰‍👩🏽' => 'ᎠᎨᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏾‍🐰‍👩🏿' => 'ᎠᎨᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏿‍🐰‍👩🏻' => 'ᎠᎨᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏿‍🐰‍👩🏼' => 'ᎠᎨᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏿‍🐰‍👩🏽' => 'ᎠᎨᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏿‍🐰‍👩🏾' => 'ᎠᎨᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏻‍🤝‍🧑🏻' => 'ᎠᏂᏴᏫ ᏚᎾᏙᏯᏂᎠ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧑🏻‍🤝‍🧑🏼' => 'ᎠᏂᏴᏫ ᏚᎾᏙᏯᏂᎠ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧑🏻‍🤝‍🧑🏽' => 'ᎠᏂᏴᏫ ᏚᎾᏙᏯᏂᎠ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏻‍🤝‍🧑🏾' => 'ᎠᏂᏴᏫ ᏚᎾᏙᏯᏂᎠ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏻‍🤝‍🧑🏿' => 'ᎠᏂᏴᏫ ᏚᎾᏙᏯᏂᎠ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏼‍🤝‍🧑🏻' => 'ᎠᏂᏴᏫ ᏚᎾᏙᏯᏂᎠ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧑🏼‍🤝‍🧑🏼' => 'ᎠᏂᏴᏫ ᏚᎾᏙᏯᏂᎠ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧑🏼‍🤝‍🧑🏽' => 'ᎠᏂᏴᏫ ᏚᎾᏙᏯᏂᎠ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏼‍🤝‍🧑🏾' => 'ᎠᏂᏴᏫ ᏚᎾᏙᏯᏂᎠ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏼‍🤝‍🧑🏿' => 'ᎠᏂᏴᏫ ᏚᎾᏙᏯᏂᎠ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏽‍🤝‍🧑🏻' => 'ᎠᏂᏴᏫ ᏚᎾᏙᏯᏂᎠ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧑🏽‍🤝‍🧑🏼' => 'ᎠᏂᏴᏫ ᏚᎾᏙᏯᏂᎠ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧑🏽‍🤝‍🧑🏽' => 'ᎠᏂᏴᏫ ᏚᎾᏙᏯᏂᎠ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏽‍🤝‍🧑🏾' => 'ᎠᏂᏴᏫ ᏚᎾᏙᏯᏂᎠ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏽‍🤝‍🧑🏿' => 'ᎠᏂᏴᏫ ᏚᎾᏙᏯᏂᎠ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏾‍🤝‍🧑🏻' => 'ᎠᏂᏴᏫ ᏚᎾᏙᏯᏂᎠ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧑🏾‍🤝‍🧑🏼' => 'ᎠᏂᏴᏫ ᏚᎾᏙᏯᏂᎠ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧑🏾‍🤝‍🧑🏽' => 'ᎠᏂᏴᏫ ᏚᎾᏙᏯᏂᎠ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏾‍🤝‍🧑🏾' => 'ᎠᏂᏴᏫ ᏚᎾᏙᏯᏂᎠ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏾‍🤝‍🧑🏿' => 'ᎠᏂᏴᏫ ᏚᎾᏙᏯᏂᎠ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏿‍🤝‍🧑🏻' => 'ᎠᏂᏴᏫ ᏚᎾᏙᏯᏂᎠ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧑🏿‍🤝‍🧑🏼' => 'ᎠᏂᏴᏫ ᏚᎾᏙᏯᏂᎠ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧑🏿‍🤝‍🧑🏽' => 'ᎠᏂᏴᏫ ᏚᎾᏙᏯᏂᎠ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏿‍🤝‍🧑🏾' => 'ᎠᏂᏴᏫ ᏚᎾᏙᏯᏂᎠ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏿‍🤝‍🧑🏿' => 'ᎠᏂᏴᏫ ᏚᎾᏙᏯᏂᎠ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏻‍🤝‍👩🏼' => 'ᎠᏂᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏻‍🤝‍👩🏽' => 'ᎠᏂᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏻‍🤝‍👩🏾' => 'ᎠᏂᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏻‍🤝‍👩🏿' => 'ᎠᏂᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏼‍🤝‍👩🏻' => 'ᎠᏂᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏼‍🤝‍👩🏽' => 'ᎠᏂᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏼‍🤝‍👩🏾' => 'ᎠᏂᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏼‍🤝‍👩🏿' => 'ᎠᏂᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏽‍🤝‍👩🏻' => 'ᎠᏂᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏽‍🤝‍👩🏼' => 'ᎠᏂᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏽‍🤝‍👩🏾' => 'ᎠᏂᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏽‍🤝‍👩🏿' => 'ᎠᏂᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏾‍🤝‍👩🏻' => 'ᎠᏂᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏾‍🤝‍👩🏼' => 'ᎠᏂᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏾‍🤝‍👩🏽' => 'ᎠᏂᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏾‍🤝‍👩🏿' => 'ᎠᏂᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏿‍🤝‍👩🏻' => 'ᎠᏂᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏿‍🤝‍👩🏼' => 'ᎠᏂᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏿‍🤝‍👩🏽' => 'ᎠᏂᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏿‍🤝‍👩🏾' => 'ᎠᏂᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏻‍🤝‍👨🏼' => 'ᎠᏍᎦᏯ ᎠᎴ ᎠᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏻‍🤝‍👨🏽' => 'ᎠᏍᎦᏯ ᎠᎴ ᎠᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏻‍🤝‍👨🏾' => 'ᎠᏍᎦᏯ ᎠᎴ ᎠᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏻‍🤝‍👨🏿' => 'ᎠᏍᎦᏯ ᎠᎴ ᎠᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏼‍🤝‍👨🏻' => 'ᎠᏍᎦᏯ ᎠᎴ ᎠᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏼‍🤝‍👨🏽' => 'ᎠᏍᎦᏯ ᎠᎴ ᎠᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏼‍🤝‍👨🏾' => 'ᎠᏍᎦᏯ ᎠᎴ ᎠᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏼‍🤝‍👨🏿' => 'ᎠᏍᎦᏯ ᎠᎴ ᎠᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏽‍🤝‍👨🏻' => 'ᎠᏍᎦᏯ ᎠᎴ ᎠᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏽‍🤝‍👨🏼' => 'ᎠᏍᎦᏯ ᎠᎴ ᎠᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏽‍🤝‍👨🏾' => 'ᎠᏍᎦᏯ ᎠᎴ ᎠᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏽‍🤝‍👨🏿' => 'ᎠᏍᎦᏯ ᎠᎴ ᎠᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏾‍🤝‍👨🏻' => 'ᎠᏍᎦᏯ ᎠᎴ ᎠᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏾‍🤝‍👨🏼' => 'ᎠᏍᎦᏯ ᎠᎴ ᎠᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏾‍🤝‍👨🏽' => 'ᎠᏍᎦᏯ ᎠᎴ ᎠᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏾‍🤝‍👨🏿' => 'ᎠᏍᎦᏯ ᎠᎴ ᎠᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏿‍🤝‍👨🏻' => 'ᎠᏍᎦᏯ ᎠᎴ ᎠᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏿‍🤝‍👨🏼' => 'ᎠᏍᎦᏯ ᎠᎴ ᎠᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏿‍🤝‍👨🏽' => 'ᎠᏍᎦᏯ ᎠᎴ ᎠᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏿‍🤝‍👨🏾' => 'ᎠᏍᎦᏯ ᎠᎴ ᎠᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏻‍🤝‍👨🏼' => 'ᎠᏂᏍᎦᏯ ᏚᎾᏙᏯᏂᎠᎩ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👨🏻‍🤝‍👨🏽' => 'ᎠᏂᏍᎦᏯ ᏚᎾᏙᏯᏂᎠᎩ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏻‍🤝‍👨🏾' => 'ᎠᏂᏍᎦᏯ ᏚᎾᏙᏯᏂᎠᎩ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏻‍🤝‍👨🏿' => 'ᎠᏂᏍᎦᏯ ᏚᎾᏙᏯᏂᎠᎩ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏼‍🤝‍👨🏻' => 'ᎠᏂᏍᎦᏯ ᏚᎾᏙᏯᏂᎠᎩ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👨🏼‍🤝‍👨🏽' => 'ᎠᏂᏍᎦᏯ ᏚᎾᏙᏯᏂᎠᎩ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏼‍🤝‍👨🏾' => 'ᎠᏂᏍᎦᏯ ᏚᎾᏙᏯᏂᎠᎩ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏼‍🤝‍👨🏿' => 'ᎠᏂᏍᎦᏯ ᏚᎾᏙᏯᏂᎠᎩ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏽‍🤝‍👨🏻' => 'ᎠᏂᏍᎦᏯ ᏚᎾᏙᏯᏂᎠᎩ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👨🏽‍🤝‍👨🏼' => 'ᎠᏂᏍᎦᏯ ᏚᎾᏙᏯᏂᎠᎩ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👨🏽‍🤝‍👨🏾' => 'ᎠᏂᏍᎦᏯ ᏚᎾᏙᏯᏂᎠᎩ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏽‍🤝‍👨🏿' => 'ᎠᏂᏍᎦᏯ ᏚᎾᏙᏯᏂᎠᎩ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏾‍🤝‍👨🏻' => 'ᎠᏂᏍᎦᏯ ᏚᎾᏙᏯᏂᎠᎩ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👨🏾‍🤝‍👨🏼' => 'ᎠᏂᏍᎦᏯ ᏚᎾᏙᏯᏂᎠᎩ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👨🏾‍🤝‍👨🏽' => 'ᎠᏂᏍᎦᏯ ᏚᎾᏙᏯᏂᎠᎩ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏾‍🤝‍👨🏿' => 'ᎠᏂᏍᎦᏯ ᏚᎾᏙᏯᏂᎠᎩ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏿‍🤝‍👨🏻' => 'ᎠᏂᏍᎦᏯ ᏚᎾᏙᏯᏂᎠᎩ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👨🏿‍🤝‍👨🏼' => 'ᎠᏂᏍᎦᏯ ᏚᎾᏙᏯᏂᎠᎩ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👨🏿‍🤝‍👨🏽' => 'ᎠᏂᏍᎦᏯ ᏚᎾᏙᏯᏂᎠᎩ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏿‍🤝‍👨🏾' => 'ᎠᏂᏍᎦᏯ ᏚᎾᏙᏯᏂᎠᎩ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩‍❤‍💋‍👨' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᏍᎦᏯ',
    '👨‍❤‍💋‍👨' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ',
    '👩‍❤‍💋‍👩' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᎨᏯ, ᎠᎨᏯ',
    '👨‍👩‍👧‍👦' => 'ᏏᏓᏁᎸᎢ: ᎠᏍᎦᏯ, ᎠᎨᏯ, ᎠᎨᏳᏣ, ᎠᏧᏣ',
    '👨‍👩‍👦‍👦' => 'ᏏᏓᏁᎸᎢ: ᎠᏍᎦᏯ, ᎠᎨᏯ, ᎠᏧᏣ, ᎠᏧᏣ',
    '👨‍👩‍👧‍👧' => 'ᏏᏓᏁᎸᎢ: ᎠᏍᎦᏯ, ᎠᎨᏯ, ᎠᎨᏳᏣ, ᎠᎨᏳᏣ',
    '👨‍👨‍👧‍👦' => 'ᏏᏓᏁᎸᎢ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎠᎨᏳᏣ, ᎠᏧᏣ',
    '👨‍👨‍👦‍👦' => 'ᏏᏓᏁᎸᎢ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎠᏧᏣ, ᎠᏧᏣ',
    '👨‍👨‍👧‍👧' => 'ᏏᏓᏁᎸᎢ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎠᎨᏳᏣ, ᎠᎨᏳᏣ',
    '👩‍👩‍👧‍👦' => 'ᏏᏓᏁᎸᎢ: ᎠᎨᏯ, ᎠᎨᏯ, ᎠᎨᏳᏣ, ᎠᏧᏣ',
    '👩‍👩‍👦‍👦' => 'ᏏᏓᏁᎸᎢ: ᎠᎨᏯ, ᎠᎨᏯ, ᎠᏧᏣ, ᎠᏧᏣ',
    '👩‍👩‍👧‍👧' => 'ᏏᏓᏁᎸᎢ: ᎠᎨᏯ, ᎠᎨᏯ, ᎠᎨᏳᏣ, ᎠᎨᏳᏣ',
    '🧑‍🧑‍🧒‍🧒' => 'ᏏᏓᏁᎸ: ᎠᏅᏓ, ᎠᏅᏓ, ᎠᏲᏟ, ᎠᏲᏟ',
    '🚶🏻‍♀‍➡' => 'ᎠᎨᏯ ᎠᏨᏏᏰ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🚶🏼‍♀‍➡' => 'ᎠᎨᏯ ᎠᏨᏏᏰ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🚶🏽‍♀‍➡' => 'ᎠᎨᏯ ᎠᏨᏏᏰ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🚶🏾‍♀‍➡' => 'ᎠᎨᏯ ᎠᏨᏏᏰ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🚶🏿‍♀‍➡' => 'ᎠᎨᏯ ᎠᏨᏏᏰ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🚶🏻‍♂‍➡' => 'ᎠᏍᎦᏯ ᎠᏨᏏᏰ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🚶🏼‍♂‍➡' => 'ᎠᏍᎦᏯ ᎠᏨᏏᏰ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🚶🏽‍♂‍➡' => 'ᎠᏍᎦᏯ ᎠᏨᏏᏰ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🚶🏾‍♂‍➡' => 'ᎠᏍᎦᏯ ᎠᏨᏏᏰ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🚶🏿‍♂‍➡' => 'ᎠᏍᎦᏯ ᎠᏨᏏᏰ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🧎🏻‍♀‍➡' => 'ᎠᎨᏯ ᏕᏥᎾᏆᎾ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🧎🏼‍♀‍➡' => 'ᎠᎨᏯ ᏕᏥᎾᏆᎾ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🧎🏽‍♀‍➡' => 'ᎠᎨᏯ ᏕᏥᎾᏆᎾ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🧎🏾‍♀‍➡' => 'ᎠᎨᏯ ᏕᏥᎾᏆᎾ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🧎🏿‍♀‍➡' => 'ᎠᎨᏯ ᏕᏥᎾᏆᎾ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🧎🏻‍♂‍➡' => 'ᎠᏍᎦᏯ ᏕᏥᎾᏆᎾ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🧎🏼‍♂‍➡' => 'ᎠᏍᎦᏯ ᏕᏥᎾᏆᎾ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🧎🏽‍♂‍➡' => 'ᎠᏍᎦᏯ ᏕᏥᎾᏆᎾ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🧎🏾‍♂‍➡' => 'ᎠᏍᎦᏯ ᏕᏥᎾᏆᎾ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🧎🏿‍♂‍➡' => 'ᎠᏍᎦᏯ ᏕᏥᎾᏆᎾ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🧑🏻‍🦯‍➡' => 'ᏴᏫ ᏗᎨᏫ ᎬᏂᏍᏓ ᎬᏗ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🧑🏼‍🦯‍➡' => 'ᏴᏫ ᏗᎨᏫ ᎬᏂᏍᏓ ᎬᏗ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🧑🏽‍🦯‍➡' => 'ᏴᏫ ᏗᎨᏫ ᎬᏂᏍᏓ ᎬᏗ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🧑🏾‍🦯‍➡' => 'ᏴᏫ ᏗᎨᏫ ᎬᏂᏍᏓ ᎬᏗ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🧑🏿‍🦯‍➡' => 'ᏴᏫ ᏗᎨᏫ ᎬᏂᏍᏓ ᎬᏗ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '👨🏻‍🦯‍➡' => 'ᎠᏍᎦᏯ ᏗᎨᏫ ᎦᏅᏍᏓ ᎬᏗ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '👨🏼‍🦯‍➡' => 'ᎠᏍᎦᏯ ᏗᎨᏫ ᎦᏅᏍᏓ ᎬᏗ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '👨🏽‍🦯‍➡' => 'ᎠᏍᎦᏯ ᏗᎨᏫ ᎦᏅᏍᏓ ᎬᏗ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '👨🏾‍🦯‍➡' => 'ᎠᏍᎦᏯ ᏗᎨᏫ ᎦᏅᏍᏓ ᎬᏗ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '👨🏿‍🦯‍➡' => 'ᎠᏍᎦᏯ ᏗᎨᏫ ᎦᏅᏍᏓ ᎬᏗ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '👩🏻‍🦯‍➡' => 'ᎠᎨᏯ ᏗᎨᏫ ᎦᏅᏍᏓ ᎬᏗ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '👩🏼‍🦯‍➡' => 'ᎠᎨᏯ ᏗᎨᏫ ᎦᏅᏍᏓ ᎬᏗ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '👩🏽‍🦯‍➡' => 'ᎠᎨᏯ ᏗᎨᏫ ᎦᏅᏍᏓ ᎬᏗ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '👩🏾‍🦯‍➡' => 'ᎠᎨᏯ ᏗᎨᏫ ᎦᏅᏍᏓ ᎬᏗ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '👩🏿‍🦯‍➡' => 'ᎠᎨᏯ ᏗᎨᏫ ᎦᏅᏍᏓ ᎬᏗ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🧑🏻‍🦼‍➡' => 'ᏴᏫ ᎠᎾᎦᎵᏍᎩ ᎦᏆᏘᏗ ᎦᏍᏗᎶ ᎬᏗ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🧑🏼‍🦼‍➡' => 'ᏴᏫ ᎠᎾᎦᎵᏍᎩ ᎦᏆᏘᏗ ᎦᏍᏗᎶ ᎬᏗ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🧑🏽‍🦼‍➡' => 'ᏴᏫ ᎠᎾᎦᎵᏍᎩ ᎦᏆᏘᏗ ᎦᏍᏗᎶ ᎬᏗ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🧑🏾‍🦼‍➡' => 'ᏴᏫ ᎠᎾᎦᎵᏍᎩ ᎦᏆᏘᏗ ᎦᏍᏗᎶ ᎬᏗ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🧑🏿‍🦼‍➡' => 'ᏴᏫ ᎠᎾᎦᎵᏍᎩ ᎦᏆᏘᏗ ᎦᏍᏗᎶ ᎬᏗ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '👨🏻‍🦼‍➡' => 'ᎠᏍᎦᏯ ᎬᏗ ᎠᏂᎩᏍᏗᏍᎩ ᎦᏆᏙᏗ ᎦᏍᎩᎶ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '👨🏼‍🦼‍➡' => 'ᎠᏍᎦᏯ ᎬᏗ ᎠᏂᎩᏍᏗᏍᎩ ᎦᏆᏙᏗ ᎦᏍᎩᎶ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '👨🏽‍🦼‍➡' => 'ᎠᏍᎦᏯ ᎬᏗ ᎠᏂᎩᏍᏗᏍᎩ ᎦᏆᏙᏗ ᎦᏍᎩᎶ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '👨🏾‍🦼‍➡' => 'ᎠᏍᎦᏯ ᎬᏗ ᎠᏂᎩᏍᏗᏍᎩ ᎦᏆᏙᏗ ᎦᏍᎩᎶ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '👨🏿‍🦼‍➡' => 'ᎠᏍᎦᏯ ᎬᏗ ᎠᏂᎩᏍᏗᏍᎩ ᎦᏆᏙᏗ ᎦᏍᎩᎶ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '👩🏻‍🦼‍➡' => 'ᎠᎨᏯ ᎬᏗ ᎠᏂᎩᏍᏗᏍᎩ ᎦᏆᏙᏗ ᎦᏍᎩᎶ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '👩🏼‍🦼‍➡' => 'ᎠᎨᏯ ᎬᏗ ᎠᏂᎩᏍᏗᏍᎩ ᎦᏆᏙᏗ ᎦᏍᎩᎶ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '👩🏽‍🦼‍➡' => 'ᎠᎨᏯ ᎬᏗ ᎠᏂᎩᏍᏗᏍᎩ ᎦᏆᏙᏗ ᎦᏍᎩᎶ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '👩🏾‍🦼‍➡' => 'ᎠᎨᏯ ᎬᏗ ᎠᏂᎩᏍᏗᏍᎩ ᎦᏆᏙᏗ ᎦᏍᎩᎶ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '👩🏿‍🦼‍➡' => 'ᎠᎨᏯ ᎬᏗ ᎠᏂᎩᏍᏗᏍᎩ ᎦᏆᏙᏗ ᎦᏍᎩᎶ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🧑🏻‍🦽‍➡' => 'ᏴᏫ ᎦᏆᏘᏗ ᎦᏍᎩᎶ ᎬᏗ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🧑🏼‍🦽‍➡' => 'ᏴᏫ ᎦᏆᏘᏗ ᎦᏍᎩᎶ ᎬᏗ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🧑🏽‍🦽‍➡' => 'ᏴᏫ ᎦᏆᏘᏗ ᎦᏍᎩᎶ ᎬᏗ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🧑🏾‍🦽‍➡' => 'ᏴᏫ ᎦᏆᏘᏗ ᎦᏍᎩᎶ ᎬᏗ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🧑🏿‍🦽‍➡' => 'ᏴᏫ ᎦᏆᏘᏗ ᎦᏍᎩᎶ ᎬᏗ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '👨🏻‍🦽‍➡' => 'ᎠᏍᎦᏯ ᎬᏗ ᎦᏆᏙᏗ ᎦᏍᎩᎶ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '👨🏼‍🦽‍➡' => 'ᎠᏍᎦᏯ ᎬᏗ ᎦᏆᏙᏗ ᎦᏍᎩᎶ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '👨🏽‍🦽‍➡' => 'ᎠᏍᎦᏯ ᎬᏗ ᎦᏆᏙᏗ ᎦᏍᎩᎶ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '👨🏾‍🦽‍➡' => 'ᎠᏍᎦᏯ ᎬᏗ ᎦᏆᏙᏗ ᎦᏍᎩᎶ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '👨🏿‍🦽‍➡' => 'ᎠᏍᎦᏯ ᎬᏗ ᎦᏆᏙᏗ ᎦᏍᎩᎶ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '👩🏻‍🦽‍➡' => 'ᎠᎨᏯ ᎬᏗ ᎦᏆᏙᏗ ᎦᏍᎩᎶ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '👩🏼‍🦽‍➡' => 'ᎠᎨᏯ ᎬᏗ ᎦᏆᏙᏗ ᎦᏍᎩᎶ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '👩🏽‍🦽‍➡' => 'ᎠᎨᏯ ᎬᏗ ᎦᏆᏙᏗ ᎦᏍᎩᎶ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '👩🏾‍🦽‍➡' => 'ᎠᎨᏯ ᎬᏗ ᎦᏆᏙᏗ ᎦᏍᎩᎶ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '👩🏿‍🦽‍➡' => 'ᎠᎨᏯ ᎬᏗ ᎦᏆᏙᏗ ᎦᏍᎩᎶ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🏃🏻‍♀‍➡' => 'ᎠᎨᏯ ᎠᏛᏟᏒᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🏃🏼‍♀‍➡' => 'ᎠᎨᏯ ᎠᏛᏟᏒᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🏃🏽‍♀‍➡' => 'ᎠᎨᏯ ᎠᏛᏟᏒᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🏃🏾‍♀‍➡' => 'ᎠᎨᏯ ᎠᏛᏟᏒᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🏃🏿‍♀‍➡' => 'ᎠᎨᏯ ᎠᏛᏟᏒᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🏃🏻‍♂‍➡' => 'ᎠᏍᎦᏯ ᎠᏛᏟᏒᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🏃🏼‍♂‍➡' => 'ᎠᏍᎦᏯ ᎠᏛᏟᏒᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🏃🏽‍♂‍➡' => 'ᎠᏍᎦᏯ ᎠᏛᏟᏒᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🏃🏾‍♂‍➡' => 'ᎠᏍᎦᏯ ᎠᏛᏟᏒᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🏃🏿‍♂‍➡' => 'ᎠᏍᎦᏯ ᎠᏛᏟᏒᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🫱🏻‍🫲🏼' => 'ᎠᏓᏲᎵᎲᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🫱🏻‍🫲🏽' => 'ᎠᏓᏲᎵᎲᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🫱🏻‍🫲🏾' => 'ᎠᏓᏲᎵᎲᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🫱🏻‍🫲🏿' => 'ᎠᏓᏲᎵᎲᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🫱🏼‍🫲🏻' => 'ᎠᏓᏲᎵᎲᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🫱🏼‍🫲🏽' => 'ᎠᏓᏲᎵᎲᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🫱🏼‍🫲🏾' => 'ᎠᏓᏲᎵᎲᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🫱🏼‍🫲🏿' => 'ᎠᏓᏲᎵᎲᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🫱🏽‍🫲🏻' => 'ᎠᏓᏲᎵᎲᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🫱🏽‍🫲🏼' => 'ᎠᏓᏲᎵᎲᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🫱🏽‍🫲🏾' => 'ᎠᏓᏲᎵᎲᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🫱🏽‍🫲🏿' => 'ᎠᏓᏲᎵᎲᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🫱🏾‍🫲🏻' => 'ᎠᏓᏲᎵᎲᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🫱🏾‍🫲🏼' => 'ᎠᏓᏲᎵᎲᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🫱🏾‍🫲🏽' => 'ᎠᏓᏲᎵᎲᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🫱🏾‍🫲🏿' => 'ᎠᏓᏲᎵᎲᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🫱🏿‍🫲🏻' => 'ᎠᏓᏲᎵᎲᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🫱🏿‍🫲🏼' => 'ᎠᏓᏲᎵᎲᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🫱🏿‍🫲🏽' => 'ᎠᏓᏲᎵᎲᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🫱🏿‍🫲🏾' => 'ᎠᏓᏲᎵᎲᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🚶‍♀‍➡' => 'ᎠᎨᏯ ᎠᏨᏏᏰ: ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🚶‍♂‍➡' => 'ᎠᏍᎦᏯ ᎠᏨᏏᏰ: ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🧎‍♀‍➡' => 'ᎠᎨᏯ ᏕᏥᎾᏆᎾ: ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🧎‍♂‍➡' => 'ᎠᏍᎦᏯ ᏕᏥᎾᏆᎾ: ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🧑‍🦯‍➡' => 'ᏴᏫ ᏗᎨᏫ ᎬᏂᏍᏓ ᎬᏗ: ᎠᎦᏘᏏ ᎢᏗᏢ',
    '👨‍🦯‍➡' => 'ᎠᏍᎦᏯ ᏗᎨᏫ ᎦᏅᏍᏓ ᎬᏗ: ᎠᎦᏘᏏ ᎢᏗᏢ',
    '👩‍🦯‍➡' => 'ᎠᎨᏯ ᏗᎨᏫ ᎦᏅᏍᏓ ᎬᏗ: ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🧑‍🦼‍➡' => 'ᏴᏫ ᎠᎾᎦᎵᏍᎩ ᎦᏆᏘᏗ ᎦᏍᏗᎶ ᎬᏗ: ᎠᎦᏘᏏ ᎢᏗᏢ',
    '👨‍🦼‍➡' => 'ᎠᏍᎦᏯ ᎬᏗ ᎠᏂᎩᏍᏗᏍᎩ ᎦᏆᏙᏗ ᎦᏍᎩᎶ: ᎠᎦᏘᏏ ᎢᏗᏢ',
    '👩‍🦼‍➡' => 'ᎠᎨᏯ ᎬᏗ ᎠᏂᎩᏍᏗᏍᎩ ᎦᏆᏙᏗ ᎦᏍᎩᎶ: ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🧑‍🦽‍➡' => 'ᏴᏫ ᎦᏆᏘᏗ ᎦᏍᎩᎶ ᎬᏗ: ᎠᎦᏘᏏ ᎢᏗᏢ',
    '👨‍🦽‍➡' => 'ᎠᏍᎦᏯ ᎬᏗ ᎦᏆᏙᏗ ᎦᏍᎩᎶ: ᎠᎦᏘᏏ ᎢᏗᏢ',
    '👩‍🦽‍➡' => 'ᎠᎨᏯ ᎬᏗ ᎦᏆᏙᏗ ᎦᏍᎩᎶ: ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🏃‍♀‍➡' => 'ᎠᎨᏯ ᎠᏛᏟᏒᎢ: ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🏃‍♂‍➡' => 'ᎠᏍᎦᏯ ᎠᏛᏟᏒᎢ: ᎠᎦᏘᏏ ᎢᏗᏢ',
    '👩‍❤‍👨' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᏍᎦᏯ',
    '👨‍❤‍👨' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ',
    '👩‍❤‍👩' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᎨᏯ, ᎠᎨᏯ',
    '👨‍👩‍👦' => 'ᏏᏓᏁᎸᎢ: ᎠᏍᎦᏯ, ᎠᎨᏯ, ᎠᏧᏣ',
    '👨‍👩‍👧' => 'ᏏᏓᏁᎸᎢ: ᎠᏍᎦᏯ, ᎠᎨᏯ, ᎠᎨᏳᏣ',
    '👨‍👨‍👦' => 'ᏏᏓᏁᎸᎢ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎠᏧᏣ',
    '👨‍👨‍👧' => 'ᏏᏓᏁᎸᎢ: ᎠᏍᎦᏯ, ᎠᏍᎦᏯ, ᎠᎨᏳᏣ',
    '👩‍👩‍👦' => 'ᏏᏓᏁᎸᎢ: ᎠᎨᏯ, ᎠᎨᏯ, ᎠᏧᏣ',
    '👩‍👩‍👧' => 'ᏏᏓᏁᎸᎢ: ᎠᎨᏯ, ᎠᎨᏯ, ᎠᎨᏳᏣ',
    '👨‍👦‍👦' => 'ᏏᏓᏁᎸᎢ: ᎠᏍᎦᏯ, ᎠᏧᏣ, ᎠᏧᏣ',
    '👨‍👧‍👦' => 'ᏏᏓᏁᎸᎢ: ᎠᏍᎦᏯ, ᎠᎨᏳᏣ, ᎠᏧᏣ',
    '👨‍👧‍👧' => 'ᏏᏓᏁᎸᎢ: ᎠᏍᎦᏯ, ᎠᎨᏳᏣ, ᎠᎨᏳᏣ',
    '👩‍👦‍👦' => 'ᏏᏓᏁᎸᎢ: ᎠᎨᏯ, ᎠᏧᏣ, ᎠᏧᏣ',
    '👩‍👧‍👦' => 'ᏏᏓᏁᎸᎢ: ᎠᎨᏯ, ᎠᎨᏳᏣ, ᎠᏧᏣ',
    '👩‍👧‍👧' => 'ᏏᏓᏁᎸᎢ: ᎠᎨᏯ, ᎠᎨᏳᏣ, ᎠᎨᏳᏣ',
    '🧑‍🤝‍🧑' => 'ᎠᏂᏴᏫ ᏚᎾᏙᏯᏂᎠ',
    '🧑‍🧑‍🧒' => 'ᏏᏓᏁᎸ: ᎠᏅᏓ, ᎠᏅᏓ, ᎠᏲᏟ',
    '🧑‍🧒‍🧒' => 'ᏏᏓᏁᎸ: ᎠᏅᏓ, ᎠᏲᏟ, ᎠᏲᏟ',
    '🧑🏻‍🦰' => 'ᎤᏔᎾ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎩᎦᎨ ᎤᏍᏘᎦ',
    '🧑🏼‍🦰' => 'ᎤᏔᎾ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎩᎦᎨ ᎤᏍᏘᎦ',
    '🧑🏽‍🦰' => 'ᎤᏔᎾ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎩᎦᎨ ᎤᏍᏘᎦ',
    '🧑🏾‍🦰' => 'ᎤᏔᎾ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎩᎦᎨ ᎤᏍᏘᎦ',
    '🧑🏿‍🦰' => 'ᎤᏔᎾ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎩᎦᎨ ᎤᏍᏘᎦ',
    '🧑🏻‍🦱' => 'ᎤᏔᎾ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎤᎵᏥᏍᏆᏁᏓ ᎤᏍᏘᎦ',
    '🧑🏼‍🦱' => 'ᎤᏔᎾ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎤᎵᏥᏍᏆᏁᏓ ᎤᏍᏘᎦ',
    '🧑🏽‍🦱' => 'ᎤᏔᎾ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎵᏥᏍᏆᏁᏓ ᎤᏍᏘᎦ',
    '🧑🏾‍🦱' => 'ᎤᏔᎾ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎵᏥᏍᏆᏁᏓ ᎤᏍᏘᎦ',
    '🧑🏿‍🦱' => 'ᎤᏔᎾ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎵᏥᏍᏆᏁᏓ ᎤᏍᏘᎦ',
    '🧑🏻‍🦳' => 'ᎤᏔᎾ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎤᏁᎦ ᎤᏍᏘᎦ',
    '🧑🏼‍🦳' => 'ᎤᏔᎾ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎤᏁᎦ ᎤᏍᏘᎦ',
    '🧑🏽‍🦳' => 'ᎤᏔᎾ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏁᎦ ᎤᏍᏘᎦ',
    '🧑🏾‍🦳' => 'ᎤᏔᎾ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏁᎦ ᎤᏍᏘᎦ',
    '🧑🏿‍🦳' => 'ᎤᏔᎾ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏁᎦ ᎤᏍᏘᎦ',
    '🧑🏻‍🦲' => 'ᎤᏔᎾ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎤᎨᏬᏗ',
    '🧑🏼‍🦲' => 'ᎤᏔᎾ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎤᎨᏬᏗ',
    '🧑🏽‍🦲' => 'ᎤᏔᎾ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎨᏬᏗ',
    '🧑🏾‍🦲' => 'ᎤᏔᎾ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎨᏬᏗ',
    '🧑🏿‍🦲' => 'ᎤᏔᎾ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎨᏬᏗ',
    '🧑🏻‍🩰' => 'ᏆᎴ ᎠᎵᏍᎩᏍᎩ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧑🏼‍🩰' => 'ᏆᎴ ᎠᎵᏍᎩᏍᎩ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧑🏽‍🩰' => 'ᏆᎴ ᎠᎵᏍᎩᏍᎩ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏾‍🩰' => 'ᏆᎴ ᎠᎵᏍᎩᏍᎩ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏿‍🩰' => 'ᏆᎴ ᎠᎵᏍᎩᏍᎩ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧔🏻‍♂' => 'ᎠᏍᎦᏯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᎭᏄᎸᏒ',
    '🧔🏼‍♂' => 'ᎠᏍᎦᏯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᎭᏄᎸᏒ',
    '🧔🏽‍♂' => 'ᎠᏍᎦᏯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎭᏄᎸᏒ',
    '🧔🏾‍♂' => 'ᎠᏍᎦᏯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎭᏄᎸᏒ',
    '🧔🏿‍♂' => 'ᎠᏍᎦᏯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎭᏄᎸᏒ',
    '👱🏻‍♂' => 'ᎠᏍᎦᏯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᏓᎶᏂᎨ ᎤᏍᏘᎩ',
    '👱🏼‍♂' => 'ᎠᏍᎦᏯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᏓᎶᏂᎨ ᎤᏍᏘᎩ',
    '👱🏽‍♂' => 'ᎠᏍᎦᏯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᏓᎶᏂᎨ ᎤᏍᏘᎩ',
    '👱🏾‍♂' => 'ᎠᏍᎦᏯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᏓᎶᏂᎨ ᎤᏍᏘᎩ',
    '👱🏿‍♂' => 'ᎠᏍᎦᏯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᏓᎶᏂᎨ ᎤᏍᏘᎩ',
    '👨🏻‍🦰' => 'ᎠᏍᎦᏯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎩᎦᎨ ᎤᏍᏘᎦ',
    '👨🏼‍🦰' => 'ᎠᏍᎦᏯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎩᎦᎨ ᎤᏍᏘᎦ',
    '👨🏽‍🦰' => 'ᎠᏍᎦᏯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎩᎦᎨ ᎤᏍᏘᎦ',
    '👨🏾‍🦰' => 'ᎠᏍᎦᏯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎩᎦᎨ ᎤᏍᏘᎦ',
    '👨🏿‍🦰' => 'ᎠᏍᎦᏯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎩᎦᎨ ᎤᏍᏘᎦ',
    '👨🏻‍🦱' => 'ᎠᏍᎦᏯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎤᎵᏥᏍᏆᏁᏓ ᎤᏍᏘᎦ',
    '👨🏼‍🦱' => 'ᎠᏍᎦᏯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎤᎵᏥᏍᏆᏁᏓ ᎤᏍᏘᎦ',
    '👨🏽‍🦱' => 'ᎠᏍᎦᏯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎵᏥᏍᏆᏁᏓ ᎤᏍᏘᎦ',
    '👨🏾‍🦱' => 'ᎠᏍᎦᏯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎵᏥᏍᏆᏁᏓ ᎤᏍᏘᎦ',
    '👨🏿‍🦱' => 'ᎠᏍᎦᏯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎵᏥᏍᏆᏁᏓ ᎤᏍᏘᎦ',
    '👨🏻‍🦳' => 'ᎠᏍᎦᏯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎤᏁᎦ ᎤᏍᏘᎦ',
    '👨🏼‍🦳' => 'ᎠᏍᎦᏯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎤᏁᎦ ᎤᏍᏘᎦ',
    '👨🏽‍🦳' => 'ᎠᏍᎦᏯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏁᎦ ᎤᏍᏘᎦ',
    '👨🏾‍🦳' => 'ᎠᏍᎦᏯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏁᎦ ᎤᏍᏘᎦ',
    '👨🏿‍🦳' => 'ᎠᏍᎦᏯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏁᎦ ᎤᏍᏘᎦ',
    '👨🏻‍🦲' => 'ᎠᏍᎦᏯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎤᎨᏬᏗ',
    '👨🏼‍🦲' => 'ᎠᏍᎦᏯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎤᎨᏬᏗ',
    '👨🏽‍🦲' => 'ᎠᏍᎦᏯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎨᏬᏗ',
    '👨🏾‍🦲' => 'ᎠᏍᎦᏯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎨᏬᏗ',
    '👨🏿‍🦲' => 'ᎠᏍᎦᏯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎨᏬᏗ',
    '🧔🏻‍♀' => 'ᎠᎨᏯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᎭᏄᎸᏒ',
    '🧔🏼‍♀' => 'ᎠᎨᏯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᎭᏄᎸᏒ',
    '🧔🏽‍♀' => 'ᎠᎨᏯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎭᏄᎸᏒ',
    '🧔🏾‍♀' => 'ᎠᎨᏯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎭᏄᎸᏒ',
    '🧔🏿‍♀' => 'ᎠᎨᏯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎭᏄᎸᏒ',
    '👱🏻‍♀' => 'ᎠᎨᏯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᏓᎶᏂᎨ ᎤᏍᏘᎩ',
    '👱🏼‍♀' => 'ᎠᎨᏯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᏓᎶᏂᎨ ᎤᏍᏘᎩ',
    '👱🏽‍♀' => 'ᎠᎨᏯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᏓᎶᏂᎨ ᎤᏍᏘᎩ',
    '👱🏾‍♀' => 'ᎠᎨᏯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᏓᎶᏂᎨ ᎤᏍᏘᎩ',
    '👱🏿‍♀' => 'ᎠᎨᏯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᏓᎶᏂᎨ ᎤᏍᏘᎩ',
    '👩🏻‍🦰' => 'ᎠᎨᏯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎩᎦᎨ ᎤᏍᏘᎦ',
    '👩🏼‍🦰' => 'ᎠᎨᏯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎩᎦᎨ ᎤᏍᏘᎦ',
    '👩🏽‍🦰' => 'ᎠᎨᏯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎩᎦᎨ ᎤᏍᏘᎦ',
    '👩🏾‍🦰' => 'ᎠᎨᏯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎩᎦᎨ ᎤᏍᏘᎦ',
    '👩🏿‍🦰' => 'ᎠᎨᏯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎩᎦᎨ ᎤᏍᏘᎦ',
    '👩🏻‍🦱' => 'ᎠᎨᏯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎤᎵᏥᏍᏆᏁᏓ ᎤᏍᏘᎦ',
    '👩🏼‍🦱' => 'ᎠᎨᏯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎤᎵᏥᏍᏆᏁᏓ ᎤᏍᏘᎦ',
    '👩🏽‍🦱' => 'ᎠᎨᏯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎵᏥᏍᏆᏁᏓ ᎤᏍᏘᎦ',
    '👩🏾‍🦱' => 'ᎠᎨᏯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎵᏥᏍᏆᏁᏓ ᎤᏍᏘᎦ',
    '👩🏿‍🦱' => 'ᎠᎨᏯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎵᏥᏍᏆᏁᏓ ᎤᏍᏘᎦ',
    '👩🏻‍🦳' => 'ᎠᎨᏯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎤᏁᎦ ᎤᏍᏘᎦ',
    '👩🏼‍🦳' => 'ᎠᎨᏯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎤᏁᎦ ᎤᏍᏘᎦ',
    '👩🏽‍🦳' => 'ᎠᎨᏯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏁᎦ ᎤᏍᏘᎦ',
    '👩🏾‍🦳' => 'ᎠᎨᏯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏁᎦ ᎤᏍᏘᎦ',
    '👩🏿‍🦳' => 'ᎠᎨᏯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᏁᎦ ᎤᏍᏘᎦ',
    '👩🏻‍🦲' => 'ᎠᎨᏯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎤᎨᏬᏗ',
    '👩🏼‍🦲' => 'ᎠᎨᏯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎤᎨᏬᏗ',
    '👩🏽‍🦲' => 'ᎠᎨᏯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎨᏬᏗ',
    '👩🏾‍🦲' => 'ᎠᎨᏯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎨᏬᏗ',
    '👩🏿‍🦲' => 'ᎠᎨᏯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎤᎨᏬᏗ',
    '🙍🏻‍♂' => 'ᎠᏍᎦᏯ ᎤᏓᏁᎪᏳᎭ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🙍🏼‍♂' => 'ᎠᏍᎦᏯ ᎤᏓᏁᎪᏳᎭ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🙍🏽‍♂' => 'ᎠᏍᎦᏯ ᎤᏓᏁᎪᏳᎭ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙍🏾‍♂' => 'ᎠᏍᎦᏯ ᎤᏓᏁᎪᏳᎭ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙍🏿‍♂' => 'ᎠᏍᎦᏯ ᎤᏓᏁᎪᏳᎭ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙍🏻‍♀' => 'ᎠᎨᏯ ᎤᏓᏁᎪᏳᎭ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🙍🏼‍♀' => 'ᎠᎨᏯ ᎤᏓᏁᎪᏳᎭ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🙍🏽‍♀' => 'ᎠᎨᏯ ᎤᏓᏁᎪᏳᎭ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙍🏾‍♀' => 'ᎠᎨᏯ ᎤᏓᏁᎪᏳᎭ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙍🏿‍♀' => 'ᎠᎨᏯ ᎤᏓᏁᎪᏳᎭ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙎🏻‍♂' => 'ᎠᏍᎦᏯ ᎤᏇᏟᎬ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🙎🏼‍♂' => 'ᎠᏍᎦᏯ ᎤᏇᏟᎬ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🙎🏽‍♂' => 'ᎠᏍᎦᏯ ᎤᏇᏟᎬ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙎🏾‍♂' => 'ᎠᏍᎦᏯ ᎤᏇᏟᎬ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙎🏿‍♂' => 'ᎠᏍᎦᏯ ᎤᏇᏟᎬ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙎🏻‍♀' => 'ᎠᎨᏯ ᎤᏇᏟᎬ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🙎🏼‍♀' => 'ᎠᎨᏯ ᎤᏇᏟᎬ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🙎🏽‍♀' => 'ᎠᎨᏯ ᎤᏇᏟᎬ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙎🏾‍♀' => 'ᎠᎨᏯ ᎤᏇᏟᎬ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙎🏿‍♀' => 'ᎠᎨᏯ ᎤᏇᏟᎬ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙅🏻‍♂' => 'ᎠᏍᎦᏯ ᏓᏐᏰᏍᎬ ᎥᏝ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🙅🏼‍♂' => 'ᎠᏍᎦᏯ ᏓᏐᏰᏍᎬ ᎥᏝ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🙅🏽‍♂' => 'ᎠᏍᎦᏯ ᏓᏐᏰᏍᎬ ᎥᏝ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙅🏾‍♂' => 'ᎠᏍᎦᏯ ᏓᏐᏰᏍᎬ ᎥᏝ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙅🏿‍♂' => 'ᎠᏍᎦᏯ ᏓᏐᏰᏍᎬ ᎥᏝ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙅🏻‍♀' => 'ᎠᎨᏯ ᏓᏐᏰᏍᎬ ᎥᏝ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🙅🏼‍♀' => 'ᎠᎨᏯ ᏓᏐᏰᏍᎬ ᎥᏝ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🙅🏽‍♀' => 'ᎠᎨᏯ ᏓᏐᏰᏍᎬ ᎥᏝ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙅🏾‍♀' => 'ᎠᎨᏯ ᏓᏐᏰᏍᎬ ᎥᏝ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙅🏿‍♀' => 'ᎠᎨᏯ ᏓᏐᏰᏍᎬ ᎥᏝ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙆🏻‍♂' => 'ᎠᏍᎦᏯ ᏓᏐᏰᏍᎬ ᎭᏩ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🙆🏼‍♂' => 'ᎠᏍᎦᏯ ᏓᏐᏰᏍᎬ ᎭᏩ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🙆🏽‍♂' => 'ᎠᏍᎦᏯ ᏓᏐᏰᏍᎬ ᎭᏩ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙆🏾‍♂' => 'ᎠᏍᎦᏯ ᏓᏐᏰᏍᎬ ᎭᏩ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙆🏿‍♂' => 'ᎠᏍᎦᏯ ᏓᏐᏰᏍᎬ ᎭᏩ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙆🏻‍♀' => 'ᎠᎨᏯ ᏓᏐᏰᏍᎬ ᎭᏩ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🙆🏼‍♀' => 'ᎠᎨᏯ ᏓᏐᏰᏍᎬ ᎭᏩ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🙆🏽‍♀' => 'ᎠᎨᏯ ᏓᏐᏰᏍᎬ ᎭᏩ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙆🏾‍♀' => 'ᎠᎨᏯ ᏓᏐᏰᏍᎬ ᎭᏩ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙆🏿‍♀' => 'ᎠᎨᏯ ᏓᏐᏰᏍᎬ ᎭᏩ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💁🏻‍♂' => 'ᎠᏍᎦᏯ ᎤᏘᏌᏗ ᎤᏬᏱ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '💁🏼‍♂' => 'ᎠᏍᎦᏯ ᎤᏘᏌᏗ ᎤᏬᏱ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '💁🏽‍♂' => 'ᎠᏍᎦᏯ ᎤᏘᏌᏗ ᎤᏬᏱ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💁🏾‍♂' => 'ᎠᏍᎦᏯ ᎤᏘᏌᏗ ᎤᏬᏱ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💁🏿‍♂' => 'ᎠᏍᎦᏯ ᎤᏘᏌᏗ ᎤᏬᏱ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💁🏻‍♀' => 'ᎠᎨᏯ ᎤᏘᏌᏗ ᎤᏬᏱ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '💁🏼‍♀' => 'ᎠᎨᏯ ᎤᏘᏌᏗ ᎤᏬᏱ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '💁🏽‍♀' => 'ᎠᎨᏯ ᎤᏘᏌᏗ ᎤᏬᏱ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💁🏾‍♀' => 'ᎠᎨᏯ ᎤᏘᏌᏗ ᎤᏬᏱ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💁🏿‍♀' => 'ᎠᎨᏯ ᎤᏘᏌᏗ ᎤᏬᏱ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙋🏻‍♂' => 'ᎠᏍᎦᏯ ᎤᏎᎵᏔ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🙋🏼‍♂' => 'ᎠᏍᎦᏯ ᎤᏎᎵᏔ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🙋🏽‍♂' => 'ᎠᏍᎦᏯ ᎤᏎᎵᏔ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙋🏾‍♂' => 'ᎠᏍᎦᏯ ᎤᏎᎵᏔ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙋🏿‍♂' => 'ᎠᏍᎦᏯ ᎤᏎᎵᏔ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙋🏻‍♀' => 'ᎠᎨᏯ ᎠᏌᎳᏗᏍᎬ ᎤᏬᏰᏂ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🙋🏼‍♀' => 'ᎠᎨᏯ ᎠᏌᎳᏗᏍᎬ ᎤᏬᏰᏂ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🙋🏽‍♀' => 'ᎠᎨᏯ ᎠᏌᎳᏗᏍᎬ ᎤᏬᏰᏂ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙋🏾‍♀' => 'ᎠᎨᏯ ᎠᏌᎳᏗᏍᎬ ᎤᏬᏰᏂ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙋🏿‍♀' => 'ᎠᎨᏯ ᎠᏌᎳᏗᏍᎬ ᎤᏬᏰᏂ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧏🏻‍♂' => 'ᏧᎵᎡᎾ ᎠᏍᎦᏯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧏🏼‍♂' => 'ᏧᎵᎡᎾ ᎠᏍᎦᏯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧏🏽‍♂' => 'ᏧᎵᎡᎾ ᎠᏍᎦᏯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧏🏾‍♂' => 'ᏧᎵᎡᎾ ᎠᏍᎦᏯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧏🏿‍♂' => 'ᏧᎵᎡᎾ ᎠᏍᎦᏯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧏🏻‍♀' => 'ᏧᎵᎡᎾ ᎠᎨᏯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧏🏼‍♀' => 'ᏧᎵᎡᎾ ᎠᎨᏯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧏🏽‍♀' => 'ᏧᎵᎡᎾ ᎠᎨᏯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧏🏾‍♀' => 'ᏧᎵᎡᎾ ᎠᎨᏯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧏🏿‍♀' => 'ᏧᎵᎡᎾ ᎠᎨᏯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙇🏻‍♂' => 'ᎠᏍᎦᏯ ᎤᏘᏌᏘ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🙇🏼‍♂' => 'ᎠᏍᎦᏯ ᎤᏘᏌᏘ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🙇🏽‍♂' => 'ᎠᏍᎦᏯ ᎤᏘᏌᏘ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙇🏾‍♂' => 'ᎠᏍᎦᏯ ᎤᏘᏌᏘ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙇🏿‍♂' => 'ᎠᏍᎦᏯ ᎤᏘᏌᏘ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙇🏻‍♀' => 'ᎠᎨᏯ ᎤᏘᏌᏘ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🙇🏼‍♀' => 'ᎠᎨᏯ ᎤᏘᏌᏘ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🙇🏽‍♀' => 'ᎠᎨᏯ ᎤᏘᏌᏘ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙇🏾‍♀' => 'ᎠᎨᏯ ᎤᏘᏌᏘ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙇🏿‍♀' => 'ᎠᎨᏯ ᎤᏘᏌᏘ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤦🏻‍♂' => 'ᎠᏍᎦᏯ ᎤᎧᏛᎢ ᎠᏓᏏᏔᏗᏍᎬᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🤦🏼‍♂' => 'ᎠᏍᎦᏯ ᎤᎧᏛᎢ ᎠᏓᏏᏔᏗᏍᎬᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🤦🏽‍♂' => 'ᎠᏍᎦᏯ ᎤᎧᏛᎢ ᎠᏓᏏᏔᏗᏍᎬᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤦🏾‍♂' => 'ᎠᏍᎦᏯ ᎤᎧᏛᎢ ᎠᏓᏏᏔᏗᏍᎬᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤦🏿‍♂' => 'ᎠᏍᎦᏯ ᎤᎧᏛᎢ ᎠᏓᏏᏔᏗᏍᎬᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤦🏻‍♀' => 'ᎠᎨᏯ ᎤᎧᏛᎢ ᎠᏓᏏᏔᏗᏍᎬᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🤦🏼‍♀' => 'ᎠᎨᏯ ᎤᎧᏛᎢ ᎠᏓᏏᏔᏗᏍᎬᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🤦🏽‍♀' => 'ᎠᎨᏯ ᎤᎧᏛᎢ ᎠᏓᏏᏔᏗᏍᎬᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤦🏾‍♀' => 'ᎠᎨᏯ ᎤᎧᏛᎢ ᎠᏓᏏᏔᏗᏍᎬᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤦🏿‍♀' => 'ᎠᎨᏯ ᎤᎧᏛᎢ ᎠᏓᏏᏔᏗᏍᎬᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤷🏻‍♂' => 'ᎠᏍᎦᏯ ᏗᎦᏅᏬ ᏚᏌᎳᏛ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🤷🏼‍♂' => 'ᎠᏍᎦᏯ ᏗᎦᏅᏬ ᏚᏌᎳᏛ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🤷🏽‍♂' => 'ᎠᏍᎦᏯ ᏗᎦᏅᏬ ᏚᏌᎳᏛ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤷🏾‍♂' => 'ᎠᏍᎦᏯ ᏗᎦᏅᏬ ᏚᏌᎳᏛ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤷🏿‍♂' => 'ᎠᏍᎦᏯ ᏗᎦᏅᏬ ᏚᏌᎳᏛ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤷🏻‍♀' => 'ᎠᎨᏯ ᏗᎦᏅᏬ ᏚᏌᎳᏛ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🤷🏼‍♀' => 'ᎠᎨᏯ ᏗᎦᏅᏬ ᏚᏌᎳᏛ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🤷🏽‍♀' => 'ᎠᎨᏯ ᏗᎦᏅᏬ ᏚᏌᎳᏛ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤷🏾‍♀' => 'ᎠᎨᏯ ᏗᎦᏅᏬ ᏚᏌᎳᏛ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤷🏿‍♀' => 'ᎠᎨᏯ ᏗᎦᏅᏬ ᏚᏌᎳᏛ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏻‍⚕' => 'ᏙᎯ ᏃᏛᎿᏕᎬᎢ ᏧᎸᏫᏍᏓᏁᎯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧑🏼‍⚕' => 'ᏙᎯ ᏃᏛᎿᏕᎬᎢ ᏧᎸᏫᏍᏓᏁᎯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧑🏽‍⚕' => 'ᏙᎯ ᏃᏛᎿᏕᎬᎢ ᏧᎸᏫᏍᏓᏁᎯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏾‍⚕' => 'ᏙᎯ ᏃᏛᎿᏕᎬᎢ ᏧᎸᏫᏍᏓᏁᎯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏿‍⚕' => 'ᏙᎯ ᏃᏛᎿᏕᎬᎢ ᏧᎸᏫᏍᏓᏁᎯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏻‍⚕' => 'ᎠᏍᎦᏯ ᏙᎯᏃᏛᎿᏕᎬᎢ ᎤᎦᏎᏍᏗ ᏧᎸᏫᏍᏓᏁᎯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👨🏼‍⚕' => 'ᎠᏍᎦᏯ ᏙᎯᏃᏛᎿᏕᎬᎢ ᎤᎦᏎᏍᏗ ᏧᎸᏫᏍᏓᏁᎯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👨🏽‍⚕' => 'ᎠᏍᎦᏯ ᏙᎯᏃᏛᎿᏕᎬᎢ ᎤᎦᏎᏍᏗ ᏧᎸᏫᏍᏓᏁᎯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏾‍⚕' => 'ᎠᏍᎦᏯ ᏙᎯᏃᏛᎿᏕᎬᎢ ᎤᎦᏎᏍᏗ ᏧᎸᏫᏍᏓᏁᎯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏿‍⚕' => 'ᎠᏍᎦᏯ ᏙᎯᏃᏛᎿᏕᎬᎢ ᎤᎦᏎᏍᏗ ᏧᎸᏫᏍᏓᏁᎯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏻‍⚕' => 'ᎠᎨᏯ ᏙᎯ ᏃᏛᎿᏕᎬᎢ ᏧᎸᏫᏍᏓᏁᎯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏼‍⚕' => 'ᎠᎨᏯ ᏙᎯ ᏃᏛᎿᏕᎬᎢ ᏧᎸᏫᏍᏓᏁᎯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏽‍⚕' => 'ᎠᎨᏯ ᏙᎯ ᏃᏛᎿᏕᎬᎢ ᏧᎸᏫᏍᏓᏁᎯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏾‍⚕' => 'ᎠᎨᏯ ᏙᎯ ᏃᏛᎿᏕᎬᎢ ᏧᎸᏫᏍᏓᏁᎯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏿‍⚕' => 'ᎠᎨᏯ ᏙᎯ ᏃᏛᎿᏕᎬᎢ ᏧᎸᏫᏍᏓᏁᎯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏻‍🎓' => 'ᏗᏕᎶᏆᏍᎩ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧑🏼‍🎓' => 'ᏗᏕᎶᏆᏍᎩ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧑🏽‍🎓' => 'ᏗᏕᎶᏆᏍᎩ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏾‍🎓' => 'ᏗᏕᎶᏆᏍᎩ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏿‍🎓' => 'ᏗᏕᎶᏆᏍᎩ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏻‍🎓' => 'ᎠᏍᎦᏯ ᏗᏕᎶᏆᏍᎩ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👨🏼‍🎓' => 'ᎠᏍᎦᏯ ᏗᏕᎶᏆᏍᎩ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👨🏽‍🎓' => 'ᎠᏍᎦᏯ ᏗᏕᎶᏆᏍᎩ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏾‍🎓' => 'ᎠᏍᎦᏯ ᏗᏕᎶᏆᏍᎩ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏿‍🎓' => 'ᎠᏍᎦᏯ ᏗᏕᎶᏆᏍᎩ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏻‍🎓' => 'ᎠᎨᏯ ᏗᏕᎶᏆᏍᎩ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏼‍🎓' => 'ᎠᎨᏯ ᏗᏕᎶᏆᏍᎩ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏽‍🎓' => 'ᎠᎨᏯ ᏗᏕᎶᏆᏍᎩ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏾‍🎓' => 'ᎠᎨᏯ ᏗᏕᎶᏆᏍᎩ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏿‍🎓' => 'ᎠᎨᏯ ᏗᏕᎶᏆᏍᎩ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏻‍🏫' => 'ᏗᏕᏲᎲᏍᎩ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧑🏼‍🏫' => 'ᏗᏕᏲᎲᏍᎩ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧑🏽‍🏫' => 'ᏗᏕᏲᎲᏍᎩ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏾‍🏫' => 'ᏗᏕᏲᎲᏍᎩ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏿‍🏫' => 'ᏗᏕᏲᎲᏍᎩ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏻‍🏫' => 'ᎠᏍᎦᏯ ᏗᏕᏲᎲᏍᎩ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👨🏼‍🏫' => 'ᎠᏍᎦᏯ ᏗᏕᏲᎲᏍᎩ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👨🏽‍🏫' => 'ᎠᏍᎦᏯ ᏗᏕᏲᎲᏍᎩ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏾‍🏫' => 'ᎠᏍᎦᏯ ᏗᏕᏲᎲᏍᎩ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏿‍🏫' => 'ᎠᏍᎦᏯ ᏗᏕᏲᎲᏍᎩ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏻‍🏫' => 'ᎠᎨᏯ ᏗᏕᏲᎲᏍᎩ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏼‍🏫' => 'ᎠᎨᏯ ᏗᏕᏲᎲᏍᎩ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏽‍🏫' => 'ᎠᎨᏯ ᏗᏕᏲᎲᏍᎩ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏾‍🏫' => 'ᎠᎨᏯ ᏗᏕᏲᎲᏍᎩ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏿‍🏫' => 'ᎠᎨᏯ ᏗᏕᏲᎲᏍᎩ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏻‍⚖' => 'ᏗᎫᎪᏗᏍᎩ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧑🏼‍⚖' => 'ᏗᎫᎪᏗᏍᎩ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧑🏽‍⚖' => 'ᏗᎫᎪᏗᏍᎩ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏾‍⚖' => 'ᏗᎫᎪᏗᏍᎩ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏿‍⚖' => 'ᏗᎫᎪᏗᏍᎩ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏻‍⚖' => 'ᎠᏍᎦᏯ ᏗᎫᎪᏗᏍᎩ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👨🏼‍⚖' => 'ᎠᏍᎦᏯ ᏗᎫᎪᏗᏍᎩ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👨🏽‍⚖' => 'ᎠᏍᎦᏯ ᏗᎫᎪᏗᏍᎩ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏾‍⚖' => 'ᎠᏍᎦᏯ ᏗᎫᎪᏗᏍᎩ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏿‍⚖' => 'ᎠᏍᎦᏯ ᏗᎫᎪᏗᏍᎩ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏻‍⚖' => 'ᎠᎨᏯ ᏗᎫᎪᏗᏍᎩ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏼‍⚖' => 'ᎠᎨᏯ ᏗᎫᎪᏗᏍᎩ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏽‍⚖' => 'ᎠᎨᏯ ᏗᎫᎪᏗᏍᎩ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏾‍⚖' => 'ᎠᎨᏯ ᏗᎫᎪᏗᏍᎩ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏿‍⚖' => 'ᎠᎨᏯ ᏗᎫᎪᏗᏍᎩ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏻‍🌾' => 'ᏗᎦᎶᎩᏍᎩ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧑🏼‍🌾' => 'ᏗᎦᎶᎩᏍᎩ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧑🏽‍🌾' => 'ᏗᎦᎶᎩᏍᎩ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏾‍🌾' => 'ᏗᎦᎶᎩᏍᎩ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏿‍🌾' => 'ᏗᎦᎶᎩᏍᎩ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏻‍🌾' => 'ᎠᏍᎦᏯ ᏗᎦᎶᎩᏍᎩ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👨🏼‍🌾' => 'ᎠᏍᎦᏯ ᏗᎦᎶᎩᏍᎩ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👨🏽‍🌾' => 'ᎠᏍᎦᏯ ᏗᎦᎶᎩᏍᎩ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏾‍🌾' => 'ᎠᏍᎦᏯ ᏗᎦᎶᎩᏍᎩ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏿‍🌾' => 'ᎠᏍᎦᏯ ᏗᎦᎶᎩᏍᎩ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏻‍🌾' => 'ᎠᎨᏯ ᏗᎦᎶᎩᏍᎩ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏼‍🌾' => 'ᎠᎨᏯ ᏗᎦᎶᎩᏍᎩ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏽‍🌾' => 'ᎠᎨᏯ ᏗᎦᎶᎩᏍᎩ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏾‍🌾' => 'ᎠᎨᏯ ᏗᎦᎶᎩᏍᎩ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏿‍🌾' => 'ᎠᎨᏯ ᏗᎦᎶᎩᏍᎩ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏻‍🍳' => 'ᏗᏓᏍᏓᏴᎲᏍᎩ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧑🏼‍🍳' => 'ᏗᏓᏍᏓᏴᎲᏍᎩ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧑🏽‍🍳' => 'ᏗᏓᏍᏓᏴᎲᏍᎩ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏾‍🍳' => 'ᏗᏓᏍᏓᏴᎲᏍᎩ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏿‍🍳' => 'ᏗᏓᏍᏓᏴᎲᏍᎩ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏻‍🍳' => 'ᎠᏍᎦᏯ ᎠᏓᏍᏓᏴᎲᏍᎦ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👨🏼‍🍳' => 'ᎠᏍᎦᏯ ᎠᏓᏍᏓᏴᎲᏍᎦ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👨🏽‍🍳' => 'ᎠᏍᎦᏯ ᎠᏓᏍᏓᏴᎲᏍᎦ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏾‍🍳' => 'ᎠᏍᎦᏯ ᎠᏓᏍᏓᏴᎲᏍᎦ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏿‍🍳' => 'ᎠᏍᎦᏯ ᎠᏓᏍᏓᏴᎲᏍᎦ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏻‍🍳' => 'ᎠᎨᏯ ᏗᏓᏍᏓᏴᎲᏍᎩ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏼‍🍳' => 'ᎠᎨᏯ ᏗᏓᏍᏓᏴᎲᏍᎩ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏽‍🍳' => 'ᎠᎨᏯ ᏗᏓᏍᏓᏴᎲᏍᎩ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏾‍🍳' => 'ᎠᎨᏯ ᏗᏓᏍᏓᏴᎲᏍᎩ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏿‍🍳' => 'ᎠᎨᏯ ᏗᏓᏍᏓᏴᎲᏍᎩ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏻‍🔧' => 'ᏙᏆᎴᎷ ᎣᏍᏓ ᏱᏗᎬᏁᎯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧑🏼‍🔧' => 'ᏙᏆᎴᎷ ᎣᏍᏓ ᏱᏗᎬᏁᎯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧑🏽‍🔧' => 'ᏙᏆᎴᎷ ᎣᏍᏓ ᏱᏗᎬᏁᎯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏾‍🔧' => 'ᏙᏆᎴᎷ ᎣᏍᏓ ᏱᏗᎬᏁᎯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏿‍🔧' => 'ᏙᏆᎴᎷ ᎣᏍᏓ ᏱᏗᎬᏁᎯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏻‍🔧' => 'ᎠᏍᎦᏯ ᏙᏆᎴᎷ ᏧᎸᏫᏍᏓᏁᎯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👨🏼‍🔧' => 'ᎠᏍᎦᏯ ᏙᏆᎴᎷ ᏧᎸᏫᏍᏓᏁᎯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👨🏽‍🔧' => 'ᎠᏍᎦᏯ ᏙᏆᎴᎷ ᏧᎸᏫᏍᏓᏁᎯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏾‍🔧' => 'ᎠᏍᎦᏯ ᏙᏆᎴᎷ ᏧᎸᏫᏍᏓᏁᎯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏿‍🔧' => 'ᎠᏍᎦᏯ ᏙᏆᎴᎷ ᏧᎸᏫᏍᏓᏁᎯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏻‍🔧' => 'ᎠᎨᏯ ᏙᏆᎴᎷ ᎣᏍᏓ ᏱᏗᎬᏁᎯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏼‍🔧' => 'ᎠᎨᏯ ᏙᏆᎴᎷ ᎣᏍᏓ ᏱᏗᎬᏁᎯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏽‍🔧' => 'ᎠᎨᏯ ᏙᏆᎴᎷ ᎣᏍᏓ ᏱᏗᎬᏁᎯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏾‍🔧' => 'ᎠᎨᏯ ᏙᏆᎴᎷ ᎣᏍᏓ ᏱᏗᎬᏁᎯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏿‍🔧' => 'ᎠᎨᏯ ᏙᏆᎴᎷ ᎣᏍᏓ ᏱᏗᎬᏁᎯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏻‍🏭' => 'ᏗᎦᎸᏫᏍᏓᏁᏗ ᏧᎸᏫᏍᏓᏁᎯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧑🏼‍🏭' => 'ᏗᎦᎸᏫᏍᏓᏁᏗ ᏧᎸᏫᏍᏓᏁᎯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧑🏽‍🏭' => 'ᏗᎦᎸᏫᏍᏓᏁᏗ ᏧᎸᏫᏍᏓᏁᎯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏾‍🏭' => 'ᏗᎦᎸᏫᏍᏓᏁᏗ ᏧᎸᏫᏍᏓᏁᎯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏿‍🏭' => 'ᏗᎦᎸᏫᏍᏓᏁᏗ ᏧᎸᏫᏍᏓᏁᎯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏻‍🏭' => 'ᎠᏍᎦᏯ ᎤᏃᏢᏅᏗ ᏧᎸᏫᏍᏓᏁᎯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👨🏼‍🏭' => 'ᎠᏍᎦᏯ ᎤᏃᏢᏅᏗ ᏧᎸᏫᏍᏓᏁᎯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👨🏽‍🏭' => 'ᎠᏍᎦᏯ ᎤᏃᏢᏅᏗ ᏧᎸᏫᏍᏓᏁᎯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏾‍🏭' => 'ᎠᏍᎦᏯ ᎤᏃᏢᏅᏗ ᏧᎸᏫᏍᏓᏁᎯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏿‍🏭' => 'ᎠᏍᎦᏯ ᎤᏃᏢᏅᏗ ᏧᎸᏫᏍᏓᏁᎯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏻‍🏭' => 'ᎠᎨᏯ ᏗᎦᎸᏫᏍᏓᏁᏗ ᏧᎸᏫᏍᏓᏁᎯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏼‍🏭' => 'ᎠᎨᏯ ᏗᎦᎸᏫᏍᏓᏁᏗ ᏧᎸᏫᏍᏓᏁᎯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏽‍🏭' => 'ᎠᎨᏯ ᏗᎦᎸᏫᏍᏓᏁᏗ ᏧᎸᏫᏍᏓᏁᎯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏾‍🏭' => 'ᎠᎨᏯ ᏗᎦᎸᏫᏍᏓᏁᏗ ᏧᎸᏫᏍᏓᏁᎯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏿‍🏭' => 'ᎠᎨᏯ ᏗᎦᎸᏫᏍᏓᏁᏗ ᏧᎸᏫᏍᏓᏁᎯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏻‍💼' => 'ᏗᎦᎸᏫᏍᏓᏁᏗᎢ ᏧᎸᏫᏍᏓᏁᎯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧑🏼‍💼' => 'ᏗᎦᎸᏫᏍᏓᏁᏗᎢ ᏧᎸᏫᏍᏓᏁᎯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧑🏽‍💼' => 'ᏗᎦᎸᏫᏍᏓᏁᏗᎢ ᏧᎸᏫᏍᏓᏁᎯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏾‍💼' => 'ᏗᎦᎸᏫᏍᏓᏁᏗᎢ ᏧᎸᏫᏍᏓᏁᎯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏿‍💼' => 'ᏗᎦᎸᏫᏍᏓᏁᏗᎢ ᏧᎸᏫᏍᏓᏁᎯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏻‍💼' => 'ᎠᏍᎦᏯ ᎤᏬᏟ ᏧᎸᏫᏍᏓᏁᎯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👨🏼‍💼' => 'ᎠᏍᎦᏯ ᎤᏬᏟ ᏧᎸᏫᏍᏓᏁᎯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👨🏽‍💼' => 'ᎠᏍᎦᏯ ᎤᏬᏟ ᏧᎸᏫᏍᏓᏁᎯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏾‍💼' => 'ᎠᏍᎦᏯ ᎤᏬᏟ ᏧᎸᏫᏍᏓᏁᎯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏿‍💼' => 'ᎠᏍᎦᏯ ᎤᏬᏟ ᏧᎸᏫᏍᏓᏁᎯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏻‍💼' => 'ᎠᎨᏯ ᏗᎦᎸᏫᏍᏓᏁᏗ ᏧᏄᏫᏍᏓᏁᎯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏼‍💼' => 'ᎠᎨᏯ ᏗᎦᎸᏫᏍᏓᏁᏗ ᏧᏄᏫᏍᏓᏁᎯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏽‍💼' => 'ᎠᎨᏯ ᏗᎦᎸᏫᏍᏓᏁᏗ ᏧᏄᏫᏍᏓᏁᎯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏾‍💼' => 'ᎠᎨᏯ ᏗᎦᎸᏫᏍᏓᏁᏗ ᏧᏄᏫᏍᏓᏁᎯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏿‍💼' => 'ᎠᎨᏯ ᏗᎦᎸᏫᏍᏓᏁᏗ ᏧᏄᏫᏍᏓᏁᎯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏻‍🔬' => 'ᎤᎦᏛᎲᏍᎩ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧑🏼‍🔬' => 'ᎤᎦᏛᎲᏍᎩ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧑🏽‍🔬' => 'ᎤᎦᏛᎲᏍᎩ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏾‍🔬' => 'ᎤᎦᏛᎲᏍᎩ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏿‍🔬' => 'ᎤᎦᏛᎲᏍᎩ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏻‍🔬' => 'ᎠᏍᎦᏯ ᎤᎦᏛᎲᏍᎩ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👨🏼‍🔬' => 'ᎠᏍᎦᏯ ᎤᎦᏛᎲᏍᎩ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👨🏽‍🔬' => 'ᎠᏍᎦᏯ ᎤᎦᏛᎲᏍᎩ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏾‍🔬' => 'ᎠᏍᎦᏯ ᎤᎦᏛᎲᏍᎩ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏿‍🔬' => 'ᎠᏍᎦᏯ ᎤᎦᏛᎲᏍᎩ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏻‍🔬' => 'ᎠᎨᏯ ᎤᎦᏛᎲᏍᎩ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏼‍🔬' => 'ᎠᎨᏯ ᎤᎦᏛᎲᏍᎩ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏽‍🔬' => 'ᎠᎨᏯ ᎤᎦᏛᎲᏍᎩ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏾‍🔬' => 'ᎠᎨᏯ ᎤᎦᏛᎲᏍᎩ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏿‍🔬' => 'ᎠᎨᏯ ᎤᎦᏛᎲᏍᎩ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏻‍💻' => 'ᎠᏏᎳᏕᏫᏒᎢ ᏧᎸᏫᏍᏓᏁᎯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧑🏼‍💻' => 'ᎠᏏᎳᏕᏫᏒᎢ ᏧᎸᏫᏍᏓᏁᎯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧑🏽‍💻' => 'ᎠᏏᎳᏕᏫᏒᎢ ᏧᎸᏫᏍᏓᏁᎯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏾‍💻' => 'ᎠᏏᎳᏕᏫᏒᎢ ᏧᎸᏫᏍᏓᏁᎯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏿‍💻' => 'ᎠᏏᎳᏕᏫᏒᎢ ᏧᎸᏫᏍᏓᏁᎯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏻‍💻' => 'ᎠᏍᎦᏯ ᏓᏏᎳᏕᏫᏒᎢ ᏧᎸᏫᏍᏓᏁᎯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👨🏼‍💻' => 'ᎠᏍᎦᏯ ᏓᏏᎳᏕᏫᏒᎢ ᏧᎸᏫᏍᏓᏁᎯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👨🏽‍💻' => 'ᎠᏍᎦᏯ ᏓᏏᎳᏕᏫᏒᎢ ᏧᎸᏫᏍᏓᏁᎯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏾‍💻' => 'ᎠᏍᎦᏯ ᏓᏏᎳᏕᏫᏒᎢ ᏧᎸᏫᏍᏓᏁᎯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏿‍💻' => 'ᎠᏍᎦᏯ ᏓᏏᎳᏕᏫᏒᎢ ᏧᎸᏫᏍᏓᏁᎯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏻‍💻' => 'ᎠᎨᏯ ᎠᏏᎳᏕᏫᏒᎢ ᏧᎸᏫᏍᏓᏁᎯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏼‍💻' => 'ᎠᎨᏯ ᎠᏏᎳᏕᏫᏒᎢ ᏧᎸᏫᏍᏓᏁᎯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏽‍💻' => 'ᎠᎨᏯ ᎠᏏᎳᏕᏫᏒᎢ ᏧᎸᏫᏍᏓᏁᎯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏾‍💻' => 'ᎠᎨᏯ ᎠᏏᎳᏕᏫᏒᎢ ᏧᎸᏫᏍᏓᏁᎯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏿‍💻' => 'ᎠᎨᏯ ᎠᏏᎳᏕᏫᏒᎢ ᏧᎸᏫᏍᏓᏁᎯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏻‍🎤' => 'ᏗᎧᏃᎩᏍᏗᏍᎩ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧑🏼‍🎤' => 'ᏗᎧᏃᎩᏍᏗᏍᎩ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧑🏽‍🎤' => 'ᏗᎧᏃᎩᏍᏗᏍᎩ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏾‍🎤' => 'ᏗᎧᏃᎩᏍᏗᏍᎩ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏿‍🎤' => 'ᏗᎧᏃᎩᏍᏗᏍᎩ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏻‍🎤' => 'ᎠᏍᎦᏯ ᏗᎧᏃᎩᏍᎩ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👨🏼‍🎤' => 'ᎠᏍᎦᏯ ᏗᎧᏃᎩᏍᎩ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👨🏽‍🎤' => 'ᎠᏍᎦᏯ ᏗᎧᏃᎩᏍᎩ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏾‍🎤' => 'ᎠᏍᎦᏯ ᏗᎧᏃᎩᏍᎩ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏿‍🎤' => 'ᎠᏍᎦᏯ ᏗᎧᏃᎩᏍᎩ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏻‍🎤' => 'ᎠᎨᏯ ᏗᎧᏃᎩᏍᎩ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏼‍🎤' => 'ᎠᎨᏯ ᏗᎧᏃᎩᏍᎩ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏽‍🎤' => 'ᎠᎨᏯ ᏗᎧᏃᎩᏍᎩ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏾‍🎤' => 'ᎠᎨᏯ ᏗᎧᏃᎩᏍᎩ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏿‍🎤' => 'ᎠᎨᏯ ᏗᎧᏃᎩᏍᎩ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏻‍🎨' => 'ᏗᏟᎶᏍᏗᏍᎩ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧑🏼‍🎨' => 'ᏗᏟᎶᏍᏗᏍᎩ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧑🏽‍🎨' => 'ᏗᏟᎶᏍᏗᏍᎩ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏾‍🎨' => 'ᏗᏟᎶᏍᏗᏍᎩ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏿‍🎨' => 'ᏗᏟᎶᏍᏗᏍᎩ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏻‍🎨' => 'ᎠᏍᎦᏯ ᏗᏑᏫᏍᎩ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👨🏼‍🎨' => 'ᎠᏍᎦᏯ ᏗᏑᏫᏍᎩ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👨🏽‍🎨' => 'ᎠᏍᎦᏯ ᏗᏑᏫᏍᎩ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏾‍🎨' => 'ᎠᏍᎦᏯ ᏗᏑᏫᏍᎩ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏿‍🎨' => 'ᎠᏍᎦᏯ ᏗᏑᏫᏍᎩ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏻‍🎨' => 'ᎠᎨᏯ ᏗᏟᎶᏍᏗᏍᎩ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏼‍🎨' => 'ᎠᎨᏯ ᏗᏟᎶᏍᏗᏍᎩ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏽‍🎨' => 'ᎠᎨᏯ ᏗᏟᎶᏍᏗᏍᎩ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏾‍🎨' => 'ᎠᎨᏯ ᏗᏟᎶᏍᏗᏍᎩ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏿‍🎨' => 'ᎠᎨᏯ ᏗᏟᎶᏍᏗᏍᎩ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏻‍✈' => 'ᏥᏳ ᎠᎲᎵᏙᎯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧑🏼‍✈' => 'ᏥᏳ ᎠᎲᎵᏙᎯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧑🏽‍✈' => 'ᏥᏳ ᎠᎲᎵᏙᎯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏾‍✈' => 'ᏥᏳ ᎠᎲᎵᏙᎯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏿‍✈' => 'ᏥᏳ ᎠᎲᎵᏙᎯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏻‍✈' => 'ᎠᏍᎦᏯ ᏥᏳ ᎧᏅᏫᏍᏗᏍᎩ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👨🏼‍✈' => 'ᎠᏍᎦᏯ ᏥᏳ ᎧᏅᏫᏍᏗᏍᎩ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👨🏽‍✈' => 'ᎠᏍᎦᏯ ᏥᏳ ᎧᏅᏫᏍᏗᏍᎩ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏾‍✈' => 'ᎠᏍᎦᏯ ᏥᏳ ᎧᏅᏫᏍᏗᏍᎩ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏿‍✈' => 'ᎠᏍᎦᏯ ᏥᏳ ᎧᏅᏫᏍᏗᏍᎩ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏻‍✈' => 'ᎠᎨᏯ ᏥᏳ ᎠᎲᎵᏙᎯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏼‍✈' => 'ᎠᎨᏯ ᏥᏳ ᎠᎲᎵᏙᎯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏽‍✈' => 'ᎠᎨᏯ ᏥᏳ ᎠᎲᎵᏙᎯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏾‍✈' => 'ᎠᎨᏯ ᏥᏳ ᎠᎲᎵᏙᎯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏿‍✈' => 'ᎠᎨᏯ ᏥᏳ ᎠᎲᎵᏙᎯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏻‍🚀' => 'ᎠᏝᏫᏗᏍᎩ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧑🏼‍🚀' => 'ᎠᏝᏫᏗᏍᎩ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧑🏽‍🚀' => 'ᎠᏝᏫᏗᏍᎩ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏾‍🚀' => 'ᎠᏝᏫᏗᏍᎩ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏿‍🚀' => 'ᎠᏝᏫᏗᏍᎩ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏻‍🚀' => 'ᎠᏍᎦᏯ ᎦᎸᎶᎯ ᎡᏙᎯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👨🏼‍🚀' => 'ᎠᏍᎦᏯ ᎦᎸᎶᎯ ᎡᏙᎯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👨🏽‍🚀' => 'ᎠᏍᎦᏯ ᎦᎸᎶᎯ ᎡᏙᎯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏾‍🚀' => 'ᎠᏍᎦᏯ ᎦᎸᎶᎯ ᎡᏙᎯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏿‍🚀' => 'ᎠᏍᎦᏯ ᎦᎸᎶᎯ ᎡᏙᎯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏻‍🚀' => 'ᎠᎨᏯ ᎦᎸᎶᎯ ᎡᏙᎯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏼‍🚀' => 'ᎠᎨᏯ ᎦᎸᎶᎯ ᎡᏙᎯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏽‍🚀' => 'ᎠᎨᏯ ᎦᎸᎶᎯ ᎡᏙᎯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏾‍🚀' => 'ᎠᎨᏯ ᎦᎸᎶᎯ ᎡᏙᎯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏿‍🚀' => 'ᎠᎨᏯ ᎦᎸᎶᎯ ᎡᏙᎯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏻‍🚒' => 'ᏗᎦᏝᏗᏍᎩ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧑🏼‍🚒' => 'ᏗᎦᏝᏗᏍᎩ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧑🏽‍🚒' => 'ᏗᎦᏝᏗᏍᎩ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏾‍🚒' => 'ᏗᎦᏝᏗᏍᎩ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏿‍🚒' => 'ᏗᎦᏝᏗᏍᎩ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏻‍🚒' => 'ᎠᏍᎦᏯ ᏗᎬᏝᏗᏍᎩ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👨🏼‍🚒' => 'ᎠᏍᎦᏯ ᏗᎬᏝᏗᏍᎩ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👨🏽‍🚒' => 'ᎠᏍᎦᏯ ᏗᎬᏝᏗᏍᎩ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏾‍🚒' => 'ᎠᏍᎦᏯ ᏗᎬᏝᏗᏍᎩ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏿‍🚒' => 'ᎠᏍᎦᏯ ᏗᎬᏝᏗᏍᎩ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏻‍🚒' => 'ᎠᎨᏯ ᏗᎦᏝᏗᏍᎩ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏼‍🚒' => 'ᎠᎨᏯ ᏗᎦᏝᏗᏍᎩ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏽‍🚒' => 'ᎠᎨᏯ ᏗᎦᏝᏗᏍᎩ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏾‍🚒' => 'ᎠᎨᏯ ᏗᎦᏝᏗᏍᎩ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏿‍🚒' => 'ᎠᎨᏯ ᏗᎦᏝᏗᏍᎩ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👮🏻‍♂' => 'ᎠᏍᎦᏯ ᏗᏓᏂᏱᏍᎩ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👮🏼‍♂' => 'ᎠᏍᎦᏯ ᏗᏓᏂᏱᏍᎩ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👮🏽‍♂' => 'ᎠᏍᎦᏯ ᏗᏓᏂᏱᏍᎩ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👮🏾‍♂' => 'ᎠᏍᎦᏯ ᏗᏓᏂᏱᏍᎩ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👮🏿‍♂' => 'ᎠᏍᎦᏯ ᏗᏓᏂᏱᏍᎩ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👮🏻‍♀' => 'ᎠᎨᏯ ᏗᏓᏂᏱᏍᎩ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👮🏼‍♀' => 'ᎠᎨᏯ ᏗᏓᏂᏱᏍᎩ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👮🏽‍♀' => 'ᎠᎨᏯ ᏗᏓᏂᏱᏍᎩ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👮🏾‍♀' => 'ᎠᎨᏯ ᏗᏓᏂᏱᏍᎩ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👮🏿‍♀' => 'ᎠᎨᏯ ᏗᏓᏂᏱᏍᎩ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🕵🏻‍♂' => 'ᎠᏍᎦᏯ ᎤᎦᏛᏂᏙᎯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🕵🏼‍♂' => 'ᎠᏍᎦᏯ ᎤᎦᏛᏂᏙᎯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🕵🏽‍♂' => 'ᎠᏍᎦᏯ ᎤᎦᏛᏂᏙᎯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🕵🏾‍♂' => 'ᎠᏍᎦᏯ ᎤᎦᏛᏂᏙᎯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🕵🏿‍♂' => 'ᎠᏍᎦᏯ ᎤᎦᏛᏂᏙᎯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🕵🏻‍♀' => 'ᎠᎨᏯ ᎤᎦᏛᏂᏙᎯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🕵🏼‍♀' => 'ᎠᎨᏯ ᎤᎦᏛᏂᏙᎯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🕵🏽‍♀' => 'ᎠᎨᏯ ᎤᎦᏛᏂᏙᎯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🕵🏾‍♀' => 'ᎠᎨᏯ ᎤᎦᏛᏂᏙᎯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🕵🏿‍♀' => 'ᎠᎨᏯ ᎤᎦᏛᏂᏙᎯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💂🏻‍♂' => 'ᎠᏍᎦᏯ ᎠᏯᏫᏍᎩ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '💂🏼‍♂' => 'ᎠᏍᎦᏯ ᎠᏯᏫᏍᎩ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '💂🏽‍♂' => 'ᎠᏍᎦᏯ ᎠᏯᏫᏍᎩ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💂🏾‍♂' => 'ᎠᏍᎦᏯ ᎠᏯᏫᏍᎩ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💂🏿‍♂' => 'ᎠᏍᎦᏯ ᎠᏯᏫᏍᎩ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💂🏻‍♀' => 'ᎠᎨᏯ ᎠᏯᏫᏍᎩ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '💂🏼‍♀' => 'ᎠᎨᏯ ᎠᏯᏫᏍᎩ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '💂🏽‍♀' => 'ᎠᎨᏯ ᎠᏯᏫᏍᎩ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💂🏾‍♀' => 'ᎠᎨᏯ ᎠᏯᏫᏍᎩ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💂🏿‍♀' => 'ᎠᎨᏯ ᎠᏯᏫᏍᎩ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👷🏻‍♂' => 'ᎠᏍᎦᏯ ᏗᏁᏍᎨᏍᎩ ᏧᎸᏫᏍᏓᏁᎯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👷🏼‍♂' => 'ᎠᏍᎦᏯ ᏗᏁᏍᎨᏍᎩ ᏧᎸᏫᏍᏓᏁᎯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👷🏽‍♂' => 'ᎠᏍᎦᏯ ᏗᏁᏍᎨᏍᎩ ᏧᎸᏫᏍᏓᏁᎯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👷🏾‍♂' => 'ᎠᏍᎦᏯ ᏗᏁᏍᎨᏍᎩ ᏧᎸᏫᏍᏓᏁᎯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👷🏿‍♂' => 'ᎠᏍᎦᏯ ᏗᏁᏍᎨᏍᎩ ᏧᎸᏫᏍᏓᏁᎯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👷🏻‍♀' => 'ᎠᎨᏯ ᏗᏁᏍᎨᏍᎩ ᏧᎸᏫᏍᏓᏁᎯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👷🏼‍♀' => 'ᎠᎨᏯ ᏗᏁᏍᎨᏍᎩ ᏧᎸᏫᏍᏓᏁᎯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👷🏽‍♀' => 'ᎠᎨᏯ ᏗᏁᏍᎨᏍᎩ ᏧᎸᏫᏍᏓᏁᎯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👷🏾‍♀' => 'ᎠᎨᏯ ᏗᏁᏍᎨᏍᎩ ᏧᎸᏫᏍᏓᏁᎯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👷🏿‍♀' => 'ᎠᎨᏯ ᏗᏁᏍᎨᏍᎩ ᏧᎸᏫᏍᏓᏁᎯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👳🏻‍♂' => 'ᎠᏍᎦᏯ ᎤᎵᏍᏚᎳ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👳🏼‍♂' => 'ᎠᏍᎦᏯ ᎤᎵᏍᏚᎳ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👳🏽‍♂' => 'ᎠᏍᎦᏯ ᎤᎵᏍᏚᎳ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👳🏾‍♂' => 'ᎠᏍᎦᏯ ᎤᎵᏍᏚᎳ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👳🏿‍♂' => 'ᎠᏍᎦᏯ ᎤᎵᏍᏚᎳ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👳🏻‍♀' => 'ᎠᎨᏯ ᎤᎵᏍᏚᎳ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👳🏼‍♀' => 'ᎠᎨᏯ ᎤᎵᏍᏚᎳ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👳🏽‍♀' => 'ᎠᎨᏯ ᎤᎵᏍᏚᎳ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👳🏾‍♀' => 'ᎠᎨᏯ ᎤᎵᏍᏚᎳ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👳🏿‍♀' => 'ᎠᎨᏯ ᎤᎵᏍᏚᎳ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤵🏻‍♂' => 'ᎠᏍᎦᏯ ᎤᏬᏚᎯ ᎤᏄᏩ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🤵🏼‍♂' => 'ᎠᏍᎦᏯ ᎤᏬᏚᎯ ᎤᏄᏩ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🤵🏽‍♂' => 'ᎠᏍᎦᏯ ᎤᏬᏚᎯ ᎤᏄᏩ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤵🏾‍♂' => 'ᎠᏍᎦᏯ ᎤᏬᏚᎯ ᎤᏄᏩ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤵🏿‍♂' => 'ᎠᏍᎦᏯ ᎤᏬᏚᎯ ᎤᏄᏩ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤵🏻‍♀' => 'ᎠᎨᏯ ᎤᏬᏚᎯ ᎤᏄᏩ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🤵🏼‍♀' => 'ᎠᎨᏯ ᎤᏬᏚᎯ ᎤᏄᏩ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🤵🏽‍♀' => 'ᎠᎨᏯ ᎤᏬᏚᎯ ᎤᏄᏩ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤵🏾‍♀' => 'ᎠᎨᏯ ᎤᏬᏚᎯ ᎤᏄᏩ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤵🏿‍♀' => 'ᎠᎨᏯ ᎤᏬᏚᎯ ᎤᏄᏩ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👰🏻‍♂' => 'ᎠᏍᎦᏯ ᎫᏝᎢ ᎤᎧᏛ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👰🏼‍♂' => 'ᎠᏍᎦᏯ ᎫᏝᎢ ᎤᎧᏛ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👰🏽‍♂' => 'ᎠᏍᎦᏯ ᎫᏝᎢ ᎤᎧᏛ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👰🏾‍♂' => 'ᎠᏍᎦᏯ ᎫᏝᎢ ᎤᎧᏛ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👰🏿‍♂' => 'ᎠᏍᎦᏯ ᎫᏝᎢ ᎤᎧᏛ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👰🏻‍♀' => 'ᎠᎨᏯ ᎫᏝᎢ ᎤᎧᏛ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👰🏼‍♀' => 'ᎠᎨᏯ ᎫᏝᎢ ᎤᎧᏛ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👰🏽‍♀' => 'ᎠᎨᏯ ᎫᏝᎢ ᎤᎧᏛ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👰🏾‍♀' => 'ᎠᎨᏯ ᎫᏝᎢ ᎤᎧᏛ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👰🏿‍♀' => 'ᎠᎨᏯ ᎫᏝᎢ ᎤᎧᏛ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏻‍🍼' => 'ᎠᎨᏯ ᏧᏓᏍᏓᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏼‍🍼' => 'ᎠᎨᏯ ᏧᏓᏍᏓᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏽‍🍼' => 'ᎠᎨᏯ ᏧᏓᏍᏓᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏾‍🍼' => 'ᎠᎨᏯ ᏧᏓᏍᏓᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏿‍🍼' => 'ᎠᎨᏯ ᏧᏓᏍᏓᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏻‍🍼' => 'ᎠᏍᎦᏯ ᏧᏓᏍᏓᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👨🏼‍🍼' => 'ᎠᏍᎦᏯ ᏧᏓᏍᏓᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👨🏽‍🍼' => 'ᎠᏍᎦᏯ ᏧᏓᏍᏓᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏾‍🍼' => 'ᎠᏍᎦᏯ ᏧᏓᏍᏓᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏿‍🍼' => 'ᎠᏍᎦᏯ ᏧᏓᏍᏓᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏻‍🍼' => 'ᏴᏫ ᏧᏓᏍᏓᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧑🏼‍🍼' => 'ᏴᏫ ᏧᏓᏍᏓᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧑🏽‍🍼' => 'ᏴᏫ ᏧᏓᏍᏓᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏾‍🍼' => 'ᏴᏫ ᏧᏓᏍᏓᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏿‍🍼' => 'ᏴᏫ ᏧᏓᏍᏓᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏻‍🎄' => 'ᏧᏠᏱ ᏧᏠᎦᎴᏓ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧑🏼‍🎄' => 'ᏧᏠᏱ ᏧᏠᎦᎴᏓ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧑🏽‍🎄' => 'ᏧᏠᏱ ᏧᏠᎦᎴᏓ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏾‍🎄' => 'ᏧᏠᏱ ᏧᏠᎦᎴᏓ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏿‍🎄' => 'ᏧᏠᏱ ᏧᏠᎦᎴᏓ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🦸🏻‍♂' => 'ᎠᏍᎦᏯ ᏄᎬᏫᏳᏒᎩ ᏩᏥᎸᏉᏛ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🦸🏼‍♂' => 'ᎠᏍᎦᏯ ᏄᎬᏫᏳᏒᎩ ᏩᏥᎸᏉᏛ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🦸🏽‍♂' => 'ᎠᏍᎦᏯ ᏄᎬᏫᏳᏒᎩ ᏩᏥᎸᏉᏛ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🦸🏾‍♂' => 'ᎠᏍᎦᏯ ᏄᎬᏫᏳᏒᎩ ᏩᏥᎸᏉᏛ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🦸🏿‍♂' => 'ᎠᏍᎦᏯ ᏄᎬᏫᏳᏒᎩ ᏩᏥᎸᏉᏛ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🦸🏻‍♀' => 'ᎠᎨᏯ ᏄᎬᏫᏳᏒᎩ ᏩᏥᎸᏉᏛ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🦸🏼‍♀' => 'ᎠᎨᏯ ᏄᎬᏫᏳᏒᎩ ᏩᏥᎸᏉᏛ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🦸🏽‍♀' => 'ᎠᎨᏯ ᏄᎬᏫᏳᏒᎩ ᏩᏥᎸᏉᏛ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🦸🏾‍♀' => 'ᎠᎨᏯ ᏄᎬᏫᏳᏒᎩ ᏩᏥᎸᏉᏛ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🦸🏿‍♀' => 'ᎠᎨᏯ ᏄᎬᏫᏳᏒᎩ ᏩᏥᎸᏉᏛ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🦹🏻‍♂' => 'ᎠᏍᎦᏯ ᏄᎬᏫᏳᏒᎩ ᎠᏍᎦᏂ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🦹🏼‍♂' => 'ᎠᏍᎦᏯ ᏄᎬᏫᏳᏒᎩ ᎠᏍᎦᏂ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🦹🏽‍♂' => 'ᎠᏍᎦᏯ ᏄᎬᏫᏳᏒᎩ ᎠᏍᎦᏂ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🦹🏾‍♂' => 'ᎠᏍᎦᏯ ᏄᎬᏫᏳᏒᎩ ᎠᏍᎦᏂ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🦹🏿‍♂' => 'ᎠᏍᎦᏯ ᏄᎬᏫᏳᏒᎩ ᎠᏍᎦᏂ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🦹🏻‍♀' => 'ᎠᎨᏯ ᏄᎬᏫᏳᏒᎩ ᎠᏍᎦᏂ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🦹🏼‍♀' => 'ᎠᎨᏯ ᏄᎬᏫᏳᏒᎩ ᎠᏍᎦᏂ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🦹🏽‍♀' => 'ᎠᎨᏯ ᏄᎬᏫᏳᏒᎩ ᎠᏍᎦᏂ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🦹🏾‍♀' => 'ᎠᎨᏯ ᏄᎬᏫᏳᏒᎩ ᎠᏍᎦᏂ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🦹🏿‍♀' => 'ᎠᎨᏯ ᏄᎬᏫᏳᏒᎩ ᎠᏍᎦᏂ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧙🏻‍♂' => 'ᎠᏍᎦᏯ ᎠᏓᏪ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧙🏼‍♂' => 'ᎠᏍᎦᏯ ᎠᏓᏪ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧙🏽‍♂' => 'ᎠᏍᎦᏯ ᎠᏓᏪ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧙🏾‍♂' => 'ᎠᏍᎦᏯ ᎠᏓᏪ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧙🏿‍♂' => 'ᎠᏍᎦᏯ ᎠᏓᏪ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧙🏻‍♀' => 'ᎠᎨᏯ ᎠᏓᏪ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧙🏼‍♀' => 'ᎠᎨᏯ ᎠᏓᏪ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧙🏽‍♀' => 'ᎠᎨᏯ ᎠᏓᏪ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧙🏾‍♀' => 'ᎠᎨᏯ ᎠᏓᏪ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧙🏿‍♀' => 'ᎠᎨᏯ ᎠᏓᏪ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧚🏻‍♂' => 'ᎠᏍᎦᏯ ᏴᏫ ᎤᏍᏗ ᎦᏃᎯᎵᏙᎯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧚🏼‍♂' => 'ᎠᏍᎦᏯ ᏴᏫ ᎤᏍᏗ ᎦᏃᎯᎵᏙᎯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧚🏽‍♂' => 'ᎠᏍᎦᏯ ᏴᏫ ᎤᏍᏗ ᎦᏃᎯᎵᏙᎯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧚🏾‍♂' => 'ᎠᏍᎦᏯ ᏴᏫ ᎤᏍᏗ ᎦᏃᎯᎵᏙᎯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧚🏿‍♂' => 'ᎠᏍᎦᏯ ᏴᏫ ᎤᏍᏗ ᎦᏃᎯᎵᏙᎯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧚🏻‍♀' => 'ᎠᎨᏯ ᏴᏫ ᎤᏍᏗ ᎦᏃᎯᎵᏙᎯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧚🏼‍♀' => 'ᎠᎨᏯ ᏴᏫ ᎤᏍᏗ ᎦᏃᎯᎵᏙᎯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧚🏽‍♀' => 'ᎠᎨᏯ ᏴᏫ ᎤᏍᏗ ᎦᏃᎯᎵᏙᎯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧚🏾‍♀' => 'ᎠᎨᏯ ᏴᏫ ᎤᏍᏗ ᎦᏃᎯᎵᏙᎯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧚🏿‍♀' => 'ᎠᎨᏯ ᏴᏫ ᎤᏍᏗ ᎦᏃᎯᎵᏙᎯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧛🏻‍♂' => 'ᎠᏍᎦᏯ ᎩᎦ ᎠᏓᏁᎩᏛᎯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧛🏼‍♂' => 'ᎠᏍᎦᏯ ᎩᎦ ᎠᏓᏁᎩᏛᎯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧛🏽‍♂' => 'ᎠᏍᎦᏯ ᎩᎦ ᎠᏓᏁᎩᏛᎯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧛🏾‍♂' => 'ᎠᏍᎦᏯ ᎩᎦ ᎠᏓᏁᎩᏛᎯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧛🏿‍♂' => 'ᎠᏍᎦᏯ ᎩᎦ ᎠᏓᏁᎩᏛᎯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧛🏻‍♀' => 'ᎠᎨᏯ ᎩᎦ ᎠᏓᏁᎩᎡᎯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧛🏼‍♀' => 'ᎠᎨᏯ ᎩᎦ ᎠᏓᏁᎩᎡᎯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧛🏽‍♀' => 'ᎠᎨᏯ ᎩᎦ ᎠᏓᏁᎩᎡᎯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧛🏾‍♀' => 'ᎠᎨᏯ ᎩᎦ ᎠᏓᏁᎩᎡᎯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧛🏿‍♀' => 'ᎠᎨᏯ ᎩᎦ ᎠᏓᏁᎩᎡᎯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧜🏻‍♂' => 'ᎠᏍᎦᏯ ᎠᏣᏗ ᎤᎬᎭᏟ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧜🏼‍♂' => 'ᎠᏍᎦᏯ ᎠᏣᏗ ᎤᎬᎭᏟ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧜🏽‍♂' => 'ᎠᏍᎦᏯ ᎠᏣᏗ ᎤᎬᎭᏟ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧜🏾‍♂' => 'ᎠᏍᎦᏯ ᎠᏣᏗ ᎤᎬᎭᏟ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧜🏿‍♂' => 'ᎠᏍᎦᏯ ᎠᏣᏗ ᎤᎬᎭᏟ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧜🏻‍♀' => 'ᎠᎨᏯ ᎠᏣᏗ ᎤᎬᎭᏟ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧜🏼‍♀' => 'ᎠᎨᏯ ᎠᏣᏗ ᎤᎬᎭᏟ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧜🏽‍♀' => 'ᎠᎨᏯ ᎠᏣᏗ ᎤᎬᎭᏟ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧜🏾‍♀' => 'ᎠᎨᏯ ᎠᏣᏗ ᎤᎬᎭᏟ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧜🏿‍♀' => 'ᎠᎨᏯ ᎠᏣᏗ ᎤᎬᎭᏟ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧝🏻‍♂' => 'ᎠᏍᎦᏯ ᏴᏫ ᎢᏳᏍᏗ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧝🏼‍♂' => 'ᎠᏍᎦᏯ ᏴᏫ ᎢᏳᏍᏗ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧝🏽‍♂' => 'ᎠᏍᎦᏯ ᏴᏫ ᎢᏳᏍᏗ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧝🏾‍♂' => 'ᎠᏍᎦᏯ ᏴᏫ ᎢᏳᏍᏗ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧝🏿‍♂' => 'ᎠᏍᎦᏯ ᏴᏫ ᎢᏳᏍᏗ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧝🏻‍♀' => 'ᎠᎨᏯ ᏴᏫ ᎢᏳᏍᏗ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧝🏼‍♀' => 'ᎠᎨᏯ ᏴᏫ ᎢᏳᏍᏗ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧝🏽‍♀' => 'ᎠᎨᏯ ᏴᏫ ᎢᏳᏍᏗ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧝🏾‍♀' => 'ᎠᎨᏯ ᏴᏫ ᎢᏳᏍᏗ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧝🏿‍♀' => 'ᎠᎨᏯ ᏴᏫ ᎢᏳᏍᏗ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💆🏻‍♂' => 'ᎠᏍᎦᏯ ᎠᏥᏍᎪᎵᏰᏍᎬᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '💆🏼‍♂' => 'ᎠᏍᎦᏯ ᎠᏥᏍᎪᎵᏰᏍᎬᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '💆🏽‍♂' => 'ᎠᏍᎦᏯ ᎠᏥᏍᎪᎵᏰᏍᎬᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💆🏾‍♂' => 'ᎠᏍᎦᏯ ᎠᏥᏍᎪᎵᏰᏍᎬᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💆🏿‍♂' => 'ᎠᏍᎦᏯ ᎠᏥᏍᎪᎵᏰᏍᎬᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💆🏻‍♀' => 'ᎠᎨᏯ ᎠᏥᏍᎪᎵᏰᏍᎬᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '💆🏼‍♀' => 'ᎠᎨᏯ ᎠᏥᏍᎪᎵᏰᏍᎬᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '💆🏽‍♀' => 'ᎠᎨᏯ ᎠᏥᏍᎪᎵᏰᏍᎬᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💆🏾‍♀' => 'ᎠᎨᏯ ᎠᏥᏍᎪᎵᏰᏍᎬᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💆🏿‍♀' => 'ᎠᎨᏯ ᎠᏥᏍᎪᎵᏰᏍᎬᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💇🏻‍♂' => 'ᎠᏍᎦᏯ ᎠᏥᏍᏙᏰᏍᎬᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '💇🏼‍♂' => 'ᎠᏍᎦᏯ ᎠᏥᏍᏙᏰᏍᎬᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '💇🏽‍♂' => 'ᎠᏍᎦᏯ ᎠᏥᏍᏙᏰᏍᎬᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💇🏾‍♂' => 'ᎠᏍᎦᏯ ᎠᏥᏍᏙᏰᏍᎬᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💇🏿‍♂' => 'ᎠᏍᎦᏯ ᎠᏥᏍᏙᏰᏍᎬᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💇🏻‍♀' => 'ᎠᎨᏯ ᎠᏥᏍᏙᏰᏍᎬᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '💇🏼‍♀' => 'ᎠᎨᏯ ᎠᏥᏍᏙᏰᏍᎬᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '💇🏽‍♀' => 'ᎠᎨᏯ ᎠᏥᏍᏙᏰᏍᎬᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💇🏾‍♀' => 'ᎠᎨᏯ ᎠᏥᏍᏙᏰᏍᎬᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💇🏿‍♀' => 'ᎠᎨᏯ ᎠᏥᏍᏙᏰᏍᎬᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🚶🏻‍♂' => 'ᎠᏍᎦᏯ ᎠᏨᏏᏰ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🚶🏼‍♂' => 'ᎠᏍᎦᏯ ᎠᏨᏏᏰ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🚶🏽‍♂' => 'ᎠᏍᎦᏯ ᎠᏨᏏᏰ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🚶🏾‍♂' => 'ᎠᏍᎦᏯ ᎠᏨᏏᏰ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🚶🏿‍♂' => 'ᎠᏍᎦᏯ ᎠᏨᏏᏰ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🚶🏻‍♀' => 'ᎠᎨᏯ ᎠᏨᏏᏰ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🚶🏼‍♀' => 'ᎠᎨᏯ ᎠᏨᏏᏰ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🚶🏽‍♀' => 'ᎠᎨᏯ ᎠᏨᏏᏰ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🚶🏾‍♀' => 'ᎠᎨᏯ ᎠᏨᏏᏰ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🚶🏿‍♀' => 'ᎠᎨᏯ ᎠᏨᏏᏰ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🚶🏻‍➡' => 'ᏴᏫ ᎠᏨᏏᏰ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🚶🏼‍➡' => 'ᏴᏫ ᎠᏨᏏᏰ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🚶🏽‍➡' => 'ᏴᏫ ᎠᏨᏏᏰ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🚶🏾‍➡' => 'ᏴᏫ ᎠᏨᏏᏰ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🚶🏿‍➡' => 'ᏴᏫ ᎠᏨᏏᏰ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🧍🏻‍♂' => 'ᎠᏍᎦᏯ ᎦᏙᎦ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧍🏼‍♂' => 'ᎠᏍᎦᏯ ᎦᏙᎦ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧍🏽‍♂' => 'ᎠᏍᎦᏯ ᎦᏙᎦ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧍🏾‍♂' => 'ᎠᏍᎦᏯ ᎦᏙᎦ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧍🏿‍♂' => 'ᎠᏍᎦᏯ ᎦᏙᎦ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧍🏻‍♀' => 'ᎠᎨᏯ ᎦᏙᎦ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧍🏼‍♀' => 'ᎠᎨᏯ ᎦᏙᎦ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧍🏽‍♀' => 'ᎠᎨᏯ ᎦᏙᎦ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧍🏾‍♀' => 'ᎠᎨᏯ ᎦᏙᎦ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧍🏿‍♀' => 'ᎠᎨᏯ ᎦᏙᎦ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧎🏻‍♂' => 'ᎠᏍᎦᏯ ᏕᏥᎾᏆᎾ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧎🏼‍♂' => 'ᎠᏍᎦᏯ ᏕᏥᎾᏆᎾ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧎🏽‍♂' => 'ᎠᏍᎦᏯ ᏕᏥᎾᏆᎾ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧎🏾‍♂' => 'ᎠᏍᎦᏯ ᏕᏥᎾᏆᎾ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧎🏿‍♂' => 'ᎠᏍᎦᏯ ᏕᏥᎾᏆᎾ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧎🏻‍♀' => 'ᎠᎨᏯ ᏕᏥᎾᏆᎾ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧎🏼‍♀' => 'ᎠᎨᏯ ᏕᏥᎾᏆᎾ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧎🏽‍♀' => 'ᎠᎨᏯ ᏕᏥᎾᏆᎾ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧎🏾‍♀' => 'ᎠᎨᏯ ᏕᏥᎾᏆᎾ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧎🏿‍♀' => 'ᎠᎨᏯ ᏕᏥᎾᏆᎾ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧎🏻‍➡' => 'ᏴᏫ ᏕᏥᎾᏆᎾ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🧎🏼‍➡' => 'ᏴᏫ ᏕᏥᎾᏆᎾ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🧎🏽‍➡' => 'ᏴᏫ ᏕᏥᎾᏆᎾ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🧎🏾‍➡' => 'ᏴᏫ ᏕᏥᎾᏆᎾ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🧎🏿‍➡' => 'ᏴᏫ ᏕᏥᎾᏆᎾ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🧑🏻‍🦯' => 'ᏴᏫ ᏗᎨᏫ ᎬᏂᏍᏓ ᎬᏗ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧑🏼‍🦯' => 'ᏴᏫ ᏗᎨᏫ ᎬᏂᏍᏓ ᎬᏗ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧑🏽‍🦯' => 'ᏴᏫ ᏗᎨᏫ ᎬᏂᏍᏓ ᎬᏗ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏾‍🦯' => 'ᏴᏫ ᏗᎨᏫ ᎬᏂᏍᏓ ᎬᏗ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏿‍🦯' => 'ᏴᏫ ᏗᎨᏫ ᎬᏂᏍᏓ ᎬᏗ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏻‍🦯' => 'ᎠᏍᎦᏯ ᏗᎨᏫ ᎦᏅᏍᏓ ᎬᏗ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👨🏼‍🦯' => 'ᎠᏍᎦᏯ ᏗᎨᏫ ᎦᏅᏍᏓ ᎬᏗ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👨🏽‍🦯' => 'ᎠᏍᎦᏯ ᏗᎨᏫ ᎦᏅᏍᏓ ᎬᏗ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏾‍🦯' => 'ᎠᏍᎦᏯ ᏗᎨᏫ ᎦᏅᏍᏓ ᎬᏗ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏿‍🦯' => 'ᎠᏍᎦᏯ ᏗᎨᏫ ᎦᏅᏍᏓ ᎬᏗ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏻‍🦯' => 'ᎠᎨᏯ ᏗᎨᏫ ᎦᏅᏍᏓ ᎬᏗ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏼‍🦯' => 'ᎠᎨᏯ ᏗᎨᏫ ᎦᏅᏍᏓ ᎬᏗ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏽‍🦯' => 'ᎠᎨᏯ ᏗᎨᏫ ᎦᏅᏍᏓ ᎬᏗ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏾‍🦯' => 'ᎠᎨᏯ ᏗᎨᏫ ᎦᏅᏍᏓ ᎬᏗ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏿‍🦯' => 'ᎠᎨᏯ ᏗᎨᏫ ᎦᏅᏍᏓ ᎬᏗ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏻‍🦼' => 'ᏴᏫ ᎠᎾᎦᎵᏍᎩ ᎦᏆᏘᏗ ᎦᏍᏗᎶ ᎬᏗ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧑🏼‍🦼' => 'ᏴᏫ ᎠᎾᎦᎵᏍᎩ ᎦᏆᏘᏗ ᎦᏍᏗᎶ ᎬᏗ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧑🏽‍🦼' => 'ᏴᏫ ᎠᎾᎦᎵᏍᎩ ᎦᏆᏘᏗ ᎦᏍᏗᎶ ᎬᏗ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏾‍🦼' => 'ᏴᏫ ᎠᎾᎦᎵᏍᎩ ᎦᏆᏘᏗ ᎦᏍᏗᎶ ᎬᏗ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏿‍🦼' => 'ᏴᏫ ᎠᎾᎦᎵᏍᎩ ᎦᏆᏘᏗ ᎦᏍᏗᎶ ᎬᏗ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏻‍🦼' => 'ᎠᏍᎦᏯ ᎬᏗ ᎠᏂᎩᏍᏗᏍᎩ ᎦᏆᏙᏗ ᎦᏍᎩᎶ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👨🏼‍🦼' => 'ᎠᏍᎦᏯ ᎬᏗ ᎠᏂᎩᏍᏗᏍᎩ ᎦᏆᏙᏗ ᎦᏍᎩᎶ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👨🏽‍🦼' => 'ᎠᏍᎦᏯ ᎬᏗ ᎠᏂᎩᏍᏗᏍᎩ ᎦᏆᏙᏗ ᎦᏍᎩᎶ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏾‍🦼' => 'ᎠᏍᎦᏯ ᎬᏗ ᎠᏂᎩᏍᏗᏍᎩ ᎦᏆᏙᏗ ᎦᏍᎩᎶ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏿‍🦼' => 'ᎠᏍᎦᏯ ᎬᏗ ᎠᏂᎩᏍᏗᏍᎩ ᎦᏆᏙᏗ ᎦᏍᎩᎶ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏻‍🦼' => 'ᎠᎨᏯ ᎬᏗ ᎠᏂᎩᏍᏗᏍᎩ ᎦᏆᏙᏗ ᎦᏍᎩᎶ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏼‍🦼' => 'ᎠᎨᏯ ᎬᏗ ᎠᏂᎩᏍᏗᏍᎩ ᎦᏆᏙᏗ ᎦᏍᎩᎶ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏽‍🦼' => 'ᎠᎨᏯ ᎬᏗ ᎠᏂᎩᏍᏗᏍᎩ ᎦᏆᏙᏗ ᎦᏍᎩᎶ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏾‍🦼' => 'ᎠᎨᏯ ᎬᏗ ᎠᏂᎩᏍᏗᏍᎩ ᎦᏆᏙᏗ ᎦᏍᎩᎶ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏿‍🦼' => 'ᎠᎨᏯ ᎬᏗ ᎠᏂᎩᏍᏗᏍᎩ ᎦᏆᏙᏗ ᎦᏍᎩᎶ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏻‍🦽' => 'ᏴᏫ ᎦᏆᏘᏗ ᎦᏍᎩᎶ ᎬᏗ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧑🏼‍🦽' => 'ᏴᏫ ᎦᏆᏘᏗ ᎦᏍᎩᎶ ᎬᏗ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧑🏽‍🦽' => 'ᏴᏫ ᎦᏆᏘᏗ ᎦᏍᎩᎶ ᎬᏗ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏾‍🦽' => 'ᏴᏫ ᎦᏆᏘᏗ ᎦᏍᎩᎶ ᎬᏗ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏿‍🦽' => 'ᏴᏫ ᎦᏆᏘᏗ ᎦᏍᎩᎶ ᎬᏗ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏻‍🦽' => 'ᎠᏍᎦᏯ ᎬᏗ ᎦᏆᏙᏗ ᎦᏍᎩᎶ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👨🏼‍🦽' => 'ᎠᏍᎦᏯ ᎬᏗ ᎦᏆᏙᏗ ᎦᏍᎩᎶ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👨🏽‍🦽' => 'ᎠᏍᎦᏯ ᎬᏗ ᎦᏆᏙᏗ ᎦᏍᎩᎶ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏾‍🦽' => 'ᎠᏍᎦᏯ ᎬᏗ ᎦᏆᏙᏗ ᎦᏍᎩᎶ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏿‍🦽' => 'ᎠᏍᎦᏯ ᎬᏗ ᎦᏆᏙᏗ ᎦᏍᎩᎶ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏻‍🦽' => 'ᎠᎨᏯ ᎬᏗ ᎦᏆᏙᏗ ᎦᏍᎩᎶ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏼‍🦽' => 'ᎠᎨᏯ ᎬᏗ ᎦᏆᏙᏗ ᎦᏍᎩᎶ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏽‍🦽' => 'ᎠᎨᏯ ᎬᏗ ᎦᏆᏙᏗ ᎦᏍᎩᎶ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏾‍🦽' => 'ᎠᎨᏯ ᎬᏗ ᎦᏆᏙᏗ ᎦᏍᎩᎶ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏿‍🦽' => 'ᎠᎨᏯ ᎬᏗ ᎦᏆᏙᏗ ᎦᏍᎩᎶ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏃🏻‍♂' => 'ᎠᏍᎦᏯ ᎠᏛᏟᏒᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🏃🏼‍♂' => 'ᎠᏍᎦᏯ ᎠᏛᏟᏒᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🏃🏽‍♂' => 'ᎠᏍᎦᏯ ᎠᏛᏟᏒᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏃🏾‍♂' => 'ᎠᏍᎦᏯ ᎠᏛᏟᏒᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏃🏿‍♂' => 'ᎠᏍᎦᏯ ᎠᏛᏟᏒᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏃🏻‍♀' => 'ᎠᎨᏯ ᎠᏛᏟᏒᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🏃🏼‍♀' => 'ᎠᎨᏯ ᎠᏛᏟᏒᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🏃🏽‍♀' => 'ᎠᎨᏯ ᎠᏛᏟᏒᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏃🏾‍♀' => 'ᎠᎨᏯ ᎠᏛᏟᏒᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏃🏿‍♀' => 'ᎠᎨᏯ ᎠᏛᏟᏒᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏃🏻‍➡' => 'ᏴᏫ ᎠᏛᏟᏒᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🏃🏼‍➡' => 'ᏴᏫ ᎠᏛᏟᏒᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🏃🏽‍➡' => 'ᏴᏫ ᎠᏛᏟᏒᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🏃🏾‍➡' => 'ᏴᏫ ᎠᏛᏟᏒᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🏃🏿‍➡' => 'ᏴᏫ ᎠᏛᏟᏒᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᎠᎦᏘᏏ ᎢᏗᏢ',
    '👯🏻‍♀' => 'ᎠᎨᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👯🏼‍♀' => 'ᎠᎨᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👯🏽‍♀' => 'ᎠᎨᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👯🏾‍♀' => 'ᎠᎨᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👯🏿‍♀' => 'ᎠᎨᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👯🏻‍♂' => 'ᎠᏍᎦᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👯🏼‍♂' => 'ᎠᏍᎦᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👯🏽‍♂' => 'ᎠᏍᎦᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👯🏾‍♂' => 'ᎠᏍᎦᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👯🏿‍♂' => 'ᎠᏍᎦᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧖🏻‍♂' => 'ᎠᏍᎦᏯ ᎠᏯᎠ ᎠᏔᎶᎴᎬ ᎧᏅᏑᎸ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧖🏼‍♂' => 'ᎠᏍᎦᏯ ᎠᏯᎠ ᎠᏔᎶᎴᎬ ᎧᏅᏑᎸ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧖🏽‍♂' => 'ᎠᏍᎦᏯ ᎠᏯᎠ ᎠᏔᎶᎴᎬ ᎧᏅᏑᎸ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧖🏾‍♂' => 'ᎠᏍᎦᏯ ᎠᏯᎠ ᎠᏔᎶᎴᎬ ᎧᏅᏑᎸ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧖🏿‍♂' => 'ᎠᏍᎦᏯ ᎠᏯᎠ ᎠᏔᎶᎴᎬ ᎧᏅᏑᎸ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧖🏻‍♀' => 'ᎠᎨᏯ ᎠᏯᎠ ᎠᏔᎶᎴᎬ ᎧᏅᏑᎸ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧖🏼‍♀' => 'ᎠᎨᏯ ᎠᏯᎠ ᎠᏔᎶᎴᎬ ᎧᏅᏑᎸ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧖🏽‍♀' => 'ᎠᎨᏯ ᎠᏯᎠ ᎠᏔᎶᎴᎬ ᎧᏅᏑᎸ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧖🏾‍♀' => 'ᎠᎨᏯ ᎠᏯᎠ ᎠᏔᎶᎴᎬ ᎧᏅᏑᎸ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧖🏿‍♀' => 'ᎠᎨᏯ ᎠᏯᎠ ᎠᏔᎶᎴᎬ ᎧᏅᏑᎸ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧗🏻‍♂' => 'ᎠᏍᎦᏯ ᎦᎵᏙᎭ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧗🏼‍♂' => 'ᎠᏍᎦᏯ ᎦᎵᏙᎭ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧗🏽‍♂' => 'ᎠᏍᎦᏯ ᎦᎵᏙᎭ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧗🏾‍♂' => 'ᎠᏍᎦᏯ ᎦᎵᏙᎭ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧗🏿‍♂' => 'ᎠᏍᎦᏯ ᎦᎵᏙᎭ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧗🏻‍♀' => 'ᎠᎨᏯ ᎦᎵᏙᎭ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧗🏼‍♀' => 'ᎠᎨᏯ ᎦᎵᏙᎭ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧗🏽‍♀' => 'ᎠᎨᏯ ᎦᎵᏙᎭ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧗🏾‍♀' => 'ᎠᎨᏯ ᎦᎵᏙᎭ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧗🏿‍♀' => 'ᎠᎨᏯ ᎦᎵᏙᎭ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏌🏻‍♂' => 'ᎠᏍᎦᏯ ᎪᏍᏛᏂᎲᎢ ᏍᏆᏞᏍᏗ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🏌🏼‍♂' => 'ᎠᏍᎦᏯ ᎪᏍᏛᏂᎲᎢ ᏍᏆᏞᏍᏗ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🏌🏽‍♂' => 'ᎠᏍᎦᏯ ᎪᏍᏛᏂᎲᎢ ᏍᏆᏞᏍᏗ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏌🏾‍♂' => 'ᎠᏍᎦᏯ ᎪᏍᏛᏂᎲᎢ ᏍᏆᏞᏍᏗ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏌🏿‍♂' => 'ᎠᏍᎦᏯ ᎪᏍᏛᏂᎲᎢ ᏍᏆᏞᏍᏗ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏌🏻‍♀' => 'ᎠᎨᏯ ᎪᏍᏛᏂᎲᎢ ᏍᏆᏞᏍᏗ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🏌🏼‍♀' => 'ᎠᎨᏯ ᎪᏍᏛᏂᎲᎢ ᏍᏆᏞᏍᏗ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🏌🏽‍♀' => 'ᎠᎨᏯ ᎪᏍᏛᏂᎲᎢ ᏍᏆᏞᏍᏗ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏌🏾‍♀' => 'ᎠᎨᏯ ᎪᏍᏛᏂᎲᎢ ᏍᏆᏞᏍᏗ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏌🏿‍♀' => 'ᎠᎨᏯ ᎪᏍᏛᏂᎲᎢ ᏍᏆᏞᏍᏗ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏄🏻‍♂' => 'ᎠᏍᎦᏯ ᎠᎹ ᏓᏍᏗᎳᏁᎬ ᎡᏁᏙᎯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🏄🏼‍♂' => 'ᎠᏍᎦᏯ ᎠᎹ ᏓᏍᏗᎳᏁᎬ ᎡᏁᏙᎯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🏄🏽‍♂' => 'ᎠᏍᎦᏯ ᎠᎹ ᏓᏍᏗᎳᏁᎬ ᎡᏁᏙᎯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏄🏾‍♂' => 'ᎠᏍᎦᏯ ᎠᎹ ᏓᏍᏗᎳᏁᎬ ᎡᏁᏙᎯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏄🏿‍♂' => 'ᎠᏍᎦᏯ ᎠᎹ ᏓᏍᏗᎳᏁᎬ ᎡᏁᏙᎯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏄🏻‍♀' => 'ᎠᎨᏯ ᎠᎹ ᏓᏍᏗᎳᏁᎬ ᎡᏁᏙᎯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🏄🏼‍♀' => 'ᎠᎨᏯ ᎠᎹ ᏓᏍᏗᎳᏁᎬ ᎡᏁᏙᎯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🏄🏽‍♀' => 'ᎠᎨᏯ ᎠᎹ ᏓᏍᏗᎳᏁᎬ ᎡᏁᏙᎯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏄🏾‍♀' => 'ᎠᎨᏯ ᎠᎹ ᏓᏍᏗᎳᏁᎬ ᎡᏁᏙᎯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏄🏿‍♀' => 'ᎠᎨᏯ ᎠᎹ ᏓᏍᏗᎳᏁᎬ ᎡᏁᏙᎯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🚣🏻‍♂' => 'ᎠᏍᎦᏯ ᏥᏳ ᎦᎦᏪᏍᎦ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🚣🏼‍♂' => 'ᎠᏍᎦᏯ ᏥᏳ ᎦᎦᏪᏍᎦ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🚣🏽‍♂' => 'ᎠᏍᎦᏯ ᏥᏳ ᎦᎦᏪᏍᎦ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🚣🏾‍♂' => 'ᎠᏍᎦᏯ ᏥᏳ ᎦᎦᏪᏍᎦ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🚣🏿‍♂' => 'ᎠᏍᎦᏯ ᏥᏳ ᎦᎦᏪᏍᎦ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🚣🏻‍♀' => 'ᎠᎨᏯ ᏥᏳ ᎦᎦᏪᏍᎦ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🚣🏼‍♀' => 'ᎠᎨᏯ ᏥᏳ ᎦᎦᏪᏍᎦ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🚣🏽‍♀' => 'ᎠᎨᏯ ᏥᏳ ᎦᎦᏪᏍᎦ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🚣🏾‍♀' => 'ᎠᎨᏯ ᏥᏳ ᎦᎦᏪᏍᎦ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🚣🏿‍♀' => 'ᎠᎨᏯ ᏥᏳ ᎦᎦᏪᏍᎦ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏊🏻‍♂' => 'ᎠᏍᎦᏯ ᎠᏓᏬ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🏊🏼‍♂' => 'ᎠᏍᎦᏯ ᎠᏓᏬ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🏊🏽‍♂' => 'ᎠᏍᎦᏯ ᎠᏓᏬ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏊🏾‍♂' => 'ᎠᏍᎦᏯ ᎠᏓᏬ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏊🏿‍♂' => 'ᎠᏍᎦᏯ ᎠᏓᏬ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏊🏻‍♀' => 'ᎠᎨᏯ ᎠᏓᏬ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🏊🏼‍♀' => 'ᎠᎨᏯ ᎠᏓᏬ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🏊🏽‍♀' => 'ᎠᎨᏯ ᎠᏓᏬ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏊🏾‍♀' => 'ᎠᎨᏯ ᎠᏓᏬ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏊🏿‍♀' => 'ᎠᎨᏯ ᎠᏓᏬ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '⛹🏻‍♂' => 'ᎠᏍᎦᏯ ᏍᏆᏞᏍᏗ ᎠᏓᏓᏕᎬ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '⛹🏼‍♂' => 'ᎠᏍᎦᏯ ᏍᏆᏞᏍᏗ ᎠᏓᏓᏕᎬ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '⛹🏽‍♂' => 'ᎠᏍᎦᏯ ᏍᏆᏞᏍᏗ ᎠᏓᏓᏕᎬ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '⛹🏾‍♂' => 'ᎠᏍᎦᏯ ᏍᏆᏞᏍᏗ ᎠᏓᏓᏕᎬ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '⛹🏿‍♂' => 'ᎠᏍᎦᏯ ᏍᏆᏞᏍᏗ ᎠᏓᏓᏕᎬ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '⛹🏻‍♀' => 'ᎠᎨᏯ ᏍᏆᏞᏍᏗ ᎠᏓᏓᏕᎬ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '⛹🏼‍♀' => 'ᎠᎨᏯ ᏍᏆᏞᏍᏗ ᎠᏓᏓᏕᎬ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '⛹🏽‍♀' => 'ᎠᎨᏯ ᏍᏆᏞᏍᏗ ᎠᏓᏓᏕᎬ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '⛹🏾‍♀' => 'ᎠᎨᏯ ᏍᏆᏞᏍᏗ ᎠᏓᏓᏕᎬ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '⛹🏿‍♀' => 'ᎠᎨᏯ ᏍᏆᏞᏍᏗ ᎠᏓᏓᏕᎬ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏋🏻‍♂' => 'ᎠᏍᎦᏯ ᏓᎵᏌᎳᏗᏍᎬ ᏧᏓᎨᏓ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🏋🏼‍♂' => 'ᎠᏍᎦᏯ ᏓᎵᏌᎳᏗᏍᎬ ᏧᏓᎨᏓ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🏋🏽‍♂' => 'ᎠᏍᎦᏯ ᏓᎵᏌᎳᏗᏍᎬ ᏧᏓᎨᏓ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏋🏾‍♂' => 'ᎠᏍᎦᏯ ᏓᎵᏌᎳᏗᏍᎬ ᏧᏓᎨᏓ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏋🏿‍♂' => 'ᎠᏍᎦᏯ ᏓᎵᏌᎳᏗᏍᎬ ᏧᏓᎨᏓ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏋🏻‍♀' => 'ᎠᎨᏯ ᏓᎵᏌᎳᏗᏍᎬᎢ ᏧᏓᎨᏓ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🏋🏼‍♀' => 'ᎠᎨᏯ ᏓᎵᏌᎳᏗᏍᎬᎢ ᏧᏓᎨᏓ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🏋🏽‍♀' => 'ᎠᎨᏯ ᏓᎵᏌᎳᏗᏍᎬᎢ ᏧᏓᎨᏓ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏋🏾‍♀' => 'ᎠᎨᏯ ᏓᎵᏌᎳᏗᏍᎬᎢ ᏧᏓᎨᏓ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏋🏿‍♀' => 'ᎠᎨᏯ ᏓᎵᏌᎳᏗᏍᎬᎢ ᏧᏓᎨᏓ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🚴🏻‍♂' => 'ᎠᏍᎦᏯ ᏔᎵ ᏗᎦᏩᏘ ᎤᎩᎸᏗ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🚴🏼‍♂' => 'ᎠᏍᎦᏯ ᏔᎵ ᏗᎦᏩᏘ ᎤᎩᎸᏗ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🚴🏽‍♂' => 'ᎠᏍᎦᏯ ᏔᎵ ᏗᎦᏩᏘ ᎤᎩᎸᏗ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🚴🏾‍♂' => 'ᎠᏍᎦᏯ ᏔᎵ ᏗᎦᏩᏘ ᎤᎩᎸᏗ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🚴🏿‍♂' => 'ᎠᏍᎦᏯ ᏔᎵ ᏗᎦᏩᏘ ᎤᎩᎸᏗ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🚴🏻‍♀' => 'ᎠᎨᏯ ᏔᎵ ᏗᎦᏩᏘ ᎤᎩᎸᏗ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🚴🏼‍♀' => 'ᎠᎨᏯ ᏔᎵ ᏗᎦᏩᏘ ᎤᎩᎸᏗ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🚴🏽‍♀' => 'ᎠᎨᏯ ᏔᎵ ᏗᎦᏩᏘ ᎤᎩᎸᏗ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🚴🏾‍♀' => 'ᎠᎨᏯ ᏔᎵ ᏗᎦᏩᏘ ᎤᎩᎸᏗ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🚴🏿‍♀' => 'ᎠᎨᏯ ᏔᎵ ᏗᎦᏩᏘ ᎤᎩᎸᏗ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🚵🏻‍♂' => 'ᎠᏍᎦᏯ ᎤᏅᏓᏢ ᏔᎵ ᏗᎦᏩᏘ ᎤᎩᎸᏗ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🚵🏼‍♂' => 'ᎠᏍᎦᏯ ᎤᏅᏓᏢ ᏔᎵ ᏗᎦᏩᏘ ᎤᎩᎸᏗ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🚵🏽‍♂' => 'ᎠᏍᎦᏯ ᎤᏅᏓᏢ ᏔᎵ ᏗᎦᏩᏘ ᎤᎩᎸᏗ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🚵🏾‍♂' => 'ᎠᏍᎦᏯ ᎤᏅᏓᏢ ᏔᎵ ᏗᎦᏩᏘ ᎤᎩᎸᏗ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🚵🏿‍♂' => 'ᎠᏍᎦᏯ ᎤᏅᏓᏢ ᏔᎵ ᏗᎦᏩᏘ ᎤᎩᎸᏗ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🚵🏻‍♀' => 'ᎠᎨᏯ ᎤᏅᏓᎴ ᏔᎵ ᏗᎦᏩᏘ ᎤᎩᎸᏗ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🚵🏼‍♀' => 'ᎠᎨᏯ ᎤᏅᏓᎴ ᏔᎵ ᏗᎦᏩᏘ ᎤᎩᎸᏗ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🚵🏽‍♀' => 'ᎠᎨᏯ ᎤᏅᏓᎴ ᏔᎵ ᏗᎦᏩᏘ ᎤᎩᎸᏗ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🚵🏾‍♀' => 'ᎠᎨᏯ ᎤᏅᏓᎴ ᏔᎵ ᏗᎦᏩᏘ ᎤᎩᎸᏗ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🚵🏿‍♀' => 'ᎠᎨᏯ ᎤᏅᏓᎴ ᏔᎵ ᏗᎦᏩᏘ ᎤᎩᎸᏗ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤸🏻‍♂' => 'ᎠᏍᎦᏯ ᏓᏁᏍᏆᏕᎬ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🤸🏼‍♂' => 'ᎠᏍᎦᏯ ᏓᏁᏍᏆᏕᎬ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🤸🏽‍♂' => 'ᎠᏍᎦᏯ ᏓᏁᏍᏆᏕᎬ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤸🏾‍♂' => 'ᎠᏍᎦᏯ ᏓᏁᏍᏆᏕᎬ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤸🏿‍♂' => 'ᎠᏍᎦᏯ ᏓᏁᏍᏆᏕᎬ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤸🏻‍♀' => 'ᎠᎨᏯ ᏓᏁᏍᏆᏕᎬ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🤸🏼‍♀' => 'ᎠᎨᏯ ᏓᏁᏍᏆᏕᎬ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🤸🏽‍♀' => 'ᎠᎨᏯ ᏓᏁᏍᏆᏕᎬ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤸🏾‍♀' => 'ᎠᎨᏯ ᏓᏁᏍᏆᏕᎬ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤸🏿‍♀' => 'ᎠᎨᏯ ᏓᏁᏍᏆᏕᎬ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤼🏻‍♀' => 'ᎠᎨᏯ ᏓᏁᎯᎲ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🤼🏼‍♀' => 'ᎠᎨᏯ ᏓᏁᎯᎲ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🤼🏽‍♀' => 'ᎠᎨᏯ ᏓᏁᎯᎲ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤼🏾‍♀' => 'ᎠᎨᏯ ᏓᏁᎯᎲ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤼🏿‍♀' => 'ᎠᎨᏯ ᏓᏁᎯᎲ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤼🏻‍♂' => 'ᎠᏂᏍᎦᏯ ᏓᏁᎯᎲ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🤼🏼‍♂' => 'ᎠᏂᏍᎦᏯ ᏓᏁᎯᎲ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🤼🏽‍♂' => 'ᎠᏂᏍᎦᏯ ᏓᏁᎯᎲ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤼🏾‍♂' => 'ᎠᏂᏍᎦᏯ ᏓᏁᎯᎲ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤼🏿‍♂' => 'ᎠᏂᏍᎦᏯ ᏓᏁᎯᎲ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤽🏻‍♂' => 'ᎠᏍᎦᏯ ᎠᎹ ᎠᎳᏍᎦᎵᏙᏗ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🤽🏼‍♂' => 'ᎠᏍᎦᏯ ᎠᎹ ᎠᎳᏍᎦᎵᏙᏗ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🤽🏽‍♂' => 'ᎠᏍᎦᏯ ᎠᎹ ᎠᎳᏍᎦᎵᏙᏗ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤽🏾‍♂' => 'ᎠᏍᎦᏯ ᎠᎹ ᎠᎳᏍᎦᎵᏙᏗ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤽🏿‍♂' => 'ᎠᏍᎦᏯ ᎠᎹ ᎠᎳᏍᎦᎵᏙᏗ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤽🏻‍♀' => 'ᎠᎨᏯ ᎠᎹ ᎠᎳᏍᎦᎵᏙᏗ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🤽🏼‍♀' => 'ᎠᎨᏯ ᎠᎹ ᎠᎳᏍᎦᎵᏙᏗ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🤽🏽‍♀' => 'ᎠᎨᏯ ᎠᎹ ᎠᎳᏍᎦᎵᏙᏗ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤽🏾‍♀' => 'ᎠᎨᏯ ᎠᎹ ᎠᎳᏍᎦᎵᏙᏗ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤽🏿‍♀' => 'ᎠᎨᏯ ᎠᎹ ᎠᎳᏍᎦᎵᏙᏗ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤾🏻‍♂' => 'ᎠᏍᎦᏯ ᏓᏁᎶᎲᏍᎬᎢ ᎦᏂᏴᏙᏗ ᎠᎳᏍᎦᎵᏙᏗ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🤾🏼‍♂' => 'ᎠᏍᎦᏯ ᏓᏁᎶᎲᏍᎬᎢ ᎦᏂᏴᏙᏗ ᎠᎳᏍᎦᎵᏙᏗ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🤾🏽‍♂' => 'ᎠᏍᎦᏯ ᏓᏁᎶᎲᏍᎬᎢ ᎦᏂᏴᏙᏗ ᎠᎳᏍᎦᎵᏙᏗ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤾🏾‍♂' => 'ᎠᏍᎦᏯ ᏓᏁᎶᎲᏍᎬᎢ ᎦᏂᏴᏙᏗ ᎠᎳᏍᎦᎵᏙᏗ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤾🏿‍♂' => 'ᎠᏍᎦᏯ ᏓᏁᎶᎲᏍᎬᎢ ᎦᏂᏴᏙᏗ ᎠᎳᏍᎦᎵᏙᏗ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤾🏻‍♀' => 'ᎠᎨᏯ ᏓᏁᎶᎲᏍᎬᎢ ᎦᏂᏴᏙᏗ ᎠᎳᏍᎦᎵᏙᏗ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🤾🏼‍♀' => 'ᎠᎨᏯ ᏓᏁᎶᎲᏍᎬᎢ ᎦᏂᏴᏙᏗ ᎠᎳᏍᎦᎵᏙᏗ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🤾🏽‍♀' => 'ᎠᎨᏯ ᏓᏁᎶᎲᏍᎬᎢ ᎦᏂᏴᏙᏗ ᎠᎳᏍᎦᎵᏙᏗ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤾🏾‍♀' => 'ᎠᎨᏯ ᏓᏁᎶᎲᏍᎬᎢ ᎦᏂᏴᏙᏗ ᎠᎳᏍᎦᎵᏙᏗ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤾🏿‍♀' => 'ᎠᎨᏯ ᏓᏁᎶᎲᏍᎬᎢ ᎦᏂᏴᏙᏗ ᎠᎳᏍᎦᎵᏙᏗ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤹🏻‍♂' => 'ᎠᏍᎦᏯ ᏓᏍᏆᏞᏏᏙᎲᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🤹🏼‍♂' => 'ᎠᏍᎦᏯ ᏓᏍᏆᏞᏏᏙᎲᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🤹🏽‍♂' => 'ᎠᏍᎦᏯ ᏓᏍᏆᏞᏏᏙᎲᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤹🏾‍♂' => 'ᎠᏍᎦᏯ ᏓᏍᏆᏞᏏᏙᎲᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤹🏿‍♂' => 'ᎠᏍᎦᏯ ᏓᏍᏆᏞᏏᏙᎲᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤹🏻‍♀' => 'ᎠᎨᏯ ᏓᏍᏆᏞᏏᏙᎲᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🤹🏼‍♀' => 'ᎠᎨᏯ ᏓᏍᏆᏞᏏᏙᎲᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🤹🏽‍♀' => 'ᎠᎨᏯ ᏓᏍᏆᏞᏏᏙᎲᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤹🏾‍♀' => 'ᎠᎨᏯ ᏓᏍᏆᏞᏏᏙᎲᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤹🏿‍♀' => 'ᎠᎨᏯ ᏓᏍᏆᏞᏏᏙᎲᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧘🏻‍♂' => 'ᎠᏍᎦᏯ ᏚᏓᏝᏗᏍᏗ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧘🏼‍♂' => 'ᎠᏍᎦᏯ ᏚᏓᏝᏗᏍᏗ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧘🏽‍♂' => 'ᎠᏍᎦᏯ ᏚᏓᏝᏗᏍᏗ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧘🏾‍♂' => 'ᎠᏍᎦᏯ ᏚᏓᏝᏗᏍᏗ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧘🏿‍♂' => 'ᎠᏍᎦᏯ ᏚᏓᏝᏗᏍᏗ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧘🏻‍♀' => 'ᎠᎨᏯ ᏚᏓᏝᏗᏍᏗ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧘🏼‍♀' => 'ᎠᎨᏯ ᏚᏓᏝᏗᏍᏗ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧘🏽‍♀' => 'ᎠᎨᏯ ᏚᏓᏝᏗᏍᏗ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧘🏾‍♀' => 'ᎠᎨᏯ ᏚᏓᏝᏗᏍᏗ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧘🏿‍♀' => 'ᎠᎨᏯ ᏚᏓᏝᏗᏍᏗ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑‍🦰' => 'ᎤᏔᎾ: ᎩᎦᎨ ᎤᏍᏘᎦ',
    '🧑‍🦱' => 'ᎤᏔᎾ: ᎤᎵᏥᏍᏆᏁᏓ ᎤᏍᏘᎦ',
    '🧑‍🦳' => 'ᎤᏔᎾ: ᎤᏁᎦ ᎤᏍᏘᎦ',
    '🧑‍🦲' => 'ᎤᏔᎾ: ᎤᎨᏬᏗ',
    '👨‍🦰' => 'ᎠᏍᎦᏯ: ᎩᎦᎨ ᎤᏍᏘᎦ',
    '👨‍🦱' => 'ᎠᏍᎦᏯ: ᎤᎵᏥᏍᏆᏁᏓ ᎤᏍᏘᎦ',
    '👨‍🦳' => 'ᎠᏍᎦᏯ: ᎤᏁᎦ ᎤᏍᏘᎦ',
    '👨‍🦲' => 'ᎠᏍᎦᏯ: ᎤᎨᏬᏗ',
    '👩‍🦰' => 'ᎠᎨᏯ: ᎩᎦᎨ ᎤᏍᏘᎦ',
    '👩‍🦱' => 'ᎠᎨᏯ: ᎤᎵᏥᏍᏆᏁᏓ ᎤᏍᏘᎦ',
    '👩‍🦳' => 'ᎠᎨᏯ: ᎤᏁᎦ ᎤᏍᏘᎦ',
    '👩‍🦲' => 'ᎠᎨᏯ: ᎤᎨᏬᏗ',
    '🚶‍➡' => 'ᏴᏫ ᎠᏨᏏᏰ: ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🧎‍➡' => 'ᏴᏫ ᏕᏥᎾᏆᎾ: ᎠᎦᏘᏏ ᎢᏗᏢ',
    '🏃‍➡' => 'ᏴᏫ ᎠᏛᏟᏒᎢ: ᎠᎦᏘᏏ ᎢᏗᏢ',
    '👨‍👦' => 'ᏏᏓᏁᎸᎢ: ᎠᏍᎦᏯ, ᎠᏧᏣ',
    '👨‍👧' => 'ᏏᏓᏁᎸᎢ: ᎠᏍᎦᏯ, ᎠᎨᏳᏣ',
    '👩‍👦' => 'ᏏᏓᏁᎸᎢ: ᎠᎨᏯ, ᎠᏧᏣ',
    '👩‍👧' => 'ᏏᏓᏁᎸᎢ: ᎠᎨᏯ, ᎠᎨᏳᏣ',
    '😶‍🌫' => 'ᎤᎧᏛ ᎭᏫᏂ ᏧᎶᎩᎵ',
    '😮‍💨' => 'ᎤᎧᏛ ᎤᏓᏅᏖᏙᏗ',
    '🙂‍↕' => 'ᎤᏍᎫᏴᎢ',
    '😵‍💫' => 'ᎤᎧᏛ ᏗᎩᏙᎵ ᎠᎦᎷᎦ ᎢᏳᏍᏗ',
    '❤‍🔥' => 'ᎤᎾᏫ ᎠᎪᎲᏍᏗᏍᎪᎢ',
    '❤‍🩹' => 'ᎣᏍᏓ ᏄᏩᏁᎸᎢ ᎤᎾᏫ',
    '👁‍🗨' => 'ᎠᎦᏘ ᎥᎿ ᎥᎧᏁᎬᎢ ᎤᏆᎷᏒ',
    '🧔‍♂' => 'ᎠᏍᎦᏯ: ᎠᎭᏄᎸᏒ',
    '👱‍♂' => 'ᎠᏍᎦᏯ: ᏓᎶᏂᎨ ᎤᏍᏘᎩ',
    '🧔‍♀' => 'ᎠᎨᏯ: ᎠᎭᏄᎸᏒ',
    '👱‍♀' => 'ᎠᎨᏯ: ᏓᎶᏂᎨ ᎤᏍᏘᎩ',
    '🙍‍♂' => 'ᎠᏍᎦᏯ ᎤᏓᏁᎪᏳᎭ',
    '🙍‍♀' => 'ᎠᎨᏯ ᎤᏓᏁᎪᏳᎭ',
    '🙎‍♂' => 'ᎠᏍᎦᏯ ᎤᏇᏟᎬ',
    '🙎‍♀' => 'ᎠᎨᏯ ᎤᏇᏟᎬ',
    '🙅‍♂' => 'ᎠᏍᎦᏯ ᏓᏐᏰᏍᎬ ᎥᏝ',
    '🙅‍♀' => 'ᎠᎨᏯ ᏓᏐᏰᏍᎬ ᎥᏝ',
    '🙆‍♂' => 'ᎠᏍᎦᏯ ᏓᏐᏰᏍᎬ ᎭᏩ',
    '🙆‍♀' => 'ᎠᎨᏯ ᏓᏐᏰᏍᎬ ᎭᏩ',
    '💁‍♂' => 'ᎠᏍᎦᏯ ᎤᏘᏌᏗ ᎤᏬᏱ',
    '💁‍♀' => 'ᎠᎨᏯ ᎤᏘᏌᏗ ᎤᏬᏱ',
    '🙋‍♂' => 'ᎠᏍᎦᏯ ᎤᏎᎵᏔ',
    '🙋‍♀' => 'ᎠᎨᏯ ᎠᏌᎳᏗᏍᎬ ᎤᏬᏰᏂ',
    '🧏‍♂' => 'ᏧᎵᎡᎾ ᎠᏍᎦᏯ',
    '🧏‍♀' => 'ᏧᎵᎡᎾ ᎠᎨᏯ',
    '🙇‍♂' => 'ᎠᏍᎦᏯ ᎤᏘᏌᏘ',
    '🙇‍♀' => 'ᎠᎨᏯ ᎤᏘᏌᏘ',
    '🤦‍♂' => 'ᎠᏍᎦᏯ ᎤᎧᏛᎢ ᎠᏓᏏᏔᏗᏍᎬᎢ',
    '🤦‍♀' => 'ᎠᎨᏯ ᎤᎧᏛᎢ ᎠᏓᏏᏔᏗᏍᎬᎢ',
    '🤷‍♂' => 'ᎠᏍᎦᏯ ᏗᎦᏅᏬ ᏚᏌᎳᏛ',
    '🤷‍♀' => 'ᎠᎨᏯ ᏗᎦᏅᏬ ᏚᏌᎳᏛ',
    '🧑‍⚕' => 'ᏙᎯ ᏃᏛᎿᏕᎬᎢ ᏧᎸᏫᏍᏓᏁᎯ',
    '👨‍⚕' => 'ᎠᏍᎦᏯ ᏙᎯᏃᏛᎿᏕᎬᎢ ᎤᎦᏎᏍᏗ ᏧᎸᏫᏍᏓᏁᎯ',
    '👩‍⚕' => 'ᎠᎨᏯ ᏙᎯ ᏃᏛᎿᏕᎬᎢ ᏧᎸᏫᏍᏓᏁᎯ',
    '🧑‍🎓' => 'ᏗᏕᎶᏆᏍᎩ',
    '👨‍🎓' => 'ᎠᏍᎦᏯ ᏗᏕᎶᏆᏍᎩ',
    '👩‍🎓' => 'ᎠᎨᏯ ᏗᏕᎶᏆᏍᎩ',
    '🧑‍🏫' => 'ᏗᏕᏲᎲᏍᎩ',
    '👨‍🏫' => 'ᎠᏍᎦᏯ ᏗᏕᏲᎲᏍᎩ',
    '👩‍🏫' => 'ᎠᎨᏯ ᏗᏕᏲᎲᏍᎩ',
    '🧑‍⚖' => 'ᏗᎫᎪᏗᏍᎩ',
    '👨‍⚖' => 'ᎠᏍᎦᏯ ᏗᎫᎪᏗᏍᎩ',
    '👩‍⚖' => 'ᎠᎨᏯ ᏗᎫᎪᏗᏍᎩ',
    '🧑‍🌾' => 'ᏗᎦᎶᎩᏍᎩ',
    '👨‍🌾' => 'ᎠᏍᎦᏯ ᏗᎦᎶᎩᏍᎩ',
    '👩‍🌾' => 'ᎠᎨᏯ ᏗᎦᎶᎩᏍᎩ',
    '🧑‍🍳' => 'ᏗᏓᏍᏓᏴᎲᏍᎩ',
    '👨‍🍳' => 'ᎠᏍᎦᏯ ᎠᏓᏍᏓᏴᎲᏍᎦ',
    '👩‍🍳' => 'ᎠᎨᏯ ᏗᏓᏍᏓᏴᎲᏍᎩ',
    '🧑‍🔧' => 'ᏙᏆᎴᎷ ᎣᏍᏓ ᏱᏗᎬᏁᎯ',
    '👨‍🔧' => 'ᎠᏍᎦᏯ ᏙᏆᎴᎷ ᏧᎸᏫᏍᏓᏁᎯ',
    '👩‍🔧' => 'ᎠᎨᏯ ᏙᏆᎴᎷ ᎣᏍᏓ ᏱᏗᎬᏁᎯ',
    '🧑‍🏭' => 'ᏗᎦᎸᏫᏍᏓᏁᏗ ᏧᎸᏫᏍᏓᏁᎯ',
    '👨‍🏭' => 'ᎠᏍᎦᏯ ᎤᏃᏢᏅᏗ ᏧᎸᏫᏍᏓᏁᎯ',
    '👩‍🏭' => 'ᎠᎨᏯ ᏗᎦᎸᏫᏍᏓᏁᏗ ᏧᎸᏫᏍᏓᏁᎯ',
    '🧑‍💼' => 'ᏗᎦᎸᏫᏍᏓᏁᏗᎢ ᏧᎸᏫᏍᏓᏁᎯ',
    '👨‍💼' => 'ᎠᏍᎦᏯ ᎤᏬᏟ ᏧᎸᏫᏍᏓᏁᎯ',
    '👩‍💼' => 'ᎠᎨᏯ ᏗᎦᎸᏫᏍᏓᏁᏗ ᏧᏄᏫᏍᏓᏁᎯ',
    '🧑‍🔬' => 'ᎤᎦᏛᎲᏍᎩ',
    '👨‍🔬' => 'ᎠᏍᎦᏯ ᎤᎦᏛᎲᏍᎩ',
    '👩‍🔬' => 'ᎠᎨᏯ ᎤᎦᏛᎲᏍᎩ',
    '🧑‍💻' => 'ᎠᏏᎳᏕᏫᏒᎢ ᏧᎸᏫᏍᏓᏁᎯ',
    '👨‍💻' => 'ᎠᏍᎦᏯ ᏓᏏᎳᏕᏫᏒᎢ ᏧᎸᏫᏍᏓᏁᎯ',
    '👩‍💻' => 'ᎠᎨᏯ ᎠᏏᎳᏕᏫᏒᎢ ᏧᎸᏫᏍᏓᏁᎯ',
    '🧑‍🎤' => 'ᏗᎧᏃᎩᏍᏗᏍᎩ',
    '👨‍🎤' => 'ᎠᏍᎦᏯ ᏗᎧᏃᎩᏍᎩ',
    '👩‍🎤' => 'ᎠᎨᏯ ᏗᎧᏃᎩᏍᎩ',
    '🧑‍🎨' => 'ᏗᏟᎶᏍᏗᏍᎩ',
    '👨‍🎨' => 'ᎠᏍᎦᏯ ᏗᏑᏫᏍᎩ',
    '👩‍🎨' => 'ᎠᎨᏯ ᏗᏟᎶᏍᏗᏍᎩ',
    '🧑‍✈' => 'ᏥᏳ ᎠᎲᎵᏙᎯ',
    '👨‍✈' => 'ᎠᏍᎦᏯ ᏥᏳ ᎧᏅᏫᏍᏗᏍᎩ',
    '👩‍✈' => 'ᎠᎨᏯ ᏥᏳ ᎠᎲᎵᏙᎯ',
    '🧑‍🚀' => 'ᎠᏝᏫᏗᏍᎩ',
    '👨‍🚀' => 'ᎠᏍᎦᏯ ᎦᎸᎶᎯ ᎡᏙᎯ',
    '👩‍🚀' => 'ᎠᎨᏯ ᎦᎸᎶᎯ ᎡᏙᎯ',
    '🧑‍🚒' => 'ᏗᎦᏝᏗᏍᎩ',
    '👨‍🚒' => 'ᎠᏍᎦᏯ ᏗᎬᏝᏗᏍᎩ',
    '👩‍🚒' => 'ᎠᎨᏯ ᏗᎦᏝᏗᏍᎩ',
    '👮‍♂' => 'ᎠᏍᎦᏯ ᏗᏓᏂᏱᏍᎩ',
    '👮‍♀' => 'ᎠᎨᏯ ᏗᏓᏂᏱᏍᎩ',
    '🕵‍♂' => 'ᎠᏍᎦᏯ ᎤᎦᏛᏂᏙᎯ',
    '🕵‍♀' => 'ᎠᎨᏯ ᎤᎦᏛᏂᏙᎯ',
    '💂‍♂' => 'ᎠᏍᎦᏯ ᎠᏯᏫᏍᎩ',
    '💂‍♀' => 'ᎠᎨᏯ ᎠᏯᏫᏍᎩ',
    '👷‍♂' => 'ᎠᏍᎦᏯ ᏗᏁᏍᎨᏍᎩ ᏧᎸᏫᏍᏓᏁᎯ',
    '👷‍♀' => 'ᎠᎨᏯ ᏗᏁᏍᎨᏍᎩ ᏧᎸᏫᏍᏓᏁᎯ',
    '👳‍♂' => 'ᎠᏍᎦᏯ ᎤᎵᏍᏚᎳ',
    '👳‍♀' => 'ᎠᎨᏯ ᎤᎵᏍᏚᎳ',
    '🤵‍♂' => 'ᎠᏍᎦᏯ ᎤᏬᏚᎯ ᎤᏄᏩ',
    '🤵‍♀' => 'ᎠᎨᏯ ᎤᏬᏚᎯ ᎤᏄᏩ',
    '👰‍♂' => 'ᎠᏍᎦᏯ ᎫᏝᎢ ᎤᎧᏛ',
    '👰‍♀' => 'ᎠᎨᏯ ᎫᏝᎢ ᎤᎧᏛ',
    '👩‍🍼' => 'ᎠᎨᏯ ᏧᏓᏍᏓᎢ',
    '👨‍🍼' => 'ᎠᏍᎦᏯ ᏧᏓᏍᏓᎢ',
    '🧑‍🍼' => 'ᏴᏫ ᏧᏓᏍᏓᎢ',
    '🧑‍🎄' => 'ᏧᏠᏱ ᏧᏠᎦᎴᏓ',
    '🦸‍♂' => 'ᎠᏍᎦᏯ ᏄᎬᏫᏳᏒᎩ ᏩᏥᎸᏉᏛ',
    '🦸‍♀' => 'ᎠᎨᏯ ᏄᎬᏫᏳᏒᎩ ᏩᏥᎸᏉᏛ',
    '🦹‍♂' => 'ᎠᏍᎦᏯ ᏄᎬᏫᏳᏒᎩ ᎠᏍᎦᏂ',
    '🦹‍♀' => 'ᎠᎨᏯ ᏄᎬᏫᏳᏒᎩ ᎠᏍᎦᏂ',
    '🧙‍♂' => 'ᎠᏍᎦᏯ ᎠᏓᏪ',
    '🧙‍♀' => 'ᎠᎨᏯ ᎠᏓᏪ',
    '🧚‍♂' => 'ᎠᏍᎦᏯ ᏴᏫ ᎤᏍᏗ ᎦᏃᎯᎵᏙᎯ',
    '🧚‍♀' => 'ᎠᎨᏯ ᏴᏫ ᎤᏍᏗ ᎦᏃᎯᎵᏙᎯ',
    '🧛‍♂' => 'ᎠᏍᎦᏯ ᎩᎦ ᎠᏓᏁᎩᏛᎯ',
    '🧛‍♀' => 'ᎠᎨᏯ ᎩᎦ ᎠᏓᏁᎩᎡᎯ',
    '🧜‍♂' => 'ᎠᏍᎦᏯ ᎠᏣᏗ ᎤᎬᎭᏟ',
    '🧜‍♀' => 'ᎠᎨᏯ ᎠᏣᏗ ᎤᎬᎭᏟ',
    '🧝‍♂' => 'ᎠᏍᎦᏯ ᏴᏫ ᎢᏳᏍᏗ',
    '🧝‍♀' => 'ᎠᎨᏯ ᏴᏫ ᎢᏳᏍᏗ',
    '🧞‍♂' => 'ᎠᏍᎦᏯ ᏥᎾᏱ',
    '🧞‍♀' => 'ᎠᎨᏯ ᏥᎾᏱ',
    '🧟‍♂' => 'ᎠᏍᎦᏯ ᎤᏲᎱᏒ ᎤᏗᏛᏓ',
    '🧟‍♀' => 'ᎠᎨᏯ ᎤᏲᎱᏒ ᎤᏗᏛᏓ',
    '💆‍♂' => 'ᎠᏍᎦᏯ ᎠᏥᏍᎪᎵᏰᏍᎬᎢ',
    '💆‍♀' => 'ᎠᎨᏯ ᎠᏥᏍᎪᎵᏰᏍᎬᎢ',
    '💇‍♂' => 'ᎠᏍᎦᏯ ᎠᏥᏍᏙᏰᏍᎬᎢ',
    '💇‍♀' => 'ᎠᎨᏯ ᎠᏥᏍᏙᏰᏍᎬᎢ',
    '🚶‍♂' => 'ᎠᏍᎦᏯ ᎠᏨᏏᏰ',
    '🚶‍♀' => 'ᎠᎨᏯ ᎠᏨᏏᏰ',
    '🧍‍♂' => 'ᎠᏍᎦᏯ ᎦᏙᎦ',
    '🧍‍♀' => 'ᎠᎨᏯ ᎦᏙᎦ',
    '🧎‍♂' => 'ᎠᏍᎦᏯ ᏕᏥᎾᏆᎾ',
    '🧎‍♀' => 'ᎠᎨᏯ ᏕᏥᎾᏆᎾ',
    '🧑‍🦯' => 'ᏴᏫ ᏗᎨᏫ ᎬᏂᏍᏓ ᎬᏗ',
    '👨‍🦯' => 'ᎠᏍᎦᏯ ᏗᎨᏫ ᎦᏅᏍᏓ ᎬᏗ',
    '👩‍🦯' => 'ᎠᎨᏯ ᏗᎨᏫ ᎦᏅᏍᏓ ᎬᏗ',
    '🧑‍🦼' => 'ᏴᏫ ᎠᎾᎦᎵᏍᎩ ᎦᏆᏘᏗ ᎦᏍᏗᎶ ᎬᏗ',
    '👨‍🦼' => 'ᎠᏍᎦᏯ ᎬᏗ ᎠᏂᎩᏍᏗᏍᎩ ᎦᏆᏙᏗ ᎦᏍᎩᎶ',
    '👩‍🦼' => 'ᎠᎨᏯ ᎬᏗ ᎠᏂᎩᏍᏗᏍᎩ ᎦᏆᏙᏗ ᎦᏍᎩᎶ',
    '🧑‍🦽' => 'ᏴᏫ ᎦᏆᏘᏗ ᎦᏍᎩᎶ ᎬᏗ',
    '👨‍🦽' => 'ᎠᏍᎦᏯ ᎬᏗ ᎦᏆᏙᏗ ᎦᏍᎩᎶ',
    '👩‍🦽' => 'ᎠᎨᏯ ᎬᏗ ᎦᏆᏙᏗ ᎦᏍᎩᎶ',
    '🏃‍♂' => 'ᎠᏍᎦᏯ ᎠᏛᏟᏒᎢ',
    '🏃‍♀' => 'ᎠᎨᏯ ᎠᏛᏟᏒᎢ',
    '🧑‍🩰' => 'ᏆᎴ ᎠᎵᏍᎩᏍᎩ',
    '👯‍♂' => 'ᎠᏍᎦᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ',
    '👯‍♀' => 'ᎠᎨᏯ ᏥᏍᏚ ᏗᎦᎴ ᎣᏍᏓ ᎤᏍᏆᎸᎡᎲᎢ',
    '🧖‍♂' => 'ᎠᏍᎦᏯ ᎠᏯᎠ ᎠᏔᎶᎴᎬ ᎧᏅᏑᎸ',
    '🧖‍♀' => 'ᎠᎨᏯ ᎠᏯᎠ ᎠᏔᎶᎴᎬ ᎧᏅᏑᎸ',
    '🧗‍♂' => 'ᎠᏍᎦᏯ ᎦᎵᏙᎭ',
    '🧗‍♀' => 'ᎠᎨᏯ ᎦᎵᏙᎭ',
    '🏌‍♂' => 'ᎠᏍᎦᏯ ᎪᏍᏛᏂᎲᎢ ᏍᏆᏞᏍᏗ',
    '🏌‍♀' => 'ᎠᎨᏯ ᎪᏍᏛᏂᎲᎢ ᏍᏆᏞᏍᏗ',
    '🏄‍♂' => 'ᎠᏍᎦᏯ ᎠᎹ ᏓᏍᏗᎳᏁᎬ ᎡᏁᏙᎯ',
    '🏄‍♀' => 'ᎠᎨᏯ ᎠᎹ ᏓᏍᏗᎳᏁᎬ ᎡᏁᏙᎯ',
    '🚣‍♂' => 'ᎠᏍᎦᏯ ᏥᏳ ᎦᎦᏪᏍᎦ',
    '🚣‍♀' => 'ᎠᎨᏯ ᏥᏳ ᎦᎦᏪᏍᎦ',
    '🏊‍♂' => 'ᎠᏍᎦᏯ ᎠᏓᏬ',
    '🏊‍♀' => 'ᎠᎨᏯ ᎠᏓᏬ',
    '⛹‍♂' => 'ᎠᏍᎦᏯ ᏍᏆᏞᏍᏗ ᎠᏓᏓᏕᎬ',
    '⛹‍♀' => 'ᎠᎨᏯ ᏍᏆᏞᏍᏗ ᎠᏓᏓᏕᎬ',
    '🏋‍♂' => 'ᎠᏍᎦᏯ ᏓᎵᏌᎳᏗᏍᎬ ᏧᏓᎨᏓ',
    '🏋‍♀' => 'ᎠᎨᏯ ᏓᎵᏌᎳᏗᏍᎬᎢ ᏧᏓᎨᏓ',
    '🚴‍♂' => 'ᎠᏍᎦᏯ ᏔᎵ ᏗᎦᏩᏘ ᎤᎩᎸᏗ',
    '🚴‍♀' => 'ᎠᎨᏯ ᏔᎵ ᏗᎦᏩᏘ ᎤᎩᎸᏗ',
    '🚵‍♂' => 'ᎠᏍᎦᏯ ᎤᏅᏓᏢ ᏔᎵ ᏗᎦᏩᏘ ᎤᎩᎸᏗ',
    '🚵‍♀' => 'ᎠᎨᏯ ᎤᏅᏓᎴ ᏔᎵ ᏗᎦᏩᏘ ᎤᎩᎸᏗ',
    '🤸‍♂' => 'ᎠᏍᎦᏯ ᏓᏁᏍᏆᏕᎬ',
    '🤸‍♀' => 'ᎠᎨᏯ ᏓᏁᏍᏆᏕᎬ',
    '🤼‍♂' => 'ᎠᏂᏍᎦᏯ ᏓᏁᎯᎲ',
    '🤼‍♀' => 'ᎠᎨᏯ ᏓᏁᎯᎲ',
    '🤽‍♂' => 'ᎠᏍᎦᏯ ᎠᎹ ᎠᎳᏍᎦᎵᏙᏗ',
    '🤽‍♀' => 'ᎠᎨᏯ ᎠᎹ ᎠᎳᏍᎦᎵᏙᏗ',
    '🤾‍♂' => 'ᎠᏍᎦᏯ ᏓᏁᎶᎲᏍᎬᎢ ᎦᏂᏴᏙᏗ ᎠᎳᏍᎦᎵᏙᏗ',
    '🤾‍♀' => 'ᎠᎨᏯ ᏓᏁᎶᎲᏍᎬᎢ ᎦᏂᏴᏙᏗ ᎠᎳᏍᎦᎵᏙᏗ',
    '🤹‍♂' => 'ᎠᏍᎦᏯ ᏓᏍᏆᏞᏏᏙᎲᎢ',
    '🤹‍♀' => 'ᎠᎨᏯ ᏓᏍᏆᏞᏏᏙᎲᎢ',
    '🧘‍♂' => 'ᎠᏍᎦᏯ ᏚᏓᏝᏗᏍᏗ',
    '🧘‍♀' => 'ᎠᎨᏯ ᏚᏓᏝᏗᏍᏗ',
    '🧑‍🧒' => 'ᏏᏓᏁᎸ: ᎠᏅᏓ, ᎠᏲᏟ',
    '🐕‍🦺' => 'ᎠᏓᏍᏕᎸᏗ ᎩᏟ',
    '🐈‍⬛' => 'ᎬᎿᎨ ᏪᏌ',
    '🐻‍❄' => 'ᎤᏁᏍᏓᎳ ᏲᎾ',
    '🐦‍⬛' => 'ᏥᏍᏆᎵᏍᏗ',
    '🐦‍🔥' => 'ᏧᎴᎯᏌᏅᎯ',
    '🍋‍🟩' => 'ᎳᎻ',
    '🍄‍🟫' => 'ᎤᏬᏗᎨ ᏓᏬᎵ',
    '⛓‍💥' => 'ᎤᏲᏨᎯ ᎤᎾᏓᏕᏒᏓ',
    '🏳‍🌈' => 'ᎤᏅᎪᎳᏛ ᎦᏓᏘ',
    '🏳‍⚧' => 'ᏌᎪᏂᎨ, ᎩᎦᎨ ᎤᏍᎪᎸ, ᎠᎴ ᎤᏁᎦ ᎦᏓᏘ',
    '🏴‍☠' => 'ᏥᏳᎡᏙᎯ ᎠᏓᏌᎲᏍᎩ ᎦᏓᏗ',
    '👋🏻' => 'ᎠᏲᎵᎭ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👋🏼' => 'ᎠᏲᎵᎭ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👋🏽' => 'ᎠᏲᎵᎭ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👋🏾' => 'ᎠᏲᎵᎭ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👋🏿' => 'ᎠᏲᎵᎭ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤚🏻' => 'ᎠᏒᎵᏛᏅ ᎣᏂᏗᏢ ᎣᏬᏰᎾ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🤚🏼' => 'ᎠᏒᎵᏛᏅ ᎣᏂᏗᏢ ᎣᏬᏰᎾ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🤚🏽' => 'ᎠᏒᎵᏛᏅ ᎣᏂᏗᏢ ᎣᏬᏰᎾ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤚🏾' => 'ᎠᏒᎵᏛᏅ ᎣᏂᏗᏢ ᎣᏬᏰᎾ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤚🏿' => 'ᎠᏒᎵᏛᏅ ᎣᏂᏗᏢ ᎣᏬᏰᎾ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🖐🏻' => 'ᎤᏌᎳᏓ ᎤᏬᏱ ᎢᏧᏓᎵ ᏕᎦᏰᏌᏛ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🖐🏼' => 'ᎤᏌᎳᏓ ᎤᏬᏱ ᎢᏧᏓᎵ ᏕᎦᏰᏌᏛ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🖐🏽' => 'ᎤᏌᎳᏓ ᎤᏬᏱ ᎢᏧᏓᎵ ᏕᎦᏰᏌᏛ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🖐🏾' => 'ᎤᏌᎳᏓ ᎤᏬᏱ ᎢᏧᏓᎵ ᏕᎦᏰᏌᏛ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🖐🏿' => 'ᎤᏌᎳᏓ ᎤᏬᏱ ᎢᏧᏓᎵ ᏕᎦᏰᏌᏛ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '✋🏻' => 'ᎣᏬᏰᎾ ᎠᏌᎵᏛᏅᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '✋🏼' => 'ᎣᏬᏰᎾ ᎠᏌᎵᏛᏅᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '✋🏽' => 'ᎣᏬᏰᎾ ᎠᏌᎵᏛᏅᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '✋🏾' => 'ᎣᏬᏰᎾ ᎠᏌᎵᏛᏅᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '✋🏿' => 'ᎣᏬᏰᎾ ᎠᏌᎵᏛᏅᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🖖🏻' => 'ᏗᎪᏍᏓᏱᏗᎦᎵᏟᎩ ᎠᏓᏲᎵᏍᏗ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🖖🏼' => 'ᏗᎪᏍᏓᏱᏗᎦᎵᏟᎩ ᎠᏓᏲᎵᏍᏗ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🖖🏽' => 'ᏗᎪᏍᏓᏱᏗᎦᎵᏟᎩ ᎠᏓᏲᎵᏍᏗ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🖖🏾' => 'ᏗᎪᏍᏓᏱᏗᎦᎵᏟᎩ ᎠᏓᏲᎵᏍᏗ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🖖🏿' => 'ᏗᎪᏍᏓᏱᏗᎦᎵᏟᎩ ᎠᏓᏲᎵᏍᏗ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🫱🏻' => 'ᎤᏬᏰᏂ ᎠᎦᏘᏏ ᏗᏜ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🫱🏼' => 'ᎤᏬᏰᏂ ᎠᎦᏘᏏ ᏗᏜ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🫱🏽' => 'ᎤᏬᏰᏂ ᎠᎦᏘᏏ ᏗᏜ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🫱🏾' => 'ᎤᏬᏰᏂ ᎠᎦᏘᏏ ᏗᏜ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🫱🏿' => 'ᎤᏬᏰᏂ ᎠᎦᏘᏏ ᏗᏜ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🫲🏻' => 'ᎤᏬᏰᏂ ᎠᎦᏍᎦᏂ ᏗᏜ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🫲🏼' => 'ᎤᏬᏰᏂ ᎠᎦᏍᎦᏂ ᏗᏜ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🫲🏽' => 'ᎤᏬᏰᏂ ᎠᎦᏍᎦᏂ ᏗᏜ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🫲🏾' => 'ᎤᏬᏰᏂ ᎠᎦᏍᎦᏂ ᏗᏜ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🫲🏿' => 'ᎤᏬᏰᏂ ᎠᎦᏍᎦᏂ ᏗᏜ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🫳🏻' => 'ᎭᏫᎾᏗᏢ ᎤᏬᏰᏂ ᎡᎳᏗ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🫳🏼' => 'ᎭᏫᎾᏗᏢ ᎤᏬᏰᏂ ᎡᎳᏗ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🫳🏽' => 'ᎭᏫᎾᏗᏢ ᎤᏬᏰᏂ ᎡᎳᏗ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🫳🏾' => 'ᎭᏫᎾᏗᏢ ᎤᏬᏰᏂ ᎡᎳᏗ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🫳🏿' => 'ᎭᏫᎾᏗᏢ ᎤᏬᏰᏂ ᎡᎳᏗ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🫴🏻' => 'ᎭᏫᎾᏗᏢ ᎤᏬᏰᏂ ᎦᎸᎳᏗ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🫴🏼' => 'ᎭᏫᎾᏗᏢ ᎤᏬᏰᏂ ᎦᎸᎳᏗ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🫴🏽' => 'ᎭᏫᎾᏗᏢ ᎤᏬᏰᏂ ᎦᎸᎳᏗ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🫴🏾' => 'ᎭᏫᎾᏗᏢ ᎤᏬᏰᏂ ᎦᎸᎳᏗ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🫴🏿' => 'ᎭᏫᎾᏗᏢ ᎤᏬᏰᏂ ᎦᎸᎳᏗ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🫷🏻' => 'ᎠᎦᏍᎦᏂ ᎤᏩᏌᏙᏍᏗ ᎤᏬᏰᏂ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🫷🏼' => 'ᎠᎦᏍᎦᏂ ᎤᏩᏌᏙᏍᏗ ᎤᏬᏰᏂ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🫷🏽' => 'ᎠᎦᏍᎦᏂ ᎤᏩᏌᏙᏍᏗ ᎤᏬᏰᏂ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🫷🏾' => 'ᎠᎦᏍᎦᏂ ᎤᏩᏌᏙᏍᏗ ᎤᏬᏰᏂ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🫷🏿' => 'ᎠᎦᏍᎦᏂ ᎤᏩᏌᏙᏍᏗ ᎤᏬᏰᏂ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🫸🏻' => 'ᎠᎦᏘᏏ ᎤᏩᏌᏙᏍᏗ ᎤᏬᏰᏂ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🫸🏼' => 'ᎠᎦᏘᏏ ᎤᏩᏌᏙᏍᏗ ᎤᏬᏰᏂ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🫸🏽' => 'ᎠᎦᏘᏏ ᎤᏩᏌᏙᏍᏗ ᎤᏬᏰᏂ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🫸🏾' => 'ᎠᎦᏘᏏ ᎤᏩᏌᏙᏍᏗ ᎤᏬᏰᏂ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🫸🏿' => 'ᎠᎦᏘᏏ ᎤᏩᏌᏙᏍᏗ ᎤᏬᏰᏂ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👌🏻' => 'ᎣᏏᏊ ᎪᏯᏛ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👌🏼' => 'ᎣᏏᏊ ᎪᏯᏛ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👌🏽' => 'ᎣᏏᏊ ᎪᏯᏛ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👌🏾' => 'ᎣᏏᏊ ᎪᏯᏛ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👌🏿' => 'ᎣᏏᏊ ᎪᏯᏛ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤌🏻' => 'ᏗᏓᏇᏄᎩᏍᏗ ᏕᎦᏰᏌᏛ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🤌🏼' => 'ᏗᏓᏇᏄᎩᏍᏗ ᏕᎦᏰᏌᏛ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🤌🏽' => 'ᏗᏓᏇᏄᎩᏍᏗ ᏕᎦᏰᏌᏛ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤌🏾' => 'ᏗᏓᏇᏄᎩᏍᏗ ᏕᎦᏰᏌᏛ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤌🏿' => 'ᏗᏓᏇᏄᎩᏍᏗ ᏕᎦᏰᏌᏛ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤏🏻' => 'ᏗᏓᏇᏄᎩᏍᏗ ᎤᏬᏰᏂ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🤏🏼' => 'ᏗᏓᏇᏄᎩᏍᏗ ᎤᏬᏰᏂ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🤏🏽' => 'ᏗᏓᏇᏄᎩᏍᏗ ᎤᏬᏰᏂ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤏🏾' => 'ᏗᏓᏇᏄᎩᏍᏗ ᎤᏬᏰᏂ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤏🏿' => 'ᏗᏓᏇᏄᎩᏍᏗ ᎤᏬᏰᏂ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '✌🏻' => 'ᎤᏓᏠᏒ ᎤᏬᏱ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '✌🏼' => 'ᎤᏓᏠᏒ ᎤᏬᏱ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '✌🏽' => 'ᎤᏓᏠᏒ ᎤᏬᏱ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '✌🏾' => 'ᎤᏓᏠᏒ ᎤᏬᏱ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '✌🏿' => 'ᎤᏓᏠᏒ ᎤᏬᏱ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤞🏻' => 'ᏧᏓᎿᏫᏓ ᏕᎦᏰᏌᏛ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🤞🏼' => 'ᏧᏓᎿᏫᏓ ᏕᎦᏰᏌᏛ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🤞🏽' => 'ᏧᏓᎿᏫᏓ ᏕᎦᏰᏌᏛ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤞🏾' => 'ᏧᏓᎿᏫᏓ ᏕᎦᏰᏌᏛ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤞🏿' => 'ᏧᏓᎿᏫᏓ ᏕᎦᏰᏌᏛ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🫰🏻' => 'ᎤᏬᏰᏂ ᎾᎿ ᎠᏚᏂᎯ ᏯᏍᏓ ᎠᎴ ᎦᏰᏌᏛ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🫰🏼' => 'ᎤᏬᏰᏂ ᎾᎿ ᎠᏚᏂᎯ ᏯᏍᏓ ᎠᎴ ᎦᏰᏌᏛ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🫰🏽' => 'ᎤᏬᏰᏂ ᎾᎿ ᎠᏚᏂᎯ ᏯᏍᏓ ᎠᎴ ᎦᏰᏌᏛ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🫰🏾' => 'ᎤᏬᏰᏂ ᎾᎿ ᎠᏚᏂᎯ ᏯᏍᏓ ᎠᎴ ᎦᏰᏌᏛ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🫰🏿' => 'ᎤᏬᏰᏂ ᎾᎿ ᎠᏚᏂᎯ ᏯᏍᏓ ᎠᎴ ᎦᏰᏌᏛ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤟🏻' => 'ᎬᎨᏳᎢ ᎤᏬᏯᏂᏍᎩ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🤟🏼' => 'ᎬᎨᏳᎢ ᎤᏬᏯᏂᏍᎩ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🤟🏽' => 'ᎬᎨᏳᎢ ᎤᏬᏯᏂᏍᎩ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤟🏾' => 'ᎬᎨᏳᎢ ᎤᏬᏯᏂᏍᎩ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤟🏿' => 'ᎬᎨᏳᎢ ᎤᏬᏯᏂᏍᎩ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤘🏻' => 'ᎤᏲᎾ ᏓᏟᎶᏍᏛ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🤘🏼' => 'ᎤᏲᎾ ᏓᏟᎶᏍᏛ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🤘🏽' => 'ᎤᏲᎾ ᏓᏟᎶᏍᏛ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤘🏾' => 'ᎤᏲᎾ ᏓᏟᎶᏍᏛ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤘🏿' => 'ᎤᏲᎾ ᏓᏟᎶᏍᏛ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤙🏻' => 'ᏗᏍᏓᏁᎸᎩ ᎤᏬᏱ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🤙🏼' => 'ᏗᏍᏓᏁᎸᎩ ᎤᏬᏱ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🤙🏽' => 'ᏗᏍᏓᏁᎸᎩ ᎤᏬᏱ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤙🏾' => 'ᏗᏍᏓᏁᎸᎩ ᎤᏬᏱ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤙🏿' => 'ᏗᏍᏓᏁᎸᎩ ᎤᏬᏱ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👈🏻' => 'ᎣᏂᏗᏜᎪᏯᏗ ᎠᏍᏓᏩᏛᏍᏗ ᎠᏎᎯ ᎠᎦᏍᎦᏂ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👈🏼' => 'ᎣᏂᏗᏜᎪᏯᏗ ᎠᏍᏓᏩᏛᏍᏗ ᎠᏎᎯ ᎠᎦᏍᎦᏂ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👈🏽' => 'ᎣᏂᏗᏜᎪᏯᏗ ᎠᏍᏓᏩᏛᏍᏗ ᎠᏎᎯ ᎠᎦᏍᎦᏂ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👈🏾' => 'ᎣᏂᏗᏜᎪᏯᏗ ᎠᏍᏓᏩᏛᏍᏗ ᎠᏎᎯ ᎠᎦᏍᎦᏂ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👈🏿' => 'ᎣᏂᏗᏜᎪᏯᏗ ᎠᏍᏓᏩᏛᏍᏗ ᎠᏎᎯ ᎠᎦᏍᎦᏂ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👉🏻' => 'ᎣᏂᏗᏜᎪᏯᏗ ᎠᏍᏓᏩᏛᏍᏗ ᎠᏎᎯ ᎠᎦᏘᏏ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👉🏼' => 'ᎣᏂᏗᏜᎪᏯᏗ ᎠᏍᏓᏩᏛᏍᏗ ᎠᏎᎯ ᎠᎦᏘᏏ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👉🏽' => 'ᎣᏂᏗᏜᎪᏯᏗ ᎠᏍᏓᏩᏛᏍᏗ ᎠᏎᎯ ᎠᎦᏘᏏ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👉🏾' => 'ᎣᏂᏗᏜᎪᏯᏗ ᎠᏍᏓᏩᏛᏍᏗ ᎠᏎᎯ ᎠᎦᏘᏏ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👉🏿' => 'ᎣᏂᏗᏜᎪᏯᏗ ᎠᏍᏓᏩᏛᏍᏗ ᎠᏎᎯ ᎠᎦᏘᏏ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👆🏻' => 'ᎣᏂᏗᏜᎪᏯᏗ ᎠᏍᏓᏩᏛᏍᏗ ᏩᏎᎯᎲ ᎦᎸᎳᏓᎬᏘ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👆🏼' => 'ᎣᏂᏗᏜᎪᏯᏗ ᎠᏍᏓᏩᏛᏍᏗ ᏩᏎᎯᎲ ᎦᎸᎳᏓᎬᏘ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👆🏽' => 'ᎣᏂᏗᏜᎪᏯᏗ ᎠᏍᏓᏩᏛᏍᏗ ᏩᏎᎯᎲ ᎦᎸᎳᏓᎬᏘ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👆🏾' => 'ᎣᏂᏗᏜᎪᏯᏗ ᎠᏍᏓᏩᏛᏍᏗ ᏩᏎᎯᎲ ᎦᎸᎳᏓᎬᏘ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👆🏿' => 'ᎣᏂᏗᏜᎪᏯᏗ ᎠᏍᏓᏩᏛᏍᏗ ᏩᏎᎯᎲ ᎦᎸᎳᏓᎬᏘ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🖕🏻' => 'ᎠᏰᏟ ᎦᏰᏌᏛ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🖕🏼' => 'ᎠᏰᏟ ᎦᏰᏌᏛ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🖕🏽' => 'ᎠᏰᏟ ᎦᏰᏌᏛ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🖕🏾' => 'ᎠᏰᏟ ᎦᏰᏌᏛ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🖕🏿' => 'ᎠᏰᏟ ᎦᏰᏌᏛ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👇🏻' => 'ᎣᏂᏗᏜᎪᏯᏗ ᎠᏍᏓᏩᏛᏍᏗ ᏩᏎᎯᎲᎢ ᎡᎳᏗ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👇🏼' => 'ᎣᏂᏗᏜᎪᏯᏗ ᎠᏍᏓᏩᏛᏍᏗ ᏩᏎᎯᎲᎢ ᎡᎳᏗ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👇🏽' => 'ᎣᏂᏗᏜᎪᏯᏗ ᎠᏍᏓᏩᏛᏍᏗ ᏩᏎᎯᎲᎢ ᎡᎳᏗ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👇🏾' => 'ᎣᏂᏗᏜᎪᏯᏗ ᎠᏍᏓᏩᏛᏍᏗ ᏩᏎᎯᎲᎢ ᎡᎳᏗ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👇🏿' => 'ᎣᏂᏗᏜᎪᏯᏗ ᎠᏍᏓᏩᏛᏍᏗ ᏩᏎᎯᎲᎢ ᎡᎳᏗ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '☝🏻' => 'ᎠᏎᎯ ᏩᏎᎯᎲᎢ ᎦᎸᎳᏗ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '☝🏼' => 'ᎠᏎᎯ ᏩᏎᎯᎲᎢ ᎦᎸᎳᏗ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '☝🏽' => 'ᎠᏎᎯ ᏩᏎᎯᎲᎢ ᎦᎸᎳᏗ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '☝🏾' => 'ᎠᏎᎯ ᏩᏎᎯᎲᎢ ᎦᎸᎳᏗ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '☝🏿' => 'ᎠᏎᎯ ᏩᏎᎯᎲᎢ ᎦᎸᎳᏗ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🫵🏻' => 'ᎦᏰᏌᏛ ᎠᏓᏚᎯᏍᏙᏗ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🫵🏼' => 'ᎦᏰᏌᏛ ᎠᏓᏚᎯᏍᏙᏗ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🫵🏽' => 'ᎦᏰᏌᏛ ᎠᏓᏚᎯᏍᏙᏗ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🫵🏾' => 'ᎦᏰᏌᏛ ᎠᏓᏚᎯᏍᏙᏗ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🫵🏿' => 'ᎦᏰᏌᏛ ᎠᏓᏚᎯᏍᏙᏗ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👍🏻' => 'ᎤᏔᎾ ᎦᏰᏌᏛ ᎤᎵᏌᎳᏓ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👍🏼' => 'ᎤᏔᎾ ᎦᏰᏌᏛ ᎤᎵᏌᎳᏓ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👍🏽' => 'ᎤᏔᎾ ᎦᏰᏌᏛ ᎤᎵᏌᎳᏓ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👍🏾' => 'ᎤᏔᎾ ᎦᏰᏌᏛ ᎤᎵᏌᎳᏓ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👍🏿' => 'ᎤᏔᎾ ᎦᏰᏌᏛ ᎤᎵᏌᎳᏓ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👎🏻' => 'ᎤᏔᎾ ᎦᏰᏌᏛ ᎡᎳᏗᏜ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👎🏼' => 'ᎤᏔᎾ ᎦᏰᏌᏛ ᎡᎳᏗᏜ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👎🏽' => 'ᎤᏔᎾ ᎦᏰᏌᏛ ᎡᎳᏗᏜ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👎🏾' => 'ᎤᏔᎾ ᎦᏰᏌᏛ ᎡᎳᏗᏜ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👎🏿' => 'ᎤᏔᎾ ᎦᏰᏌᏛ ᎡᎳᏗᏜ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '✊🏻' => 'ᎠᎵᏇᏅ ᎠᏒᎵᏛᏅᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '✊🏼' => 'ᎠᎵᏇᏅ ᎠᏒᎵᏛᏅᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '✊🏽' => 'ᎠᎵᏇᏅ ᎠᏒᎵᏛᏅᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '✊🏾' => 'ᎠᎵᏇᏅ ᎠᏒᎵᏛᏅᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '✊🏿' => 'ᎠᎵᏇᏅ ᎠᏒᎵᏛᏅᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👊🏻' => 'ᏂᏓᏳᏍᏗᏛ ᎠᎵᏇᏅ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👊🏼' => 'ᏂᏓᏳᏍᏗᏛ ᎠᎵᏇᏅ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👊🏽' => 'ᏂᏓᏳᏍᏗᏛ ᎠᎵᏇᏅ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👊🏾' => 'ᏂᏓᏳᏍᏗᏛ ᎠᎵᏇᏅ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👊🏿' => 'ᏂᏓᏳᏍᏗᏛ ᎠᎵᏇᏅ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤛🏻' => 'ᎠᎦᏍᎦᏂ-ᏍᏈᎾ ᎤᎦᏙᏍᏓ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🤛🏼' => 'ᎠᎦᏍᎦᏂ-ᏍᏈᎾ ᎤᎦᏙᏍᏓ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🤛🏽' => 'ᎠᎦᏍᎦᏂ-ᏍᏈᎾ ᎤᎦᏙᏍᏓ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤛🏾' => 'ᎠᎦᏍᎦᏂ-ᏍᏈᎾ ᎤᎦᏙᏍᏓ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤛🏿' => 'ᎠᎦᏍᎦᏂ-ᏍᏈᎾ ᎤᎦᏙᏍᏓ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤜🏻' => 'ᎠᎦᏘᏏ-ᏩᎦᏘᎲ ᎠᎵᏇᏅ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🤜🏼' => 'ᎠᎦᏘᏏ-ᏩᎦᏘᎲ ᎠᎵᏇᏅ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🤜🏽' => 'ᎠᎦᏘᏏ-ᏩᎦᏘᎲ ᎠᎵᏇᏅ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤜🏾' => 'ᎠᎦᏘᏏ-ᏩᎦᏘᎲ ᎠᎵᏇᏅ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤜🏿' => 'ᎠᎦᏘᏏ-ᏩᎦᏘᎲ ᎠᎵᏇᏅ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👏🏻' => 'ᏓᏏᏛᏂᎲᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👏🏼' => 'ᏓᏏᏛᏂᎲᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👏🏽' => 'ᏓᏏᏛᏂᎲᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👏🏾' => 'ᏓᏏᏛᏂᎲᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👏🏿' => 'ᏓᏏᏛᏂᎲᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙌🏻' => 'ᏗᎪᏰᎾ ᏗᏌᎵᏛᏅᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🙌🏼' => 'ᏗᎪᏰᎾ ᏗᏌᎵᏛᏅᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🙌🏽' => 'ᏗᎪᏰᎾ ᏗᏌᎵᏛᏅᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙌🏾' => 'ᏗᎪᏰᎾ ᏗᏌᎵᏛᏅᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙌🏿' => 'ᏗᎪᏰᎾ ᏗᏌᎵᏛᏅᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🫶🏻' => 'ᎠᏓᏅᏙ ᏧᏬᏰᏂ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🫶🏼' => 'ᎠᏓᏅᏙ ᏧᏬᏰᏂ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🫶🏽' => 'ᎠᏓᏅᏙ ᏧᏬᏰᏂ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🫶🏾' => 'ᎠᏓᏅᏙ ᏧᏬᏰᏂ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🫶🏿' => 'ᎠᏓᏅᏙ ᏧᏬᏰᏂ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👐🏻' => 'ᏗᏚᎢᏓ ᏙᏬᏰᎾ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👐🏼' => 'ᏗᏚᎢᏓ ᏙᏬᏰᎾ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👐🏽' => 'ᏗᏚᎢᏓ ᏙᏬᏰᎾ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👐🏾' => 'ᏗᏚᎢᏓ ᏙᏬᏰᎾ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👐🏿' => 'ᏗᏚᎢᏓ ᏙᏬᏰᎾ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤲🏻' => 'ᏚᎾᏙᏯᏂᎠ ᎦᎸᎳᏗ ᎠᏒᏅᏍᏗ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🤲🏼' => 'ᏚᎾᏙᏯᏂᎠ ᎦᎸᎳᏗ ᎠᏒᏅᏍᏗ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🤲🏽' => 'ᏚᎾᏙᏯᏂᎠ ᎦᎸᎳᏗ ᎠᏒᏅᏍᏗ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤲🏾' => 'ᏚᎾᏙᏯᏂᎠ ᎦᎸᎳᏗ ᎠᏒᏅᏍᏗ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤲🏿' => 'ᏚᎾᏙᏯᏂᎠ ᎦᎸᎳᏗ ᎠᏒᏅᏍᏗ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤝🏻' => 'ᎠᏓᏲᎵᎲᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🤝🏼' => 'ᎠᏓᏲᎵᎲᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🤝🏽' => 'ᎠᏓᏲᎵᎲᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤝🏾' => 'ᎠᏓᏲᎵᎲᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤝🏿' => 'ᎠᏓᏲᎵᎲᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙏🏻' => 'ᏚᏆᏰᏅᏍᏛ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🙏🏼' => 'ᏚᏆᏰᏅᏍᏛ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🙏🏽' => 'ᏚᏆᏰᏅᏍᏛ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙏🏾' => 'ᏚᏆᏰᏅᏍᏛ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙏🏿' => 'ᏚᏆᏰᏅᏍᏛ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '✍🏻' => 'ᎤᏬᏱ ᎪᏪᎳᏅᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '✍🏼' => 'ᎤᏬᏱ ᎪᏪᎳᏅᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '✍🏽' => 'ᎤᏬᏱ ᎪᏪᎳᏅᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '✍🏾' => 'ᎤᏬᏱ ᎪᏪᎳᏅᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '✍🏿' => 'ᎤᏬᏱ ᎪᏪᎳᏅᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💅🏻' => 'ᎤᏑᎦᏢ ᎦᏅᎵᏰᏗ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '💅🏼' => 'ᎤᏑᎦᏢ ᎦᏅᎵᏰᏗ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '💅🏽' => 'ᎤᏑᎦᏢ ᎦᏅᎵᏰᏗ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💅🏾' => 'ᎤᏑᎦᏢ ᎦᏅᎵᏰᏗ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💅🏿' => 'ᎤᏑᎦᏢ ᎦᏅᎵᏰᏗ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤳🏻' => 'ᎣᏮᏌ ᏗᏓᏟᎶᏍᏔᏅᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🤳🏼' => 'ᎣᏮᏌ ᏗᏓᏟᎶᏍᏔᏅᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🤳🏽' => 'ᎣᏮᏌ ᏗᏓᏟᎶᏍᏔᏅᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤳🏾' => 'ᎣᏮᏌ ᏗᏓᏟᎶᏍᏔᏅᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤳🏿' => 'ᎣᏮᏌ ᏗᏓᏟᎶᏍᏔᏅᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💪🏻' => 'ᏫᎦᎳᎦ ᎤᏟᎸᏛ ᎦᎸᎳᏗᏟ ᎧᏃᎨᎾ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '💪🏼' => 'ᏫᎦᎳᎦ ᎤᏟᎸᏛ ᎦᎸᎳᏗᏟ ᎧᏃᎨᎾ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '💪🏽' => 'ᏫᎦᎳᎦ ᎤᏟᎸᏛ ᎦᎸᎳᏗᏟ ᎧᏃᎨᎾ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💪🏾' => 'ᏫᎦᎳᎦ ᎤᏟᎸᏛ ᎦᎸᎳᏗᏟ ᎧᏃᎨᎾ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💪🏿' => 'ᏫᎦᎳᎦ ᎤᏟᎸᏛ ᎦᎸᎳᏗᏟ ᎧᏃᎨᎾ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🦵🏻' => 'ᎦᏅᏍᎨᏂ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🦵🏼' => 'ᎦᏅᏍᎨᏂ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🦵🏽' => 'ᎦᏅᏍᎨᏂ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🦵🏾' => 'ᎦᏅᏍᎨᏂ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🦵🏿' => 'ᎦᏅᏍᎨᏂ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🦶🏻' => 'ᎤᎳᏏᏕᏂ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🦶🏼' => 'ᎤᎳᏏᏕᏂ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🦶🏽' => 'ᎤᎳᏏᏕᏂ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🦶🏾' => 'ᎤᎳᏏᏕᏂ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🦶🏿' => 'ᎤᎳᏏᏕᏂ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👂🏻' => 'ᎦᎴᏂ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👂🏼' => 'ᎦᎴᏂ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👂🏽' => 'ᎦᎴᏂ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👂🏾' => 'ᎦᎴᏂ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👂🏿' => 'ᎦᎴᏂ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🦻🏻' => 'ᎦᎴᏂ ᎬᏗ ᎠᏛᎩᏍᎬ ᎬᏙᏗ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🦻🏼' => 'ᎦᎴᏂ ᎬᏗ ᎠᏛᎩᏍᎬ ᎬᏙᏗ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🦻🏽' => 'ᎦᎴᏂ ᎬᏗ ᎠᏛᎩᏍᎬ ᎬᏙᏗ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🦻🏾' => 'ᎦᎴᏂ ᎬᏗ ᎠᏛᎩᏍᎬ ᎬᏙᏗ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🦻🏿' => 'ᎦᎴᏂ ᎬᏗ ᎠᏛᎩᏍᎬ ᎬᏙᏗ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👃🏻' => 'ᎧᏴᏐᎵ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👃🏼' => 'ᎧᏴᏐᎵ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👃🏽' => 'ᎧᏴᏐᎵ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👃🏾' => 'ᎧᏴᏐᎵ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👃🏿' => 'ᎧᏴᏐᎵ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👶🏻' => 'ᎤᏍᏗ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👶🏼' => 'ᎤᏍᏗ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👶🏽' => 'ᎤᏍᏗ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👶🏾' => 'ᎤᏍᏗ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👶🏿' => 'ᎤᏍᏗ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧒🏻' => 'ᎠᏲᏟ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧒🏼' => 'ᎠᏲᏟ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧒🏽' => 'ᎠᏲᏟ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧒🏾' => 'ᎠᏲᏟ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧒🏿' => 'ᎠᏲᏟ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👦🏻' => 'ᎠᏧᏣ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👦🏼' => 'ᎠᏧᏣ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👦🏽' => 'ᎠᏧᏣ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👦🏾' => 'ᎠᏧᏣ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👦🏿' => 'ᎠᏧᏣ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👧🏻' => 'ᎠᎨᏳᏣ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👧🏼' => 'ᎠᎨᏳᏣ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👧🏽' => 'ᎠᎨᏳᏣ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👧🏾' => 'ᎠᎨᏳᏣ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👧🏿' => 'ᎠᎨᏳᏣ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏻' => 'ᎤᏔᎾ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧑🏼' => 'ᎤᏔᎾ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧑🏽' => 'ᎤᏔᎾ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏾' => 'ᎤᏔᎾ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧑🏿' => 'ᎤᏔᎾ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👱🏻' => 'ᏴᏫ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᏓᎶᏂᎨ-ᎤᏍᏘᎩ',
    '👱🏼' => 'ᏴᏫ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᏓᎶᏂᎨ-ᎤᏍᏘᎩ',
    '👱🏽' => 'ᏴᏫ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᏓᎶᏂᎨ-ᎤᏍᏘᎩ',
    '👱🏾' => 'ᏴᏫ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᏓᎶᏂᎨ-ᎤᏍᏘᎩ',
    '👱🏿' => 'ᏴᏫ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᏓᎶᏂᎨ-ᎤᏍᏘᎩ',
    '👨🏻' => 'ᎠᏍᎦᏯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👨🏼' => 'ᎠᏍᎦᏯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👨🏽' => 'ᎠᏍᎦᏯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏾' => 'ᎠᏍᎦᏯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👨🏿' => 'ᎠᏍᎦᏯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧔🏻' => 'ᎠᏍᎦᏯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ, ᏗᎭᏄᎸᎯ',
    '🧔🏼' => 'ᎠᏍᎦᏯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ, ᏗᎭᏄᎸᎯ',
    '🧔🏽' => 'ᎠᏍᎦᏯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᏗᎭᏄᎸᎯ',
    '🧔🏾' => 'ᎠᏍᎦᏯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᏗᎭᏄᎸᎯ',
    '🧔🏿' => 'ᎠᏍᎦᏯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ, ᏗᎭᏄᎸᎯ',
    '👩🏻' => 'ᎠᎨᏯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👩🏼' => 'ᎠᎨᏯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👩🏽' => 'ᎠᎨᏯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏾' => 'ᎠᎨᏯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👩🏿' => 'ᎠᎨᏯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧓🏻' => 'ᎠᎦᏴᎵ ᎤᏔᎾ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧓🏼' => 'ᎠᎦᏴᎵ ᎤᏔᎾ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧓🏽' => 'ᎠᎦᏴᎵ ᎤᏔᎾ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧓🏾' => 'ᎠᎦᏴᎵ ᎤᏔᎾ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧓🏿' => 'ᎠᎦᏴᎵ ᎤᏔᎾ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👴🏻' => 'ᎤᏛᏐᏅ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👴🏼' => 'ᎤᏛᏐᏅ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👴🏽' => 'ᎤᏛᏐᏅ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👴🏾' => 'ᎤᏛᏐᏅ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👴🏿' => 'ᎤᏛᏐᏅ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👵🏻' => 'ᎠᎬᏴᎵᎨ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👵🏼' => 'ᎠᎬᏴᎵᎨ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👵🏽' => 'ᎠᎬᏴᎵᎨ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👵🏾' => 'ᎠᎬᏴᎵᎨ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👵🏿' => 'ᎠᎬᏴᎵᎨ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙍🏻' => 'ᏴᏫ ᎤᏓᏁᎪᏳ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🙍🏼' => 'ᏴᏫ ᎤᏓᏁᎪᏳ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🙍🏽' => 'ᏴᏫ ᎤᏓᏁᎪᏳ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙍🏾' => 'ᏴᏫ ᎤᏓᏁᎪᏳ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙍🏿' => 'ᏴᏫ ᎤᏓᏁᎪᏳ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙎🏻' => 'ᏴᏫ ᎤᏇᏟᎬ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🙎🏼' => 'ᏴᏫ ᎤᏇᏟᎬ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🙎🏽' => 'ᏴᏫ ᎤᏇᏟᎬ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙎🏾' => 'ᏴᏫ ᎤᏇᏟᎬ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙎🏿' => 'ᏴᏫ ᎤᏇᏟᎬ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙅🏻' => 'ᏴᏫ ᎾᏛᏁᎲ ᎥᏝ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🙅🏼' => 'ᏴᏫ ᎾᏛᏁᎲ ᎥᏝ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🙅🏽' => 'ᏴᏫ ᎾᏛᏁᎲ ᎥᏝ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙅🏾' => 'ᏴᏫ ᎾᏛᏁᎲ ᎥᏝ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙅🏿' => 'ᏴᏫ ᎾᏛᏁᎲ ᎥᏝ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙆🏻' => 'ᏴᏫ ᎠᏎᏟᏙᎲ ᎭᏩ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🙆🏼' => 'ᏴᏫ ᎠᏎᏟᏙᎲ ᎭᏩ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🙆🏽' => 'ᏴᏫ ᎠᏎᏟᏙᎲ ᎭᏩ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙆🏾' => 'ᏴᏫ ᎠᏎᏟᏙᎲ ᎭᏩ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙆🏿' => 'ᏴᏫ ᎠᏎᏟᏙᎲ ᎭᏩ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💁🏻' => 'ᏴᏫ ᎬᏂᎨᏒ ᏂᎬᏁᎲ ᏆᏂᏲᏍᏗ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '💁🏼' => 'ᏴᏫ ᎬᏂᎨᏒ ᏂᎬᏁᎲ ᏆᏂᏲᏍᏗ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '💁🏽' => 'ᏴᏫ ᎬᏂᎨᏒ ᏂᎬᏁᎲ ᏆᏂᏲᏍᏗ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💁🏾' => 'ᏴᏫ ᎬᏂᎨᏒ ᏂᎬᏁᎲ ᏆᏂᏲᏍᏗ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💁🏿' => 'ᏴᏫ ᎬᏂᎨᏒ ᏂᎬᏁᎲ ᏆᏂᏲᏍᏗ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙋🏻' => 'ᏴᏫ ᎤᏬᏰᎾ ᎠᎵᏌᎵᏛᏍᎬᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🙋🏼' => 'ᏴᏫ ᎤᏬᏰᎾ ᎠᎵᏌᎵᏛᏍᎬᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🙋🏽' => 'ᏴᏫ ᎤᏬᏰᎾ ᎠᎵᏌᎵᏛᏍᎬᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙋🏾' => 'ᏴᏫ ᎤᏬᏰᎾ ᎠᎵᏌᎵᏛᏍᎬᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙋🏿' => 'ᏴᏫ ᎤᏬᏰᎾ ᎠᎵᏌᎵᏛᏍᎬᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧏🏻' => 'ᏧᎵᎡᎾ ᏴᏫ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧏🏼' => 'ᏧᎵᎡᎾ ᏴᏫ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧏🏽' => 'ᏧᎵᎡᎾ ᏴᏫ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧏🏾' => 'ᏧᎵᎡᎾ ᏴᏫ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧏🏿' => 'ᏧᎵᎡᎾ ᏴᏫ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙇🏻' => 'ᏴᏫ ᎤᏘᏌᏘ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🙇🏼' => 'ᏴᏫ ᎤᏘᏌᏘ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🙇🏽' => 'ᏴᏫ ᎤᏘᏌᏘ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙇🏾' => 'ᏴᏫ ᎤᏘᏌᏘ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🙇🏿' => 'ᏴᏫ ᎤᏘᏌᏘ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤦🏻' => 'ᏴᏫ ᎤᎧᏛᎢ ᎠᏓᏏᏔᏗᏍᎬᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🤦🏼' => 'ᏴᏫ ᎤᎧᏛᎢ ᎠᏓᏏᏔᏗᏍᎬᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🤦🏽' => 'ᏴᏫ ᎤᎧᏛᎢ ᎠᏓᏏᏔᏗᏍᎬᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤦🏾' => 'ᏴᏫ ᎤᎧᏛᎢ ᎠᏓᏏᏔᏗᏍᎬᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤦🏿' => 'ᏴᏫ ᎤᎧᏛᎢ ᎠᏓᏏᏔᏗᏍᎬᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤷🏻' => 'ᏴᏫ ᏗᎦᏅᏬ ᏚᏌᎳᏛ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🤷🏼' => 'ᏴᏫ ᏗᎦᏅᏬ ᏚᏌᎳᏛ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🤷🏽' => 'ᏴᏫ ᏗᎦᏅᏬ ᏚᏌᎳᏛ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤷🏾' => 'ᏴᏫ ᏗᎦᏅᏬ ᏚᏌᎳᏛ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤷🏿' => 'ᏴᏫ ᏗᎦᏅᏬ ᏚᏌᎳᏛ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👮🏻' => 'ᏗᏓᏂᏱᏍᎩ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👮🏼' => 'ᏗᏓᏂᏱᏍᎩ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👮🏽' => 'ᏗᏓᏂᏱᏍᎩ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👮🏾' => 'ᏗᏓᏂᏱᏍᎩ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👮🏿' => 'ᏗᏓᏂᏱᏍᎩ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🕵🏻' => 'ᎤᎦᏛᏂᏙᎯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🕵🏼' => 'ᎤᎦᏛᏂᏙᎯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🕵🏽' => 'ᎤᎦᏛᏂᏙᎯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🕵🏾' => 'ᎤᎦᏛᏂᏙᎯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🕵🏿' => 'ᎤᎦᏛᏂᏙᎯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💂🏻' => 'ᎠᏯᏫᏍᎩ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '💂🏼' => 'ᎠᏯᏫᏍᎩ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '💂🏽' => 'ᎠᏯᏫᏍᎩ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💂🏾' => 'ᎠᏯᏫᏍᎩ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💂🏿' => 'ᎠᏯᏫᏍᎩ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🥷🏻' => 'ᏂᏅᏣ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🥷🏼' => 'ᏂᏅᏣ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🥷🏽' => 'ᏂᏅᏣ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🥷🏾' => 'ᏂᏅᏣ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🥷🏿' => 'ᏂᏅᏣ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👷🏻' => 'ᏗᏁᏍᎨᏍᎩ ᏧᎸᏫᏍᏓᏁᎯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👷🏼' => 'ᏗᏁᏍᎨᏍᎩ ᏧᎸᏫᏍᏓᏁᎯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👷🏽' => 'ᏗᏁᏍᎨᏍᎩ ᏧᎸᏫᏍᏓᏁᎯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👷🏾' => 'ᏗᏁᏍᎨᏍᎩ ᏧᎸᏫᏍᏓᏁᎯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👷🏿' => 'ᏗᏁᏍᎨᏍᎩ ᏧᎸᏫᏍᏓᏁᎯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🫅🏻' => 'ᎤᎬᏫᏳᎯ ᎤᎵᏍᏚᎳ ᎠᏕᎳ ᏓᎶᏂᎨ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🫅🏼' => 'ᎤᎬᏫᏳᎯ ᎤᎵᏍᏚᎳ ᎠᏕᎳ ᏓᎶᏂᎨ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🫅🏽' => 'ᎤᎬᏫᏳᎯ ᎤᎵᏍᏚᎳ ᎠᏕᎳ ᏓᎶᏂᎨ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🫅🏾' => 'ᎤᎬᏫᏳᎯ ᎤᎵᏍᏚᎳ ᎠᏕᎳ ᏓᎶᏂᎨ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🫅🏿' => 'ᎤᎬᏫᏳᎯ ᎤᎵᏍᏚᎳ ᎠᏕᎳ ᏓᎶᏂᎨ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤴🏻' => 'ᎠᏫᎾ ᎤᎬᏬᏳᎯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🤴🏼' => 'ᎠᏫᎾ ᎤᎬᏬᏳᎯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🤴🏽' => 'ᎠᏫᎾ ᎤᎬᏬᏳᎯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤴🏾' => 'ᎠᏫᎾ ᎤᎬᏬᏳᎯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤴🏿' => 'ᎠᏫᎾ ᎤᎬᏬᏳᎯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👸🏻' => 'ᎠᏔ ᎤᎬᏫᏳᎯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👸🏼' => 'ᎠᏔ ᎤᎬᏫᏳᎯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👸🏽' => 'ᎠᏔ ᎤᎬᏫᏳᎯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👸🏾' => 'ᎠᏔ ᎤᎬᏫᏳᎯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👸🏿' => 'ᎠᏔ ᎤᎬᏫᏳᎯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👳🏻' => 'ᏴᏫ ᎦᎸᏪᏍᏓᏅ ᎤᎵᏍᏚᎳ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👳🏼' => 'ᏴᏫ ᎦᎸᏪᏍᏓᏅ ᎤᎵᏍᏚᎳ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👳🏽' => 'ᏴᏫ ᎦᎸᏪᏍᏓᏅ ᎤᎵᏍᏚᎳ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👳🏾' => 'ᏴᏫ ᎦᎸᏪᏍᏓᏅ ᎤᎵᏍᏚᎳ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👳🏿' => 'ᏴᏫ ᎦᎸᏪᏍᏓᏅ ᎤᎵᏍᏚᎳ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👲🏻' => 'ᎠᏍᎦᏯ ᏣᏂᏏ ᎤᎵᏍᏇᏚᎩ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👲🏼' => 'ᎠᏍᎦᏯ ᏣᏂᏏ ᎤᎵᏍᏇᏚᎩ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👲🏽' => 'ᎠᏍᎦᏯ ᏣᏂᏏ ᎤᎵᏍᏇᏚᎩ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👲🏾' => 'ᎠᏍᎦᏯ ᏣᏂᏏ ᎤᎵᏍᏇᏚᎩ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👲🏿' => 'ᎠᏍᎦᏯ ᏣᏂᏏ ᎤᎵᏍᏇᏚᎩ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧕🏻' => 'ᎠᎨᏯ ᎤᎵᏍᏆᏃᎯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧕🏼' => 'ᎠᎨᏯ ᎤᎵᏍᏆᏃᎯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧕🏽' => 'ᎠᎨᏯ ᎤᎵᏍᏆᏃᎯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧕🏾' => 'ᎠᎨᏯ ᎤᎵᏍᏆᏃᎯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧕🏿' => 'ᎠᎨᏯ ᎤᎵᏍᏆᏃᎯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤵🏻' => 'ᎠᏍᎦᏯ ᎤᏍᏓᏯᎬᏍᏗ ᏧᏄᏩ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🤵🏼' => 'ᎠᏍᎦᏯ ᎤᏍᏓᏯᎬᏍᏗ ᏧᏄᏩ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🤵🏽' => 'ᎠᏍᎦᏯ ᎤᏍᏓᏯᎬᏍᏗ ᏧᏄᏩ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤵🏾' => 'ᎠᏍᎦᏯ ᎤᏍᏓᏯᎬᏍᏗ ᏧᏄᏩ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤵🏿' => 'ᎠᏍᎦᏯ ᎤᏍᏓᏯᎬᏍᏗ ᏧᏄᏩ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👰🏻' => 'ᏣᎦᏨᏍᏔᏂᏓ ᎠᎨᏯ ᎤᏨᏅᎯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👰🏼' => 'ᏣᎦᏨᏍᏔᏂᏓ ᎠᎨᏯ ᎤᏨᏅᎯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👰🏽' => 'ᏣᎦᏨᏍᏔᏂᏓ ᎠᎨᏯ ᎤᏨᏅᎯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👰🏾' => 'ᏣᎦᏨᏍᏔᏂᏓ ᎠᎨᏯ ᎤᏨᏅᎯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👰🏿' => 'ᏣᎦᏨᏍᏔᏂᏓ ᎠᎨᏯ ᎤᏨᏅᎯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤰🏻' => 'ᎦᏁᎵᏓ ᎠᎨᏯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🤰🏼' => 'ᎦᏁᎵᏓ ᎠᎨᏯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🤰🏽' => 'ᎦᏁᎵᏓ ᎠᎨᏯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤰🏾' => 'ᎦᏁᎵᏓ ᎠᎨᏯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤰🏿' => 'ᎦᏁᎵᏓ ᎠᎨᏯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🫃🏻' => 'ᎦᏁᎵᏓ ᎠᏍᎦᏯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🫃🏼' => 'ᎦᏁᎵᏓ ᎠᏍᎦᏯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🫃🏽' => 'ᎦᏁᎵᏓ ᎠᏍᎦᏯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🫃🏾' => 'ᎦᏁᎵᏓ ᎠᏍᎦᏯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🫃🏿' => 'ᎦᏁᎵᏓ ᎠᏍᎦᏯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🫄🏻' => 'ᎦᏁᎵᏓ ᏴᏫ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🫄🏼' => 'ᎦᏁᎵᏓ ᏴᏫ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🫄🏽' => 'ᎦᏁᎵᏓ ᏴᏫ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🫄🏾' => 'ᎦᏁᎵᏓ ᏴᏫ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🫄🏿' => 'ᎦᏁᎵᏓ ᏴᏫ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤱🏻' => 'ᏧᏓᏍᏓᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🤱🏼' => 'ᏧᏓᏍᏓᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🤱🏽' => 'ᏧᏓᏍᏓᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤱🏾' => 'ᏧᏓᏍᏓᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤱🏿' => 'ᏧᏓᏍᏓᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👼🏻' => 'ᎤᏍᏗ ᏗᎧᎿᏩᏗᏙᎯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👼🏼' => 'ᎤᏍᏗ ᏗᎧᎿᏩᏗᏙᎯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👼🏽' => 'ᎤᏍᏗ ᏗᎧᎿᏩᏗᏙᎯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👼🏾' => 'ᎤᏍᏗ ᏗᎧᎿᏩᏗᏙᎯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👼🏿' => 'ᎤᏍᏗ ᏗᎧᎿᏩᏗᏙᎯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🎅🏻' => 'ᏧᏠᎦᎴᏓ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🎅🏼' => 'ᏧᏠᎦᎴᏓ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🎅🏽' => 'ᏧᏠᎦᎴᏓ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🎅🏾' => 'ᏧᏠᎦᎴᏓ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🎅🏿' => 'ᏧᏠᎦᎴᏓ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤶🏻' => 'ᎠᎨᏯ ᎦᏁᎵ. ᏧᏠᎦᎴᏓ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🤶🏼' => 'ᎠᎨᏯ ᎦᏁᎵ. ᏧᏠᎦᎴᏓ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🤶🏽' => 'ᎠᎨᏯ ᎦᏁᎵ. ᏧᏠᎦᎴᏓ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤶🏾' => 'ᎠᎨᏯ ᎦᏁᎵ. ᏧᏠᎦᎴᏓ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤶🏿' => 'ᎠᎨᏯ ᎦᏁᎵ. ᏧᏠᎦᎴᏓ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🦸🏻' => 'ᏄᎬᏫᏳᏒᎩ ᏩᏥᎸᏉᏛ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🦸🏼' => 'ᏄᎬᏫᏳᏒᎩ ᏩᏥᎸᏉᏛ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🦸🏽' => 'ᏄᎬᏫᏳᏒᎩ ᏩᏥᎸᏉᏛ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🦸🏾' => 'ᏄᎬᏫᏳᏒᎩ ᏩᏥᎸᏉᏛ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🦸🏿' => 'ᏄᎬᏫᏳᏒᎩ ᏩᏥᎸᏉᏛ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🦹🏻' => 'ᏄᎬᏫᏳᏒᎩ ᎠᏍᎦᏂ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🦹🏼' => 'ᏄᎬᏫᏳᏒᎩ ᎠᏍᎦᏂ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🦹🏽' => 'ᏄᎬᏫᏳᏒᎩ ᎠᏍᎦᏂ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🦹🏾' => 'ᏄᎬᏫᏳᏒᎩ ᎠᏍᎦᏂ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🦹🏿' => 'ᏄᎬᏫᏳᏒᎩ ᎠᏍᎦᏂ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧙🏻' => 'ᎠᏓᏪ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧙🏼' => 'ᎠᏓᏪ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧙🏽' => 'ᎠᏓᏪ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧙🏾' => 'ᎠᏓᏪ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧙🏿' => 'ᎠᏓᏪ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧚🏻' => 'ᏴᏫ ᎤᏍᏗ ᎦᏃᎯᎵᏙᎯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧚🏼' => 'ᏴᏫ ᎤᏍᏗ ᎦᏃᎯᎵᏙᎯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧚🏽' => 'ᏴᏫ ᎤᏍᏗ ᎦᏃᎯᎵᏙᎯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧚🏾' => 'ᏴᏫ ᎤᏍᏗ ᎦᏃᎯᎵᏙᎯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧚🏿' => 'ᏴᏫ ᎤᏍᏗ ᎦᏃᎯᎵᏙᎯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧛🏻' => 'ᎩᎦ ᎠᏓᏁᎩᎡᎯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧛🏼' => 'ᎩᎦ ᎠᏓᏁᎩᎡᎯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧛🏽' => 'ᎩᎦ ᎠᏓᏁᎩᎡᎯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧛🏾' => 'ᎩᎦ ᎠᏓᏁᎩᎡᎯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧛🏿' => 'ᎩᎦ ᎠᏓᏁᎩᎡᎯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧜🏻' => 'ᏴᏫ ᎠᏣᏗ ᎤᎬᎭᏟ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧜🏼' => 'ᏴᏫ ᎠᏣᏗ ᎤᎬᎭᏟ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧜🏽' => 'ᏴᏫ ᎠᏣᏗ ᎤᎬᎭᏟ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧜🏾' => 'ᏴᏫ ᎠᏣᏗ ᎤᎬᎭᏟ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧜🏿' => 'ᏴᏫ ᎠᏣᏗ ᎤᎬᎭᏟ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧝🏻' => 'ᏴᏫ ᎤᏍᏆᏂᎪᏗᏳ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧝🏼' => 'ᏴᏫ ᎤᏍᏆᏂᎪᏗᏳ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧝🏽' => 'ᏴᏫ ᎤᏍᏆᏂᎪᏗᏳ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧝🏾' => 'ᏴᏫ ᎤᏍᏆᏂᎪᏗᏳ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧝🏿' => 'ᏴᏫ ᎤᏍᏆᏂᎪᏗᏳ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💆🏻' => 'ᏴᏫ ᎠᏥᏓᏍᎪᎵᏰᏍᎬᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '💆🏼' => 'ᏴᏫ ᎠᏥᏓᏍᎪᎵᏰᏍᎬᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '💆🏽' => 'ᏴᏫ ᎠᏥᏓᏍᎪᎵᏰᏍᎬᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💆🏾' => 'ᏴᏫ ᎠᏥᏓᏍᎪᎵᏰᏍᎬᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💆🏿' => 'ᏴᏫ ᎠᏥᏓᏍᎪᎵᏰᏍᎬᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💇🏻' => 'ᏴᏫ ᎾᏛᏁᎲ ᎠᎵᏍᏙᏰᏗ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '💇🏼' => 'ᏴᏫ ᎾᏛᏁᎲ ᎠᎵᏍᏙᏰᏗ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '💇🏽' => 'ᏴᏫ ᎾᏛᏁᎲ ᎠᎵᏍᏙᏰᏗ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💇🏾' => 'ᏴᏫ ᎾᏛᏁᎲ ᎠᎵᏍᏙᏰᏗ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💇🏿' => 'ᏴᏫ ᎾᏛᏁᎲ ᎠᎵᏍᏙᏰᏗ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🚶🏻' => 'ᏴᏫ ᎠᏨᏏᏰ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🚶🏼' => 'ᏴᏫ ᎠᏨᏏᏰ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🚶🏽' => 'ᏴᏫ ᎠᏨᏏᏰ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🚶🏾' => 'ᏴᏫ ᎠᏨᏏᏰ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🚶🏿' => 'ᏴᏫ ᎠᏨᏏᏰ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧍🏻' => 'ᏴᏫ ᎦᏙᎦ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧍🏼' => 'ᏴᏫ ᎦᏙᎦ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧍🏽' => 'ᏴᏫ ᎦᏙᎦ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧍🏾' => 'ᏴᏫ ᎦᏙᎦ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧍🏿' => 'ᏴᏫ ᎦᏙᎦ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧎🏻' => 'ᏴᏫ ᏕᏥᎾᏆᎾ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧎🏼' => 'ᏴᏫ ᏕᏥᎾᏆᎾ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧎🏽' => 'ᏴᏫ ᏕᏥᎾᏆᎾ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧎🏾' => 'ᏴᏫ ᏕᏥᎾᏆᎾ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧎🏿' => 'ᏴᏫ ᏕᏥᎾᏆᎾ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏃🏻' => 'ᏴᏫ ᎠᏛᏟᏒᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🏃🏼' => 'ᏴᏫ ᎠᏛᏟᏒᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🏃🏽' => 'ᏴᏫ ᎠᏛᏟᏒᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏃🏾' => 'ᏴᏫ ᎠᏛᏟᏒᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏃🏿' => 'ᏴᏫ ᎠᏛᏟᏒᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💃🏻' => 'ᎠᎨᏯ ᎠᎵᏍᎩᏍᎩ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '💃🏼' => 'ᎠᎨᏯ ᎠᎵᏍᎩᏍᎩ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '💃🏽' => 'ᎠᎨᏯ ᎠᎵᏍᎩᏍᎩ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💃🏾' => 'ᎠᎨᏯ ᎠᎵᏍᎩᏍᎩ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💃🏿' => 'ᎠᎨᏯ ᎠᎵᏍᎩᏍᎩ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🕺🏻' => 'ᎠᏍᎦᏯ ᎠᎵᏍᎩᏍᎬ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🕺🏼' => 'ᎠᏍᎦᏯ ᎠᎵᏍᎩᏍᎬ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🕺🏽' => 'ᎠᏍᎦᏯ ᎠᎵᏍᎩᏍᎬ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🕺🏾' => 'ᎠᏍᎦᏯ ᎠᎵᏍᎩᏍᎬ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🕺🏿' => 'ᎠᏍᎦᏯ ᎠᎵᏍᎩᏍᎬ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🕴🏻' => 'ᎠᏍᎦᏯ ᏚᎸᏫᏍᏓᏁᎯ ᏧᏠᏱᎭ ᏓᎴᎲᏍᎬᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🕴🏼' => 'ᎠᏍᎦᏯ ᏚᎸᏫᏍᏓᏁᎯ ᏧᏠᏱᎭ ᏓᎴᎲᏍᎬᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🕴🏽' => 'ᎠᏍᎦᏯ ᏚᎸᏫᏍᏓᏁᎯ ᏧᏠᏱᎭ ᏓᎴᎲᏍᎬᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🕴🏾' => 'ᎠᏍᎦᏯ ᏚᎸᏫᏍᏓᏁᎯ ᏧᏠᏱᎭ ᏓᎴᎲᏍᎬᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🕴🏿' => 'ᎠᏍᎦᏯ ᏚᎸᏫᏍᏓᏁᎯ ᏧᏠᏱᎭ ᏓᎴᎲᏍᎬᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👯🏻' => 'ᏴᏫ ᏥᏍᏚ ᏗᎦᎴ ᎤᏂᏍᏆᎸᎡᎲᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👯🏼' => 'ᏴᏫ ᏥᏍᏚ ᏗᎦᎴ ᎤᏂᏍᏆᎸᎡᎲᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👯🏽' => 'ᏴᏫ ᏥᏍᏚ ᏗᎦᎴ ᎤᏂᏍᏆᎸᎡᎲᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👯🏾' => 'ᏴᏫ ᏥᏍᏚ ᏗᎦᎴ ᎤᏂᏍᏆᎸᎡᎲᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👯🏿' => 'ᏴᏫ ᏥᏍᏚ ᏗᎦᎴ ᎤᏂᏍᏆᎸᎡᎲᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧖🏻' => 'ᎩᎶ ᎠᏯᎠ ᎠᏔᎶᎴᎬ ᎧᏅᏑᎸ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧖🏼' => 'ᎩᎶ ᎠᏯᎠ ᎠᏔᎶᎴᎬ ᎧᏅᏑᎸ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧖🏽' => 'ᎩᎶ ᎠᏯᎠ ᎠᏔᎶᎴᎬ ᎧᏅᏑᎸ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧖🏾' => 'ᎩᎶ ᎠᏯᎠ ᎠᏔᎶᎴᎬ ᎧᏅᏑᎸ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧖🏿' => 'ᎩᎶ ᎠᏯᎠ ᎠᏔᎶᎴᎬ ᎧᏅᏑᎸ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧗🏻' => 'ᏴᏫ ᎦᎵᏙᎭ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧗🏼' => 'ᏴᏫ ᎦᎵᏙᎭ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧗🏽' => 'ᏴᏫ ᎦᎵᏙᎭ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧗🏾' => 'ᏴᏫ ᎦᎵᏙᎭ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧗🏿' => 'ᏴᏫ ᎦᎵᏙᎭ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏇🏻' => 'ᏐᏈᎵ ᏓᎾᏙᎩᏯᏍᎬᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🏇🏼' => 'ᏐᏈᎵ ᏓᎾᏙᎩᏯᏍᎬᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🏇🏽' => 'ᏐᏈᎵ ᏓᎾᏙᎩᏯᏍᎬᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏇🏾' => 'ᏐᏈᎵ ᏓᎾᏙᎩᏯᏍᎬᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏇🏿' => 'ᏐᏈᎵ ᏓᎾᏙᎩᏯᏍᎬᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏂🏻' => 'ᎥᏂᏥ ᏗᏟᎾᏒᏙᏗ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🏂🏼' => 'ᎥᏂᏥ ᏗᏟᎾᏒᏙᏗ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🏂🏽' => 'ᎥᏂᏥ ᏗᏟᎾᏒᏙᏗ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏂🏾' => 'ᎥᏂᏥ ᏗᏟᎾᏒᏙᏗ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏂🏿' => 'ᎥᏂᏥ ᏗᏟᎾᏒᏙᏗ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏌🏻' => 'ᎠᏏᏴᏫ ᎪᏍᏛᏂᎲᎢ ᏍᏆᏞᏍᏗ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🏌🏼' => 'ᎠᏏᏴᏫ ᎪᏍᏛᏂᎲᎢ ᏍᏆᏞᏍᏗ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🏌🏽' => 'ᎠᏏᏴᏫ ᎪᏍᏛᏂᎲᎢ ᏍᏆᏞᏍᏗ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏌🏾' => 'ᎠᏏᏴᏫ ᎪᏍᏛᏂᎲᎢ ᏍᏆᏞᏍᏗ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏌🏿' => 'ᎠᏏᏴᏫ ᎪᏍᏛᏂᎲᎢ ᏍᏆᏞᏍᏗ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏄🏻' => 'ᏴᏫ ᎠᎹ ᏓᏍᏗᎳᏁᎬ ᎡᏙᎯ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🏄🏼' => 'ᏴᏫ ᎠᎹ ᏓᏍᏗᎳᏁᎬ ᎡᏙᎯ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🏄🏽' => 'ᏴᏫ ᎠᎹ ᏓᏍᏗᎳᏁᎬ ᎡᏙᎯ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏄🏾' => 'ᏴᏫ ᎠᎹ ᏓᏍᏗᎳᏁᎬ ᎡᏙᎯ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏄🏿' => 'ᏴᏫ ᎠᎹ ᏓᏍᏗᎳᏁᎬ ᎡᏙᎯ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🚣🏻' => 'ᏴᏫ ᎦᎦᏪᏍᎦ ᏥᏳ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🚣🏼' => 'ᏴᏫ ᎦᎦᏪᏍᎦ ᏥᏳ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🚣🏽' => 'ᏴᏫ ᎦᎦᏪᏍᎦ ᏥᏳ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🚣🏾' => 'ᏴᏫ ᎦᎦᏪᏍᎦ ᏥᏳ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🚣🏿' => 'ᏴᏫ ᎦᎦᏪᏍᎦ ᏥᏳ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏊🏻' => 'ᏴᏫ ᎠᏓᏬ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🏊🏼' => 'ᏴᏫ ᎠᏓᏬ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🏊🏽' => 'ᏴᏫ ᎠᏓᏬ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏊🏾' => 'ᏴᏫ ᎠᏓᏬ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏊🏿' => 'ᏴᏫ ᎠᏓᏬ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '⛹🏻' => 'ᏴᏫ ᏍᏆᏞᏍᏗ ᎠᏓᏓᎨᎬ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '⛹🏼' => 'ᏴᏫ ᏍᏆᏞᏍᏗ ᎠᏓᏓᎨᎬ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '⛹🏽' => 'ᏴᏫ ᏍᏆᏞᏍᏗ ᎠᏓᏓᎨᎬ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '⛹🏾' => 'ᏴᏫ ᏍᏆᏞᏍᏗ ᎠᏓᏓᎨᎬ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '⛹🏿' => 'ᏴᏫ ᏍᏆᏞᏍᏗ ᎠᏓᏓᎨᎬ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏋🏻' => 'ᏴᏫ ᏓᎵᏌᎳᏗᏍᎬᎢ ᏧᏓᎨᏓ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🏋🏼' => 'ᏴᏫ ᏓᎵᏌᎳᏗᏍᎬᎢ ᏧᏓᎨᏓ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🏋🏽' => 'ᏴᏫ ᏓᎵᏌᎳᏗᏍᎬᎢ ᏧᏓᎨᏓ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏋🏾' => 'ᏴᏫ ᏓᎵᏌᎳᏗᏍᎬᎢ ᏧᏓᎨᏓ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏋🏿' => 'ᏴᏫ ᏓᎵᏌᎳᏗᏍᎬᎢ ᏧᏓᎨᏓ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🚴🏻' => 'ᏴᏫ ᏓᏝᏱᏍᎬᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🚴🏼' => 'ᏴᏫ ᏓᏝᏱᏍᎬᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🚴🏽' => 'ᏴᏫ ᏓᏝᏱᏍᎬᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🚴🏾' => 'ᏴᏫ ᏓᏝᏱᏍᎬᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🚴🏿' => 'ᏴᏫ ᏓᏝᏱᏍᎬᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🚵🏻' => 'ᏴᏫ ᎤᏅᏓᏢ ᏔᎵ ᏗᎦᏩᏘ ᎤᎩᎸᏗ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🚵🏼' => 'ᏴᏫ ᎤᏅᏓᏢ ᏔᎵ ᏗᎦᏩᏘ ᎤᎩᎸᏗ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🚵🏽' => 'ᏴᏫ ᎤᏅᏓᏢ ᏔᎵ ᏗᎦᏩᏘ ᎤᎩᎸᏗ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🚵🏾' => 'ᏴᏫ ᎤᏅᏓᏢ ᏔᎵ ᏗᎦᏩᏘ ᎤᎩᎸᏗ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🚵🏿' => 'ᏴᏫ ᎤᏅᏓᏢ ᏔᎵ ᏗᎦᏩᏘ ᎤᎩᎸᏗ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤸🏻' => 'ᏴᏫ ᏓᏁᏍᏆᏕᎬ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🤸🏼' => 'ᏴᏫ ᏓᏁᏍᏆᏕᎬ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🤸🏽' => 'ᏴᏫ ᏓᏁᏍᏆᏕᎬ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤸🏾' => 'ᏴᏫ ᏓᏁᏍᏆᏕᎬ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤸🏿' => 'ᏴᏫ ᏓᏁᏍᏆᏕᎬ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤼🏻' => 'ᎠᏂᏴᏫ ᏓᏁᎯᎲ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🤼🏼' => 'ᎠᏂᏴᏫ ᏓᏁᎯᎲ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🤼🏽' => 'ᎠᏂᏴᏫ ᏓᏁᎯᎲ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤼🏾' => 'ᎠᏂᏴᏫ ᏓᏁᎯᎲ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤼🏿' => 'ᎠᏂᏴᏫ ᏓᏁᎯᎲ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤽🏻' => 'ᏴᏫ ᏓᏁᎶᎲᏍᎬ ᎠᎹ ᎠᎳᏍᎦᎵᏙᏗ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🤽🏼' => 'ᏴᏫ ᏓᏁᎶᎲᏍᎬ ᎠᎹ ᎠᎳᏍᎦᎵᏙᏗ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🤽🏽' => 'ᏴᏫ ᏓᏁᎶᎲᏍᎬ ᎠᎹ ᎠᎳᏍᎦᎵᏙᏗ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤽🏾' => 'ᏴᏫ ᏓᏁᎶᎲᏍᎬ ᎠᎹ ᎠᎳᏍᎦᎵᏙᏗ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤽🏿' => 'ᏴᏫ ᏓᏁᎶᎲᏍᎬ ᎠᎹ ᎠᎳᏍᎦᎵᏙᏗ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤾🏻' => 'ᏴᏫ ᏓᏁᎶᎲᏍᎬ ᏍᏆᏞᏍᏗ ᎦᎸᏛᏂᏍᏙᏗ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🤾🏼' => 'ᏴᏫ ᏓᏁᎶᎲᏍᎬ ᏍᏆᏞᏍᏗ ᎦᎸᏛᏂᏍᏙᏗ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🤾🏽' => 'ᏴᏫ ᏓᏁᎶᎲᏍᎬ ᏍᏆᏞᏍᏗ ᎦᎸᏛᏂᏍᏙᏗ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤾🏾' => 'ᏴᏫ ᏓᏁᎶᎲᏍᎬ ᏍᏆᏞᏍᏗ ᎦᎸᏛᏂᏍᏙᏗ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤾🏿' => 'ᏴᏫ ᏓᏁᎶᎲᏍᎬ ᏍᏆᏞᏍᏗ ᎦᎸᏛᏂᏍᏙᏗ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤹🏻' => 'ᏴᏫ ᏓᏍᏆᏞᏏᏙᎲᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🤹🏼' => 'ᏴᏫ ᏓᏍᏆᏞᏏᏙᎲᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🤹🏽' => 'ᏴᏫ ᏓᏍᏆᏞᏏᏙᎲᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤹🏾' => 'ᏴᏫ ᏓᏍᏆᏞᏏᏙᎲᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🤹🏿' => 'ᏴᏫ ᏓᏍᏆᏞᏏᏙᎲᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧘🏻' => 'ᏴᏫ ᏚᏓᏝᏗᏍᏗ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🧘🏼' => 'ᏴᏫ ᏚᏓᏝᏗᏍᏗ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🧘🏽' => 'ᏴᏫ ᏚᏓᏝᏗᏍᏗ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧘🏾' => 'ᏴᏫ ᏚᏓᏝᏗᏍᏗ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🧘🏿' => 'ᏴᏫ ᏚᏓᏝᏗᏍᏗ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🛀🏻' => 'ᏴᏫ ᎠᏓᏬᏍᎬᎢ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🛀🏼' => 'ᏴᏫ ᎠᏓᏬᏍᎬᎢ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🛀🏽' => 'ᏴᏫ ᎠᏓᏬᏍᎬᎢ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🛀🏾' => 'ᏴᏫ ᎠᏓᏬᏍᎬᎢ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🛀🏿' => 'ᏴᏫ ᎠᏓᏬᏍᎬᎢ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🛌🏻' => 'ᏴᏫ ᎦᏂᏟ ᎦᏅᎬ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🛌🏼' => 'ᏴᏫ ᎦᏂᏟ ᎦᏅᎬ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🛌🏽' => 'ᏴᏫ ᎦᏂᏟ ᎦᏅᎬ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🛌🏾' => 'ᏴᏫ ᎦᏂᏟ ᎦᏅᎬ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🛌🏿' => 'ᏴᏫ ᎦᏂᏟ ᎦᏅᎬ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👭🏻' => 'ᎠᏂᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👭🏼' => 'ᎠᏂᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👭🏽' => 'ᎠᏂᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👭🏾' => 'ᎠᏂᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👭🏿' => 'ᎠᏂᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👫🏻' => 'ᎠᏍᎦᏯ ᎠᎴ ᎠᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👫🏼' => 'ᎠᏍᎦᏯ ᎠᎴ ᎠᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👫🏽' => 'ᎠᏍᎦᏯ ᎠᎴ ᎠᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👫🏾' => 'ᎠᏍᎦᏯ ᎠᎴ ᎠᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👫🏿' => 'ᎠᏍᎦᏯ ᎠᎴ ᎠᎨᏯ ᏚᎾᏙᏯᏂᎠ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👬🏻' => 'ᎠᏂᏍᎦᏯ ᏚᎾᏙᏯᏂᎠᎩ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '👬🏼' => 'ᎠᏂᏍᎦᏯ ᏚᎾᏙᏯᏂᎠᎩ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '👬🏽' => 'ᎠᏂᏍᎦᏯ ᏚᎾᏙᏯᏂᎠᎩ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👬🏾' => 'ᎠᏂᏍᎦᏯ ᏚᎾᏙᏯᏂᎠᎩ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '👬🏿' => 'ᎠᏂᏍᎦᏯ ᏚᎾᏙᏯᏂᎠᎩ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💏🏻' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '💏🏼' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '💏🏽' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💏🏾' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💏🏿' => 'ᎠᏔᏪᏙᎢᏍᏗ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💑🏻' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '💑🏼' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '💑🏽' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💑🏾' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '💑🏿' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ: ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🇦🇨' => 'ᎦᏓᏗ: ᎤᎵᏌᎳᏓᏅ ᎤᎦᏚᏛᎢ',
    '🇦🇩' => 'ᎦᏓᏗ: ᎠᏂᏙᎳ',
    '🇦🇪' => 'ᎦᏓᏗ: ᏌᏊ ᎢᏳᎾᎵᏍᏔᏅ ᎡᎳᏈ ᎢᎹᎵᏘᏏ',
    '🇦🇫' => 'ᎦᏓᏗ: ᎠᏫᎨᏂᏍᏖᏂ',
    '🇦🇬' => 'ᎦᏓᏗ: ᎤᏪᏘ & ᏆᏊᏓ',
    '🇦🇮' => 'ᎦᏓᏗ: ᎠᏂᎩᎳ',
    '🇦🇱' => 'ᎦᏓᏗ: ᎠᎵᏇᏂᏯ',
    '🇦🇲' => 'ᎦᏓᏗ: ᎠᎵᎻᏂᎠ',
    '🇦🇴' => 'ᎦᏓᏗ: ᎠᏂᎪᎳ',
    '🇦🇶' => 'ᎦᏓᏗ: ᏧᏁᏍᏓᎸ',
    '🇦🇷' => 'ᎦᏓᏗ: ᎠᏥᏂᏘᏂᎠ',
    '🇦🇸' => 'ᎦᏓᏗ: ᎠᎺᎵᎧ ᏌᎼᎠ',
    '🇦🇹' => 'ᎦᏓᏗ: ᎠᏍᏟᏯ',
    '🇦🇺' => 'ᎦᏓᏗ: ᎡᎳᏗᏜ',
    '🇦🇼' => 'ᎦᏓᏗ: ᎠᎷᏆ',
    '🇦🇽' => 'ᎦᏓᏗ: ᎣᎴᏅᏓ ᏚᎦᏚᏛᎢ',
    '🇦🇿' => 'ᎦᏓᏗ: ᎠᏎᏆᏣᏂ',
    '🇧🇦' => 'ᎦᏓᏗ: ᏉᏏᏂᎠ & ᎲᏤᎪᏫᎾ',
    '🇧🇧' => 'ᎦᏓᏗ: ᏆᏇᏙᏍ',
    '🇧🇩' => 'ᎦᏓᏗ: ᏆᏂᎦᎵᏕᏍ',
    '🇧🇪' => 'ᎦᏓᏗ: ᏇᎵᏥᎥᎻ',
    '🇧🇫' => 'ᎦᏓᏗ: ᏋᎩᎾ ᏩᏐ',
    '🇧🇬' => 'ᎦᏓᏗ: ᏊᎵᎨᎵᎠ',
    '🇧🇭' => 'ᎦᏓᏗ: ᏆᎭᎴᎢᏂ',
    '🇧🇮' => 'ᎦᏓᏗ: ᏋᎷᏂᏗ',
    '🇧🇯' => 'ᎦᏓᏗ: ᏆᏂᎢᏂ',
    '🇧🇱' => 'ᎦᏓᏗ: ᎤᏓᏅᏘ ᏆᏕᎳᎻ',
    '🇧🇲' => 'ᎦᏓᏗ: ᏆᏊᏓ',
    '🇧🇳' => 'ᎦᏓᏗ: ᏊᎾᎢ',
    '🇧🇴' => 'ᎦᏓᏗ: ᏉᎵᏫᎠ',
    '🇧🇶' => 'ᎦᏓᏗ: ᎧᎵᏈᎢᏂᎯ ᎾᏍᎩᏁᏛᎳᏂ',
    '🇧🇷' => 'ᎦᏓᏗ: ᏆᏏᎵ',
    '🇧🇸' => 'ᎦᏓᏗ: ᎾᏍᎩ ᏆᎭᎹᏍ',
    '🇧🇹' => 'ᎦᏓᏗ: ᏊᏔᏂ',
    '🇧🇻' => 'ᎦᏓᏗ: ᏊᏪ ᎤᎦᏚᏛᎢ',
    '🇧🇼' => 'ᎦᏓᏗ: ᏆᏣᏩᎾ',
    '🇧🇾' => 'ᎦᏓᏗ: ᏇᎳᎷᏍ',
    '🇧🇿' => 'ᎦᏓᏗ: ᏇᎵᏍ',
    '🇨🇦' => 'ᎦᏓᏗ: ᎨᎾᏓ',
    '🇨🇨' => 'ᎦᏓᏗ: ᎪᎪᏍ (ᎩᎵᏂ) ᏚᎦᏚᏛᎢ',
    '🇨🇩' => 'ᎦᏓᏗ: ᎧᏂᎪ - ᎨᏂᏝᏌ',
    '🇨🇫' => 'ᎦᏓᏗ: ᎬᎿᎨᏍᏛ ᎠᏰᏟ ᏍᎦᏚᎩ',
    '🇨🇬' => 'ᎦᏓᏗ: ᎧᏂᎪ - ᏆᏌᏩᎵ',
    '🇨🇭' => 'ᎦᏓᏗ: ᏍᏫᏍ',
    '🇨🇮' => 'ᎦᏓᏗ: ᎢᏬᎵ ᎾᎿ ᎠᎹᏳᎶᏗ',
    '🇨🇰' => 'ᎦᏓᏗ: ᎠᏓᏍᏓᏴᎲᏍᎩ ᏚᎦᏚᏛᎢ',
    '🇨🇱' => 'ᎦᏓᏗ: ᏥᎵ',
    '🇨🇲' => 'ᎦᏓᏗ: ᎧᎹᎷᏂ',
    '🇨🇳' => 'ᎦᏓᏗ: ᏓᎶᏂᎨᏍᏛ',
    '🇨🇴' => 'ᎦᏓᏗ: ᎪᎸᎻᏈᎢᎠ',
    '🇨🇵' => 'ᎦᏓᏗ: ᎦᏂᏴᏔᏅᎣᏓᎸ ᎤᎦᏚᏛᎢ',
    '🇨🇶' => 'ᎦᏓᏗ: ᏌᎬ',
    '🇨🇷' => 'ᎦᏓᏗ: ᎪᏍᏓ ᎵᎧ',
    '🇨🇺' => 'ᎦᏓᏗ: ᎫᏆ',
    '🇨🇻' => 'ᎦᏓᏗ: ᎢᎬᎾᏕᎾ ᎢᏤᏳᏍᏗ',
    '🇨🇼' => 'ᎦᏓᏗ: ᎫᎳᎨᎣ',
    '🇨🇽' => 'ᎦᏓᏗ: ᏓᏂᏍᏓᏲᎯᎲ ᎤᎦᏚᏛᎢ',
    '🇨🇾' => 'ᎦᏓᏗ: ᏌᎢᏆᏍ',
    '🇨🇿' => 'ᎦᏓᏗ: ᏤᎩᎠ',
    '🇩🇪' => 'ᎦᏓᏗ: ᎠᏂᏛᏥ',
    '🇩🇬' => 'ᎦᏓᏗ: ᏗᏰᎪ ᎦᏏᏯ',
    '🇩🇯' => 'ᎦᏓᏗ: ᏥᏊᏗ',
    '🇩🇰' => 'ᎦᏓᏗ: ᏗᏂᎹᎦ',
    '🇩🇲' => 'ᎦᏓᏗ: ᏙᎻᏂᎧ',
    '🇩🇴' => 'ᎦᏓᏗ: ᏙᎻᏂᎧᏂ ᏍᎦᏚᎩ',
    '🇩🇿' => 'ᎦᏓᏗ: ᎠᎵᏥᎵᏯ',
    '🇪🇦' => 'ᎦᏓᏗ: ᏑᏔ ᎠᎴ ᎺᎵᏯ',
    '🇪🇨' => 'ᎦᏓᏗ: ᎡᏆᏙᎵ',
    '🇪🇪' => 'ᎦᏓᏗ: ᎡᏍᏙᏂᏯ',
    '🇪🇬' => 'ᎦᏓᏗ: ᎢᏥᏈᎢ',
    '🇪🇭' => 'ᎦᏓᏗ: ᏭᏕᎵᎬ ᏗᏜ ᏌᎮᎳ',
    '🇪🇷' => 'ᎦᏓᏗ: ᎡᎵᏟᏯ',
    '🇪🇸' => 'ᎦᏓᏗ: ᎠᏂᏍᏆᏂᏱ',
    '🇪🇹' => 'ᎦᏓᏗ: ᎢᏗᎣᏈᎠ',
    '🇪🇺' => 'ᎦᏓᏗ: ᏳᎳᏛ ᎠᏂᎤᎾᏓᏡᎬ',
    '🇫🇮' => 'ᎦᏓᏗ: ᏫᏂᎦᏙᎯ',
    '🇫🇯' => 'ᎦᏓᏗ: ᏫᏥ',
    '🇫🇰' => 'ᎦᏓᏗ: ᏩᎩ ᏚᎦᏚᏛᎢ',
    '🇫🇲' => 'ᎦᏓᏗ: ᎹᎢᏉᏂᏏᏯ',
    '🇫🇴' => 'ᎦᏓᏗ: ᏪᎶ ᏚᎦᏚᏛᎢ',
    '🇫🇷' => 'ᎦᏓᏗ: ᎦᎸᏥᏱ',
    '🇬🇦' => 'ᎦᏓᏗ: ᎦᏉᏂ',
    '🇬🇧' => 'ᎦᏓᏗ: ᎩᎵᏏᏲ',
    '🇬🇩' => 'ᎦᏓᏗ: ᏋᎾᏓ',
    '🇬🇪' => 'ᎦᏓᏗ: ᏣᎠᏥᎢ',
    '🇬🇫' => 'ᎦᏓᏗ: ᎠᏂᎦᎸᏥ ᎩᎠ',
    '🇬🇬' => 'ᎦᏓᏗ: ᎬᏂᏏ',
    '🇬🇭' => 'ᎦᏓᏗ: ᎦᎠᎾ',
    '🇬🇮' => 'ᎦᏓᏗ: ᏥᏆᎵᏓ',
    '🇬🇱' => 'ᎦᏓᏗ: ᎢᏤᏍᏛᏱ',
    '🇬🇲' => 'ᎦᏓᏗ: ᎦᎹᏈᎢᎠ',
    '🇬🇳' => 'ᎦᏓᏗ: ᎩᎢᏂ',
    '🇬🇵' => 'ᎦᏓᏗ: ᏩᏓᎷᏇ',
    '🇬🇶' => 'ᎦᏓᏗ: ᎡᏆᏙᎵᎠᎵ ᎩᎢᏂ',
    '🇬🇷' => 'ᎦᏓᏗ: ᎪᎢᎯ',
    '🇬🇸' => 'ᎦᏓᏗ: ᏧᎦᏃᏮ ᏣᎠᏥᎢ ᎠᎴ ᎾᏍᎩ ᏧᎦᏃᏮ ᎠᏍᏛᎭᏟ ᏚᎦᏚᏛᎢ',
    '🇬🇹' => 'ᎦᏓᏗ: ᏩᏔᎹᎳ',
    '🇬🇺' => 'ᎦᏓᏗ: ᏆᎻ',
    '🇬🇼' => 'ᎦᏓᏗ: ᎩᎢᏂ-ᏈᏌᎤᏫ',
    '🇬🇾' => 'ᎦᏓᏗ: ᎦᏯᎾ',
    '🇭🇰' => 'ᎦᏓᏗ: ᎰᏂᎩ ᎪᏂᎩ ᎤᏓᏤᎵᏓ ᏧᏂᎸᏫᏍᏓᏁᏗ ᎢᎬᎾᏕᎾ ᏓᎶᏂᎨᏍᏛ',
    '🇭🇲' => 'ᎦᏓᏗ: ᎲᏗ ᎤᎦᏚᏛᎢ ᎠᎴ ᎺᎩᏓᎾᎵᏗ ᏚᎦᏚᏛᎢ',
    '🇭🇳' => 'ᎦᏓᏗ: ᎭᏂᏚᎳᏍ',
    '🇭🇷' => 'ᎦᏓᏗ: ᎧᎶᎡᏏᎠ',
    '🇭🇹' => 'ᎦᏓᏗ: ᎮᎢᏘ',
    '🇭🇺' => 'ᎦᏓᏗ: ᎲᏂᎦᎵ',
    '🇮🇨' => 'ᎦᏓᏗ: ᏥᏍᏆ ᏚᎦᏚᏛᎢ',
    '🇮🇩' => 'ᎦᏓᏗ: ᎢᏂᏙᏂᏍᏯ',
    '🇮🇪' => 'ᎦᏓᏗ: ᎠᏲᎳᏂ',
    '🇮🇱' => 'ᎦᏓᏗ: ᎢᏏᎵᏱ',
    '🇮🇲' => 'ᎦᏓᏗ: ᎤᏍᏗ ᎤᎦᏚᏛᎢ ᎾᎿ ᎠᏍᎦᏯ',
    '🇮🇳' => 'ᎦᏓᏗ: ᎢᏅᏗᎾ',
    '🇮🇴' => 'ᎦᏓᏗ: ᏈᏗᏏ ᏴᏫᏯ ᎠᎺᏉ ᎢᎬᎾᏕᏅ',
    '🇮🇶' => 'ᎦᏓᏗ: ᎢᎳᎩ',
    '🇮🇷' => 'ᎦᏓᏗ: ᎢᎴᏂ',
    '🇮🇸' => 'ᎦᏓᏗ: ᏧᏁᏍᏓᎸᎯ',
    '🇮🇹' => 'ᎦᏓᏗ: ᎢᏔᎵ',
    '🇯🇪' => 'ᎦᏓᏗ: ᏨᎵᏏ',
    '🇯🇲' => 'ᎦᏓᏗ: ᏣᎺᎢᎧ',
    '🇯🇴' => 'ᎦᏓᏗ: ᏦᏓᏂ',
    '🇯🇵' => 'ᎦᏓᏗ: ᏣᏩᏂᏏ',
    '🇰🇪' => 'ᎦᏓᏗ: ᎨᏂᏯ',
    '🇰🇬' => 'ᎦᏓᏗ: ᎩᎵᏣᎢᏍ',
    '🇰🇭' => 'ᎦᏓᏗ: ᎧᎹᏉᏗᎠᏂ',
    '🇰🇮' => 'ᎦᏓᏗ: ᎧᎵᏆᏘ',
    '🇰🇲' => 'ᎦᏓᏗ: ᎪᎼᎳᏍ',
    '🇰🇳' => 'ᎦᏓᏗ: ᎤᏓᏅᏘ ᎨᏘᏏ ᎠᎴ ᏁᏪᏏ',
    '🇰🇵' => 'ᎦᏓᏗ: ᏧᏴᏢ ᎪᎵᎠ',
    '🇰🇷' => 'ᎦᏓᏗ: ᏧᎦᏃᏮ ᎪᎵᎠ',
    '🇰🇼' => 'ᎦᏓᏗ: ᎫᏪᎢᏘ',
    '🇰🇾' => 'ᎦᏓᏗ: ᎨᎢᎹᏂ ᏚᎦᏚᏛᎢ',
    '🇰🇿' => 'ᎦᏓᏗ: ᎧᏎᎧᏍᏕᏂ',
    '🇱🇦' => 'ᎦᏓᏗ: ᎴᎣᏍ',
    '🇱🇧' => 'ᎦᏓᏗ: ᎴᏆᎾᏂ',
    '🇱🇨' => 'ᎦᏓᏗ: ᎤᏓᏅᏘ ᎷᏏᏯ',
    '🇱🇮' => 'ᎦᏓᏗ: ᎵᎦᏗᏂᏍᏓᏂ',
    '🇱🇰' => 'ᎦᏓᏗ: ᏍᎵ ᎳᏂᎧ',
    '🇱🇷' => 'ᎦᏓᏗ: ᎳᏈᎵᏯ',
    '🇱🇸' => 'ᎦᏓᏗ: ᎴᏐᏙ',
    '🇱🇹' => 'ᎦᏓᏗ: ᎵᏗᏪᏂᎠ',
    '🇱🇺' => 'ᎦᏓᏗ: ᎸᎧᏎᏋᎩ',
    '🇱🇻' => 'ᎦᏓᏗ: ᎳᏘᏫᎠ',
    '🇱🇾' => 'ᎦᏓᏗ: ᎵᏈᏯ',
    '🇲🇦' => 'ᎦᏓᏗ: ᎼᎶᎪ',
    '🇲🇨' => 'ᎦᏓᏗ: ᎹᎾᎪ',
    '🇲🇩' => 'ᎦᏓᏗ: ᎹᎵᏙᏫᎠ',
    '🇲🇪' => 'ᎦᏓᏗ: ᎼᏂᏔᏁᎦᎶ',
    '🇲🇫' => 'ᎦᏓᏗ: ᎤᏓᏅᏘ ᏡᏡ',
    '🇲🇬' => 'ᎦᏓᏗ: ᎹᏓᎦᏍᎧᎵ',
    '🇲🇭' => 'ᎦᏓᏗ: ᎹᏌᎵ ᏚᎦᏚᏛᎢ',
    '🇲🇰' => 'ᎦᏓᏗ: ᏧᏴᏜ ᎹᏎᏙᏂᏯ',
    '🇲🇱' => 'ᎦᏓᏗ: ᎹᎵ',
    '🇲🇲' => 'ᎦᏓᏗ: ᎹᏯᎹᎵ (ᏇᎵᎹ)',
    '🇲🇳' => 'ᎦᏓᏗ: ᎹᏂᎪᎵᎠ',
    '🇲🇴' => 'ᎦᏓᏗ: ᎹᎧᎣ (ᎤᏓᏤᎵᏓ ᏧᏂᎸᏫᏍᏓᏁᏗ ᎢᎬᎾᏕᎾ) ᏣᎢ',
    '🇲🇵' => 'ᎦᏓᏗ: ᏧᏴᏢ ᏗᏜ ᎹᎵᎠᎾ ᏚᎦᏚᏛᎢ',
    '🇲🇶' => 'ᎦᏓᏗ: ᎹᏘᏂᎨ',
    '🇲🇷' => 'ᎦᏓᏗ: ᎹᏘᎢᏯ',
    '🇲🇸' => 'ᎦᏓᏗ: ᎹᏂᏘᏌᎳᏗ',
    '🇲🇹' => 'ᎦᏓᏗ: ᎹᎵᏔ',
    '🇲🇺' => 'ᎦᏓᏗ: ᎼᎵᏏᎥᏍ',
    '🇲🇻' => 'ᎦᏓᏗ: ᎹᎵᏗᏫᏍ',
    '🇲🇼' => 'ᎦᏓᏗ: ᎹᎳᏫ',
    '🇲🇽' => 'ᎦᏓᏗ: ᎠᏂᏍᏆᏂ',
    '🇲🇾' => 'ᎦᏓᏗ: ᎹᎴᏏᎢᎠ',
    '🇲🇿' => 'ᎦᏓᏗ: ᎼᏎᎻᏇᎩ',
    '🇳🇦' => 'ᎦᏓᏗ: ᎾᎻᏈᎢᏯ',
    '🇳🇨' => 'ᎦᏓᏗ: ᎢᏤ ᎧᎵᏙᏂᎠᏂ',
    '🇳🇪' => 'ᎦᏓᏗ: ᎾᎢᏨ',
    '🇳🇫' => 'ᎦᏓᏗ: ᏃᎵᏬᎵᎩ ᎤᎦᏚᏛᎢ',
    '🇳🇬' => 'ᎦᏓᏗ: ᏂᏥᎵᏯ',
    '🇳🇮' => 'ᎦᏓᏗ: ᏂᎧᎳᏆ',
    '🇳🇱' => 'ᎦᏓᏗ: ᏁᏛᎳᏂ',
    '🇳🇴' => 'ᎦᏓᏗ: ᏃᏪ',
    '🇳🇵' => 'ᎦᏓᏗ: ᏁᏆᎵ',
    '🇳🇷' => 'ᎦᏓᏗ: ᏃᎤᎷ',
    '🇳🇺' => 'ᎦᏓᏗ: ᏂᏳ',
    '🇳🇿' => 'ᎦᏓᏗ: ᎢᏤ ᏏᎢᎴᏂᏗ',
    '🇴🇲' => 'ᎦᏓᏗ: ᎣᎺᏂ',
    '🇵🇦' => 'ᎦᏓᏗ: ᏆᎾᎹ',
    '🇵🇪' => 'ᎦᏓᏗ: ᏇᎷ',
    '🇵🇫' => 'ᎦᏓᏗ: ᎠᏂᎦᎸᏥ ᏆᎵᏂᏏᎠ',
    '🇵🇬' => 'ᎦᏓᏗ: ᏆᏇ ᎢᏤ ᎩᎢᏂ',
    '🇵🇭' => 'ᎦᏓᏗ: ᎠᏂᏈᎵᎩᏃ',
    '🇵🇰' => 'ᎦᏓᏗ: ᏆᎩᏍᏖᏂ',
    '🇵🇱' => 'ᎦᏓᏗ: ᏉᎳᏂ',
    '🇵🇲' => 'ᎦᏓᏗ: ᎤᏓᏅᏘ ᏈᏰ ᎠᎴ ᎻᏇᎶᏂ',
    '🇵🇳' => 'ᎦᏓᏗ: ᏈᎧᎵᏂ ᏚᎦᏚᏛᎢ',
    '🇵🇷' => 'ᎦᏓᏗ: ᏇᎡᏙ ᎵᎢᎪ',
    '🇵🇸' => 'ᎦᏓᏗ: ᏆᎴᏍᏗᏂᎠᏂ ᏄᎬᏫᏳᏌᏕᎩ',
    '🇵🇹' => 'ᎦᏓᏗ: ᏉᏥᎦᎳ',
    '🇵🇼' => 'ᎦᏓᏗ: ᏆᎴᎠᏫ',
    '🇵🇾' => 'ᎦᏓᏗ: ᏆᎳᏇᎢᏯ',
    '🇶🇦' => 'ᎦᏓᏗ: ᎧᏔᎵ',
    '🇷🇪' => 'ᎦᏓᏗ: ᎴᏳᏂᎠᏂ',
    '🇷🇴' => 'ᎦᏓᏗ: ᎶᎹᏂᏯ',
    '🇷🇸' => 'ᎦᏓᏗ: ᏒᏈᏯ',
    '🇷🇺' => 'ᎦᏓᏗ: ᏲᏂᎢ',
    '🇷🇼' => 'ᎦᏓᏗ: ᎶᏩᏂᏓ',
    '🇸🇦' => 'ᎦᏓᏗ: ᏌᎤᏗ ᎡᎴᏈᎠ',
    '🇸🇧' => 'ᎦᏓᏗ: ᏐᎶᎹᏂ ᏚᎦᏚᏛᎢ',
    '🇸🇨' => 'ᎦᏓᏗ: ᏏᎡᏥᎵᏍ',
    '🇸🇩' => 'ᎦᏓᏗ: ᏑᏕᏂ',
    '🇸🇪' => 'ᎦᏓᏗ: ᏍᏫᏕᏂ',
    '🇸🇬' => 'ᎦᏓᏗ: ᏏᏂᎦᏉᎵ',
    '🇸🇭' => 'ᎦᏓᏗ: ᎤᏓᏅᏘ ᎮᎵᎾ',
    '🇸🇮' => 'ᎦᏓᏗ: ᏍᎶᏫᏂᎠ',
    '🇸🇯' => 'ᎦᏓᏗ: ᏍᏩᎵᏆᎵᏗ ᎠᎴ ᏤᏂ ᎹᏰᏂ',
    '🇸🇰' => 'ᎦᏓᏗ: ᏍᎶᏩᎩᎠ',
    '🇸🇱' => 'ᎦᏓᏗ: ᏏᎡᎳ ᎴᎣᏂ',
    '🇸🇲' => 'ᎦᏓᏗ: ᎤᏓᏅᏘ ᎹᎵᎢᏃ',
    '🇸🇳' => 'ᎦᏓᏗ: ᏏᏂᎦᎵ',
    '🇸🇴' => 'ᎦᏓᏗ: ᏐᎹᎵ',
    '🇸🇷' => 'ᎦᏓᏗ: ᏒᎵᎾᎻ',
    '🇸🇸' => 'ᎦᏓᏗ: ᏧᎦᎾᏮ ᏑᏕᏂ',
    '🇸🇹' => 'ᎦᏓᏗ: ᏌᎣ ᏙᎺ ᎠᎴ ᏈᏂᏏᏇ',
    '🇸🇻' => 'ᎦᏓᏗ: ᎡᎵᏌᎵᏆᏙᎵ',
    '🇸🇽' => 'ᎦᏓᏗ: ᏏᏂᏘ ᎹᏘᏂ',
    '🇸🇾' => 'ᎦᏓᏗ: ᏏᎵᎠ',
    '🇸🇿' => 'ᎦᏓᏗ: ᎡᏍᏩᏘᏂ',
    '🇹🇦' => 'ᎦᏓᏗ: ᏟᏍᏛᏂ Ꮣ ᎫᎾᎭ',
    '🇹🇨' => 'ᎦᏓᏗ: ᎠᏂᏛᎵᎩ ᎠᎴ ᎨᎢᎪ ᏚᎦᏚᏛᎢ',
    '🇹🇩' => 'ᎦᏓᏗ: ᏣᏗ',
    '🇹🇫' => 'ᎦᏓᏗ: ᎠᏂᎦᎸᏥ ᏧᎦᎾᏮ ᎦᏙᎯ ᎤᎵᏍᏛᎢ',
    '🇹🇬' => 'ᎦᏓᏗ: ᏙᎪ',
    '🇹🇭' => 'ᎦᏓᏗ: ᏔᏯᎴᏂ',
    '🇹🇯' => 'ᎦᏓᏗ: ᏔᏥᎩᏍᏕᏂ',
    '🇹🇰' => 'ᎦᏓᏗ: ᏙᎨᎳᏭ',
    '🇹🇱' => 'ᎦᏓᏗ: ᏘᎼᎵ-ᎴᏍᏖ',
    '🇹🇲' => 'ᎦᏓᏗ: ᏛᎵᎩᎺᏂᏍᏔᏂ',
    '🇹🇳' => 'ᎦᏓᏗ: ᏚᏂᏏᏍᎠ',
    '🇹🇴' => 'ᎦᏓᏗ: ᏙᎾᎦ',
    '🇹🇷' => 'ᎦᏓᏗ: ᎬᏃ',
    '🇹🇹' => 'ᎦᏓᏗ: ᏟᏂᏕᏗ ᎠᎴ ᏙᏆᎪ',
    '🇹🇻' => 'ᎦᏓᏗ: ᏚᏩᎷ',
    '🇹🇼' => 'ᎦᏓᏗ: ᏔᎢᏩᏂ',
    '🇹🇿' => 'ᎦᏓᏗ: ᏖᏂᏏᏂᏯ',
    '🇺🇦' => 'ᎦᏓᏗ: ᏳᎧᎴᏂ',
    '🇺🇬' => 'ᎦᏓᏗ: ᏳᎦᏂᏓ',
    '🇺🇲' => 'ᎦᏓᏗ: U.S. ᎠᏍᏛ ᏚᎦᏚᏛᎢ',
    '🇺🇳' => 'ᎦᏓᏗ: ᏌᏊ ᎢᏳᎾᎵᏍᏔᏅ ᎠᏰᎵ ᏚᎾᏙᏢᏒ',
    '🇺🇸' => 'ᎦᏓᏗ: ᏌᏊ ᎢᏳᎾᎵᏍᏔᏅ ᏍᎦᏚᎩ',
    '🇺🇾' => 'ᎦᏓᏗ: ᏳᎷᏇ',
    '🇺🇿' => 'ᎦᏓᏗ: ᎤᏍᏇᎩᏍᏖᏂ',
    '🇻🇦' => 'ᎦᏓᏗ: ᎠᏥᎳᏁᏠ ᎦᏚᎲ',
    '🇻🇨' => 'ᎦᏓᏗ: ᎤᏓᏅᏘ ᏫᏂᏏᏂᏗ ᎠᎴ ᎾᏍᎩ ᏇᎾᏗᏁᏍ',
    '🇻🇪' => 'ᎦᏓᏗ: ᏪᏁᏑᏪᎳ',
    '🇻🇬' => 'ᎦᏓᏗ: ᏈᏗᏍ ᎠᏒᏂᎸ ᏂᎨᏒᎾ ᏚᎦᏚᏛᎢ',
    '🇻🇮' => 'ᎦᏓᏗ: U.S. ᎠᏒᏂᎸ ᏂᎨᏒᎾ ᏚᎦᏚᏛᎢ',
    '🇻🇳' => 'ᎦᏓᏗ: ᏫᎡᏘᎾᎻ',
    '🇻🇺' => 'ᎦᏓᏗ: ᏩᏂᎤᏩᏚ',
    '🇼🇫' => 'ᎦᏓᏗ: ᏩᎵᏍ ᎠᎴ ᏊᏚᎾ',
    '🇼🇸' => 'ᎦᏓᏗ: ᏌᎼᎠ',
    '🇽🇰' => 'ᎦᏓᏗ: ᎪᏐᏉ',
    '🇾🇪' => 'ᎦᏓᏗ: ᏰᎺᏂ',
    '🇾🇹' => 'ᎦᏓᏗ: ᎺᏯᏖ',
    '🇿🇦' => 'ᎦᏓᏗ: ᏧᎦᎾᏮ ᎬᎿᎨᏍᏛ',
    '🇿🇲' => 'ᎦᏓᏗ: ᏌᎻᏈᏯ',
    '🇿🇼' => 'ᎦᏓᏗ: ᏏᎻᏆᏇ',
    '🔟' => 'ᎠᏚᎢᏍᏘᎠᎵᏚᎶ: 10',
    '🏻' => 'ᎤᏗᏴᎳᏘ ᎤᏁᎦᎵ ᏄᏍᏛᎢ',
    '🏼' => 'ᎠᏲᏟᎨ-ᎤᏗᏴᎳᏘ ᎤᏁᎦᎸ ᏄᎿᏍᏛᎢ',
    '🏽' => 'ᎠᏲᏟᎨ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏾' => 'ᎠᏲᏟᎨ-ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '🏿' => 'ᎤᎵᏏᎩ ᎣᏁᎦᎸ ᏄᏍᏛᎢ',
    '😀' => 'ᎤᏤᏣᏍᏗ ᎤᎧᏛ',
    '😃' => 'ᎤᏤᏣᏍᏗ ᎤᎧᏛ ᎾᏍᎩ ᎤᏔᎾ ᏗᎦᏙᎵ',
    '😄' => 'ᎤᏤᏣᏍᏗ ᎤᎧᏛ ᎾᏍᎩ ᎤᏤᏣᏍᏗ ᏗᎦᏙᎵ',
    '😁' => 'ᎤᏤᏣᏍᏗ ᎤᎧᏛ ᎾᏍᎩ ᎤᏤᏣᏍᏗ ᏓᎧᏅᎢ',
    '😆' => 'ᎤᏤᏣᏍᏗ ᏍᏈᏘ ᎤᎧᏛ',
    '😅' => 'ᎤᏤᏣᏍᏗ ᎤᎧᏛ ᎠᎵ',
    '🤣' => 'ᎣᏐᏫᎵᏙᎲ ᎥᎿ ᏯᏖᏃ ᎣᏬᎵᏓᏁᎲᎢ',
    '😂' => 'ᎤᎧᏛᎢ ᎤᏠᏯᏍᏗ ᏚᎦᎳᏁᏒ Ꮎ ᎤᎵᎮᎵᏍᏗ',
    '🙂' => 'ᏍᏗᎩᏓ ᎤᏰᏓᏍᎬ ᎤᎧᏛ',
    '🙃' => 'ᏗᏁᏍᏈᏛᏅ-ᎡᎳᏗᏜ ᎤᎧᏛ',
    '🫠' => 'ᎦᏅᏬᏍᎬ ᎤᎧᏛ',
    '😉' => 'ᎠᏓᎦᏔᏁ ᎠᎦᏙᎵ',
    '😊' => 'ᎤᏰᏗᏍᎩ ᎤᎧᏔ Ꮎ ᏧᏰᏗᏍᎩ ᏗᎦᏙᎵ',
    '😇' => 'ᎤᏰᏗᏍᎩ ᎤᎧᏔ ᎤᎵᎪᏓ',
    '🥰' => 'ᎭᏰᏍᎩ ᎤᎧᏛ ᎭᏠᏯᏍᏗ ᏗᏓᏅᏙ',
    '😍' => 'ᎤᏰᏗᏍᎩ ᎤᎧᏔ ᎤᎵᎪ ᎤᏓᏅᏙ-ᏗᎦᏙᎵ',
    '🤩' => 'ᏃᏈᏏ-ᎤᏮᏂᎸᎢ',
    '😘' => 'ᎤᎧᏛᎢ ᎠᏦᏔᏍᎬ ᎠᏓᏔᏪᏙᏗ',
    '😗' => 'ᎠᏓᏔᏪᏙᏍᎩ ᎤᎧᏛ',
    '☺' => 'ᎤᏰᏥᏍᎬᎢ ᎤᎧᏛ',
    '😚' => 'ᎠᏓᏔᏪᏙᏍᎩ ᎤᎧᏛ ᏚᎦᏔᏍᏛᎢ',
    '😙' => 'ᎠᏓᏔᏪᏙᏍᎩ ᎤᎧᏛ ᎤᏤᏣᏍᏗ ᏗᎧᏂ',
    '🥲' => 'ᎭᏰᏍᎩ ᎤᎧᏛ ᎭᏠᏯᏍᏗ ᎤᏰᏍᎩ',
    '😋' => 'ᎤᎧᏛᎢ ᎠᏓᏍᏓᏴᎲᏍᎬ ᎤᎦᎾᏍᏛ ᎠᎵᏍᏓᏴᏗ',
    '😛' => 'ᎤᎧᏛ ᎾᎿ ᎦᏅᎪ',
    '😜' => 'ᏚᎦᏔᏍᏓ ᎤᎧᏛ ᎾᎿ ᎦᏅᎪ',
    '🤪' => 'ᎤᎷᎶᏨ ᎤᎧᏛ',
    '😝' => 'ᏍᏈᏘ ᎤᎧᏛ ᎾᎿ ᎦᏅᎪ',
    '🤑' => 'ᎠᏕᎳ-ᎠᎰᎵ ᎤᎧᏛ',
    '🤗' => 'ᎠᏄᎩᏢᏍᎩ ᎤᎧᏛ',
    '🤭' => 'ᎤᎧᏛ ᎠᎰᎵ ᎤᏭᏝᎢ',
    '🫢' => 'ᎤᎧᏛ ᎾᎿ ᎠᏍᏚᎢᏓ ᏗᎦᏙᎵ ᎠᎴ ᎠᎰᎵ ᎤᏭᏝᎢ',
    '🫣' => 'ᎤᎧᏛ ᎾᎿ ᎤᏔᏅᎢ ᎠᎦᏙᎵ',
    '🤫' => 'ᎡᎶᏪᎢ ᎾᎬᏁᎲᎢ ᎤᎧᏛ',
    '🤔' => 'ᎠᏓᎾᏖᏍᎩ ᎤᎧᏛ',
    '🫡' => 'ᎠᏓᏲᎵᏍᏗ ᎤᎧᏛ',
    '🤐' => 'ᎥᎧᏁᏍᏗ-ᎠᎰᎵᎤᎧᏓ ᎤᎧᏛ',
    '🤨' => 'ᎤᎧᏛ ᎤᎵᏌᎳᏗ ᎤᎦᏖᏌᎾᎸᎢ',
    '😐' => 'ᏃᎵᎪᏛᎾ ᎤᎧᏛ',
    '😑' => 'ᎤᎧᏛᎢ ᏅᏓᏁᏟᏴᏒᎾ ᎤᎧᏛ',
    '😶' => 'ᎤᎧᏛᎢ ᏄᏠᏯᏍᏛᎾ ᎠᏲᎵ',
    '🫥' => 'ᎤᏓᏓᎸ ᎠᏍᏓᏅᏅᎢ ᎤᎧᏛ',
    '😏' => 'ᎤᏰᏗᏍᎩ ᎤᎧᏛ',
    '😒' => 'ᏄᏰᏗᏍᎬᎾ ᎤᎧᏛ',
    '🙄' => 'ᎤᎧᏛᎢ ᎤᏠᏯᏍᏗ ᎦᎦᏐᏆᎴᎦ ᏗᎦᏙᎵ',
    '😬' => 'ᎤᏓᏁᎪᏳᎲᎢ ᎤᎧᏛ',
    '🤥' => 'ᎠᎵᏍᎪᏅᏍᎦ ᎤᎧᏛ',
    '🫨' => 'ᎦᎵᏍᏛᏂᎭ',
    '😌' => 'ᎤᏯᏪᏐᏢ ᎤᎧᏛ',
    '😔' => 'ᎠᏓᏅᏖᎸᏍᎩ ᎤᎧᏛ',
    '😪' => 'ᎦᏢᏍᎩ ᎤᎧᏛ',
    '🤤' => 'ᏗᎭᏬᎢᎭ ᎤᎧᏛ',
    '😴' => 'ᎦᏟᎯ ᎤᎧᏛ',
    '🫩' => 'ᎤᎧᏛ ᏧᎵᏏᎩ ᏗᎦᏙᎵ',
    '😷' => 'ᎤᎧᏛᎢ ᎤᏠᏯᏍᏗ ᎦᏃᏢᎩᏅᏬᏘ ᎠᎵᎬᏚᎶᏗ',
    '🤒' => 'ᎤᎧᏛᎢ ᎤᏠᏯᏍᏗ ᎤᏗᏞᎬ ᎤᎦᏅᏮ ᎠᏎᎯᎯ',
    '🤕' => 'ᎤᎧᏛᎢ ᎤᏠᏯᏍᏗ ᎠᏍᎪᎳ-ᎤᏐᏅᏅ ᎦᏇᏅᏙᏗ',
    '🤢' => 'ᎤᎸᏕᎳᏗ ᎤᎧᏛ',
    '🤮' => 'ᎤᎧᏛ ᏚᎦᏍᏗᎲᎢ',
    '🤧' => 'ᏧᏴᏍᏙᏍᎩ ᎤᎧᏔ',
    '🥵' => 'ᎤᏗᏞᎦ ᎤᎧᏛ',
    '🥶' => 'ᎤᏴᏜ ᎤᎧᏛ',
    '🥴' => 'ᎤᎸᏕᏍᏗ ᎤᎧᏛ',
    '😵' => 'ᎤᎸᏕᎯᏓ ᎤᎧᏛ',
    '🤯' => 'ᎠᏔᏍᎩᏍᎩ ᎠᎦᏍᏓᏛ',
    '🤠' => 'ᏗᏍᎳᏗᏍᎩ ᎤᎵᏍᏇᏚᎩ ᎤᎧᏛ',
    '🥳' => 'ᎤᎧᏛ ᎤᎾᏓᏡᎨᏍᎬ',
    '🥸' => 'ᎠᏣᏅᏙᏗ ᎤᎧᏛ',
    '😎' => 'ᎤᏰᏗᏍᎩ ᎤᎧᏔ ᏅᏓ ᏗᎦᏛᏅᏙᏗ ᏗᎦᏛᏅᏗᏍᏗ',
    '🤓' => 'ᎤᎦᎸᏗ ᎤᎧᏛ',
    '🧐' => 'ᏗᎦᏛᏅᏙᏗ ᎤᎧᏛ',
    '😕' => 'ᎤᏎᎩᏲᏤᎸᎢ ᎤᎧᏛ',
    '🫤' => 'ᎤᎧᏛ ᎾᎿ ᎤᏙᏌᏘ ᎠᎰᎵ',
    '😟' => 'ᎤᏪᎵᎯᏍᎩ ᎤᎧᏛ',
    '🙁' => 'ᏍᏗᎩᏓ ᎤᏓᏁᎪᏳᏒ ᎤᎧᏛ',
    '☹' => 'ᎤᏓᏁᎪᏳ ᎤᎧᏛ',
    '😮' => 'ᎤᎧᏛ ᎤᏠᏯᏍᏗ ᎤᏔᏠᎬᎢ',
    '😯' => 'ᎡᎶᏪ ᎤᎧᏛ',
    '😲' => 'ᎠᏥᏎᎦᏍᏔᏅᎢ ᎤᎧᏛ',
    '😳' => 'ᎦᏃᎱᎪᏗ ᎤᎧᏛ',
    '🫪' => 'ᏗᏍᏙᏖᏗ ᎤᎧᏛ',
    '🥺' => 'ᎦᏂᎳᏗᎠ ᎤᎧᏛ',
    '🥹' => 'ᏧᎦᏌᏬᏛ ᎤᎧᏛ',
    '😦' => 'ᎤᏓᏁᎪᏳᎲᎢ ᎤᎧᏛ ᎤᏔᏠᎩ',
    '😧' => 'ᎠᎩᏟᏲᎬᎢ ᎤᎧᏛ',
    '😨' => 'ᎤᎾᏰᏌᏘ ᎤᎧᏛ',
    '😰' => 'ᎤᎷᎶ ᎤᎧᏛ ᎠᎵ',
    '😥' => 'ᎡᏍᎦ ᎤᏰᎸᏅᎢ ᎠᏎᏃ ᎤᎵᎮᎵᏨᎢ ᎤᎧᏛ',
    '😢' => 'ᎠᏠᏱᎭ ᎤᎧᏛ',
    '😭' => 'ᏗᎭᎳᏓ ᎠᏠᏱᏍᎩ ᎤᎧᏛ',
    '😱' => 'ᎤᎧᏛᎢ ᎨᎷᎲᏍᎦ ᎾᏍᎩ ᎦᎾᏰᎯᏍᏗ',
    '😖' => 'ᎤᎭᎾᎸ ᎤᎧᏛ',
    '😣' => 'ᏥᎾᏛᏁᎰᎢ ᎤᎧᏛ',
    '😞' => 'ᎡᏍᎦ ᎤᏰᎸᏅᎢ ᎤᎧᏛ',
    '😓' => 'ᎤᎧᏛᎢ ᎤᏠᏯᏍᏗ ᎤᏴᏟ ᎠᎵ',
    '😩' => 'ᏗᎦᏍᏗᏰᏍᏒ ᎤᎧᏓ',
    '😫' => 'ᏚᏯᏪᎦ ᎤᎧᏛ',
    '🥱' => 'ᎦᎸᏍᎦ ᎤᎧᏛ',
    '😤' => 'ᎤᎧᏛᎢ ᎤᏠᏯᏍᏗ ᎾᏍᎩᎾ ᎧᏴᏐᎵ',
    '😡' => 'ᎤᏓᏁᎯᏳ ᎤᎧᏛ',
    '😠' => 'ᎤᎿᎸᎯ ᎤᎧᏛ',
    '🤬' => 'ᎤᎧᏛ ᎤᏙᏪᎸ ᎤᏭᏝᎢ ᎠᎰᎵ',
    '😈' => 'ᎤᏰᏗᏍᎩ ᎤᎧᏔ ᎤᎵᎪᏓ ᏚᏲᎾ',
    '👿' => 'ᎤᎿᎸᎢ ᎤᎧᏛ ᏧᏲᎾ',
    '💀' => 'ᎪᎳᎭ ᎤᏍᎦ',
    '☠' => 'ᎪᎳᎭ ᎤᏍᎦ ᎠᎴ ᏧᏓᎿᏫᏓ ᏧᎪᎳ',
    '💩' => 'ᎦᏒᏛ Ꮎ ᎢᎩᏏ',
    '🤡' => 'ᏧᎦᎸᏓ ᎤᎧᏛ',
    '👹' => 'ᏴᏫ ᎢᏳᏍᏗ',
    '👺' => 'ᎩᎦᎨ ᏴᏫ',
    '👻' => 'ᎠᏥᏍᎩᎵ',
    '👽' => 'ᎢᎾ ᏂᏓᏳᎶᏒᎢ',
    '👾' => 'ᎢᎾ ᏂᏓᏳᎶᏒᎢ ᎦᏂᏰᎩ',
    '🤖' => 'ᏔᎷᎩᏍᎩ ᏴᏫ ᎤᎧᏛ',
    '😺' => 'ᎤᏤᏣᏍᏗ ᏪᏌ ᎤᎧᏛ',
    '😸' => 'ᎤᏤᏣᏍᏗ ᏪᏌ ᎤᎧᏛ ᎾᏍᎩ ᎤᏤᏣᏍᏗ ᏓᎧᏅᎢ',
    '😹' => 'ᏪᏌ ᎤᎧᏛᎢ ᎠᎵᎮᎵᎬᎢ ᎤᎧᏛᎢ',
    '😻' => 'ᏪᏌ ᎤᏰᏗᏍᎬ ᎤᎧᏔ ᏧᎾᏫ-ᏗᎧᏂ',
    '😼' => 'ᏪᏌ ᎤᎧᏛᎢ ᎠᏓᏰᎵᎠ ᎤᏤᏣᏍᏛᎢ',
    '😽' => 'ᎠᏓᏔᏪᏙᏍᎩ ᏪᏌ ᎤᎧᏛ',
    '🙀' => 'ᏗᎦᏍᏗᏰᏍᎩ ᏪᏌ ᎤᎧᏓ',
    '😿' => 'ᎠᏠᏱᎭ ᏪᏌ ᎤᎧᏛ',
    '😾' => 'ᎤᏓᏁᎯᏳ ᏪᏌ ᎤᎧᏛ',
    '🙈' => 'Ꮭ ᎾᎪᏫᏘᎲᎾ-ᎤᏁᎫᏥᏓ- ᎠᏓᎴᏍᎩᏱᏍᎩ',
    '🙉' => 'ᎠᏛᎩᏍᎩ-ᏂᎨᏒᎾ-ᎤᏲ ᎠᏓᎴᏍᎩᏱᏍᎩ',
    '🙊' => 'ᏂᎦᏬᏂᏍᎬᎾ ᎤᏲ ᎠᏓᎴᏍᎩᏱᏍᎩ',
    '💌' => 'ᎠᏓᎸᏉᎪᏪᎳᏅ',
    '💘' => 'ᎤᎿᏫ ᎦᏝᏗ ᎬᏗ',
    '💝' => 'ᎤᎿᏫ ᎠᏇᏡᏍᏗ',
    '💖' => 'ᎠᏔᎷᎩᏍᎩ ᎠᏓᏅᏙ',
    '💗' => 'ᎠᎵᏌᎳᏗᎲᎢ ᎤᎿᏫ',
    '💓' => 'ᎤᎿᏫ ᎠᏓᎾᏫᏍᎬ',
    '💞' => 'ᏗᏕᏲ ᏚᏓᏅᏛ',
    '💕' => 'ᏔᎵ ᏗᏓᏅᏙ',
    '💟' => 'ᎤᎿᏫ ᏗᏟᎶᏍᏔᏅ',
    '❣' => 'ᎤᏓᎨᏓ ᎤᎿᏫ ᏍᏓᏱ ᎥᎧᏁᎬᎢ',
    '💔' => 'ᎤᏲᏨᎢ ᎤᎿᏫ',
    '❤' => 'ᎩᎦᎨ ᎤᎿᏫ',
    '🩷' => 'ᎩᎦᎨ ᎤᏍᎪᎸ ᎤᎾᏫ',
    '🧡' => 'ᎠᏓᎶᏂᎨ ᎤᎿᏫ',
    '💛' => 'ᏓᎶᏂᎨ ᎤᎿᏫ',
    '💚' => 'ᎢᏤᏳᏍᏗ ᎤᎿᏫ',
    '💙' => 'ᏌᎪᏂᎨ ᎤᎿᏫ',
    '🩵' => 'ᏌᎪᏂᎨ ᎤᏍᎪᎸ ᎤᎾᏫ',
    '💜' => 'ᎠᏓᎲᎵᎨ ᎤᎿᏫ',
    '🤎' => 'ᎤᏬᏗᎨ ᎤᎾᏫ',
    '🖤' => 'ᎬᎿᎨ ᎤᎾᏫ',
    '🩶' => 'ᎬᎿᎨ ᎤᏍᎪᎸ ᎤᎾᏫ',
    '🤍' => 'ᎤᏁᎦ ᎤᎾᏫ',
    '💋' => 'ᎠᏔᏪᏙᏅᎢ ᎤᏙᏪᎸᎢ',
    '💯' => 'ᎠᎪᎯᏧᏈ ᎬᏅᏅᎢ',
    '💢' => 'ᎤᎿᎸᎯ ᏓᏟᎶᏍᏛᎢ',
    '🫯' => 'ᎠᏥᎳᎱ ᎠᎶᎩᎸ',
    '💥' => 'ᏚᎾᏓᏛᏂᎸ',
    '💫' => 'ᎤᎸᏕᎯᏓ',
    '💦' => 'ᎠᎵ ᏧᏩᏬᏨ',
    '💨' => 'ᎠᏓᎾᏫᏍᏗᏍᎬᎢ',
    '🕳' => 'ᎠᏔᎴᏒᎢ',
    '💬' => 'ᎦᏬᏂᎯᏍᏗᎢ ᎤᏃᎴ ᎠᏲᏙᏗ',
    '🗨' => 'ᎠᎦᏍᎦᏂ ᎦᏬᏂᎯᏍᏗᎢ ᎤᏆᎷᏒᎢ',
    '🗯' => 'ᎠᎦᏘᏏ ᎤᎿᎸᎯ ᎤᏆᎷᏒᎢ',
    '💭' => 'ᎠᏓᎾᏖᎸᏍᎩ ᎤᏃᎴ ᎠᏦᏔᏍᏙᏗ',
    '💤' => 'ᏃᏃᏃ',
    '👋' => 'ᎠᏲᎵᎭ',
    '🤚' => 'ᎠᏒᎵᏛᏅ ᎣᏂᏗᏢ ᎣᏬᏰᎾ',
    '🖐' => 'ᎤᏌᎳᏓ ᎤᏬᏱ ᎢᏧᏓᎵ ᏕᎦᏰᏌᏛ',
    '✋' => 'ᎣᏬᏰᎾ ᎠᏌᎵᏛᏅᎢ',
    '🖖' => 'ᏗᎪᏍᏓᏱᏗᎦᎵᏟᎩ ᎠᏓᏲᎵᏍᏗ',
    '🫱' => 'ᎤᏬᏰᏂ ᎠᎦᏘᏏ ᏗᏜ',
    '🫲' => 'ᎤᏬᏰᏂ ᎠᎦᏍᎦᏂ ᏗᏜ',
    '🫳' => 'ᎭᏫᎾᏗᏢ ᎤᏬᏰᏂ ᎡᎳᏗ',
    '🫴' => 'ᎭᏫᎾᏗᏢ ᎤᏬᏰᏂ ᎦᎸᎳᏗ',
    '🫷' => 'ᎠᎦᏍᎦᏂ ᎤᏩᏌᏙᏍᏗ ᎤᏬᏰᏂ',
    '🫸' => 'ᎠᎦᏘᏏ ᎤᏩᏌᏙᏍᏗ ᎤᏬᏰᏂ',
    '👌' => 'ᎣᏏᏊ ᎪᏯᏛ',
    '🤌' => 'ᏗᏓᏇᏄᎩᏍᏗ ᏕᎦᏰᏌᏛ',
    '🤏' => 'ᏗᏓᏇᏄᎩᏍᏗ ᎤᏬᏰᏂ',
    '✌' => 'ᎤᏓᏠᏒ ᎤᏬᏱ',
    '🤞' => 'ᏧᏓᎿᏫᏓ ᏕᎦᏰᏌᏛ',
    '🫰' => 'ᎤᏬᏰᏂ ᎾᎿ ᎠᏚᏂᎯ ᏯᏍᏓ ᎠᎴ ᎦᏰᏌᏛ',
    '🤟' => 'ᎬᎨᏳᎢ ᎤᏬᏯᏂᏍᎩ',
    '🤘' => 'ᎤᏲᎾ ᏓᏟᎶᏍᏛ',
    '🤙' => 'ᏗᏍᏓᏁᎸᎩ ᎤᏬᏱ',
    '👈' => 'ᎣᏂᏗᏜᎪᏯᏗ ᎠᏍᏓᏩᏛᏍᏗ ᎠᏎᎯ ᎠᎦᏍᎦᏂ',
    '👉' => 'ᎣᏂᏗᏜᎪᏯᏗ ᎠᏍᏓᏩᏛᏍᏗ ᎠᏎᎯ ᎠᎦᏘᏏ',
    '👆' => 'ᎣᏂᏗᏜᎪᏯᏗ ᎠᏍᏓᏩᏛᏍᏗ ᏩᏎᎯᎲ ᎦᎸᎳᏓᎬᏘ',
    '🖕' => 'ᎠᏰᏟ ᎦᏰᏌᏛ',
    '👇' => 'ᎣᏂᏗᏜᎪᏯᏗ ᎠᏍᏓᏩᏛᏍᏗ ᏩᏎᎯᎲᎢ ᎡᎳᏗ',
    '☝' => 'ᎠᏎᎯ ᏩᏎᎯᎲᎢ ᎦᎸᎳᏗ',
    '🫵' => 'ᎦᏰᏌᏛ ᎠᏓᏚᎯᏍᏙᏗ',
    '👍' => 'ᎤᏔᎾ ᎦᏰᏌᏛ ᎤᎵᏌᎳᏓ',
    '👎' => 'ᎤᏔᎾ ᎦᏰᏌᏛ ᎡᎳᏗᏜ',
    '✊' => 'ᎠᎵᏇᏅ ᎠᏒᎵᏛᏅᎢ',
    '👊' => 'ᏂᏓᏳᏍᏗᏛ ᎠᎵᏇᏅ',
    '🤛' => 'ᎠᎦᏍᎦᏂ-ᏍᏈᎾ ᎤᎦᏙᏍᏓ',
    '🤜' => 'ᎠᎦᏘᏏ-ᏩᎦᏘᎲ ᎠᎵᏇᏅ',
    '👏' => 'ᏓᏏᏛᏂᎲᎢ',
    '🙌' => 'ᏗᎪᏰᎾ ᏗᏌᎵᏛᏅᎢ',
    '🫶' => 'ᎠᏓᏅᏙ ᏧᏬᏰᏂ',
    '👐' => 'ᏗᏚᎢᏓ ᏙᏬᏰᎾ',
    '🤲' => 'ᏚᎾᏙᏯᏂᎠ ᎦᎸᎳᏗ ᎠᏒᏅᏍᏗ',
    '🤝' => 'ᎠᏓᏲᎵᎲᎢ',
    '🙏' => 'ᏚᏆᏰᏅᏍᏛ',
    '✍' => 'ᎤᏬᏱ ᎪᏪᎳᏅᎢ',
    '💅' => 'ᎤᏑᎦᏢ ᎦᏅᎵᏰᏗ',
    '🤳' => 'ᎣᏮᏌ ᏗᏓᏟᎶᏍᏔᏅᎢ',
    '💪' => 'ᏫᎦᎳᎦ ᎤᏟᎸᏛ ᎦᎸᎳᏗᏟ ᎧᏃᎨᎾ',
    '🦾' => 'ᏔᎷᎩᏍᎩ ᎧᏃᎨᏂ',
    '🦿' => 'ᏔᎷᎩᏍᎩ ᎦᏅᏍᎨᏂ',
    '🦵' => 'ᎦᏅᏍᎨᏂ',
    '🦶' => 'ᎤᎳᏏᏕᏂ',
    '👂' => 'ᎦᎴᏂ',
    '🦻' => 'ᎦᎴᏂ ᎬᏗ ᎠᏛᎩᏍᎬ ᎬᏙᏗ',
    '👃' => 'ᎧᏴᏐᎵ',
    '🧠' => 'ᎤᏅᏥᏓ',
    '🫀' => 'ᎤᎿᏫ',
    '🫁' => 'ᏗᏛᎵᏗᏍᏙᏗᎢ',
    '🦷' => 'ᎦᏅᏙᎬ',
    '🦴' => 'ᎪᎳ',
    '👀' => 'ᏗᎦᏔ',
    '👁' => 'ᎠᎦᏘ',
    '👅' => 'ᎦᏂᎪ',
    '👄' => 'ᎠᎰᎵ',
    '🫦' => 'ᎤᎭᏁᎦᎸᎢ ᎠᏍᎦᎳ',
    '👶' => 'ᎤᏍᏗ',
    '🧒' => 'ᎠᏲᏟ',
    '👦' => 'ᎠᏧᏣ',
    '👧' => 'ᎠᎨᏳᏣ',
    '🧑' => 'ᎤᏔᎾ',
    '👱' => 'ᏴᏫ: ᏓᎶᏂᎨ-ᎤᏍᏘᎩ',
    '👨' => 'ᎠᏍᎦᏯ',
    '🧔' => 'ᎠᏍᎦᏯ: ᏗᎭᏄᎸᎯ',
    '👩' => 'ᎠᎨᏯ',
    '🧓' => 'ᎠᎦᏴᎵ ᎤᏔᎾ',
    '👴' => 'ᎤᏛᏐᏅ',
    '👵' => 'ᎠᎬᏴᎵᎨ',
    '🙍' => 'ᏴᏫ ᎤᏓᏁᎪᏳ',
    '🙎' => 'ᏴᏫ ᎤᏇᏟᎬ',
    '🙅' => 'ᏴᏫ ᎾᏛᏁᎲ ᎥᏝ',
    '🙆' => 'ᏴᏫ ᎠᏎᏟᏙᎲ ᎭᏩ',
    '💁' => 'ᏴᏫ ᎬᏂᎨᏒ ᏂᎬᏁᎲ ᏆᏂᏲᏍᏗ',
    '🙋' => 'ᏴᏫ ᎤᏬᏰᎾ ᎠᎵᏌᎵᏛᏍᎬᎢ',
    '🧏' => 'ᏧᎵᎡᎾ ᏴᏫ',
    '🙇' => 'ᏴᏫ ᎤᏘᏌᏘ',
    '🤦' => 'ᏴᏫ ᎤᎧᏛᎢ ᎠᏓᏏᏔᏗᏍᎬᎢ',
    '🤷' => 'ᏴᏫ ᏗᎦᏅᏬ ᏚᏌᎳᏛ',
    '👮' => 'ᏗᏓᏂᏱᏍᎩ',
    '🕵' => 'ᎤᎦᏛᏂᏙᎯ',
    '💂' => 'ᎠᏯᏫᏍᎩ',
    '🥷' => 'ᏂᏅᏣ',
    '👷' => 'ᏗᏁᏍᎨᏍᎩ ᏧᎸᏫᏍᏓᏁᎯ',
    '🫅' => 'ᎤᎬᏫᏳᎯ ᎤᎵᏍᏚᎳ ᎠᏕᎳ ᏓᎶᏂᎨ',
    '🤴' => 'ᎠᏫᎾ ᎤᎬᏬᏳᎯ',
    '👸' => 'ᎠᏔ ᎤᎬᏫᏳᎯ',
    '👳' => 'ᏴᏫ ᎦᎸᏪᏍᏓᏅ ᎤᎵᏍᏚᎳ',
    '👲' => 'ᎠᏍᎦᏯ ᏣᏂᏏ ᎤᎵᏍᏇᏚᎩ',
    '🧕' => 'ᎠᎨᏯ ᎤᎵᏍᏆᏃᎯ',
    '🤵' => 'ᎠᏍᎦᏯ ᎤᏍᏓᏯᎬᏍᏗ ᏧᏄᏩ',
    '👰' => 'ᏣᎦᏨᏍᏔᏂᏓ ᎠᎨᏯ ᎤᏨᏅᎯ',
    '🤰' => 'ᎦᏁᎵᏓ ᎠᎨᏯ',
    '🫃' => 'ᎦᏁᎵᏓ ᎠᏍᎦᏯ',
    '🫄' => 'ᎦᏁᎵᏓ ᏴᏫ',
    '🤱' => 'ᏧᏓᏍᏓᎢ',
    '👼' => 'ᎤᏍᏗ ᏗᎧᎿᏩᏗᏙᎯ',
    '🎅' => 'ᏧᏠᎦᎴᏓ',
    '🤶' => 'ᎠᎨᏯ ᎦᏁᎵ. ᏧᏠᎦᎴᏓ',
    '🦸' => 'ᏄᎬᏫᏳᏒᎩ ᏩᏥᎸᏉᏛ',
    '🦹' => 'ᏄᎬᏫᏳᏒᎩ ᎠᏍᎦᏂ',
    '🧙' => 'ᎠᏓᏪ',
    '🧚' => 'ᏴᏫ ᎤᏍᏗ ᎦᏃᎯᎵᏙᎯ',
    '🧛' => 'ᎩᎦ ᎠᏓᏁᎩᎡᎯ',
    '🧜' => 'ᏴᏫ ᎠᏣᏗ ᎤᎬᎭᏟ',
    '🧝' => 'ᏴᏫ ᎤᏍᏆᏂᎪᏗᏳ',
    '🧞' => 'ᏥᎾᏱ',
    '🧟' => 'ᎤᏲᎱᏒ ᎤᏗᏛᏓ',
    '🧌' => 'ᎦᎾᏰᎩ ᏴᏫ ᎢᏳᏍᏗ',
    '🫈' => 'ᎠᏍᏖᎬᎢ ᏍᎩᎵ',
    '💆' => 'ᏴᏫ ᎠᏥᏓᏍᎪᎵᏰᏍᎬᎢ',
    '💇' => 'ᏴᏫ ᎾᏛᏁᎲ ᎠᎵᏍᏙᏰᏗ',
    '🚶' => 'ᏴᏫ ᎠᏨᏏᏰ',
    '🧍' => 'ᏴᏫ ᎦᏙᎦ',
    '🧎' => 'ᏴᏫ ᏕᏥᎾᏆᎾ',
    '🏃' => 'ᏴᏫ ᎠᏛᏟᏒᎢ',
    '💃' => 'ᎠᎨᏯ ᎠᎵᏍᎩᏍᎩ',
    '🕺' => 'ᎠᏍᎦᏯ ᎠᎵᏍᎩᏍᎬ',
    '🕴' => 'ᎠᏍᎦᏯ ᏚᎸᏫᏍᏓᏁᎯ ᏧᏠᏱᎭ ᏓᎴᎲᏍᎬᎢ',
    '👯' => 'ᏴᏫ ᏥᏍᏚ ᏗᎦᎴ ᎤᏂᏍᏆᎸᎡᎲᎢ',
    '🧖' => 'ᎩᎶ ᎠᏯᎠ ᎠᏔᎶᎴᎬ ᎧᏅᏑᎸ',
    '🧗' => 'ᏴᏫ ᎦᎵᏙᎭ',
    '🤺' => 'ᏴᏫ ᎭᏰᎵᏍᏗ ᎬᏗ ᎦᏁᏦᏍᏗᎲ',
    '🏇' => 'ᏐᏈᎵ ᏓᎾᏙᎩᏯᏍᎬᎢ',
    '⛷' => 'ᏴᏫ ᏗᏟᎾᏒᏙᏗᏍᎩ',
    '🏂' => 'ᎥᏂᏥ ᏗᏟᎾᏒᏙᏗ',
    '🏌' => 'ᎠᏏᏴᏫ ᎪᏍᏛᏂᎲᎢ ᏍᏆᏞᏍᏗ',
    '🏄' => 'ᏴᏫ ᎠᎹ ᏓᏍᏗᎳᏁᎬ ᎡᏙᎯ',
    '🚣' => 'ᏴᏫ ᎦᎦᏪᏍᎦ ᏥᏳ',
    '🏊' => 'ᏴᏫ ᎠᏓᏬ',
    '⛹' => 'ᏴᏫ ᏍᏆᏞᏍᏗ ᎠᏓᏓᎨᎬ',
    '🏋' => 'ᏴᏫ ᏓᎵᏌᎳᏗᏍᎬᎢ ᏧᏓᎨᏓ',
    '🚴' => 'ᏴᏫ ᏓᏝᏱᏍᎬᎢ',
    '🚵' => 'ᏴᏫ ᎤᏅᏓᏢ ᏔᎵ ᏗᎦᏩᏘ ᎤᎩᎸᏗ',
    '🤸' => 'ᏴᏫ ᏓᏁᏍᏆᏕᎬ',
    '🤼' => 'ᎠᏂᏴᏫ ᏓᏁᎯᎲ',
    '🤽' => 'ᏴᏫ ᏓᏁᎶᎲᏍᎬ ᎠᎹ ᎠᎳᏍᎦᎵᏙᏗ',
    '🤾' => 'ᏴᏫ ᏓᏁᎶᎲᏍᎬ ᏍᏆᏞᏍᏗ ᎦᎸᏛᏂᏍᏙᏗ',
    '🤹' => 'ᏴᏫ ᏓᏍᏆᏞᏏᏙᎲᎢ',
    '🧘' => 'ᏴᏫ ᏚᏓᏝᏗᏍᏗ',
    '🛀' => 'ᏴᏫ ᎠᏓᏬᏍᎬᎢ',
    '🛌' => 'ᏴᏫ ᎦᏂᏟ ᎦᏅᎬ',
    '👭' => 'ᎠᏂᎨᏯ ᏚᎾᏙᏯᏂᎠ',
    '👫' => 'ᎠᏍᎦᏯ ᎠᎴ ᎠᎨᏯ ᏚᎾᏙᏯᏂᎠ',
    '👬' => 'ᎠᏂᏍᎦᏯ ᏚᎾᏙᏯᏂᎠᎩ',
    '💏' => 'ᎠᏔᏪᏙᎢᏍᏗ',
    '💑' => 'ᏗᎾᏤᎯ ᏧᏂᎿᏫ',
    '🗣' => 'ᎧᏁᎩ ᎠᏍᎪᎵ',
    '👤' => 'ᎤᏲᏨᎢ ᎥᎿ ᎤᏙᏢᏒᎢ',
    '👥' => 'ᎠᏲᎪᎢ ᎥᎿ ᎤᏙᏢᏒᎢ',
    '🫂' => 'ᎠᏂᏴᏫ ᏓᏓᏍᏆᏂᏱᏍᎬ',
    '👪' => 'ᏏᏓᏁᎸᎢ',
    '👣' => 'ᏚᎳᏏᏅᎢ ᏚᏙᏪᎸᎢ',
    '🫆' => 'ᎦᏰᏌᏛ ᏚᏙᏪᎸᎢ',
    '🦰' => 'ᎩᎦᎨ ᎤᏍᏘᎦ',
    '🦱' => 'ᎤᎵᏥᏍᏆᏁᏓ ᎤᏍᏘᎦ',
    '🦳' => 'ᎤᏁᎦ ᎤᏍᏘᎦ',
    '🦲' => 'ᎤᎨᏬᏗ',
    '🐵' => 'ᎠᏓᎴᏍᎩᏱᏍᎩ ᎤᎧᏛ',
    '🐒' => 'ᎠᏓᎴᏍᎩᏱᏍᎩ',
    '🦍' => 'ᎤᏔᎾ ᎠᏓᎴᏍᎩᏱᏍᎩ',
    '🦧' => 'ᎩᎦᎨ ᎤᏔᎾ ᎠᏓᎴᏍᎩᏱᏍᎩ',
    '🐶' => 'ᎩᎵ ᎤᎧᏛ',
    '🐕' => 'ᎩᎵ',
    '🦮' => 'ᏗᎨᏫ ᏥᏍᏕᎵᏍᎩ ᎩᏟ',
    '🐩' => 'ᎩᎵ ᏧᎵᏥᏍᏆᏁᏗ',
    '🐺' => 'ᏩᏯ',
    '🦊' => 'ᏧᏟ',
    '🦝' => 'ᎬᎵ',
    '🐱' => 'ᏪᏌ ᎤᎧᏛ',
    '🐈' => 'ᏪᏌ',
    '🦁' => 'ᏢᏓᏥ',
    '🐯' => 'ᎬᎮ ᎤᎧᏛ',
    '🐅' => 'ᎬᎮ',
    '🐆' => 'ᏪᏌ ᏧᏅᏣ',
    '🐴' => 'ᏐᏈᎵ ᎤᎧᏛ',
    '🫎' => 'ᎠᏫ ᎡᏆ ᎢᏳᏍᏗ',
    '🫏' => 'ᏗᎦᎴᏅᎯᏓ',
    '🐎' => 'ᏐᏈᎵ',
    '🦄' => 'ᏐᏈᎵ ᎤᎷᎩ',
    '🦓' => 'ᏧᎶᏟᏗ ᏐᏈᎵ',
    '🦌' => 'ᎠᎭᏫ',
    '🦬' => 'ᏯᎾᏌ',
    '🐮' => 'ᏩᎦ ᎤᎧᏛ',
    '🐂' => 'ᏩᎦ ᏧᎧᏅᏍᏕᎾ',
    '🐃' => 'ᏯᎾᏏ ᎠᎹ',
    '🐄' => 'ᏩᎦ',
    '🐷' => 'ᏏᏆ ᎤᎧᏛ',
    '🐖' => 'ᏏᏆ',
    '🐗' => 'ᏏᏆ ᏧᎧᏅᏍᏕᎾ',
    '🐽' => 'ᏏᏆ ᎧᏴᏐᎵ',
    '🐏' => 'ᎤᏃᏕᎾ ᏧᎧᏅᏍᏕᎾ',
    '🐑' => 'ᎤᏃᏕᎾ ᎠᏓ',
    '🐐' => 'ᎤᎦᏐᏣᏁᏓ',
    '🐪' => 'ᎨᎻᎵ',
    '🐫' => 'ᏔᎵ-ᎤᏩᏐᎯᏟ ᎨᎻᎵ',
    '🦙' => 'ᎨᎻᎵ ᏳᏍᏗ',
    '🦒' => 'ᏗᎦᎵᏍᏚᎩᏍᎩ',
    '🐘' => 'ᎤᏔᎾ ᎧᎹᎹ',
    '🦣' => 'ᎠᎦᏴᎵ ᎧᎹᎹ',
    '🦏' => 'ᎳᏃᏏᎳ',
    '🦛' => 'ᏗᏆᎴᏂ ᏏᏆᏳᏍᏗ',
    '🐭' => 'ᏥᏍᏕᏥ ᎤᎧᏛ',
    '🐁' => 'ᏥᏍᏕᏥ',
    '🐀' => 'ᎧᏂᏈᏌ',
    '🐹' => 'ᏎᎳᏈᏏ ᏗᎧᏃᏗᎢ',
    '🐰' => 'ᏥᏍᏚ ᎤᎧᏛ',
    '🐇' => 'ᏥᏍᏚ',
    '🐿' => 'ᎩᏳᎦ',
    '🦫' => 'ᏙᏯ',
    '🦔' => 'ᏚᏩᏱᏢᎡᎯᏏᏆ',
    '🦇' => 'ᏜᎺᎭ',
    '🐻' => 'ᏲᎾ',
    '🐨' => 'ᎪᎠᎳ',
    '🐼' => 'ᎬᎿᎨ ᎤᏁᎦᏃ ᏲᎾ',
    '🦥' => 'ᎤᏍᎦᏃᎵ ᎦᎴᎩ',
    '🦦' => 'ᏥᏯ',
    '🦨' => 'ᏗᎵ',
    '🦘' => 'ᎧᎾᎦᏭ',
    '🦡' => 'ᎠᏓᏕᏯᏙᏗᏍᎩ',
    '🐾' => 'ᏚᎳᏏᏅ ᏚᏙᏪᎸᎢ',
    '🦃' => 'ᎬᏂ',
    '🐔' => 'ᏣᏔᎦ',
    '🐓' => 'ᏣᏔᎦ ᎠᏨᏯ',
    '🐣' => 'ᏣᏔᎩ ᎠᏣᎢ',
    '🐤' => 'ᎤᏍᏗ ᏣᏔᎩ',
    '🐥' => 'ᎢᎬᏱ-ᏗᏜ ᎤᏍᏗ ᏥᏔᎦ',
    '🐦' => 'ᏥᏍᏆ',
    '🐧' => 'ᏧᏴᏝ ᎡᎯ ᏥᏍᏆ',
    '🕊' => 'ᎫᎴ ᏗᏍᎪᏂ',
    '🦅' => 'ᏬᎭᎵ',
    '🦆' => 'ᎧᏬᏄ',
    '🦢' => 'ᏍᎨᏆ',
    '🦉' => 'ᎤᎫᎫ',
    '🦤' => 'ᏙᏙ',
    '🪶' => 'ᎤᎩᏓᏟ',
    '🦩' => 'ᎠᏚᎯᏅᏍᏗ ᏥᏍᏆ',
    '🦚' => 'ᎬᎾ ᏧᏆᏔᎵ ᏧᎷᎩ ᎠᏨᏯᎢ',
    '🦜' => 'ᏥᏍᏆ ᎦᏬᏂᏍᎩ',
    '🪽' => 'ᎧᏃᎨᏂ',
    '🪿' => 'ᏌᏌ',
    '🐸' => 'ᏩᎶᏏ ᎤᎧᏛ',
    '🐊' => 'ᏧᎳᏍᎩ',
    '🐢' => 'ᏓᎦᏏ',
    '🦎' => 'ᏘᏲᎭᎵ',
    '🐍' => 'ᎢᎾᏓ',
    '🐲' => 'ᎤᎦᏖᎾ ᎤᎧᏛ',
    '🐉' => 'ᎢᎾᏓ ᏗᎪᏯᏗ',
    '🦕' => 'ᏘᏲᎭᎵ ᎤᎳᏏᏕᎾ',
    '🦖' => 'Ꭴ-ᎤᎬᏫᏳᎯ',
    '🐳' => 'ᎧᏬᎵᏕᏍᎬ ᏓᏆ',
    '🐋' => 'ᏓᏆ',
    '🐬' => 'ᏗᎵᏆᏕᎩ',
    '🫍' => 'ᎣᎧ',
    '🦭' => 'ᏗᏏᏫᏍᎩ',
    '🐟' => 'ᎠᏣᏗ',
    '🐠' => 'ᎤᏗᏞᎦ ᎠᏣᏗ',
    '🐡' => 'ᎠᏦᏔᏍᎩᎠᏣᏗ',
    '🦈' => 'ᏗᎧᏳᎦ',
    '🐙' => 'ᎠᏓᏢᎢ',
    '🐚' => 'ᎠᏕᏲᎯ ᎠᏯᏍᎦᎸᎢ',
    '🪸' => 'ᏅᏯ ᎠᎹᏱ',
    '🪼' => 'ᏩᏂᎨ ᎠᏣᏗ',
    '🦀' => 'ᎤᏯᏍᎦᏬᏗ',
    '🦞' => 'ᎤᏔᎾ ᏥᏍᏛᎾ',
    '🦐' => 'ᏥᏅᏅ',
    '🦑' => 'ᏍᏈᏗ',
    '🦪' => 'ᎤᏔᎾ ᏓᎬᎾ',
    '🐌' => 'ᎡᎳᏆ',
    '🦋' => 'ᎤᏍᏗ ᎧᎹᎹ',
    '🐛' => 'ᏥᏍᎪᏯ',
    '🐜' => 'ᏙᏒᏓᎵ',
    '🐝' => 'ᎦᏍᎪᏳ',
    '🪲' => 'ᏧᎵᏍᎫᏩ',
    '🐞' => 'ᎠᎨᏯ ᏧᎵᏍᎫᏩ',
    '🦗' => 'ᏔᎳᏚ',
    '🪳' => 'ᎤᏂᎾᏌ',
    '🕷' => 'ᎧᎿᏁᏍᎩ',
    '🕸' => 'ᎧᎿᏁᏍᎩ ᎤᏏᎳᏛᎢ',
    '🦂' => 'ᏥᏍᏛᎾ ᎠᏓᏨᏍᎩ',
    '🦟' => 'ᏙᏌ',
    '🪰' => 'ᏛᎦ',
    '🪱' => 'ᎤᏥᏯ',
    '🦠' => 'ᎥᏳᎩ ᎠᏓᏠᎩ',
    '💐' => 'ᏧᏂᏥᎸᏍᎩ',
    '🌸' => 'ᎩᏔᏯ ᎤᏥᎸᏅ',
    '💮' => 'ᎤᏁᎦ ᎤᏥᎸᏍᎩ',
    '🪷' => 'ᏓᎶᏂᎨᏍᏛ ᎠᏥᎸᏍᎩ',
    '🏵' => 'ᎠᎧᏁᏍᏗ',
    '🌹' => 'ᎶᏏ',
    '🥀' => 'ᎤᏩᏅᏬᏒ ᎠᏥᎸᏍᎩ',
    '🌺' => 'ᎭᏈᏍᎬᏏ',
    '🌻' => 'ᏅᏓᏗᎧᏅᏩᏗᏙᎯ',
    '🌼' => 'ᎤᏥᎸᏅ',
    '🌷' => 'ᏚᎵᏈ',
    '🪻' => 'ᎤᎬ ᎠᏔᏍᎩᏍᎩ',
    '🌱' => 'ᎤᎦᏔᏛᏅ',
    '🪴' => 'ᎦᎪᏗ',
    '🌲' => 'ᎠᏥᎾ ᎢᏡᎬᎢ',
    '🌳' => 'ᎦᎵᏍᏚᏬᏍᎬᎢ ᎢᏡᎬᎢ',
    '🌴' => 'ᏧᎦᏄᏓᏅᎯᏛ ᎢᏡᎬᎢ',
    '🌵' => 'ᎤᎵᎡᏍᎩ',
    '🌾' => 'ᎠᏍᏓᏴᏓᏅ Ꮎ ᏓᎵᏆ',
    '🌿' => 'ᎤᎿᏍᏕᎳ',
    '☘' => 'ᏧᎦᎶᎦ',
    '🍀' => 'ᏅᎩ ᏧᎦᎶᎩ ᎩᎦᎨ ᎠᏥᎸᏍᎩ',
    '🍁' => 'ᏢᏩᎩ ᎤᏆᎶᎩ',
    '🍂' => 'ᎤᎵᏍᏚᎪᏒᎩ',
    '🍃' => 'ᎤᎦᎶᎦ ᎦᏃᏰ ᎦᏃᎸᏍᎬᎢ',
    '🪹' => 'ᎧᏁᏍᏓᎳᎲᎢ',
    '🪺' => 'ᎧᏁᏍᏓᎳᎲᎢ ᎠᎴ ᏧᏪᏥ',
    '🍄' => 'ᏓᏬᎵ',
    '🪾' => 'ᎤᏲᎱᏒ ᎢᏡᎬᎢ',
    '🍇' => 'ᎤᏂᏖᎸᎳᏗ',
    '🍈' => 'ᎬᎩᏍᏗ',
    '🍉' => 'ᎠᎹ ᎬᎩᏍᏗ',
    '🍊' => 'ᎠᏓᎶᏂᎨ ᎠᎩᏍᏗ',
    '🍋' => 'ᎵᎹᏂ',
    '🍌' => 'ᏆᏁᎾ',
    '🍍' => 'ᏃᏣ ᏒᎦᏔ ᎠᎩᏍᏓ',
    '🥭' => 'ᎺᏂᎪ',
    '🍎' => 'ᎩᎦᎨ ᏒᎦᏔ',
    '🍏' => 'ᎢᏤᏳᏍᏗ ᏒᎦᏔ',
    '🍐' => 'ᎦᏛᏗ',
    '🍑' => 'ᏆᎾ',
    '🍒' => 'ᎩᏔᏯ',
    '🍓' => 'ᎠᏂ',
    '🫐' => 'ᎫᏩᏯ',
    '🥝' => 'ᎩᏫ ᎤᏓᏔᏅᎢ',
    '🍅' => 'ᏓᎹᏟ',
    '🫒' => 'ᎣᎵᏩ',
    '🥥' => 'ᏐᏈ ᎤᏪᏥ',
    '🥑' => 'ᏧᎳᏍᎩ ᎤᏪᏥ',
    '🍆' => 'ᎤᏪᏥᎦᎪᏗ',
    '🥔' => 'ᏄᎾ',
    '🥕' => 'ᏓᎶᏂᎨ ᎦᏢᏍᎩ',
    '🌽' => 'ᏎᎷ ᎦᎵᏟᎬ',
    '🌶' => 'ᎤᏗᏞᎩ ᏗᏆᏲᏗ',
    '🫑' => 'ᎤᎭᎸᏂ ᎤᏥᎸ ᎤᏴᏍᏗ',
    '🥒' => 'ᎦᎦᎹ',
    '🥬' => 'ᎢᏤᎢᏳᏍᏗ ᎤᎦᎶᎦ',
    '🥦' => 'ᏧᎦᏅᏕᎾ ᎤᏍᏗ',
    '🧄' => 'ᏃᏳᏟ',
    '🧅' => 'ᏒᎩ',
    '🥜' => 'ᎠᏂᏅᎯᏓ ᏚᏯ',
    '🫘' => 'ᏚᏯ',
    '🌰' => 'ᏘᎵ',
    '🫚' => 'ᏄᏱᎦᎵ',
    '🫛' => 'ᎤᏅᏢᏓᎵ',
    '🫜' => 'ᎤᎾᏍᏕᏢ ᎠᎩᏍᏗ',
    '🍞' => 'ᎦᏚ',
    '🥐' => 'ᎦᎸᏥ ᎦᏚ',
    '🥖' => 'ᎦᏅᎯᏓ ᏌᎨ ᎦᏚ',
    '🫓' => 'ᎠᏍᏓᏅᏅᎢ ᎦᏚ',
    '🥨' => 'ᎤᏍᏓᎦᏴᎯᏓ ᎦᏚ',
    '🥯' => 'ᎤᏣᎴᏍᏗᎤᎦᏔ ᎦᏚ',
    '🥞' => 'ᏔᎷᎩᏍᎩ ᎦᏚ',
    '🧇' => 'ᏅᎩ ᏧᎾᏏᏯ ᎦᏚ',
    '🧀' => 'ᎤᏅᏗ ᎦᏚᏅ ᎠᎦᏯᎷᏴᎢ',
    '🍖' => 'ᎭᏫᏯ ᎦᏁᎦᎸ ᎪᎳ',
    '🍗' => 'ᏥᏔᎦ ᎦᎦᎸ',
    '🥩' => 'ᎭᏫᏯ ᎠᎬᎭᎷᏴᎢ',
    '🥓' => 'ᎭᏫᏯ ᏗᎦᏒᏍᏔᏅ',
    '🍔' => 'ᎭᏫᏯ ᎠᏍᏛᎭᏟ',
    '🍟' => 'ᎦᎸᏥᏅᎾ ᏗᎬᏣᎳᏅᎯ',
    '🍕' => 'ᎠᏍᏓᎲᏢᏅ ᎠᎩᏍᏗ',
    '🌭' => 'ᎠᏒᏅᏙᏗ ᎭᏫᏯ',
    '🥪' => 'ᎠᏍᏛᎭᏟ',
    '🌮' => 'ᏎᎷ ᎦᏚ ᎤᏂᏍᏛᎦᏱᏓ',
    '🌯' => 'ᎦᏇᏅ',
    '🫔' => 'ᏔᎹᎴ',
    '🥙' => 'ᎦᏆᏅᏓᏅ ᎠᏍᏓᏅᏅᎢ ᎦᏚ',
    '🧆' => 'ᏍᏆᏞᏍᏗ ᏚᏳᎾᏍᏗᎢ',
    '🥚' => 'ᎤᏪᏥ',
    '🍳' => 'ᎠᏓᏍᏓᏴᎲᏍᎩ',
    '🥘' => 'ᏅᏬᏚ ᎤᏩᏖᏌᏓ Ꮎ ᎠᎵᏍᏓᏴᏗ',
    '🍲' => 'ᏧᎳᏍᎩ ᎧᎵ ᎠᎵᏍᏓᏴᏗ',
    '🫕' => 'ᎤᏅᏗ ᎦᏚᏅ ᎬᎾᏬᏍᎦ',
    '🥣' => 'ᎤᏅᏪᏓ ᎾᏍᎩ ᎬᏩᏠᏯᏍᏗ ᎠᏗᏙᏘ',
    '🥗' => 'ᎢᏤᏳᏍᏗ ᎪᏍᏓ ᎠᎩᏍᏗ',
    '🍿' => 'ᏎᎷ ᎠᏔᏍᎩᏍᎩ',
    '🧈' => 'ᎪᏢᎾ',
    '🧂' => 'ᎠᎹ',
    '🥫' => 'ᎦᏟᏔᏅᎢ ᎠᎵᏍᏓᏰᏗ',
    '🍱' => 'ᏣᏱᏂᏏ ᎤᎵᏍᏓᏰᏗ',
    '🍘' => 'ᏓᎵᏆ ᎦᏚ ᎤᏍᏓᎬᏴᎯᏓ',
    '🍙' => 'ᏓᎵᏆ ᏍᏆᏞᏍᏗ',
    '🍚' => 'ᏓᎵᏆ ᎬᏂᏍᏔᏅᎢ',
    '🍛' => 'ᏓᎵᏆ ᎤᎦᎹ',
    '🍜' => 'ᎠᏥᎳ ᎦᏌᏙᏯᏍᎩ ᏗᏩᎵ',
    '🍝' => 'ᏍᏆᎨᏘ',
    '🍠' => 'ᎦᏚᏅ ᏄᎾ ᎠᏂᏅᎯᏓ',
    '🍢' => 'ᎣᏗᏂ',
    '🍣' => 'ᎠᏑᏴᎾ ᎠᎩᏍᏗ',
    '🍤' => 'ᎬᏣᎳᏅᎢ ᏥᏅᏅ',
    '🍥' => 'ᎠᏣᏗ ᎦᏚ ᎤᎦᎾᏍᏓ ᎤᏠᏯᏍᏗ ᎠᏗᏆᎸᏕᏲᎯ',
    '🥮' => 'ᎤᏓ ᎦᏚ ᎤᎦᎾᏍᏓ',
    '🍡' => 'ᏕᏂᎪ',
    '🥟' => 'ᎦᎸᏅᎢ',
    '🥠' => 'ᏣᏂᏏ ᎦᏚ ᎤᎦᎾᏍᏓ',
    '🥡' => 'ᎠᏫᏛᏗ ᎧᏁᏌ',
    '🍦' => 'ᎦᏁᏍᏓᎵᏗᏍᏓᏅ ᎤᏅᏗ',
    '🍧' => 'ᎤᏁᏍᏓᎳ ᎠᏍᏙᏰᏓ',
    '🍨' => 'ᎤᏅᏗ ᎦᏁᏍᏓᎳᏗᏍᏔᏅ',
    '🍩' => 'ᎠᏔᎴᏓ ᎦᏚ',
    '🍪' => 'ᎦᏚ ᎤᎦᎾᏍᏗ',
    '🎂' => 'ᎤᏕᏘᏱᏍᎬᎢ ᎦᏚ ᎤᎦᎾᏍᏓ',
    '🍰' => 'ᎦᏚ ᎤᎦᎾᏍᏓ',
    '🧁' => 'ᎤᎵᏍᏈᏗ ᎦᏚ ᎤᎦᎾᏍᏗ',
    '🥧' => 'ᎨᎵᏍᎩ',
    '🍫' => 'ᎤᏬᏗᎨ ᎧᎵᏎᏥ',
    '🍬' => 'ᎧᎵᏎᏥ',
    '🍭' => 'ᎧᎵᏎᏥ ᎦᏅᎯᏓ',
    '🍮' => 'ᎨᎵᏍᏔᏅ',
    '🍯' => 'ᏩᏚᎵᏏ ᎠᏟᏍᏙᏗ',
    '🍼' => 'ᎤᏍᏗ ᎤᏍᏛᏍᏗ',
    '🥛' => 'ᎤᏅᏗ ᎤᎸᏌᏗ ᎠᏟᏍᏛᎢ',
    '☕' => 'ᎤᏗᏞᎩ ᎠᏗᏔᏍᏗ',
    '🫖' => 'ᎠᎹ ᎠᎪᏙᏗ',
    '🍵' => 'ᎤᎵᏍᏈᏘ ᎦᏂᏴᏙᏗ ᏄᏍᏛᎾ',
    '🍶' => 'ᎠᏗᏔᏍᏗ',
    '🍾' => 'ᎫᎩ ᎬᏩᏠᏯᏍᏗ ᎠᏔᏍᎩᏍᎩ',
    '🍷' => 'ᎩᎦᎨ ᎠᏗᏔᏍᏗ ᎫᎩ',
    '🍸' => 'ᎠᏕᏯᏅᎢ ᎠᏗᏔᏍᏗ ᎤᎸᏌᏗ',
    '🍹' => 'ᏧᎦᏃᏩ ᎠᏗᏔᏍᏗ',
    '🍺' => 'ᎠᏬᎩᏢᏍᎩ ᎠᏟᏍᏙᏗ',
    '🍻' => 'ᏓᏓᏒᏅᏍᏗᎲ ᎠᏬᎩᏢᏍᎩ ᏗᏟᏙᏗ',
    '🥂' => 'ᏓᏓᏒᏅᏍᏗᎲ ᏧᎸᏌᏗ',
    '🥃' => 'ᎫᎩ ᎠᏟᏍᏙᏗ',
    '🫗' => 'ᎠᏟᎠ',
    '🥤' => 'ᎤᎵᏍᏈᏘ ᎾᏍᎩ ᎬᏩᏠᏯᏍᏗ ᎠᎹᏗᏙᏗ',
    '🧋' => 'ᏚᏆᎷᏒ ᎤᎦᎶᎦ',
    '🧃' => 'ᎠᏗᏔᏍᏗ ᎧᏁᏌᎢ',
    '🧉' => 'ᎤᎩᎶᎩ ᎠᏗᏔᏍᏗ',
    '🧊' => 'ᎤᏁᏍᏓᎳ ᏧᎾᏏᏯ ᏅᎩ',
    '🥢' => 'ᎦᎷᏍᏗᎦᏅᏍᏗ',
    '🍽' => 'ᏴᎩ ᎠᎴ ᎠᏰᎳᏍᏗ ᏖᎵᏙᏃ',
    '🍴' => 'ᏳᎩ ᎠᎴ ᎭᏰᎵᏍᏗ',
    '🥄' => 'ᎠᏗᏙᏗ',
    '🔪' => 'ᎠᏓᏍᏓᏱᏗᎢ ᎠᏰᎳᏍᏗ',
    '🫙' => 'ᎫᎫᎢ',
    '🏺' => 'ᎩᎦᎨ ᎠᏗᏔᏍᏗ ᏗᏟᏍᏙᏗ',
    '🌍' => 'ᎡᎶᎯ ᏗᏟᎶᏍᏔᏅ ᎬᏂᎨᏒ ᏂᎬᎾ ᏳᎳᏈ-ᎬᎿᎨᏍᏛ',
    '🌎' => 'ᎡᎶᎯ ᏗᏟᎶᏍᏔᏅ ᎬᏂᎨᏒ ᏂᎬᎾ ᎠᎹᏰᎵ',
    '🌏' => 'ᎡᎶᎯ ᏗᏟᎶᏍᏔᏅ ᎬᏂᎨᏒ ᏂᎬᎾ ᏓᎶᏂᎨ-ᎡᎳᏗ',
    '🌐' => 'ᎡᎶᎯ ᏗᏟᎶᏍᏔᏅᎢ ᎬᏩᏠᏯᏍᏗ ᎹᎵᏗᏂᏱᏏ',
    '🗺' => 'ᎧᎵ ᎡᎶᎯ ᎡᎶᎯ ᏓᏟᎶᏍᏛᎢ',
    '🗾' => 'ᎡᎶᎯ ᏓᏟᎶᏍᏛ ᎾᎿ ᏤᏇᎾ',
    '🧭' => 'ᎠᎳᏂ ᎠᎦᏙᏗ',
    '🏔' => 'ᎥᏃᏥ-ᏚᏭᏝᎥᎢ ᎤᏓᎳ',
    '⛰' => 'ᎤᏅᏓᏢᎢ',
    '🛘' => 'ᎦᏙᎯ ᎠᏠᎳᏙᏗ',
    '🌋' => 'ᎦᏙ ᎠᏔᎴᏒ ᎠᏔᏍᎩᏍᎩ',
    '🗻' => 'ᏡᏥ ᎣᏓᎸ',
    '🏕' => 'ᏓᏂᎵᏦᏛᏍᎬᎢ',
    '🏖' => 'ᏃᏳᎯ ᎠᏓᏩᏗᏍᏙᏗ',
    '🏜' => 'ᎢᎪᏛ',
    '🏝' => 'ᎢᎪᏛ ᎤᎦᏚᏛᎢ',
    '🏞' => 'ᎢᎬᎾᏕᎾ ᎠᏰᎵ ᎡᏓᏍᏗᎢ',
    '🏟' => 'ᎤᎾᎴᏅᏗ',
    '🏛' => 'ᎤᏪᏘ ᎠᏓᏁᎸᎢ',
    '🏗' => 'ᏓᎣᏁᏍᎨᏍᎬᎢ ᏗᎾᏁᏍᎨᏍᎩ',
    '🧱' => 'ᏅᏯᎠᏛᏓᏔᏅᎯ',
    '🪨' => 'ᏅᏯᎢ',
    '🪵' => 'ᎠᏓ',
    '🛖' => 'ᎲᏘ',
    '🏘' => 'ᏗᎦᎵᏦᏕ',
    '🏚' => 'ᎠᏁᏍᎦᏬᏍᎦ ᎦᎵᏦᏕ',
    '🏠' => 'ᎦᎵᏦᏕ',
    '🏡' => 'ᎦᎵᏦᏕ ᎬᏩᏠᏯᏍᏗ ᎠᏫᏒᏅᎢ',
    '🏢' => 'ᏗᎦᎶᏫᏍᏓᏁᏗ ᎠᏓᏁᎸᎢ',
    '🏣' => 'ᏣᏩᏂᏏ ᎪᏪᎵ ᏧᏂᏍᏚᎢᏍᏗ',
    '🏤' => 'ᎪᏪᎵ ᏗᎦᏁᏍᏗᎢ',
    '🏥' => 'ᏧᏂᏢᎩ',
    '🏦' => 'ᎠᏕᎳᏧᏂᏗ ᎤᎾᏕᏘᏱᏍᎬ',
    '🏨' => 'ᏧᏂᏒᏍᏗ',
    '🏩' => 'ᎠᏓᎸᏉᏗ ᎠᏒᏍᏗ',
    '🏪' => 'ᎠᎯᏓᏃ ᏩᏓᎾᏁᏍᏗᎢ',
    '🏫' => 'ᏗᏕᎶᏆᏍᏗ',
    '🏬' => 'ᎤᏔᎾ ᎠᏓᏅᏅᎢ',
    '🏭' => 'ᎪᎱᏍᏗ ᎤᏃᏢᏗ',
    '🏯' => 'ᏣᏩᏂᏏ ᎤᏂᏯᏫᏍᏗ',
    '🏰' => 'ᎤᏂᏯᏫᏍᏗ',
    '💒' => 'ᏕᎨᎩᏨᏍᏗᎲᎢ',
    '🗼' => 'ᏙᎩᏲ ᎨᏛᎢ',
    '🗽' => 'ᎠᎴᏔᏅ ᎣᏩᏌ ᏗᎫᎪᏔᏂᏓᏍᏗ ᏓᏟᎶᏍᏛᎢ',
    '⛪' => 'ᏧᏂᎳᏫᏍᏗ',
    '🕌' => 'ᏗᎦᎳᏫᏍᏗ',
    '🛕' => 'ᎯᏂᏚ ᏧᏂᎳᏫᏍᏗ',
    '🕍' => 'ᎠᏂᏧᏏ ᏧᏂᎳᏫᏍᏗ',
    '⛩' => 'ᏏᏂᏙᎯ ᎠᏤᎵᏍᏛᎢ',
    '🕋' => 'ᎧᏆ',
    '⛲' => 'ᎠᎹ ᎤᎾᏄᎪᎢᏍᏗ',
    '⛺' => 'ᎦᎵᏦᏛ',
    '🌁' => 'ᎤᎬᎭᏓ',
    '🌃' => 'ᎤᏒᏗᏜ ᏃᏈᏏ',
    '🏙' => 'ᎦᏚᎲᎢ ᎠᏍᏛᎢ',
    '🌄' => 'ᎤᎩᏥᏍᎬ ᎦᏚ ᏚᏙᏓᎸ',
    '🌅' => 'ᎤᎩᏥᏍᎬ',
    '🌆' => 'ᎦᎫᎲᎢᎤᏙᏢᏒᎢ ᎤᏒᎯᏰᏱ',
    '🌇' => 'ᎤᏕᎵᎬᎢ',
    '🌉' => 'ᎠᏒᏢᎢ ᎤᏒᎢ',
    '♨' => 'ᎤᏗᏞᎦ ᏕᎦᏅᎪᎬᎢ',
    '🎠' => 'ᎠᏕᏲᎯ ᏐᏈᎵ',
    '🛝' => 'ᎠᏠᎳᏙᏗ',
    '🎡' => 'ᏥᏳᏓᏔᎸ ᎦᏆᏙᏗ',
    '🎢' => 'ᏚᎨᏓᎵᏍᏛ ᎠᏦᏙᏗ',
    '💈' => 'ᏗᏓᏍᏙᏰᏍᎩ ᎨᏛᎢ',
    '🎪' => 'ᎠᎾᏛᏁᎵᏍᎩ ᎤᎾᎵᏦᏛᎢ',
    '🚂' => 'ᏗᎦᏣᏄᎳ',
    '🚃' => 'ᏗᎦᏣᏄᎳ ᏙᎴᎳ',
    '🚄' => 'ᎦᏣᏄᎵ-ᎠᏥᎳᏗᎮᎩ ᏗᎦᏣᏄᎵ',
    '🚅' => 'ᎦᏂ ᏗᎦᏣᏄᎵ',
    '🚆' => 'ᏗᎦᏣᏄᎵ',
    '🚇' => 'ᎤᏔᎾ ᏗᎦᏚᎲ',
    '🚈' => 'ᎦᏎᎧ ᏗᏐᏲ',
    '🚉' => 'ᎠᏓᏁᎸ',
    '🚊' => 'ᏗᎦᏣᏄᎵ ᎦᏚᎲ',
    '🚝' => 'ᏍᏌᏊ ᎦᏅᏅ ᏥᏴ',
    '🚞' => 'ᎣᏓᎸ ᎦᏥᏄᎵ ᎤᎶᎯᏍᏗ',
    '🚋' => 'ᏙᏆᎴᎳ ᏴᏫ ᏗᏘᏂᏙᎯ',
    '🚌' => 'ᏗᎾᏕᎶᏆᏍᎩ ᎤᎾᏦᏙᏗ',
    '🚍' => 'ᏗᎾᏕᎶᏆᏍᎩ ᎤᎾᏦᏙᏗ ᏂᏓᏳᏍᏗᏛ',
    '🚎' => 'ᏴᏫ ᏗᏘᏂᏙ ᏙᎴᎳ',
    '🚐' => 'ᎤᏍᏗ ᏙᎴᎳ ᏴᏫ ᏗᏘᏂᏙᎯ',
    '🚑' => 'ᏧᏂᏢᎩ ᏗᏯᏅᎯᏙᎯ',
    '🚒' => 'ᎠᏥᎳ ᎠᏥᎸ ᎠᏂᎩᏍᎩ',
    '🚓' => 'ᏗᏓᏂᎩᏍᎩ ᏙᎴᎳ',
    '🚔' => 'ᏂᏓᏳᏍᏗᏛ ᏗᏓᏂᎩᏍᎩ ᏙᎴᎳ',
    '🚕' => 'ᎠᏓᏣᏁᏗ',
    '🚖' => 'ᏂᏓᏳᏍᏗᏛ ᎠᏈᏗ ᎠᏦᏙᏗ',
    '🚗' => 'ᏗᎦᏚᎴᎾ',
    '🚘' => 'ᏂᏓᏳᏍᏗᏛ ᏙᎴᎳ',
    '🚙' => 'ᎠᎳᏍᎦᎵᏗ ᎬᏙᏗ ᏙᎴᎳ',
    '🛻' => 'ᎠᏫᏛᏗ ᎦᎾᏌᏁᏍᏙᏗ',
    '🚚' => 'ᎦᏅᏔᏂᏙᎯ ᎦᎾᏌᏁᏍᏙᏗ',
    '🚛' => 'ᎸᏁᎢᏍᏔᏅ ᎦᏅᏔᏂᏙᎯ',
    '🚜' => 'ᏗᎦᏓᎷᎩᏍᎩ ᏙᏆᎴᎳ',
    '🏎' => 'ᎠᏙᎩᏯᏍᏗ ᏙᏆᎴᎷ',
    '🏍' => 'ᏔᎵ ᏗᎦᏩᏘ ᎠᎩᎸᏙᏗ',
    '🛵' => 'ᏔᎵ ᏗᎦᏩᏘ',
    '🦽' => 'ᎦᏆᏙᏗ ᎦᏍᎩᎶ',
    '🦼' => 'ᎠᏂᎩᏍᏗᏍᎩ ᎦᏆᏙᏗ ᎦᏍᎩᎶ',
    '🛺' => 'ᎠᏂᎩᏍᏗᏍᎩ ᏓᏆᎴᎷ ᎢᏳᏍᏗ',
    '🚲' => 'ᏔᎵ ᏗᎦᏆᏘ ᎠᎩᎸᏙᏗ',
    '🛴' => 'ᎦᏯᏂᏖᏍᏗ ᎠᎩᎸᏙᏗ',
    '🛹' => 'ᎠᎵᏲᏙᏗ ᏯᏖᎾ',
    '🛼' => 'ᏓᎾᏟᎾᏒᏗᎲᎢ ᏗᎦᏆᏙᏗ',
    '🚏' => 'ᏗᎾᏕᎶᏆᏍᎩ ᎤᎾᏦᏙᏗ ᏧᎴᏫᏍᏙᏗ',
    '🛣' => 'ᎦᎳᏅᏛ',
    '🛤' => 'ᎠᏥᎳ ᏅᏃᎯ',
    '🛢' => 'ᎪᎢ ᏒᏙᎾ',
    '⛽' => 'ᎨᏌᎵᏂ ᎦᏌᏙᏯᏍᎩ',
    '🛞' => 'ᎦᏆᏙᏗ',
    '🚨' => 'ᏗᏓᏂᎩᏍᎩ ᏙᎴᎳ ᎠᏨᏍᏗ',
    '🚥' => 'ᏥᏱ ᏄᏍᏗᏓᏅ ᎠᏨᏍᏗ',
    '🚦' => 'ᏥᏳᎪᏗ ᏙᎴᎳ ᏗᏨᏍᏓᏁᎯ',
    '🛑' => 'ᎠᎴᏫᏍᏙᏗ',
    '🚧' => 'ᏗᏁᏍᎨᏍᎩ',
    '⚓' => 'ᎦᏅᎯᏍᏙᏗ',
    '🛟' => 'ᎦᏌᏆᎳ ᎦᏄᎯᏒ',
    '⛵' => 'ᏥᏳ ᎠᏂᎩᏍᎩ',
    '🛶' => 'ᎠᎹ ᏥᏳ',
    '🚤' => 'ᎦᏳᏄᎳ ᏥᏳ',
    '🛳' => 'ᏴᏫ ᎠᏣᏍᎩ ᎡᏆ ᏥᏳ',
    '⛴' => 'ᏗᎦᏐᎯᏍᏗᏍᎩ',
    '🛥' => 'ᎦᏣᏄᎵ ᏥᏳ',
    '🚢' => 'ᎡᏆ ᏥᏳ',
    '✈' => 'ᏥᏳ ᎦᏃᎯᎵᏙᎯ',
    '🛩' => 'ᎤᏍᏗ ᏥᏳ ᎦᏃᎯᎵᏙᎯ',
    '🛫' => 'ᏥᏳ ᎦᏃᎯᎵᏙᎯ ᎤᏂᎩᏍᏗᎢ',
    '🛬' => 'ᏥᏳ ᎦᏃᎯᎵᏙᎯ ᎦᎷᎬᎢ',
    '🪂' => 'ᎤᏍᎦᏃᎵ ᎦᎶᏍᎬ',
    '💺' => 'ᏴᏫ ᎦᏍᎩᎶ',
    '🚁' => 'ᎦᎸᎡᏗ ᎬᏘ ᎠᎵᏲᎷᎩᏍᎩ',
    '🚟' => 'ᎦᎸᎳᏗ ᏕᎦᏅᏅᎢ ᎠᎦᎳ ᏅᏃᎯ',
    '🚠' => 'ᎣᏓᎸ ᏙᎴᎳ ᎠᏏᎳᏛᎢ',
    '🚡' => 'ᎤᏯᏅᎢ ᏕᎫᏓᎸ ᎦᎸᎳᏗ ᎤᎾᏦᏙᏗ',
    '🛰' => 'ᎦᎸᎶᎯ ᎠᎦᏖᏃᎵᏙ',
    '🚀' => 'ᎦᎸᎳᏗ ᎡᏙᎯ ᏥᏳ',
    '🛸' => 'ᎦᏃᎯᎵᏙᎯ ᏖᎵᏙ',
    '🛎' => 'ᎠᏫᎾ ᎠᎵᏍᏕᎸᎯᏙᎯ ᎤᎭᎸᏂ',
    '🧳' => 'ᏗᎾᏬ ᏗᎦᎸᏙᏗ',
    '⌛' => 'ᏃᏱ ᎠᏟᎠᎵᏒᎢ ᎠᏎᎯᎯ ᎠᏍᏆᏛ',
    '⏳' => 'ᏃᏱ ᎠᏟᎠᎵᏒᎢ ᎠᏎᎯᎯ Ꮭ ᎠᏍᏆᏛ',
    '⌚' => 'ᎤᏍᏗ ᏩᏥ',
    '⏰' => 'ᎠᏓᏱᏗᏍᏙᏗ ᏩᏥ',
    '⏱' => 'ᎠᎴᏫᏍᏗᏍᎩ ᏩᏥ',
    '⏲' => 'ᎠᏟᎠᎵᏒᎢ ᏩᏥ',
    '🕰' => 'ᎠᏯᏔᎾᎸᎢ ᎠᏠᏗ ᏩᏥ',
    '🕛' => 'ᏔᎵᏚ ᎠᏟᎠᎵᏒᎢ',
    '🕧' => 'ᏔᎵᏚ-ᏦᏍᎪᎯ',
    '🕐' => 'ᏌᏊ ᎠᏟᎠᎵᏒ',
    '🕜' => 'ᏌᏊ-ᏦᏍᎪᎯ',
    '🕑' => 'ᏔᎵ ᎠᏟᎠᎵᏒᎢ',
    '🕝' => 'ᏔᎵ-ᏦᏍᎪᎯ',
    '🕒' => 'ᏦᎢ ᎠᏟᎠᎵᏒᎢ',
    '🕞' => 'ᏦᎢ-ᏦᏍᎪᎯ',
    '🕓' => 'ᏅᎩ ᎠᏟᎠᎵᏒᎢ',
    '🕟' => 'ᏅᎩ-ᏦᏍᎪᎯ',
    '🕔' => 'ᎯᏍᎩ ᎠᏟᎠᎵᏒᎢ',
    '🕠' => 'ᎯᏍᎩ-ᏦᏍᎪᎯ',
    '🕕' => 'ᏑᏓᎵ ᎠᏟᎠᎵᏒᎢ',
    '🕡' => 'ᏑᏓᎵ-ᏦᏍᎪᎯ',
    '🕖' => 'ᎦᎵᏉᎩ ᎠᏟᎠᎵᏒᎢ',
    '🕢' => 'ᎦᎵᏉᎩ-ᏦᏍᎪᎯ',
    '🕗' => 'ᏧᏁᎳ ᎠᏟᎠᎵᏒᎢ',
    '🕣' => 'ᏧᏁᎳ-ᏦᏍᎪᎯ',
    '🕘' => 'ᏐᏁᎳ ᎠᏟᎠᎵᏒᎢ',
    '🕤' => 'ᏐᏁᎳ-ᏦᏍᎪᎯ',
    '🕙' => 'ᏍᎪᎯ ᎠᏓᎠᎵᏒᎢ',
    '🕥' => 'ᏍᎪᎯ-ᏦᏍᎪᎯ',
    '🕚' => 'ᏌᏚ ᎠᏟᎠᎵᏍᏒ',
    '🕦' => 'ᏌᏚ-ᏦᏍᎪᎯ',
    '🌑' => 'ᎢᏤ ᏅᏓ ᎤᏒᎢ ᎡᎯ',
    '🌒' => 'ᎣᏂ ᏣᎢᏐ ᏅᏓ ᎤᏒ ᎡᎯ',
    '🌓' => 'ᏅᏓ ᎤᏒ ᎡᎯ ᎢᎬᏱᏱ ᎩᏄᏘᏗ ᎧᎸᎢ',
    '🌔' => 'Ꮲ ᏦᎢ ᎩᏄᎩᏗ ᏅᏓ ᎤᏒ ᎡᎯ',
    '🌕' => 'ᎧᎵ ᏅᏓ ᎤᏒ ᎡᎯ',
    '🌖' => 'ᎩᏄᏘᏗ ᎠᏟᎵᏒ ᏅᏓ ᎤᏒ ᎡᎯ',
    '🌗' => 'ᎣᏂᎢ ᎩᏄᏘᏗ ᏅᏓ ᎤᏒ ᎡᎯ',
    '🌘' => 'ᎠᎦᏍᎦᏂᏗᏜ ᏅᏓ ᎤᏒ ᎡᎯ',
    '🌙' => 'ᎠᏓᏲᎲ ᏅᏓ ᎤᏒ ᎡᎯ',
    '🌚' => 'ᎢᏤ ᏅᏓ ᎤᏒ ᎡᎯ ᎤᎧᏛ',
    '🌛' => 'ᎢᎬᏱ ᎩᏄᏘᏗ ᏅᏓ ᎤᏒ ᎡᎯ ᎤᎧᏛ',
    '🌜' => 'ᎣᏂᎢ ᎩᏄᏘᏗ ᏅᏓ ᎤᏒ ᎡᎯ ᎤᎧᏛ',
    '🌡' => 'ᎤᏗᏞᎬᎢ ᎤᎦᎾᏮ ᎠᏎᎯᎯ',
    '☀' => 'ᏅᏓ ᎢᎦ ᎡᎯ',
    '🌝' => 'ᎧᎵ ᏅᏓ ᎤᏒ ᎡᎯ ᎤᎧᏛ',
    '🌞' => 'ᏅᏓ ᎢᎦ ᎡᎯ ᎤᎧᏓ',
    '🪐' => 'ᎠᎵᏰᏑᏍᏔᏬ ᎡᎶᎯ',
    '⭐' => 'ᏃᏈᏏ',
    '🌟' => 'ᎤᏥᏍᏓᎷᎩᏍᎩ ᏃᏈᏏ',
    '🌠' => 'ᎤᏬᎰᏒ ᏃᏈᏏ',
    '🌌' => 'ᏃᏈᏏ ᏂᏚᏍᏗᏓᏅ',
    '☁' => 'ᎤᎶᎩᎳ',
    '⛅' => 'ᏅᏓ ᎣᏂᏗᏜ ᏄᏛᎾ ᎤᎶᎩᎸᎢ',
    '⛈' => 'ᎤᎶᎩᎳ ᎠᎾᎦᎵᏍᎩ ᎠᎴ ᎠᎦᏍᎩ',
    '🌤' => 'ᏅᏓ ᎢᎦ ᎡᎯ ᏧᏘᏍᏓ ᎤᏍᏗᎢ ᏧᎶᎩᎵᎢ ᎣᏂᏗᏢᎢ',
    '🌥' => 'ᏅᏓ ᎢᎦ ᎡᎯ ᏧᏘᏍᏓ ᎤᏔᎾ ᏧᎶᎩᎸᎢ ᎣᏂᏗᏢᎢ',
    '🌦' => 'ᏅᏓ ᎢᎦ ᎡᎯ ᏧᏘᏍᏓ ᎠᎦᏍᎩᎢ ᏧᎶᎩᎸᎢ ᎣᏂᏗᏢᎢ',
    '🌧' => 'ᎤᎶᎩᎳ ᎠᎦᏍᎩ',
    '🌨' => 'ᎤᎶᎩᎳ ᎥᏂᏥ',
    '🌩' => 'ᎤᎶᎩᎳ ᎠᎾᎦᎵᎭ',
    '🌪' => 'ᎠᎦᎷᎦ ᎤᏔᎾ',
    '🌫' => 'ᎤᎬᎭᏗ',
    '🌬' => 'ᎦᏃᎸᏍᎬ ᎤᎸᏛ',
    '🌀' => 'ᎠᎦᎷᎦ ᎡᏆ',
    '🌈' => 'ᎤᏃᏉᎳᏛ',
    '🌂' => 'ᎠᏍᏚᏅ ᎠᏓᏩᏗᏍᏙᏗ',
    '☂' => 'ᎠᏓᏩᏗᏍᏙᏗ',
    '☔' => 'ᎠᏓᏓᏫᏍᏙᏗ ᎤᎵᏗᏗ ᎠᎦᏍᎦ',
    '⛱' => 'ᎠᏓᏩᏗᏍᏙᏗ ᎦᏙᎢ ᏥᏯ',
    '⚡' => 'ᎤᏟᏂᎩᏓ ᎠᎾᎦᎵᏍᎩ',
    '❄' => 'ᎤᏭᏔᏅᎢ',
    '☃' => 'ᎥᏂᏥ ᎠᏍᎦᏯ',
    '⛄' => 'ᎥᏂᏥ ᎠᏍᎦᏯ ᏂᎫᏘᎲᎾ',
    '☄' => 'ᏢᏓᏥ ᎩᎦᎨ',
    '🔥' => 'ᎠᏥᎳ',
    '💧' => 'ᎤᏩᏬᏨ',
    '🌊' => 'ᎠᎹ ᎤᏔᎾ ᎠᏖᎸᏓ',
    '🎃' => 'ᏤᎩ-ᎠᏨᏍᏗ',
    '🎄' => 'ᏓᏂᏍᏓᏲᎯᎲᎢ ᎢᏡᎬᎢ',
    '🎆' => 'ᏗᏔᏍᎩᏍᎩ',
    '🎇' => 'ᎠᏥᏍᏓᎷᎩᏍᎩ',
    '🧨' => 'ᎠᏔᏍᎩᏍᏙᏗ',
    '✨' => 'ᏗᏥᏍᏓᎷᎩᏍᎩ',
    '🎈' => 'ᎤᏃᎸᎠᏲᏙᏗ',
    '🎉' => 'ᎠᎵᏍᏆᎵᏍᎩ ᎠᏲᏍᏗᏍᎩ',
    '🎊' => 'ᎠᎵᎪᏛᏍᎩ ᎪᏪᎵ ᏍᏆᏞᏍᏗ',
    '🎋' => 'ᎠᎵᎮᎵᏍᏙᏗ ᎢᏡᎬ',
    '🎍' => 'ᏃᏣ ᎠᏬᏚᏍᏓᏅ',
    '🎎' => 'ᏣᏩᏂᏏ ᏗᏁᏟᏙᏗ',
    '🎏' => 'ᎠᏣᏗ ᏗᏟᎶᏍᏔᏅ ᎦᏓᏘ ᎠᏇᏡᏍᏗ',
    '🎐' => 'ᎦᏃᎸᏍᎬ ᏧᏃᏟᏍᏗ',
    '🎑' => 'ᏅᏓ ᎠᎪᏩᏛᏗ ᏓᏂᎳᏫᎬᎢ',
    '🧧' => 'ᎩᎦᎨ ᎪᏪᎵ ᎠᏍᏚᏙᏗ',
    '🎀' => 'ᎠᏇᎷᏍᏗ',
    '🎁' => 'ᎦᏇᏂᏓᏅ ᎠᏓᏁᏗ',
    '🎗' => 'ᎠᏅᏓᏗᏍᏙᏗ ᎠᏇᏡᏍᏗ',
    '🎟' => 'ᎠᏈᏴᏙᏗ ᎪᏪᎵ',
    '🎫' => 'ᎪᏪᎳ ᎠᏴᏍᏙᏗ',
    '🎖' => 'ᎠᏂᏲᏍᎩ ᏔᎷᎩᏍᎩ',
    '🏆' => 'ᎠᏓᏌᏅ',
    '🏅' => 'ᎠᎳᏍᎦᎸᏓ ᎠᏓᏒᏅ',
    '🥇' => 'ᎢᎬᏱᎢ ᎤᏓᏒᏅᎢ ᏔᎷᎩᏍᎩ',
    '🥈' => 'ᏔᎵᏁ ᎤᏓᏒᏅᎢ ᏔᎷᎩᏍᎩ',
    '🥉' => 'ᏦᎢᏁ ᎤᏓᏒᏅᎢ ᏔᎷᎩᏍᎩ',
    '⚽' => 'ᎦᏯᏂᏖᏍᏗ ᏍᏆᏞᏍᏗ',
    '⚾' => 'ᎠᎳᏍᎦᏟᏗ',
    '🥎' => 'ᏩᎾᎨᏍᏆᏞᏍᏗ',
    '🏀' => 'ᏔᎷᏣ ᏍᏆᏞᏍᏗ',
    '🏐' => 'ᏍᏆᏞᏍᏗ ᎦᏌᏛᏂᏍᏓ',
    '🏈' => 'ᎠᎺᎵᎧ ᏍᏆᏞᏍᏗ ᎠᎾᏯᏖᏍᎩ',
    '🏉' => 'ᎠᏱᏓᏍᏗ ᏍᏆᏞᏍᏗ',
    '🎾' => 'ᏩᎾ ᏍᏆᏞᏍᏗ ᎪᏍᏛᏂᏍᏙᏗ',
    '🥏' => 'ᎠᏠᏗ ᎦᏃᎯᎵᏙᎯ',
    '🎳' => 'ᎠᎵᏐᏆᎴᏱᏍᏗ',
    '🏏' => 'ᏔᎳᏚ ᏗᏁᏟᏙᏗ',
    '🏑' => 'ᏠᎨᏏ ᎠᎳᏍᎧᎵᏓ',
    '🏒' => 'ᎤᏁᏍᏓᎸᎢ ᎠᏁᏦᏗ',
    '🥍' => 'ᎠᏁᏦᏓ',
    '🏓' => 'ᎬᏂᎵᏓᏍᏗ ᎤᏓᏌᎧ ᏍᏆᏞᏍᏗ',
    '🏸' => 'ᎠᏁᏦᏗ',
    '🥊' => 'ᏗᎾᏓᏛᏂ ᎤᎾᎵᏰᏑᎶ',
    '🥋' => 'ᏗᏟᏙᏗ ᏗᎾᏬ',
    '🥅' => 'ᎠᎦᏯ ᎷᏗ',
    '⛳' => 'ᎦᏓᏘ ᎾᎿ ᎠᏔᎴᏒ',
    '⛸' => 'ᎤᏁᏍᏓᎳ ᏓᎾᏟᎾᏒᏗᎲᎢ',
    '🎣' => 'ᏑᏗ',
    '🤿' => 'ᎠᏕᏛᏍᎦ ᎠᎵᎬᏚᎶᎢ',
    '🎽' => 'ᎠᏟ ᎠᎾᏬ',
    '🎿' => 'ᏗᏟᎾᏒᏙᏗᏍᎩ',
    '🛷' => 'ᎠᏲᏟᏍᎩ',
    '🥌' => 'ᏭᎾᏕᎬᎢ ᏅᏯ',
    '🎯' => 'ᏥᏳᎪᏗ ᎬᏂᎸᎢ',
    '🪀' => 'ᏲᏲ',
    '🪁' => 'ᎠᎳᏫᏅᏙᏗ',
    '🔫' => 'ᎦᎶᏪ ᏍᏆᎳ',
    '🎱' => '8 ᎪᏪᎳ ᎦᏓᏲᏍᏗ',
    '🔮' => 'ᎤᎸᏌᏗ ᏍᏆᏞᏍᏗ',
    '🪄' => 'ᎤᏍᏆᏂᎪᏗᏳ ᎦᏅᏍᏓ',
    '🎮' => 'ᎠᏓᏴᎵᏛᏍᎩ ᏗᏁᎵᏙᏗ',
    '🕹' => 'ᎨᏘᏴᏍᏗ',
    '🎰' => 'ᎠᏕᎳ ᎦᏠᏗ ᎪᏢᏍᎩ',
    '🎲' => 'ᎠᏁᏟᏙᏗ ᎦᎵᏬᎩ',
    '🧩' => 'ᏥᎩᏌ',
    '🧸' => 'ᏖᏗ ᏲᎾ',
    '🪅' => 'ᎠᏂᏍᏆᏂ ᏓᏂᏥᎳᏓᏗᏍᎬ',
    '🪩' => 'ᎠᏓᎨᏗ ᏍᏆᏞᏍᏗ',
    '🪆' => 'ᏕᎧᏁᏍᏓᏝᎲᎢ ᏗᏁᏟᏗ',
    '♠' => 'ᎪᏕᏍᏗ ᏧᏠᏱᎭ',
    '♥' => 'ᎤᎿᏫ ᏧᏠᏱᎭ',
    '♦' => 'ᎦᎸᏉᏗ ᏅᏯ ᏧᏠᏱᎭ',
    '♣' => 'ᏗᏓᏍᏆᎸᏂᏍᏗ ᏧᏠᏱᎭ',
    '♟' => 'ᏤᎡᏍ ᎠᎦᏘᏗᏍᏙᏗ',
    '🃏' => 'ᎦᏪᏟᏍᎩ',
    '🀄' => 'ᎹᏦᏂᎩ ᎩᎦᎨ ᎡᏆ ᏔᏲᎭᎵ',
    '🎴' => 'ᎤᏥᎸᏍᎩ ᏓᏆᎾᏲᎯᎭ',
    '🎭' => 'ᎾᎾᏛᏁᎵᏍᎬᎢ',
    '🖼' => 'ᏗᏟᎶᏍᏔᏅᎢ ᎦᏘᏅᏔᏅᎢ',
    '🎨' => 'ᏗᏑᏫᏗᎩ ᏯᏖᎾ',
    '🧵' => 'ᎠᏍᏘ',
    '🪡' => 'ᏴᎩ',
    '🧶' => 'ᎤᏩᏂ ᎠᏍᏘ',
    '🪢' => 'ᏓᎧᏁᎲ',
    '👓' => 'ᏗᎦᏘᏅᏗ',
    '🕶' => 'ᎠᎦᎵᏍᎬᎢ ᏗᎦᏘᏅᏛᏗ',
    '🥽' => 'ᎠᏂᎫᎦᎵ',
    '🥼' => 'ᎠᎦᏛᏙᏗ ᎧᏅᏑᎸ ᎦᏌᎴᎾ',
    '🦺' => 'ᏄᎾᏰᎯᏍᏛᎾ ᏪᏍᏗ',
    '👔' => 'ᎠᎭᏢᏗ',
    '👕' => 'ᎭᏫᎾ-ᎠᎿᏬᏍᏗ',
    '👖' => 'ᏗᏑᎶ',
    '🧣' => 'ᎠᏯᏠ',
    '🧤' => 'ᏗᎵᏰᏑᎶ',
    '🧥' => 'ᎦᏌᎴᎾ',
    '🧦' => 'ᏗᎵᏲ',
    '👗' => 'ᎠᏌᏃ',
    '👘' => 'ᎩᎼᏃ',
    '🥻' => 'ᎯᏂᏗ ᎠᏌᏃ',
    '🩱' => 'ᏌᏊᎯ ᎥᏓᏬᏍᎬᎢ ᏗᎿᏬᏍᏗ',
    '🩲' => 'ᎠᏑᎶ ᏙᏳ ᏍᏆᎳ',
    '🩳' => 'ᎠᏑᎶ ᏍᏆᎳ',
    '👙' => 'ᎥᏓᏬᏍᎬᎢ ᏗᎿᏬᏍᏗ',
    '👚' => 'ᎠᎨᏯ ᏧᎾᏬᏍᏗ',
    '🪭' => 'ᎤᏬᏰᏂ ᎠᏘᏃᏰᏍᎩ ᎤᎭ',
    '👛' => 'ᎠᏔᏁᏌᏟᏗ',
    '👜' => 'ᏕᎦᎵᏟᏗ ᎧᏂᏓᏍᏗ',
    '👝' => 'ᎦᏂᏴᏙᏗ ᏕᎦᎶᏗ',
    '🛍' => 'ᎠᏓᎿᎿᎩᎠ ᏗᏕᎦᎵᏟᏗ',
    '🎒' => 'ᏗᏕᎶᏆᏍᏗ ᎦᎵᏒᏍᏓ',
    '🩴' => 'ᎠᏍᏚᎢᏓ ᎠᎳᏑᎶ',
    '👞' => 'ᎠᏍᎦᏯ ᎤᎳᎱᎶᎢ',
    '👟' => 'ᎠᏟᏓᏍᏗ ᎠᎳᏑᎶᎯ',
    '🥾' => 'ᎤᏨᏏᏰᏍᎬ ᎬᏩᎵᏲᏍᏗ',
    '🥿' => 'ᎠᏯᏛᏌ ᏗᎳᏑᎶ',
    '👠' => 'ᎢᎾ-ᎢᏗᎦᏘ ᎠᎳᏑᎶ',
    '👡' => 'ᎠᎨᏯ ᏧᎳᏑᎶ',
    '🩰' => 'ᎠᎳᏍᎩᏍᏗ ᏗᎳᏑᎶ',
    '👢' => 'ᎠᎨᏯ ᎤᎳᏑᎶᎢ',
    '🪮' => 'ᎤᏍᏘᎬ ᎠᏔᏬᏍᏗ',
    '👑' => 'ᎤᎬᏫᏳᎯ ᎠᎵᏍᏚᎶ',
    '👒' => 'ᎠᎨᏯ ᎤᎵᏚᎶ',
    '🎩' => 'ᎦᏚ ᎠᎵᏍᏇᏚᏬ',
    '🎓' => 'ᏗᏍᏆᏗᏍᎩ ᎤᎵᏍᏚᎶ',
    '🧢' => 'ᎤᎬᏣᏘ ᎠᎵᏍᏚᎶ',
    '🪖' => 'ᎠᏲᏍᎩ ᎤᎵᏍᏚᎶᏗ',
    '⛑' => 'ᎠᏓᏍᏕᎵᏍᎩ ᏧᎸᏫᏍᏓᏁᎯ ᎤᎵᏍᏚᎶᏗ',
    '📿' => 'ᎠᏓᏙᎵᏍᏙᏗ ᏗᏕᎳ',
    '💄' => 'ᎣᎭᏁᎦᎸ ᎦᏅᎵᏰᏗ',
    '💍' => 'ᎠᎵᏰᏑᏔᏫ',
    '💎' => 'ᎦᎸᏉᏗ ᏅᏯ',
    '🔇' => 'ᎡᏝᏪ ᏂᎬᏁᎸ',
    '🔈' => 'ᎦᏬᏂᏍᎩ ᎡᎳᏗᏜ ᎠᏍᏓᏱᏗᏍᏗ',
    '🔉' => 'ᎦᏬᏂᏍᎩ ᎠᏰᏟ ᎠᏍᏓᏱᏗᏍᏗ',
    '🔊' => 'ᎦᏬᏂᏍᎩ ᎦᎸᎳᏗ ᎠᏍᏓᏱᏗᏍᏗ',
    '📢' => 'ᏗᎭᎳᏓ ᎦᏬᏂᏍᎩ',
    '📣' => 'ᏗᎭᎳᏙᏗ ᏫᎦᏬᏂᏍᏙᏗ',
    '📯' => 'ᎪᏪᎵ ᏧᏂᏍᏚᎢᏍᏗ ᎤᏲᎾ',
    '🔔' => 'ᎤᏯᎸᏂ',
    '🔕' => 'ᎤᏯᎸᏂ ᎾᏍᎩ ᎬᏗ ᎤᏁᏍᏠᎥ',
    '🎼' => 'ᏗᎧᏃᎩᏓ ᎪᏪᎳᏅ',
    '🎵' => 'ᏗᎧᏃᎩᏍᏙᏗ ᎠᏍᏓᏫᏛᏂᏗ',
    '🎶' => 'ᏗᎧᏃᎩᏍᏙᏗ ᏗᏍᏓᏫᏛᏂᏗ',
    '🎙' => 'ᏧᏂᏃᎩᏍᏙᏗ ᎧᏅᏑᎸ ᏍᏓᏱ ᎦᏃᏴᎵᏍᏗᏍᎩ',
    '🎚' => 'ᎤᏩᏂᏕᏍᎩ ᎠᏲᏟᏍᎩ',
    '🎛' => 'ᎠᎯᎸᏍᏗ ᏗᎦᏂᏱᏙᏗ',
    '🎤' => 'ᏫᎦᏬᏂᏍᏙᏗ',
    '🎧' => 'ᏗᏟᎤᏍᏙᏗ',
    '📻' => 'ᏗᎧᏃᎩᏍᎩ',
    '🎷' => 'ᏌᎦᎪᏁ',
    '🎺' => 'ᏢᏇᏘ',
    '🪊' => 'ᏚᏉᏂ',
    '🪗' => 'ᎠᎪᏗᎠᏂ',
    '🎸' => 'ᏗᏇᏄᎩᏍᏗ',
    '🎹' => 'ᏗᎧᏃᎩᏍᏙᏗ ᏗᏐᏅᏍᏙᏗ',
    '🎻' => 'ᎠᏰᏟᏰᏗ',
    '🪕' => 'ᏗᏍᏗ ᏗᎧᏃᎩᏍᏗ',
    '🥁' => 'ᎱᎵ',
    '🪘' => 'ᎱᎵ ᎦᏅᎯᏓ',
    '🪇' => 'ᎠᏂᏍᏆᏂ ᎦᎾᏤᏘ',
    '🪈' => 'ᎠᏤᎷᎯᏍᏗ',
    '🪉' => 'ᏗᎧᏃᎩᏍᏙᏗ',
    '📱' => 'ᏙᎴᎳᏊ ᏗᎵᏃᎮᏓ',
    '📲' => 'ᏙᎴᎳᏊ ᏗᎵᏃᎮᏓ ᎤᎵᎪᏗ ᎦᏟᏓ',
    '☎' => 'ᏴᏫ ᏗᏟᏃᎮᏗ',
    '📞' => 'ᏗᎵᏃᎮᏗ ᎦᏬᏂᏍᏙᏗ',
    '📟' => 'ᎠᏓᏯᏂ',
    '📠' => 'ᏗᏟᎶᏍᏔᏅ ᎪᏪᎵ ᏫᎦᏅᎥᏍᎩ',
    '🔋' => 'ᎠᎾᎦᎵᏍᎩ',
    '🪫' => 'ᎡᎳᏗ ᎠᎾᎦᎵᏍᎩ',
    '🔌' => 'ᎠᎾᎦᎵᏍᎩ ᏗᎫᏓᎸᏗ',
    '💻' => 'ᎠᏄᎵᏍᏗ ᎠᎦᏙᎥᏒᎢ ᎠᏍᏆᏂᎪᏗᏍᎩ',
    '🖥' => 'ᎦᏍᎩᎶᎩ ᎦᏚ ᎠᎦᏙᎥᎯᏍᏗᏍᎩ ᎠᏍᏆᏂᎪᏗᏍᎩ',
    '🖨' => 'ᏗᎦᎴᏴᏗᏍᎩ',
    '⌨' => 'ᏗᏐᏅᏍᏙᏗ',
    '🖱' => 'ᎠᎦᏙᎥᎯᏍᏗᏍᎩ ᎠᏍᏆᏂᎪᏗᏍᎩ ᏥᏍᏕᏥ',
    '🖲' => 'ᎪᎷᏅᏓᏍᏆᏞᏍᏗ',
    '💽' => 'ᎠᎦᏙᎥᎯᏍᏗᏍᎩ ᎠᏍᏆᏂᎪᏗᏍᎩ ᎠᏠᏗ',
    '💾' => 'ᏩᏂᎨ ᎠᏠᏗ',
    '💿' => 'ᎠᎪᏩᏛᏗ ᎠᏠᏗ',
    '📀' => 'ᎠᏙᎠ',
    '🧮' => 'ᏗᏎᏍᏗ ᏗᏎᏍᏙᏗ',
    '🎥' => 'ᎠᏗᏴᎳᏛᏍᎩ ᏗᏓᏟᎶᏍᏗᏍᎩ',
    '🎞' => 'ᎠᏗᏴᎳᏗᏍᎩ ᎦᏟᏙᏗ',
    '📽' => 'ᎠᏗᏴᎳᏙᏗ ᏗᎦᎸᏌᏗᏍᎩ',
    '🎬' => 'ᏗᏏᏛᏂᎭ ᏯᏖᎾ',
    '📺' => 'ᏗᏓᏴᎵᏛᏍᎩ',
    '📷' => 'ᏗᏓᏟᎶᏍᏙᏗ',
    '📸' => 'ᏗᏓᏟᎶᏍᏙᏗ ᎤᏥᏍᏓᎷᎩ ᎠᏩᏠᏯᏍᏓ',
    '📹' => 'ᎠᏓᏴᎵᏛᏍᎩ ᏗᏓᏟᎶᏍᏗᏍᎩ',
    '📼' => 'ᎦᏠᏗ ᏗᎧᏃᎩᏍᎩ',
    '🔍' => 'ᎠᎦᏍᎦᏂ ᎠᎦᏙᏗ ᎠᏔᏃᎯᏍᏗᏍᎩ ᎤᎸᏌᏗ',
    '🔎' => 'ᎠᎦᏘᏏ ᏩᏎᎯᎲ ᎡᏆ ᏂᎬᏁ ᎫᎦ',
    '🕯' => 'ᎤᎧᎾᏫ ᎠᏨᏍᏗ',
    '💡' => 'ᎠᏨᏍᏗ ᎦᏗ',
    '🔦' => 'ᎤᏍᏗ ᎠᏨᏍᏗ',
    '🏮' => 'ᎩᎦᎨ ᎪᏪᎳ ᎠᏨᏍᏗ',
    '🪔' => 'ᏗᏯ ᎠᏨᏍᏗ',
    '📔' => 'ᎪᏪᎵ ᎤᎵᎪᏒ ᏗᏟᎶᏍᏓᏅ ᎫᏢᏗ',
    '📕' => 'ᎠᏍᏚᎲ ᎪᏪᎵ',
    '📖' => 'ᎯᏍᏚᎢ ᎪᏪᎵ ᏗᎪᎵᏰᏗ',
    '📗' => 'ᎢᏤᏳᏍᏗ ᏗᎪᏪᎵ',
    '📘' => 'ᏌᎪᏂᎨ ᎪᏪᎵ',
    '📙' => 'ᎠᏓᎶᏂᎨ ᎪᏪᎵ ᏗᎪᎵᏰᏙᏗ',
    '📚' => 'ᏗᎪᏪᎵ',
    '📓' => 'ᎪᏪᎵ ᏗᎪᏪᎶᏙᏗ',
    '📒' => 'ᎪᏪᎵ ᎤᎭᎨᏓ',
    '📃' => 'ᎤᎦᏅᏓᏛ ᎤᎵᎪᏗ ᎤᎵᏥᏍᏆᏁᏗ',
    '📜' => 'ᎦᏅᏍᎩ',
    '📄' => 'ᎤᎦᏅᏓᏛ ᎤᎧᏛ ᎦᎸᎳᏗ',
    '📰' => 'ᏗᎦᏃᏣᎳᏅᎢ',
    '🗞' => 'ᎦᏐᏆᎴᏢᎢ-ᏗᎦᏃᏣᎳᏅᎢ ᎪᏪᎵ',
    '📑' => 'ᎪᏪᎵᎪᏣᎸᏗ ᏗᎦᏗ',
    '🔖' => 'ᎪᏪᎵᎪᏣᎸᏗ',
    '🏷' => 'ᎪᏪᎸᎢ',
    '🪙' => 'ᎢᏯᏓᏅᏖᏗ',
    '💰' => 'ᎠᏕᎳ ᏕᎦᎶᏗ',
    '🪎' => 'ᏧᎬᏩᎶᏗ ᎠᏍᏆᏂᎪᏛ ᎦᏁᏥ',
    '💴' => 'ᏤᏈᏂᏏ ᎠᏕᎳ ᏧᏂᏗᎢ ᎪᏪᎵ',
    '💵' => 'ᎤᏃᏍᏓ ᎠᏕᎳ ᏧᏂᏗᎢ ᎪᏪᎵ',
    '💶' => 'ᏳᎳᏈ ᎠᏕᎳ ᏧᏂᏗᎢ ᎪᏪᎵ',
    '💷' => 'ᎩᎵᏏᏲ ᎠᏕᎳ ᏧᏂᏗᎢ ᎪᏪᎵ',
    '💸' => 'ᎠᏕᎳ ᏗᎪᏯᏓ',
    '💳' => 'ᎠᏓᏚᏍᎩ ᏆᏂᏲᏍᏗ',
    '🧾' => 'ᎢᎦᎢ ᎠᎫᏴᎲᎢ ᎪᏪᎳ',
    '💹' => 'ᎧᏃᎮᏓ ᏓᏟᎶᏍᏛ ᎧᏁᏉᎬᎢ ᏣᏩᏂᏏ ᎠᏕᎳ',
    '✉' => 'ᎪᏪᎵ ᎠᎸᏙᏗ',
    '📧' => 'ᎠᎾᎦᎵᏍᎩ ᎪᏪᎸ',
    '📨' => 'ᎦᎷᎩ ᎪᏪᎵ ᎦᎸᏙᏗ',
    '📩' => 'ᎪᏪᎵ ᎠᏍᏚᏗ ᎠᏠᏯᏍᏗ ᎦᏝᏗ',
    '📤' => 'ᏙᏱ ᎧᏁᏌ ᏖᎵᏙ',
    '📥' => 'ᎪᏪᎵ ᏧᎷᎯᏍᏗ ᏗᎦᎸᏙᏗ',
    '📦' => 'ᎦᏇᏂᏓᏅᎢ',
    '📫' => 'ᎠᏍᏚᏅ ᎪᏪᎵ ᏗᎦᎸᏙᏗ ᎦᏓᏘᏃ ᎠᏌᎳᏓᏅᎢ',
    '📪' => 'ᎠᏍᏚᏅ ᎪᏪᎵ ᏗᎦᎸᏙᏗ ᎦᏓᏘᏃ ᎡᎳᏗ ᏱᎬᏁᎸᎢ',
    '📬' => 'ᎯᏍᏚᎢ ᎣᏪᎵ ᏗᎦᏁᏍᏗ ᎤᎵᎪᏗ ᎠᏌᎸᏛᏅ ᎦᏗ',
    '📭' => 'ᎯᏍᏚᎢ ᎪᏪᎵ ᏗᎦᏁᏍᏗ ᎤᎵᎪᏗ ᎡᎳᏗᏜ ᎦᏗ',
    '📮' => 'ᎪᏪᎵ ᎧᏁᏌ',
    '🗳' => 'ᏗᏙᎩᏯᏍᎩ ᎧᏁᏌ ᎾᏍᎩ ᎬᏗ ᏗᏙᎩᏯᏍᎩ',
    '✏' => 'ᏗᎪᏪᎶᏙᏗ',
    '✒' => 'ᎬᎿᎨ ᏫᎪᏍᏓᏴ',
    '🖋' => 'ᎠᏤᏬᎩ ᏗᎪᏪᎶᏗ',
    '🖊' => 'ᏗᎪᏪᎶᏗ',
    '🖌' => 'ᎠᏑᏫᏍᏙᏗ',
    '🖍' => 'ᏗᏑᏫᏍᏙᏗ ᎪᏪᎶᏙᏗ',
    '📝' => 'ᏍᏆᎳ ᎪᏪᎳᏅ',
    '💼' => 'ᎦᏅᏔᏅᏙᏗ',
    '📁' => 'ᎠᏍᏆᏂᎪᏙᏗ ᏗᏴᏈᏛᎥᏍᎩ',
    '📂' => 'ᎯᏍᏚᎢ ᎠᏍᏆᏂᎪᏙᏗ ᎠᏰᏈᏛᏍᎩ',
    '🗂' => 'ᏆᏂᏲᏍᏗ ᎠᏍᏓᏩᏛᏍᏗ ᏔᎵ ᏱᎦᏗᏍᎩ',
    '📅' => 'ᏅᏓ ᏗᏎᏍᏗ',
    '📆' => 'ᎦᏯᎴᏍᏗ-ᏅᏓ ᏗᏎᏍᏗ',
    '🗒' => 'ᎦᏄᏖᏲᎸ ᎪᏪᎶᏗ ᎪᏪᎵ',
    '🗓' => 'ᎦᏄᏖᏲᎸ ᏅᏓ ᏗᏎᏍᏗ',
    '📇' => 'ᏗᏆᏂᏲᏍᏗ ᎠᏍᏓᏩᏛᏍᏗ',
    '📈' => 'ᎧᏃᎮᏓ ᏓᏟᎶᏍᏛ ᎧᏁᏉᎬᎢ',
    '📉' => 'ᎧᏃᎮᏓ ᏓᏟᎶᏍᏛ ᎠᎦᏲᎶᎬᎢ',
    '📊' => 'ᎦᎾᎸᎢ ᎧᏃᎮᏍᎩ ᏗᏟᎶᏍᏔᏅ',
    '📋' => 'ᏗᎬᎭᎸᏓ ᏗᏍᏆᏂᎪᏙᏗ',
    '📌' => 'ᏴᎩ ᎦᎭᏙᏗ',
    '📍' => 'ᎦᏐᏆᎸ ᏴᎩ ᎦᎭᏙᏗ',
    '📎' => 'ᏔᎷᎩᏍᏗ ᎬᏙᏗ',
    '🖇' => 'ᏗᎫᏓᎸᏅᎢ ᎪᏪᎵ ᏗᎦᏂᏴᏙᏗ',
    '📏' => 'ᏥᏳᎩᏗ ᎠᏟᎶᏍᎩ',
    '📐' => 'ᏦᎢ ᏧᏅᏏᏓ ᎠᏟᎶᏍᏗ',
    '✂' => 'ᏗᎵᏍᏙᏗ',
    '🗃' => 'ᎠᏆᏂᏲᏍᏗ ᎠᏥᎳ ᎤᏣᏍᎦᏘ ᎧᏁᏌ',
    '🗄' => 'ᎠᏍᎪᏂᎪᏙᏗ ᎦᏍᎩᎸ',
    '🗑' => 'ᎤᏲᏩᏗᏅᏗ ᏔᎷᏣ',
    '🔒' => 'ᏍᏓᏱ ᎠᏍᏍᎭ',
    '🔓' => 'ᏙᎠᏍᏚ',
    '🔏' => 'ᏍᏓᏱ ᎠᏍᏚᎲᎢ ᎫᏍᏈᏛᏗ ᎬᏗ',
    '🔐' => 'ᏍᏓᏱ ᎠᏍᏚᎲᎢ ᏍᏚᎢᏍᏗ ᎬᏗ',
    '🔑' => 'ᏍᏚᎢᏍᏗ',
    '🗝' => 'ᎤᏪᏘ ᏍᏚᎢᏍᏗ',
    '🔨' => 'ᎦᏅᏩᎶᏍᏗ',
    '🪓' => 'ᎦᎷᏯᏍᏗ',
    '⛏' => 'ᏗᎧᎾᏍᏕᏟᏗ',
    '⚒' => 'ᎬᏅᏩᎶᏍᏗ ᎠᎴ ᏗᎧᎾᏍᏕᏟᏗ',
    '🛠' => 'ᎬᏅᏩᎶᏍᏗ ᎠᎴ ᏗᎦᏚᏩᎸᏕᏍᏙᏗ',
    '🗡' => 'ᏗᎦᏘᏍᏗ',
    '⚔' => 'ᏧᏓᎿᏫᏓ ᏗᏰᎳᏍᏗ ᏗᎦᏅᎯᏓ',
    '💣' => 'ᎠᏔᏍᎩᏍᎩ',
    '🪃' => 'ᏩᏗᏅᏗ ᎠᎴ ᎥᎦᎷᏨ',
    '🏹' => 'ᎦᎵᏣᏗ ᎠᎴ ᎠᏝᏗ',
    '🛡' => 'ᎠᏚᏢᏙᏗ',
    '🪚' => 'ᏗᏁᏍᎨᏍᎩ ᎦᎾᏙᎩ',
    '🔧' => 'ᏗᎦᏚᏩᎸᏕᏍᏙᏗ',
    '🪛' => 'ᎤᏗᏆᎸᏕᏱᏓ ᎬᏔᏂᏓᏍᏗ',
    '🔩' => 'ᎠᏍᏓᏱᏗᏍᏙᏗ ᎠᎴ ᎦᎭᏗ',
    '⚙' => 'ᎬᏔᏅᏙᏗ',
    '🗜' => 'ᎬᏙᏗ',
    '⚖' => 'ᎢᏗᎦᏘᎭ ᏗᎦᏛᏗ',
    '🦯' => 'ᏗᎨᏫ ᎦᏅᏍᏓ ᎬᏙᏗ',
    '🔗' => 'ᎫᏓᎸᏙᏗ',
    '⛓' => 'ᏧᎾᏓᏕᏒᏗ',
    '🪝' => 'ᏑᏗᎢ',
    '🧰' => 'ᎬᏔᏂᏓᏍᏗ ᎦᎵᏔᏅᏙᏗ ᎧᏁᏌᎢ',
    '🧲' => 'ᏔᎷᎩᏍᎩ ᎦᏌᏁᏍᎩ',
    '🪜' => 'ᎠᏴᏠ',
    '🪏' => 'ᎠᎪᏕᏍᏗ',
    '⚗' => 'ᎠᎪᏙᏗ',
    '🧪' => 'ᎠᎦᏛᏗ ᎤᏒᏙᏂ',
    '🧫' => 'ᎤᏩᎾᏬᏍᏒ ᏒᏙᏂ ᎤᎸᏌᏗ',
    '🧬' => 'ᏧᏚᎪᏔᏅ ᎬᏃᏗ ᏧᏓᎴᏅᎲ',
    '🔬' => 'ᎤᏍᏗ ᎪᎱᏍᏗ ᎠᎪᎵᏱᏍᏙᏗ',
    '🔭' => 'ᎦᎸᎳᏗ ᏩᎪᏩᏛᏗ',
    '📡' => 'ᎦᎸᎶᎯ ᎠᎦᏖᏃᎵᏙ ᎡᏙᎯ ᎾᏏᎳᏛᎾ',
    '💉' => 'ᏴᎩ ᎠᏓᏣᏲᏍᏙᏗ',
    '🩸' => 'ᎩᎦ',
    '💊' => 'ᏅᏬᏓ ᎠᎩᏍᏓ',
    '🩹' => 'ᎤᏓᎦᏣᎦᎵ ᎠᎦᏍᏢᏅᎢ',
    '🩼' => 'ᎠᏙᎳᏅᏍᏗ',
    '🩺' => 'ᎤᎾᏫ ᎠᏛᏓᏍᏗ',
    '🩻' => 'ᎪᎳ ᏗᏟᎶᏍᏔᏅᎢ',
    '🚪' => 'ᏍᏚᏗ',
    '🛗' => 'ᎠᏓᏌᎳᏗᏍᎩ',
    '🪞' => 'ᎠᏓᎨᏗ',
    '🪟' => 'ᏦᎳᏂ',
    '🛏' => 'ᎦᏂᏟ',
    '🛋' => 'ᎦᏅᎯᏓ ᎦᏍᎩᎶ ᎠᎴ ᎠᏨᏍᏗ',
    '🪑' => 'ᎦᏍᎩᎶ',
    '🚽' => 'ᏙᏱ ᎡᏓᏍᏗ',
    '🪠' => 'ᏙᏱ ᎡᏓᏍᏘᏱ ᎪᎱᏍᏗ ᎬᏔᏂᏓᏍᏗ',
    '🚿' => 'ᎠᏍᏚᏟᏥᏙ',
    '🛁' => 'ᎤᎾᏓᏬᏍᏗ',
    '🪤' => 'ᏥᏍᏕᏥ ᏌᏛᏗ',
    '🪒' => 'ᎠᎵᏍᏙᏯᏙᏗ',
    '🧴' => 'ᎠᏓᏅᎵᏰᏗ ᎫᎦ',
    '🧷' => 'ᎤᏍᏆᏘ',
    '🧹' => 'ᎬᏃᏌᏯᏍᏗ',
    '🧺' => 'ᏔᎷᏣ',
    '🧻' => 'ᎪᏪᎵ ᎦᏇᏅᏔᏅ',
    '🪣' => 'ᎠᎹ ᎠᎫᎩᏍᏙᏗ',
    '🧼' => 'ᎣᏝ',
    '🫧' => 'ᏚᏆᎷᏒ',
    '🪥' => 'ᏛᎦᎾᏙᎬ ᏗᎦᏅᎦᎸᏙᏗ',
    '🧽' => 'ᏓᏬᎵ ᎢᏳᏍᏗ',
    '🧯' => 'ᎠᏓᏪᎳᎩᏍᎬ ᏗᎦᏟᏗᏍᏙᏗ',
    '🛒' => 'ᏙᎴᎳ',
    '🚬' => 'ᎪᎩᏍᏗ',
    '⚰' => 'ᎧᏁᏌᎢ',
    '🪦' => 'ᏅᏯ ᎠᏂᏓᏗᏍᎪᏘᎢ',
    '⚱' => 'ᎦᏂᏐᏗ ᎪᏍᏓ ᎦᏟᏗ',
    '🧿' => 'ᎠᎦᏙᎵ ᎢᏳᏍᏗ ᎠᎵᏍᏕᎸᏙᏗ',
    '🪬' => 'ᎭᎻᏌ',
    '🗿' => 'ᎼᎢ',
    '🪧' => 'ᏕᎦᏃᏣᎸ',
    '🪪' => 'ᎢᎪᎵᏍᏙᏗ ᎠᏆᏂᏲᏍᏗ',
    '🏧' => 'ᎪᎢᎷ ᎪᏪᎵ',
    '🚮' => 'ᎤᏲ ᏩᏗᏅᏗ ᎠᎪᎵᏰᏗ',
    '🚰' => 'ᎠᏗᏔᏍᏗ ᎠᎹ',
    '♿' => 'ᎦᏍᎩᎶ ᎠᏦᏙᏗ ᎦᏯᎸᎢ',
    '🚹' => 'ᎠᏂᏍᎦᏯ ᎤᏂᏴᏍᏗ',
    '🚺' => 'ᎠᎨᏯ ᎤᏴᏍᏗᎢ',
    '🚻' => 'ᎡᏓᏍᏗ',
    '🚼' => 'ᎤᏍᏗ ᏗᏟᎶᏍᏔᏅᎢ',
    '🚾' => 'ᎧᏅᏑᎸᎢ',
    '🛂' => 'ᎦᎶᎯᏍᏙᏗ ᏗᎫᎩᏗᏍᎩ',
    '🛃' => 'ᏄᏍᏛᎢ ᎢᏳᎾᏛᏁᏗ',
    '🛄' => 'ᎦᏅᏔᏅᏙᏗ ᎪᎯᏳᏗᏍᎩ',
    '🛅' => 'ᎠᎦᏍᎦᏂ ᏕᎦᎸᏛᎢ',
    '⚠' => 'ᎦᎾᏰᎯᏍᏗ',
    '🚸' => 'ᏗᏂᏲᏟ ᏧᏂᏗᏫᏍᏗ',
    '⛔' => 'ᎥᏝ ᎠᏴᏍᏗ',
    '🚫' => 'ᎠᎨᏳᏓᏅᎢ',
    '🚳' => 'ᏝᎨᏒ ᏔᎵ ᏗᎦᏩᏘ',
    '🚭' => 'ᏞᏍᏗ ᏲᎦᏍᎨᏍᏗ',
    '🚯' => 'ᏞᏍᏗ ᎦᎵᎨᏴᏛᏅ',
    '🚱' => 'Ꮭ-ᎦᏅᏥᏓᏍᏗ ᎠᎹ',
    '🚷' => 'ᎥᏝ ᎠᎾᏨᏏᏰᏍᎩ',
    '📵' => 'Ꮭ ᏙᎴᎳᏊ ᏗᎵᏃᎮᏓ',
    '🔞' => 'ᏞᏍᏗ ᏂᎨᏒᎾ ᏁᎳᏚ ᎢᏳᏕᏘᏴᏓ',
    '☢' => 'ᎡᏍᎦ ᏯᏓᏛᏁᎯ',
    '☣' => 'ᎠᏓᎯᎯ',
    '⬆' => 'ᎦᎸᎳᏓᎦᏘ ᎦᏝᏗ',
    '↗' => 'ᎦᎸᎳᏗ-ᎠᎦᏘᏏ ᎦᏝᏗ',
    '➡' => 'ᎠᎦᏘᏏ ᎦᏝᏗ',
    '↘' => 'ᎡᎳᏗ-ᎠᎦᏘᏏ ᎦᏝᏗ',
    '⬇' => 'ᎡᎳᏗ ᎦᏝᏗ',
    '↙' => 'ᎡᎳᏗ-ᎠᎦᏍᎦᏂ ᎦᏝᏗ',
    '⬅' => 'ᎠᎦᏍᎦᏂ ᎦᏝᏗ',
    '↖' => 'ᎦᎸᎳᏗ-ᎠᎦᏍᎦᏂ ᎦᏝᏗ',
    '↕' => 'ᎦᎸᎳᏗ - ᎡᎳᏗ ᎦᏝᏗ',
    '↔' => 'ᎠᎦᏍᎦᏂ - ᎦᏘᏏ ᎦᏝᏗ',
    '↩' => 'ᎠᎦᏘᏏ ᎦᏝᏗ ᎠᏕᏲ ᎠᎦᏍᎦᏂ',
    '↪' => 'ᎠᎦᏍᎦᏂ ᎦᏝᏗ ᎠᏕᏲ ᎠᎦᏘᏏ',
    '⤴' => 'ᎠᎦᏘᏏ ᎦᏝᏗ ᎠᏕᏲ ᎦᎸᎳᏗᎠᎦᏘ',
    '⤵' => 'ᎠᎦᏘᏏ ᎦᏝᏗ ᎠᏑᏲ ᎡᎳᏗᎠᎦᏘ',
    '🔃' => 'ᎪᏪᎵ ᏗᎦᏂᏱᏙᏗ',
    '🔄' => 'ᏩᏥ ᎦᏏᏅᏍᏔᏅ ᎪᏪᎵ ᏗᎦᏂᏱᏙᏗ',
    '🔙' => 'ᎣᏂᏗᏢ ᎦᏝᏗ',
    '🔚' => 'ᏭᎵᏍᏆᏛ ᎦᏝᏗ',
    '🔛' => 'ᎧᏂᎩᏓ! ᎦᏝᏗ',
    '🔜' => 'ᏞᎩᏭ ᎦᏝᏗ',
    '🔝' => 'ᎦᏚ ᎦᏝᏗ',
    '🛐' => 'ᎤᏙᏢᏒ ᏧᏂᎳᏫᏍᏗᎢ',
    '⚛' => 'ᎢᎦᏓ ᎪᏪᎸ',
    '🕉' => 'ᎣᎹ',
    '✡' => 'ᏃᏈᏏ ᏕᏫ',
    '☸' => 'ᎦᏩᏘ ᏓᎭᎹ',
    '☯' => 'ᏱᏂ ᏰᎾᎩ',
    '✝' => 'ᎴᏔᏂ ᎤᎾᏤᎵ ᏓᏓᎿᏫᏍᏛ',
    '☦' => 'ᎠᏂᏧᏏ ᎤᎾᏤᎵ ᏓᏓᎿᏫᏍᏛ',
    '☪' => 'ᏃᏈᏏ ᎠᎴ ᎤᏓᏍᏈᏘ',
    '☮' => 'ᏅᏩᏙᎯᏯᏛ ᎪᏪᎵ',
    '🕎' => 'ᎦᎵᏉᎩ ᏗᏨᏍᏗ',
    '🔯' => 'ᎤᏅᏥ ᏑᏓᎵ-ᏕᎪᏍᏓᏯ ᏃᏈᏏ',
    '🪯' => 'ᎧᏅᏓ',
    '♈' => 'ᏓᎿᏩ',
    '♉' => 'ᏧᎧᏅᏍᏕᎾ',
    '♊' => 'ᏥᎹᎾᏱ',
    '♋' => 'ᎠᏓᏰᏍᎩ',
    '♌' => 'ᎵᏲ',
    '♍' => 'ᏇᎵᎪ',
    '♎' => 'ᎵᏆ',
    '♏' => 'ᏍᎪᏈᏴᏍ',
    '♐' => 'ᎦᎵᏣᏗᏍᎩ',
    '♑' => 'ᎧᏈᎪᏂ',
    '♒' => 'ᎠᎹ ᎦᏅᏥᏙ',
    '♓' => 'ᎠᏂᏣᏗ',
    '⛎' => 'ᎢᎾᏓ ᎦᏂᏴᏓ',
    '🔀' => 'ᏗᏑᏰᏗ ᏚᏙᏪᎸ ᎦᏗ',
    '🔁' => 'ᏂᎲᎦ ᎦᏛᏗ',
    '🔂' => 'ᏂᎲᎦ ᎤᏩᏌ ᎦᏛᏗ',
    '▶' => 'ᏗᏁᏟᏙᏗ ᎦᏗ',
    '⏩' => 'ᎦᏣᏄᎵ-ᎢᎬᏱᏗᏢ ᎠᏐᎥᏍᏙᏗ',
    '⏭' => 'ᏔᎵᏁ ᎠᎢᏒᎢ ᎦᏗ',
    '⏯' => 'ᏔᏁᏟᏓ ᎠᎴᏱᎩ ᏗᎾᎯᏍᏗ ᎦᏗ',
    '◀' => 'ᏗᎦᏁᏍᏈᏔᏅᎢ ᎦᏗ',
    '⏪' => 'ᎦᏣᏄᎵ ᎠᏨᏍᏙᏗ ᎠᏐᎥᏍᏙᏗ',
    '⏮' => 'ᎣᏂᎢ ᎠᏍᏓᏩᏛᏍᏗ ᎦᏗ',
    '🔼' => 'ᎦᎸᎳᏗ ᎦᏗ',
    '⏫' => 'ᎦᏣᏄᎵ ᎦᎸᎳᏗᏢ ᎠᏐᎥᏍᏙᏗ',
    '🔽' => 'ᎡᎳᏗ ᎦᏗ',
    '⏬' => 'ᎦᏣᏄᎵ ᎡᎳᏗ ᎠᏐᎥᏍᏙᏗ',
    '⏸' => 'ᎦᎾᎯᏍᏙᏗ ᎦᏗ',
    '⏹' => 'ᎠᎴᏫᏍᏙᏗ ᎦᏗ',
    '⏺' => 'ᎦᏂᏱᏙᏗ ᎦᏗ',
    '⏏' => 'ᎦᎴᏍᏗ ᎦᏗ',
    '🎦' => 'ᏗᏓᏴᎳᏛᏍᎩ',
    '🔅' => 'ᎠᏍᎪᎸᏓ ᎦᏗ',
    '🔆' => 'ᎤᏍᎪᏍᏗ ᎦᏗ',
    '📶' => 'ᏚᎷᎬᎢ ᏕᎦᎾᎸᎢ',
    '🛜' => 'ᏂᏓᏏᎳᏛᎾ',
    '📳' => 'ᎠᎵᏖᎸᎲᏍᎬ ᏄᏛᏅ',
    '📴' => 'ᏙᎴᎳᏊ ᏗᎵᏃᎮᏓ ᎠᏜᏛ',
    '♀' => 'ᎠᎨᏯ ᎪᏟᏍᏙᏗ',
    '♂' => 'ᎠᏍᎦᏯ ᎪᏟᏍᏙᏗ',
    '⚧' => 'ᏄᏬᎵᏍᏛᎾ ᎪᏟᏍᏙᏗ',
    '✖' => 'ᎤᏓᎨᏓ ᏗᏎᏢᎢ ᎤᏙᏪᎸ',
    '➕' => 'ᎤᏓᎨᏓ ᎧᏁᏉᎩ ᎤᏙᏪᎸ',
    '➖' => 'ᎤᏓᎨᏓ ᎠᎦᏲᎶᏗᏍᎩ ᎤᏙᏪᎸ',
    '➗' => 'ᎤᏓᎨᏓ ᏱᎦᏛᎢ ᎤᏙᏪᎸ',
    '🟰' => 'ᎦᎨᏓ ᎢᏧᎳᎭ ᎪᏪᎸ',
    '♾' => 'ᎢᎪᎯᏓ',
    '‼' => 'ᏔᎵᎭ ᏍᏓᏱ ᎤᏃᏴᎩ ᎤᏙᏪᎸ',
    '⁉' => 'ᏍᏓᏱ ᎤᏃᏴᎩ ᎠᏛᏛᎲᏍᎩ ᎤᏙᏪᎸ',
    '❓' => 'ᎠᏛᏛᎲᏍᎩ ᎤᏙᏪᎸ',
    '❔' => 'ᎤᏁᎦ ᎠᏛᏛᎲᏍᎩ ᎤᏙᏪᎸ',
    '❕' => 'ᎤᏁᎦ ᏍᏓᏱ ᎤᏃᏴᎩ ᎤᏙᏪᎸ',
    '❗' => 'ᏍᏓᏱ ᎤᏃᏴᎩ ᎤᏙᏪᎸ',
    '〰' => 'ᎠᎵᏐᏰᎭ ᎤᏓᏂᏴᎢ',
    '💱' => 'ᎠᏕᎳ ᎦᏁᏟᏴᏍᏗ',
    '💲' => 'ᎤᏓᎨᏓ ᎤᏃᏍᏗ ᎪᏪᎵ',
    '⚕' => 'ᏅᏬᏘ ᎤᏙᏢᎭ',
    '♻' => 'ᎢᎬᎦᏔᏂᏓᏍᏗ ᎪᏪᎵ',
    '⚜' => 'ᎠᏥᎳ ᎠᏁᎶᎯ ᎠᏥᎸᏍᎩ',
    '🔱' => 'ᏴᎩ ᏓᏟᎶᏍᏛ',
    '📛' => 'ᏙᏙᎥᎢ ᎦᏗ',
    '🔰' => 'ᏣᏩᏂᏏ ᏓᏟᎶᏍᏗᏍᎬᎢ ᎾᏍᎩ ᎬᏩᏙᏗ ᎠᎴᏂᏍᎩ',
    '⭕' => 'ᎤᏒᏙᏂ ᎩᎦᎨ ᎦᏐᏆᎳ',
    '✅' => 'ᎪᏪᎳᏅᎯ ᎠᏍᏓᏅᏅᎢ',
    '☑' => 'ᎪᏪᎳᏅᎯ ᎧᏁᏌᎢ',
    '✔' => 'ᎪᏪᎳᏅᎯ',
    '❌' => 'ᏓᏓᎿᏫᏍᏛ ᎤᏙᏪᎸ',
    '❎' => 'ᏓᏓᎿᏫᏍᏛ ᎤᏙᏪᎸ ᎠᏍᏓᏅᏅᎢ',
    '➰' => 'ᎤᎵᏥᏍᏆᏁᏓ ᎦᏕᏱᏍᏛᎢ',
    '➿' => 'ᏔᎵ ᏧᎵᏥᏍᏆᏁᏓ ᎦᏕᏱᏍᏛ',
    '〽' => 'ᎢᎦᏛ ᎦᏁᏟᏴᏍᏗ ᎤᏙᏪᎸ',
    '✳' => 'ᏧᏁᎳ-ᏧᏯᏓᏘ ᎤᏙᏪᎸ',
    '✴' => 'ᏧᏁᎳ-ᏗᎪᏍᏓᏱ ᏃᏈᏏ',
    '❇' => 'ᎤᏥᏍᏓᎷᎩᏍᎩ',
    '™' => 'ᎠᎵᏱᏛᎢ ᎪᏪᎸ',
    '🫟' => 'ᏩᏍᏚᏟᏥᎯ',
    '🔠' => 'ᏗᎦᏘᏅᏗᏍᏗ ᎳᏔᏂ ᎦᎸᎳᏗᏗᎪᏪᎵ',
    '🔡' => 'ᏗᎦᏘᏅᏗᏍᏗ ᎴᏔᏂ ᎡᎳᏗᏗᎪᏪᎵ',
    '🔢' => 'ᏗᎦᏘᏅᏗᏍᏗ ᏗᏎᏍᏗ',
    '🔣' => 'ᏗᎦᏘᏅᏗᏍᏗ ᏚᏙᏪᎸᎢ',
    '🔤' => 'ᏗᎦᏘᏅᏗᏍᏗ ᎴᏔᏂ ᏗᎪᎵᏰᏗ',
    '🅰' => 'A ᎦᏗ (ᎢᏳᏍᏗ ᎩᎦ ᎣᏁᎲᎢ)',
    '🆎' => 'AB ᎦᏗ (ᎢᏳᏍᏗ ᎩᎦ ᎣᏁᎲᎢ)',
    '🅱' => 'B ᎦᏗ (ᎢᏳᏍᏗ ᎩᎦ ᎣᏁᎲᎢ)',
    '🆑' => 'CL ᎦᏗ',
    '🆒' => 'ᎤᏁᏏᏴᏝ ᎦᏗ',
    '🆓' => 'ᎠᏎᏭᎢ ᎦᏗ',
    'ℹ' => 'ᎧᏃᎮᏢᏅᎢ',
    '🆔' => 'ID ᎦᏗ',
    'Ⓜ' => 'ᎦᏕᏱᏍᏛ M',
    '🆕' => 'ᎢᏤᎢ ᎦᏗ',
    '🆖' => 'NG ᎦᏗ',
    '🅾' => 'O ᎦᏗ (ᎢᏳᏍᏗ ᎩᎦ ᎤᏁᎲᎢ)',
    '🆗' => 'ᎣᏏᏊ ᎦᏗ',
    '🅿' => 'P ᎦᏗ',
    '🆘' => 'SOS ᎦᏗ',
    '🆙' => 'ᎦᎸᎳᏗᎢ! ᎦᏗ',
    '🆚' => 'VS ᎦᏗ',
    '🈁' => 'ᏣᏩᏂᏏ “ᎠᎭᏂ” ᎦᏗ',
    '🈂' => 'ᏣᏩᏂᏏ “ᎠᏓᏂᏟᏗᎢ” ᎦᏗ',
    '🈷' => 'ᏣᏩᏂᏏ “ᏏᏅᏓ ᏳᏓᎵ ᎠᏯᏙᏢᎢ” ᎦᏗ',
    '🈶' => 'ᏣᏩᏂᏏ “ᎠᏎᏭ ᏂᎨᏒᎾ” ᎦᏗ',
    '🈯' => 'ᏣᏩᏂᏏ “ᎦᏃᎯᏴᎢ” ᎦᏗ',
    '🉐' => 'ᏣᏩᏂᏏ “ᏗᎪᏏᏌᏅ” ᎦᏗ',
    '🈹' => 'ᏣᏩᏂᏏ “ᎦᏲᏟ ᏧᎬᏩᎶᏗ” ᎦᏗ',
    '🈚' => 'ᏣᏩᏂᏏ “ᎠᏎᏭᎢ” ᎦᏗ',
    '🈲' => 'ᏣᏩᏂᏏ “ᎢᏯᏛᏁᏗ ᏂᎨᏒᎾ” ᎦᏗ',
    '🉑' => 'ᏣᏩᏂᏏ “ᏗᏓᏂᎸᏍᏗ” ᎦᏗ',
    '🈸' => 'ᏣᏩᏂᏏ “ᎠᎧᎵᏏᏐᏗ” ᎦᏗ',
    '🈴' => 'ᏣᏩᏂᏏ “ᏕᎦᎶᏍᎬᎢ” ᎦᏗ',
    '🈳' => 'ᏣᏩᏂᏏ “ᎤᏟᏅᏓ” ᎦᏗ',
    '㊗' => 'ᏣᏩᏂᏏ “ᎠᎵᎮᎵᏍᏗ” ᎦᏗ',
    '㊙' => 'ᏣᏩᏂᏏ “ᎤᏕᎵᏓ” ᏗᎦ',
    '🈺' => 'ᏣᏩᏂᏏ “ᎠᏍᏚᎢᏓ ᏗᎦᎸᏫᏍᏓᏁᏗ” ᎦᏗ',
    '🈵' => 'ᏣᏩᏂᏏ “ᎥᏝ ᏱᏟᏅᏓ” ᎦᏗ',
    '🔴' => 'ᎩᎦᎨ ᎦᏐᏆᎸ',
    '🟠' => 'ᎠᏓᎶᏂᎨ ᎦᏐᏆᎸ',
    '🟡' => 'ᏓᎶᏂᎨ ᎦᏐᏆᎸ',
    '🟢' => 'ᎢᏤ ᎢᏳᏍᏗ ᎦᏐᏆᎸ',
    '🔵' => 'ᏌᎪᏂᎨ ᎦᏐᏆᎸ',
    '🟣' => 'ᎠᏓᎲᎵᎨ ᎦᏐᏆᎸ',
    '🟤' => 'ᎤᏬᏗᎨ ᎦᏐᏆᎸ',
    '⚫' => 'ᎬᎿᎨᎢ ᎦᏐᏆᎸ',
    '⚪' => 'ᎤᏁᎦ ᎦᏕᏯᏍᏛ',
    '🟥' => 'ᎩᎦᎨ ᏅᎩ ᏧᏅᏏᏯ',
    '🟧' => 'ᎠᏓᎶᏂᎨ ᏅᎩ ᏧᏅᏏᏯ',
    '🟨' => 'ᏓᎶᏂᎨ ᏅᎩ ᏧᏅᏏᏯ',
    '🟩' => 'ᎢᏤ ᎢᏳᏍᏗ ᏅᎩ ᏧᏅᏏᏯ',
    '🟦' => 'ᏌᎪᏂᎨ ᏅᎩ ᏧᏅᏏᏯ',
    '🟪' => 'ᎠᏓᎲᎵᎨ ᏅᎩ ᏧᏅᏏᏯ',
    '🟫' => 'ᎤᏬᏗᎨ ᏅᎩ ᏧᏅᏏᏯ',
    '⬛' => 'ᎬᎿᎨ ᎤᏔᎾ ᎾᎩ ᏧᏅᏏᏱ',
    '⬜' => 'ᎤᏁᎦ ᎤᏔᎾ ᏅᎩ ᏗᏧᏅᏏᏯ',
    '◼' => 'ᎬᎿᎨ ᎠᏲᏟᎨ ᏅᎩ ᏧᏅᏏᏯ',
    '◻' => 'ᎤᏁᎦ ᎠᏲᏟᎨ ᏅᎩ ᏧᏅᏏᏯ',
    '◾' => 'ᎬᎿᎨ ᎠᏲᏟᎨ-ᎤᏍᏗ ᎾᎩ ᏧᏅᏏᏯ',
    '◽' => 'ᎤᏁᎦ ᎠᏲᏟᎨ-ᎤᏍᏗ ᏅᎩ ᏧᏅᏏᏯ',
    '▪' => 'ᎬᎿᎨ ᎤᏍᏗ ᏅᎩ ᏧᏅᏏᏯ',
    '▫' => 'ᎤᏁᎦ ᎤᏍᏗ ᏅᎩ ᏧᏅᏏᏯ',
    '🔶' => 'ᎤᏔᎾ ᎣᏂᏥ ᎦᎸᏉᏗ ᏅᏯ',
    '🔷' => 'ᎤᏔᎾ ᏌᎪᏂ ᎦᎸᏉᏗ ᏅᏯ',
    '🔸' => 'ᎤᏍᏗ ᎠᏓᎶᏂᎨ ᎤᏣᏍᏓᎷᎩᏍᎩ ᏅᏯ',
    '🔹' => 'ᎤᏍᏗ ᏌᎪᏂᎨ ᎤᏣᏍᏓᎷᎩᏍᎩ ᏅᏯ',
    '🔺' => 'ᎩᎦᎨ ᏦᎢ ᏧᏏᏅᏓ ᎠᏎᎯ ᎦᎸᎳᏗ',
    '🔻' => 'ᎩᎦᎨ ᏦᎢ ᏧᏏᏅᏓ ᎠᏎᎯ ᎡᎳᏗᏜ',
    '💠' => 'ᎤᏥᏍᏓᎷᎩᏍᎩ ᎤᏓᏓᏟ',
    '🔘' => 'ᏗᎧᏃᎩᏍᏗ ᎦᏗ',
    '🔳' => 'ᎤᏁᎦ ᏅᎩ ᏧᏅᏏᏯ ᎦᏛ',
    '🔲' => 'ᎬᎿᎨ ᏅᎩ ᏧᏅᏏᏯ ᎦᏗ',
    '🏁' => 'ᏧᏅᏣᏘ ᎦᏓᏘ',
    '🚩' => 'ᏦᎢ ᏧᏅᏏᏓ ᎦᏗ',
    '🎌' => 'ᏧᏓᎿᏫᏓ ᏗᎦᏓᏗ',
    '🏴' => 'ᎬᎿᎨ ᎦᏓᏘ',
    '🏳' => 'ᎤᏁᎦ ᎦᏓᏘ',
];
