<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'porik, kiž so koši: dorosćeny, dorosćeny, swětła barba kože a srěnjoswětła barba kože',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'porik, kiž so koši: dorosćeny, dorosćeny, swětła barba kože a srěnja barba kože',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'porik, kiž so koši: dorosćeny, dorosćeny, swětła barba kože a srěnjoćmowa barba kože',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'porik, kiž so koši: dorosćeny, dorosćeny, swětła barba kože a ćmowa barba kože',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'porik, kiž so koši: dorosćeny, dorosćeny, srěnjoswětła barba kože a swětła barba kože',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'porik, kiž so koši: dorosćeny, dorosćeny, srěnjoswětła barba kože a srěnja barba kože',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'porik, kiž so koši: dorosćeny, dorosćeny, srěnjoswětła barba kože a srěnjoćmowa barba kože',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'porik, kiž so koši: dorosćeny, dorosćeny, srěnjoswětła barba kože a ćmowa barba kože',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'porik, kiž so koši: dorosćeny, dorosćeny, srěnja barba kože a swětła barba kože',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'porik, kiž so koši: dorosćeny, dorosćeny, srěnja barba kože a srěnjoswětła barba kože',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'porik, kiž so koši: dorosćeny, dorosćeny, srěnja barba kože a srěnjoćmowa barba kože',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'porik, kiž so koši: dorosćeny, dorosćeny, srěnja barba kože a ćmowa barba kože',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'porik, kiž so koši: dorosćeny, dorosćeny, srěnjoćmowa barba kože a swětła barba kože',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'porik, kiž so koši: dorosćeny, dorosćeny, srěnjoćmowa barba kože a srěnjoswětła barba kože',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'porik, kiž so koši: dorosćeny, dorosćeny, srěnjoćmowa barba kože a srěnja barba kože',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'porik, kiž so koši: dorosćeny, dorosćeny, srěnjoćmowa barba kože a ćmowa barba kože',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'porik, kiž so koši: dorosćeny, dorosćeny, ćmowa barba kože a swětła barba kože',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'porik, kiž so koši: dorosćeny, dorosćeny, ćmowa barba kože a srěnjoswětła barba kože',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'porik, kiž so koši: dorosćeny, dorosćeny, ćmowa barba kože a srěnja barba kože',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'porik, kiž so koši: dorosćeny, dorosćeny, ćmowa barba kože a srěnjoćmowa barba kože',
    '👨🏻‍❤‍💋‍👨🏻' => 'porik, kiž so koši: muž, muž a swětła barba kože',
    '👨🏻‍❤‍💋‍👨🏼' => 'porik, kiž so koši: muž, muž, swětła barba kože a srěnjoswětła barba kože',
    '👨🏻‍❤‍💋‍👨🏽' => 'porik, kiž so koši: muž, muž, swětła barba kože a srěnja barba kože',
    '👨🏻‍❤‍💋‍👨🏾' => 'porik, kiž so koši: muž, muž, swětła barba kože a srěnjoćmowa barba kože',
    '👨🏻‍❤‍💋‍👨🏿' => 'porik, kiž so koši: muž, muž, swětła barba kože a ćmowa barba kože',
    '👨🏼‍❤‍💋‍👨🏻' => 'porik, kiž so koši: muž, muž, srěnjoswětła barba kože a swětła barba kože',
    '👨🏼‍❤‍💋‍👨🏼' => 'porik, kiž so koši: muž, muž a srěnjoswětła barba kože',
    '👨🏼‍❤‍💋‍👨🏽' => 'porik, kiž so koši: muž, muž, srěnjoswětła barba kože a srěnja barba kože',
    '👨🏼‍❤‍💋‍👨🏾' => 'porik, kiž so koši: muž, muž, srěnjoswětła barba kože a srěnjoćmowa barba kože',
    '👨🏼‍❤‍💋‍👨🏿' => 'porik, kiž so koši: muž, muž, srěnjoswětła barba kože a ćmowa barba kože',
    '👨🏽‍❤‍💋‍👨🏻' => 'porik, kiž so koši: muž, muž, srěnja barba kože a swětła barba kože',
    '👨🏽‍❤‍💋‍👨🏼' => 'porik, kiž so koši: muž, muž, srěnja barba kože a srěnjoswětła barba kože',
    '👨🏽‍❤‍💋‍👨🏽' => 'porik, kiž so koši: muž, muž a srěnja barba kože',
    '👨🏽‍❤‍💋‍👨🏾' => 'porik, kiž so koši: muž, muž, srěnja barba kože a srěnjoćmowa barba kože',
    '👨🏽‍❤‍💋‍👨🏿' => 'porik, kiž so koši: muž, muž, srěnja barba kože a ćmowa barba kože',
    '👨🏾‍❤‍💋‍👨🏻' => 'porik, kiž so koši: muž, muž, srěnjoćmowa barba kože a swětła barba kože',
    '👨🏾‍❤‍💋‍👨🏼' => 'porik, kiž so koši: muž, muž, srěnjoćmowa barba kože a srěnjoswětła barba kože',
    '👨🏾‍❤‍💋‍👨🏽' => 'porik, kiž so koši: muž, muž, srěnjoćmowa barba kože a srěnja barba kože',
    '👨🏾‍❤‍💋‍👨🏾' => 'porik, kiž so koši: muž, muž a srěnjoćmowa barba kože',
    '👨🏾‍❤‍💋‍👨🏿' => 'porik, kiž so koši: muž, muž, srěnjoćmowa barba kože a ćmowa barba kože',
    '👨🏿‍❤‍💋‍👨🏻' => 'porik, kiž so koši: muž, muž, ćmowa barba kože a swětła barba kože',
    '👨🏿‍❤‍💋‍👨🏼' => 'porik, kiž so koši: muž, muž, ćmowa barba kože a srěnjoswětła barba kože',
    '👨🏿‍❤‍💋‍👨🏽' => 'porik, kiž so koši: muž, muž, ćmowa barba kože a srěnja barba kože',
    '👨🏿‍❤‍💋‍👨🏾' => 'porik, kiž so koši: muž, muž, ćmowa barba kože a srěnjoćmowa barba kože',
    '👨🏿‍❤‍💋‍👨🏿' => 'porik, kiž so koši: muž, muž a ćmowa barba kože',
    '👩🏻‍❤‍💋‍👨🏻' => 'porik, kiž so koši: žona, muž a swětła barba kože',
    '👩🏻‍❤‍💋‍👨🏼' => 'porik, kiž so koši: žona, muž, swětła barba kože a srěnjoswětła barba kože',
    '👩🏻‍❤‍💋‍👨🏽' => 'porik, kiž so koši: žona, muž, swětła barba kože a srěnja barba kože',
    '👩🏻‍❤‍💋‍👨🏾' => 'porik, kiž so koši: žona, muž, swětła barba kože a srěnjoćmowa barba kože',
    '👩🏻‍❤‍💋‍👨🏿' => 'porik, kiž so koši: žona, muž, swětła barba kože a ćmowa barba kože',
    '👩🏼‍❤‍💋‍👨🏻' => 'porik, kiž so koši: žona, muž, srěnjoswětła barba kože a swětła barba kože',
    '👩🏼‍❤‍💋‍👨🏼' => 'porik, kiž so koši: žona, muž a srěnjoswětła barba kože',
    '👩🏼‍❤‍💋‍👨🏽' => 'porik, kiž so koši: žona, muž, srěnjoswětła barba kože a srěnja barba kože',
    '👩🏼‍❤‍💋‍👨🏾' => 'porik, kiž so koši: žona, muž, srěnjoswětła barba kože a srěnjoćmowa barba kože',
    '👩🏼‍❤‍💋‍👨🏿' => 'porik, kiž so koši: žona, muž, srěnjoswětła barba kože a ćmowa barba kože',
    '👩🏽‍❤‍💋‍👨🏻' => 'porik, kiž so koši: žona, muž, srěnja barba kože a swětła barba kože',
    '👩🏽‍❤‍💋‍👨🏼' => 'porik, kiž so koši: žona, muž, srěnja barba kože a srěnjoswětła barba kože',
    '👩🏽‍❤‍💋‍👨🏽' => 'porik, kiž so koši: žona, muž a srěnja barba kože',
    '👩🏽‍❤‍💋‍👨🏾' => 'porik, kiž so koši: žona, muž, srěnja barba kože a srěnjoćmowa barba kože',
    '👩🏽‍❤‍💋‍👨🏿' => 'porik, kiž so koši: žona, muž, srěnja barba kože a ćmowa barba kože',
    '👩🏾‍❤‍💋‍👨🏻' => 'porik, kiž so koši: žona, muž, srěnjoćmowa barba kože a swětła barba kože',
    '👩🏾‍❤‍💋‍👨🏼' => 'porik, kiž so koši: žona, muž, srěnjoćmowa barba kože a srěnjoswětła barba kože',
    '👩🏾‍❤‍💋‍👨🏽' => 'porik, kiž so koši: žona, muž, srěnjoćmowa barba kože a srěnja barba kože',
    '👩🏾‍❤‍💋‍👨🏾' => 'porik, kiž so koši: žona, muž a srěnjoćmowa barba kože',
    '👩🏾‍❤‍💋‍👨🏿' => 'porik, kiž so koši: žona, muž, srěnjoćmowa barba kože a ćmowa barba kože',
    '👩🏿‍❤‍💋‍👨🏻' => 'porik, kiž so koši: žona, muž, ćmowa barba kože a swětła barba kože',
    '👩🏿‍❤‍💋‍👨🏼' => 'porik, kiž so koši: žona, muž, ćmowa barba kože a srěnjoswětła barba kože',
    '👩🏿‍❤‍💋‍👨🏽' => 'porik, kiž so koši: žona, muž, ćmowa barba kože a srěnja barba kože',
    '👩🏿‍❤‍💋‍👨🏾' => 'porik, kiž so koši: žona, muž, ćmowa barba kože a srěnjoćmowa barba kože',
    '👩🏿‍❤‍💋‍👨🏿' => 'porik, kiž so koši: žona, muž a ćmowa barba kože',
    '👩🏻‍❤‍💋‍👩🏻' => 'porik, kiž so koši: žona, žona a swětła barba kože',
    '👩🏻‍❤‍💋‍👩🏼' => 'porik, kiž so koši: žona, žona, swětła barba kože a srěnjoswětła barba kože',
    '👩🏻‍❤‍💋‍👩🏽' => 'porik, kiž so koši: žona, žona, swětła barba kože a srěnja barba kože',
    '👩🏻‍❤‍💋‍👩🏾' => 'porik, kiž so koši: žona, žona, swětła barba kože a srěnjoćmowa barba kože',
    '👩🏻‍❤‍💋‍👩🏿' => 'porik, kiž so koši: žona, žona, swětła barba kože a ćmowa barba kože',
    '👩🏼‍❤‍💋‍👩🏻' => 'porik, kiž so koši: žona, žona, srěnjoswětła barba kože a swětła barba kože',
    '👩🏼‍❤‍💋‍👩🏼' => 'porik, kiž so koši: žona, žona a srěnjoswětła barba kože',
    '👩🏼‍❤‍💋‍👩🏽' => 'porik, kiž so koši: žona, žona, srěnjoswětła barba kože a srěnja barba kože',
    '👩🏼‍❤‍💋‍👩🏾' => 'porik, kiž so koši: žona, žona, srěnjoswětła barba kože a srěnjoćmowa barba kože',
    '👩🏼‍❤‍💋‍👩🏿' => 'porik, kiž so koši: žona, žona, srěnjoswětła barba kože a ćmowa barba kože',
    '👩🏽‍❤‍💋‍👩🏻' => 'porik, kiž so koši: žona, žona, srěnja barba kože a swětła barba kože',
    '👩🏽‍❤‍💋‍👩🏼' => 'porik, kiž so koši: žona, žona, srěnja barba kože a srěnjoswětła barba kože',
    '👩🏽‍❤‍💋‍👩🏽' => 'porik, kiž so koši: žona, žona a srěnja barba kože',
    '👩🏽‍❤‍💋‍👩🏾' => 'porik, kiž so koši: žona, žona, srěnja barba kože a srěnjoćmowa barba kože',
    '👩🏽‍❤‍💋‍👩🏿' => 'porik, kiž so koši: žona, žona, srěnja barba kože a ćmowa barba kože',
    '👩🏾‍❤‍💋‍👩🏻' => 'porik, kiž so koši: žona, žona, srěnjoćmowa barba kože a swětła barba kože',
    '👩🏾‍❤‍💋‍👩🏼' => 'porik, kiž so koši: žona, žona, srěnjoćmowa barba kože a srěnjoswětła barba kože',
    '👩🏾‍❤‍💋‍👩🏽' => 'porik, kiž so koši: žona, žona, srěnjoćmowa barba kože a srěnja barba kože',
    '👩🏾‍❤‍💋‍👩🏾' => 'porik, kiž so koši: žona, žona a srěnjoćmowa barba kože',
    '👩🏾‍❤‍💋‍👩🏿' => 'porik, kiž so koši: žona, žona, srěnjoćmowa barba kože a ćmowa barba kože',
    '👩🏿‍❤‍💋‍👩🏻' => 'porik, kiž so koši: žona, žona, ćmowa barba kože a swětła barba kože',
    '👩🏿‍❤‍💋‍👩🏼' => 'porik, kiž so koši: žona, žona, ćmowa barba kože a srěnjoswětła barba kože',
    '👩🏿‍❤‍💋‍👩🏽' => 'porik, kiž so koši: žona, žona, ćmowa barba kože a srěnja barba kože',
    '👩🏿‍❤‍💋‍👩🏾' => 'porik, kiž so koši: žona, žona, ćmowa barba kože a srěnjoćmowa barba kože',
    '👩🏿‍❤‍💋‍👩🏿' => 'porik, kiž so koši: žona, žona a ćmowa barba kože',
    '🧑🏻‍🫯‍🧑🏼' => 'wosobje, kiž wjerhatej: swětła barba kože, srěnjoswětła barba kože',
    '🧑🏻‍🫯‍🧑🏽' => 'wosobje, kiž wjerhatej: swětła barba kože, srěnja barba kože',
    '🧑🏻‍🫯‍🧑🏾' => 'wosobje, kiž wjerhatej: swětła barba kože, srěnjoćmowa barba kože',
    '🧑🏻‍🫯‍🧑🏿' => 'wosobje, kiž wjerhatej: swětła barba kože, ćmowa barba kože',
    '🧑🏼‍🫯‍🧑🏻' => 'wosobje, kiž wjerhatej: srěnjoswětła barba kože, swětła barba kože',
    '🧑🏼‍🫯‍🧑🏽' => 'wosobje, kiž wjerhatej: srěnjoswětła barba kože, srěnja barba kože',
    '🧑🏼‍🫯‍🧑🏾' => 'wosobje, kiž wjerhatej: srěnjoswětła barba kože, srěnjoćmowa barba kože',
    '🧑🏼‍🫯‍🧑🏿' => 'wosobje, kiž wjerhatej: srěnjoswětła barba kože, ćmowa barba kože',
    '🧑🏽‍🫯‍🧑🏻' => 'wosobje, kiž wjerhatej: srěnja barba kože, swětła barba kože',
    '🧑🏽‍🫯‍🧑🏼' => 'wosobje, kiž wjerhatej: srěnja barba kože, srěnjoswětła barba kože',
    '🧑🏽‍🫯‍🧑🏾' => 'wosobje, kiž wjerhatej: srěnja barba kože, srěnjoćmowa barba kože',
    '🧑🏽‍🫯‍🧑🏿' => 'wosobje, kiž wjerhatej: srěnja barba kože, ćmowa barba kože',
    '🧑🏾‍🫯‍🧑🏻' => 'wosobje, kiž wjerhatej: srěnjoćmowa barba kože, swětła barba kože',
    '🧑🏾‍🫯‍🧑🏼' => 'wosobje, kiž wjerhatej: srěnjoćmowa barba kože, srěnjoswětła barba kože',
    '🧑🏾‍🫯‍🧑🏽' => 'wosobje, kiž wjerhatej: srěnjoćmowa barba kože, srěnja barba kože',
    '🧑🏾‍🫯‍🧑🏿' => 'wosobje, kiž wjerhatej: srěnjoćmowa barba kože, ćmowa barba kože',
    '🧑🏿‍🫯‍🧑🏻' => 'wosobje, kiž wjerhatej: ćmowa barba kože, swětła barba kože',
    '🧑🏿‍🫯‍🧑🏼' => 'wosobje, kiž wjerhatej: ćmowa barba kože, srěnjoswětła barba kože',
    '🧑🏿‍🫯‍🧑🏽' => 'wosobje, kiž wjerhatej: ćmowa barba kože, srěnja barba kože',
    '🧑🏿‍🫯‍🧑🏾' => 'wosobje, kiž wjerhatej: ćmowa barba kože, srěnjoćmowa barba kože',
    '🧑🏻‍❤‍🧑🏼' => 'porik z wutrobičku: dorosćeny, dorosćeny, swětła barba kože a srěnjoswětła barba kože',
    '🧑🏻‍❤‍🧑🏽' => 'porik z wutrobičku: dorosćeny, dorosćeny, swětła barba kože a srěnja barba kože',
    '🧑🏻‍❤‍🧑🏾' => 'porik z wutrobičku: dorosćeny, dorosćeny, swětła barba kože a srěnjoćmowa barba kože',
    '🧑🏻‍❤‍🧑🏿' => 'porik z wutrobičku: dorosćeny, dorosćeny, swětła barba kože a ćmowa barba kože',
    '🧑🏼‍❤‍🧑🏻' => 'porik z wutrobičku: dorosćeny, dorosćeny, srěnjoswětła barba kože a swětła barba kože',
    '🧑🏼‍❤‍🧑🏽' => 'porik z wutrobičku: dorosćeny, dorosćeny, srěnjoswětła barba kože a srěnja barba kože',
    '🧑🏼‍❤‍🧑🏾' => 'porik z wutrobičku: dorosćeny, dorosćeny, srěnjoswětła barba kože a srěnjoćmowa barba kože',
    '🧑🏼‍❤‍🧑🏿' => 'porik z wutrobičku: dorosćeny, dorosćeny, srěnjoswětła barba kože a ćmowa barba kože',
    '🧑🏽‍❤‍🧑🏻' => 'porik z wutrobičku: dorosćeny, dorosćeny, srěnja barba kože a swětła barba kože',
    '🧑🏽‍❤‍🧑🏼' => 'porik z wutrobičku: dorosćeny, dorosćeny, srěnja barba kože a srěnjoswětła barba kože',
    '🧑🏽‍❤‍🧑🏾' => 'porik z wutrobičku: dorosćeny, dorosćeny, srěnja barba kože a srěnjoćmowa barba kože',
    '🧑🏽‍❤‍🧑🏿' => 'porik z wutrobičku: dorosćeny, dorosćeny, srěnja barba kože a ćmowa barba kože',
    '🧑🏾‍❤‍🧑🏻' => 'porik z wutrobičku: dorosćeny, dorosćeny, srěnjoćmowa barba kože a swětła barba kože',
    '🧑🏾‍❤‍🧑🏼' => 'porik z wutrobičku: dorosćeny, dorosćeny, srěnjoćmowa barba kože a srěnjoswětła barba kože',
    '🧑🏾‍❤‍🧑🏽' => 'porik z wutrobičku: dorosćeny, dorosćeny, srěnjoćmowa barba kože a srěnja barba kože',
    '🧑🏾‍❤‍🧑🏿' => 'porik z wutrobičku: dorosćeny, dorosćeny, srěnjoćmowa barba kože a ćmowa barba kože',
    '🧑🏿‍❤‍🧑🏻' => 'porik z wutrobičku: dorosćeny, dorosćeny, ćmowa barba kože a swětła barba kože',
    '🧑🏿‍❤‍🧑🏼' => 'porik z wutrobičku: dorosćeny, dorosćeny, ćmowa barba kože a srěnjoswětła barba kože',
    '🧑🏿‍❤‍🧑🏽' => 'porik z wutrobičku: dorosćeny, dorosćeny, ćmowa barba kože a srěnja barba kože',
    '🧑🏿‍❤‍🧑🏾' => 'porik z wutrobičku: dorosćeny, dorosćeny, ćmowa barba kože a srěnjoćmowa barba kože',
    '🧑🏻‍🐰‍🧑🏼' => 'wosobje ze zaječimaj wušomaj: swětła barba kože, srěnjoswětła barba kože',
    '🧑🏻‍🐰‍🧑🏽' => 'wosobje ze zaječimaj wušomaj: swětła barba kože, srěnja barba kože',
    '🧑🏻‍🐰‍🧑🏾' => 'wosobje ze zaječimaj wušomaj: swětła barba kože, srěnjoćmowa barba kože',
    '🧑🏻‍🐰‍🧑🏿' => 'wosobje ze zaječimaj wušomaj: swětła barba kože, ćmowa barba kože',
    '🧑🏼‍🐰‍🧑🏻' => 'wosobje ze zaječimaj wušomaj: srěnjoswětła barba kože, swětła barba kože',
    '🧑🏼‍🐰‍🧑🏽' => 'wosobje ze zaječimaj wušomaj: srěnjoswětła barba kože, srěnja barba kože',
    '🧑🏼‍🐰‍🧑🏾' => 'wosobje ze zaječimaj wušomaj: srěnjoswětła barba kože, srěnjoćmowa barba kože',
    '🧑🏼‍🐰‍🧑🏿' => 'wosobje ze zaječimaj wušomaj: srěnjoswětła barba kože, ćmowa barba kože',
    '🧑🏽‍🐰‍🧑🏻' => 'wosobje ze zaječimaj wušomaj: srěnja barba kože, swětła barba kože',
    '🧑🏽‍🐰‍🧑🏼' => 'wosobje ze zaječimaj wušomaj: srěnja barba kože, srěnjoswětła barba kože',
    '🧑🏽‍🐰‍🧑🏾' => 'wosobje ze zaječimaj wušomaj: srěnja barba kože, srěnjoćmowa barba kože',
    '🧑🏽‍🐰‍🧑🏿' => 'wosobje ze zaječimaj wušomaj: srěnja barba kože, ćmowa barba kože',
    '🧑🏾‍🐰‍🧑🏻' => 'wosobje ze zaječimaj wušomaj: srěnjoćmowa barba kože, swětła barba kože',
    '🧑🏾‍🐰‍🧑🏼' => 'wosobje ze zaječimaj wušomaj: srěnjoćmowa barba kože, srěnjoswětła barba kože',
    '🧑🏾‍🐰‍🧑🏽' => 'wosobje ze zaječimaj wušomaj: srěnjoćmowa barba kože, srěnja barba kože',
    '🧑🏾‍🐰‍🧑🏿' => 'wosobje ze zaječimaj wušomaj: srěnjoćmowa barba kože, ćmowa barba kože',
    '🧑🏿‍🐰‍🧑🏻' => 'wosobje ze zaječimaj wušomaj: ćmowa barba kože, swětła barba kože',
    '🧑🏿‍🐰‍🧑🏼' => 'wosobje ze zaječimaj wušomaj: ćmowa barba kože, srěnjoswětła barba kože',
    '🧑🏿‍🐰‍🧑🏽' => 'wosobje ze zaječimaj wušomaj: ćmowa barba kože, srěnja barba kože',
    '🧑🏿‍🐰‍🧑🏾' => 'wosobje ze zaječimaj wušomaj: ćmowa barba kože, srěnjoćmowa barba kože',
    '👨🏻‍🫯‍👨🏼' => 'wjerharjej: swětła barba kože, srěnjoswětła barba kože',
    '👨🏻‍🫯‍👨🏽' => 'wjerharjej: swětła barba kože, srěnja barba kože',
    '👨🏻‍🫯‍👨🏾' => 'wjerharjej: swětła barba kože, srěnjoćmowa barba kože',
    '👨🏻‍🫯‍👨🏿' => 'wjerharjej: swětła barba kože, ćmowa barba kože',
    '👨🏼‍🫯‍👨🏻' => 'wjerharjej: srěnjoswětła barba kože, swětła barba kože',
    '👨🏼‍🫯‍👨🏽' => 'wjerharjej: srěnjoswětła barba kože, srěnja barba kože',
    '👨🏼‍🫯‍👨🏾' => 'wjerharjej: srěnjoswětła barba kože, srěnjoćmowa barba kože',
    '👨🏼‍🫯‍👨🏿' => 'wjerharjej: srěnjoswětła barba kože, ćmowa barba kože',
    '👨🏽‍🫯‍👨🏻' => 'wjerharjej: srěnja barba kože, swětła barba kože',
    '👨🏽‍🫯‍👨🏼' => 'wjerharjej: srěnja barba kože, srěnjoswětła barba kože',
    '👨🏽‍🫯‍👨🏾' => 'wjerharjej: srěnja barba kože, srěnjoćmowa barba kože',
    '👨🏽‍🫯‍👨🏿' => 'wjerharjej: srěnja barba kože, ćmowa barba kože',
    '👨🏾‍🫯‍👨🏻' => 'wjerharjej: srěnjoćmowa barba kože, swětła barba kože',
    '👨🏾‍🫯‍👨🏼' => 'wjerharjej: srěnjoćmowa barba kože, srěnjoswětła barba kože',
    '👨🏾‍🫯‍👨🏽' => 'wjerharjej: srěnjoćmowa barba kože, srěnja barba kože',
    '👨🏾‍🫯‍👨🏿' => 'wjerharjej: srěnjoćmowa barba kože, ćmowa barba kože',
    '👨🏿‍🫯‍👨🏻' => 'wjerharjej: ćmowa barba kože, swětła barba kože',
    '👨🏿‍🫯‍👨🏼' => 'wjerharjej: ćmowa barba kože, srěnjoswětła barba kože',
    '👨🏿‍🫯‍👨🏽' => 'wjerharjej: ćmowa barba kože, srěnja barba kože',
    '👨🏿‍🫯‍👨🏾' => 'wjerharjej: ćmowa barba kože, srěnjoćmowa barba kože',
    '👨🏻‍❤‍👨🏻' => 'porik z wutrobičku: muž, muž a swětła barba kože',
    '👨🏻‍❤‍👨🏼' => 'porik z wutrobičku: muž, muž, swětła barba kože a srěnjoswětła barba kože',
    '👨🏻‍❤‍👨🏽' => 'porik z wutrobičku: muž, muž, swětła barba kože a srěnja barba kože',
    '👨🏻‍❤‍👨🏾' => 'porik z wutrobičku: muž, muž, swětła barba kože a srěnjoćmowa barba kože',
    '👨🏻‍❤‍👨🏿' => 'porik z wutrobičku: muž, muž, swětła barba kože a ćmowa barba kože',
    '👨🏼‍❤‍👨🏻' => 'porik z wutrobičku: muž, muž, srěnjoswětła barba kože a swětła barba kože',
    '👨🏼‍❤‍👨🏼' => 'porik z wutrobičku: muž, muž a srěnjoswětła barba kože',
    '👨🏼‍❤‍👨🏽' => 'porik z wutrobičku: muž, muž, srěnjoswětła barba kože a srěnja barba kože',
    '👨🏼‍❤‍👨🏾' => 'porik z wutrobičku: muž, muž, srěnjoswětła barba kože a srěnjoćmowa barba kože',
    '👨🏼‍❤‍👨🏿' => 'porik z wutrobičku: muž, muž, srěnjoswětła barba kože a ćmowa barba kože',
    '👨🏽‍❤‍👨🏻' => 'porik z wutrobičku: muž, muž, srěnja barba kože a swětła barba kože',
    '👨🏽‍❤‍👨🏼' => 'porik z wutrobičku: muž, muž, srěnja barba kože a srěnjoswětła barba kože',
    '👨🏽‍❤‍👨🏽' => 'porik z wutrobičku: muž, muž a srěnja barba kože',
    '👨🏽‍❤‍👨🏾' => 'porik z wutrobičku: muž, muž, srěnja barba kože a srěnjoćmowa barba kože',
    '👨🏽‍❤‍👨🏿' => 'porik z wutrobičku: muž, muž, srěnja barba kože a ćmowa barba kože',
    '👨🏾‍❤‍👨🏻' => 'porik z wutrobičku: muž, muž, srěnjoćmowa barba kože a swětła barba kože',
    '👨🏾‍❤‍👨🏼' => 'porik z wutrobičku: muž, muž, srěnjoćmowa barba kože a srěnjoswětła barba kože',
    '👨🏾‍❤‍👨🏽' => 'porik z wutrobičku: muž, muž, srěnjoćmowa barba kože a srěnja barba kože',
    '👨🏾‍❤‍👨🏾' => 'porik z wutrobičku: muž, muž a srěnjoćmowa barba kože',
    '👨🏾‍❤‍👨🏿' => 'porik z wutrobičku: muž, muž, srěnjoćmowa barba kože a ćmowa barba kože',
    '👨🏿‍❤‍👨🏻' => 'porik z wutrobičku: muž, muž, ćmowa barba kože a swětła barba kože',
    '👨🏿‍❤‍👨🏼' => 'porik z wutrobičku: muž, muž, ćmowa barba kože a srěnjoswětła barba kože',
    '👨🏿‍❤‍👨🏽' => 'porik z wutrobičku: muž, muž, ćmowa barba kože a srěnja barba kože',
    '👨🏿‍❤‍👨🏾' => 'porik z wutrobičku: muž, muž, ćmowa barba kože a srěnjoćmowa barba kože',
    '👨🏿‍❤‍👨🏿' => 'porik z wutrobičku: muž, muž a ćmowa barba kože',
    '👨🏻‍🐰‍👨🏼' => 'mužej ze zaječimaj wušomaj: swětła barba kože, srěnjoswětła barba kože',
    '👨🏻‍🐰‍👨🏽' => 'mužej ze zaječimaj wušomaj: swětła barba kože, srěnja barba kože',
    '👨🏻‍🐰‍👨🏾' => 'mužej ze zaječimaj wušomaj: swětła barba kože, srěnjoćmowa barba kože',
    '👨🏻‍🐰‍👨🏿' => 'mužej ze zaječimaj wušomaj: swětła barba kože, ćmowa barba kože',
    '👨🏼‍🐰‍👨🏻' => 'mužej ze zaječimaj wušomaj: srěnjoswětła barba kože, swětła barba kože',
    '👨🏼‍🐰‍👨🏽' => 'mužej ze zaječimaj wušomaj: srěnjoswětła barba kože, srěnja barba kože',
    '👨🏼‍🐰‍👨🏾' => 'mužej ze zaječimaj wušomaj: srěnjoswětła barba kože, srěnjoćmowa barba kože',
    '👨🏼‍🐰‍👨🏿' => 'mužej ze zaječimaj wušomaj: srěnjoswětła barba kože, ćmowa barba kože',
    '👨🏽‍🐰‍👨🏻' => 'mužej ze zaječimaj wušomaj: srěnja barba kože, swětła barba kože',
    '👨🏽‍🐰‍👨🏼' => 'mužej ze zaječimaj wušomaj: srěnja barba kože, srěnjoswětła barba kože',
    '👨🏽‍🐰‍👨🏾' => 'mužej ze zaječimaj wušomaj: srěnja barba kože, srěnjoćmowa barba kože',
    '👨🏽‍🐰‍👨🏿' => 'mužej ze zaječimaj wušomaj: srěnja barba kože, ćmowa barba kože',
    '👨🏾‍🐰‍👨🏻' => 'mužej ze zaječimaj wušomaj: srěnjoćmowa barba kože, swětła barba kože',
    '👨🏾‍🐰‍👨🏼' => 'mužej ze zaječimaj wušomaj: srěnjoćmowa barba kože, srěnjoswětła barba kože',
    '👨🏾‍🐰‍👨🏽' => 'mužej ze zaječimaj wušomaj: srěnjoćmowa barba kože, srěnja barba kože',
    '👨🏾‍🐰‍👨🏿' => 'mužej ze zaječimaj wušomaj: srěnjoćmowa barba kože, ćmowa barba kože',
    '👨🏿‍🐰‍👨🏻' => 'mužej ze zaječimaj wušomaj: ćmowa barba kože, swětła barba kože',
    '👨🏿‍🐰‍👨🏼' => 'mužej ze zaječimaj wušomaj: ćmowa barba kože, srěnjoswětła barba kože',
    '👨🏿‍🐰‍👨🏽' => 'mužej ze zaječimaj wušomaj: ćmowa barba kože, srěnja barba kože',
    '👨🏿‍🐰‍👨🏾' => 'mužej ze zaječimaj wušomaj: ćmowa barba kože, srěnjoćmowa barba kože',
    '👩🏻‍🫯‍👩🏼' => 'wjerharce: swětła barba kože, srěnjoswětła barba kože',
    '👩🏻‍🫯‍👩🏽' => 'wjerharce: swětła barba kože, srěnja barba kože',
    '👩🏻‍🫯‍👩🏾' => 'wjerharce: swětła barba kože, srěnjoćmowa barba kože',
    '👩🏻‍🫯‍👩🏿' => 'wjerharce: swětła barba kože, ćmowa barba kože',
    '👩🏼‍🫯‍👩🏻' => 'wjerharce: srěnjoswětła barba kože, swětła barba kože',
    '👩🏼‍🫯‍👩🏽' => 'wjerharce: srěnjoswětła barba kože, srěnja barba kože',
    '👩🏼‍🫯‍👩🏾' => 'wjerharce: srěnjoswětła barba kože, srěnjoćmowa barba kože',
    '👩🏼‍🫯‍👩🏿' => 'wjerharce: srěnjoswětła barba kože, ćmowa barba kože',
    '👩🏽‍🫯‍👩🏻' => 'wjerharce: srěnja barba kože, swětła barba kože',
    '👩🏽‍🫯‍👩🏼' => 'wjerharce: srěnja barba kože, srěnjoswětła barba kože',
    '👩🏽‍🫯‍👩🏾' => 'wjerharce: srěnja barba kože, srěnjoćmowa barba kože',
    '👩🏽‍🫯‍👩🏿' => 'wjerharce: srěnja barba kože, ćmowa barba kože',
    '👩🏾‍🫯‍👩🏻' => 'wjerharce: srěnjoćmowa barba kože, swětła barba kože',
    '👩🏾‍🫯‍👩🏼' => 'wjerharce: srěnjoćmowa barba kože, srěnjoswětła barba kože',
    '👩🏾‍🫯‍👩🏽' => 'wjerharce: srěnjoćmowa barba kože, srěnja barba kože',
    '👩🏾‍🫯‍👩🏿' => 'wjerharce: srěnjoćmowa barba kože, ćmowa barba kože',
    '👩🏿‍🫯‍👩🏻' => 'wjerharce: ćmowa barba kože, swětła barba kože',
    '👩🏿‍🫯‍👩🏼' => 'wjerharce: ćmowa barba kože, srěnjoswětła barba kože',
    '👩🏿‍🫯‍👩🏽' => 'wjerharce: ćmowa barba kože, srěnja barba kože',
    '👩🏿‍🫯‍👩🏾' => 'wjerharce: ćmowa barba kože, srěnjoćmowa barba kože',
    '👩🏻‍❤‍👨🏻' => 'porik z wutrobičku: žona, muž a swětła barba kože',
    '👩🏻‍❤‍👨🏼' => 'porik z wutrobičku: žona, muž, swětła barba kože a srěnjoswětła barba kože',
    '👩🏻‍❤‍👨🏽' => 'porik z wutrobičku: žona, muž, swětła barba kože a srěnja barba kože',
    '👩🏻‍❤‍👨🏾' => 'porik z wutrobičku: žona, muž, swětła barba kože a srěnjoćmowa barba kože',
    '👩🏻‍❤‍👨🏿' => 'porik z wutrobičku: žona, muž, swětła barba kože a ćmowa barba kože',
    '👩🏼‍❤‍👨🏻' => 'porik z wutrobičku: žona, muž, srěnjoswětła barba kože a swětła barba kože',
    '👩🏼‍❤‍👨🏼' => 'porik z wutrobičku: žona, muž a srěnjoswětła barba kože',
    '👩🏼‍❤‍👨🏽' => 'porik z wutrobičku: žona, muž, srěnjoswětła barba kože a srěnja barba kože',
    '👩🏼‍❤‍👨🏾' => 'porik z wutrobičku: žona, muž, srěnjoswětła barba kože a srěnjoćmowa barba kože',
    '👩🏼‍❤‍👨🏿' => 'porik z wutrobičku: žona, muž, srěnjoswětła barba kože a ćmowa barba kože',
    '👩🏽‍❤‍👨🏻' => 'porik z wutrobičku: žona, muž, srěnja barba kože a swětła barba kože',
    '👩🏽‍❤‍👨🏼' => 'porik z wutrobičku: žona, muž, srěnja barba kože a srěnjoswětła barba kože',
    '👩🏽‍❤‍👨🏽' => 'porik z wutrobičku: žona, muž a srěnja barba kože',
    '👩🏽‍❤‍👨🏾' => 'porik z wutrobičku: žona, muž, srěnja barba kože a srěnjoćmowa barba kože',
    '👩🏽‍❤‍👨🏿' => 'porik z wutrobičku: žona, muž, srěnja barba kože a ćmowa barba kože',
    '👩🏾‍❤‍👨🏻' => 'porik z wutrobičku: žona, muž, srěnjoćmowa barba kože a swětła barba kože',
    '👩🏾‍❤‍👨🏼' => 'porik z wutrobičku: žona, muž, srěnjoćmowa barba kože a srěnjoswětła barba kože',
    '👩🏾‍❤‍👨🏽' => 'porik z wutrobičku: žona, muž, srěnjoćmowa barba kože a srěnja barba kože',
    '👩🏾‍❤‍👨🏾' => 'porik z wutrobičku: žona, muž a srěnjoćmowa barba kože',
    '👩🏾‍❤‍👨🏿' => 'porik z wutrobičku: žona, muž, srěnjoćmowa barba kože a ćmowa barba kože',
    '👩🏿‍❤‍👨🏻' => 'porik z wutrobičku: žona, muž, ćmowa barba kože a swětła barba kože',
    '👩🏿‍❤‍👨🏼' => 'porik z wutrobičku: žona, muž, ćmowa barba kože a srěnjoswětła barba kože',
    '👩🏿‍❤‍👨🏽' => 'porik z wutrobičku: žona, muž, ćmowa barba kože a srěnja barba kože',
    '👩🏿‍❤‍👨🏾' => 'porik z wutrobičku: žona, muž, ćmowa barba kože a srěnjoćmowa barba kože',
    '👩🏿‍❤‍👨🏿' => 'porik z wutrobičku: žona, muž a ćmowa barba kože',
    '👩🏻‍❤‍👩🏻' => 'porik z wutrobičku: žona, žona a swětła barba kože',
    '👩🏻‍❤‍👩🏼' => 'porik z wutrobičku: žona, žona, swětła barba kože a srěnjoswětła barba kože',
    '👩🏻‍❤‍👩🏽' => 'porik z wutrobičku: žona, žona, swětła barba kože a srěnja barba kože',
    '👩🏻‍❤‍👩🏾' => 'porik z wutrobičku: žona, žona, swětła barba kože a srěnjoćmowa barba kože',
    '👩🏻‍❤‍👩🏿' => 'porik z wutrobičku: žona, žona, swětła barba kože a ćmowa barba kože',
    '👩🏼‍❤‍👩🏻' => 'porik z wutrobičku: žona, žona, srěnjoswětła barba kože a swětła barba kože',
    '👩🏼‍❤‍👩🏼' => 'porik z wutrobičku: žona, žona a srěnjoswětła barba kože',
    '👩🏼‍❤‍👩🏽' => 'porik z wutrobičku: žona, žona, srěnjoswětła barba kože a srěnja barba kože',
    '👩🏼‍❤‍👩🏾' => 'porik z wutrobičku: žona, žona, srěnjoswětła barba kože a srěnjoćmowa barba kože',
    '👩🏼‍❤‍👩🏿' => 'porik z wutrobičku: žona, žona, srěnjoswětła barba kože a ćmowa barba kože',
    '👩🏽‍❤‍👩🏻' => 'porik z wutrobičku: žona, žona, srěnja barba kože a swětła barba kože',
    '👩🏽‍❤‍👩🏼' => 'porik z wutrobičku: žona, žona, srěnja barba kože a srěnjoswětła barba kože',
    '👩🏽‍❤‍👩🏽' => 'porik z wutrobičku: žona, žona a srěnja barba kože',
    '👩🏽‍❤‍👩🏾' => 'porik z wutrobičku: žona, žona, srěnja barba kože a srěnjoćmowa barba kože',
    '👩🏽‍❤‍👩🏿' => 'porik z wutrobičku: žona, žona, srěnja barba kože a ćmowa barba kože',
    '👩🏾‍❤‍👩🏻' => 'porik z wutrobičku: žona, žona, srěnjoćmowa barba kože a swětła barba kože',
    '👩🏾‍❤‍👩🏼' => 'porik z wutrobičku: žona, žona, srěnjoćmowa barba kože a srěnjoswětła barba kože',
    '👩🏾‍❤‍👩🏽' => 'porik z wutrobičku: žona, žona, srěnjoćmowa barba kože a srěnja barba kože',
    '👩🏾‍❤‍👩🏾' => 'porik z wutrobičku: žona, žona a srěnjoćmowa barba kože',
    '👩🏾‍❤‍👩🏿' => 'porik z wutrobičku: žona, žona, srěnjoćmowa barba kože a ćmowa barba kože',
    '👩🏿‍❤‍👩🏻' => 'porik z wutrobičku: žona, žona, ćmowa barba kože a swětła barba kože',
    '👩🏿‍❤‍👩🏼' => 'porik z wutrobičku: žona, žona, ćmowa barba kože a srěnjoswětła barba kože',
    '👩🏿‍❤‍👩🏽' => 'porik z wutrobičku: žona, žona, ćmowa barba kože a srěnja barba kože',
    '👩🏿‍❤‍👩🏾' => 'porik z wutrobičku: žona, žona, ćmowa barba kože a srěnjoćmowa barba kože',
    '👩🏿‍❤‍👩🏿' => 'porik z wutrobičku: žona, žona a ćmowa barba kože',
    '👩🏻‍🐰‍👩🏼' => 'žonje ze zaječimaj wušomaj: swětła barba kože, srěnjoswětła barba kože',
    '👩🏻‍🐰‍👩🏽' => 'žonje ze zaječimaj wušomaj: swětła barba kože, srěnja barba kože',
    '👩🏻‍🐰‍👩🏾' => 'žonje ze zaječimaj wušomaj: swětła barba kože, srěnjoćmowa barba kože',
    '👩🏻‍🐰‍👩🏿' => 'žonje ze zaječimaj wušomaj: swětła barba kože, ćmowa barba kože',
    '👩🏼‍🐰‍👩🏻' => 'žonje ze zaječimaj wušomaj: srěnjoswětła barba kože, swětła barba kože',
    '👩🏼‍🐰‍👩🏽' => 'žonje ze zaječimaj wušomaj: srěnjoswětła barba kože, srěnja barba kože',
    '👩🏼‍🐰‍👩🏾' => 'žonje ze zaječimaj wušomaj: srěnjoswětła barba kože, srěnjoćmowa barba kože',
    '👩🏼‍🐰‍👩🏿' => 'žonje ze zaječimaj wušomaj: srěnjoswětła barba kože, ćmowa barba kože',
    '👩🏽‍🐰‍👩🏻' => 'žonje ze zaječimaj wušomaj: srěnja barba kože, swětła barba kože',
    '👩🏽‍🐰‍👩🏼' => 'žonje ze zaječimaj wušomaj: srěnja barba kože, srěnjoswětła barba kože',
    '👩🏽‍🐰‍👩🏾' => 'žonje ze zaječimaj wušomaj: srěnja barba kože, srěnjoćmowa barba kože',
    '👩🏽‍🐰‍👩🏿' => 'žonje ze zaječimaj wušomaj: srěnja barba kože, ćmowa barba kože',
    '👩🏾‍🐰‍👩🏻' => 'žonje ze zaječimaj wušomaj: srěnjoćmowa barba kože, swětła barba kože',
    '👩🏾‍🐰‍👩🏼' => 'žonje ze zaječimaj wušomaj: srěnjoćmowa barba kože, srěnjoswětła barba kože',
    '👩🏾‍🐰‍👩🏽' => 'žonje ze zaječimaj wušomaj: srěnjoćmowa barba kože, srěnja barba kože',
    '👩🏾‍🐰‍👩🏿' => 'žonje ze zaječimaj wušomaj: srěnjoćmowa barba kože, ćmowa barba kože',
    '👩🏿‍🐰‍👩🏻' => 'žonje ze zaječimaj wušomaj: ćmowa barba kože, swětła barba kože',
    '👩🏿‍🐰‍👩🏼' => 'žonje ze zaječimaj wušomaj: ćmowa barba kože, srěnjoswětła barba kože',
    '👩🏿‍🐰‍👩🏽' => 'žonje ze zaječimaj wušomaj: ćmowa barba kože, srěnja barba kože',
    '👩🏿‍🐰‍👩🏾' => 'žonje ze zaječimaj wušomaj: ćmowa barba kože, srěnjoćmowa barba kože',
    '🧑🏻‍🤝‍🧑🏻' => 'dwě wosobje dźeržitej so za ruku: swětła barba kože',
    '🧑🏻‍🤝‍🧑🏼' => 'dwě wosobje dźeržitej so za ruku: swětła barba kože, srěnjoswětła barba kože',
    '🧑🏻‍🤝‍🧑🏽' => 'dwě wosobje dźeržitej so za ruku: swětła barba kože, srěnja barba kože',
    '🧑🏻‍🤝‍🧑🏾' => 'dwě wosobje dźeržitej so za ruku: swětła barba kože, srěnjoćmowa barba kože',
    '🧑🏻‍🤝‍🧑🏿' => 'dwě wosobje dźeržitej so za ruku: swětła barba kože, ćmowa barba kože',
    '🧑🏼‍🤝‍🧑🏻' => 'dwě wosobje dźeržitej so za ruku: srěnjoswětła barba kože, swětła barba kože',
    '🧑🏼‍🤝‍🧑🏼' => 'dwě wosobje dźeržitej so za ruku: srěnjoswětła barba kože',
    '🧑🏼‍🤝‍🧑🏽' => 'dwě wosobje dźeržitej so za ruku: srěnjoswětła barba kože, srěnja barba kože',
    '🧑🏼‍🤝‍🧑🏾' => 'dwě wosobje dźeržitej so za ruku: srěnjoswětła barba kože, srěnjoćmowa barba kože',
    '🧑🏼‍🤝‍🧑🏿' => 'dwě wosobje dźeržitej so za ruku: srěnjoswětła barba kože, ćmowa barba kože',
    '🧑🏽‍🤝‍🧑🏻' => 'dwě wosobje dźeržitej so za ruku: srěnja barba kože, swětła barba kože',
    '🧑🏽‍🤝‍🧑🏼' => 'dwě wosobje dźeržitej so za ruku: srěnja barba kože, srěnjoswětła barba kože',
    '🧑🏽‍🤝‍🧑🏽' => 'dwě wosobje dźeržitej so za ruku: srěnja barba kože',
    '🧑🏽‍🤝‍🧑🏾' => 'dwě wosobje dźeržitej so za ruku: srěnja barba kože, srěnjoćmowa barba kože',
    '🧑🏽‍🤝‍🧑🏿' => 'dwě wosobje dźeržitej so za ruku: srěnja barba kože, ćmowa barba kože',
    '🧑🏾‍🤝‍🧑🏻' => 'dwě wosobje dźeržitej so za ruku: srěnjoćmowa barba kože, swětła barba kože',
    '🧑🏾‍🤝‍🧑🏼' => 'dwě wosobje dźeržitej so za ruku: srěnjoćmowa barba kože, srěnjoswětła barba kože',
    '🧑🏾‍🤝‍🧑🏽' => 'dwě wosobje dźeržitej so za ruku: srěnjoćmowa barba kože, srěnja barba kože',
    '🧑🏾‍🤝‍🧑🏾' => 'dwě wosobje dźeržitej so za ruku: srěnjoćmowa barba kože',
    '🧑🏾‍🤝‍🧑🏿' => 'dwě wosobje dźeržitej so za ruku: srěnjoćmowa barba kože, ćmowa barba kože',
    '🧑🏿‍🤝‍🧑🏻' => 'dwě wosobje dźeržitej so za ruku: ćmowa barba kože, swětła barba kože',
    '🧑🏿‍🤝‍🧑🏼' => 'dwě wosobje dźeržitej so za ruku: ćmowa barba kože, srěnjoswětła barba kože',
    '🧑🏿‍🤝‍🧑🏽' => 'dwě wosobje dźeržitej so za ruku: ćmowa barba kože, srěnja barba kože',
    '🧑🏿‍🤝‍🧑🏾' => 'dwě wosobje dźeržitej so za ruku: ćmowa barba kože, srěnjoćmowa barba kože',
    '🧑🏿‍🤝‍🧑🏿' => 'dwě wosobje dźeržitej so za ruku: ćmowa barba kože',
    '👩🏻‍🤝‍👩🏼' => 'žonje dźeržitej so za ruku: swětła barba kože, srěnjoswětła barba kože',
    '👩🏻‍🤝‍👩🏽' => 'žonje dźeržitej so za ruku: swětła barba kože, srěnja barba kože',
    '👩🏻‍🤝‍👩🏾' => 'žonje dźeržitej so za ruku: swětła barba kože, srěnjoćmowa barba kože',
    '👩🏻‍🤝‍👩🏿' => 'žonje dźeržitej so za ruku: swětła barba kože, ćmowa barba kože',
    '👩🏼‍🤝‍👩🏻' => 'žonje dźeržitej so za ruku: srěnjoswětła barba kože, swětła barba kože',
    '👩🏼‍🤝‍👩🏽' => 'žonje dźeržitej so za ruku: srěnjoswětła barba kože, srěnja barba kože',
    '👩🏼‍🤝‍👩🏾' => 'žonje dźeržitej so za ruku: srěnjoswětła barba kože, srěnjoćmowa barba kože',
    '👩🏼‍🤝‍👩🏿' => 'žonje dźeržitej so za ruku: srěnjoswětła barba kože, ćmowa barba kože',
    '👩🏽‍🤝‍👩🏻' => 'žonje dźeržitej so za ruku: srěnja barba kože, swětła barba kože',
    '👩🏽‍🤝‍👩🏼' => 'žonje dźeržitej so za ruku: srěnja barba kože, srěnjoswětła barba kože',
    '👩🏽‍🤝‍👩🏾' => 'žonje dźeržitej so za ruku: srěnja barba kože, srěnjoćmowa barba kože',
    '👩🏽‍🤝‍👩🏿' => 'žonje dźeržitej so za ruku: srěnja barba kože, ćmowa barba kože',
    '👩🏾‍🤝‍👩🏻' => 'žonje dźeržitej so za ruku: srěnjoćmowa barba kože, swětła barba kože',
    '👩🏾‍🤝‍👩🏼' => 'žonje dźeržitej so za ruku: srěnjoćmowa barba kože, srěnjoswětła barba kože',
    '👩🏾‍🤝‍👩🏽' => 'žonje dźeržitej so za ruku: srěnjoćmowa barba kože, srěnja barba kože',
    '👩🏾‍🤝‍👩🏿' => 'žonje dźeržitej so za ruku: srěnjoćmowa barba kože, ćmowa barba kože',
    '👩🏿‍🤝‍👩🏻' => 'žonje dźeržitej so za ruku: ćmowa barba kože, swětła barba kože',
    '👩🏿‍🤝‍👩🏼' => 'žonje dźeržitej so za ruku: ćmowa barba kože, srěnjoswětła barba kože',
    '👩🏿‍🤝‍👩🏽' => 'žonje dźeržitej so za ruku: ćmowa barba kože, srěnja barba kože',
    '👩🏿‍🤝‍👩🏾' => 'žonje dźeržitej so za ruku: ćmowa barba kože, srěnjoćmowa barba kože',
    '👩🏻‍🤝‍👨🏼' => 'muž a žona dźeržitaj so za ruku: swětła barba kože, srěnjoswětła barba kože',
    '👩🏻‍🤝‍👨🏽' => 'muž a žona dźeržitaj so za ruku: swětła barba kože, srěnja barba kože',
    '👩🏻‍🤝‍👨🏾' => 'muž a žona dźeržitaj so za ruku: swětła barba kože, srěnjoćmowa barba kože',
    '👩🏻‍🤝‍👨🏿' => 'muž a žona dźeržitaj so za ruku: swětła barba kože, ćmowa barba kože',
    '👩🏼‍🤝‍👨🏻' => 'muž a žona dźeržitaj so za ruku: srěnjoswětła barba kože, swětła barba kože',
    '👩🏼‍🤝‍👨🏽' => 'muž a žona dźeržitaj so za ruku: srěnjoswětła barba kože, srěnja barba kože',
    '👩🏼‍🤝‍👨🏾' => 'muž a žona dźeržitaj so za ruku: srěnjoswětła barba kože, srěnjoćmowa barba kože',
    '👩🏼‍🤝‍👨🏿' => 'muž a žona dźeržitaj so za ruku: srěnjoswětła barba kože, ćmowa barba kože',
    '👩🏽‍🤝‍👨🏻' => 'muž a žona dźeržitaj so za ruku: srěnja barba kože, swětła barba kože',
    '👩🏽‍🤝‍👨🏼' => 'muž a žona dźeržitaj so za ruku: srěnja barba kože, srěnjoswětła barba kože',
    '👩🏽‍🤝‍👨🏾' => 'muž a žona dźeržitaj so za ruku: srěnja barba kože, srěnjoćmowa barba kože',
    '👩🏽‍🤝‍👨🏿' => 'muž a žona dźeržitaj so za ruku: srěnja barba kože, ćmowa barba kože',
    '👩🏾‍🤝‍👨🏻' => 'muž a žona dźeržitaj so za ruku: srěnjoćmowa barba kože, swětła barba kože',
    '👩🏾‍🤝‍👨🏼' => 'muž a žona dźeržitaj so za ruku: srěnjoćmowa barba kože, srěnjoswětła barba kože',
    '👩🏾‍🤝‍👨🏽' => 'muž a žona dźeržitaj so za ruku: srěnjoćmowa barba kože, srěnja barba kože',
    '👩🏾‍🤝‍👨🏿' => 'muž a žona dźeržitaj so za ruku: srěnjoćmowa barba kože, ćmowa barba kože',
    '👩🏿‍🤝‍👨🏻' => 'muž a žona dźeržitaj so za ruku: ćmowa barba kože, swětła barba kože',
    '👩🏿‍🤝‍👨🏼' => 'muž a žona dźeržitaj so za ruku: ćmowa barba kože, srěnjoswětła barba kože',
    '👩🏿‍🤝‍👨🏽' => 'muž a žona dźeržitaj so za ruku: ćmowa barba kože, srěnja barba kože',
    '👩🏿‍🤝‍👨🏾' => 'muž a žona dźeržitaj so za ruku: ćmowa barba kože, srěnjoćmowa barba kože',
    '👨🏻‍🤝‍👨🏼' => 'mužej dźeržitaj so za ruku: swětła barba kože, srěnjoswětła barba kože',
    '👨🏻‍🤝‍👨🏽' => 'mužej dźeržitaj so za ruku: swětła barba kože, srěnja barba kože',
    '👨🏻‍🤝‍👨🏾' => 'mužej dźeržitaj so za ruku: swětła barba kože, srěnjoćmowa barba kože',
    '👨🏻‍🤝‍👨🏿' => 'mužej dźeržitaj so za ruku: swětła barba kože, ćmowa barba kože',
    '👨🏼‍🤝‍👨🏻' => 'mužej dźeržitaj so za ruku: srěnjoswětła barba kože, swětła barba kože',
    '👨🏼‍🤝‍👨🏽' => 'mužej dźeržitaj so za ruku: srěnjoswětła barba kože, srěnja barba kože',
    '👨🏼‍🤝‍👨🏾' => 'mužej dźeržitaj so za ruku: srěnjoswětła barba kože, srěnjoćmowa barba kože',
    '👨🏼‍🤝‍👨🏿' => 'mužej dźeržitaj so za ruku: srěnjoswětła barba kože, ćmowa barba kože',
    '👨🏽‍🤝‍👨🏻' => 'mužej dźeržitaj so za ruku: srěnja barba kože, swětła barba kože',
    '👨🏽‍🤝‍👨🏼' => 'mužej dźeržitaj so za ruku: srěnja barba kože, srěnjoswětła barba kože',
    '👨🏽‍🤝‍👨🏾' => 'mužej dźeržitaj so za ruku: srěnja barba kože, srěnjoćmowa barba kože',
    '👨🏽‍🤝‍👨🏿' => 'mužej dźeržitaj so za ruku: srěnja barba kože, ćmowa barba kože',
    '👨🏾‍🤝‍👨🏻' => 'mužej dźeržitaj so za ruku: srěnjoćmowa barba kože, swětła barba kože',
    '👨🏾‍🤝‍👨🏼' => 'mužej dźeržitaj so za ruku: srěnjoćmowa barba kože, srěnjoswětła barba kože',
    '👨🏾‍🤝‍👨🏽' => 'mužej dźeržitaj so za ruku: srěnjoćmowa barba kože, srěnja barba kože',
    '👨🏾‍🤝‍👨🏿' => 'mužej dźeržitaj so za ruku: srěnjoćmowa barba kože, ćmowa barba kože',
    '👨🏿‍🤝‍👨🏻' => 'mužej dźeržitaj so za ruku: ćmowa barba kože, swětła barba kože',
    '👨🏿‍🤝‍👨🏼' => 'mužej dźeržitaj so za ruku: ćmowa barba kože, srěnjoswětła barba kože',
    '👨🏿‍🤝‍👨🏽' => 'mužej dźeržitaj so za ruku: ćmowa barba kože, srěnja barba kože',
    '👨🏿‍🤝‍👨🏾' => 'mužej dźeržitaj so za ruku: ćmowa barba kože, srěnjoćmowa barba kože',
    '👩‍❤‍💋‍👨' => 'porik, kiž so koši: žona, muž',
    '👨‍❤‍💋‍👨' => 'porik, kiž so koši: muž, muž',
    '👩‍❤‍💋‍👩' => 'porik, kiž so koši: žona, žona',
    '👨‍👩‍👧‍👦' => 'swójba: muž, žona, holca a hólc',
    '👨‍👩‍👦‍👦' => 'swójba: muž, žona, hólc a hólc',
    '👨‍👩‍👧‍👧' => 'swójba: muž, žona, holca a holca',
    '👨‍👨‍👧‍👦' => 'swójba: muž, muž, holca a hólc',
    '👨‍👨‍👦‍👦' => 'swójba: muž, muž, hólc a hólc',
    '👨‍👨‍👧‍👧' => 'swójba: muž, muž, holca a holca',
    '👩‍👩‍👧‍👦' => 'swójba: žona, žona, holca a hólc',
    '👩‍👩‍👦‍👦' => 'swójba: žona, žona, hólc a hólc',
    '👩‍👩‍👧‍👧' => 'swójba: žona, žona, holca a holca',
    '🧑‍🧑‍🧒‍🧒' => 'swójba: dorosćenaj a dźěsći',
    '🚶🏻‍♀‍➡' => 'pěška: swětła barba kože, doprawa',
    '🚶🏼‍♀‍➡' => 'pěška: srěnjoswětła barba kože, doprawa',
    '🚶🏽‍♀‍➡' => 'pěška: srěnja barba kože, doprawa',
    '🚶🏾‍♀‍➡' => 'pěška: srěnjoćmowa barba kože, doprawa',
    '🚶🏿‍♀‍➡' => 'pěška: ćmowa barba kože, doprawa',
    '🚶🏻‍♂‍➡' => 'pěšk: swětła barba kože, doprawa',
    '🚶🏼‍♂‍➡' => 'pěšk: srěnjoswětła barba kože, doprawa',
    '🚶🏽‍♂‍➡' => 'pěšk: srěnja barba kože, doprawa',
    '🚶🏾‍♂‍➡' => 'pěšk: srěnjoćmowa barba kože, doprawa',
    '🚶🏿‍♂‍➡' => 'pěšk: ćmowa barba kože, doprawa',
    '🧎🏻‍♀‍➡' => 'klečaca žona: swětła barba kože, doprawa',
    '🧎🏼‍♀‍➡' => 'klečaca žona: srěnjoswětła barba kože, doprawa',
    '🧎🏽‍♀‍➡' => 'klečaca žona: srěnja barba kože, doprawa',
    '🧎🏾‍♀‍➡' => 'klečaca žona: srěnjoćmowa barba kože, doprawa',
    '🧎🏿‍♀‍➡' => 'klečaca žona: ćmowa barba kože, doprawa',
    '🧎🏻‍♂‍➡' => 'klečacy muž: swětła barba kože, doprawa',
    '🧎🏼‍♂‍➡' => 'klečacy muž: srěnjoswětła barba kože, doprawa',
    '🧎🏽‍♂‍➡' => 'klečacy muž: srěnja barba kože, doprawa',
    '🧎🏾‍♂‍➡' => 'klečacy muž: srěnjoćmowa barba kože, doprawa',
    '🧎🏿‍♂‍➡' => 'klečacy muž: ćmowa barba kože, doprawa',
    '🧑🏻‍🦯‍➡' => 'wosoba z kijom za slepych: swětła barba kože, doprawa',
    '🧑🏼‍🦯‍➡' => 'wosoba z kijom za slepych: srěnjoswětła barba kože, doprawa',
    '🧑🏽‍🦯‍➡' => 'wosoba z kijom za slepych: srěnja barba kože, doprawa',
    '🧑🏾‍🦯‍➡' => 'wosoba z kijom za slepych: srěnjoćmowa barba kože, doprawa',
    '🧑🏿‍🦯‍➡' => 'wosoba z kijom za slepych: ćmowa barba kože, doprawa',
    '👨🏻‍🦯‍➡' => 'muž z kijom za slepych: swětła barba kože, doprawa',
    '👨🏼‍🦯‍➡' => 'muž z kijom za slepych: srěnjoswětła barba kože, doprawa',
    '👨🏽‍🦯‍➡' => 'muž z kijom za slepych: srěnja barba kože, doprawa',
    '👨🏾‍🦯‍➡' => 'muž z kijom za slepych: srěnjoćmowa barba kože, doprawa',
    '👨🏿‍🦯‍➡' => 'muž z kijom za slepych: ćmowa barba kože, doprawa',
    '👩🏻‍🦯‍➡' => 'žona z kijom za slepych: swětła barba kože, doprawa',
    '👩🏼‍🦯‍➡' => 'žona z kijom za slepych: srěnjoswětła barba kože, doprawa',
    '👩🏽‍🦯‍➡' => 'žona z kijom za slepych: srěnja barba kože, doprawa',
    '👩🏾‍🦯‍➡' => 'žona z kijom za slepych: srěnjoćmowa barba kože, doprawa',
    '👩🏿‍🦯‍➡' => 'žona z kijom za slepych: ćmowa barba kože, doprawa',
    '🧑🏻‍🦼‍➡' => 'wosoba w elektriskim jězbnym stole: swětła barba kože, doprawa',
    '🧑🏼‍🦼‍➡' => 'wosoba w elektriskim jězbnym stole: srěnjoswětła barba kože, doprawa',
    '🧑🏽‍🦼‍➡' => 'wosoba w elektriskim jězbnym stole: srěnja barba kože, doprawa',
    '🧑🏾‍🦼‍➡' => 'wosoba w elektriskim jězbnym stole: srěnjoćmowa barba kože, doprawa',
    '🧑🏿‍🦼‍➡' => 'wosoba w elektriskim jězbnym stole: ćmowa barba kože, doprawa',
    '👨🏻‍🦼‍➡' => 'muž w elektriskim jězbnym stole: swětła barba kože, doprawa',
    '👨🏼‍🦼‍➡' => 'muž w elektriskim jězbnym stole: srěnjoswětła barba kože, doprawa',
    '👨🏽‍🦼‍➡' => 'muž w elektriskim jězbnym stole: srěnja barba kože, doprawa',
    '👨🏾‍🦼‍➡' => 'muž w elektriskim jězbnym stole: srěnjoćmowa barba kože, doprawa',
    '👨🏿‍🦼‍➡' => 'muž w elektriskim jězbnym stole: ćmowa barba kože, doprawa',
    '👩🏻‍🦼‍➡' => 'žona w elektriskim jězbnym stole: swětła barba kože, doprawa',
    '👩🏼‍🦼‍➡' => 'žona w elektriskim jězbnym stole: srěnjoswětła barba kože, doprawa',
    '👩🏽‍🦼‍➡' => 'žona w elektriskim jězbnym stole: srěnja barba kože, doprawa',
    '👩🏾‍🦼‍➡' => 'žona w elektriskim jězbnym stole: srěnjoćmowa barba kože, doprawa',
    '👩🏿‍🦼‍➡' => 'žona w elektriskim jězbnym stole: ćmowa barba kože, doprawa',
    '🧑🏻‍🦽‍➡' => 'wosoba w jězbnym stole: swětła barba kože, doprawa',
    '🧑🏼‍🦽‍➡' => 'wosoba w jězbnym stole: srěnjoswětła barba kože, doprawa',
    '🧑🏽‍🦽‍➡' => 'wosoba w jězbnym stole: srěnja barba kože, doprawa',
    '🧑🏾‍🦽‍➡' => 'wosoba w jězbnym stole: srěnjoćmowa barba kože, doprawa',
    '🧑🏿‍🦽‍➡' => 'wosoba w jězbnym stole: ćmowa barba kože, doprawa',
    '👨🏻‍🦽‍➡' => 'muž w jězbnym stole: swětła barba kože, doprawa',
    '👨🏼‍🦽‍➡' => 'muž w jězbnym stole: srěnjoswětła barba kože, doprawa',
    '👨🏽‍🦽‍➡' => 'muž w jězbnym stole: srěnja barba kože, doprawa',
    '👨🏾‍🦽‍➡' => 'muž w jězbnym stole: srěnjoćmowa barba kože, doprawa',
    '👨🏿‍🦽‍➡' => 'muž w jězbnym stole: ćmowa barba kože, doprawa',
    '👩🏻‍🦽‍➡' => 'žona w jězbnym stole: swětła barba kože, doprawa',
    '👩🏼‍🦽‍➡' => 'žona w jězbnym stole: srěnjoswětła barba kože, doprawa',
    '👩🏽‍🦽‍➡' => 'žona w jězbnym stole: srěnja barba kože, doprawa',
    '👩🏾‍🦽‍➡' => 'žona w jězbnym stole: srěnjoćmowa barba kože, doprawa',
    '👩🏿‍🦽‍➡' => 'žona w jězbnym stole: ćmowa barba kože, doprawa',
    '🏃🏻‍♀‍➡' => 'běhaca žona: swětła barba kože, doprawa',
    '🏃🏼‍♀‍➡' => 'běhaca žona: srěnjoswětła barba kože, doprawa',
    '🏃🏽‍♀‍➡' => 'běhaca žona: srěnja barba kože, doprawa',
    '🏃🏾‍♀‍➡' => 'běhaca žona: srěnjoćmowa barba kože, doprawa',
    '🏃🏿‍♀‍➡' => 'běhaca žona: ćmowa barba kože, doprawa',
    '🏃🏻‍♂‍➡' => 'běhacy muž: swětła barba kože, doprawa',
    '🏃🏼‍♂‍➡' => 'běhacy muž: srěnjoswětła barba kože, doprawa',
    '🏃🏽‍♂‍➡' => 'běhacy muž: srěnja barba kože, doprawa',
    '🏃🏾‍♂‍➡' => 'běhacy muž: srěnjoćmowa barba kože, doprawa',
    '🏃🏿‍♂‍➡' => 'běhacy muž: ćmowa barba kože, doprawa',
    '🫱🏻‍🫲🏼' => 'zawdaće ruki: swětła barba kože, srěnjoswětła barba kože',
    '🫱🏻‍🫲🏽' => 'zawdaće ruki: swětła barba kože, srěnja barba kože',
    '🫱🏻‍🫲🏾' => 'zawdaće ruki: swětła barba kože, srěnjoćmowa barba kože',
    '🫱🏻‍🫲🏿' => 'zawdaće ruki: swětła barba kože, ćmowa barba kože',
    '🫱🏼‍🫲🏻' => 'zawdaće ruki: srěnjoswětła barba kože, swětła barba kože',
    '🫱🏼‍🫲🏽' => 'zawdaće ruki: srěnjoswětła barba kože, srěnja barba kože',
    '🫱🏼‍🫲🏾' => 'zawdaće ruki: srěnjoswětła barba kože, srěnjoćmowa barba kože',
    '🫱🏼‍🫲🏿' => 'zawdaće ruki: srěnjoswětła barba kože, ćmowa barba kože',
    '🫱🏽‍🫲🏻' => 'zawdaće ruki: srěnja barba kože, swětła barba kože',
    '🫱🏽‍🫲🏼' => 'zawdaće ruki: srěnja barba kože, srěnjoswětła barba kože',
    '🫱🏽‍🫲🏾' => 'zawdaće ruki: srěnja barba kože, srěnjoćmowa barba kože',
    '🫱🏽‍🫲🏿' => 'zawdaće ruki: srěnja barba kože, ćmowa barba kože',
    '🫱🏾‍🫲🏻' => 'zawdaće ruki: srěnjoćmowa barba kože, swětła barba kože',
    '🫱🏾‍🫲🏼' => 'zawdaće ruki: srěnjoćmowa barba kože, srěnjoswětła barba kože',
    '🫱🏾‍🫲🏽' => 'zawdaće ruki: srěnjoćmowa barba kože, srěnja barba kože',
    '🫱🏾‍🫲🏿' => 'zawdaće ruki: srěnjoćmowa barba kože, ćmowa barba kože',
    '🫱🏿‍🫲🏻' => 'zawdaće ruki: ćmowa barba kože, swětła barba kože',
    '🫱🏿‍🫲🏼' => 'zawdaće ruki: ćmowa barba kože, srěnjoswětła barba kože',
    '🫱🏿‍🫲🏽' => 'zawdaće ruki: ćmowa barba kože, srěnja barba kože',
    '🫱🏿‍🫲🏾' => 'zawdaće ruki: ćmowa barba kože, srěnjoćmowa barba kože',
    '🚶‍♀‍➡' => 'pěška: doprawa',
    '🚶‍♂‍➡' => 'pěšk: doprawa',
    '🧎‍♀‍➡' => 'klečaca žona: doprawa',
    '🧎‍♂‍➡' => 'klečacy muž: doprawa',
    '🧑‍🦯‍➡' => 'wosoba z kijom za slepych: doprawa',
    '👨‍🦯‍➡' => 'muž z kijom za slepych: doprawa',
    '👩‍🦯‍➡' => 'žona z kijom za slepych: doprawa',
    '🧑‍🦼‍➡' => 'wosoba w elektriskim jězbnym stole: doprawa',
    '👨‍🦼‍➡' => 'muž w elektriskim jězbnym stole: doprawa',
    '👩‍🦼‍➡' => 'žona w elektriskim jězbnym stole: doprawa',
    '🧑‍🦽‍➡' => 'wosoba w jězbnym stole: doprawa',
    '👨‍🦽‍➡' => 'muž w jězbnym stole: doprawa',
    '👩‍🦽‍➡' => 'žona w jězbnym stole: doprawa',
    '🏃‍♀‍➡' => 'běhaca žona: doprawa',
    '🏃‍♂‍➡' => 'běhacy muž: doprawa',
    '👩‍❤‍👨' => 'porik z wutrobičku: žona, muž',
    '👨‍❤‍👨' => 'porik z wutrobičku: muž, muž',
    '👩‍❤‍👩' => 'porik z wutrobičku: žona, žona',
    '👨‍👩‍👦' => 'swójba: muž, žona a hólc',
    '👨‍👩‍👧' => 'swójba: muž, žona a holca',
    '👨‍👨‍👦' => 'swójba: muž, muž a hólc',
    '👨‍👨‍👧' => 'swójba: muž, muž a holca',
    '👩‍👩‍👦' => 'swójba: žona, žona a hólc',
    '👩‍👩‍👧' => 'swójba: žona, žona a holca',
    '👨‍👦‍👦' => 'swójba: muž, hólc a hólc',
    '👨‍👧‍👦' => 'swójba: muž, holca a hólc',
    '👨‍👧‍👧' => 'swójba: muž, holca a holca',
    '👩‍👦‍👦' => 'swójba: žona, hólc a hólc',
    '👩‍👧‍👦' => 'swójba: žona, holca a hólc',
    '👩‍👧‍👧' => 'swójba: žona, holca a holca',
    '🧑‍🤝‍🧑' => 'dwě wosobje dźeržitej so za ruku',
    '🧑‍🧑‍🧒' => 'swójba: dorosćenaj a dźěćo',
    '🧑‍🧒‍🧒' => 'swójba: dorosćeny a dźěsći',
    '🧑🏻‍🦰' => 'dorosćeny: swětła barba kože, čerwjene włosy',
    '🧑🏼‍🦰' => 'dorosćeny: srěnjoswětła barba kože, čerwjene włosy',
    '🧑🏽‍🦰' => 'dorosćeny: srěnja barba kože, čerwjene włosy',
    '🧑🏾‍🦰' => 'dorosćeny: srěnjoćmowa barba kože, čerwjene włosy',
    '🧑🏿‍🦰' => 'dorosćeny: ćmowa barba kože, čerwjene włosy',
    '🧑🏻‍🦱' => 'dorosćeny: swětła barba kože, kudźerjate włosy',
    '🧑🏼‍🦱' => 'dorosćeny: srěnjoswětła barba kože, kudźerjate włosy',
    '🧑🏽‍🦱' => 'dorosćeny: srěnja barba kože, kudźerjate włosy',
    '🧑🏾‍🦱' => 'dorosćeny: srěnjoćmowa barba kože, kudźerjate włosy',
    '🧑🏿‍🦱' => 'dorosćeny: ćmowa barba kože, kudźerjate włosy',
    '🧑🏻‍🦳' => 'dorosćeny: swětła barba kože, šědźiwe włosy',
    '🧑🏼‍🦳' => 'dorosćeny: srěnjoswětła barba kože, šědźiwe włosy',
    '🧑🏽‍🦳' => 'dorosćeny: srěnja barba kože, šědźiwe włosy',
    '🧑🏾‍🦳' => 'dorosćeny: srěnjoćmowa barba kože, šědźiwe włosy',
    '🧑🏿‍🦳' => 'dorosćeny: ćmowa barba kože, šědźiwe włosy',
    '🧑🏻‍🦲' => 'dorosćeny: swětła barba kože, plěch',
    '🧑🏼‍🦲' => 'dorosćeny: srěnjoswětła barba kože, plěch',
    '🧑🏽‍🦲' => 'dorosćeny: srěnja barba kože, plěch',
    '🧑🏾‍🦲' => 'dorosćeny: srěnjoćmowa barba kože, plěch',
    '🧑🏿‍🦲' => 'dorosćeny: ćmowa barba kože, plěch',
    '🧑🏻‍🩰' => 'baletowa rejowarka: swětła barba kože',
    '🧑🏼‍🩰' => 'baletowa rejowarka: srěnjoswětła barba kože',
    '🧑🏽‍🩰' => 'baletowa rejowarka: srěnja barba kože',
    '🧑🏾‍🩰' => 'baletowa rejowarka: srěnjoćmowa barba kože',
    '🧑🏿‍🩰' => 'baletowa rejowarka: ćmowa barba kože',
    '🧔🏻‍♂' => 'muž: swětła barba kože, broda',
    '🧔🏼‍♂' => 'muž: srěnjoswětła barba kože, broda',
    '🧔🏽‍♂' => 'muž: srěnja barba kože, broda',
    '🧔🏾‍♂' => 'muž: srěnjoćmowa barba kože, broda',
    '🧔🏿‍♂' => 'muž: ćmowa barba kože, broda',
    '👱🏻‍♂' => 'muž: swětła barba kože, blond włosy',
    '👱🏼‍♂' => 'muž: srěnjoswětła barba kože, blond włosy',
    '👱🏽‍♂' => 'muž: srěnja barba kože, blond włosy',
    '👱🏾‍♂' => 'muž: srěnjoćmowa barba kože, blond włosy',
    '👱🏿‍♂' => 'muž: ćmowa barba kože, blond włosy',
    '👨🏻‍🦰' => 'muž: swětła barba kože, čerwjene włosy',
    '👨🏼‍🦰' => 'muž: srěnjoswětła barba kože, čerwjene włosy',
    '👨🏽‍🦰' => 'muž: srěnja barba kože, čerwjene włosy',
    '👨🏾‍🦰' => 'muž: srěnjoćmowa barba kože, čerwjene włosy',
    '👨🏿‍🦰' => 'muž: ćmowa barba kože, čerwjene włosy',
    '👨🏻‍🦱' => 'muž: swětła barba kože, kudźerjate włosy',
    '👨🏼‍🦱' => 'muž: srěnjoswětła barba kože, kudźerjate włosy',
    '👨🏽‍🦱' => 'muž: srěnja barba kože, kudźerjate włosy',
    '👨🏾‍🦱' => 'muž: srěnjoćmowa barba kože, kudźerjate włosy',
    '👨🏿‍🦱' => 'muž: ćmowa barba kože, kudźerjate włosy',
    '👨🏻‍🦳' => 'muž: swětła barba kože, šědźiwe włosy',
    '👨🏼‍🦳' => 'muž: srěnjoswětła barba kože, šědźiwe włosy',
    '👨🏽‍🦳' => 'muž: srěnja barba kože, šědźiwe włosy',
    '👨🏾‍🦳' => 'muž: srěnjoćmowa barba kože, šědźiwe włosy',
    '👨🏿‍🦳' => 'muž: ćmowa barba kože, šědźiwe włosy',
    '👨🏻‍🦲' => 'muž: swětła barba kože, plěch',
    '👨🏼‍🦲' => 'muž: srěnjoswětła barba kože, plěch',
    '👨🏽‍🦲' => 'muž: srěnja barba kože, plěch',
    '👨🏾‍🦲' => 'muž: srěnjoćmowa barba kože, plěch',
    '👨🏿‍🦲' => 'muž: ćmowa barba kože, plěch',
    '🧔🏻‍♀' => 'žona: swětła barba kože, broda',
    '🧔🏼‍♀' => 'žona: srěnjoswětła barba kože, broda',
    '🧔🏽‍♀' => 'žona: srěnja barba kože, broda',
    '🧔🏾‍♀' => 'žona: srěnjoćmowa barba kože, broda',
    '🧔🏿‍♀' => 'žona: ćmowa barba kože, broda',
    '👱🏻‍♀' => 'žona: swětła barba kože, blond włosy',
    '👱🏼‍♀' => 'žona: srěnjoswětła barba kože, blond włosy',
    '👱🏽‍♀' => 'žona: srěnja barba kože, blond włosy',
    '👱🏾‍♀' => 'žona: srěnjoćmowa barba kože, blond włosy',
    '👱🏿‍♀' => 'žona: ćmowa barba kože, blond włosy',
    '👩🏻‍🦰' => 'žona: swětła barba kože, čerwjene włosy',
    '👩🏼‍🦰' => 'žona: srěnjoswětła barba kože, čerwjene włosy',
    '👩🏽‍🦰' => 'žona: srěnja barba kože, čerwjene włosy',
    '👩🏾‍🦰' => 'žona: srěnjoćmowa barba kože, čerwjene włosy',
    '👩🏿‍🦰' => 'žona: ćmowa barba kože, čerwjene włosy',
    '👩🏻‍🦱' => 'žona: swětła barba kože, kudźerjate włosy',
    '👩🏼‍🦱' => 'žona: srěnjoswětła barba kože, kudźerjate włosy',
    '👩🏽‍🦱' => 'žona: srěnja barba kože, kudźerjate włosy',
    '👩🏾‍🦱' => 'žona: srěnjoćmowa barba kože, kudźerjate włosy',
    '👩🏿‍🦱' => 'žona: ćmowa barba kože, kudźerjate włosy',
    '👩🏻‍🦳' => 'žona: swětła barba kože, šědźiwe włosy',
    '👩🏼‍🦳' => 'žona: srěnjoswětła barba kože, šědźiwe włosy',
    '👩🏽‍🦳' => 'žona: srěnja barba kože, šědźiwe włosy',
    '👩🏾‍🦳' => 'žona: srěnjoćmowa barba kože, šědźiwe włosy',
    '👩🏿‍🦳' => 'žona: ćmowa barba kože, šědźiwe włosy',
    '👩🏻‍🦲' => 'žona: swětła barba kože, plěch',
    '👩🏼‍🦲' => 'žona: srěnjoswětła barba kože, plěch',
    '👩🏽‍🦲' => 'žona: srěnja barba kože, plěch',
    '👩🏾‍🦲' => 'žona: srěnjoćmowa barba kože, plěch',
    '👩🏿‍🦲' => 'žona: ćmowa barba kože, plěch',
    '🙍🏻‍♂' => 'muž, kiž moršći čoło: swětła barba kože',
    '🙍🏼‍♂' => 'muž, kiž moršći čoło: srěnjoswětła barba kože',
    '🙍🏽‍♂' => 'muž, kiž moršći čoło: srěnja barba kože',
    '🙍🏾‍♂' => 'muž, kiž moršći čoło: srěnjoćmowa barba kože',
    '🙍🏿‍♂' => 'muž, kiž moršći čoło: ćmowa barba kože',
    '🙍🏻‍♀' => 'žona, kiž moršći čoło: swětła barba kože',
    '🙍🏼‍♀' => 'žona, kiž moršći čoło: srěnjoswětła barba kože',
    '🙍🏽‍♀' => 'žona, kiž moršći čoło: srěnja barba kože',
    '🙍🏾‍♀' => 'žona, kiž moršći čoło: srěnjoćmowa barba kože',
    '🙍🏿‍♀' => 'žona, kiž moršći čoło: ćmowa barba kože',
    '🙎🏻‍♂' => 'muž, kiž kózlika wjaza: swětła barba kože',
    '🙎🏼‍♂' => 'muž, kiž kózlika wjaza: srěnjoswětła barba kože',
    '🙎🏽‍♂' => 'muž, kiž kózlika wjaza: srěnja barba kože',
    '🙎🏾‍♂' => 'muž, kiž kózlika wjaza: srěnjoćmowa barba kože',
    '🙎🏿‍♂' => 'muž, kiž kózlika wjaza: ćmowa barba kože',
    '🙎🏻‍♀' => 'žona, kiž kózlika wjaza: swětła barba kože',
    '🙎🏼‍♀' => 'žona, kiž kózlika wjaza: srěnjoswětła barba kože',
    '🙎🏽‍♀' => 'žona, kiž kózlika wjaza: srěnja barba kože',
    '🙎🏾‍♀' => 'žona, kiž kózlika wjaza: srěnjoćmowa barba kože',
    '🙎🏿‍♀' => 'žona, kiž kózlika wjaza: ćmowa barba kože',
    '🙅🏻‍♂' => 'muž z překřižowanymaj rukomaj: swětła barba kože',
    '🙅🏼‍♂' => 'muž z překřižowanymaj rukomaj: srěnjoswětła barba kože',
    '🙅🏽‍♂' => 'muž z překřižowanymaj rukomaj: srěnja barba kože',
    '🙅🏾‍♂' => 'muž z překřižowanymaj rukomaj: srěnjoćmowa barba kože',
    '🙅🏿‍♂' => 'muž z překřižowanymaj rukomaj: ćmowa barba kože',
    '🙅🏻‍♀' => 'žona z překřižowanymaj rukomaj: swětła barba kože',
    '🙅🏼‍♀' => 'žona z překřižowanymaj rukomaj: srěnjoswětła barba kože',
    '🙅🏽‍♀' => 'žona z překřižowanymaj rukomaj: srěnja barba kože',
    '🙅🏾‍♀' => 'žona z překřižowanymaj rukomaj: srěnjoćmowa barba kože',
    '🙅🏿‍♀' => 'žona z překřižowanymaj rukomaj: ćmowa barba kože',
    '🙆🏻‍♂' => 'muž z rukomaj na hłowje: swětła barba kože',
    '🙆🏼‍♂' => 'muž z rukomaj na hłowje: srěnjoswětła barba kože',
    '🙆🏽‍♂' => 'muž z rukomaj na hłowje: srěnja barba kože',
    '🙆🏾‍♂' => 'muž z rukomaj na hłowje: srěnjoćmowa barba kože',
    '🙆🏿‍♂' => 'muž z rukomaj na hłowje: ćmowa barba kože',
    '🙆🏻‍♀' => 'žona z rukomaj na hłowje: swětła barba kože',
    '🙆🏼‍♀' => 'žona z rukomaj na hłowje: srěnjoswětła barba kože',
    '🙆🏽‍♀' => 'žona z rukomaj na hłowje: srěnja barba kože',
    '🙆🏾‍♀' => 'žona z rukomaj na hłowje: srěnjoćmowa barba kože',
    '🙆🏿‍♀' => 'žona z rukomaj na hłowje: ćmowa barba kože',
    '💁🏻‍♂' => 'muž z dłónju horje: swětła barba kože',
    '💁🏼‍♂' => 'muž z dłónju horje: srěnjoswětła barba kože',
    '💁🏽‍♂' => 'muž z dłónju horje: srěnja barba kože',
    '💁🏾‍♂' => 'muž z dłónju horje: srěnjoćmowa barba kože',
    '💁🏿‍♂' => 'muž z dłónju horje: ćmowa barba kože',
    '💁🏻‍♀' => 'žona z dłónju horje: swětła barba kože',
    '💁🏼‍♀' => 'žona z dłónju horje: srěnjoswětła barba kože',
    '💁🏽‍♀' => 'žona z dłónju horje: srěnja barba kože',
    '💁🏾‍♀' => 'žona z dłónju horje: srěnjoćmowa barba kože',
    '💁🏿‍♀' => 'žona z dłónju horje: ćmowa barba kože',
    '🙋🏻‍♂' => 'muž ze zběhnjenej ruku: swětła barba kože',
    '🙋🏼‍♂' => 'muž ze zběhnjenej ruku: srěnjoswětła barba kože',
    '🙋🏽‍♂' => 'muž ze zběhnjenej ruku: srěnja barba kože',
    '🙋🏾‍♂' => 'muž ze zběhnjenej ruku: srěnjoćmowa barba kože',
    '🙋🏿‍♂' => 'muž ze zběhnjenej ruku: ćmowa barba kože',
    '🙋🏻‍♀' => 'žona ze zběhnjenej ruku: swětła barba kože',
    '🙋🏼‍♀' => 'žona ze zběhnjenej ruku: srěnjoswětła barba kože',
    '🙋🏽‍♀' => 'žona ze zběhnjenej ruku: srěnja barba kože',
    '🙋🏾‍♀' => 'žona ze zběhnjenej ruku: srěnjoćmowa barba kože',
    '🙋🏿‍♀' => 'žona ze zběhnjenej ruku: ćmowa barba kože',
    '🧏🏻‍♂' => 'hłuchi muž: swětła barba kože',
    '🧏🏼‍♂' => 'hłuchi muž: srěnjoswětła barba kože',
    '🧏🏽‍♂' => 'hłuchi muž: srěnja barba kože',
    '🧏🏾‍♂' => 'hłuchi muž: srěnjoćmowa barba kože',
    '🧏🏿‍♂' => 'hłuchi muž: ćmowa barba kože',
    '🧏🏻‍♀' => 'hłucha žona: swětła barba kože',
    '🧏🏼‍♀' => 'hłucha žona: srěnjoswětła barba kože',
    '🧏🏽‍♀' => 'hłucha žona: srěnja barba kože',
    '🧏🏾‍♀' => 'hłucha žona: srěnjoćmowa barba kože',
    '🧏🏿‍♀' => 'hłucha žona: ćmowa barba kože',
    '🙇🏻‍♂' => 'muž, kiž so pokłoni: swětła barba kože',
    '🙇🏼‍♂' => 'muž, kiž so pokłoni: srěnjoswětła barba kože',
    '🙇🏽‍♂' => 'muž, kiž so pokłoni: srěnja barba kože',
    '🙇🏾‍♂' => 'muž, kiž so pokłoni: srěnjoćmowa barba kože',
    '🙇🏿‍♂' => 'muž, kiž so pokłoni: ćmowa barba kože',
    '🙇🏻‍♀' => 'žona, kiž so pokłoni: swětła barba kože',
    '🙇🏼‍♀' => 'žona, kiž so pokłoni: srěnjoswětła barba kože',
    '🙇🏽‍♀' => 'žona, kiž so pokłoni: srěnja barba kože',
    '🙇🏾‍♀' => 'žona, kiž so pokłoni: srěnjoćmowa barba kože',
    '🙇🏿‍♀' => 'žona, kiž so pokłoni: ćmowa barba kože',
    '🤦🏻‍♂' => 'muž, kiž so za hłowu přimnje: swětła barba kože',
    '🤦🏼‍♂' => 'muž, kiž so za hłowu přimnje: srěnjoswětła barba kože',
    '🤦🏽‍♂' => 'muž, kiž so za hłowu přimnje: srěnja barba kože',
    '🤦🏾‍♂' => 'muž, kiž so za hłowu přimnje: srěnjoćmowa barba kože',
    '🤦🏿‍♂' => 'muž, kiž so za hłowu přimnje: ćmowa barba kože',
    '🤦🏻‍♀' => 'žona, kiž so za hłowu přimnje: swětła barba kože',
    '🤦🏼‍♀' => 'žona, kiž so za hłowu přimnje: srěnjoswětła barba kože',
    '🤦🏽‍♀' => 'žona, kiž so za hłowu přimnje: srěnja barba kože',
    '🤦🏾‍♀' => 'žona, kiž so za hłowu přimnje: srěnjoćmowa barba kože',
    '🤦🏿‍♀' => 'žona, kiž so za hłowu přimnje: ćmowa barba kože',
    '🤷🏻‍♂' => 'muž, kiž z ramjenjomaj suknje: swětła barba kože',
    '🤷🏼‍♂' => 'muž, kiž z ramjenjomaj suknje: srěnjoswětła barba kože',
    '🤷🏽‍♂' => 'muž, kiž z ramjenjomaj suknje: srěnja barba kože',
    '🤷🏾‍♂' => 'muž, kiž z ramjenjomaj suknje: srěnjoćmowa barba kože',
    '🤷🏿‍♂' => 'muž, kiž z ramjenjomaj suknje: ćmowa barba kože',
    '🤷🏻‍♀' => 'žona, kiž z ramjenjomaj suknje: swětła barba kože',
    '🤷🏼‍♀' => 'žona, kiž z ramjenjomaj suknje: srěnjoswětła barba kože',
    '🤷🏽‍♀' => 'žona, kiž z ramjenjomaj suknje: srěnja barba kože',
    '🤷🏾‍♀' => 'žona, kiž z ramjenjomaj suknje: srěnjoćmowa barba kože',
    '🤷🏿‍♀' => 'žona, kiž z ramjenjomaj suknje: ćmowa barba kože',
    '🧑🏻‍⚕' => 'lěkar/ka: swětła barba kože',
    '🧑🏼‍⚕' => 'lěkar/ka: srěnjoswětła barba kože',
    '🧑🏽‍⚕' => 'lěkar/ka: srěnja barba kože',
    '🧑🏾‍⚕' => 'lěkar/ka: srěnjoćmowa barba kože',
    '🧑🏿‍⚕' => 'lěkar/ka: ćmowa barba kože',
    '👨🏻‍⚕' => 'lěkar: swětła barba kože',
    '👨🏼‍⚕' => 'lěkar: srěnjoswětła barba kože',
    '👨🏽‍⚕' => 'lěkar: srěnja barba kože',
    '👨🏾‍⚕' => 'lěkar: srěnjoćmowa barba kože',
    '👨🏿‍⚕' => 'lěkar: ćmowa barba kože',
    '👩🏻‍⚕' => 'lěkarka: swětła barba kože',
    '👩🏼‍⚕' => 'lěkarka: srěnjoswětła barba kože',
    '👩🏽‍⚕' => 'lěkarka: srěnja barba kože',
    '👩🏾‍⚕' => 'lěkarka: srěnjoćmowa barba kože',
    '👩🏿‍⚕' => 'lěkarka: ćmowa barba kože',
    '🧑🏻‍🎓' => 'student/ka: swětła barba kože',
    '🧑🏼‍🎓' => 'student/ka: srěnjoswětła barba kože',
    '🧑🏽‍🎓' => 'student/ka: srěnja barba kože',
    '🧑🏾‍🎓' => 'student/ka: srěnjoćmowa barba kože',
    '🧑🏿‍🎓' => 'student/ka: ćmowa barba kože',
    '👨🏻‍🎓' => 'student: swětła barba kože',
    '👨🏼‍🎓' => 'student: srěnjoswětła barba kože',
    '👨🏽‍🎓' => 'student: srěnja barba kože',
    '👨🏾‍🎓' => 'student: srěnjoćmowa barba kože',
    '👨🏿‍🎓' => 'student: ćmowa barba kože',
    '👩🏻‍🎓' => 'studentka: swětła barba kože',
    '👩🏼‍🎓' => 'studentka: srěnjoswětła barba kože',
    '👩🏽‍🎓' => 'studentka: srěnja barba kože',
    '👩🏾‍🎓' => 'studentka: srěnjoćmowa barba kože',
    '👩🏿‍🎓' => 'studentka: ćmowa barba kože',
    '🧑🏻‍🏫' => 'wučer/ka: swětła barba kože',
    '🧑🏼‍🏫' => 'wučer/ka: srěnjoswětła barba kože',
    '🧑🏽‍🏫' => 'wučer/ka: srěnja barba kože',
    '🧑🏾‍🏫' => 'wučer/ka: srěnjoćmowa barba kože',
    '🧑🏿‍🏫' => 'wučer/ka: ćmowa barba kože',
    '👨🏻‍🏫' => 'wučer: swětła barba kože',
    '👨🏼‍🏫' => 'wučer: srěnjoswětła barba kože',
    '👨🏽‍🏫' => 'wučer: srěnja barba kože',
    '👨🏾‍🏫' => 'wučer: srěnjoćmowa barba kože',
    '👨🏿‍🏫' => 'wučer: ćmowa barba kože',
    '👩🏻‍🏫' => 'wučerka: swětła barba kože',
    '👩🏼‍🏫' => 'wučerka: srěnjoswětła barba kože',
    '👩🏽‍🏫' => 'wučerka: srěnja barba kože',
    '👩🏾‍🏫' => 'wučerka: srěnjoćmowa barba kože',
    '👩🏿‍🏫' => 'wučerka: ćmowa barba kože',
    '🧑🏻‍⚖' => 'sudnik/ sudnica: swětła barba kože',
    '🧑🏼‍⚖' => 'sudnik/ sudnica: srěnjoswětła barba kože',
    '🧑🏽‍⚖' => 'sudnik/ sudnica: srěnja barba kože',
    '🧑🏾‍⚖' => 'sudnik/ sudnica: srěnjoćmowa barba kože',
    '🧑🏿‍⚖' => 'sudnik/ sudnica: ćmowa barba kože',
    '👨🏻‍⚖' => 'sudnik: swětła barba kože',
    '👨🏼‍⚖' => 'sudnik: srěnjoswětła barba kože',
    '👨🏽‍⚖' => 'sudnik: srěnja barba kože',
    '👨🏾‍⚖' => 'sudnik: srěnjoćmowa barba kože',
    '👨🏿‍⚖' => 'sudnik: ćmowa barba kože',
    '👩🏻‍⚖' => 'sudnica: swětła barba kože',
    '👩🏼‍⚖' => 'sudnica: srěnjoswětła barba kože',
    '👩🏽‍⚖' => 'sudnica: srěnja barba kože',
    '👩🏾‍⚖' => 'sudnica: srěnjoćmowa barba kože',
    '👩🏿‍⚖' => 'sudnica: ćmowa barba kože',
    '🧑🏻‍🌾' => 'bur/owka: swětła barba kože',
    '🧑🏼‍🌾' => 'bur/owka: srěnjoswětła barba kože',
    '🧑🏽‍🌾' => 'bur/owka: srěnja barba kože',
    '🧑🏾‍🌾' => 'bur/owka: srěnjoćmowa barba kože',
    '🧑🏿‍🌾' => 'bur/owka: ćmowa barba kože',
    '👨🏻‍🌾' => 'bur: swětła barba kože',
    '👨🏼‍🌾' => 'bur: srěnjoswětła barba kože',
    '👨🏽‍🌾' => 'bur: srěnja barba kože',
    '👨🏾‍🌾' => 'bur: srěnjoćmowa barba kože',
    '👨🏿‍🌾' => 'bur: ćmowa barba kože',
    '👩🏻‍🌾' => 'burowka: swětła barba kože',
    '👩🏼‍🌾' => 'burowka: srěnjoswětła barba kože',
    '👩🏽‍🌾' => 'burowka: srěnja barba kože',
    '👩🏾‍🌾' => 'burowka: srěnjoćmowa barba kože',
    '👩🏿‍🌾' => 'burowka: ćmowa barba kože',
    '🧑🏻‍🍳' => 'kuchar/ka: swětła barba kože',
    '🧑🏼‍🍳' => 'kuchar/ka: srěnjoswětła barba kože',
    '🧑🏽‍🍳' => 'kuchar/ka: srěnja barba kože',
    '🧑🏾‍🍳' => 'kuchar/ka: srěnjoćmowa barba kože',
    '🧑🏿‍🍳' => 'kuchar/ka: ćmowa barba kože',
    '👨🏻‍🍳' => 'kuchar: swětła barba kože',
    '👨🏼‍🍳' => 'kuchar: srěnjoswětła barba kože',
    '👨🏽‍🍳' => 'kuchar: srěnja barba kože',
    '👨🏾‍🍳' => 'kuchar: srěnjoćmowa barba kože',
    '👨🏿‍🍳' => 'kuchar: ćmowa barba kože',
    '👩🏻‍🍳' => 'kucharka: swětła barba kože',
    '👩🏼‍🍳' => 'kucharka: srěnjoswětła barba kože',
    '👩🏽‍🍳' => 'kucharka: srěnja barba kože',
    '👩🏾‍🍳' => 'kucharka: srěnjoćmowa barba kože',
    '👩🏿‍🍳' => 'kucharka: ćmowa barba kože',
    '🧑🏻‍🔧' => 'mechanikar/ka: swětła barba kože',
    '🧑🏼‍🔧' => 'mechanikar/ka: srěnjoswětła barba kože',
    '🧑🏽‍🔧' => 'mechanikar/ka: srěnja barba kože',
    '🧑🏾‍🔧' => 'mechanikar/ka: srěnjoćmowa barba kože',
    '🧑🏿‍🔧' => 'mechanikar/ka: ćmowa barba kože',
    '👨🏻‍🔧' => 'mechanikar: swětła barba kože',
    '👨🏼‍🔧' => 'mechanikar: srěnjoswětła barba kože',
    '👨🏽‍🔧' => 'mechanikar: srěnja barba kože',
    '👨🏾‍🔧' => 'mechanikar: srěnjoćmowa barba kože',
    '👨🏿‍🔧' => 'mechanikar: ćmowa barba kože',
    '👩🏻‍🔧' => 'mechanikarka: swětła barba kože',
    '👩🏼‍🔧' => 'mechanikarka: srěnjoswětła barba kože',
    '👩🏽‍🔧' => 'mechanikarka: srěnja barba kože',
    '👩🏾‍🔧' => 'mechanikarka: srěnjoćmowa barba kože',
    '👩🏿‍🔧' => 'mechanikarka: ćmowa barba kože',
    '🧑🏻‍🏭' => 'dźěłaćer/ka w fabrice: swětła barba kože',
    '🧑🏼‍🏭' => 'dźěłaćer/ka w fabrice: srěnjoswětła barba kože',
    '🧑🏽‍🏭' => 'dźěłaćer/ka w fabrice: srěnja barba kože',
    '🧑🏾‍🏭' => 'dźěłaćer/ka w fabrice: srěnjoćmowa barba kože',
    '🧑🏿‍🏭' => 'dźěłaćer/ka w fabrice: ćmowa barba kože',
    '👨🏻‍🏭' => 'dźěłaćer w fabrice: swětła barba kože',
    '👨🏼‍🏭' => 'dźěłaćer w fabrice: srěnjoswětła barba kože',
    '👨🏽‍🏭' => 'dźěłaćer w fabrice: srěnja barba kože',
    '👨🏾‍🏭' => 'dźěłaćer w fabrice: srěnjoćmowa barba kože',
    '👨🏿‍🏭' => 'dźěłaćer w fabrice: ćmowa barba kože',
    '👩🏻‍🏭' => 'dźěłaćerka w fabrice: swětła barba kože',
    '👩🏼‍🏭' => 'dźěłaćerka w fabrice: srěnjoswětła barba kože',
    '👩🏽‍🏭' => 'dźěłaćerka w fabrice: srěnja barba kože',
    '👩🏾‍🏭' => 'dźěłaćerka w fabrice: srěnjoćmowa barba kože',
    '👩🏿‍🏭' => 'dźěłaćerka w fabrice: ćmowa barba kože',
    '🧑🏻‍💼' => 'přistajeny/přistajena w běrowje: swětła barba kože',
    '🧑🏼‍💼' => 'přistajeny/přistajena w běrowje: srěnjoswětła barba kože',
    '🧑🏽‍💼' => 'přistajeny/přistajena w běrowje: srěnja barba kože',
    '🧑🏾‍💼' => 'přistajeny/přistajena w běrowje: srěnjoćmowa barba kože',
    '🧑🏿‍💼' => 'přistajeny/přistajena w běrowje: ćmowa barba kože',
    '👨🏻‍💼' => 'přistajeny w běrowje: swětła barba kože',
    '👨🏼‍💼' => 'přistajeny w běrowje: srěnjoswětła barba kože',
    '👨🏽‍💼' => 'přistajeny w běrowje: srěnja barba kože',
    '👨🏾‍💼' => 'přistajeny w běrowje: srěnjoćmowa barba kože',
    '👨🏿‍💼' => 'přistajeny w běrowje: ćmowa barba kože',
    '👩🏻‍💼' => 'přistajena w běrowje: swětła barba kože',
    '👩🏼‍💼' => 'přistajena w běrowje: srěnjoswětła barba kože',
    '👩🏽‍💼' => 'přistajena w běrowje: srěnja barba kože',
    '👩🏾‍💼' => 'přistajena w běrowje: srěnjoćmowa barba kože',
    '👩🏿‍💼' => 'přistajena w běrowje: ćmowa barba kože',
    '🧑🏻‍🔬' => 'wědomostnik/ wědomostnica: swětła barba kože',
    '🧑🏼‍🔬' => 'wědomostnik/ wědomostnica: srěnjoswětła barba kože',
    '🧑🏽‍🔬' => 'wědomostnik/ wědomostnica: srěnja barba kože',
    '🧑🏾‍🔬' => 'wědomostnik/ wědomostnica: srěnjoćmowa barba kože',
    '🧑🏿‍🔬' => 'wědomostnik/ wědomostnica: ćmowa barba kože',
    '👨🏻‍🔬' => 'wědomostnik: swětła barba kože',
    '👨🏼‍🔬' => 'wědomostnik: srěnjoswětła barba kože',
    '👨🏽‍🔬' => 'wědomostnik: srěnja barba kože',
    '👨🏾‍🔬' => 'wědomostnik: srěnjoćmowa barba kože',
    '👨🏿‍🔬' => 'wědomostnik: ćmowa barba kože',
    '👩🏻‍🔬' => 'wědomostnica: swětła barba kože',
    '👩🏼‍🔬' => 'wědomostnica: srěnjoswětła barba kože',
    '👩🏽‍🔬' => 'wědomostnica: srěnja barba kože',
    '👩🏾‍🔬' => 'wědomostnica: srěnjoćmowa barba kože',
    '👩🏿‍🔬' => 'wědomostnica: ćmowa barba kože',
    '🧑🏻‍💻' => 'technologa/technologowka: swětła barba kože',
    '🧑🏼‍💻' => 'technologa/technologowka: srěnjoswětła barba kože',
    '🧑🏽‍💻' => 'technologa/technologowka: srěnja barba kože',
    '🧑🏾‍💻' => 'technologa/technologowka: srěnjoćmowa barba kože',
    '🧑🏿‍💻' => 'technologa/technologowka: ćmowa barba kože',
    '👨🏻‍💻' => 'technologa: swětła barba kože',
    '👨🏼‍💻' => 'technologa: srěnjoswětła barba kože',
    '👨🏽‍💻' => 'technologa: srěnja barba kože',
    '👨🏾‍💻' => 'technologa: srěnjoćmowa barba kože',
    '👨🏿‍💻' => 'technologa: ćmowa barba kože',
    '👩🏻‍💻' => 'technologowka: swětła barba kože',
    '👩🏼‍💻' => 'technologowka: srěnjoswětła barba kože',
    '👩🏽‍💻' => 'technologowka: srěnja barba kože',
    '👩🏾‍💻' => 'technologowka: srěnjoćmowa barba kože',
    '👩🏿‍💻' => 'technologowka: ćmowa barba kože',
    '🧑🏻‍🎤' => 'spěwar/ka: swětła barba kože',
    '🧑🏼‍🎤' => 'spěwar/ka: srěnjoswětła barba kože',
    '🧑🏽‍🎤' => 'spěwar/ka: srěnja barba kože',
    '🧑🏾‍🎤' => 'spěwar/ka: srěnjoćmowa barba kože',
    '🧑🏿‍🎤' => 'spěwar/ka: ćmowa barba kože',
    '👨🏻‍🎤' => 'spěwar: swětła barba kože',
    '👨🏼‍🎤' => 'spěwar: srěnjoswětła barba kože',
    '👨🏽‍🎤' => 'spěwar: srěnja barba kože',
    '👨🏾‍🎤' => 'spěwar: srěnjoćmowa barba kože',
    '👨🏿‍🎤' => 'spěwar: ćmowa barba kože',
    '👩🏻‍🎤' => 'spěwarka: swětła barba kože',
    '👩🏼‍🎤' => 'spěwarka: srěnjoswětła barba kože',
    '👩🏽‍🎤' => 'spěwarka: srěnja barba kože',
    '👩🏾‍🎤' => 'spěwarka: srěnjoćmowa barba kože',
    '👩🏿‍🎤' => 'spěwarka: ćmowa barba kože',
    '🧑🏻‍🎨' => 'wuměłc/wuměłča: swětła barba kože',
    '🧑🏼‍🎨' => 'wuměłc/wuměłča: srěnjoswětła barba kože',
    '🧑🏽‍🎨' => 'wuměłc/wuměłča: srěnja barba kože',
    '🧑🏾‍🎨' => 'wuměłc/wuměłča: srěnjoćmowa barba kože',
    '🧑🏿‍🎨' => 'wuměłc/wuměłča: ćmowa barba kože',
    '👨🏻‍🎨' => 'wuměłc: swětła barba kože',
    '👨🏼‍🎨' => 'wuměłc: srěnjoswětła barba kože',
    '👨🏽‍🎨' => 'wuměłc: srěnja barba kože',
    '👨🏾‍🎨' => 'wuměłc: srěnjoćmowa barba kože',
    '👨🏿‍🎨' => 'wuměłc: ćmowa barba kože',
    '👩🏻‍🎨' => 'wuměłča: swětła barba kože',
    '👩🏼‍🎨' => 'wuměłča: srěnjoswětła barba kože',
    '👩🏽‍🎨' => 'wuměłča: srěnja barba kože',
    '👩🏾‍🎨' => 'wuměłča: srěnjoćmowa barba kože',
    '👩🏿‍🎨' => 'wuměłča: ćmowa barba kože',
    '🧑🏻‍✈' => 'pilot/ka: swětła barba kože',
    '🧑🏼‍✈' => 'pilot/ka: srěnjoswětła barba kože',
    '🧑🏽‍✈' => 'pilot/ka: srěnja barba kože',
    '🧑🏾‍✈' => 'pilot/ka: srěnjoćmowa barba kože',
    '🧑🏿‍✈' => 'pilot/ka: ćmowa barba kože',
    '👨🏻‍✈' => 'pilot: swětła barba kože',
    '👨🏼‍✈' => 'pilot: srěnjoswětła barba kože',
    '👨🏽‍✈' => 'pilot: srěnja barba kože',
    '👨🏾‍✈' => 'pilot: srěnjoćmowa barba kože',
    '👨🏿‍✈' => 'pilot: ćmowa barba kože',
    '👩🏻‍✈' => 'pilotka: swětła barba kože',
    '👩🏼‍✈' => 'pilotka: srěnjoswětła barba kože',
    '👩🏽‍✈' => 'pilotka: srěnja barba kože',
    '👩🏾‍✈' => 'pilotka: srěnjoćmowa barba kože',
    '👩🏿‍✈' => 'pilotka: ćmowa barba kože',
    '🧑🏻‍🚀' => 'astronawt/ka: swětła barba kože',
    '🧑🏼‍🚀' => 'astronawt/ka: srěnjoswětła barba kože',
    '🧑🏽‍🚀' => 'astronawt/ka: srěnja barba kože',
    '🧑🏾‍🚀' => 'astronawt/ka: srěnjoćmowa barba kože',
    '🧑🏿‍🚀' => 'astronawt/ka: ćmowa barba kože',
    '👨🏻‍🚀' => 'awstronawt: swětła barba kože',
    '👨🏼‍🚀' => 'awstronawt: srěnjoswětła barba kože',
    '👨🏽‍🚀' => 'awstronawt: srěnja barba kože',
    '👨🏾‍🚀' => 'awstronawt: srěnjoćmowa barba kože',
    '👨🏿‍🚀' => 'awstronawt: ćmowa barba kože',
    '👩🏻‍🚀' => 'astronawtka: swětła barba kože',
    '👩🏼‍🚀' => 'astronawtka: srěnjoswětła barba kože',
    '👩🏽‍🚀' => 'astronawtka: srěnja barba kože',
    '👩🏾‍🚀' => 'astronawtka: srěnjoćmowa barba kože',
    '👩🏿‍🚀' => 'astronawtka: ćmowa barba kože',
    '🧑🏻‍🚒' => 'wohnjowy wobornik/ wohnjowa wobornica: swětła barba kože',
    '🧑🏼‍🚒' => 'wohnjowy wobornik/ wohnjowa wobornica: srěnjoswětła barba kože',
    '🧑🏽‍🚒' => 'wohnjowy wobornik/ wohnjowa wobornica: srěnja barba kože',
    '🧑🏾‍🚒' => 'wohnjowy wobornik/ wohnjowa wobornica: srěnjoćmowa barba kože',
    '🧑🏿‍🚒' => 'wohnjowy wobornik/ wohnjowa wobornica: ćmowa barba kože',
    '👨🏻‍🚒' => 'wohnjowy wobornik: swětła barba kože',
    '👨🏼‍🚒' => 'wohnjowy wobornik: srěnjoswětła barba kože',
    '👨🏽‍🚒' => 'wohnjowy wobornik: srěnja barba kože',
    '👨🏾‍🚒' => 'wohnjowy wobornik: srěnjoćmowa barba kože',
    '👨🏿‍🚒' => 'wohnjowy wobornik: ćmowa barba kože',
    '👩🏻‍🚒' => 'wohnjowa wobornica: swětła barba kože',
    '👩🏼‍🚒' => 'wohnjowa wobornica: srěnjoswětła barba kože',
    '👩🏽‍🚒' => 'wohnjowa wobornica: srěnja barba kože',
    '👩🏾‍🚒' => 'wohnjowa wobornica: srěnjoćmowa barba kože',
    '👩🏿‍🚒' => 'wohnjowa wobornica: ćmowa barba kože',
    '👮🏻‍♂' => 'policist: swětła barba kože',
    '👮🏼‍♂' => 'policist: srěnjoswětła barba kože',
    '👮🏽‍♂' => 'policist: srěnja barba kože',
    '👮🏾‍♂' => 'policist: srěnjoćmowa barba kože',
    '👮🏿‍♂' => 'policist: ćmowa barba kože',
    '👮🏻‍♀' => 'policistka: swětła barba kože',
    '👮🏼‍♀' => 'policistka: srěnjoswětła barba kože',
    '👮🏽‍♀' => 'policistka: srěnja barba kože',
    '👮🏾‍♀' => 'policistka: srěnjoćmowa barba kože',
    '👮🏿‍♀' => 'policistka: ćmowa barba kože',
    '🕵🏻‍♂' => 'detektiw: swětła barba kože',
    '🕵🏼‍♂' => 'detektiw: srěnjoswětła barba kože',
    '🕵🏽‍♂' => 'detektiw: srěnja barba kože',
    '🕵🏾‍♂' => 'detektiw: srěnjoćmowa barba kože',
    '🕵🏿‍♂' => 'detektiw: ćmowa barba kože',
    '🕵🏻‍♀' => 'detektiwka: swětła barba kože',
    '🕵🏼‍♀' => 'detektiwka: srěnjoswětła barba kože',
    '🕵🏽‍♀' => 'detektiwka: srěnja barba kože',
    '🕵🏾‍♀' => 'detektiwka: srěnjoćmowa barba kože',
    '🕵🏿‍♀' => 'detektiwka: ćmowa barba kože',
    '💂🏻‍♂' => 'stražnik: swětła barba kože',
    '💂🏼‍♂' => 'stražnik: srěnjoswětła barba kože',
    '💂🏽‍♂' => 'stražnik: srěnja barba kože',
    '💂🏾‍♂' => 'stražnik: srěnjoćmowa barba kože',
    '💂🏿‍♂' => 'stražnik: ćmowa barba kože',
    '💂🏻‍♀' => 'stražnica: swětła barba kože',
    '💂🏼‍♀' => 'stražnica: srěnjoswětła barba kože',
    '💂🏽‍♀' => 'stražnica: srěnja barba kože',
    '💂🏾‍♀' => 'stražnica: srěnjoćmowa barba kože',
    '💂🏿‍♀' => 'stražnica: ćmowa barba kože',
    '👷🏻‍♂' => 'twarski dźěłaćer: swětła barba kože',
    '👷🏼‍♂' => 'twarski dźěłaćer: srěnjoswětła barba kože',
    '👷🏽‍♂' => 'twarski dźěłaćer: srěnja barba kože',
    '👷🏾‍♂' => 'twarski dźěłaćer: srěnjoćmowa barba kože',
    '👷🏿‍♂' => 'twarski dźěłaćer: ćmowa barba kože',
    '👷🏻‍♀' => 'twarska dźěłaćerka: swětła barba kože',
    '👷🏼‍♀' => 'twarska dźěłaćerka: srěnjoswětła barba kože',
    '👷🏽‍♀' => 'twarska dźěłaćerka: srěnja barba kože',
    '👷🏾‍♀' => 'twarska dźěłaćerka: srěnjoćmowa barba kože',
    '👷🏿‍♀' => 'twarska dźěłaćerka: ćmowa barba kože',
    '👳🏻‍♂' => 'muž z turbanom: swětła barba kože',
    '👳🏼‍♂' => 'muž z turbanom: srěnjoswětła barba kože',
    '👳🏽‍♂' => 'muž z turbanom: srěnja barba kože',
    '👳🏾‍♂' => 'muž z turbanom: srěnjoćmowa barba kože',
    '👳🏿‍♂' => 'muž z turbanom: ćmowa barba kože',
    '👳🏻‍♀' => 'žona z turbanom: swětła barba kože',
    '👳🏼‍♀' => 'žona z turbanom: srěnjoswětła barba kože',
    '👳🏽‍♀' => 'žona z turbanom: srěnja barba kože',
    '👳🏾‍♀' => 'žona z turbanom: srěnjoćmowa barba kože',
    '👳🏿‍♀' => 'žona z turbanom: ćmowa barba kože',
    '🤵🏻‍♂' => 'muž w smokingu: swětła barba kože',
    '🤵🏼‍♂' => 'muž w smokingu: srěnjoswětła barba kože',
    '🤵🏽‍♂' => 'muž w smokingu: srěnja barba kože',
    '🤵🏾‍♂' => 'muž w smokingu: srěnjoćmowa barba kože',
    '🤵🏿‍♂' => 'muž w smokingu: ćmowa barba kože',
    '🤵🏻‍♀' => 'žona w smokingu: swětła barba kože',
    '🤵🏼‍♀' => 'žona w smokingu: srěnjoswětła barba kože',
    '🤵🏽‍♀' => 'žona w smokingu: srěnja barba kože',
    '🤵🏾‍♀' => 'žona w smokingu: srěnjoćmowa barba kože',
    '🤵🏿‍♀' => 'žona w smokingu: ćmowa barba kože',
    '👰🏻‍♂' => 'muž ze šlewjerjom: swětła barba kože',
    '👰🏼‍♂' => 'muž ze šlewjerjom: srěnjoswětła barba kože',
    '👰🏽‍♂' => 'muž ze šlewjerjom: srěnja barba kože',
    '👰🏾‍♂' => 'muž ze šlewjerjom: srěnjoćmowa barba kože',
    '👰🏿‍♂' => 'muž ze šlewjerjom: ćmowa barba kože',
    '👰🏻‍♀' => 'žona ze šlewjerjom: swětła barba kože',
    '👰🏼‍♀' => 'žona ze šlewjerjom: srěnjoswětła barba kože',
    '👰🏽‍♀' => 'žona ze šlewjerjom: srěnja barba kože',
    '👰🏾‍♀' => 'žona ze šlewjerjom: srěnjoćmowa barba kože',
    '👰🏿‍♀' => 'žona ze šlewjerjom: ćmowa barba kože',
    '👩🏻‍🍼' => 'žona, kiž dawa ćěšenkej mloko: swětła barba kože',
    '👩🏼‍🍼' => 'žona, kiž dawa ćěšenkej mloko: srěnjoswětła barba kože',
    '👩🏽‍🍼' => 'žona, kiž dawa ćěšenkej mloko: srěnja barba kože',
    '👩🏾‍🍼' => 'žona, kiž dawa ćěšenkej mloko: srěnjoćmowa barba kože',
    '👩🏿‍🍼' => 'žona, kiž dawa ćěšenkej mloko: ćmowa barba kože',
    '👨🏻‍🍼' => 'muž, kiž dawa ćěšenkej mloko: swětła barba kože',
    '👨🏼‍🍼' => 'muž, kiž dawa ćěšenkej mloko: srěnjoswětła barba kože',
    '👨🏽‍🍼' => 'muž, kiž dawa ćěšenkej mloko: srěnja barba kože',
    '👨🏾‍🍼' => 'muž, kiž dawa ćěšenkej mloko: srěnjoćmowa barba kože',
    '👨🏿‍🍼' => 'muž, kiž dawa ćěšenkej mloko: ćmowa barba kože',
    '🧑🏻‍🍼' => 'wosoba, kiž dawa ćěšenkej mloko: swětła barba kože',
    '🧑🏼‍🍼' => 'wosoba, kiž dawa ćěšenkej mloko: srěnjoswětła barba kože',
    '🧑🏽‍🍼' => 'wosoba, kiž dawa ćěšenkej mloko: srěnja barba kože',
    '🧑🏾‍🍼' => 'wosoba, kiž dawa ćěšenkej mloko: srěnjoćmowa barba kože',
    '🧑🏿‍🍼' => 'wosoba, kiž dawa ćěšenkej mloko: ćmowa barba kože',
    '🧑🏻‍🎄' => 'hodowna wosoba: swětła barba kože',
    '🧑🏼‍🎄' => 'hodowna wosoba: srěnjoswětła barba kože',
    '🧑🏽‍🎄' => 'hodowna wosoba: srěnja barba kože',
    '🧑🏾‍🎄' => 'hodowna wosoba: srěnjoćmowa barba kože',
    '🧑🏿‍🎄' => 'hodowna wosoba: ćmowa barba kože',
    '🦸🏻‍♂' => 'superrjek: swětła barba kože',
    '🦸🏼‍♂' => 'superrjek: srěnjoswětła barba kože',
    '🦸🏽‍♂' => 'superrjek: srěnja barba kože',
    '🦸🏾‍♂' => 'superrjek: srěnjoćmowa barba kože',
    '🦸🏿‍♂' => 'superrjek: ćmowa barba kože',
    '🦸🏻‍♀' => 'superrjekowka: swětła barba kože',
    '🦸🏼‍♀' => 'superrjekowka: srěnjoswětła barba kože',
    '🦸🏽‍♀' => 'superrjekowka: srěnja barba kože',
    '🦸🏾‍♀' => 'superrjekowka: srěnjoćmowa barba kože',
    '🦸🏿‍♀' => 'superrjekowka: ćmowa barba kože',
    '🦹🏻‍♂' => 'superšamałc: swětła barba kože',
    '🦹🏼‍♂' => 'superšamałc: srěnjoswětła barba kože',
    '🦹🏽‍♂' => 'superšamałc: srěnja barba kože',
    '🦹🏾‍♂' => 'superšamałc: srěnjoćmowa barba kože',
    '🦹🏿‍♂' => 'superšamałc: ćmowa barba kože',
    '🦹🏻‍♀' => 'superšamałča: swětła barba kože',
    '🦹🏼‍♀' => 'superšamałča: srěnjoswětła barba kože',
    '🦹🏽‍♀' => 'superšamałča: srěnja barba kože',
    '🦹🏾‍♀' => 'superšamałča: srěnjoćmowa barba kože',
    '🦹🏿‍♀' => 'superšamałča: ćmowa barba kože',
    '🧙🏻‍♂' => 'kuzłar: swětła barba kože',
    '🧙🏼‍♂' => 'kuzłar: srěnjoswětła barba kože',
    '🧙🏽‍♂' => 'kuzłar: srěnja barba kože',
    '🧙🏾‍♂' => 'kuzłar: srěnjoćmowa barba kože',
    '🧙🏿‍♂' => 'kuzłar: ćmowa barba kože',
    '🧙🏻‍♀' => 'kuzłarniča: swětła barba kože',
    '🧙🏼‍♀' => 'kuzłarniča: srěnjoswětła barba kože',
    '🧙🏽‍♀' => 'kuzłarniča: srěnja barba kože',
    '🧙🏾‍♀' => 'kuzłarniča: srěnjoćmowa barba kože',
    '🧙🏿‍♀' => 'kuzłarniča: ćmowa barba kože',
    '🧚🏻‍♂' => 'muska sonina: swětła barba kože',
    '🧚🏼‍♂' => 'muska sonina: srěnjoswětła barba kože',
    '🧚🏽‍♂' => 'muska sonina: srěnja barba kože',
    '🧚🏾‍♂' => 'muska sonina: srěnjoćmowa barba kože',
    '🧚🏿‍♂' => 'muska sonina: ćmowa barba kože',
    '🧚🏻‍♀' => 'žónska sonina: swětła barba kože',
    '🧚🏼‍♀' => 'žónska sonina: srěnjoswětła barba kože',
    '🧚🏽‍♀' => 'žónska sonina: srěnja barba kože',
    '🧚🏾‍♀' => 'žónska sonina: srěnjoćmowa barba kože',
    '🧚🏿‍♀' => 'žónska sonina: ćmowa barba kože',
    '🧛🏻‍♂' => 'muski wampir: swětła barba kože',
    '🧛🏼‍♂' => 'muski wampir: srěnjoswětła barba kože',
    '🧛🏽‍♂' => 'muski wampir: srěnja barba kože',
    '🧛🏾‍♂' => 'muski wampir: srěnjoćmowa barba kože',
    '🧛🏿‍♂' => 'muski wampir: ćmowa barba kože',
    '🧛🏻‍♀' => 'žónski wampir: swětła barba kože',
    '🧛🏼‍♀' => 'žónski wampir: srěnjoswětła barba kože',
    '🧛🏽‍♀' => 'žónski wampir: srěnja barba kože',
    '🧛🏾‍♀' => 'žónski wampir: srěnjoćmowa barba kože',
    '🧛🏿‍♀' => 'žónski wampir: ćmowa barba kože',
    '🧜🏻‍♂' => 'wódny muž: swětła barba kože',
    '🧜🏼‍♂' => 'wódny muž: srěnjoswětła barba kože',
    '🧜🏽‍♂' => 'wódny muž: srěnja barba kože',
    '🧜🏾‍♂' => 'wódny muž: srěnjoćmowa barba kože',
    '🧜🏿‍♂' => 'wódny muž: ćmowa barba kože',
    '🧜🏻‍♀' => 'mórska knježna: swětła barba kože',
    '🧜🏼‍♀' => 'mórska knježna: srěnjoswětła barba kože',
    '🧜🏽‍♀' => 'mórska knježna: srěnja barba kože',
    '🧜🏾‍♀' => 'mórska knježna: srěnjoćmowa barba kože',
    '🧜🏿‍♀' => 'mórska knježna: ćmowa barba kože',
    '🧝🏻‍♂' => 'muski soninak: swětła barba kože',
    '🧝🏼‍♂' => 'muski soninak: srěnjoswětła barba kože',
    '🧝🏽‍♂' => 'muski soninak: srěnja barba kože',
    '🧝🏾‍♂' => 'muski soninak: srěnjoćmowa barba kože',
    '🧝🏿‍♂' => 'muski soninak: ćmowa barba kože',
    '🧝🏻‍♀' => 'žónski soninak: swětła barba kože',
    '🧝🏼‍♀' => 'žónski soninak: srěnjoswětła barba kože',
    '🧝🏽‍♀' => 'žónski soninak: srěnja barba kože',
    '🧝🏾‍♀' => 'žónski soninak: srěnjoćmowa barba kože',
    '🧝🏿‍♀' => 'žónski soninak: ćmowa barba kože',
    '💆🏻‍♂' => 'muž, kiž dóstanje masažu hłowy: swětła barba kože',
    '💆🏼‍♂' => 'muž, kiž dóstanje masažu hłowy: srěnjoswětła barba kože',
    '💆🏽‍♂' => 'muž, kiž dóstanje masažu hłowy: srěnja barba kože',
    '💆🏾‍♂' => 'muž, kiž dóstanje masažu hłowy: srěnjoćmowa barba kože',
    '💆🏿‍♂' => 'muž, kiž dóstanje masažu hłowy: ćmowa barba kože',
    '💆🏻‍♀' => 'žona, kiž dóstanje masažu hłowy: swětła barba kože',
    '💆🏼‍♀' => 'žona, kiž dóstanje masažu hłowy: srěnjoswětła barba kože',
    '💆🏽‍♀' => 'žona, kiž dóstanje masažu hłowy: srěnja barba kože',
    '💆🏾‍♀' => 'žona, kiž dóstanje masažu hłowy: srěnjoćmowa barba kože',
    '💆🏿‍♀' => 'žona, kiž dóstanje masažu hłowy: ćmowa barba kože',
    '💇🏻‍♂' => 'muž, kiž da sej włosy třihać: swětła barba kože',
    '💇🏼‍♂' => 'muž, kiž da sej włosy třihać: srěnjoswětła barba kože',
    '💇🏽‍♂' => 'muž, kiž da sej włosy třihać: srěnja barba kože',
    '💇🏾‍♂' => 'muž, kiž da sej włosy třihać: srěnjoćmowa barba kože',
    '💇🏿‍♂' => 'muž, kiž da sej włosy třihać: ćmowa barba kože',
    '💇🏻‍♀' => 'žona, kiž da sej włosy třihać: swětła barba kože',
    '💇🏼‍♀' => 'žona, kiž da sej włosy třihać: srěnjoswětła barba kože',
    '💇🏽‍♀' => 'žona, kiž da sej włosy třihać: srěnja barba kože',
    '💇🏾‍♀' => 'žona, kiž da sej włosy třihać: srěnjoćmowa barba kože',
    '💇🏿‍♀' => 'žona, kiž da sej włosy třihać: ćmowa barba kože',
    '🚶🏻‍♂' => 'pěšk: swětła barba kože',
    '🚶🏼‍♂' => 'pěšk: srěnjoswětła barba kože',
    '🚶🏽‍♂' => 'pěšk: srěnja barba kože',
    '🚶🏾‍♂' => 'pěšk: srěnjoćmowa barba kože',
    '🚶🏿‍♂' => 'pěšk: ćmowa barba kože',
    '🚶🏻‍♀' => 'pěška: swětła barba kože',
    '🚶🏼‍♀' => 'pěška: srěnjoswětła barba kože',
    '🚶🏽‍♀' => 'pěška: srěnja barba kože',
    '🚶🏾‍♀' => 'pěška: srěnjoćmowa barba kože',
    '🚶🏿‍♀' => 'pěška: ćmowa barba kože',
    '🚶🏻‍➡' => 'wosoba, kiž je pěši po puću: swětła barba kože, doprawa',
    '🚶🏼‍➡' => 'wosoba, kiž je pěši po puću: srěnjoswětła barba kože, doprawa',
    '🚶🏽‍➡' => 'wosoba, kiž je pěši po puću: srěnja barba kože, doprawa',
    '🚶🏾‍➡' => 'wosoba, kiž je pěši po puću: srěnjoćmowa barba kože, doprawa',
    '🚶🏿‍➡' => 'wosoba, kiž je pěši po puću: ćmowa barba kože, doprawa',
    '🧍🏻‍♂' => 'stejacy muž: swětła barba kože',
    '🧍🏼‍♂' => 'stejacy muž: srěnjoswětła barba kože',
    '🧍🏽‍♂' => 'stejacy muž: srěnja barba kože',
    '🧍🏾‍♂' => 'stejacy muž: srěnjoćmowa barba kože',
    '🧍🏿‍♂' => 'stejacy muž: ćmowa barba kože',
    '🧍🏻‍♀' => 'stejaca žona: swětła barba kože',
    '🧍🏼‍♀' => 'stejaca žona: srěnjoswětła barba kože',
    '🧍🏽‍♀' => 'stejaca žona: srěnja barba kože',
    '🧍🏾‍♀' => 'stejaca žona: srěnjoćmowa barba kože',
    '🧍🏿‍♀' => 'stejaca žona: ćmowa barba kože',
    '🧎🏻‍♂' => 'klečacy muž: swětła barba kože',
    '🧎🏼‍♂' => 'klečacy muž: srěnjoswětła barba kože',
    '🧎🏽‍♂' => 'klečacy muž: srěnja barba kože',
    '🧎🏾‍♂' => 'klečacy muž: srěnjoćmowa barba kože',
    '🧎🏿‍♂' => 'klečacy muž: ćmowa barba kože',
    '🧎🏻‍♀' => 'klečaca žona: swětła barba kože',
    '🧎🏼‍♀' => 'klečaca žona: srěnjoswětła barba kože',
    '🧎🏽‍♀' => 'klečaca žona: srěnja barba kože',
    '🧎🏾‍♀' => 'klečaca žona: srěnjoćmowa barba kože',
    '🧎🏿‍♀' => 'klečaca žona: ćmowa barba kože',
    '🧎🏻‍➡' => 'klečaca wosoba: swětła barba kože, doprawa',
    '🧎🏼‍➡' => 'klečaca wosoba: srěnjoswětła barba kože, doprawa',
    '🧎🏽‍➡' => 'klečaca wosoba: srěnja barba kože, doprawa',
    '🧎🏾‍➡' => 'klečaca wosoba: srěnjoćmowa barba kože, doprawa',
    '🧎🏿‍➡' => 'klečaca wosoba: ćmowa barba kože, doprawa',
    '🧑🏻‍🦯' => 'wosoba z kijom za slepych: swětła barba kože',
    '🧑🏼‍🦯' => 'wosoba z kijom za slepych: srěnjoswětła barba kože',
    '🧑🏽‍🦯' => 'wosoba z kijom za slepych: srěnja barba kože',
    '🧑🏾‍🦯' => 'wosoba z kijom za slepych: srěnjoćmowa barba kože',
    '🧑🏿‍🦯' => 'wosoba z kijom za slepych: ćmowa barba kože',
    '👨🏻‍🦯' => 'muž z kijom za slepych: swětła barba kože',
    '👨🏼‍🦯' => 'muž z kijom za slepych: srěnjoswětła barba kože',
    '👨🏽‍🦯' => 'muž z kijom za slepych: srěnja barba kože',
    '👨🏾‍🦯' => 'muž z kijom za slepych: srěnjoćmowa barba kože',
    '👨🏿‍🦯' => 'muž z kijom za slepych: ćmowa barba kože',
    '👩🏻‍🦯' => 'žona z kijom za slepych: swětła barba kože',
    '👩🏼‍🦯' => 'žona z kijom za slepych: srěnjoswětła barba kože',
    '👩🏽‍🦯' => 'žona z kijom za slepych: srěnja barba kože',
    '👩🏾‍🦯' => 'žona z kijom za slepych: srěnjoćmowa barba kože',
    '👩🏿‍🦯' => 'žona z kijom za slepych: ćmowa barba kože',
    '🧑🏻‍🦼' => 'wosoba w elektriskim jězbnym stole: swětła barba kože',
    '🧑🏼‍🦼' => 'wosoba w elektriskim jězbnym stole: srěnjoswětła barba kože',
    '🧑🏽‍🦼' => 'wosoba w elektriskim jězbnym stole: srěnja barba kože',
    '🧑🏾‍🦼' => 'wosoba w elektriskim jězbnym stole: srěnjoćmowa barba kože',
    '🧑🏿‍🦼' => 'wosoba w elektriskim jězbnym stole: ćmowa barba kože',
    '👨🏻‍🦼' => 'muž w elektriskim jězbnym stole: swětła barba kože',
    '👨🏼‍🦼' => 'muž w elektriskim jězbnym stole: srěnjoswětła barba kože',
    '👨🏽‍🦼' => 'muž w elektriskim jězbnym stole: srěnja barba kože',
    '👨🏾‍🦼' => 'muž w elektriskim jězbnym stole: srěnjoćmowa barba kože',
    '👨🏿‍🦼' => 'muž w elektriskim jězbnym stole: ćmowa barba kože',
    '👩🏻‍🦼' => 'žona w elektriskim jězbnym stole: swětła barba kože',
    '👩🏼‍🦼' => 'žona w elektriskim jězbnym stole: srěnjoswětła barba kože',
    '👩🏽‍🦼' => 'žona w elektriskim jězbnym stole: srěnja barba kože',
    '👩🏾‍🦼' => 'žona w elektriskim jězbnym stole: srěnjoćmowa barba kože',
    '👩🏿‍🦼' => 'žona w elektriskim jězbnym stole: ćmowa barba kože',
    '🧑🏻‍🦽' => 'wosoba w jězbnym stole: swětła barba kože',
    '🧑🏼‍🦽' => 'wosoba w jězbnym stole: srěnjoswětła barba kože',
    '🧑🏽‍🦽' => 'wosoba w jězbnym stole: srěnja barba kože',
    '🧑🏾‍🦽' => 'wosoba w jězbnym stole: srěnjoćmowa barba kože',
    '🧑🏿‍🦽' => 'wosoba w jězbnym stole: ćmowa barba kože',
    '👨🏻‍🦽' => 'muž w jězbnym stole: swětła barba kože',
    '👨🏼‍🦽' => 'muž w jězbnym stole: srěnjoswětła barba kože',
    '👨🏽‍🦽' => 'muž w jězbnym stole: srěnja barba kože',
    '👨🏾‍🦽' => 'muž w jězbnym stole: srěnjoćmowa barba kože',
    '👨🏿‍🦽' => 'muž w jězbnym stole: ćmowa barba kože',
    '👩🏻‍🦽' => 'žona w jězbnym stole: swětła barba kože',
    '👩🏼‍🦽' => 'žona w jězbnym stole: srěnjoswětła barba kože',
    '👩🏽‍🦽' => 'žona w jězbnym stole: srěnja barba kože',
    '👩🏾‍🦽' => 'žona w jězbnym stole: srěnjoćmowa barba kože',
    '👩🏿‍🦽' => 'žona w jězbnym stole: ćmowa barba kože',
    '🏃🏻‍♂' => 'běhacy muž: swětła barba kože',
    '🏃🏼‍♂' => 'běhacy muž: srěnjoswětła barba kože',
    '🏃🏽‍♂' => 'běhacy muž: srěnja barba kože',
    '🏃🏾‍♂' => 'běhacy muž: srěnjoćmowa barba kože',
    '🏃🏿‍♂' => 'běhacy muž: ćmowa barba kože',
    '🏃🏻‍♀' => 'běhaca žona: swětła barba kože',
    '🏃🏼‍♀' => 'běhaca žona: srěnjoswětła barba kože',
    '🏃🏽‍♀' => 'běhaca žona: srěnja barba kože',
    '🏃🏾‍♀' => 'běhaca žona: srěnjoćmowa barba kože',
    '🏃🏿‍♀' => 'běhaca žona: ćmowa barba kože',
    '🏃🏻‍➡' => 'běhaca wosoba: swětła barba kože, doprawa',
    '🏃🏼‍➡' => 'běhaca wosoba: srěnjoswětła barba kože, doprawa',
    '🏃🏽‍➡' => 'běhaca wosoba: srěnja barba kože, doprawa',
    '🏃🏾‍➡' => 'běhaca wosoba: srěnjoćmowa barba kože, doprawa',
    '🏃🏿‍➡' => 'běhaca wosoba: ćmowa barba kože, doprawa',
    '👯🏻‍♀' => 'žonje ze zaječimaj wušomaj: swětła barba kože',
    '👯🏼‍♀' => 'žonje ze zaječimaj wušomaj: srěnjoswětła barba kože',
    '👯🏽‍♀' => 'žonje ze zaječimaj wušomaj: srěnja barba kože',
    '👯🏾‍♀' => 'žonje ze zaječimaj wušomaj: srěnjoćmowa barba kože',
    '👯🏿‍♀' => 'žonje ze zaječimaj wušomaj: ćmowa barba kože',
    '👯🏻‍♂' => 'mužej ze zaječimaj wušomaj: swětła barba kože',
    '👯🏼‍♂' => 'mužej ze zaječimaj wušomaj: srěnjoswětła barba kože',
    '👯🏽‍♂' => 'mužej ze zaječimaj wušomaj: srěnja barba kože',
    '👯🏾‍♂' => 'mužej ze zaječimaj wušomaj: srěnjoćmowa barba kože',
    '👯🏿‍♂' => 'mužej ze zaječimaj wušomaj: ćmowa barba kože',
    '🧖🏻‍♂' => 'muž w sawnje: swětła barba kože',
    '🧖🏼‍♂' => 'muž w sawnje: srěnjoswětła barba kože',
    '🧖🏽‍♂' => 'muž w sawnje: srěnja barba kože',
    '🧖🏾‍♂' => 'muž w sawnje: srěnjoćmowa barba kože',
    '🧖🏿‍♂' => 'muž w sawnje: ćmowa barba kože',
    '🧖🏻‍♀' => 'žona w sawnje: swětła barba kože',
    '🧖🏼‍♀' => 'žona w sawnje: srěnjoswětła barba kože',
    '🧖🏽‍♀' => 'žona w sawnje: srěnja barba kože',
    '🧖🏾‍♀' => 'žona w sawnje: srěnjoćmowa barba kože',
    '🧖🏿‍♀' => 'žona w sawnje: ćmowa barba kože',
    '🧗🏻‍♂' => 'krosnowar: swětła barba kože',
    '🧗🏼‍♂' => 'krosnowar: srěnjoswětła barba kože',
    '🧗🏽‍♂' => 'krosnowar: srěnja barba kože',
    '🧗🏾‍♂' => 'krosnowar: srěnjoćmowa barba kože',
    '🧗🏿‍♂' => 'krosnowar: ćmowa barba kože',
    '🧗🏻‍♀' => 'krosnowarka: swětła barba kože',
    '🧗🏼‍♀' => 'krosnowarka: srěnjoswětła barba kože',
    '🧗🏽‍♀' => 'krosnowarka: srěnja barba kože',
    '🧗🏾‍♀' => 'krosnowarka: srěnjoćmowa barba kože',
    '🧗🏿‍♀' => 'krosnowarka: ćmowa barba kože',
    '🏌🏻‍♂' => 'hrajer golfa: swětła barba kože',
    '🏌🏼‍♂' => 'hrajer golfa: srěnjoswětła barba kože',
    '🏌🏽‍♂' => 'hrajer golfa: srěnja barba kože',
    '🏌🏾‍♂' => 'hrajer golfa: srěnjoćmowa barba kože',
    '🏌🏿‍♂' => 'hrajer golfa: ćmowa barba kože',
    '🏌🏻‍♀' => 'hrajerka golfa: swětła barba kože',
    '🏌🏼‍♀' => 'hrajerka golfa: srěnjoswětła barba kože',
    '🏌🏽‍♀' => 'hrajerka golfa: srěnja barba kože',
    '🏌🏾‍♀' => 'hrajerka golfa: srěnjoćmowa barba kože',
    '🏌🏿‍♀' => 'hrajerka golfa: ćmowa barba kože',
    '🏄🏻‍♂' => 'surfowar: swětła barba kože',
    '🏄🏼‍♂' => 'surfowar: srěnjoswětła barba kože',
    '🏄🏽‍♂' => 'surfowar: srěnja barba kože',
    '🏄🏾‍♂' => 'surfowar: srěnjoćmowa barba kože',
    '🏄🏿‍♂' => 'surfowar: ćmowa barba kože',
    '🏄🏻‍♀' => 'surfowarka: swětła barba kože',
    '🏄🏼‍♀' => 'surfowarka: srěnjoswětła barba kože',
    '🏄🏽‍♀' => 'surfowarka: srěnja barba kože',
    '🏄🏾‍♀' => 'surfowarka: srěnjoćmowa barba kože',
    '🏄🏿‍♀' => 'surfowarka: ćmowa barba kože',
    '🚣🏻‍♂' => 'wjesłowar: swětła barba kože',
    '🚣🏼‍♂' => 'wjesłowar: srěnjoswětła barba kože',
    '🚣🏽‍♂' => 'wjesłowar: srěnja barba kože',
    '🚣🏾‍♂' => 'wjesłowar: srěnjoćmowa barba kože',
    '🚣🏿‍♂' => 'wjesłowar: ćmowa barba kože',
    '🚣🏻‍♀' => 'wjesłowarka: swětła barba kože',
    '🚣🏼‍♀' => 'wjesłowarka: srěnjoswětła barba kože',
    '🚣🏽‍♀' => 'wjesłowarka: srěnja barba kože',
    '🚣🏾‍♀' => 'wjesłowarka: srěnjoćmowa barba kože',
    '🚣🏿‍♀' => 'wjesłowarka: ćmowa barba kože',
    '🏊🏻‍♂' => 'płuwar: swětła barba kože',
    '🏊🏼‍♂' => 'płuwar: srěnjoswětła barba kože',
    '🏊🏽‍♂' => 'płuwar: srěnja barba kože',
    '🏊🏾‍♂' => 'płuwar: srěnjoćmowa barba kože',
    '🏊🏿‍♂' => 'płuwar: ćmowa barba kože',
    '🏊🏻‍♀' => 'płuwarka: swětła barba kože',
    '🏊🏼‍♀' => 'płuwarka: srěnjoswětła barba kože',
    '🏊🏽‍♀' => 'płuwarka: srěnja barba kože',
    '🏊🏾‍♀' => 'płuwarka: srěnjoćmowa barba kože',
    '🏊🏿‍♀' => 'płuwarka: ćmowa barba kože',
    '⛹🏻‍♂' => 'muž z bulom: swětła barba kože',
    '⛹🏼‍♂' => 'muž z bulom: srěnjoswětła barba kože',
    '⛹🏽‍♂' => 'muž z bulom: srěnja barba kože',
    '⛹🏾‍♂' => 'muž z bulom: srěnjoćmowa barba kože',
    '⛹🏿‍♂' => 'muž z bulom: ćmowa barba kože',
    '⛹🏻‍♀' => 'žona z bulom: swětła barba kože',
    '⛹🏼‍♀' => 'žona z bulom: srěnjoswětła barba kože',
    '⛹🏽‍♀' => 'žona z bulom: srěnja barba kože',
    '⛹🏾‍♀' => 'žona z bulom: srěnjoćmowa barba kože',
    '⛹🏿‍♀' => 'žona z bulom: ćmowa barba kože',
    '🏋🏻‍♂' => 'zběhar wahow: swětła barba kože',
    '🏋🏼‍♂' => 'zběhar wahow: srěnjoswětła barba kože',
    '🏋🏽‍♂' => 'zběhar wahow: srěnja barba kože',
    '🏋🏾‍♂' => 'zběhar wahow: srěnjoćmowa barba kože',
    '🏋🏿‍♂' => 'zběhar wahow: ćmowa barba kože',
    '🏋🏻‍♀' => 'zběharka wahow: swětła barba kože',
    '🏋🏼‍♀' => 'zběharka wahow: srěnjoswětła barba kože',
    '🏋🏽‍♀' => 'zběharka wahow: srěnja barba kože',
    '🏋🏾‍♀' => 'zběharka wahow: srěnjoćmowa barba kože',
    '🏋🏿‍♀' => 'zběharka wahow: ćmowa barba kože',
    '🚴🏻‍♂' => 'kolesowar: swětła barba kože',
    '🚴🏼‍♂' => 'kolesowar: srěnjoswětła barba kože',
    '🚴🏽‍♂' => 'kolesowar: srěnja barba kože',
    '🚴🏾‍♂' => 'kolesowar: srěnjoćmowa barba kože',
    '🚴🏿‍♂' => 'kolesowar: ćmowa barba kože',
    '🚴🏻‍♀' => 'kolesowarka: swětła barba kože',
    '🚴🏼‍♀' => 'kolesowarka: srěnjoswětła barba kože',
    '🚴🏽‍♀' => 'kolesowarka: srěnja barba kože',
    '🚴🏾‍♀' => 'kolesowarka: srěnjoćmowa barba kože',
    '🚴🏿‍♀' => 'kolesowarka: ćmowa barba kože',
    '🚵🏻‍♂' => 'mountainbiker: swětła barba kože',
    '🚵🏼‍♂' => 'mountainbiker: srěnjoswětła barba kože',
    '🚵🏽‍♂' => 'mountainbiker: srěnja barba kože',
    '🚵🏾‍♂' => 'mountainbiker: srěnjoćmowa barba kože',
    '🚵🏿‍♂' => 'mountainbiker: ćmowa barba kože',
    '🚵🏻‍♀' => 'mountainbikerka: swětła barba kože',
    '🚵🏼‍♀' => 'mountainbikerka: srěnjoswětła barba kože',
    '🚵🏽‍♀' => 'mountainbikerka: srěnja barba kože',
    '🚵🏾‍♀' => 'mountainbikerka: srěnjoćmowa barba kože',
    '🚵🏿‍♀' => 'mountainbikerka: ćmowa barba kože',
    '🤸🏻‍♂' => 'muž, kiž so nabok přemjetuje: swětła barba kože',
    '🤸🏼‍♂' => 'muž, kiž so nabok přemjetuje: srěnjoswětła barba kože',
    '🤸🏽‍♂' => 'muž, kiž so nabok přemjetuje: srěnja barba kože',
    '🤸🏾‍♂' => 'muž, kiž so nabok přemjetuje: srěnjoćmowa barba kože',
    '🤸🏿‍♂' => 'muž, kiž so nabok přemjetuje: ćmowa barba kože',
    '🤸🏻‍♀' => 'žona, kiž so nabok přemjetuje: swětła barba kože',
    '🤸🏼‍♀' => 'žona, kiž so nabok přemjetuje: srěnjoswětła barba kože',
    '🤸🏽‍♀' => 'žona, kiž so nabok přemjetuje: srěnja barba kože',
    '🤸🏾‍♀' => 'žona, kiž so nabok přemjetuje: srěnjoćmowa barba kože',
    '🤸🏿‍♀' => 'žona, kiž so nabok přemjetuje: ćmowa barba kože',
    '🤼🏻‍♀' => 'wjerharce: swětła barba kože',
    '🤼🏼‍♀' => 'wjerharce: srěnjoswětła barba kože',
    '🤼🏽‍♀' => 'wjerharce: srěnja barba kože',
    '🤼🏾‍♀' => 'wjerharce: srěnjoćmowa barba kože',
    '🤼🏿‍♀' => 'wjerharce: ćmowa barba kože',
    '🤼🏻‍♂' => 'wjerharjej: swětła barba kože',
    '🤼🏼‍♂' => 'wjerharjej: srěnjoswětła barba kože',
    '🤼🏽‍♂' => 'wjerharjej: srěnja barba kože',
    '🤼🏾‍♂' => 'wjerharjej: srěnjoćmowa barba kože',
    '🤼🏿‍♂' => 'wjerharjej: ćmowa barba kože',
    '🤽🏻‍♂' => 'hrajer wodobula: swětła barba kože',
    '🤽🏼‍♂' => 'hrajer wodobula: srěnjoswětła barba kože',
    '🤽🏽‍♂' => 'hrajer wodobula: srěnja barba kože',
    '🤽🏾‍♂' => 'hrajer wodobula: srěnjoćmowa barba kože',
    '🤽🏿‍♂' => 'hrajer wodobula: ćmowa barba kože',
    '🤽🏻‍♀' => 'hrajerka wodobula: swětła barba kože',
    '🤽🏼‍♀' => 'hrajerka wodobula: srěnjoswětła barba kože',
    '🤽🏽‍♀' => 'hrajerka wodobula: srěnja barba kože',
    '🤽🏾‍♀' => 'hrajerka wodobula: srěnjoćmowa barba kože',
    '🤽🏿‍♀' => 'hrajerka wodobula: ćmowa barba kože',
    '🤾🏻‍♂' => 'mjetar: swětła barba kože',
    '🤾🏼‍♂' => 'mjetar: srěnjoswětła barba kože',
    '🤾🏽‍♂' => 'mjetar: srěnja barba kože',
    '🤾🏾‍♂' => 'mjetar: srěnjoćmowa barba kože',
    '🤾🏿‍♂' => 'mjetar: ćmowa barba kože',
    '🤾🏻‍♀' => 'mjetarka: swětła barba kože',
    '🤾🏼‍♀' => 'mjetarka: srěnjoswětła barba kože',
    '🤾🏽‍♀' => 'mjetarka: srěnja barba kože',
    '🤾🏾‍♀' => 'mjetarka: srěnjoćmowa barba kože',
    '🤾🏿‍♀' => 'mjetarka: ćmowa barba kože',
    '🤹🏻‍♂' => 'žongler: swětła barba kože',
    '🤹🏼‍♂' => 'žongler: srěnjoswětła barba kože',
    '🤹🏽‍♂' => 'žongler: srěnja barba kože',
    '🤹🏾‍♂' => 'žongler: srěnjoćmowa barba kože',
    '🤹🏿‍♂' => 'žongler: ćmowa barba kože',
    '🤹🏻‍♀' => 'žonglerka: swětła barba kože',
    '🤹🏼‍♀' => 'žonglerka: srěnjoswětła barba kože',
    '🤹🏽‍♀' => 'žonglerka: srěnja barba kože',
    '🤹🏾‍♀' => 'žonglerka: srěnjoćmowa barba kože',
    '🤹🏿‍♀' => 'žonglerka: ćmowa barba kože',
    '🧘🏻‍♂' => 'muž w lotosowym sydźe: swětła barba kože',
    '🧘🏼‍♂' => 'muž w lotosowym sydźe: srěnjoswětła barba kože',
    '🧘🏽‍♂' => 'muž w lotosowym sydźe: srěnja barba kože',
    '🧘🏾‍♂' => 'muž w lotosowym sydźe: srěnjoćmowa barba kože',
    '🧘🏿‍♂' => 'muž w lotosowym sydźe: ćmowa barba kože',
    '🧘🏻‍♀' => 'žona w lotosowym sydźe: swětła barba kože',
    '🧘🏼‍♀' => 'žona w lotosowym sydźe: srěnjoswětła barba kože',
    '🧘🏽‍♀' => 'žona w lotosowym sydźe: srěnja barba kože',
    '🧘🏾‍♀' => 'žona w lotosowym sydźe: srěnjoćmowa barba kože',
    '🧘🏿‍♀' => 'žona w lotosowym sydźe: ćmowa barba kože',
    '🧑‍🦰' => 'dorosćeny: čerwjene włosy',
    '🧑‍🦱' => 'dorosćeny: kudźerjate włosy',
    '🧑‍🦳' => 'dorosćeny: šědźiwe włosy',
    '🧑‍🦲' => 'dorosćeny: plěch',
    '👨‍🦰' => 'muž: čerwjene włosy',
    '👨‍🦱' => 'muž: kudźerjate włosy',
    '👨‍🦳' => 'muž: šědźiwe włosy',
    '👨‍🦲' => 'muž: plěch',
    '👩‍🦰' => 'žona: čerwjene włosy',
    '👩‍🦱' => 'žona: kudźerjate włosy',
    '👩‍🦳' => 'žona: šědźiwe włosy',
    '👩‍🦲' => 'žona: plěch',
    '🚶‍➡' => 'wosoba, kiž je pěši po puću: doprawa',
    '🧎‍➡' => 'klečaca wosoba: doprawa',
    '🏃‍➡' => 'běhaca wosoba: doprawa',
    '👨‍👦' => 'swójba: muž, hólc',
    '👨‍👧' => 'swójba: muž, holca',
    '👩‍👦' => 'swójba: žona, hólc',
    '👩‍👧' => 'swójba: žona, holca',
    '😶‍🌫' => 'wobličo w mróčelach',
    '😮‍💨' => 'wobličo, kiž wudycha',
    '🙂‍↕' => 'wobličo, kiž nyga',
    '😵‍💫' => 'wobličo ze spiralojtymaj wočomaj',
    '❤‍🔥' => 'wutrobička so pali',
    '❤‍🩹' => 'wutrobu hojić',
    '👁‍🗨' => 'wóčko w rěčnym pucherju',
    '🧔‍♂' => 'muž: broda',
    '👱‍♂' => 'muž: blond włosy',
    '🧔‍♀' => 'žona: broda',
    '👱‍♀' => 'žona: blond włosy',
    '🙍‍♂' => 'muž, kiž moršći čoło',
    '🙍‍♀' => 'žona, kiž moršći čoło',
    '🙎‍♂' => 'muž, kiž kózlika wjaza',
    '🙎‍♀' => 'žona, kiž kózlika wjaza',
    '🙅‍♂' => 'muž z překřižowanymaj rukomaj',
    '🙅‍♀' => 'žona z překřižowanymaj rukomaj',
    '🙆‍♂' => 'muž z rukomaj na hłowje',
    '🙆‍♀' => 'žona z rukomaj na hłowje',
    '💁‍♂' => 'muž z dłónju horje',
    '💁‍♀' => 'žona z dłónju horje',
    '🙋‍♂' => 'muž ze zběhnjenej ruku',
    '🙋‍♀' => 'žona ze zběhnjenej ruku',
    '🧏‍♂' => 'hłuchi muž',
    '🧏‍♀' => 'hłucha žona',
    '🙇‍♂' => 'muž, kiž so pokłoni',
    '🙇‍♀' => 'žona, kiž so pokłoni',
    '🤦‍♂' => 'muž, kiž so za hłowu přimnje',
    '🤦‍♀' => 'žona, kiž so za hłowu přimnje',
    '🤷‍♂' => 'muž, kiž z ramjenjomaj suknje',
    '🤷‍♀' => 'žona, kiž z ramjenjomaj suknje',
    '🧑‍⚕' => 'lěkar/ka',
    '👨‍⚕' => 'lěkar',
    '👩‍⚕' => 'lěkarka',
    '🧑‍🎓' => 'student/ka',
    '👨‍🎓' => 'student',
    '👩‍🎓' => 'studentka',
    '🧑‍🏫' => 'wučer/ka',
    '👨‍🏫' => 'wučer',
    '👩‍🏫' => 'wučerka',
    '🧑‍⚖' => 'sudnik/ sudnica',
    '👨‍⚖' => 'sudnik',
    '👩‍⚖' => 'sudnica',
    '🧑‍🌾' => 'bur/owka',
    '👨‍🌾' => 'bur',
    '👩‍🌾' => 'burowka',
    '🧑‍🍳' => 'kuchar/ka',
    '👨‍🍳' => 'kuchar',
    '👩‍🍳' => 'kucharka',
    '🧑‍🔧' => 'mechanikar/ka',
    '👨‍🔧' => 'mechanikar',
    '👩‍🔧' => 'mechanikarka',
    '🧑‍🏭' => 'dźěłaćer/ka w fabrice',
    '👨‍🏭' => 'dźěłaćer w fabrice',
    '👩‍🏭' => 'dźěłaćerka w fabrice',
    '🧑‍💼' => 'přistajeny/přistajena w běrowje',
    '👨‍💼' => 'přistajeny w běrowje',
    '👩‍💼' => 'přistajena w běrowje',
    '🧑‍🔬' => 'wědomostnik/ wědomostnica',
    '👨‍🔬' => 'wědomostnik',
    '👩‍🔬' => 'wědomostnica',
    '🧑‍💻' => 'technologa/technologowka',
    '👨‍💻' => 'technologa',
    '👩‍💻' => 'technologowka',
    '🧑‍🎤' => 'spěwar/ka',
    '👨‍🎤' => 'spěwar',
    '👩‍🎤' => 'spěwarka',
    '🧑‍🎨' => 'wuměłc/wuměłča',
    '👨‍🎨' => 'wuměłc',
    '👩‍🎨' => 'wuměłča',
    '🧑‍✈' => 'pilot/ka',
    '👨‍✈' => 'pilot',
    '👩‍✈' => 'pilotka',
    '🧑‍🚀' => 'astronawt/ka',
    '👨‍🚀' => 'awstronawt',
    '👩‍🚀' => 'astronawtka',
    '🧑‍🚒' => 'wohnjowy wobornik/ wohnjowa wobornica',
    '👨‍🚒' => 'wohnjowy wobornik',
    '👩‍🚒' => 'wohnjowa wobornica',
    '👮‍♂' => 'policist',
    '👮‍♀' => 'policistka',
    '🕵‍♂' => 'detektiw',
    '🕵‍♀' => 'detektiwka',
    '💂‍♂' => 'stražnik',
    '💂‍♀' => 'stražnica',
    '👷‍♂' => 'twarski dźěłaćer',
    '👷‍♀' => 'twarska dźěłaćerka',
    '👳‍♂' => 'muž z turbanom',
    '👳‍♀' => 'žona z turbanom',
    '🤵‍♂' => 'muž w smokingu',
    '🤵‍♀' => 'žona w smokingu',
    '👰‍♂' => 'muž ze šlewjerjom',
    '👰‍♀' => 'žona ze šlewjerjom',
    '👩‍🍼' => 'žona, kiž dawa ćěšenkej mloko',
    '👨‍🍼' => 'muž, kiž dawa ćěšenkej mloko',
    '🧑‍🍼' => 'wosoba, kiž dawa ćěšenkej mloko',
    '🧑‍🎄' => 'hodowna wosoba',
    '🦸‍♂' => 'superrjek',
    '🦸‍♀' => 'superrjekowka',
    '🦹‍♂' => 'superšamałc',
    '🦹‍♀' => 'superšamałča',
    '🧙‍♂' => 'kuzłar',
    '🧙‍♀' => 'kuzłarniča',
    '🧚‍♂' => 'muska sonina',
    '🧚‍♀' => 'žónska sonina',
    '🧛‍♂' => 'muski wampir',
    '🧛‍♀' => 'žónski wampir',
    '🧜‍♂' => 'wódny muž',
    '🧜‍♀' => 'mórska knježna',
    '🧝‍♂' => 'muski soninak',
    '🧝‍♀' => 'žónski soninak',
    '🧞‍♂' => 'muski duch z bleše',
    '🧞‍♀' => 'žónski duch z bleše',
    '🧟‍♂' => 'muski zombie',
    '🧟‍♀' => 'žónski zombie',
    '💆‍♂' => 'muž, kiž dóstanje masažu hłowy',
    '💆‍♀' => 'žona, kiž dóstanje masažu hłowy',
    '💇‍♂' => 'muž, kiž da sej włosy třihać',
    '💇‍♀' => 'žona, kiž da sej włosy třihać',
    '🚶‍♂' => 'pěšk',
    '🚶‍♀' => 'pěška',
    '🧍‍♂' => 'stejacy muž',
    '🧍‍♀' => 'stejaca žona',
    '🧎‍♂' => 'klečacy muž',
    '🧎‍♀' => 'klečaca žona',
    '🧑‍🦯' => 'wosoba z kijom za slepych',
    '👨‍🦯' => 'muž z kijom za slepych',
    '👩‍🦯' => 'žona z kijom za slepych',
    '🧑‍🦼' => 'wosoba w elektriskim jězbnym stole',
    '👨‍🦼' => 'muž w elektriskim jězbnym stole',
    '👩‍🦼' => 'žona w elektriskim jězbnym stole',
    '🧑‍🦽' => 'wosoba w jězbnym stole',
    '👨‍🦽' => 'muž w jězbnym stole',
    '👩‍🦽' => 'žona w jězbnym stole',
    '🏃‍♂' => 'běhacy muž',
    '🏃‍♀' => 'běhaca žona',
    '🧑‍🩰' => 'baletowa rejowarka',
    '👯‍♂' => 'mužej ze zaječimaj wušomaj',
    '👯‍♀' => 'žonje ze zaječimaj wušomaj',
    '🧖‍♂' => 'muž w sawnje',
    '🧖‍♀' => 'žona w sawnje',
    '🧗‍♂' => 'krosnowar',
    '🧗‍♀' => 'krosnowarka',
    '🏌‍♂' => 'hrajer golfa',
    '🏌‍♀' => 'hrajerka golfa',
    '🏄‍♂' => 'surfowar',
    '🏄‍♀' => 'surfowarka',
    '🚣‍♂' => 'wjesłowar',
    '🚣‍♀' => 'wjesłowarka',
    '🏊‍♂' => 'płuwar',
    '🏊‍♀' => 'płuwarka',
    '⛹‍♂' => 'muž z bulom',
    '⛹‍♀' => 'žona z bulom',
    '🏋‍♂' => 'zběhar wahow',
    '🏋‍♀' => 'zběharka wahow',
    '🚴‍♂' => 'kolesowar',
    '🚴‍♀' => 'kolesowarka',
    '🚵‍♂' => 'mountainbiker',
    '🚵‍♀' => 'mountainbikerka',
    '🤸‍♂' => 'muž, kiž so nabok přemjetuje',
    '🤸‍♀' => 'žona, kiž so nabok přemjetuje',
    '🤼‍♂' => 'wjerharjej',
    '🤼‍♀' => 'wjerharce',
    '🤽‍♂' => 'hrajer wodobula',
    '🤽‍♀' => 'hrajerka wodobula',
    '🤾‍♂' => 'mjetar',
    '🤾‍♀' => 'mjetarka',
    '🤹‍♂' => 'žongler',
    '🤹‍♀' => 'žonglerka',
    '🧘‍♂' => 'muž w lotosowym sydźe',
    '🧘‍♀' => 'žona w lotosowym sydźe',
    '🧑‍🧒' => 'swójba: dorosćeny a dźěćo',
    '🐕‍🦺' => 'słužbny pos',
    '🐈‍⬛' => 'čorna kóčka',
    '🐻‍❄' => 'hłowa běłeho mjedwjedźa',
    '🐦‍⬛' => 'čorny ptačk',
    '🐦‍🔥' => 'feniks',
    '🍋‍🟩' => 'limona',
    '🍄‍🟫' => 'bruny hrib',
    '⛓‍💥' => 'roztorhnjeny rjećaz',
    '🏳‍🌈' => 'tučelojta chorhojčka',
    '🏳‍⚧' => 'transgender-chorhojčka',
    '🏴‍☠' => 'piratowska chorhojčka',
    '👋🏻' => 'kiwaca ruka: swětła barba kože',
    '👋🏼' => 'kiwaca ruka: srěnjoswětła barba kože',
    '👋🏽' => 'kiwaca ruka: srěnja barba kože',
    '👋🏾' => 'kiwaca ruka: srěnjoćmowa barba kože',
    '👋🏿' => 'kiwaca ruka: ćmowa barba kože',
    '🤚🏻' => 'zběhnjena ruka wotzady: swětła barba kože',
    '🤚🏼' => 'zběhnjena ruka wotzady: srěnjoswětła barba kože',
    '🤚🏽' => 'zběhnjena ruka wotzady: srěnja barba kože',
    '🤚🏾' => 'zběhnjena ruka wotzady: srěnjoćmowa barba kože',
    '🤚🏿' => 'zběhnjena ruka wotzady: ćmowa barba kože',
    '🖐🏻' => 'ruka z rozšěrjenymi porstami: swětła barba kože',
    '🖐🏼' => 'ruka z rozšěrjenymi porstami: srěnjoswětła barba kože',
    '🖐🏽' => 'ruka z rozšěrjenymi porstami: srěnja barba kože',
    '🖐🏾' => 'ruka z rozšěrjenymi porstami: srěnjoćmowa barba kože',
    '🖐🏿' => 'ruka z rozšěrjenymi porstami: ćmowa barba kože',
    '✋🏻' => 'zběhnjena ruka: swětła barba kože',
    '✋🏼' => 'zběhnjena ruka: srěnjoswětła barba kože',
    '✋🏽' => 'zběhnjena ruka: srěnja barba kože',
    '✋🏾' => 'zběhnjena ruka: srěnjoćmowa barba kože',
    '✋🏿' => 'zběhnjena ruka: ćmowa barba kože',
    '🖖🏻' => 'wulkaniski postrow: swětła barba kože',
    '🖖🏼' => 'wulkaniski postrow: srěnjoswětła barba kože',
    '🖖🏽' => 'wulkaniski postrow: srěnja barba kože',
    '🖖🏾' => 'wulkaniski postrow: srěnjoćmowa barba kože',
    '🖖🏿' => 'wulkaniski postrow: ćmowa barba kože',
    '🫱🏻' => 'ruka doprawa: swětła barba kože',
    '🫱🏼' => 'ruka doprawa: srěnjoswětła barba kože',
    '🫱🏽' => 'ruka doprawa: srěnja barba kože',
    '🫱🏾' => 'ruka doprawa: srěnjoćmowa barba kože',
    '🫱🏿' => 'ruka doprawa: ćmowa barba kože',
    '🫲🏻' => 'ruka dolěwa: swětła barba kože',
    '🫲🏼' => 'ruka dolěwa: srěnjoswětła barba kože',
    '🫲🏽' => 'ruka dolěwa: srěnja barba kože',
    '🫲🏾' => 'ruka dolěwa: srěnjoćmowa barba kože',
    '🫲🏿' => 'ruka dolěwa: ćmowa barba kože',
    '🫳🏻' => 'dłóń pokazuje dele: swětła barba kože',
    '🫳🏼' => 'dłóń pokazuje dele: srěnjoswětła barba kože',
    '🫳🏽' => 'dłóń pokazuje dele: srěnja barba kože',
    '🫳🏾' => 'dłóń pokazuje dele: srěnjoćmowa barba kože',
    '🫳🏿' => 'dłóń pokazuje dele: ćmowa barba kože',
    '🫴🏻' => 'dłóń pokazuje horje: swětła barba kože',
    '🫴🏼' => 'dłóń pokazuje horje: srěnjoswětła barba kože',
    '🫴🏽' => 'dłóń pokazuje horje: srěnja barba kože',
    '🫴🏾' => 'dłóń pokazuje horje: srěnjoćmowa barba kože',
    '🫴🏿' => 'dłóń pokazuje horje: ćmowa barba kože',
    '🫷🏻' => 'ruka, kiž tłóči dolěwa: swětła barba kože',
    '🫷🏼' => 'ruka, kiž tłóči dolěwa: srěnjoswětła barba kože',
    '🫷🏽' => 'ruka, kiž tłóči dolěwa: srěnja barba kože',
    '🫷🏾' => 'ruka, kiž tłóči dolěwa: srěnjoćmowa barba kože',
    '🫷🏿' => 'ruka, kiž tłóči dolěwa: ćmowa barba kože',
    '🫸🏻' => 'ruka, kiž tłóči doprawa: swětła barba kože',
    '🫸🏼' => 'ruka, kiž tłóči doprawa: srěnjoswětła barba kože',
    '🫸🏽' => 'ruka, kiž tłóči doprawa: srěnja barba kože',
    '🫸🏾' => 'ruka, kiž tłóči doprawa: srěnjoćmowa barba kože',
    '🫸🏿' => 'ruka, kiž tłóči doprawa: ćmowa barba kože',
    '👌🏻' => 'gesta "w porjadku": swětła barba kože',
    '👌🏼' => 'gesta "w porjadku": srěnjoswětła barba kože',
    '👌🏽' => 'gesta "w porjadku": srěnja barba kože',
    '👌🏾' => 'gesta "w porjadku": srěnjoćmowa barba kože',
    '👌🏿' => 'gesta "w porjadku": ćmowa barba kože',
    '🤌🏻' => 'hromadźe stłóčene porsty: swětła barba kože',
    '🤌🏼' => 'hromadźe stłóčene porsty: srěnjoswětła barba kože',
    '🤌🏽' => 'hromadźe stłóčene porsty: srěnja barba kože',
    '🤌🏾' => 'hromadźe stłóčene porsty: srěnjoćmowa barba kože',
    '🤌🏿' => 'hromadźe stłóčene porsty: ćmowa barba kože',
    '🤏🏻' => 'gesta "mało": swětła barba kože',
    '🤏🏼' => 'gesta "mało": srěnjoswětła barba kože',
    '🤏🏽' => 'gesta "mało": srěnja barba kože',
    '🤏🏾' => 'gesta "mało": srěnjoćmowa barba kože',
    '🤏🏿' => 'gesta "mało": ćmowa barba kože',
    '✌🏻' => 'gesta dobyća: swětła barba kože',
    '✌🏼' => 'gesta dobyća: srěnjoswětła barba kože',
    '✌🏽' => 'gesta dobyća: srěnja barba kože',
    '✌🏾' => 'gesta dobyća: srěnjoćmowa barba kože',
    '✌🏿' => 'gesta dobyća: ćmowa barba kože',
    '🤞🏻' => 'ruka ze skřižowanymaj porstomaj: swětła barba kože',
    '🤞🏼' => 'ruka ze skřižowanymaj porstomaj: srěnjoswětła barba kože',
    '🤞🏽' => 'ruka ze skřižowanymaj porstomaj: srěnja barba kože',
    '🤞🏾' => 'ruka ze skřižowanymaj porstomaj: srěnjoćmowa barba kože',
    '🤞🏿' => 'ruka ze skřižowanymaj porstomaj: ćmowa barba kože',
    '🫰🏻' => 'ruka z křižowanym pokazowakom a palcom: swětła barba kože',
    '🫰🏼' => 'ruka z křižowanym pokazowakom a palcom: srěnjoswětła barba kože',
    '🫰🏽' => 'ruka z křižowanym pokazowakom a palcom: srěnja barba kože',
    '🫰🏾' => 'ruka z křižowanym pokazowakom a palcom: srěnjoćmowa barba kože',
    '🫰🏿' => 'ruka z křižowanym pokazowakom a palcom: ćmowa barba kože',
    '🤟🏻' => 'gesta "ja će lubuju": swětła barba kože',
    '🤟🏼' => 'gesta "ja će lubuju": srěnjoswětła barba kože',
    '🤟🏽' => 'gesta "ja će lubuju": srěnja barba kože',
    '🤟🏾' => 'gesta "ja će lubuju": srěnjoćmowa barba kože',
    '🤟🏿' => 'gesta "ja će lubuju": ćmowa barba kože',
    '🤘🏻' => 'gesta rohow: swětła barba kože',
    '🤘🏼' => 'gesta rohow: srěnjoswětła barba kože',
    '🤘🏽' => 'gesta rohow: srěnja barba kože',
    '🤘🏾' => 'gesta rohow: srěnjoćmowa barba kože',
    '🤘🏿' => 'gesta rohow: ćmowa barba kože',
    '🤙🏻' => 'gesta "zazwoń mje": swětła barba kože',
    '🤙🏼' => 'gesta "zazwoń mje": srěnjoswětła barba kože',
    '🤙🏽' => 'gesta "zazwoń mje": srěnja barba kože',
    '🤙🏾' => 'gesta "zazwoń mje": srěnjoćmowa barba kože',
    '🤙🏿' => 'gesta "zazwoń mje": ćmowa barba kože',
    '👈🏻' => 'pokazowak, kiž pokazuje dolěwa: swětła barba kože',
    '👈🏼' => 'pokazowak, kiž pokazuje dolěwa: srěnjoswětła barba kože',
    '👈🏽' => 'pokazowak, kiž pokazuje dolěwa: srěnja barba kože',
    '👈🏾' => 'pokazowak, kiž pokazuje dolěwa: srěnjoćmowa barba kože',
    '👈🏿' => 'pokazowak, kiž pokazuje dolěwa: ćmowa barba kože',
    '👉🏻' => 'pokazowak, kiž pokazuje doprawa: swětła barba kože',
    '👉🏼' => 'pokazowak, kiž pokazuje doprawa: srěnjoswětła barba kože',
    '👉🏽' => 'pokazowak, kiž pokazuje doprawa: srěnja barba kože',
    '👉🏾' => 'pokazowak, kiž pokazuje doprawa: srěnjoćmowa barba kože',
    '👉🏿' => 'pokazowak, kiž pokazuje doprawa: ćmowa barba kože',
    '👆🏻' => 'pokazowak, kiž pokazuje horje, wotzady: swětła barba kože',
    '👆🏼' => 'pokazowak, kiž pokazuje horje, wotzady: srěnjoswětła barba kože',
    '👆🏽' => 'pokazowak, kiž pokazuje horje, wotzady: srěnja barba kože',
    '👆🏾' => 'pokazowak, kiž pokazuje horje, wotzady: srěnjoćmowa barba kože',
    '👆🏿' => 'pokazowak, kiž pokazuje horje, wotzady: ćmowa barba kože',
    '🖕🏻' => 'srjedźny porst: swětła barba kože',
    '🖕🏼' => 'srjedźny porst: srěnjoswětła barba kože',
    '🖕🏽' => 'srjedźny porst: srěnja barba kože',
    '🖕🏾' => 'srjedźny porst: srěnjoćmowa barba kože',
    '🖕🏿' => 'srjedźny porst: ćmowa barba kože',
    '👇🏻' => 'pokazowak, kiž pokazuje dele: swětła barba kože',
    '👇🏼' => 'pokazowak, kiž pokazuje dele: srěnjoswětła barba kože',
    '👇🏽' => 'pokazowak, kiž pokazuje dele: srěnja barba kože',
    '👇🏾' => 'pokazowak, kiž pokazuje dele: srěnjoćmowa barba kože',
    '👇🏿' => 'pokazowak, kiž pokazuje dele: ćmowa barba kože',
    '☝🏻' => 'pokazowak, kiž pokazuje horje, wotprědka: swětła barba kože',
    '☝🏼' => 'pokazowak, kiž pokazuje horje, wotprědka: srěnjoswětła barba kože',
    '☝🏽' => 'pokazowak, kiž pokazuje horje, wotprědka: srěnja barba kože',
    '☝🏾' => 'pokazowak, kiž pokazuje horje, wotprědka: srěnjoćmowa barba kože',
    '☝🏿' => 'pokazowak, kiž pokazuje horje, wotprědka: ćmowa barba kože',
    '🫵🏻' => 'pokazowak, wusměrjeny na hladaceho: swětła barba kože',
    '🫵🏼' => 'pokazowak, wusměrjeny na hladaceho: srěnjoswětła barba kože',
    '🫵🏽' => 'pokazowak, wusměrjeny na hladaceho: srěnja barba kože',
    '🫵🏾' => 'pokazowak, wusměrjeny na hladaceho: srěnjoćmowa barba kože',
    '🫵🏿' => 'pokazowak, wusměrjeny na hladaceho: ćmowa barba kože',
    '👍🏻' => 'palc horje: swětła barba kože',
    '👍🏼' => 'palc horje: srěnjoswětła barba kože',
    '👍🏽' => 'palc horje: srěnja barba kože',
    '👍🏾' => 'palc horje: srěnjoćmowa barba kože',
    '👍🏿' => 'palc horje: ćmowa barba kože',
    '👎🏻' => 'palc dele: swětła barba kože',
    '👎🏼' => 'palc dele: srěnjoswětła barba kože',
    '👎🏽' => 'palc dele: srěnja barba kože',
    '👎🏾' => 'palc dele: srěnjoćmowa barba kože',
    '👎🏿' => 'palc dele: ćmowa barba kože',
    '✊🏻' => 'zběhnjena pjasć: swětła barba kože',
    '✊🏼' => 'zběhnjena pjasć: srěnjoswětła barba kože',
    '✊🏽' => 'zběhnjena pjasć: srěnja barba kože',
    '✊🏾' => 'zběhnjena pjasć: srěnjoćmowa barba kože',
    '✊🏿' => 'zběhnjena pjasć: ćmowa barba kože',
    '👊🏻' => 'spinana pjasć: swětła barba kože',
    '👊🏼' => 'spinana pjasć: srěnjoswětła barba kože',
    '👊🏽' => 'spinana pjasć: srěnja barba kože',
    '👊🏾' => 'spinana pjasć: srěnjoćmowa barba kože',
    '👊🏿' => 'spinana pjasć: ćmowa barba kože',
    '🤛🏻' => 'pjasć dolěwa: swětła barba kože',
    '🤛🏼' => 'pjasć dolěwa: srěnjoswětła barba kože',
    '🤛🏽' => 'pjasć dolěwa: srěnja barba kože',
    '🤛🏾' => 'pjasć dolěwa: srěnjoćmowa barba kože',
    '🤛🏿' => 'pjasć dolěwa: ćmowa barba kože',
    '🤜🏻' => 'pjasć doprawa: swětła barba kože',
    '🤜🏼' => 'pjasć doprawa: srěnjoswětła barba kože',
    '🤜🏽' => 'pjasć doprawa: srěnja barba kože',
    '🤜🏾' => 'pjasć doprawa: srěnjoćmowa barba kože',
    '🤜🏿' => 'pjasć doprawa: ćmowa barba kože',
    '👏🏻' => 'ruce, kiž přikleskujetej: swětła barba kože',
    '👏🏼' => 'ruce, kiž přikleskujetej: srěnjoswětła barba kože',
    '👏🏽' => 'ruce, kiž přikleskujetej: srěnja barba kože',
    '👏🏾' => 'ruce, kiž přikleskujetej: srěnjoćmowa barba kože',
    '👏🏿' => 'ruce, kiž přikleskujetej: ćmowa barba kože',
    '🙌🏻' => 'zběhnjenej ruce: swětła barba kože',
    '🙌🏼' => 'zběhnjenej ruce: srěnjoswětła barba kože',
    '🙌🏽' => 'zběhnjenej ruce: srěnja barba kože',
    '🙌🏾' => 'zběhnjenej ruce: srěnjoćmowa barba kože',
    '🙌🏿' => 'zběhnjenej ruce: ćmowa barba kože',
    '🫶🏻' => 'ruce tworitej formu wutroby: swětła barba kože',
    '🫶🏼' => 'ruce tworitej formu wutroby: srěnjoswětła barba kože',
    '🫶🏽' => 'ruce tworitej formu wutroby: srěnja barba kože',
    '🫶🏾' => 'ruce tworitej formu wutroby: srěnjoćmowa barba kože',
    '🫶🏿' => 'ruce tworitej formu wutroby: ćmowa barba kože',
    '👐🏻' => 'wočinjenej ruce: swětła barba kože',
    '👐🏼' => 'wočinjenej ruce: srěnjoswětła barba kože',
    '👐🏽' => 'wočinjenej ruce: srěnja barba kože',
    '👐🏾' => 'wočinjenej ruce: srěnjoćmowa barba kože',
    '👐🏿' => 'wočinjenej ruce: ćmowa barba kože',
    '🤲🏻' => 'zběhnjenej dłóni pódla so: swětła barba kože',
    '🤲🏼' => 'zběhnjenej dłóni pódla so: srěnjoswětła barba kože',
    '🤲🏽' => 'zběhnjenej dłóni pódla so: srěnja barba kože',
    '🤲🏾' => 'zběhnjenej dłóni pódla so: srěnjoćmowa barba kože',
    '🤲🏿' => 'zběhnjenej dłóni pódla so: ćmowa barba kože',
    '🤝🏻' => 'zawdaće ruki: swětła barba kože',
    '🤝🏼' => 'zawdaće ruki: srěnjoswětła barba kože',
    '🤝🏽' => 'zawdaće ruki: srěnja barba kože',
    '🤝🏾' => 'zawdaće ruki: srěnjoćmowa barba kože',
    '🤝🏿' => 'zawdaće ruki: ćmowa barba kože',
    '🙏🏻' => 'styknjenej ruce: swětła barba kože',
    '🙏🏼' => 'styknjenej ruce: srěnjoswětła barba kože',
    '🙏🏽' => 'styknjenej ruce: srěnja barba kože',
    '🙏🏾' => 'styknjenej ruce: srěnjoćmowa barba kože',
    '🙏🏿' => 'styknjenej ruce: ćmowa barba kože',
    '✍🏻' => 'ruka, kiž pisa: swětła barba kože',
    '✍🏼' => 'ruka, kiž pisa: srěnjoswětła barba kože',
    '✍🏽' => 'ruka, kiž pisa: srěnja barba kože',
    '✍🏾' => 'ruka, kiž pisa: srěnjoćmowa barba kože',
    '✍🏿' => 'ruka, kiž pisa: ćmowa barba kože',
    '💅🏻' => 'lak za nochće: swětła barba kože',
    '💅🏼' => 'lak za nochće: srěnjoswětła barba kože',
    '💅🏽' => 'lak za nochće: srěnja barba kože',
    '💅🏾' => 'lak za nochće: srěnjoćmowa barba kože',
    '💅🏿' => 'lak za nochće: ćmowa barba kože',
    '🤳🏻' => 'selfie: swětła barba kože',
    '🤳🏼' => 'selfie: srěnjoswětła barba kože',
    '🤳🏽' => 'selfie: srěnja barba kože',
    '🤳🏾' => 'selfie: srěnjoćmowa barba kože',
    '🤳🏿' => 'selfie: ćmowa barba kože',
    '💪🏻' => 'napjaty biceps: swětła barba kože',
    '💪🏼' => 'napjaty biceps: srěnjoswětła barba kože',
    '💪🏽' => 'napjaty biceps: srěnja barba kože',
    '💪🏾' => 'napjaty biceps: srěnjoćmowa barba kože',
    '💪🏿' => 'napjaty biceps: ćmowa barba kože',
    '🦵🏻' => 'cyła noha: swětła barba kože',
    '🦵🏼' => 'cyła noha: srěnjoswětła barba kože',
    '🦵🏽' => 'cyła noha: srěnja barba kože',
    '🦵🏾' => 'cyła noha: srěnjoćmowa barba kože',
    '🦵🏿' => 'cyła noha: ćmowa barba kože',
    '🦶🏻' => 'delnja noha: swětła barba kože',
    '🦶🏼' => 'delnja noha: srěnjoswětła barba kože',
    '🦶🏽' => 'delnja noha: srěnja barba kože',
    '🦶🏾' => 'delnja noha: srěnjoćmowa barba kože',
    '🦶🏿' => 'delnja noha: ćmowa barba kože',
    '👂🏻' => 'wucho: swětła barba kože',
    '👂🏼' => 'wucho: srěnjoswětła barba kože',
    '👂🏽' => 'wucho: srěnja barba kože',
    '👂🏾' => 'wucho: srěnjoćmowa barba kože',
    '👂🏿' => 'wucho: ćmowa barba kože',
    '🦻🏻' => 'wucho ze słuchadłom: swětła barba kože',
    '🦻🏼' => 'wucho ze słuchadłom: srěnjoswětła barba kože',
    '🦻🏽' => 'wucho ze słuchadłom: srěnja barba kože',
    '🦻🏾' => 'wucho ze słuchadłom: srěnjoćmowa barba kože',
    '🦻🏿' => 'wucho ze słuchadłom: ćmowa barba kože',
    '👃🏻' => 'nós: swětła barba kože',
    '👃🏼' => 'nós: srěnjoswětła barba kože',
    '👃🏽' => 'nós: srěnja barba kože',
    '👃🏾' => 'nós: srěnjoćmowa barba kože',
    '👃🏿' => 'nós: ćmowa barba kože',
    '👶🏻' => 'ćěšenk: swětła barba kože',
    '👶🏼' => 'ćěšenk: srěnjoswětła barba kože',
    '👶🏽' => 'ćěšenk: srěnja barba kože',
    '👶🏾' => 'ćěšenk: srěnjoćmowa barba kože',
    '👶🏿' => 'ćěšenk: ćmowa barba kože',
    '🧒🏻' => 'dźěćo: swětła barba kože',
    '🧒🏼' => 'dźěćo: srěnjoswětła barba kože',
    '🧒🏽' => 'dźěćo: srěnja barba kože',
    '🧒🏾' => 'dźěćo: srěnjoćmowa barba kože',
    '🧒🏿' => 'dźěćo: ćmowa barba kože',
    '👦🏻' => 'hólc: swětła barba kože',
    '👦🏼' => 'hólc: srěnjoswětła barba kože',
    '👦🏽' => 'hólc: srěnja barba kože',
    '👦🏾' => 'hólc: srěnjoćmowa barba kože',
    '👦🏿' => 'hólc: ćmowa barba kože',
    '👧🏻' => 'holca: swětła barba kože',
    '👧🏼' => 'holca: srěnjoswětła barba kože',
    '👧🏽' => 'holca: srěnja barba kože',
    '👧🏾' => 'holca: srěnjoćmowa barba kože',
    '👧🏿' => 'holca: ćmowa barba kože',
    '🧑🏻' => 'dorosćeny: swětła barba kože',
    '🧑🏼' => 'dorosćeny: srěnjoswětła barba kože',
    '🧑🏽' => 'dorosćeny: srěnja barba kože',
    '🧑🏾' => 'dorosćeny: srěnjoćmowa barba kože',
    '🧑🏿' => 'dorosćeny: ćmowa barba kože',
    '👱🏻' => 'wosoba: swětła barba kože, blond włosy',
    '👱🏼' => 'wosoba: srěnjoswětła barba kože, blond włosy',
    '👱🏽' => 'wosoba: srěnja barba kože, blond włosy',
    '👱🏾' => 'wosoba: srěnjoćmowa barba kože, blond włosy',
    '👱🏿' => 'wosoba: ćmowa barba kože, blond włosy',
    '👨🏻' => 'muž: swětła barba kože',
    '👨🏼' => 'muž: srěnjoswětła barba kože',
    '👨🏽' => 'muž: srěnja barba kože',
    '👨🏾' => 'muž: srěnjoćmowa barba kože',
    '👨🏿' => 'muž: ćmowa barba kože',
    '🧔🏻' => 'wosoba: swětła barba kože, broda',
    '🧔🏼' => 'wosoba: srěnjoswětła barba kože, broda',
    '🧔🏽' => 'wosoba: srěnja barba kože, broda',
    '🧔🏾' => 'wosoba: srěnjoćmowa barba kože, broda',
    '🧔🏿' => 'wosoba: ćmowa barba kože, broda',
    '👩🏻' => 'žona: swětła barba kože',
    '👩🏼' => 'žona: srěnjoswětła barba kože',
    '👩🏽' => 'žona: srěnja barba kože',
    '👩🏾' => 'žona: srěnjoćmowa barba kože',
    '👩🏿' => 'žona: ćmowa barba kože',
    '🧓🏻' => 'starša wosoba: swětła barba kože',
    '🧓🏼' => 'starša wosoba: srěnjoswětła barba kože',
    '🧓🏽' => 'starša wosoba: srěnja barba kože',
    '🧓🏾' => 'starša wosoba: srěnjoćmowa barba kože',
    '🧓🏿' => 'starša wosoba: ćmowa barba kože',
    '👴🏻' => 'stary muž: swětła barba kože',
    '👴🏼' => 'stary muž: srěnjoswětła barba kože',
    '👴🏽' => 'stary muž: srěnja barba kože',
    '👴🏾' => 'stary muž: srěnjoćmowa barba kože',
    '👴🏿' => 'stary muž: ćmowa barba kože',
    '👵🏻' => 'stara žona: swětła barba kože',
    '👵🏼' => 'stara žona: srěnjoswětła barba kože',
    '👵🏽' => 'stara žona: srěnja barba kože',
    '👵🏾' => 'stara žona: srěnjoćmowa barba kože',
    '👵🏿' => 'stara žona: ćmowa barba kože',
    '🙍🏻' => 'wosoba, kiž moršći čoło: swětła barba kože',
    '🙍🏼' => 'wosoba, kiž moršći čoło: srěnjoswětła barba kože',
    '🙍🏽' => 'wosoba, kiž moršći čoło: srěnja barba kože',
    '🙍🏾' => 'wosoba, kiž moršći čoło: srěnjoćmowa barba kože',
    '🙍🏿' => 'wosoba, kiž moršći čoło: ćmowa barba kože',
    '🙎🏻' => 'wosoba, kiž kózlika wjaza: swětła barba kože',
    '🙎🏼' => 'wosoba, kiž kózlika wjaza: srěnjoswětła barba kože',
    '🙎🏽' => 'wosoba, kiž kózlika wjaza: srěnja barba kože',
    '🙎🏾' => 'wosoba, kiž kózlika wjaza: srěnjoćmowa barba kože',
    '🙎🏿' => 'wosoba, kiž kózlika wjaza: ćmowa barba kože',
    '🙅🏻' => 'wosoba z překřižowanymaj rukomaj: swětła barba kože',
    '🙅🏼' => 'wosoba z překřižowanymaj rukomaj: srěnjoswětła barba kože',
    '🙅🏽' => 'wosoba z překřižowanymaj rukomaj: srěnja barba kože',
    '🙅🏾' => 'wosoba z překřižowanymaj rukomaj: srěnjoćmowa barba kože',
    '🙅🏿' => 'wosoba z překřižowanymaj rukomaj: ćmowa barba kože',
    '🙆🏻' => 'wosoba z rukomaj na hłowje: swětła barba kože',
    '🙆🏼' => 'wosoba z rukomaj na hłowje: srěnjoswětła barba kože',
    '🙆🏽' => 'wosoba z rukomaj na hłowje: srěnja barba kože',
    '🙆🏾' => 'wosoba z rukomaj na hłowje: srěnjoćmowa barba kože',
    '🙆🏿' => 'wosoba z rukomaj na hłowje: ćmowa barba kože',
    '💁🏻' => 'wosoba z dłónju horje: swětła barba kože',
    '💁🏼' => 'wosoba z dłónju horje: srěnjoswětła barba kože',
    '💁🏽' => 'wosoba z dłónju horje: srěnja barba kože',
    '💁🏾' => 'wosoba z dłónju horje: srěnjoćmowa barba kože',
    '💁🏿' => 'wosoba z dłónju horje: ćmowa barba kože',
    '🙋🏻' => 'wosoba ze zběhnjenej ruku: swětła barba kože',
    '🙋🏼' => 'wosoba ze zběhnjenej ruku: srěnjoswětła barba kože',
    '🙋🏽' => 'wosoba ze zběhnjenej ruku: srěnja barba kože',
    '🙋🏾' => 'wosoba ze zběhnjenej ruku: srěnjoćmowa barba kože',
    '🙋🏿' => 'wosoba ze zběhnjenej ruku: ćmowa barba kože',
    '🧏🏻' => 'hłucha wosoba: swětła barba kože',
    '🧏🏼' => 'hłucha wosoba: srěnjoswětła barba kože',
    '🧏🏽' => 'hłucha wosoba: srěnja barba kože',
    '🧏🏾' => 'hłucha wosoba: srěnjoćmowa barba kože',
    '🧏🏿' => 'hłucha wosoba: ćmowa barba kože',
    '🙇🏻' => 'wosoba, kiž so pokłoni: swětła barba kože',
    '🙇🏼' => 'wosoba, kiž so pokłoni: srěnjoswětła barba kože',
    '🙇🏽' => 'wosoba, kiž so pokłoni: srěnja barba kože',
    '🙇🏾' => 'wosoba, kiž so pokłoni: srěnjoćmowa barba kože',
    '🙇🏿' => 'wosoba, kiž so pokłoni: ćmowa barba kože',
    '🤦🏻' => 'wosoba, kiž so za hłowu přimnje: swětła barba kože',
    '🤦🏼' => 'wosoba, kiž so za hłowu přimnje: srěnjoswětła barba kože',
    '🤦🏽' => 'wosoba, kiž so za hłowu přimnje: srěnja barba kože',
    '🤦🏾' => 'wosoba, kiž so za hłowu přimnje: srěnjoćmowa barba kože',
    '🤦🏿' => 'wosoba, kiž so za hłowu přimnje: ćmowa barba kože',
    '🤷🏻' => 'wosoba, kiž z ramjenjomaj suknje: swětła barba kože',
    '🤷🏼' => 'wosoba, kiž z ramjenjomaj suknje: srěnjoswětła barba kože',
    '🤷🏽' => 'wosoba, kiž z ramjenjomaj suknje: srěnja barba kože',
    '🤷🏾' => 'wosoba, kiž z ramjenjomaj suknje: srěnjoćmowa barba kože',
    '🤷🏿' => 'wosoba, kiž z ramjenjomaj suknje: ćmowa barba kože',
    '👮🏻' => 'policist/ka: swětła barba kože',
    '👮🏼' => 'policist/ka: srěnjoswětła barba kože',
    '👮🏽' => 'policist/ka: srěnja barba kože',
    '👮🏾' => 'policist/ka: srěnjoćmowa barba kože',
    '👮🏿' => 'policist/ka: ćmowa barba kože',
    '🕵🏻' => 'detektiw/ka: swětła barba kože',
    '🕵🏼' => 'detektiw/ka: srěnjoswětła barba kože',
    '🕵🏽' => 'detektiw/ka: srěnja barba kože',
    '🕵🏾' => 'detektiw/ka: srěnjoćmowa barba kože',
    '🕵🏿' => 'detektiw/ka: ćmowa barba kože',
    '💂🏻' => 'stražnik/ stražnica: swětła barba kože',
    '💂🏼' => 'stražnik/ stražnica: srěnjoswětła barba kože',
    '💂🏽' => 'stražnik/ stražnica: srěnja barba kože',
    '💂🏾' => 'stražnik/ stražnica: srěnjoćmowa barba kože',
    '💂🏿' => 'stražnik/ stražnica: ćmowa barba kože',
    '🥷🏻' => 'ninja: swětła barba kože',
    '🥷🏼' => 'ninja: srěnjoswětła barba kože',
    '🥷🏽' => 'ninja: srěnja barba kože',
    '🥷🏾' => 'ninja: srěnjoćmowa barba kože',
    '🥷🏿' => 'ninja: ćmowa barba kože',
    '👷🏻' => 'twarski dźěłaćer/ twarska dźěłaćerka: swětła barba kože',
    '👷🏼' => 'twarski dźěłaćer/ twarska dźěłaćerka: srěnjoswětła barba kože',
    '👷🏽' => 'twarski dźěłaćer/ twarska dźěłaćerka: srěnja barba kože',
    '👷🏾' => 'twarski dźěłaćer/ twarska dźěłaćerka: srěnjoćmowa barba kože',
    '👷🏿' => 'twarski dźěłaćer/ twarska dźěłaćerka: ćmowa barba kože',
    '🫅🏻' => 'wosoba z krónu: swětła barba kože',
    '🫅🏼' => 'wosoba z krónu: srěnjoswětła barba kože',
    '🫅🏽' => 'wosoba z krónu: srěnja barba kože',
    '🫅🏾' => 'wosoba z krónu: srěnjoćmowa barba kože',
    '🫅🏿' => 'wosoba z krónu: ćmowa barba kože',
    '🤴🏻' => 'princ: swětła barba kože',
    '🤴🏼' => 'princ: srěnjoswětła barba kože',
    '🤴🏽' => 'princ: srěnja barba kože',
    '🤴🏾' => 'princ: srěnjoćmowa barba kože',
    '🤴🏿' => 'princ: ćmowa barba kože',
    '👸🏻' => 'princesna: swětła barba kože',
    '👸🏼' => 'princesna: srěnjoswětła barba kože',
    '👸🏽' => 'princesna: srěnja barba kože',
    '👸🏾' => 'princesna: srěnjoćmowa barba kože',
    '👸🏿' => 'princesna: ćmowa barba kože',
    '👳🏻' => 'wosoba z turbanom: swětła barba kože',
    '👳🏼' => 'wosoba z turbanom: srěnjoswětła barba kože',
    '👳🏽' => 'wosoba z turbanom: srěnja barba kože',
    '👳🏾' => 'wosoba z turbanom: srěnjoćmowa barba kože',
    '👳🏿' => 'wosoba z turbanom: ćmowa barba kože',
    '👲🏻' => 'muž z chinskej čapku: swětła barba kože',
    '👲🏼' => 'muž z chinskej čapku: srěnjoswětła barba kože',
    '👲🏽' => 'muž z chinskej čapku: srěnja barba kože',
    '👲🏾' => 'muž z chinskej čapku: srěnjoćmowa barba kože',
    '👲🏿' => 'muž z chinskej čapku: ćmowa barba kože',
    '🧕🏻' => 'žona z rubiškom: swětła barba kože',
    '🧕🏼' => 'žona z rubiškom: srěnjoswětła barba kože',
    '🧕🏽' => 'žona z rubiškom: srěnja barba kože',
    '🧕🏾' => 'žona z rubiškom: srěnjoćmowa barba kože',
    '🧕🏿' => 'žona z rubiškom: ćmowa barba kože',
    '🤵🏻' => 'wosoba w smokingu: swětła barba kože',
    '🤵🏼' => 'wosoba w smokingu: srěnjoswětła barba kože',
    '🤵🏽' => 'wosoba w smokingu: srěnja barba kože',
    '🤵🏾' => 'wosoba w smokingu: srěnjoćmowa barba kože',
    '🤵🏿' => 'wosoba w smokingu: ćmowa barba kože',
    '👰🏻' => 'wosoba ze šlewjerjom: swětła barba kože',
    '👰🏼' => 'wosoba ze šlewjerjom: srěnjoswětła barba kože',
    '👰🏽' => 'wosoba ze šlewjerjom: srěnja barba kože',
    '👰🏾' => 'wosoba ze šlewjerjom: srěnjoćmowa barba kože',
    '👰🏿' => 'wosoba ze šlewjerjom: ćmowa barba kože',
    '🤰🏻' => 'samodruha: swětła barba kože',
    '🤰🏼' => 'samodruha: srěnjoswětła barba kože',
    '🤰🏽' => 'samodruha: srěnja barba kože',
    '🤰🏾' => 'samodruha: srěnjoćmowa barba kože',
    '🤰🏿' => 'samodruha: ćmowa barba kože',
    '🫃🏻' => 'samodruhi muž: swětła barba kože',
    '🫃🏼' => 'samodruhi muž: srěnjoswětła barba kože',
    '🫃🏽' => 'samodruhi muž: srěnja barba kože',
    '🫃🏾' => 'samodruhi muž: srěnjoćmowa barba kože',
    '🫃🏿' => 'samodruhi muž: ćmowa barba kože',
    '🫄🏻' => 'samodruha wosoba: swětła barba kože',
    '🫄🏼' => 'samodruha wosoba: srěnjoswětła barba kože',
    '🫄🏽' => 'samodruha wosoba: srěnja barba kože',
    '🫄🏾' => 'samodruha wosoba: srěnjoćmowa barba kože',
    '🫄🏿' => 'samodruha wosoba: ćmowa barba kože',
    '🤱🏻' => 'ćěšić: swětła barba kože',
    '🤱🏼' => 'ćěšić: srěnjoswětła barba kože',
    '🤱🏽' => 'ćěšić: srěnja barba kože',
    '🤱🏾' => 'ćěšić: srěnjoćmowa barba kože',
    '🤱🏿' => 'ćěšić: ćmowa barba kože',
    '👼🏻' => 'jandźelk: swětła barba kože',
    '👼🏼' => 'jandźelk: srěnjoswětła barba kože',
    '👼🏽' => 'jandźelk: srěnja barba kože',
    '👼🏾' => 'jandźelk: srěnjoćmowa barba kože',
    '👼🏿' => 'jandźelk: ćmowa barba kože',
    '🎅🏻' => 'rumpodich: swětła barba kože',
    '🎅🏼' => 'rumpodich: srěnjoswětła barba kože',
    '🎅🏽' => 'rumpodich: srěnja barba kože',
    '🎅🏾' => 'rumpodich: srěnjoćmowa barba kože',
    '🎅🏿' => 'rumpodich: ćmowa barba kože',
    '🤶🏻' => 'rumpodichowka: swětła barba kože',
    '🤶🏼' => 'rumpodichowka: srěnjoswětła barba kože',
    '🤶🏽' => 'rumpodichowka: srěnja barba kože',
    '🤶🏾' => 'rumpodichowka: srěnjoćmowa barba kože',
    '🤶🏿' => 'rumpodichowka: ćmowa barba kože',
    '🦸🏻' => 'superrjek/ superrjekowka: swětła barba kože',
    '🦸🏼' => 'superrjek/ superrjekowka: srěnjoswětła barba kože',
    '🦸🏽' => 'superrjek/ superrjekowka: srěnja barba kože',
    '🦸🏾' => 'superrjek/ superrjekowka: srěnjoćmowa barba kože',
    '🦸🏿' => 'superrjek/ superrjekowka: ćmowa barba kože',
    '🦹🏻' => 'superšamałc/superšamałča: swětła barba kože',
    '🦹🏼' => 'superšamałc/superšamałča: srěnjoswětła barba kože',
    '🦹🏽' => 'superšamałc/superšamałča: srěnja barba kože',
    '🦹🏾' => 'superšamałc/superšamałča: srěnjoćmowa barba kože',
    '🦹🏿' => 'superšamałc/superšamałča: ćmowa barba kože',
    '🧙🏻' => 'kuzłar/niča: swětła barba kože',
    '🧙🏼' => 'kuzłar/niča: srěnjoswětła barba kože',
    '🧙🏽' => 'kuzłar/niča: srěnja barba kože',
    '🧙🏾' => 'kuzłar/niča: srěnjoćmowa barba kože',
    '🧙🏿' => 'kuzłar/niča: ćmowa barba kože',
    '🧚🏻' => 'sonina: swětła barba kože',
    '🧚🏼' => 'sonina: srěnjoswětła barba kože',
    '🧚🏽' => 'sonina: srěnja barba kože',
    '🧚🏾' => 'sonina: srěnjoćmowa barba kože',
    '🧚🏿' => 'sonina: ćmowa barba kože',
    '🧛🏻' => 'wampir: swětła barba kože',
    '🧛🏼' => 'wampir: srěnjoswětła barba kože',
    '🧛🏽' => 'wampir: srěnja barba kože',
    '🧛🏾' => 'wampir: srěnjoćmowa barba kože',
    '🧛🏿' => 'wampir: ćmowa barba kože',
    '🧜🏻' => 'wosoba z morja: swětła barba kože',
    '🧜🏼' => 'wosoba z morja: srěnjoswětła barba kože',
    '🧜🏽' => 'wosoba z morja: srěnja barba kože',
    '🧜🏾' => 'wosoba z morja: srěnjoćmowa barba kože',
    '🧜🏿' => 'wosoba z morja: ćmowa barba kože',
    '🧝🏻' => 'soninak: swětła barba kože',
    '🧝🏼' => 'soninak: srěnjoswětła barba kože',
    '🧝🏽' => 'soninak: srěnja barba kože',
    '🧝🏾' => 'soninak: srěnjoćmowa barba kože',
    '🧝🏿' => 'soninak: ćmowa barba kože',
    '💆🏻' => 'wosoba, kiž dóstanje masažu hłowy: swětła barba kože',
    '💆🏼' => 'wosoba, kiž dóstanje masažu hłowy: srěnjoswětła barba kože',
    '💆🏽' => 'wosoba, kiž dóstanje masažu hłowy: srěnja barba kože',
    '💆🏾' => 'wosoba, kiž dóstanje masažu hłowy: srěnjoćmowa barba kože',
    '💆🏿' => 'wosoba, kiž dóstanje masažu hłowy: ćmowa barba kože',
    '💇🏻' => 'wosoba, kiž da sej włosy třihać: swětła barba kože',
    '💇🏼' => 'wosoba, kiž da sej włosy třihać: srěnjoswětła barba kože',
    '💇🏽' => 'wosoba, kiž da sej włosy třihać: srěnja barba kože',
    '💇🏾' => 'wosoba, kiž da sej włosy třihać: srěnjoćmowa barba kože',
    '💇🏿' => 'wosoba, kiž da sej włosy třihać: ćmowa barba kože',
    '🚶🏻' => 'wosoba, kiž je pěši po puću: swětła barba kože',
    '🚶🏼' => 'wosoba, kiž je pěši po puću: srěnjoswětła barba kože',
    '🚶🏽' => 'wosoba, kiž je pěši po puću: srěnja barba kože',
    '🚶🏾' => 'wosoba, kiž je pěši po puću: srěnjoćmowa barba kože',
    '🚶🏿' => 'wosoba, kiž je pěši po puću: ćmowa barba kože',
    '🧍🏻' => 'stejaca wosoba: swětła barba kože',
    '🧍🏼' => 'stejaca wosoba: srěnjoswětła barba kože',
    '🧍🏽' => 'stejaca wosoba: srěnja barba kože',
    '🧍🏾' => 'stejaca wosoba: srěnjoćmowa barba kože',
    '🧍🏿' => 'stejaca wosoba: ćmowa barba kože',
    '🧎🏻' => 'klečaca wosoba: swětła barba kože',
    '🧎🏼' => 'klečaca wosoba: srěnjoswětła barba kože',
    '🧎🏽' => 'klečaca wosoba: srěnja barba kože',
    '🧎🏾' => 'klečaca wosoba: srěnjoćmowa barba kože',
    '🧎🏿' => 'klečaca wosoba: ćmowa barba kože',
    '🏃🏻' => 'běhaca wosoba: swětła barba kože',
    '🏃🏼' => 'běhaca wosoba: srěnjoswětła barba kože',
    '🏃🏽' => 'běhaca wosoba: srěnja barba kože',
    '🏃🏾' => 'běhaca wosoba: srěnjoćmowa barba kože',
    '🏃🏿' => 'běhaca wosoba: ćmowa barba kože',
    '💃🏻' => 'rejowaca žona: swětła barba kože',
    '💃🏼' => 'rejowaca žona: srěnjoswětła barba kože',
    '💃🏽' => 'rejowaca žona: srěnja barba kože',
    '💃🏾' => 'rejowaca žona: srěnjoćmowa barba kože',
    '💃🏿' => 'rejowaca žona: ćmowa barba kože',
    '🕺🏻' => 'rejowacy muž: swětła barba kože',
    '🕺🏼' => 'rejowacy muž: srěnjoswětła barba kože',
    '🕺🏽' => 'rejowacy muž: srěnja barba kože',
    '🕺🏾' => 'rejowacy muž: srěnjoćmowa barba kože',
    '🕺🏿' => 'rejowacy muž: ćmowa barba kože',
    '🕴🏻' => 'muž we wobleku, kiž so znošuje: swětła barba kože',
    '🕴🏼' => 'muž we wobleku, kiž so znošuje: srěnjoswětła barba kože',
    '🕴🏽' => 'muž we wobleku, kiž so znošuje: srěnja barba kože',
    '🕴🏾' => 'muž we wobleku, kiž so znošuje: srěnjoćmowa barba kože',
    '🕴🏿' => 'muž we wobleku, kiž so znošuje: ćmowa barba kože',
    '👯🏻' => 'wosobje ze zaječimaj wušomaj: swětła barba kože',
    '👯🏼' => 'wosobje ze zaječimaj wušomaj: srěnjoswětła barba kože',
    '👯🏽' => 'wosobje ze zaječimaj wušomaj: srěnja barba kože',
    '👯🏾' => 'wosobje ze zaječimaj wušomaj: srěnjoćmowa barba kože',
    '👯🏿' => 'wosobje ze zaječimaj wušomaj: ćmowa barba kože',
    '🧖🏻' => 'wosoba w sawnje: swětła barba kože',
    '🧖🏼' => 'wosoba w sawnje: srěnjoswětła barba kože',
    '🧖🏽' => 'wosoba w sawnje: srěnja barba kože',
    '🧖🏾' => 'wosoba w sawnje: srěnjoćmowa barba kože',
    '🧖🏿' => 'wosoba w sawnje: ćmowa barba kože',
    '🧗🏻' => 'krosnowar/ka: swětła barba kože',
    '🧗🏼' => 'krosnowar/ka: srěnjoswětła barba kože',
    '🧗🏽' => 'krosnowar/ka: srěnja barba kože',
    '🧗🏾' => 'krosnowar/ka: srěnjoćmowa barba kože',
    '🧗🏿' => 'krosnowar/ka: ćmowa barba kože',
    '🏇🏻' => 'wubědźowanje na konjach: swětła barba kože',
    '🏇🏼' => 'wubědźowanje na konjach: srěnjoswětła barba kože',
    '🏇🏽' => 'wubědźowanje na konjach: srěnja barba kože',
    '🏇🏾' => 'wubědźowanje na konjach: srěnjoćmowa barba kože',
    '🏇🏿' => 'wubědźowanje na konjach: ćmowa barba kože',
    '🏂🏻' => 'snowboarder/ka: swětła barba kože',
    '🏂🏼' => 'snowboarder/ka: srěnjoswětła barba kože',
    '🏂🏽' => 'snowboarder/ka: srěnja barba kože',
    '🏂🏾' => 'snowboarder/ka: srěnjoćmowa barba kože',
    '🏂🏿' => 'snowboarder/ka: ćmowa barba kože',
    '🏌🏻' => 'wosoba, kiž hraje golf: swětła barba kože',
    '🏌🏼' => 'wosoba, kiž hraje golf: srěnjoswětła barba kože',
    '🏌🏽' => 'wosoba, kiž hraje golf: srěnja barba kože',
    '🏌🏾' => 'wosoba, kiž hraje golf: srěnjoćmowa barba kože',
    '🏌🏿' => 'wosoba, kiž hraje golf: ćmowa barba kože',
    '🏄🏻' => 'wosoba při surfowanju: swětła barba kože',
    '🏄🏼' => 'wosoba při surfowanju: srěnjoswětła barba kože',
    '🏄🏽' => 'wosoba při surfowanju: srěnja barba kože',
    '🏄🏾' => 'wosoba při surfowanju: srěnjoćmowa barba kože',
    '🏄🏿' => 'wosoba při surfowanju: ćmowa barba kože',
    '🚣🏻' => 'wosoba při wjesłowanju: swětła barba kože',
    '🚣🏼' => 'wosoba při wjesłowanju: srěnjoswětła barba kože',
    '🚣🏽' => 'wosoba při wjesłowanju: srěnja barba kože',
    '🚣🏾' => 'wosoba při wjesłowanju: srěnjoćmowa barba kože',
    '🚣🏿' => 'wosoba při wjesłowanju: ćmowa barba kože',
    '🏊🏻' => 'płuwaca wosoba: swětła barba kože',
    '🏊🏼' => 'płuwaca wosoba: srěnjoswětła barba kože',
    '🏊🏽' => 'płuwaca wosoba: srěnja barba kože',
    '🏊🏾' => 'płuwaca wosoba: srěnjoćmowa barba kože',
    '🏊🏿' => 'płuwaca wosoba: ćmowa barba kože',
    '⛹🏻' => 'wosoba z bulom: swětła barba kože',
    '⛹🏼' => 'wosoba z bulom: srěnjoswětła barba kože',
    '⛹🏽' => 'wosoba z bulom: srěnja barba kože',
    '⛹🏾' => 'wosoba z bulom: srěnjoćmowa barba kože',
    '⛹🏿' => 'wosoba z bulom: ćmowa barba kože',
    '🏋🏻' => 'wosoba, kiž zběha wahi: swětła barba kože',
    '🏋🏼' => 'wosoba, kiž zběha wahi: srěnjoswětła barba kože',
    '🏋🏽' => 'wosoba, kiž zběha wahi: srěnja barba kože',
    '🏋🏾' => 'wosoba, kiž zběha wahi: srěnjoćmowa barba kože',
    '🏋🏿' => 'wosoba, kiž zběha wahi: ćmowa barba kože',
    '🚴🏻' => 'wosoba, kiž kolesuje: swětła barba kože',
    '🚴🏼' => 'wosoba, kiž kolesuje: srěnjoswětła barba kože',
    '🚴🏽' => 'wosoba, kiž kolesuje: srěnja barba kože',
    '🚴🏾' => 'wosoba, kiž kolesuje: srěnjoćmowa barba kože',
    '🚴🏿' => 'wosoba, kiž kolesuje: ćmowa barba kože',
    '🚵🏻' => 'wosoba, kiž jězdźi z mountainbikom: swětła barba kože',
    '🚵🏼' => 'wosoba, kiž jězdźi z mountainbikom: srěnjoswětła barba kože',
    '🚵🏽' => 'wosoba, kiž jězdźi z mountainbikom: srěnja barba kože',
    '🚵🏾' => 'wosoba, kiž jězdźi z mountainbikom: srěnjoćmowa barba kože',
    '🚵🏿' => 'wosoba, kiž jězdźi z mountainbikom: ćmowa barba kože',
    '🤸🏻' => 'wosoba, kiž so nabok přemjetuje: swětła barba kože',
    '🤸🏼' => 'wosoba, kiž so nabok přemjetuje: srěnjoswětła barba kože',
    '🤸🏽' => 'wosoba, kiž so nabok přemjetuje: srěnja barba kože',
    '🤸🏾' => 'wosoba, kiž so nabok přemjetuje: srěnjoćmowa barba kože',
    '🤸🏿' => 'wosoba, kiž so nabok přemjetuje: ćmowa barba kože',
    '🤼🏻' => 'wosobje, kiž wjerhatej: swětła barba kože',
    '🤼🏼' => 'wosobje, kiž wjerhatej: srěnjoswětła barba kože',
    '🤼🏽' => 'wosobje, kiž wjerhatej: srěnja barba kože',
    '🤼🏾' => 'wosobje, kiž wjerhatej: srěnjoćmowa barba kože',
    '🤼🏿' => 'wosobje, kiž wjerhatej: ćmowa barba kože',
    '🤽🏻' => 'wosoba, kiž hraje wodobul: swětła barba kože',
    '🤽🏼' => 'wosoba, kiž hraje wodobul: srěnjoswětła barba kože',
    '🤽🏽' => 'wosoba, kiž hraje wodobul: srěnja barba kože',
    '🤽🏾' => 'wosoba, kiž hraje wodobul: srěnjoćmowa barba kože',
    '🤽🏿' => 'wosoba, kiž hraje wodobul: ćmowa barba kože',
    '🤾🏻' => 'wosoba, kiž hraje mjetańcu: swětła barba kože',
    '🤾🏼' => 'wosoba, kiž hraje mjetańcu: srěnjoswětła barba kože',
    '🤾🏽' => 'wosoba, kiž hraje mjetańcu: srěnja barba kože',
    '🤾🏾' => 'wosoba, kiž hraje mjetańcu: srěnjoćmowa barba kože',
    '🤾🏿' => 'wosoba, kiž hraje mjetańcu: ćmowa barba kože',
    '🤹🏻' => 'wosoba, kiž žonglěruje: swětła barba kože',
    '🤹🏼' => 'wosoba, kiž žonglěruje: srěnjoswětła barba kože',
    '🤹🏽' => 'wosoba, kiž žonglěruje: srěnja barba kože',
    '🤹🏾' => 'wosoba, kiž žonglěruje: srěnjoćmowa barba kože',
    '🤹🏿' => 'wosoba, kiž žonglěruje: ćmowa barba kože',
    '🧘🏻' => 'wosoba w lotosowym sydźe: swětła barba kože',
    '🧘🏼' => 'wosoba w lotosowym sydźe: srěnjoswětła barba kože',
    '🧘🏽' => 'wosoba w lotosowym sydźe: srěnja barba kože',
    '🧘🏾' => 'wosoba w lotosowym sydźe: srěnjoćmowa barba kože',
    '🧘🏿' => 'wosoba w lotosowym sydźe: ćmowa barba kože',
    '🛀🏻' => 'wosoba, kiž so kupa: swětła barba kože',
    '🛀🏼' => 'wosoba, kiž so kupa: srěnjoswětła barba kože',
    '🛀🏽' => 'wosoba, kiž so kupa: srěnja barba kože',
    '🛀🏾' => 'wosoba, kiž so kupa: srěnjoćmowa barba kože',
    '🛀🏿' => 'wosoba, kiž so kupa: ćmowa barba kože',
    '🛌🏻' => 'wosoba we łožu: swětła barba kože',
    '🛌🏼' => 'wosoba we łožu: srěnjoswětła barba kože',
    '🛌🏽' => 'wosoba we łožu: srěnja barba kože',
    '🛌🏾' => 'wosoba we łožu: srěnjoćmowa barba kože',
    '🛌🏿' => 'wosoba we łožu: ćmowa barba kože',
    '👭🏻' => 'žonje dźeržitej so za ruku: swětła barba kože',
    '👭🏼' => 'žonje dźeržitej so za ruku: srěnjoswětła barba kože',
    '👭🏽' => 'žonje dźeržitej so za ruku: srěnja barba kože',
    '👭🏾' => 'žonje dźeržitej so za ruku: srěnjoćmowa barba kože',
    '👭🏿' => 'žonje dźeržitej so za ruku: ćmowa barba kože',
    '👫🏻' => 'muž a žona dźeržitaj so za ruku: swětła barba kože',
    '👫🏼' => 'muž a žona dźeržitaj so za ruku: srěnjoswětła barba kože',
    '👫🏽' => 'muž a žona dźeržitaj so za ruku: srěnja barba kože',
    '👫🏾' => 'muž a žona dźeržitaj so za ruku: srěnjoćmowa barba kože',
    '👫🏿' => 'muž a žona dźeržitaj so za ruku: ćmowa barba kože',
    '👬🏻' => 'mužej dźeržitaj so za ruku: swětła barba kože',
    '👬🏼' => 'mužej dźeržitaj so za ruku: srěnjoswětła barba kože',
    '👬🏽' => 'mužej dźeržitaj so za ruku: srěnja barba kože',
    '👬🏾' => 'mužej dźeržitaj so za ruku: srěnjoćmowa barba kože',
    '👬🏿' => 'mužej dźeržitaj so za ruku: ćmowa barba kože',
    '💏🏻' => 'porik, kiž so koši: swětła barba kože',
    '💏🏼' => 'porik, kiž so koši: srěnjoswětła barba kože',
    '💏🏽' => 'porik, kiž so koši: srěnja barba kože',
    '💏🏾' => 'porik, kiž so koši: srěnjoćmowa barba kože',
    '💏🏿' => 'porik, kiž so koši: ćmowa barba kože',
    '💑🏻' => 'porik z wutrobičku: swětła barba kože',
    '💑🏼' => 'porik z wutrobičku: srěnjoswětła barba kože',
    '💑🏽' => 'porik z wutrobičku: srěnja barba kože',
    '💑🏾' => 'porik z wutrobičku: srěnjoćmowa barba kože',
    '💑🏿' => 'porik z wutrobičku: ćmowa barba kože',
    '🇦🇨' => 'chorhojčka: Ascension',
    '🇦🇩' => 'chorhojčka: Andorra',
    '🇦🇪' => 'chorhojčka: Zjednoćene arabske emiraty',
    '🇦🇫' => 'chorhojčka: Afghanistan',
    '🇦🇬' => 'chorhojčka: Antigua a Barbuda',
    '🇦🇮' => 'chorhojčka: Anguilla',
    '🇦🇱' => 'chorhojčka: Albanska',
    '🇦🇲' => 'chorhojčka: Armenska',
    '🇦🇴' => 'chorhojčka: Angola',
    '🇦🇶' => 'chorhojčka: Antarktika',
    '🇦🇷' => 'chorhojčka: Argentinska',
    '🇦🇸' => 'chorhojčka: Ameriska Samoa',
    '🇦🇹' => 'chorhojčka: Awstriska',
    '🇦🇺' => 'chorhojčka: Awstralska',
    '🇦🇼' => 'chorhojčka: Aruba',
    '🇦🇽' => 'chorhojčka: Åland',
    '🇦🇿' => 'chorhojčka: Azerbajdźan',
    '🇧🇦' => 'chorhojčka: Bosniska a Hercegowina',
    '🇧🇧' => 'chorhojčka: Barbados',
    '🇧🇩' => 'chorhojčka: Bangladeš',
    '🇧🇪' => 'chorhojčka: Belgiska',
    '🇧🇫' => 'chorhojčka: Burkina Faso',
    '🇧🇬' => 'chorhojčka: Bołharska',
    '🇧🇭' => 'chorhojčka: Bahrain',
    '🇧🇮' => 'chorhojčka: Burundi',
    '🇧🇯' => 'chorhojčka: Benin',
    '🇧🇱' => 'chorhojčka: St. Barthélemy',
    '🇧🇲' => 'chorhojčka: Bermudy',
    '🇧🇳' => 'chorhojčka: Brunei',
    '🇧🇴' => 'chorhojčka: Boliwiska',
    '🇧🇶' => 'chorhojčka: Karibiska Nižozemska',
    '🇧🇷' => 'chorhojčka: Brazilska',
    '🇧🇸' => 'chorhojčka: Bahamy',
    '🇧🇹' => 'chorhojčka: Bhutan',
    '🇧🇻' => 'chorhojčka: Bouvetowa kupa',
    '🇧🇼' => 'chorhojčka: Botswana',
    '🇧🇾' => 'chorhojčka: Běłoruska',
    '🇧🇿' => 'chorhojčka: Belize',
    '🇨🇦' => 'chorhojčka: Kanada',
    '🇨🇨' => 'chorhojčka: Kokosowe kupy',
    '🇨🇩' => 'chorhojčka: Kongo-Kinshasa',
    '🇨🇫' => 'chorhojčka: Centralnoafriska republika',
    '🇨🇬' => 'chorhojčka: Kongo-Brazzaville',
    '🇨🇭' => 'chorhojčka: Šwicarska',
    '🇨🇮' => 'chorhojčka: Côte d’Ivoire',
    '🇨🇰' => 'chorhojčka: Cookowe kupy',
    '🇨🇱' => 'chorhojčka: Chilska',
    '🇨🇲' => 'chorhojčka: Kamerun',
    '🇨🇳' => 'chorhojčka: China',
    '🇨🇴' => 'chorhojčka: Kolumbiska',
    '🇨🇵' => 'chorhojčka: Clippertonowa kupa',
    '🇨🇶' => 'chorhojčka: Sark',
    '🇨🇷' => 'chorhojčka: Kosta Rika',
    '🇨🇺' => 'chorhojčka: Kuba',
    '🇨🇻' => 'chorhojčka: Kap Verde',
    '🇨🇼' => 'chorhojčka: Curaçao',
    '🇨🇽' => 'chorhojčka: Hodowna kupa',
    '🇨🇾' => 'chorhojčka: Cypern',
    '🇨🇿' => 'chorhojčka: Čěska republika',
    '🇩🇪' => 'chorhojčka: Němska',
    '🇩🇬' => 'chorhojčka: Diego Garcia',
    '🇩🇯' => 'chorhojčka: Dźibuti',
    '🇩🇰' => 'chorhojčka: Danska',
    '🇩🇲' => 'chorhojčka: Dominika',
    '🇩🇴' => 'chorhojčka: Dominikanska republika',
    '🇩🇿' => 'chorhojčka: Algeriska',
    '🇪🇦' => 'chorhojčka: Ceuta a Melilla',
    '🇪🇨' => 'chorhojčka: Ekwador',
    '🇪🇪' => 'chorhojčka: Estiska',
    '🇪🇬' => 'chorhojčka: Egyptowska',
    '🇪🇭' => 'chorhojčka: Zapadna Sahara',
    '🇪🇷' => 'chorhojčka: Eritreja',
    '🇪🇸' => 'chorhojčka: Španiska',
    '🇪🇹' => 'chorhojčka: Etiopiska',
    '🇪🇺' => 'chorhojčka: Europska unija',
    '🇫🇮' => 'chorhojčka: Finska',
    '🇫🇯' => 'chorhojčka: Fidźi',
    '🇫🇰' => 'chorhojčka: Falklandske kupy',
    '🇫🇲' => 'chorhojčka: Mikroneziska',
    '🇫🇴' => 'chorhojčka: Färöske kupy',
    '🇫🇷' => 'chorhojčka: Francoska',
    '🇬🇦' => 'chorhojčka: Gabun',
    '🇬🇧' => 'chorhojčka: Zjednoćene kralestwo',
    '🇬🇩' => 'chorhojčka: Grenada',
    '🇬🇪' => 'chorhojčka: Georgiska',
    '🇬🇫' => 'chorhojčka: Francoska Guyana',
    '🇬🇬' => 'chorhojčka: Guernsey',
    '🇬🇭' => 'chorhojčka: Ghana',
    '🇬🇮' => 'chorhojčka: Gibraltar',
    '🇬🇱' => 'chorhojčka: Grönlandska',
    '🇬🇲' => 'chorhojčka: Gambija',
    '🇬🇳' => 'chorhojčka: Gineja',
    '🇬🇵' => 'chorhojčka: Guadeloupe',
    '🇬🇶' => 'chorhojčka: Ekwatorialna Gineja',
    '🇬🇷' => 'chorhojčka: Grjekska',
    '🇬🇸' => 'chorhojčka: Južna Georgiska a Južne Sandwichowe kupy',
    '🇬🇹' => 'chorhojčka: Guatemala',
    '🇬🇺' => 'chorhojčka: Guam',
    '🇬🇼' => 'chorhojčka: Gineja-Bissau',
    '🇬🇾' => 'chorhojčka: Guyana',
    '🇭🇰' => 'chorhojčka: Wosebita zarjadniska cona Hongkong',
    '🇭🇲' => 'chorhojčka: Heardowa kupa a McDonaldowe kupy',
    '🇭🇳' => 'chorhojčka: Honduras',
    '🇭🇷' => 'chorhojčka: Chorwatska',
    '🇭🇹' => 'chorhojčka: Haiti',
    '🇭🇺' => 'chorhojčka: Madźarska',
    '🇮🇨' => 'chorhojčka: Kanariske kupy',
    '🇮🇩' => 'chorhojčka: Indoneska',
    '🇮🇪' => 'chorhojčka: Irska',
    '🇮🇱' => 'chorhojčka: Israel',
    '🇮🇲' => 'chorhojčka: Man',
    '🇮🇳' => 'chorhojčka: Indiska',
    '🇮🇴' => 'chorhojčka: Britiski teritorij w Indiskim oceanje',
    '🇮🇶' => 'chorhojčka: Irak',
    '🇮🇷' => 'chorhojčka: Iran',
    '🇮🇸' => 'chorhojčka: Islandska',
    '🇮🇹' => 'chorhojčka: Italska',
    '🇯🇪' => 'chorhojčka: Jersey',
    '🇯🇲' => 'chorhojčka: Jamaika',
    '🇯🇴' => 'chorhojčka: Jordaniska',
    '🇯🇵' => 'chorhojčka: Japanska',
    '🇰🇪' => 'chorhojčka: Kenija',
    '🇰🇬' => 'chorhojčka: Kirgizistan',
    '🇰🇭' => 'chorhojčka: Kambodźa',
    '🇰🇮' => 'chorhojčka: Kiribati',
    '🇰🇲' => 'chorhojčka: Komory',
    '🇰🇳' => 'chorhojčka: St. Kitts a Nevis',
    '🇰🇵' => 'chorhojčka: Sewjerna Koreja',
    '🇰🇷' => 'chorhojčka: Južna Koreja',
    '🇰🇼' => 'chorhojčka: Kuwait',
    '🇰🇾' => 'chorhojčka: Kajmanske kupy',
    '🇰🇿' => 'chorhojčka: Kazachstan',
    '🇱🇦' => 'chorhojčka: Laos',
    '🇱🇧' => 'chorhojčka: Libanon',
    '🇱🇨' => 'chorhojčka: St. Lucia',
    '🇱🇮' => 'chorhojčka: Liechtenstein',
    '🇱🇰' => 'chorhojčka: Sri Lanka',
    '🇱🇷' => 'chorhojčka: Liberija',
    '🇱🇸' => 'chorhojčka: Lesotho',
    '🇱🇹' => 'chorhojčka: Litawska',
    '🇱🇺' => 'chorhojčka: Luxemburgska',
    '🇱🇻' => 'chorhojčka: Letiska',
    '🇱🇾' => 'chorhojčka: Libyska',
    '🇲🇦' => 'chorhojčka: Marokko',
    '🇲🇨' => 'chorhojčka: Monaco',
    '🇲🇩' => 'chorhojčka: Moldawska',
    '🇲🇪' => 'chorhojčka: Montenegro',
    '🇲🇫' => 'chorhojčka: St. Martin',
    '🇲🇬' => 'chorhojčka: Madagaskar',
    '🇲🇭' => 'chorhojčka: Marshallowe kupy',
    '🇲🇰' => 'chorhojčka: Serwjerna Makedonska',
    '🇲🇱' => 'chorhojčka: Mali',
    '🇲🇲' => 'chorhojčka: Myanmar',
    '🇲🇳' => 'chorhojčka: Mongolska',
    '🇲🇴' => 'chorhojčka: Wosebita zarjadniska cona Macao',
    '🇲🇵' => 'chorhojčka: Sewjerne Mariany',
    '🇲🇶' => 'chorhojčka: Martinique',
    '🇲🇷' => 'chorhojčka: Mawretanska',
    '🇲🇸' => 'chorhojčka: Montserrat',
    '🇲🇹' => 'chorhojčka: Malta',
    '🇲🇺' => 'chorhojčka: Mauritius',
    '🇲🇻' => 'chorhojčka: Malediwy',
    '🇲🇼' => 'chorhojčka: Malawi',
    '🇲🇽' => 'chorhojčka: Mexiko',
    '🇲🇾' => 'chorhojčka: Malajzija',
    '🇲🇿' => 'chorhojčka: Mosambik',
    '🇳🇦' => 'chorhojčka: Namibija',
    '🇳🇨' => 'chorhojčka: Nowa Kaledoniska',
    '🇳🇪' => 'chorhojčka: Niger',
    '🇳🇫' => 'chorhojčka: Norfolkowa kupa',
    '🇳🇬' => 'chorhojčka: Nigerija',
    '🇳🇮' => 'chorhojčka: Nikaragua',
    '🇳🇱' => 'chorhojčka: Nižozemska',
    '🇳🇴' => 'chorhojčka: Norwegska',
    '🇳🇵' => 'chorhojčka: Nepal',
    '🇳🇷' => 'chorhojčka: Nauru',
    '🇳🇺' => 'chorhojčka: Niue',
    '🇳🇿' => 'chorhojčka: Nowoseelandska',
    '🇴🇲' => 'chorhojčka: Oman',
    '🇵🇦' => 'chorhojčka: Panama',
    '🇵🇪' => 'chorhojčka: Peru',
    '🇵🇫' => 'chorhojčka: Francoska Polyneziska',
    '🇵🇬' => 'chorhojčka: Papuwa-Nowa Gineja',
    '🇵🇭' => 'chorhojčka: Filipiny',
    '🇵🇰' => 'chorhojčka: Pakistan',
    '🇵🇱' => 'chorhojčka: Pólska',
    '🇵🇲' => 'chorhojčka: St. Pierre a Miquelon',
    '🇵🇳' => 'chorhojčka: Pitcairnowe kupy',
    '🇵🇷' => 'chorhojčka: Puerto Rico',
    '🇵🇸' => 'chorhojčka: Palestinski awtonomny teritorij',
    '🇵🇹' => 'chorhojčka: Portugalska',
    '🇵🇼' => 'chorhojčka: Palau',
    '🇵🇾' => 'chorhojčka: Paraguay',
    '🇶🇦' => 'chorhojčka: Katar',
    '🇷🇪' => 'chorhojčka: Réunion',
    '🇷🇴' => 'chorhojčka: Rumunska',
    '🇷🇸' => 'chorhojčka: Serbiska',
    '🇷🇺' => 'chorhojčka: Ruska',
    '🇷🇼' => 'chorhojčka: Ruanda',
    '🇸🇦' => 'chorhojčka: Sawdi-Arabska',
    '🇸🇧' => 'chorhojčka: Salomony',
    '🇸🇨' => 'chorhojčka: Seychelle',
    '🇸🇩' => 'chorhojčka: Sudan',
    '🇸🇪' => 'chorhojčka: Šwedska',
    '🇸🇬' => 'chorhojčka: Singapur',
    '🇸🇭' => 'chorhojčka: St. Helena',
    '🇸🇮' => 'chorhojčka: Słowjenska',
    '🇸🇯' => 'chorhojčka: Svalbard a Jan Mayen',
    '🇸🇰' => 'chorhojčka: Słowakska',
    '🇸🇱' => 'chorhojčka: Sierra Leone',
    '🇸🇲' => 'chorhojčka: San Marino',
    '🇸🇳' => 'chorhojčka: Senegal',
    '🇸🇴' => 'chorhojčka: Somalija',
    '🇸🇷' => 'chorhojčka: Surinam',
    '🇸🇸' => 'chorhojčka: Južny Sudan',
    '🇸🇹' => 'chorhojčka: São Tomé a Príncipe',
    '🇸🇻' => 'chorhojčka: El Salvador',
    '🇸🇽' => 'chorhojčka: Sint Maarten',
    '🇸🇾' => 'chorhojčka: Syriska',
    '🇸🇿' => 'chorhojčka: Swaziska',
    '🇹🇦' => 'chorhojčka: Tristan da Cunha',
    '🇹🇨' => 'chorhojčka: kupy Turks a Caicos',
    '🇹🇩' => 'chorhojčka: Čad',
    '🇹🇫' => 'chorhojčka: Francoski južny a antarktiski teritorij',
    '🇹🇬' => 'chorhojčka: Togo',
    '🇹🇭' => 'chorhojčka: Thailandska',
    '🇹🇯' => 'chorhojčka: Tadźikistan',
    '🇹🇰' => 'chorhojčka: Tokelau',
    '🇹🇱' => 'chorhojčka: Timor-Leste',
    '🇹🇲' => 'chorhojčka: Turkmeniska',
    '🇹🇳' => 'chorhojčka: Tuneziska',
    '🇹🇴' => 'chorhojčka: Tonga',
    '🇹🇷' => 'chorhojčka: Turkowska',
    '🇹🇹' => 'chorhojčka: Trinidad a Tobago',
    '🇹🇻' => 'chorhojčka: Tuvalu',
    '🇹🇼' => 'chorhojčka: Taiwan',
    '🇹🇿' => 'chorhojčka: Tansanija',
    '🇺🇦' => 'chorhojčka: Ukraina',
    '🇺🇬' => 'chorhojčka: Uganda',
    '🇺🇲' => 'chorhojčka: Ameriska Oceaniska',
    '🇺🇳' => 'chorhojčka: Zjednoćene narody',
    '🇺🇸' => 'chorhojčka: Zjednoćene staty Ameriki',
    '🇺🇾' => 'chorhojčka: Uruguay',
    '🇺🇿' => 'chorhojčka: Uzbekistan',
    '🇻🇦' => 'chorhojčka: Vatikanske město',
    '🇻🇨' => 'chorhojčka: St. Vincent a Grenadiny',
    '🇻🇪' => 'chorhojčka: Venezuela',
    '🇻🇬' => 'chorhojčka: Britiske knježniske kupy',
    '🇻🇮' => 'chorhojčka: Ameriske knježniske kupy',
    '🇻🇳' => 'chorhojčka: Vietnam',
    '🇻🇺' => 'chorhojčka: Vanuatu',
    '🇼🇫' => 'chorhojčka: Wallis a Futuna',
    '🇼🇸' => 'chorhojčka: Samoa',
    '🇽🇰' => 'chorhojčka: Kosowo',
    '🇾🇪' => 'chorhojčka: Jemen',
    '🇾🇹' => 'chorhojčka: Mayotte',
    '🇿🇦' => 'chorhojčka: Južna Afrika (Republika)',
    '🇿🇲' => 'chorhojčka: Sambija',
    '🇿🇼' => 'chorhojčka: Simbabwe',
    '🔟' => 'tłóčatko: 10',
    '🏻' => 'swětła barba kože',
    '🏼' => 'srěnjoswětła barba kože',
    '🏽' => 'srěnja barba kože',
    '🏾' => 'srěnjoćmowa barba kože',
    '🏿' => 'ćmowa barba kože',
    '😀' => 'wobličo ze šibałym posměwkom',
    '😃' => 'wobličo ze šibałym posměwkom a wulkimaj wočomaj',
    '😄' => 'wobličo ze šibałym posměwkom a so smějacymaj wočomaj',
    '😁' => 'wobličo ze zbožownym posměwkom a so smějacymaj wočomaj',
    '😆' => 'wobličo ze šibałym posměwkom a zašćipnjenymaj wočomaj',
    '😅' => 'wobličo ze šibałym posměwkom a kapku pota',
    '🤣' => 'so ze směchom na špundowanju waleć',
    '😂' => 'wobličo ze sylzami radosće',
    '🙂' => 'so tróšku posměwkowace wobličo',
    '🙃' => 'znak stejace wobličo',
    '🫠' => 'rozběžace wobličo',
    '😉' => 'wobličo, kiž ći přimiknje',
    '😊' => 'wobličo z posměwkom a so smějacymaj wočomaj',
    '😇' => 'wobličo z posměwkom a swjatosćinom',
    '🥰' => 'wobličo z posměwkom a wutrobičkami',
    '😍' => 'wobličo ze šibałym posměwkom a wutrobičkojtymaj wočomaj',
    '🤩' => 'přemóženy',
    '😘' => 'wobličo, kiž sćele hubku',
    '😗' => 'hubkowace wobličo',
    '☺' => 'wobličo z posměwkom',
    '😚' => 'košace wobličo ze zawrjenymaj wočomaj',
    '😙' => 'hubkowace wobličo ze so smějacymaj wočomaj',
    '🥲' => 'so smějace wobličo ze sylzu',
    '😋' => 'wobličo, kiž sej hubje woblizuje',
    '😛' => 'wobličo z wutyknjenym jazykom',
    '😜' => 'wobličo, kiž ći z wutyknjenym jazykom přimiknje',
    '🤪' => 'błudne wobličo',
    '😝' => 'wobličo z wutyknjenym jazykom a zašćipnjenymaj wočomaj',
    '🤑' => 'wobličo z dolarowymi znamješkami',
    '🤗' => 'wobličo z wobjimacymaj rukomaj',
    '🤭' => 'wobličo z ruku nad hubu',
    '🫢' => 'wobličo z wočinjenymaj wočomaj a ruku na hubje',
    '🫣' => 'wobličo z kukacym wóčkom',
    '🤫' => 'napominace wobličo',
    '🤔' => 'wobličo, kiž rozmysluje',
    '🫡' => 'salutěrowace wobličo',
    '🤐' => 'wobličo ze zasmykom na hubje',
    '🤨' => 'wobličo z horje sćehnjenej brjowku',
    '😐' => 'neutralne wobličo',
    '😑' => 'wobličo bjez wuraza',
    '😶' => 'wobličo bjez huby',
    '🫥' => 'wobličo z dypkowanej smužku',
    '😏' => 'wobličo, kiž so samospodobnje směje',
    '😒' => 'hněwne wobličo',
    '🙄' => 'wobličo, kiž wjerći z wočomaj',
    '😬' => 'wobličo z grimasu',
    '🤥' => 'wobličo, kiž łži',
    '🫨' => 'třepotate mjezwočo',
    '😌' => 'wolóžene wobličo',
    '😔' => 'zamyslene wobličo',
    '😪' => 'sparne wobličo',
    '🤤' => 'wobličo, kotremuž sliny zběža',
    '😴' => 'wobličo, kotrež spi',
    '🫩' => 'wobličo ze sylzowymaj měškomaj pod wočomaj',
    '😷' => 'wobličo z nahubnikom',
    '🤒' => 'wobličo ze zymicowym termometrom',
    '🤕' => 'wobličo z wobwjazom wokoło hłowy',
    '🤢' => 'wobličo, kotremuž je špatne',
    '🤮' => 'bluwace wobličo',
    '🤧' => 'wobličo, kiž třichnje',
    '🥵' => 'wobličo, kiž so poći',
    '🥶' => 'wobličo, kiž zymu mrěje',
    '🥴' => 'zawjerćane wobličo',
    '😵' => 'wobličo, kotremuž so we hłowje wjerći',
    '🤯' => 'hłowa, kotraž rozbuchnje',
    '🤠' => 'wobličo z cowboyjowym kłobukom',
    '🥳' => 'wobličo, kiž swjeći',
    '🥸' => 'předrasćene wobličo',
    '😎' => 'wobličo z posměwkom a słónčnymi nawočemi',
    '🤓' => 'wobličo prócowaka',
    '🧐' => 'wobličo z monoklom',
    '😕' => 'bjezradne wobličo',
    '🫤' => 'wobličo z diagonalnej hubu',
    '😟' => 'starosćiwe wobličo',
    '🙁' => 'zrudźene wobličo',
    '☹' => 'wobličo, kiž zmoršći tróšku čoło',
    '😮' => 'wobličo z wočinjenej hubu',
    '😯' => 'překwapjene wobličo',
    '😲' => 'zadźiwane wobličo',
    '😳' => 'wobličo, kiž je so začerwjeniło a ma wulkej woči',
    '🫪' => 'sćehnjene wobličo',
    '🥺' => 'prošace wobličo',
    '🥹' => 'wobličo, kiž dźerži sylzy wróćo',
    '😦' => 'wobličo, kotremuž so zecnje',
    '😧' => 'čwělowane wobličo',
    '😨' => 'bojazliwe wobličo',
    '😰' => 'starosćiwe wobličo z kapku pota',
    '😥' => 'zrudne abo wolóžene wobličo',
    '😢' => 'płakace wobličo',
    '😭' => 'wobličo, kiž bječi',
    '😱' => 'wobličo, kiž ze strachom rjeji',
    '😖' => 'dospołnje bjezradne wobličo',
    '😣' => 'zasakłe wobličo',
    '😞' => 'přesłapjene wobličo',
    '😓' => 'poražene wobličo z kapku pota',
    '😩' => 'wučerpane wobličo',
    '😫' => 'mučne wobličo',
    '🥱' => 'zywace wobličo',
    '😤' => 'wobličo, kotremuž para z nosa stupa',
    '😡' => 'wobličo, kiž kózlika wjaza',
    '😠' => 'rozhněwane wobličo',
    '🤬' => 'wobličo ze symbolemi nad hubu',
    '😈' => 'so šćěrjace wobličo z rohomaj',
    '👿' => 'hněwne wobličo z rohomaj',
    '💀' => 'nop',
    '☠' => 'nop ze skřižowanymaj kosćomaj',
    '💩' => 'hromadka howna',
    '🤡' => 'wobličo clowna',
    '👹' => 'potwora',
    '👺' => 'maska kubołta',
    '👻' => 'duch',
    '👽' => 'alien',
    '👾' => 'monster z kompjuteroweje hry',
    '🤖' => 'roboter',
    '😺' => 'kóčka ze šibałym posměwkom',
    '😸' => 'kóčka ze šibałym posměwkom a so smějacymaj wočomaj',
    '😹' => 'kóčka ze sylzami radosće',
    '😻' => 'kóčka ze šibałym posměwkom a wutrobičkojtymaj wočomaj',
    '😼' => 'kóčka z kisałym posměwkom',
    '😽' => 'hubkowaca kóčka',
    '🙀' => 'wučerpana kóčka',
    '😿' => 'płakaca kóčka',
    '😾' => 'kóčka, kiž kózlika wjaza',
    '🙈' => 'wopica, kiž sej woči zadźerži',
    '🙉' => 'wopica, kiž sej wuši zadźerži',
    '🙊' => 'wopica, kiž sej hubu zadźerži',
    '💌' => 'lubosćinski list',
    '💘' => 'wutrobička z kłokom',
    '💝' => 'wutrobička ze seklu',
    '💖' => 'so zybolaca wutrobička',
    '💗' => 'rosćaca wutrobička',
    '💓' => 'pukotaca wutrobička',
    '💞' => 'kružacej wutrobičce',
    '💕' => 'dwě wutrobičce',
    '💟' => 'dekoracija z wutrobičku',
    '❣' => 'wutrobička jako wuwołak',
    '💔' => 'złamana wutrobička',
    '❤' => 'čerwjena wutrobička',
    '🩷' => 'róžojta wutroba',
    '🧡' => 'oranžojta wutrobička',
    '💛' => 'žołta wutrobička',
    '💚' => 'zelena wutrobička',
    '💙' => 'módra wutrobička',
    '🩵' => 'swětłomódra wutroba',
    '💜' => 'fijałkojta wutrobička',
    '🤎' => 'bruna wutrobička',
    '🖤' => 'čorna wutrobička',
    '🩶' => 'šěra wutroba',
    '🤍' => 'běła wutrobička',
    '💋' => 'wotćišć hubki',
    '💯' => 'sto dypkow',
    '💢' => 'symbol hněwanja',
    '🫯' => 'mróčel wojowanja',
    '💥' => 'zražka',
    '💫' => 'wjerćenje we hłowje',
    '💦' => 'kapki pota',
    '💨' => 'so z procha měć',
    '🕳' => 'dźěra',
    '💬' => 'rěčny pucher z třomi dypkami',
    '🗨' => 'rěčny pucher nalěwo',
    '🗯' => 'rěčny pucher za hněwne wuprajenje naprawo',
    '💭' => 'myslowy pucher',
    '💤' => 'spać',
    '👋' => 'kiwaca ruka',
    '🤚' => 'zběhnjena ruka wotzady',
    '🖐' => 'ruka z rozšěrjenymi porstami',
    '✋' => 'zběhnjena ruka',
    '🖖' => 'wulkaniski postrow',
    '🫱' => 'ruka doprawa',
    '🫲' => 'ruka dolěwa',
    '🫳' => 'dłóń pokazuje dele',
    '🫴' => 'dłóń pokazuje horje',
    '🫷' => 'ruka, kiž tłóči dolěwa',
    '🫸' => 'ruka, kiž tłóči doprawa',
    '👌' => 'gesta "w porjadku"',
    '🤌' => 'hromadźe stłóčene porsty',
    '🤏' => 'gesta "mało"',
    '✌' => 'gesta dobyća',
    '🤞' => 'ruka ze skřižowanymaj porstomaj',
    '🫰' => 'ruka z křižowanym pokazowakom a palcom',
    '🤟' => 'gesta "ja će lubuju"',
    '🤘' => 'gesta rohow',
    '🤙' => 'gesta "zazwoń mje"',
    '👈' => 'pokazowak, kiž pokazuje dolěwa',
    '👉' => 'pokazowak, kiž pokazuje doprawa',
    '👆' => 'pokazowak, kiž pokazuje horje, wotzady',
    '🖕' => 'srjedźny porst',
    '👇' => 'pokazowak, kiž pokazuje dele',
    '☝' => 'pokazowak, kiž pokazuje horje, wotprědka',
    '🫵' => 'pokazowak, wusměrjeny na hladaceho',
    '👍' => 'palc horje',
    '👎' => 'palc dele',
    '✊' => 'zběhnjena pjasć',
    '👊' => 'spinana pjasć',
    '🤛' => 'pjasć dolěwa',
    '🤜' => 'pjasć doprawa',
    '👏' => 'ruce, kiž přikleskujetej',
    '🙌' => 'zběhnjenej ruce',
    '🫶' => 'ruce tworitej formu wutroby',
    '👐' => 'wočinjenej ruce',
    '🤲' => 'zběhnjenej dłóni pódla so',
    '🤝' => 'zawdaće ruki',
    '🙏' => 'styknjenej ruce',
    '✍' => 'ruka, kiž pisa',
    '💅' => 'lak za nochće',
    '🤳' => 'selfie',
    '💪' => 'napjaty biceps',
    '🦾' => 'mechaniska ruka',
    '🦿' => 'mechaniska noha',
    '🦵' => 'cyła noha',
    '🦶' => 'delnja noha',
    '👂' => 'wucho',
    '🦻' => 'wucho ze słuchadłom',
    '👃' => 'nós',
    '🧠' => 'mozy',
    '🫀' => 'anatomiska wutroba (organ)',
    '🫁' => 'płuca',
    '🦷' => 'zub',
    '🦴' => 'kósć',
    '👀' => 'woči',
    '👁' => 'wóčko',
    '👅' => 'jazyk',
    '👄' => 'huba',
    '🫦' => 'huba, kiž sej na delnju hubu kusnje',
    '👶' => 'ćěšenk',
    '🧒' => 'dźěćo',
    '👦' => 'hólc',
    '👧' => 'holca',
    '🧑' => 'dorosćeny',
    '👱' => 'wosoba: blond włosy',
    '👨' => 'muž',
    '🧔' => 'wosoba: broda',
    '👩' => 'žona',
    '🧓' => 'starša wosoba',
    '👴' => 'stary muž',
    '👵' => 'stara žona',
    '🙍' => 'wosoba, kiž moršći čoło',
    '🙎' => 'wosoba, kiž kózlika wjaza',
    '🙅' => 'wosoba z překřižowanymaj rukomaj',
    '🙆' => 'wosoba z rukomaj na hłowje',
    '💁' => 'wosoba z dłónju horje',
    '🙋' => 'wosoba ze zběhnjenej ruku',
    '🧏' => 'hłucha wosoba',
    '🙇' => 'wosoba, kiž so pokłoni',
    '🤦' => 'wosoba, kiž so za hłowu přimnje',
    '🤷' => 'wosoba, kiž z ramjenjomaj suknje',
    '👮' => 'policist/ka',
    '🕵' => 'detektiw/ka',
    '💂' => 'stražnik/ stražnica',
    '🥷' => 'ninja',
    '👷' => 'twarski dźěłaćer/ twarska dźěłaćerka',
    '🫅' => 'wosoba z krónu',
    '🤴' => 'princ',
    '👸' => 'princesna',
    '👳' => 'wosoba z turbanom',
    '👲' => 'muž z chinskej čapku',
    '🧕' => 'žona z rubiškom',
    '🤵' => 'wosoba w smokingu',
    '👰' => 'wosoba ze šlewjerjom',
    '🤰' => 'samodruha',
    '🫃' => 'samodruhi muž',
    '🫄' => 'samodruha wosoba',
    '🤱' => 'ćěšić',
    '👼' => 'jandźelk',
    '🎅' => 'rumpodich',
    '🤶' => 'rumpodichowka',
    '🦸' => 'superrjek/ superrjekowka',
    '🦹' => 'superšamałc/superšamałča',
    '🧙' => 'kuzłar/niča',
    '🧚' => 'sonina',
    '🧛' => 'wampir',
    '🧜' => 'wosoba z morja',
    '🧝' => 'soninak',
    '🧞' => 'duch z bleše',
    '🧟' => 'zombie',
    '🧌' => 'kubołt',
    '🫈' => 'kosmata potwora',
    '💆' => 'wosoba, kiž dóstanje masažu hłowy',
    '💇' => 'wosoba, kiž da sej włosy třihać',
    '🚶' => 'wosoba, kiž je pěši po puću',
    '🧍' => 'stejaca wosoba',
    '🧎' => 'klečaca wosoba',
    '🏃' => 'běhaca wosoba',
    '💃' => 'rejowaca žona',
    '🕺' => 'rejowacy muž',
    '🕴' => 'muž we wobleku, kiž so znošuje',
    '👯' => 'wosobje ze zaječimaj wušomaj',
    '🧖' => 'wosoba w sawnje',
    '🧗' => 'krosnowar/ka',
    '🤺' => 'tesakowar/ka',
    '🏇' => 'wubědźowanje na konjach',
    '⛷' => 'sněhakowar/ka',
    '🏂' => 'snowboarder/ka',
    '🏌' => 'wosoba, kiž hraje golf',
    '🏄' => 'wosoba při surfowanju',
    '🚣' => 'wosoba při wjesłowanju',
    '🏊' => 'płuwaca wosoba',
    '⛹' => 'wosoba z bulom',
    '🏋' => 'wosoba, kiž zběha wahi',
    '🚴' => 'wosoba, kiž kolesuje',
    '🚵' => 'wosoba, kiž jězdźi z mountainbikom',
    '🤸' => 'wosoba, kiž so nabok přemjetuje',
    '🤼' => 'wosobje, kiž wjerhatej',
    '🤽' => 'wosoba, kiž hraje wodobul',
    '🤾' => 'wosoba, kiž hraje mjetańcu',
    '🤹' => 'wosoba, kiž žonglěruje',
    '🧘' => 'wosoba w lotosowym sydźe',
    '🛀' => 'wosoba, kiž so kupa',
    '🛌' => 'wosoba we łožu',
    '👭' => 'žonje dźeržitej so za ruku',
    '👫' => 'muž a žona dźeržitaj so za ruku',
    '👬' => 'mužej dźeržitaj so za ruku',
    '💏' => 'porik, kiž so koši',
    '💑' => 'porik z wutrobičku',
    '🗣' => 'rěčaca hłowa',
    '👤' => 'silueta wosoby',
    '👥' => 'silueta dweju wosobow',
    '🫂' => 'wosobje, kiž so wobjimatej',
    '👪' => 'swójba',
    '👣' => 'stopje',
    '🫆' => 'wotćišć porsta',
    '🦰' => 'čerwjene włosy',
    '🦱' => 'kudźerjate włosy',
    '🦳' => 'šědźiwe włosy',
    '🦲' => 'plěch',
    '🐵' => 'hłowa wopicy',
    '🐒' => 'wopica',
    '🦍' => 'gorila',
    '🦧' => 'orang-utan',
    '🐶' => 'hłowa psa',
    '🐕' => 'pos',
    '🦮' => 'pos za slepych',
    '🐩' => 'pudl',
    '🐺' => 'hłowa wjelka',
    '🦊' => 'hłowa liški',
    '🦝' => 'hłowa šupa',
    '🐱' => 'hłowa kóčki',
    '🐈' => 'kóčka',
    '🦁' => 'hłowa lawa',
    '🐯' => 'hłowa tigra',
    '🐅' => 'tiger',
    '🐆' => 'leopard',
    '🐴' => 'hłowa konja',
    '🫎' => 'hłowa łosa',
    '🫏' => 'wóslik',
    '🐎' => 'kóń',
    '🦄' => 'hłowa jednorohača',
    '🦓' => 'hłowa cebry',
    '🦌' => 'jeleń',
    '🦬' => 'bizon',
    '🐮' => 'hłowa kruwy',
    '🐂' => 'woł',
    '🐃' => 'wódny buwoł',
    '🐄' => 'kruwa',
    '🐷' => 'hłowa swinjeća',
    '🐖' => 'swinjo',
    '🐗' => 'hłowa dźiwjeho swinjeća',
    '🐽' => 'rydło',
    '🐏' => 'boran',
    '🐑' => 'wowca',
    '🐐' => 'koza',
    '🐪' => 'dromedar',
    '🐫' => 'kamel',
    '🦙' => 'lama',
    '🦒' => 'hłowa girafy',
    '🐘' => 'elefant',
    '🦣' => 'mamut',
    '🦏' => 'nosorohač',
    '🦛' => 'wodosłon',
    '🐭' => 'hłowa myški',
    '🐁' => 'myš',
    '🐀' => 'šćura',
    '🐹' => 'hłowa žurka',
    '🐰' => 'hłowa zajaca',
    '🐇' => 'zajac',
    '🐿' => 'wjewjerčka',
    '🦫' => 'bobr',
    '🦔' => 'jěž',
    '🦇' => 'njetopyr',
    '🐻' => 'hłowa mjedwjedźa',
    '🐨' => 'hłowa koale',
    '🐼' => 'hłowa pandy',
    '🦥' => 'lěniwc',
    '🦦' => 'wudra',
    '🦨' => 'skunk',
    '🦘' => 'kenguru',
    '🦡' => 'šwinc',
    '🐾' => 'wotćišćej packow',
    '🦃' => 'trutak',
    '🐔' => 'hłowa kokoše',
    '🐓' => 'honač',
    '🐣' => 'ćipka, kiž so z jejka wudypa',
    '🐤' => 'ćipka',
    '🐥' => 'ćipka wotprědka',
    '🐦' => 'ptačk',
    '🐧' => 'pinguin',
    '🕊' => 'hołb',
    '🦅' => 'worjoł',
    '🦆' => 'kačka',
    '🦢' => 'kołp',
    '🦉' => 'sowa',
    '🦤' => 'dodo',
    '🪶' => 'pjerjo',
    '🦩' => 'flamingo',
    '🦚' => 'paw',
    '🦜' => 'papagaj',
    '🪽' => 'křidło',
    '🪿' => 'huso',
    '🐸' => 'hłowa žaby',
    '🐊' => 'krokodil',
    '🐢' => 'nopawa',
    '🦎' => 'ješćelca',
    '🐍' => 'had',
    '🐲' => 'hłowa zmija',
    '🐉' => 'mytologiski zmij',
    '🦕' => 'brontosaurus',
    '🦖' => 'tyrannosaurus rex',
    '🐳' => 'wjelryba, kiž wodu pryska',
    '🐋' => 'wjelryba',
    '🐬' => 'delfin',
    '🫍' => 'orka',
    '🦭' => 'ćuleń',
    '🐟' => 'ryba',
    '🐠' => 'tropiska ryba',
    '🐡' => 'kuloryba',
    '🦈' => 'žrawc',
    '🐙' => 'kraka',
    '🐚' => 'šlinkowa chěžka',
    '🪸' => 'korala',
    '🪼' => 'kwala',
    '🦀' => 'rak',
    '🦞' => 'humer',
    '🦐' => 'garnela',
    '🦑' => 'čornica',
    '🦪' => 'wustrica',
    '🐌' => 'šlink',
    '🦋' => 'mjetelčka',
    '🐛' => 'husańca',
    '🐜' => 'mrowja',
    '🐝' => 'pčołka',
    '🪲' => 'bruk',
    '🐞' => 'bože słónčko',
    '🦗' => 'šwjerč',
    '🪳' => 'škaber',
    '🕷' => 'pawk',
    '🕸' => 'pawčina',
    '🦂' => 'skorpion',
    '🦟' => 'kuntwora',
    '🪰' => 'mucha',
    '🪱' => 'wačka',
    '🦠' => 'mikroba',
    '💐' => 'kwěćel',
    '🌸' => 'kćenje wišnje',
    '💮' => 'běłe kćenje',
    '🪷' => 'lotusowe kćenje',
    '🏵' => 'róžica',
    '🌹' => 'róža',
    '🥀' => 'zwjadła kwětka',
    '🌺' => 'hibiskus',
    '🌻' => 'słónčna róža',
    '🌼' => 'kwětka',
    '🌷' => 'tulpa',
    '🪻' => 'hyacinta',
    '🌱' => 'sadźenk',
    '🪴' => 'rostlina w horncu',
    '🌲' => 'jehlinowc',
    '🌳' => 'lisćowc',
    '🌴' => 'palma',
    '🌵' => 'kaktus',
    '🌾' => 'kłóska rajsa',
    '🌿' => 'zela',
    '☘' => 'dźećel',
    '🍀' => 'zbožo',
    '🍁' => 'łopjeno jawora',
    '🍂' => 'lisćo',
    '🍃' => 'łopjena we wětřiku',
    '🪹' => 'prózdne hnězdo',
    '🪺' => 'hnězdo z jejkomaj',
    '🍄' => 'muchorizna',
    '🪾' => 'štom bjez lisća',
    '🍇' => 'winowa kić',
    '🍈' => 'mjedowa melona',
    '🍉' => 'melona',
    '🍊' => 'mandarina',
    '🍋' => 'citrona',
    '🍌' => 'banana',
    '🍍' => 'ananas',
    '🥭' => 'mango',
    '🍎' => 'čerwjene jabłuko',
    '🍏' => 'zelene jabłuko',
    '🍐' => 'krušwa',
    '🍑' => 'brěšk',
    '🍒' => 'wišnje',
    '🍓' => 'truskalca',
    '🫐' => 'módre jahodki',
    '🥝' => 'kiwi',
    '🍅' => 'tomata',
    '🫒' => 'oliwa',
    '🥥' => 'kokosowy worjech',
    '🥑' => 'awokado',
    '🍆' => 'aubergina',
    '🥔' => 'běrna',
    '🥕' => 'morchej',
    '🌽' => 'kukuricowy potač',
    '🌶' => 'peperoni',
    '🫑' => 'paprika',
    '🥒' => 'kórka',
    '🥬' => 'łopjenojta zelenina',
    '🥦' => 'brokoli',
    '🧄' => 'kobołk',
    '🧅' => 'cybla',
    '🥜' => 'zemski worješk',
    '🫘' => 'buny',
    '🌰' => 'kastanija',
    '🫚' => 'ingwer',
    '🫛' => 'truk hrocha',
    '🫜' => 'korjenjowa zelenina',
    '🍞' => 'chlěb',
    '🥐' => 'croissant',
    '🥖' => 'baguette',
    '🫓' => 'plincaty chlěb',
    '🥨' => 'bracl',
    '🥯' => 'bagel',
    '🥞' => 'plincy',
    '🧇' => 'wafla',
    '🧀' => 'kusk twarožka',
    '🍖' => 'mjaso na kósći',
    '🍗' => 'kokošaca nóžka',
    '🥩' => 'časć mjasa',
    '🥓' => 'połć',
    '🍔' => 'hamburger',
    '🍟' => 'pomfritki',
    '🍕' => 'pica',
    '🌭' => 'hotdog',
    '🥪' => 'pomazka',
    '🌮' => 'taco',
    '🌯' => 'burrito',
    '🫔' => 'tamale',
    '🥙' => 'dener',
    '🧆' => 'falafel',
    '🥚' => 'jejko',
    '🍳' => 'pražene jejko',
    '🥘' => 'pónoj z jědźu',
    '🍲' => 'hornc z jědźu',
    '🫕' => 'fondue',
    '🥣' => 'škla z łžicu',
    '🥗' => 'solotej',
    '🍿' => 'popcorn',
    '🧈' => 'butra',
    '🧂' => 'sel',
    '🥫' => 'konserwowa tyzka',
    '🍱' => 'bento-tyzka',
    '🍘' => 'rajsowy cracker',
    '🍙' => 'rajsowa kulka',
    '🍚' => 'zwarjeny rajs',
    '🍛' => 'rajs z curryjom',
    '🍜' => 'škla z parjacej so jědźu',
    '🍝' => 'spageti',
    '🍠' => 'pražena słódka běrna',
    '🍢' => 'oden',
    '🍣' => 'sushi',
    '🍤' => 'fritěrowana garnela',
    '🍥' => 'kamaboko',
    '🥮' => 'měsačkowy tykanc',
    '🍡' => 'dango',
    '🥟' => 'piroga',
    '🥠' => 'keks z wěšćenjom',
    '🥡' => 'tyzka za jědź',
    '🍦' => 'mjechki lód',
    '🍧' => 'truhany lód',
    '🍨' => 'kulki loda',
    '🍩' => 'donut',
    '🍪' => 'poprjanc',
    '🎂' => 'narodninski tykanc',
    '🍰' => 'kusk torty',
    '🧁' => 'tykančk',
    '🥧' => 'skibka tykanca',
    '🍫' => 'tafla šokolody',
    '🍬' => 'plack',
    '🍭' => 'lizak',
    '🍮' => 'puding',
    '🍯' => 'hornčk mjeda',
    '🍼' => 'bleška za ćěšenka',
    '🥛' => 'škleńca mloka',
    '☕' => 'horcy napoj',
    '🫖' => 'čajowa kana',
    '🍵' => 'šalka čaja bjez wuška',
    '🍶' => 'sake',
    '🍾' => 'bleša sekta',
    '🍷' => 'winowa škleńca',
    '🍸' => 'cocktailowa škleńca',
    '🍹' => 'tropiski cocktail',
    '🍺' => 'karan piwa',
    '🍻' => 'karanaj piwa',
    '🥂' => 'sektowej škleńcy',
    '🥃' => 'škleńca k piću',
    '🫗' => 'kapalinu wuleć',
    '🥤' => 'škleńca z trosku',
    '🧋' => 'bubble tea',
    '🧃' => 'napoj w kartonku',
    '🧉' => 'mate-čaj',
    '🧊' => 'lodowa kóstka',
    '🥢' => 'štabiki',
    '🍽' => 'taler z nožom a widličkami',
    '🍴' => 'widlički a nóž',
    '🥄' => 'łžica',
    '🔪' => 'kuchinski nóž',
    '🫙' => 'sudobjo',
    '🏺' => 'amfora',
    '🌍' => 'zemska kula z Europu a Afriku',
    '🌎' => 'zemska kula z Ameriku',
    '🌏' => 'zemska kula z Aziju a Awstraliju',
    '🌐' => 'zemska kula z dołhostnikami a šěrokostnikami',
    '🗺' => 'swětowa karta',
    '🗾' => 'karta Japanskeje',
    '🧭' => 'kompas',
    '🏔' => 'hora ze zasněženym wjerchom',
    '⛰' => 'hora',
    '🛘' => 'zesunjenje zemje',
    '🌋' => 'wulkan',
    '🗻' => 'hora Fuji',
    '🏕' => 'stanowanje',
    '🏖' => 'přibrjóh ze słónčnikom',
    '🏜' => 'pusćina',
    '🏝' => 'samotna kupa',
    '🏞' => 'narodny park',
    '🏟' => 'stadion',
    '🏛' => 'antikne twarjenje',
    '🏗' => 'twarnišćo',
    '🧱' => 'cyhel',
    '🪨' => 'skała',
    '🪵' => 'drjewo',
    '🛖' => 'chata',
    '🏘' => 'domy',
    '🏚' => 'wopušćeny dom',
    '🏠' => 'dom',
    '🏡' => 'dom ze zahrodu',
    '🏢' => 'běrowowe twarjenje',
    '🏣' => 'japanska póšta',
    '🏤' => 'póstowy zarjad',
    '🏥' => 'chorownja',
    '🏦' => 'banka',
    '🏨' => 'hotel',
    '🏩' => 'hodźinski hotel',
    '🏪' => 'wobchod',
    '🏫' => 'šula',
    '🏬' => 'kupnica',
    '🏭' => 'fabrika',
    '🏯' => 'japanski hród',
    '🏰' => 'hród',
    '💒' => 'kwas',
    '🗼' => 'Tokioska wěža',
    '🗽' => 'Postawa swobody',
    '⛪' => 'cyrkej',
    '🕌' => 'mošeja',
    '🛕' => 'hinduistiski templ',
    '🕍' => 'synagoga',
    '⛩' => 'šintoistiske swjatnišćo',
    '🕋' => 'Kaaba',
    '⛲' => 'wodoskok',
    '⛺' => 'stan',
    '🌁' => 'młowojte',
    '🌃' => 'nóc z hwězdami',
    '🏙' => 'měšćanska silueta',
    '🌄' => 'schadźenje słónca nad horami',
    '🌅' => 'schadźenje słónca nad morjom',
    '🌆' => 'město při směrkach',
    '🌇' => 'chowanje słónca w měsće',
    '🌉' => 'móst w nocy',
    '♨' => 'horce žórła',
    '🎠' => 'kóń z karusela',
    '🛝' => 'suwadło na hrajkanišću',
    '🎡' => 'hoberske koło',
    '🎢' => 'seklowa železnička',
    '💈' => 'frizerski stołp',
    '🎪' => 'cirkusowy stan',
    '🚂' => 'parna lokomotiwa',
    '🚃' => 'wagon',
    '🚄' => 'wysokospěšny ćah',
    '🚅' => 'spěšnik',
    '🚆' => 'ćah',
    '🚇' => 'metro',
    '🚈' => 'měšćanska železnica',
    '🚉' => 'zastanišćo',
    '🚊' => 'tramwajka',
    '🚝' => 'jednokolijowa železnica',
    '🚞' => 'hórska železnica',
    '🚋' => 'wagon tramwajki',
    '🚌' => 'bus',
    '🚍' => 'bus wotprědka',
    '🚎' => 'trolejbus',
    '🚐' => 'małobus',
    '🚑' => 'chorobne awto',
    '🚒' => 'awto wohnjoweje wobory',
    '🚓' => 'policajske awto',
    '🚔' => 'policajske awto wotprědka',
    '🚕' => 'taksi',
    '🚖' => 'taksi wotprědka',
    '🚗' => 'awto',
    '🚘' => 'awto wotprědka',
    '🚙' => 'bydlenski mobil',
    '🛻' => 'pickup',
    '🚚' => 'dodawanski wóz',
    '🚛' => 'nakładne awto',
    '🚜' => 'traktor',
    '🏎' => 'wubědźowanske awto',
    '🏍' => 'motorske',
    '🛵' => 'motorroller',
    '🦽' => 'ručny jězbny stoł',
    '🦼' => 'elektriski jězbny stoł',
    '🛺' => 'awtorikša',
    '🚲' => 'koleso jako jězdźidło',
    '🛴' => 'roler k teptanju',
    '🛹' => 'skateboard',
    '🛼' => 'rólkače',
    '🚏' => 'busowe zastanišćo',
    '🛣' => 'awtodróha',
    '🛤' => 'železniske kolije',
    '🛢' => 'wolijowy sud',
    '⛽' => 'tankowanski stołp',
    '🛞' => 'koleso',
    '🚨' => 'policajska swěca',
    '🚥' => 'wodoruna ampla',
    '🚦' => 'padoruna ampla',
    '🛑' => 'stopowe znamjo',
    '🚧' => 'twarnišćowe zaraćenje',
    '⚓' => 'kótwica',
    '🛟' => 'wuchowanska boja',
    '⛵' => 'płachtak',
    '🛶' => 'kanu',
    '🚤' => 'spěšnočołm',
    '🛳' => 'pasažěrska łódź',
    '⛴' => 'přewoz',
    '🛥' => 'motorowy čołm',
    '🚢' => 'łódź',
    '✈' => 'lětadło',
    '🛩' => 'małe lětadło',
    '🛫' => 'lětadło, kiž wotleći',
    '🛬' => 'lětadło, kiž přizemi',
    '🪂' => 'padak',
    '💺' => 'městno k sedźenju',
    '🚁' => 'helikoper',
    '🚟' => 'wisata železnica',
    '🚠' => 'hórska wisata železnica',
    '🚡' => 'powjazowka',
    '🛰' => 'satelit',
    '🚀' => 'raketa',
    '🛸' => 'lětacy taler',
    '🛎' => 'zwón při recepciji',
    '🧳' => 'kófraj',
    '⌛' => 'pěskowy časnik',
    '⏳' => 'běžacy pěskowy časnik',
    '⌚' => 'ručny časnik',
    '⏰' => 'budźak',
    '⏱' => 'stopowy časnik',
    '⏲' => 'časměrjak',
    '🕰' => 'kaminowy časnik',
    '🕛' => 'w dwanaćich',
    '🕧' => 'napoł jednej',
    '🕐' => 'w jednej',
    '🕜' => 'napoł dwěmaj',
    '🕑' => 'w dwěmaj',
    '🕝' => 'napoł třoch',
    '🕒' => 'w třoch',
    '🕞' => 'napoł štyrjoch',
    '🕓' => 'w štyrjoch',
    '🕟' => 'napoł pjećich',
    '🕔' => 'w pjećich',
    '🕠' => 'napoł šesćich',
    '🕕' => 'w šesćich',
    '🕡' => 'napoł sedmich',
    '🕖' => 'w sedmich',
    '🕢' => 'napoł wosmich',
    '🕗' => 'we wosmich',
    '🕣' => 'napoł dźewjećich',
    '🕘' => 'w dźewjećich',
    '🕤' => 'napoł dźesaćich',
    '🕙' => 'w dźesaćich',
    '🕥' => 'napoł jědnaćich',
    '🕚' => 'w jědnaćich',
    '🕦' => 'napoł dwanaćich',
    '🌑' => 'młody měsačk',
    '🌒' => 'přiběracy měsačk',
    '🌓' => 'přiběracy połměsačk',
    '🌔' => 'nimale połny měsačk',
    '🌕' => 'połny měsačk',
    '🌖' => 'nic wjace połny měsačk',
    '🌗' => 'woteběracy połměsačk',
    '🌘' => 'woteběracy měsačk',
    '🌙' => 'serp měsačka',
    '🌚' => 'młody měsačk z wobličom',
    '🌛' => 'serp měsačka z wobličom nalěwo',
    '🌜' => 'serp měsačka z wobličom naprawo',
    '🌡' => 'termometer',
    '☀' => 'słónco',
    '🌝' => 'połny měsačk z wobličom',
    '🌞' => 'słónco z wobličom',
    '🪐' => 'planet z rynku',
    '⭐' => 'hwězda',
    '🌟' => 'so zybolaca hwězda',
    '🌠' => 'padaca hwězda',
    '🌌' => 'Mlóčna dróha',
    '☁' => 'mróčel',
    '⛅' => 'słónco za mróčelu',
    '⛈' => 'mróčel z błyskom a dešćom',
    '🌤' => 'słónco za mróčałku',
    '🌥' => 'słónco za wulkej mróčelu',
    '🌦' => 'słónco za dešćowej mróčelu',
    '🌧' => 'mróčel z dešćom',
    '🌨' => 'mróčel ze sněhom',
    '🌩' => 'mróčel z błyskom',
    '🌪' => 'wjerćaty wichor',
    '🌫' => 'mła',
    '🌬' => 'wětřik',
    '🌀' => 'cyklon',
    '🌈' => 'tučel',
    '🌂' => 'začinjeny předešćnik',
    '☂' => 'předešćnik',
    '☔' => 'předešćnik z dešćom',
    '⛱' => 'nastajeny słónčnik',
    '⚡' => 'wysoke napjeće',
    '❄' => 'sněženka',
    '☃' => 'sněhowy muž',
    '⛄' => 'sněhowy muž bjez sněha',
    '☄' => 'komet',
    '🔥' => 'woheń',
    '💧' => 'kapka',
    '🌊' => 'žołma',
    '🎃' => 'kirbsowa latarnja',
    '🎄' => 'hodowny štom',
    '🎆' => 'wohnjostroj',
    '🎇' => 'pryskotawka',
    '🧨' => 'praskotak',
    '✨' => 'so zybolace hwězdy',
    '🎈' => 'balonk',
    '🎉' => 'konfettijowa kanona',
    '🎊' => 'konfettijowa kula',
    '🎋' => 'štom přećow',
    '🎍' => 'bambusowa dekoracija',
    '🎎' => 'japanskej klance',
    '🎏' => 'japanske karpowe chorhoje',
    '🎐' => 'japanska wětrowa wjertawa',
    '🎑' => 'měsačkowy swjedźeń',
    '🧧' => 'čerwjena wobalka',
    '🎀' => 'sekla',
    '🎁' => 'dar',
    '🎗' => 'wopomnjenska sekla',
    '🎟' => 'zastupne lisćiki',
    '🎫' => 'tiket',
    '🎖' => 'wojerski rjad',
    '🏆' => 'pokal',
    '🏅' => 'sportowa medalja',
    '🥇' => 'złota medalja',
    '🥈' => 'slěborna medalja',
    '🥉' => 'bronzowa medalja',
    '⚽' => 'koparski bul',
    '⚾' => 'baseballowy bul',
    '🥎' => 'mjechki bul',
    '🏀' => 'basketballowy bul',
    '🏐' => 'wolejbulowy bul',
    '🏈' => 'footballowy bul',
    '🏉' => 'rugbyjowy bul',
    '🎾' => 'tenisowy bul',
    '🥏' => 'mjetanska tačel',
    '🎳' => 'bowling',
    '🏏' => 'kriket',
    '🏑' => 'pólny hokej',
    '🏒' => 'lodohokej',
    '🥍' => 'lacrosse',
    '🏓' => 'blidotenis',
    '🏸' => 'pjerkobul',
    '🥊' => 'pjasćowanska rukajca',
    '🥋' => 'woblek za bojowy sport',
    '🥅' => 'sportowe wrota',
    '⛳' => 'chorhojčka w dźěrje',
    '⛸' => 'smykače',
    '🎣' => 'wuda z rybu',
    '🤿' => 'nurjenska maska',
    '🎽' => 'běhanski shirt',
    '🎿' => 'sněhaki',
    '🛷' => 'sanki',
    '🥌' => 'curlingowy kamjeń',
    '🎯' => 'darts',
    '🪀' => 'jojo',
    '🪁' => 'zmij za pušćenje',
    '🔫' => 'pistola',
    '🎱' => 'billardowa kula',
    '🔮' => 'kristalowa kula',
    '🪄' => 'kuzłarski kij',
    '🎮' => 'gamepad',
    '🕹' => 'joystick',
    '🎰' => 'hrajny awtomat',
    '🎲' => 'kóstka',
    '🧩' => 'dźěl puzzla',
    '🧸' => 'barik',
    '🪅' => 'pinjata',
    '🪩' => 'špihelowa kula',
    '🪆' => 'matrjoška',
    '♠' => 'łopješko',
    '♥' => 'wutrobička',
    '♦' => 'karo',
    '♣' => 'křižik na hrajnej karće',
    '♟' => 'burik',
    '🃏' => 'joker',
    '🀄' => 'mahjong-kamušk',
    '🎴' => 'hrajne karty z kwětkami',
    '🎭' => 'dźiwadło',
    '🖼' => 'wobraz w ramiku',
    '🎨' => 'molerska paleta',
    '🧵' => 'nitka',
    '🪡' => 'šićowa jehlička',
    '🧶' => 'kłubach wołmy',
    '🪢' => 'suk',
    '👓' => 'nawoči',
    '🕶' => 'słónčne nawoči',
    '🥽' => 'škitne nawoči',
    '🥼' => 'laborowy kitl',
    '🦺' => 'wěstotny lac',
    '👔' => 'krawata',
    '👕' => 't-shirt',
    '👖' => 'jeansy',
    '🧣' => 'šawl',
    '🧤' => 'rukajcy',
    '🧥' => 'kabat',
    '🧦' => 'nohajcy',
    '👗' => 'šat',
    '👘' => 'kimono',
    '🥻' => 'sari',
    '🩱' => 'kupanski woblek',
    '🩲' => 'spódnje cholowy',
    '🩳' => 'shortsy',
    '👙' => 'bikini',
    '👚' => 'bluza',
    '🪭' => 'wjechlawka za wětrjenje',
    '👛' => 'móšnja',
    '👜' => 'ručna tobołka',
    '👝' => 'podpažna tobołka',
    '🛍' => 'nakupowanske toše',
    '🎒' => 'šulska toboła',
    '🩴' => 'flipflopsy',
    '👞' => 'muske črije',
    '👟' => 'sportowe črije',
    '🥾' => 'pućowanske škórnje',
    '🥿' => 'płone črije',
    '👠' => 'pjenkate črije',
    '👡' => 'žónske sandale',
    '🩰' => 'baletowe črije',
    '👢' => 'žónske škórnje',
    '🪮' => 'spinka za włosy',
    '👑' => 'króna',
    '👒' => 'žónski kłobuk',
    '🎩' => 'cylinder',
    '🎓' => 'kłobuk za wotchadničku',
    '🧢' => 'špodkata čapka',
    '🪖' => 'wojerski nahłownik',
    '⛑' => 'nahłownik z běłym křižom',
    '📿' => 'róžowc',
    '💄' => 'nahubny barbjenčk',
    '💍' => 'pjeršćeń',
    '💎' => 'drohokamjeń',
    '🔇' => 'hasnjeny wótřerěčak',
    '🔈' => 'wótřerěčak z niskej sylnosću zwuka',
    '🔉' => 'wótřerěčak ze srjedźnej sylnosću zwuka',
    '🔊' => 'wótřerěčak z wysokej sylnosću zwuka',
    '📢' => 'wótřerěčak',
    '📣' => 'megafon',
    '📯' => 'póstowy róžk',
    '🔔' => 'zwón',
    '🔕' => 'přešmórnjeny zwón',
    '🎼' => 'notowy kluč',
    '🎵' => 'nota',
    '🎶' => 'noty',
    '🎙' => 'studijowy mikrofon',
    '🎚' => 'nastajenje zwuka',
    '🎛' => 'kontrolne knefle',
    '🎤' => 'mikrofon',
    '🎧' => 'słuchatka',
    '📻' => 'radijo',
    '🎷' => 'saksofon',
    '🎺' => 'trompeta',
    '🪊' => 'pozawna',
    '🪗' => 'akordeon',
    '🎸' => 'gitara',
    '🎹' => 'klawiatura',
    '🎻' => 'husle',
    '🪕' => 'banjo',
    '🥁' => 'bubon',
    '🪘' => 'afriski bubon',
    '🪇' => 'maracasy',
    '🪈' => 'pišćałka',
    '🪉' => 'harfa',
    '📱' => 'mobilny telefon',
    '📲' => 'mobilny telefon z kłokom',
    '☎' => 'telefon',
    '📞' => 'słuchatko',
    '📟' => 'pager',
    '📠' => 'faksowak',
    '🔋' => 'baterija',
    '🪫' => 'słaba baterija',
    '🔌' => 'tykačk',
    '💻' => 'laptop',
    '🖥' => 'desktopowy kompjuter',
    '🖨' => 'ćišćak',
    '⌨' => 'tastatura',
    '🖱' => 'myška',
    '🖲' => 'trackball',
    '💽' => 'minidisk',
    '💾' => 'disketa',
    '💿' => 'CD',
    '📀' => 'DVD',
    '🧮' => 'ličbowak',
    '🎥' => 'filmowa kamera',
    '🎞' => 'filmowy pask',
    '📽' => 'filmowy projektor',
    '🎬' => 'filmowa klapa',
    '📺' => 'telewizor',
    '📷' => 'fotoaparat',
    '📸' => 'fotoaparat z błyskom',
    '📹' => 'widejokamera',
    '📼' => 'widejokaseta',
    '🔍' => 'lupa dolěwa nachilena',
    '🔎' => 'lupa doprawa nachilena',
    '🕯' => 'swěčka',
    '💡' => 'žehlawka',
    '🔦' => 'kapsna lampa',
    '🏮' => 'čerwjeny lampionk',
    '🪔' => 'wolijowa lampa',
    '📔' => 'zapisnik z rjanej wobalku',
    '📕' => 'začinjena kniha',
    '📖' => 'wočinjena kniha',
    '📗' => 'zelena kniha',
    '📘' => 'módra kniha',
    '📙' => 'oranžojta kniha',
    '📚' => 'knihi',
    '📓' => 'zapisnik',
    '📒' => 'žołty zapisnik',
    '📃' => 'zdźěla zwite łopjeno',
    '📜' => 'zawitk',
    '📄' => 'prědnja strona łopjena',
    '📰' => 'nowiny',
    '🗞' => 'zwite nowiny',
    '📑' => 'strony z čitanskimi znamjenjemi',
    '🔖' => 'čitanske znamjo',
    '🏷' => 'etiket',
    '🪙' => 'pjenjez',
    '💰' => 'měšk pjenjez',
    '🪎' => 'křinja z pokładom',
    '💴' => 'yenowka',
    '💵' => 'dolarowka',
    '💶' => 'eurowka',
    '💷' => 'puntowska bankowka',
    '💸' => 'bankowka z křidłomaj',
    '💳' => 'kreditna karta',
    '🧾' => 'kwitowanka',
    '💹' => 'diagram přirosta z yen-znamješkom',
    '✉' => 'listowa wobalka',
    '📧' => 'e-mejlka',
    '📨' => 'přichadźaca listowa wobalka',
    '📩' => 'wobalka z kłokom',
    '📤' => 'fašk za wotchadźacu póštu',
    '📥' => 'fašk za přichadźacu póštu',
    '📦' => 'pakćik',
    '📫' => 'zawrjeny listowy kašćik z póštu',
    '📪' => 'zawrjeny listowy kašćik bjez póšty',
    '📬' => 'wočinjeny listowy kašćik z póštu',
    '📭' => 'wočinjeny listowy kašćik bjez póšty',
    '📮' => 'listowy kašćik',
    '🗳' => 'wólbny kašćik z wólbnym lisćikom',
    '✏' => 'wołojnik',
    '✒' => 'čorne pjero',
    '🖋' => 'pjelnjak',
    '🖊' => 'kuli',
    '🖌' => 'seršćowc',
    '🖍' => 'wóskowy barbjenčk',
    '📝' => 'papjerka a wołojnik',
    '💼' => 'aktowka',
    '📁' => 'rjadowak',
    '📂' => 'wočinjeny rjadowak',
    '🗂' => 'kartoteka',
    '📅' => 'protyka',
    '📆' => 'wottorhanska protyka',
    '🗒' => 'blok ze spiralnej wjazbu',
    '🗓' => 'protyka ze spiralnej wjazbu',
    '📇' => 'wjerćity register za wizitki',
    '📈' => 'rosćacy diagram',
    '📉' => 'spadowacy diagram',
    '📊' => 'stołpikowy diagram',
    '📋' => 'pisanska podłoha',
    '📌' => 'připinawka',
    '📍' => 'kulojta připinawka',
    '📎' => 'spinka',
    '🖇' => 'zahokowane spinki',
    '📏' => 'lineal',
    '📐' => 'třiróžkaty lineal',
    '✂' => 'nožicy',
    '🗃' => 'kartajny kašćik',
    '🗄' => 'aktowy kamor',
    '🗑' => 'papjernik',
    '🔒' => 'zawrjeny zamk',
    '🔓' => 'wočinjeny zamk',
    '🔏' => 'zamk z pjelnjakom',
    '🔐' => 'zamk z klučikom',
    '🔑' => 'kluč',
    '🗝' => 'stary kluč',
    '🔨' => 'hamor',
    '🪓' => 'sekera',
    '⛏' => 'kilop',
    '⚒' => 'hamor a kilop',
    '🛠' => 'hamor a šrubowy kluč',
    '🗡' => 'mječik',
    '⚔' => 'skřižowanej mječej',
    '💣' => 'bomba',
    '🪃' => 'bumerang',
    '🏹' => 'kłok a prok',
    '🛡' => 'tarč',
    '🪚' => 'ručna piła',
    '🔧' => 'šrubowy kluč',
    '🪛' => 'šrubowak',
    '🔩' => 'šrub a maćica',
    '⚙' => 'zubičkate kolesko',
    '🗜' => 'šrubowe klěšće',
    '⚖' => 'waha',
    '🦯' => 'běły kij',
    '🔗' => 'wójmidle',
    '⛓' => 'rjećazy',
    '🪝' => 'kótwička',
    '🧰' => 'gratowy kašćik',
    '🧲' => 'magnet',
    '🪜' => 'rěbl',
    '🪏' => 'łopač',
    '⚗' => 'destilaciski nastroj',
    '🧪' => 'reagencowa škleńca',
    '🧫' => 'Petrijowa škleńca',
    '🧬' => 'DNA',
    '🔬' => 'mikroskop',
    '🔭' => 'teleskop',
    '📡' => 'satelitowa škla',
    '💉' => 'špryca',
    '🩸' => 'kapka kreje',
    '💊' => 'kapsla',
    '🩹' => 'plester',
    '🩼' => 'zepěra',
    '🩺' => 'stetoskop',
    '🩻' => 'roentgenowy wobraz',
    '🚪' => 'durje',
    '🛗' => 'lift',
    '🪞' => 'špihel',
    '🪟' => 'wokno',
    '🛏' => 'łožo',
    '🛋' => 'konopej a lampa',
    '🪑' => 'stólc',
    '🚽' => 'nuznik',
    '🪠' => 'srěbadło',
    '🚿' => 'duša',
    '🛁' => 'wanja',
    '🪤' => 'myšace pasle',
    '🪒' => 'britej',
    '🧴' => 'bleška z kosmetiku',
    '🧷' => 'zapinawka',
    '🧹' => 'chošćo',
    '🧺' => 'koš',
    '🧻' => 'róla papjery',
    '🪣' => 'bow',
    '🧼' => 'mydło',
    '🫧' => 'pucherje',
    '🪥' => 'zubna šćětka',
    '🧽' => 'hubica',
    '🧯' => 'hašak',
    '🛒' => 'nakupowanski wozyk',
    '🚬' => 'cigareta',
    '⚰' => 'kašć',
    '🪦' => 'narowny kamjeń',
    '⚱' => 'popjelnica',
    '🧿' => 'škitny amulet',
    '🪬' => 'hamsa',
    '🗿' => 'moai',
    '🪧' => 'transparent',
    '🪪' => 'wupokaz',
    '🏧' => 'symbol "pjenježny awtomat"',
    '🚮' => 'symbol "koš za wotpadki"',
    '🚰' => 'symbol "pitna woda"',
    '♿' => 'symbol "jězbny stoł"',
    '🚹' => 'symbol "toaleta za mužow"',
    '🚺' => 'symbol "toaleta za žony"',
    '🚻' => 'symbol "toalety"',
    '🚼' => 'symbol "ćěšenk"',
    '🚾' => 'WC',
    '🛂' => 'pasowa kontrola',
    '🛃' => 'cłowna kontrola',
    '🛄' => 'wudawanje wačokow',
    '🛅' => 'chowanje wačokow',
    '⚠' => 'warnowanje',
    '🚸' => 'dźěći přeprěča dróhu',
    '⛔' => 'zajězd zakazany',
    '🚫' => 'zakaz',
    '🚳' => 'za kolesa zakazane',
    '🚭' => 'kurić zakazane',
    '🚯' => 'wotpadki zawostajić zakazane',
    '🚱' => 'žana pitna woda',
    '🚷' => 'za pěškow zakazane',
    '📵' => 'wužiwanje mobilnych telefonow zakazane',
    '🔞' => 'za małolětnych zakazane',
    '☢' => 'radioaktiwne',
    '☣' => 'biologiski strach',
    '⬆' => 'kłok horje',
    '↗' => 'kłok doprawa horje',
    '➡' => 'kłok doprawa',
    '↘' => 'kłok doprawa dele',
    '⬇' => 'kłok dele',
    '↙' => 'kłok dolěwa dele',
    '⬅' => 'kłok dolěwa',
    '↖' => 'kłok dolěwa horje',
    '↕' => 'kłok horje a dele',
    '↔' => 'kłok dolěwa a doprawa',
    '↩' => 'kłok doprawa zwjertnje so dolěwa',
    '↪' => 'kłok dolěwa zwjertnje so doprawa',
    '⤴' => 'kłok doprawa zwjertnje so horje',
    '⤵' => 'kłok doprawa zwjertnje so dele',
    '🔃' => 'wertikalnej kłokaj w směrje časnika',
    '🔄' => 'napřećiwnej kłokaj přećiwo směrej časnika',
    '🔙' => 'kłok z napisom BACK',
    '🔚' => 'kłod z napisom END',
    '🔛' => 'kłok z napisom ON!',
    '🔜' => 'kłok z napisom SOON',
    '🔝' => 'kłok z napisom TOP',
    '🛐' => 'kultnišćo',
    '⚛' => 'symbol atoma',
    '🕉' => 'om',
    '✡' => 'Dawidowa hwězda',
    '☸' => 'koło dharmy',
    '☯' => 'jin a jang',
    '✝' => 'łaćonski křiž',
    '☦' => 'prawosławny křiž',
    '☪' => 'hwězda a połměsačk',
    '☮' => 'symbol měra',
    '🕎' => 'menora',
    '🔯' => 'heksagram z dypkom',
    '🪯' => 'khanda',
    '♈' => 'Boran (hwězdne znamjo)',
    '♉' => 'Byk (hwězdne znamjo)',
    '♊' => 'Dwójnikaj (hwězdne znamjo)',
    '♋' => 'Rak (hwězdne znamjo)',
    '♌' => 'Law (hwězdne znamjo)',
    '♍' => 'Knježna (hwězdne znamjo)',
    '♎' => 'Waha (hwězdne znamjo)',
    '♏' => 'Skorpion (hwězdne znamjo)',
    '♐' => 'Třělc (hwězdne znamjo)',
    '♑' => 'Kozoróžk (hwězdne znamjo)',
    '♒' => 'Wódny muž (hwězdne znamjo)',
    '♓' => 'Ryby (hwězdne znamjo)',
    '⛎' => 'Hadadźeržnik',
    '🔀' => 'tłóčatko "wuběraj po připadźe"',
    '🔁' => 'tłóčatko "wospjetuj"',
    '🔂' => 'tłóčatko "wospjetuj jedyn spěw"',
    '▶' => 'tłóčatko "wohrawaj"',
    '⏩' => 'tłóčatko "wothrawaj spěšnišo"',
    '⏭' => 'tłóčatko "skoč k přichodnemu titulej"',
    '⏯' => 'tłóčatko "wothrawaj abo čiń přestawku"',
    '◀' => 'tłóčatko "wjerć wróćo"',
    '⏪' => 'tłóčatko "wjerć spěšnišo wróćo"',
    '⏮' => 'tłóčatko "skoč k předchadźacemu titulej"',
    '🔼' => 'tłóčatko "horje"',
    '⏫' => 'tłóčatko "spěšnje horje"',
    '🔽' => 'tłóčatko "dele"',
    '⏬' => 'tłóčatko "spěšnje dele"',
    '⏸' => 'tłóčatko "přestawka"',
    '⏹' => 'tłóčatko "stop"',
    '⏺' => 'tłóčatko "nahrawaj"',
    '⏏' => 'tłóčatko "wusuń"',
    '🎦' => 'kino',
    '🔅' => 'tłóčatko "ćěmnišo"',
    '🔆' => 'tłóčatko "swětlišo"',
    '📶' => 'sylnosć signala',
    '🛜' => 'bjez kabla',
    '📳' => 'tłóčatko "wibraciski modus"',
    '📴' => 'tłóčatko "hasń handy"',
    '♀' => 'symbol za žónski splah',
    '♂' => 'symbol za muski splah',
    '⚧' => 'transgenderowy symbol',
    '✖' => 'znamješko multiplikacije',
    '➕' => 'znamješko plus',
    '➖' => 'znamješko minus',
    '➗' => 'znamješko diwizije',
    '🟰' => 'tołste znamjo jerunja',
    '♾' => 'znamješko bjezkónčnosće',
    '‼' => 'dwójny wuwołak',
    '⁉' => 'wuwołak a prašak',
    '❓' => 'čerwjeny prašak',
    '❔' => 'běły prašak',
    '❕' => 'běły wuwołak',
    '❗' => 'čerwjeny wuwołak',
    '〰' => 'žołmičkata linija',
    '💱' => 'měnjenje pjenjez',
    '💲' => 'tučny symbol za dolar',
    '⚕' => 'lěkarski symbol',
    '♻' => 'symbol za recycling',
    '⚜' => 'heraldiska lilija',
    '🔱' => 'třizubak',
    '📛' => 'mjenowa taflička',
    '🔰' => 'japanski symbol za započatkarja',
    '⭕' => 'prózdny čerwjeny kruh',
    '✅' => 'tłóčatko z běłej hóčku',
    '☑' => 'kontrolny kašćik z hóčku',
    '✔' => 'tučna hóčka',
    '❌' => 'křižik',
    '❎' => 'tłóčatko z křižikom',
    '➰' => 'zawróćenska sekla',
    '➿' => 'dwójna sekla',
    '〽' => 'japanski symbol za spočatk spěwa',
    '✳' => 'wosomkónčkata hwěžka',
    '✴' => 'wosomkónčkata hwězda',
    '❇' => 'zybolenje',
    '™' => 'markowe znamjo',
    '🫟' => 'plusk',
    '🔠' => 'zapodaj łaćonske wulke pismiki',
    '🔡' => 'zapodaj łaćonske małe pismiki',
    '🔢' => 'zapodaj ličby',
    '🔣' => 'zapodaj symbole',
    '🔤' => 'zapodaj łaćonske pismiki',
    '🅰' => 'znamješko A (krejna skupina)',
    '🆎' => 'znamješko AB (krejna skupina)',
    '🅱' => 'znamješko B (krejna skupina)',
    '🆑' => 'znamješko CL',
    '🆒' => 'znamješko COOL',
    '🆓' => 'znamješko FREE',
    'ℹ' => 'informacija',
    '🆔' => 'znamješko ID',
    'Ⓜ' => 'M w kruhu',
    '🆕' => 'znamješko NEW',
    '🆖' => 'znamješko NG',
    '🅾' => 'znamješko 0 (krejna skupina)',
    '🆗' => 'znamješko OK',
    '🅿' => 'znamješko P',
    '🆘' => 'znamješko SOS',
    '🆙' => 'znamješko UP!',
    '🆚' => 'znamješko VS',
    '🈁' => 'znamješko z japanskim pismikowym znamjenjom "tu"',
    '🈂' => 'znamješko z japanskim pismikowym znamjenjom "přepitk"',
    '🈷' => 'znamješko z japanskim pismikowym znamjenjom "měsačny přinošk"',
    '🈶' => 'znamješko z japanskim pismikowym znamjenjom "njeje bjezpłatne"',
    '🈯' => 'znamješko z japanskim pismikowym znamjenjom "rezerwowane"',
    '🉐' => 'znamješko z japanskim pismikowym znamjenjom "wosebje tuni poskitk"',
    '🈹' => 'znamješko z japanskim pismikowym znamjenjom "rabat"',
    '🈚' => 'znamješko z japanskim pismikowym znamjenjom "bjezpłatne"',
    '🈲' => 'znamješko z japanskim pismikowym znamjenjom "zakazane"',
    '🉑' => 'znamješko z japanskim pismikowym znamjenjom "dowolene"',
    '🈸' => 'znamješko z japanskim pismikowym znamjenjom "naprašowanje"',
    '🈴' => 'znamješko z japanskim pismikowym znamjenjom "pozitiwny posudk"',
    '🈳' => 'znamješko z japanskim pismikowym znamjenjom "swobodne"',
    '㊗' => 'znamješko z japanskim pismikowym znamjenjom "gratulacija"',
    '㊙' => 'znamješko z japanskim pismikowym znamjenjom "tajne"',
    '🈺' => 'znamješko z japanskim pismikowym znamjenjom "wočinjene"',
    '🈵' => 'znamješko z japanskim pismikowym znamjenjom "wobsadźene"',
    '🔴' => 'čerwjeny kruh',
    '🟠' => 'oranžojty kruh',
    '🟡' => 'žołty kruh',
    '🟢' => 'zeleny kruh',
    '🔵' => 'módry kruh',
    '🟣' => 'fijałkojty kruh',
    '🟤' => 'bruny kruh',
    '⚫' => 'čorny kruh',
    '⚪' => 'běły kruh',
    '🟥' => 'čerwjeny štyriróžk',
    '🟧' => 'oranžojty štyriróžk',
    '🟨' => 'žołty štyriróžk',
    '🟩' => 'zeleny štyriróžk',
    '🟦' => 'módry štyriróžk',
    '🟪' => 'fijałkojty štyriróžk',
    '🟫' => 'bruny štyriróžk',
    '⬛' => 'wulki čorny štyriróžk',
    '⬜' => 'wulki běły štyriróžk',
    '◼' => 'srěnjowulki čorny štyriróžk',
    '◻' => 'srěnjowulki běły štyriróžk',
    '◾' => 'mały čorny štyriróžk',
    '◽' => 'mały běły štyriróžk',
    '▪' => 'mólički čorny štyriróžk',
    '▫' => 'mólički běły štyriróžk',
    '🔶' => 'wulki oranžojty rombus',
    '🔷' => 'wulki módry rombus',
    '🔸' => 'mały oranžojty rombus',
    '🔹' => 'mały módry rombus',
    '🔺' => 'čerwjeny třiróžk, kiž pokazuje horje',
    '🔻' => 'čerwjeny třiróžk, kiž pokazuje dele',
    '💠' => 'rombus z dypkom',
    '🔘' => 'kulojte tłóčatko',
    '🔳' => 'běłe kwadratiske tłóčatko',
    '🔲' => 'čorne kwadratiske tłóčatko',
    '🏁' => 'cilowa chorhojčka',
    '🚩' => 'třiróžkata chorhojčka',
    '🎌' => 'skřižowanej chorhojčce',
    '🏴' => 'čorna chorhojčka',
    '🏳' => 'běła chorhojčka',
];
