<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'öpüş: böyük, böyük, açıq dəri tonu, orta-açıq dəri tonu',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'öpüş: böyük, böyük, açıq dəri tonu, orta dəri tonu',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'öpüş: böyük, böyük, açıq dəri tonu, orta-tünd dəri tonu',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'öpüş: böyük, böyük, açıq dəri tonu, tünd dəri tonu',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'öpüş: böyük, böyük, orta-açıq dəri tonu, açıq dəri tonu',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'öpüş: böyük, böyük, orta-açıq dəri tonu, orta dəri tonu',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'öpüş: böyük, böyük, orta-açıq dəri tonu, orta-tünd dəri tonu',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'öpüş: böyük, böyük, orta-açıq dəri tonu, tünd dəri tonu',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'öpüş: böyük, böyük, orta dəri tonu, açıq dəri tonu',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'öpüş: böyük, böyük, orta dəri tonu, orta-açıq dəri tonu',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'öpüş: böyük, böyük, orta dəri tonu, orta-tünd dəri tonu',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'öpüş: böyük, böyük, orta dəri tonu, tünd dəri tonu',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'öpüş: böyük, böyük, orta-tünd dəri tonu, açıq dəri tonu',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'öpüş: böyük, böyük, orta-tünd dəri tonu, orta-açıq dəri tonu',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'öpüş: böyük, böyük, orta-tünd dəri tonu, orta dəri tonu',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'öpüş: böyük, böyük, orta-tünd dəri tonu, tünd dəri tonu',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'öpüş: böyük, böyük, tünd dəri tonu, açıq dəri tonu',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'öpüş: böyük, böyük, tünd dəri tonu, orta-açıq dəri tonu',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'öpüş: böyük, böyük, tünd dəri tonu, orta dəri tonu',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'öpüş: böyük, böyük, tünd dəri tonu, orta-tünd dəri tonu',
    '👨🏻‍❤‍💋‍👨🏻' => 'öpüş: kişi, kişi, açıq dəri tonu',
    '👨🏻‍❤‍💋‍👨🏼' => 'öpüş: kişi, kişi, açıq dəri tonu, orta-açıq dəri tonu',
    '👨🏻‍❤‍💋‍👨🏽' => 'öpüş: kişi, kişi, açıq dəri tonu, orta dəri tonu',
    '👨🏻‍❤‍💋‍👨🏾' => 'öpüş: kişi, kişi, açıq dəri tonu, orta-tünd dəri tonu',
    '👨🏻‍❤‍💋‍👨🏿' => 'öpüş: kişi, kişi, açıq dəri tonu, tünd dəri tonu',
    '👨🏼‍❤‍💋‍👨🏻' => 'öpüş: kişi, kişi, orta-açıq dəri tonu, açıq dəri tonu',
    '👨🏼‍❤‍💋‍👨🏼' => 'öpüş: kişi, kişi, orta-açıq dəri tonu',
    '👨🏼‍❤‍💋‍👨🏽' => 'öpüş: kişi, kişi, orta-açıq dəri tonu, orta dəri tonu',
    '👨🏼‍❤‍💋‍👨🏾' => 'öpüş: kişi, kişi, orta-açıq dəri tonu, orta-tünd dəri tonu',
    '👨🏼‍❤‍💋‍👨🏿' => 'öpüş: kişi, kişi, orta-açıq dəri tonu, tünd dəri tonu',
    '👨🏽‍❤‍💋‍👨🏻' => 'öpüş: kişi, kişi, orta dəri tonu, açıq dəri tonu',
    '👨🏽‍❤‍💋‍👨🏼' => 'öpüş: kişi, kişi, orta dəri tonu, orta-açıq dəri tonu',
    '👨🏽‍❤‍💋‍👨🏽' => 'öpüş: kişi, kişi, orta dəri tonu',
    '👨🏽‍❤‍💋‍👨🏾' => 'öpüş: kişi, kişi, orta dəri tonu, orta-tünd dəri tonu',
    '👨🏽‍❤‍💋‍👨🏿' => 'öpüş: kişi, kişi, orta dəri tonu, tünd dəri tonu',
    '👨🏾‍❤‍💋‍👨🏻' => 'öpüş: kişi, kişi, orta-tünd dəri tonu, açıq dəri tonu',
    '👨🏾‍❤‍💋‍👨🏼' => 'öpüş: kişi, kişi, orta-tünd dəri tonu, orta-açıq dəri tonu',
    '👨🏾‍❤‍💋‍👨🏽' => 'öpüş: kişi, kişi, orta-tünd dəri tonu, orta dəri tonu',
    '👨🏾‍❤‍💋‍👨🏾' => 'öpüş: kişi, kişi, orta-tünd dəri tonu',
    '👨🏾‍❤‍💋‍👨🏿' => 'öpüş: kişi, kişi, orta-tünd dəri tonu, tünd dəri tonu',
    '👨🏿‍❤‍💋‍👨🏻' => 'öpüş: kişi, kişi, tünd dəri tonu, açıq dəri tonu',
    '👨🏿‍❤‍💋‍👨🏼' => 'öpüş: kişi, kişi, tünd dəri tonu, orta-açıq dəri tonu',
    '👨🏿‍❤‍💋‍👨🏽' => 'öpüş: kişi, kişi, tünd dəri tonu, orta dəri tonu',
    '👨🏿‍❤‍💋‍👨🏾' => 'öpüş: kişi, kişi, tünd dəri tonu, orta-tünd dəri tonu',
    '👨🏿‍❤‍💋‍👨🏿' => 'öpüş: kişi, kişi, tünd dəri tonu',
    '👩🏻‍❤‍💋‍👨🏻' => 'öpüş: qadın, kişi, açıq dəri tonu',
    '👩🏻‍❤‍💋‍👨🏼' => 'öpüş: qadın, kişi, açıq dəri tonu, orta-açıq dəri tonu',
    '👩🏻‍❤‍💋‍👨🏽' => 'öpüş: qadın, kişi, açıq dəri tonu, orta dəri tonu',
    '👩🏻‍❤‍💋‍👨🏾' => 'öpüş: qadın, kişi, açıq dəri tonu, orta-tünd dəri tonu',
    '👩🏻‍❤‍💋‍👨🏿' => 'öpüş: qadın, kişi, açıq dəri tonu, tünd dəri tonu',
    '👩🏼‍❤‍💋‍👨🏻' => 'öpüş: qadın, kişi, orta-açıq dəri tonu, açıq dəri tonu',
    '👩🏼‍❤‍💋‍👨🏼' => 'öpüş: qadın, kişi, orta-açıq dəri tonu',
    '👩🏼‍❤‍💋‍👨🏽' => 'öpüş: qadın, kişi, orta-açıq dəri tonu, orta dəri tonu',
    '👩🏼‍❤‍💋‍👨🏾' => 'öpüş: qadın, kişi, orta-açıq dəri tonu, orta-tünd dəri tonu',
    '👩🏼‍❤‍💋‍👨🏿' => 'öpüş: qadın, kişi, orta-açıq dəri tonu, tünd dəri tonu',
    '👩🏽‍❤‍💋‍👨🏻' => 'öpüş: qadın, kişi, orta dəri tonu, açıq dəri tonu',
    '👩🏽‍❤‍💋‍👨🏼' => 'öpüş: qadın, kişi, orta dəri tonu, orta-açıq dəri tonu',
    '👩🏽‍❤‍💋‍👨🏽' => 'öpüş: qadın, kişi, orta dəri tonu',
    '👩🏽‍❤‍💋‍👨🏾' => 'öpüş: qadın, kişi, orta dəri tonu, orta-tünd dəri tonu',
    '👩🏽‍❤‍💋‍👨🏿' => 'öpüş: qadın, kişi, orta dəri tonu, tünd dəri tonu',
    '👩🏾‍❤‍💋‍👨🏻' => 'öpüş: qadın, kişi, orta-tünd dəri tonu, açıq dəri tonu',
    '👩🏾‍❤‍💋‍👨🏼' => 'öpüş: qadın, kişi, orta-tünd dəri tonu, orta-açıq dəri tonu',
    '👩🏾‍❤‍💋‍👨🏽' => 'öpüş: qadın, kişi, orta-tünd dəri tonu, orta dəri tonu',
    '👩🏾‍❤‍💋‍👨🏾' => 'öpüş: qadın, kişi, orta-tünd dəri tonu',
    '👩🏾‍❤‍💋‍👨🏿' => 'öpüş: qadın, kişi, orta-tünd dəri tonu, tünd dəri tonu',
    '👩🏿‍❤‍💋‍👨🏻' => 'öpüş: qadın, kişi, tünd dəri tonu, açıq dəri tonu',
    '👩🏿‍❤‍💋‍👨🏼' => 'öpüş: qadın, kişi, tünd dəri tonu, orta-açıq dəri tonu',
    '👩🏿‍❤‍💋‍👨🏽' => 'öpüş: qadın, kişi, tünd dəri tonu, orta dəri tonu',
    '👩🏿‍❤‍💋‍👨🏾' => 'öpüş: qadın, kişi, tünd dəri tonu, orta-tünd dəri tonu',
    '👩🏿‍❤‍💋‍👨🏿' => 'öpüş: qadın, kişi, tünd dəri tonu',
    '👩🏻‍❤‍💋‍👩🏻' => 'öpüş: qadın, qadın, açıq dəri tonu',
    '👩🏻‍❤‍💋‍👩🏼' => 'öpüş: qadın, qadın, açıq dəri tonu, orta-açıq dəri tonu',
    '👩🏻‍❤‍💋‍👩🏽' => 'öpüş: qadın, qadın, açıq dəri tonu, orta dəri tonu',
    '👩🏻‍❤‍💋‍👩🏾' => 'öpüş: qadın, qadın, açıq dəri tonu, orta-tünd dəri tonu',
    '👩🏻‍❤‍💋‍👩🏿' => 'öpüş: qadın, qadın, açıq dəri tonu, tünd dəri tonu',
    '👩🏼‍❤‍💋‍👩🏻' => 'öpüş: qadın, qadın, orta-açıq dəri tonu, açıq dəri tonu',
    '👩🏼‍❤‍💋‍👩🏼' => 'öpüş: qadın, qadın, orta-açıq dəri tonu',
    '👩🏼‍❤‍💋‍👩🏽' => 'öpüş: qadın, qadın, orta-açıq dəri tonu, orta dəri tonu',
    '👩🏼‍❤‍💋‍👩🏾' => 'öpüş: qadın, qadın, orta-açıq dəri tonu, orta-tünd dəri tonu',
    '👩🏼‍❤‍💋‍👩🏿' => 'öpüş: qadın, qadın, orta-açıq dəri tonu, tünd dəri tonu',
    '👩🏽‍❤‍💋‍👩🏻' => 'öpüş: qadın, qadın, orta dəri tonu, açıq dəri tonu',
    '👩🏽‍❤‍💋‍👩🏼' => 'öpüş: qadın, qadın, orta dəri tonu, orta-açıq dəri tonu',
    '👩🏽‍❤‍💋‍👩🏽' => 'öpüş: qadın, qadın, orta dəri tonu',
    '👩🏽‍❤‍💋‍👩🏾' => 'öpüş: qadın, qadın, orta dəri tonu, orta-tünd dəri tonu',
    '👩🏽‍❤‍💋‍👩🏿' => 'öpüş: qadın, qadın, orta dəri tonu, tünd dəri tonu',
    '👩🏾‍❤‍💋‍👩🏻' => 'öpüş: qadın, qadın, orta-tünd dəri tonu, açıq dəri tonu',
    '👩🏾‍❤‍💋‍👩🏼' => 'öpüş: qadın, qadın, orta-tünd dəri tonu, orta-açıq dəri tonu',
    '👩🏾‍❤‍💋‍👩🏽' => 'öpüş: qadın, qadın, orta-tünd dəri tonu, orta dəri tonu',
    '👩🏾‍❤‍💋‍👩🏾' => 'öpüş: qadın, qadın, orta-tünd dəri tonu',
    '👩🏾‍❤‍💋‍👩🏿' => 'öpüş: qadın, qadın, orta-tünd dəri tonu, tünd dəri tonu',
    '👩🏿‍❤‍💋‍👩🏻' => 'öpüş: qadın, qadın, tünd dəri tonu, açıq dəri tonu',
    '👩🏿‍❤‍💋‍👩🏼' => 'öpüş: qadın, qadın, tünd dəri tonu, orta-açıq dəri tonu',
    '👩🏿‍❤‍💋‍👩🏽' => 'öpüş: qadın, qadın, tünd dəri tonu, orta dəri tonu',
    '👩🏿‍❤‍💋‍👩🏾' => 'öpüş: qadın, qadın, tünd dəri tonu, orta-tünd dəri tonu',
    '👩🏿‍❤‍💋‍👩🏿' => 'öpüş: qadın, qadın, tünd dəri tonu',
    '🧑🏻‍🫯‍🧑🏼' => 'güləş: açıq dəri tonu, orta-açıq dəri tonu',
    '🧑🏻‍🫯‍🧑🏽' => 'güləş: açıq dəri tonu, orta dəri tonu',
    '🧑🏻‍🫯‍🧑🏾' => 'güləş: açıq dəri tonu, orta-tünd dəri tonu',
    '🧑🏻‍🫯‍🧑🏿' => 'güləş: açıq dəri tonu, tünd dəri tonu',
    '🧑🏼‍🫯‍🧑🏻' => 'güləş: orta-açıq dəri tonu, açıq dəri tonu',
    '🧑🏼‍🫯‍🧑🏽' => 'güləş: orta-açıq dəri tonu, orta dəri tonu',
    '🧑🏼‍🫯‍🧑🏾' => 'güləş: orta-açıq dəri tonu, orta-tünd dəri tonu',
    '🧑🏼‍🫯‍🧑🏿' => 'güləş: orta-açıq dəri tonu, tünd dəri tonu',
    '🧑🏽‍🫯‍🧑🏻' => 'güləş: orta dəri tonu, açıq dəri tonu',
    '🧑🏽‍🫯‍🧑🏼' => 'güləş: orta dəri tonu, orta-açıq dəri tonu',
    '🧑🏽‍🫯‍🧑🏾' => 'güləş: orta dəri tonu, orta-tünd dəri tonu',
    '🧑🏽‍🫯‍🧑🏿' => 'güləş: orta dəri tonu, tünd dəri tonu',
    '🧑🏾‍🫯‍🧑🏻' => 'güləş: orta-tünd dəri tonu, açıq dəri tonu',
    '🧑🏾‍🫯‍🧑🏼' => 'güləş: orta-tünd dəri tonu, orta-açıq dəri tonu',
    '🧑🏾‍🫯‍🧑🏽' => 'güləş: orta-tünd dəri tonu, orta dəri tonu',
    '🧑🏾‍🫯‍🧑🏿' => 'güləş: orta-tünd dəri tonu, tünd dəri tonu',
    '🧑🏿‍🫯‍🧑🏻' => 'güləş: tünd dəri tonu, açıq dəri tonu',
    '🧑🏿‍🫯‍🧑🏼' => 'güləş: tünd dəri tonu, orta-açıq dəri tonu',
    '🧑🏿‍🫯‍🧑🏽' => 'güləş: tünd dəri tonu, orta dəri tonu',
    '🧑🏿‍🫯‍🧑🏾' => 'güləş: tünd dəri tonu, orta-tünd dəri tonu',
    '🧑🏻‍❤‍🧑🏼' => 'ürəkli cütlük: böyük, böyük, açıq dəri tonu, orta-açıq dəri tonu',
    '🧑🏻‍❤‍🧑🏽' => 'ürəkli cütlük: böyük, böyük, açıq dəri tonu, orta dəri tonu',
    '🧑🏻‍❤‍🧑🏾' => 'ürəkli cütlük: böyük, böyük, açıq dəri tonu, orta-tünd dəri tonu',
    '🧑🏻‍❤‍🧑🏿' => 'ürəkli cütlük: böyük, böyük, açıq dəri tonu, tünd dəri tonu',
    '🧑🏼‍❤‍🧑🏻' => 'ürəkli cütlük: böyük, böyük, orta-açıq dəri tonu, açıq dəri tonu',
    '🧑🏼‍❤‍🧑🏽' => 'ürəkli cütlük: böyük, böyük, orta-açıq dəri tonu, orta dəri tonu',
    '🧑🏼‍❤‍🧑🏾' => 'ürəkli cütlük: böyük, böyük, orta-açıq dəri tonu, orta-tünd dəri tonu',
    '🧑🏼‍❤‍🧑🏿' => 'ürəkli cütlük: böyük, böyük, orta-açıq dəri tonu, tünd dəri tonu',
    '🧑🏽‍❤‍🧑🏻' => 'ürəkli cütlük: böyük, böyük, orta dəri tonu, açıq dəri tonu',
    '🧑🏽‍❤‍🧑🏼' => 'ürəkli cütlük: böyük, böyük, orta dəri tonu, orta-açıq dəri tonu',
    '🧑🏽‍❤‍🧑🏾' => 'ürəkli cütlük: böyük, böyük, orta dəri tonu, orta-tünd dəri tonu',
    '🧑🏽‍❤‍🧑🏿' => 'ürəkli cütlük: böyük, böyük, orta dəri tonu, tünd dəri tonu',
    '🧑🏾‍❤‍🧑🏻' => 'ürəkli cütlük: böyük, böyük, orta-tünd dəri tonu, açıq dəri tonu',
    '🧑🏾‍❤‍🧑🏼' => 'ürəkli cütlük: böyük, böyük, orta-tünd dəri tonu, orta-açıq dəri tonu',
    '🧑🏾‍❤‍🧑🏽' => 'ürəkli cütlük: böyük, böyük, orta-tünd dəri tonu, orta dəri tonu',
    '🧑🏾‍❤‍🧑🏿' => 'ürəkli cütlük: böyük, böyük, orta-tünd dəri tonu, tünd dəri tonu',
    '🧑🏿‍❤‍🧑🏻' => 'ürəkli cütlük: böyük, böyük, tünd dəri tonu, açıq dəri tonu',
    '🧑🏿‍❤‍🧑🏼' => 'ürəkli cütlük: böyük, böyük, tünd dəri tonu, orta-açıq dəri tonu',
    '🧑🏿‍❤‍🧑🏽' => 'ürəkli cütlük: böyük, böyük, tünd dəri tonu, orta dəri tonu',
    '🧑🏿‍❤‍🧑🏾' => 'ürəkli cütlük: böyük, böyük, tünd dəri tonu, orta-tünd dəri tonu',
    '🧑🏻‍🐰‍🧑🏼' => 'şənlənən qadınlar: açıq dəri tonu, orta-açıq dəri tonu',
    '🧑🏻‍🐰‍🧑🏽' => 'şənlənən qadınlar: açıq dəri tonu, orta dəri tonu',
    '🧑🏻‍🐰‍🧑🏾' => 'şənlənən qadınlar: açıq dəri tonu, orta-tünd dəri tonu',
    '🧑🏻‍🐰‍🧑🏿' => 'şənlənən qadınlar: açıq dəri tonu, tünd dəri tonu',
    '🧑🏼‍🐰‍🧑🏻' => 'şənlənən qadınlar: orta-açıq dəri tonu, açıq dəri tonu',
    '🧑🏼‍🐰‍🧑🏽' => 'şənlənən qadınlar: orta-açıq dəri tonu, orta dəri tonu',
    '🧑🏼‍🐰‍🧑🏾' => 'şənlənən qadınlar: orta-açıq dəri tonu, orta-tünd dəri tonu',
    '🧑🏼‍🐰‍🧑🏿' => 'şənlənən qadınlar: orta-açıq dəri tonu, tünd dəri tonu',
    '🧑🏽‍🐰‍🧑🏻' => 'şənlənən qadınlar: orta dəri tonu, açıq dəri tonu',
    '🧑🏽‍🐰‍🧑🏼' => 'şənlənən qadınlar: orta dəri tonu, orta-açıq dəri tonu',
    '🧑🏽‍🐰‍🧑🏾' => 'şənlənən qadınlar: orta dəri tonu, orta-tünd dəri tonu',
    '🧑🏽‍🐰‍🧑🏿' => 'şənlənən qadınlar: orta dəri tonu, tünd dəri tonu',
    '🧑🏾‍🐰‍🧑🏻' => 'şənlənən qadınlar: orta-tünd dəri tonu, açıq dəri tonu',
    '🧑🏾‍🐰‍🧑🏼' => 'şənlənən qadınlar: orta-tünd dəri tonu, orta-açıq dəri tonu',
    '🧑🏾‍🐰‍🧑🏽' => 'şənlənən qadınlar: orta-tünd dəri tonu, orta dəri tonu',
    '🧑🏾‍🐰‍🧑🏿' => 'şənlənən qadınlar: orta-tünd dəri tonu, tünd dəri tonu',
    '🧑🏿‍🐰‍🧑🏻' => 'şənlənən qadınlar: tünd dəri tonu, açıq dəri tonu',
    '🧑🏿‍🐰‍🧑🏼' => 'şənlənən qadınlar: tünd dəri tonu, orta-açıq dəri tonu',
    '🧑🏿‍🐰‍🧑🏽' => 'şənlənən qadınlar: tünd dəri tonu, orta dəri tonu',
    '🧑🏿‍🐰‍🧑🏾' => 'şənlənən qadınlar: tünd dəri tonu, orta-tünd dəri tonu',
    '👨🏻‍🫯‍👨🏼' => 'güləşçi kişi: açıq dəri tonu, orta-açıq dəri tonu',
    '👨🏻‍🫯‍👨🏽' => 'güləşçi kişi: açıq dəri tonu, orta dəri tonu',
    '👨🏻‍🫯‍👨🏾' => 'güləşçi kişi: açıq dəri tonu, orta-tünd dəri tonu',
    '👨🏻‍🫯‍👨🏿' => 'güləşçi kişi: açıq dəri tonu, tünd dəri tonu',
    '👨🏼‍🫯‍👨🏻' => 'güləşçi kişi: orta-açıq dəri tonu, açıq dəri tonu',
    '👨🏼‍🫯‍👨🏽' => 'güləşçi kişi: orta-açıq dəri tonu, orta dəri tonu',
    '👨🏼‍🫯‍👨🏾' => 'güləşçi kişi: orta-açıq dəri tonu, orta-tünd dəri tonu',
    '👨🏼‍🫯‍👨🏿' => 'güləşçi kişi: orta-açıq dəri tonu, tünd dəri tonu',
    '👨🏽‍🫯‍👨🏻' => 'güləşçi kişi: orta dəri tonu, açıq dəri tonu',
    '👨🏽‍🫯‍👨🏼' => 'güləşçi kişi: orta dəri tonu, orta-açıq dəri tonu',
    '👨🏽‍🫯‍👨🏾' => 'güləşçi kişi: orta dəri tonu, orta-tünd dəri tonu',
    '👨🏽‍🫯‍👨🏿' => 'güləşçi kişi: orta dəri tonu, tünd dəri tonu',
    '👨🏾‍🫯‍👨🏻' => 'güləşçi kişi: orta-tünd dəri tonu, açıq dəri tonu',
    '👨🏾‍🫯‍👨🏼' => 'güləşçi kişi: orta-tünd dəri tonu, orta-açıq dəri tonu',
    '👨🏾‍🫯‍👨🏽' => 'güləşçi kişi: orta-tünd dəri tonu, orta dəri tonu',
    '👨🏾‍🫯‍👨🏿' => 'güləşçi kişi: orta-tünd dəri tonu, tünd dəri tonu',
    '👨🏿‍🫯‍👨🏻' => 'güləşçi kişi: tünd dəri tonu, açıq dəri tonu',
    '👨🏿‍🫯‍👨🏼' => 'güləşçi kişi: tünd dəri tonu, orta-açıq dəri tonu',
    '👨🏿‍🫯‍👨🏽' => 'güləşçi kişi: tünd dəri tonu, orta dəri tonu',
    '👨🏿‍🫯‍👨🏾' => 'güləşçi kişi: tünd dəri tonu, orta-tünd dəri tonu',
    '👨🏻‍❤‍👨🏻' => 'ürəkli cütlük: kişi, kişi, açıq dəri tonu',
    '👨🏻‍❤‍👨🏼' => 'ürəkli cütlük: kişi, kişi, açıq dəri tonu, orta-açıq dəri tonu',
    '👨🏻‍❤‍👨🏽' => 'ürəkli cütlük: kişi, kişi, açıq dəri tonu, orta dəri tonu',
    '👨🏻‍❤‍👨🏾' => 'ürəkli cütlük: kişi, kişi, açıq dəri tonu, orta-tünd dəri tonu',
    '👨🏻‍❤‍👨🏿' => 'ürəkli cütlük: kişi, kişi, açıq dəri tonu, tünd dəri tonu',
    '👨🏼‍❤‍👨🏻' => 'ürəkli cütlük: kişi, kişi, orta-açıq dəri tonu, açıq dəri tonu',
    '👨🏼‍❤‍👨🏼' => 'ürəkli cütlük: kişi, kişi, orta-açıq dəri tonu',
    '👨🏼‍❤‍👨🏽' => 'ürəkli cütlük: kişi, kişi, orta-açıq dəri tonu, orta dəri tonu',
    '👨🏼‍❤‍👨🏾' => 'ürəkli cütlük: kişi, kişi, orta-açıq dəri tonu, orta-tünd dəri tonu',
    '👨🏼‍❤‍👨🏿' => 'ürəkli cütlük: kişi, kişi, orta-açıq dəri tonu, tünd dəri tonu',
    '👨🏽‍❤‍👨🏻' => 'ürəkli cütlük: kişi, kişi, orta dəri tonu, açıq dəri tonu',
    '👨🏽‍❤‍👨🏼' => 'ürəkli cütlük: kişi, kişi, orta dəri tonu, orta-açıq dəri tonu',
    '👨🏽‍❤‍👨🏽' => 'ürəkli cütlük: kişi, kişi, orta dəri tonu',
    '👨🏽‍❤‍👨🏾' => 'ürəkli cütlük: kişi, kişi, orta dəri tonu, orta-tünd dəri tonu',
    '👨🏽‍❤‍👨🏿' => 'ürəkli cütlük: kişi, kişi, orta dəri tonu, tünd dəri tonu',
    '👨🏾‍❤‍👨🏻' => 'ürəkli cütlük: kişi, kişi, orta-tünd dəri tonu, açıq dəri tonu',
    '👨🏾‍❤‍👨🏼' => 'ürəkli cütlük: kişi, kişi, orta-tünd dəri tonu, orta-açıq dəri tonu',
    '👨🏾‍❤‍👨🏽' => 'ürəkli cütlük: kişi, kişi, orta-tünd dəri tonu, orta dəri tonu',
    '👨🏾‍❤‍👨🏾' => 'ürəkli cütlük: kişi, kişi, orta-tünd dəri tonu',
    '👨🏾‍❤‍👨🏿' => 'ürəkli cütlük: kişi, kişi, orta-tünd dəri tonu, tünd dəri tonu',
    '👨🏿‍❤‍👨🏻' => 'ürəkli cütlük: kişi, kişi, tünd dəri tonu, açıq dəri tonu',
    '👨🏿‍❤‍👨🏼' => 'ürəkli cütlük: kişi, kişi, tünd dəri tonu, orta-açıq dəri tonu',
    '👨🏿‍❤‍👨🏽' => 'ürəkli cütlük: kişi, kişi, tünd dəri tonu, orta dəri tonu',
    '👨🏿‍❤‍👨🏾' => 'ürəkli cütlük: kişi, kişi, tünd dəri tonu, orta-tünd dəri tonu',
    '👨🏿‍❤‍👨🏿' => 'ürəkli cütlük: kişi, kişi, tünd dəri tonu',
    '👨🏻‍🐰‍👨🏼' => 'rəqs edən kişi: açıq dəri tonu, orta-açıq dəri tonu',
    '👨🏻‍🐰‍👨🏽' => 'rəqs edən kişi: açıq dəri tonu, orta dəri tonu',
    '👨🏻‍🐰‍👨🏾' => 'rəqs edən kişi: açıq dəri tonu, orta-tünd dəri tonu',
    '👨🏻‍🐰‍👨🏿' => 'rəqs edən kişi: açıq dəri tonu, tünd dəri tonu',
    '👨🏼‍🐰‍👨🏻' => 'rəqs edən kişi: orta-açıq dəri tonu, açıq dəri tonu',
    '👨🏼‍🐰‍👨🏽' => 'rəqs edən kişi: orta-açıq dəri tonu, orta dəri tonu',
    '👨🏼‍🐰‍👨🏾' => 'rəqs edən kişi: orta-açıq dəri tonu, orta-tünd dəri tonu',
    '👨🏼‍🐰‍👨🏿' => 'rəqs edən kişi: orta-açıq dəri tonu, tünd dəri tonu',
    '👨🏽‍🐰‍👨🏻' => 'rəqs edən kişi: orta dəri tonu, açıq dəri tonu',
    '👨🏽‍🐰‍👨🏼' => 'rəqs edən kişi: orta dəri tonu, orta-açıq dəri tonu',
    '👨🏽‍🐰‍👨🏾' => 'rəqs edən kişi: orta dəri tonu, orta-tünd dəri tonu',
    '👨🏽‍🐰‍👨🏿' => 'rəqs edən kişi: orta dəri tonu, tünd dəri tonu',
    '👨🏾‍🐰‍👨🏻' => 'rəqs edən kişi: orta-tünd dəri tonu, açıq dəri tonu',
    '👨🏾‍🐰‍👨🏼' => 'rəqs edən kişi: orta-tünd dəri tonu, orta-açıq dəri tonu',
    '👨🏾‍🐰‍👨🏽' => 'rəqs edən kişi: orta-tünd dəri tonu, orta dəri tonu',
    '👨🏾‍🐰‍👨🏿' => 'rəqs edən kişi: orta-tünd dəri tonu, tünd dəri tonu',
    '👨🏿‍🐰‍👨🏻' => 'rəqs edən kişi: tünd dəri tonu, açıq dəri tonu',
    '👨🏿‍🐰‍👨🏼' => 'rəqs edən kişi: tünd dəri tonu, orta-açıq dəri tonu',
    '👨🏿‍🐰‍👨🏽' => 'rəqs edən kişi: tünd dəri tonu, orta dəri tonu',
    '👨🏿‍🐰‍👨🏾' => 'rəqs edən kişi: tünd dəri tonu, orta-tünd dəri tonu',
    '👩🏻‍🫯‍👩🏼' => 'güləşçi qadın: açıq dəri tonu, orta-açıq dəri tonu',
    '👩🏻‍🫯‍👩🏽' => 'güləşçi qadın: açıq dəri tonu, orta dəri tonu',
    '👩🏻‍🫯‍👩🏾' => 'güləşçi qadın: açıq dəri tonu, orta-tünd dəri tonu',
    '👩🏻‍🫯‍👩🏿' => 'güləşçi qadın: açıq dəri tonu, tünd dəri tonu',
    '👩🏼‍🫯‍👩🏻' => 'güləşçi qadın: orta-açıq dəri tonu, açıq dəri tonu',
    '👩🏼‍🫯‍👩🏽' => 'güləşçi qadın: orta-açıq dəri tonu, orta dəri tonu',
    '👩🏼‍🫯‍👩🏾' => 'güləşçi qadın: orta-açıq dəri tonu, orta-tünd dəri tonu',
    '👩🏼‍🫯‍👩🏿' => 'güləşçi qadın: orta-açıq dəri tonu, tünd dəri tonu',
    '👩🏽‍🫯‍👩🏻' => 'güləşçi qadın: orta dəri tonu, açıq dəri tonu',
    '👩🏽‍🫯‍👩🏼' => 'güləşçi qadın: orta dəri tonu, orta-açıq dəri tonu',
    '👩🏽‍🫯‍👩🏾' => 'güləşçi qadın: orta dəri tonu, orta-tünd dəri tonu',
    '👩🏽‍🫯‍👩🏿' => 'güləşçi qadın: orta dəri tonu, tünd dəri tonu',
    '👩🏾‍🫯‍👩🏻' => 'güləşçi qadın: orta-tünd dəri tonu, açıq dəri tonu',
    '👩🏾‍🫯‍👩🏼' => 'güləşçi qadın: orta-tünd dəri tonu, orta-açıq dəri tonu',
    '👩🏾‍🫯‍👩🏽' => 'güləşçi qadın: orta-tünd dəri tonu, orta dəri tonu',
    '👩🏾‍🫯‍👩🏿' => 'güləşçi qadın: orta-tünd dəri tonu, tünd dəri tonu',
    '👩🏿‍🫯‍👩🏻' => 'güləşçi qadın: tünd dəri tonu, açıq dəri tonu',
    '👩🏿‍🫯‍👩🏼' => 'güləşçi qadın: tünd dəri tonu, orta-açıq dəri tonu',
    '👩🏿‍🫯‍👩🏽' => 'güləşçi qadın: tünd dəri tonu, orta dəri tonu',
    '👩🏿‍🫯‍👩🏾' => 'güləşçi qadın: tünd dəri tonu, orta-tünd dəri tonu',
    '👩🏻‍❤‍👨🏻' => 'ürəkli cütlük: qadın, kişi, açıq dəri tonu',
    '👩🏻‍❤‍👨🏼' => 'ürəkli cütlük: qadın, kişi, açıq dəri tonu, orta-açıq dəri tonu',
    '👩🏻‍❤‍👨🏽' => 'ürəkli cütlük: qadın, kişi, açıq dəri tonu, orta dəri tonu',
    '👩🏻‍❤‍👨🏾' => 'ürəkli cütlük: qadın, kişi, açıq dəri tonu, orta-tünd dəri tonu',
    '👩🏻‍❤‍👨🏿' => 'ürəkli cütlük: qadın, kişi, açıq dəri tonu, tünd dəri tonu',
    '👩🏼‍❤‍👨🏻' => 'ürəkli cütlük: qadın, kişi, orta-açıq dəri tonu, açıq dəri tonu',
    '👩🏼‍❤‍👨🏼' => 'ürəkli cütlük: qadın, kişi, orta-açıq dəri tonu',
    '👩🏼‍❤‍👨🏽' => 'ürəkli cütlük: qadın, kişi, orta-açıq dəri tonu, orta dəri tonu',
    '👩🏼‍❤‍👨🏾' => 'ürəkli cütlük: qadın, kişi, orta-açıq dəri tonu, orta-tünd dəri tonu',
    '👩🏼‍❤‍👨🏿' => 'ürəkli cütlük: qadın, kişi, orta-açıq dəri tonu, tünd dəri tonu',
    '👩🏽‍❤‍👨🏻' => 'ürəkli cütlük: qadın, kişi, orta dəri tonu, açıq dəri tonu',
    '👩🏽‍❤‍👨🏼' => 'ürəkli cütlük: qadın, kişi, orta dəri tonu, orta-açıq dəri tonu',
    '👩🏽‍❤‍👨🏽' => 'ürəkli cütlük: qadın, kişi, orta dəri tonu',
    '👩🏽‍❤‍👨🏾' => 'ürəkli cütlük: qadın, kişi, orta dəri tonu, orta-tünd dəri tonu',
    '👩🏽‍❤‍👨🏿' => 'ürəkli cütlük: qadın, kişi, orta dəri tonu, tünd dəri tonu',
    '👩🏾‍❤‍👨🏻' => 'ürəkli cütlük: qadın, kişi, orta-tünd dəri tonu, açıq dəri tonu',
    '👩🏾‍❤‍👨🏼' => 'ürəkli cütlük: qadın, kişi, orta-tünd dəri tonu, orta-açıq dəri tonu',
    '👩🏾‍❤‍👨🏽' => 'ürəkli cütlük: qadın, kişi, orta-tünd dəri tonu, orta dəri tonu',
    '👩🏾‍❤‍👨🏾' => 'ürəkli cütlük: qadın, kişi, orta-tünd dəri tonu',
    '👩🏾‍❤‍👨🏿' => 'ürəkli cütlük: qadın, kişi, orta-tünd dəri tonu, tünd dəri tonu',
    '👩🏿‍❤‍👨🏻' => 'ürəkli cütlük: qadın, kişi, tünd dəri tonu, açıq dəri tonu',
    '👩🏿‍❤‍👨🏼' => 'ürəkli cütlük: qadın, kişi, tünd dəri tonu, orta-açıq dəri tonu',
    '👩🏿‍❤‍👨🏽' => 'ürəkli cütlük: qadın, kişi, tünd dəri tonu, orta dəri tonu',
    '👩🏿‍❤‍👨🏾' => 'ürəkli cütlük: qadın, kişi, tünd dəri tonu, orta-tünd dəri tonu',
    '👩🏿‍❤‍👨🏿' => 'ürəkli cütlük: qadın, kişi, tünd dəri tonu',
    '👩🏻‍❤‍👩🏻' => 'ürəkli cütlük: qadın, qadın, açıq dəri tonu',
    '👩🏻‍❤‍👩🏼' => 'ürəkli cütlük: qadın, qadın, açıq dəri tonu, orta-açıq dəri tonu',
    '👩🏻‍❤‍👩🏽' => 'ürəkli cütlük: qadın, qadın, açıq dəri tonu, orta dəri tonu',
    '👩🏻‍❤‍👩🏾' => 'ürəkli cütlük: qadın, qadın, açıq dəri tonu, orta-tünd dəri tonu',
    '👩🏻‍❤‍👩🏿' => 'ürəkli cütlük: qadın, qadın, açıq dəri tonu, tünd dəri tonu',
    '👩🏼‍❤‍👩🏻' => 'ürəkli cütlük: qadın, qadın, orta-açıq dəri tonu, açıq dəri tonu',
    '👩🏼‍❤‍👩🏼' => 'ürəkli cütlük: qadın, qadın, orta-açıq dəri tonu',
    '👩🏼‍❤‍👩🏽' => 'ürəkli cütlük: qadın, qadın, orta-açıq dəri tonu, orta dəri tonu',
    '👩🏼‍❤‍👩🏾' => 'ürəkli cütlük: qadın, qadın, orta-açıq dəri tonu, orta-tünd dəri tonu',
    '👩🏼‍❤‍👩🏿' => 'ürəkli cütlük: qadın, qadın, orta-açıq dəri tonu, tünd dəri tonu',
    '👩🏽‍❤‍👩🏻' => 'ürəkli cütlük: qadın, qadın, orta dəri tonu, açıq dəri tonu',
    '👩🏽‍❤‍👩🏼' => 'ürəkli cütlük: qadın, qadın, orta dəri tonu, orta-açıq dəri tonu',
    '👩🏽‍❤‍👩🏽' => 'ürəkli cütlük: qadın, qadın, orta dəri tonu',
    '👩🏽‍❤‍👩🏾' => 'ürəkli cütlük: qadın, qadın, orta dəri tonu, orta-tünd dəri tonu',
    '👩🏽‍❤‍👩🏿' => 'ürəkli cütlük: qadın, qadın, orta dəri tonu, tünd dəri tonu',
    '👩🏾‍❤‍👩🏻' => 'ürəkli cütlük: qadın, qadın, orta-tünd dəri tonu, açıq dəri tonu',
    '👩🏾‍❤‍👩🏼' => 'ürəkli cütlük: qadın, qadın, orta-tünd dəri tonu, orta-açıq dəri tonu',
    '👩🏾‍❤‍👩🏽' => 'ürəkli cütlük: qadın, qadın, orta-tünd dəri tonu, orta dəri tonu',
    '👩🏾‍❤‍👩🏾' => 'ürəkli cütlük: qadın, qadın, orta-tünd dəri tonu',
    '👩🏾‍❤‍👩🏿' => 'ürəkli cütlük: qadın, qadın, orta-tünd dəri tonu, tünd dəri tonu',
    '👩🏿‍❤‍👩🏻' => 'ürəkli cütlük: qadın, qadın, tünd dəri tonu, açıq dəri tonu',
    '👩🏿‍❤‍👩🏼' => 'ürəkli cütlük: qadın, qadın, tünd dəri tonu, orta-açıq dəri tonu',
    '👩🏿‍❤‍👩🏽' => 'ürəkli cütlük: qadın, qadın, tünd dəri tonu, orta dəri tonu',
    '👩🏿‍❤‍👩🏾' => 'ürəkli cütlük: qadın, qadın, tünd dəri tonu, orta-tünd dəri tonu',
    '👩🏿‍❤‍👩🏿' => 'ürəkli cütlük: qadın, qadın, tünd dəri tonu',
    '👩🏻‍🐰‍👩🏼' => 'rəqs edən qadınlar: açıq dəri tonu, orta-açıq dəri tonu',
    '👩🏻‍🐰‍👩🏽' => 'rəqs edən qadınlar: açıq dəri tonu, orta dəri tonu',
    '👩🏻‍🐰‍👩🏾' => 'rəqs edən qadınlar: açıq dəri tonu, orta-tünd dəri tonu',
    '👩🏻‍🐰‍👩🏿' => 'rəqs edən qadınlar: açıq dəri tonu, tünd dəri tonu',
    '👩🏼‍🐰‍👩🏻' => 'rəqs edən qadınlar: orta-açıq dəri tonu, açıq dəri tonu',
    '👩🏼‍🐰‍👩🏽' => 'rəqs edən qadınlar: orta-açıq dəri tonu, orta dəri tonu',
    '👩🏼‍🐰‍👩🏾' => 'rəqs edən qadınlar: orta-açıq dəri tonu, orta-tünd dəri tonu',
    '👩🏼‍🐰‍👩🏿' => 'rəqs edən qadınlar: orta-açıq dəri tonu, tünd dəri tonu',
    '👩🏽‍🐰‍👩🏻' => 'rəqs edən qadınlar: orta dəri tonu, açıq dəri tonu',
    '👩🏽‍🐰‍👩🏼' => 'rəqs edən qadınlar: orta dəri tonu, orta-açıq dəri tonu',
    '👩🏽‍🐰‍👩🏾' => 'rəqs edən qadınlar: orta dəri tonu, orta-tünd dəri tonu',
    '👩🏽‍🐰‍👩🏿' => 'rəqs edən qadınlar: orta dəri tonu, tünd dəri tonu',
    '👩🏾‍🐰‍👩🏻' => 'rəqs edən qadınlar: orta-tünd dəri tonu, açıq dəri tonu',
    '👩🏾‍🐰‍👩🏼' => 'rəqs edən qadınlar: orta-tünd dəri tonu, orta-açıq dəri tonu',
    '👩🏾‍🐰‍👩🏽' => 'rəqs edən qadınlar: orta-tünd dəri tonu, orta dəri tonu',
    '👩🏾‍🐰‍👩🏿' => 'rəqs edən qadınlar: orta-tünd dəri tonu, tünd dəri tonu',
    '👩🏿‍🐰‍👩🏻' => 'rəqs edən qadınlar: tünd dəri tonu, açıq dəri tonu',
    '👩🏿‍🐰‍👩🏼' => 'rəqs edən qadınlar: tünd dəri tonu, orta-açıq dəri tonu',
    '👩🏿‍🐰‍👩🏽' => 'rəqs edən qadınlar: tünd dəri tonu, orta dəri tonu',
    '👩🏿‍🐰‍👩🏾' => 'rəqs edən qadınlar: tünd dəri tonu, orta-tünd dəri tonu',
    '🧑🏻‍🤝‍🧑🏻' => 'əl-ələ tutan adamlar: açıq dəri tonu',
    '🧑🏻‍🤝‍🧑🏼' => 'əl-ələ tutan adamlar: açıq dəri tonu, orta-açıq dəri tonu',
    '🧑🏻‍🤝‍🧑🏽' => 'əl-ələ tutan adamlar: açıq dəri tonu, orta dəri tonu',
    '🧑🏻‍🤝‍🧑🏾' => 'əl-ələ tutan adamlar: açıq dəri tonu, orta-tünd dəri tonu',
    '🧑🏻‍🤝‍🧑🏿' => 'əl-ələ tutan adamlar: açıq dəri tonu, tünd dəri tonu',
    '🧑🏼‍🤝‍🧑🏻' => 'əl-ələ tutan adamlar: orta-açıq dəri tonu, açıq dəri tonu',
    '🧑🏼‍🤝‍🧑🏼' => 'əl-ələ tutan adamlar: orta-açıq dəri tonu',
    '🧑🏼‍🤝‍🧑🏽' => 'əl-ələ tutan adamlar: orta-açıq dəri tonu, orta dəri tonu',
    '🧑🏼‍🤝‍🧑🏾' => 'əl-ələ tutan adamlar: orta-açıq dəri tonu, orta-tünd dəri tonu',
    '🧑🏼‍🤝‍🧑🏿' => 'əl-ələ tutan adamlar: orta-açıq dəri tonu, tünd dəri tonu',
    '🧑🏽‍🤝‍🧑🏻' => 'əl-ələ tutan adamlar: orta dəri tonu, açıq dəri tonu',
    '🧑🏽‍🤝‍🧑🏼' => 'əl-ələ tutan adamlar: orta dəri tonu, orta-açıq dəri tonu',
    '🧑🏽‍🤝‍🧑🏽' => 'əl-ələ tutan adamlar: orta dəri tonu',
    '🧑🏽‍🤝‍🧑🏾' => 'əl-ələ tutan adamlar: orta dəri tonu, orta-tünd dəri tonu',
    '🧑🏽‍🤝‍🧑🏿' => 'əl-ələ tutan adamlar: orta dəri tonu, tünd dəri tonu',
    '🧑🏾‍🤝‍🧑🏻' => 'əl-ələ tutan adamlar: orta-tünd dəri tonu, açıq dəri tonu',
    '🧑🏾‍🤝‍🧑🏼' => 'əl-ələ tutan adamlar: orta-tünd dəri tonu, orta-açıq dəri tonu',
    '🧑🏾‍🤝‍🧑🏽' => 'əl-ələ tutan adamlar: orta-tünd dəri tonu, orta dəri tonu',
    '🧑🏾‍🤝‍🧑🏾' => 'əl-ələ tutan adamlar: orta-tünd dəri tonu',
    '🧑🏾‍🤝‍🧑🏿' => 'əl-ələ tutan adamlar: orta-tünd dəri tonu, tünd dəri tonu',
    '🧑🏿‍🤝‍🧑🏻' => 'əl-ələ tutan adamlar: tünd dəri tonu, açıq dəri tonu',
    '🧑🏿‍🤝‍🧑🏼' => 'əl-ələ tutan adamlar: tünd dəri tonu, orta-açıq dəri tonu',
    '🧑🏿‍🤝‍🧑🏽' => 'əl-ələ tutan adamlar: tünd dəri tonu, orta dəri tonu',
    '🧑🏿‍🤝‍🧑🏾' => 'əl-ələ tutan adamlar: tünd dəri tonu, orta-tünd dəri tonu',
    '🧑🏿‍🤝‍🧑🏿' => 'əl-ələ tutan adamlar: tünd dəri tonu',
    '👩🏻‍🤝‍👩🏼' => 'əl-ələ tutan iki qadın: açıq dəri tonu, orta-açıq dəri tonu',
    '👩🏻‍🤝‍👩🏽' => 'əl-ələ tutan iki qadın: açıq dəri tonu, orta dəri tonu',
    '👩🏻‍🤝‍👩🏾' => 'əl-ələ tutan iki qadın: açıq dəri tonu, orta-tünd dəri tonu',
    '👩🏻‍🤝‍👩🏿' => 'əl-ələ tutan iki qadın: açıq dəri tonu, tünd dəri tonu',
    '👩🏼‍🤝‍👩🏻' => 'əl-ələ tutan iki qadın: orta-açıq dəri tonu, açıq dəri tonu',
    '👩🏼‍🤝‍👩🏽' => 'əl-ələ tutan iki qadın: orta-açıq dəri tonu, orta dəri tonu',
    '👩🏼‍🤝‍👩🏾' => 'əl-ələ tutan iki qadın: orta-açıq dəri tonu, orta-tünd dəri tonu',
    '👩🏼‍🤝‍👩🏿' => 'əl-ələ tutan iki qadın: orta-açıq dəri tonu, tünd dəri tonu',
    '👩🏽‍🤝‍👩🏻' => 'əl-ələ tutan iki qadın: orta dəri tonu, açıq dəri tonu',
    '👩🏽‍🤝‍👩🏼' => 'əl-ələ tutan iki qadın: orta dəri tonu, orta-açıq dəri tonu',
    '👩🏽‍🤝‍👩🏾' => 'əl-ələ tutan iki qadın: orta dəri tonu, orta-tünd dəri tonu',
    '👩🏽‍🤝‍👩🏿' => 'əl-ələ tutan iki qadın: orta dəri tonu, tünd dəri tonu',
    '👩🏾‍🤝‍👩🏻' => 'əl-ələ tutan iki qadın: orta-tünd dəri tonu, açıq dəri tonu',
    '👩🏾‍🤝‍👩🏼' => 'əl-ələ tutan iki qadın: orta-tünd dəri tonu, orta-açıq dəri tonu',
    '👩🏾‍🤝‍👩🏽' => 'əl-ələ tutan iki qadın: orta-tünd dəri tonu, orta dəri tonu',
    '👩🏾‍🤝‍👩🏿' => 'əl-ələ tutan iki qadın: orta-tünd dəri tonu, tünd dəri tonu',
    '👩🏿‍🤝‍👩🏻' => 'əl-ələ tutan iki qadın: tünd dəri tonu, açıq dəri tonu',
    '👩🏿‍🤝‍👩🏼' => 'əl-ələ tutan iki qadın: tünd dəri tonu, orta-açıq dəri tonu',
    '👩🏿‍🤝‍👩🏽' => 'əl-ələ tutan iki qadın: tünd dəri tonu, orta dəri tonu',
    '👩🏿‍🤝‍👩🏾' => 'əl-ələ tutan iki qadın: tünd dəri tonu, orta-tünd dəri tonu',
    '👩🏻‍🤝‍👨🏼' => 'əl-ələ tutan kişi və qadın: açıq dəri tonu, orta-açıq dəri tonu',
    '👩🏻‍🤝‍👨🏽' => 'əl-ələ tutan kişi və qadın: açıq dəri tonu, orta dəri tonu',
    '👩🏻‍🤝‍👨🏾' => 'əl-ələ tutan kişi və qadın: açıq dəri tonu, orta-tünd dəri tonu',
    '👩🏻‍🤝‍👨🏿' => 'əl-ələ tutan kişi və qadın: açıq dəri tonu, tünd dəri tonu',
    '👩🏼‍🤝‍👨🏻' => 'əl-ələ tutan kişi və qadın: orta-açıq dəri tonu, açıq dəri tonu',
    '👩🏼‍🤝‍👨🏽' => 'əl-ələ tutan kişi və qadın: orta-açıq dəri tonu, orta dəri tonu',
    '👩🏼‍🤝‍👨🏾' => 'əl-ələ tutan kişi və qadın: orta-açıq dəri tonu, orta-tünd dəri tonu',
    '👩🏼‍🤝‍👨🏿' => 'əl-ələ tutan kişi və qadın: orta-açıq dəri tonu, tünd dəri tonu',
    '👩🏽‍🤝‍👨🏻' => 'əl-ələ tutan kişi və qadın: orta dəri tonu, açıq dəri tonu',
    '👩🏽‍🤝‍👨🏼' => 'əl-ələ tutan kişi və qadın: orta dəri tonu, orta-açıq dəri tonu',
    '👩🏽‍🤝‍👨🏾' => 'əl-ələ tutan kişi və qadın: orta dəri tonu, orta-tünd dəri tonu',
    '👩🏽‍🤝‍👨🏿' => 'əl-ələ tutan kişi və qadın: orta dəri tonu, tünd dəri tonu',
    '👩🏾‍🤝‍👨🏻' => 'əl-ələ tutan kişi və qadın: orta-tünd dəri tonu, açıq dəri tonu',
    '👩🏾‍🤝‍👨🏼' => 'əl-ələ tutan kişi və qadın: orta-tünd dəri tonu, orta-açıq dəri tonu',
    '👩🏾‍🤝‍👨🏽' => 'əl-ələ tutan kişi və qadın: orta-tünd dəri tonu, orta dəri tonu',
    '👩🏾‍🤝‍👨🏿' => 'əl-ələ tutan kişi və qadın: orta-tünd dəri tonu, tünd dəri tonu',
    '👩🏿‍🤝‍👨🏻' => 'əl-ələ tutan kişi və qadın: tünd dəri tonu, açıq dəri tonu',
    '👩🏿‍🤝‍👨🏼' => 'əl-ələ tutan kişi və qadın: tünd dəri tonu, orta-açıq dəri tonu',
    '👩🏿‍🤝‍👨🏽' => 'əl-ələ tutan kişi və qadın: tünd dəri tonu, orta dəri tonu',
    '👩🏿‍🤝‍👨🏾' => 'əl-ələ tutan kişi və qadın: tünd dəri tonu, orta-tünd dəri tonu',
    '👨🏻‍🤝‍👨🏼' => 'əl-ələ tutan iki kişi: açıq dəri tonu, orta-açıq dəri tonu',
    '👨🏻‍🤝‍👨🏽' => 'əl-ələ tutan iki kişi: açıq dəri tonu, orta dəri tonu',
    '👨🏻‍🤝‍👨🏾' => 'əl-ələ tutan iki kişi: açıq dəri tonu, orta-tünd dəri tonu',
    '👨🏻‍🤝‍👨🏿' => 'əl-ələ tutan iki kişi: açıq dəri tonu, tünd dəri tonu',
    '👨🏼‍🤝‍👨🏻' => 'əl-ələ tutan iki kişi: orta-açıq dəri tonu, açıq dəri tonu',
    '👨🏼‍🤝‍👨🏽' => 'əl-ələ tutan iki kişi: orta-açıq dəri tonu, orta dəri tonu',
    '👨🏼‍🤝‍👨🏾' => 'əl-ələ tutan iki kişi: orta-açıq dəri tonu, orta-tünd dəri tonu',
    '👨🏼‍🤝‍👨🏿' => 'əl-ələ tutan iki kişi: orta-açıq dəri tonu, tünd dəri tonu',
    '👨🏽‍🤝‍👨🏻' => 'əl-ələ tutan iki kişi: orta dəri tonu, açıq dəri tonu',
    '👨🏽‍🤝‍👨🏼' => 'əl-ələ tutan iki kişi: orta dəri tonu, orta-açıq dəri tonu',
    '👨🏽‍🤝‍👨🏾' => 'əl-ələ tutan iki kişi: orta dəri tonu, orta-tünd dəri tonu',
    '👨🏽‍🤝‍👨🏿' => 'əl-ələ tutan iki kişi: orta dəri tonu, tünd dəri tonu',
    '👨🏾‍🤝‍👨🏻' => 'əl-ələ tutan iki kişi: orta-tünd dəri tonu, açıq dəri tonu',
    '👨🏾‍🤝‍👨🏼' => 'əl-ələ tutan iki kişi: orta-tünd dəri tonu, orta-açıq dəri tonu',
    '👨🏾‍🤝‍👨🏽' => 'əl-ələ tutan iki kişi: orta-tünd dəri tonu, orta dəri tonu',
    '👨🏾‍🤝‍👨🏿' => 'əl-ələ tutan iki kişi: orta-tünd dəri tonu, tünd dəri tonu',
    '👨🏿‍🤝‍👨🏻' => 'əl-ələ tutan iki kişi: tünd dəri tonu, açıq dəri tonu',
    '👨🏿‍🤝‍👨🏼' => 'əl-ələ tutan iki kişi: tünd dəri tonu, orta-açıq dəri tonu',
    '👨🏿‍🤝‍👨🏽' => 'əl-ələ tutan iki kişi: tünd dəri tonu, orta dəri tonu',
    '👨🏿‍🤝‍👨🏾' => 'əl-ələ tutan iki kişi: tünd dəri tonu, orta-tünd dəri tonu',
    '👩‍❤‍💋‍👨' => 'öpüş: qadın, kişi',
    '👨‍❤‍💋‍👨' => 'öpüş: kişi, kişi',
    '👩‍❤‍💋‍👩' => 'öpüş: qadın, qadın',
    '👨‍👩‍👧‍👦' => 'ailə: kişi, qadın, qız uşağı, oğlan',
    '👨‍👩‍👦‍👦' => 'ailə: kişi, qadın, oğlan, oğlan',
    '👨‍👩‍👧‍👧' => 'ailə: kişi, qadın, qız uşağı, qız uşağı',
    '👨‍👨‍👧‍👦' => 'ailə: kişi, kişi, qız uşağı, oğlan',
    '👨‍👨‍👦‍👦' => 'ailə: kişi, kişi, oğlan, oğlan',
    '👨‍👨‍👧‍👧' => 'ailə: kişi, kişi, qız uşağı, qız uşağı',
    '👩‍👩‍👧‍👦' => 'ailə: qadın, qadın, qız uşağı, oğlan',
    '👩‍👩‍👦‍👦' => 'ailə: qadın, qadın, oğlan, oğlan',
    '👩‍👩‍👧‍👧' => 'ailə: qadın, qadın, qız uşağı, qız uşağı',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'bayraq: İngiltərə',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'bayraq: Şotlandiya',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'bayraq: Uels',
    '🧑‍🧑‍🧒‍🧒' => 'ailə: yetkin, yetkin, uşaq, uşaq',
    '🚶🏻‍♀‍➡' => 'gəzən qadın: açıq dəri tonu, sağa baxan',
    '🚶🏼‍♀‍➡' => 'gəzən qadın: orta-açıq dəri tonu, sağa baxan',
    '🚶🏽‍♀‍➡' => 'gəzən qadın: orta dəri tonu, sağa baxan',
    '🚶🏾‍♀‍➡' => 'gəzən qadın: orta-tünd dəri tonu, sağa baxan',
    '🚶🏿‍♀‍➡' => 'gəzən qadın: tünd dəri tonu, sağa baxan',
    '🚶🏻‍♂‍➡' => 'gəzən kişi: açıq dəri tonu, sağa baxan',
    '🚶🏼‍♂‍➡' => 'gəzən kişi: orta-açıq dəri tonu, sağa baxan',
    '🚶🏽‍♂‍➡' => 'gəzən kişi: orta dəri tonu, sağa baxan',
    '🚶🏾‍♂‍➡' => 'gəzən kişi: orta-tünd dəri tonu, sağa baxan',
    '🚶🏿‍♂‍➡' => 'gəzən kişi: tünd dəri tonu, sağa baxan',
    '🧎🏻‍♀‍➡' => 'dizi üstündə qadın: açıq dəri tonu, sağa baxan',
    '🧎🏼‍♀‍➡' => 'dizi üstündə qadın: orta-açıq dəri tonu, sağa baxan',
    '🧎🏽‍♀‍➡' => 'dizi üstündə qadın: orta dəri tonu, sağa baxan',
    '🧎🏾‍♀‍➡' => 'dizi üstündə qadın: orta-tünd dəri tonu, sağa baxan',
    '🧎🏿‍♀‍➡' => 'dizi üstündə qadın: tünd dəri tonu, sağa baxan',
    '🧎🏻‍♂‍➡' => 'dizi üstündə kişi: açıq dəri tonu, sağa baxan',
    '🧎🏼‍♂‍➡' => 'dizi üstündə kişi: orta-açıq dəri tonu, sağa baxan',
    '🧎🏽‍♂‍➡' => 'dizi üstündə kişi: orta dəri tonu, sağa baxan',
    '🧎🏾‍♂‍➡' => 'dizi üstündə kişi: orta-tünd dəri tonu, sağa baxan',
    '🧎🏿‍♂‍➡' => 'dizi üstündə kişi: tünd dəri tonu, sağa baxan',
    '🧑🏻‍🦯‍➡' => 'zondlayan çəlikli adam: açıq dəri tonu, sağa baxan',
    '🧑🏼‍🦯‍➡' => 'zondlayan çəlikli adam: orta-açıq dəri tonu, sağa baxan',
    '🧑🏽‍🦯‍➡' => 'zondlayan çəlikli adam: orta dəri tonu, sağa baxan',
    '🧑🏾‍🦯‍➡' => 'zondlayan çəlikli adam: orta-tünd dəri tonu, sağa baxan',
    '🧑🏿‍🦯‍➡' => 'zondlayan çəlikli adam: tünd dəri tonu, sağa baxan',
    '👨🏻‍🦯‍➡' => 'zond ilə kişi: açıq dəri tonu, sağa baxan',
    '👨🏼‍🦯‍➡' => 'zond ilə kişi: orta-açıq dəri tonu, sağa baxan',
    '👨🏽‍🦯‍➡' => 'zond ilə kişi: orta dəri tonu, sağa baxan',
    '👨🏾‍🦯‍➡' => 'zond ilə kişi: orta-tünd dəri tonu, sağa baxan',
    '👨🏿‍🦯‍➡' => 'zond ilə kişi: tünd dəri tonu, sağa baxan',
    '👩🏻‍🦯‍➡' => 'zond ilə qadın: açıq dəri tonu, sağa baxan',
    '👩🏼‍🦯‍➡' => 'zond ilə qadın: orta-açıq dəri tonu, sağa baxan',
    '👩🏽‍🦯‍➡' => 'zond ilə qadın: orta dəri tonu, sağa baxan',
    '👩🏾‍🦯‍➡' => 'zond ilə qadın: orta-tünd dəri tonu, sağa baxan',
    '👩🏿‍🦯‍➡' => 'zond ilə qadın: tünd dəri tonu, sağa baxan',
    '🧑🏻‍🦼‍➡' => 'motorlu kresloda oturmuş adam: açıq dəri tonu, sağa baxan',
    '🧑🏼‍🦼‍➡' => 'motorlu kresloda oturmuş adam: orta-açıq dəri tonu, sağa baxan',
    '🧑🏽‍🦼‍➡' => 'motorlu kresloda oturmuş adam: orta dəri tonu, sağa baxan',
    '🧑🏾‍🦼‍➡' => 'motorlu kresloda oturmuş adam: orta-tünd dəri tonu, sağa baxan',
    '🧑🏿‍🦼‍➡' => 'motorlu kresloda oturmuş adam: tünd dəri tonu, sağa baxan',
    '👨🏻‍🦼‍➡' => 'motorlu oturacaqda kişi: açıq dəri tonu, sağa baxan',
    '👨🏼‍🦼‍➡' => 'motorlu oturacaqda kişi: orta-açıq dəri tonu, sağa baxan',
    '👨🏽‍🦼‍➡' => 'motorlu oturacaqda kişi: orta dəri tonu, sağa baxan',
    '👨🏾‍🦼‍➡' => 'motorlu oturacaqda kişi: orta-tünd dəri tonu, sağa baxan',
    '👨🏿‍🦼‍➡' => 'motorlu oturacaqda kişi: tünd dəri tonu, sağa baxan',
    '👩🏻‍🦼‍➡' => 'motorlu oturacaqda qadın: açıq dəri tonu, sağa baxan',
    '👩🏼‍🦼‍➡' => 'motorlu oturacaqda qadın: orta-açıq dəri tonu, sağa baxan',
    '👩🏽‍🦼‍➡' => 'motorlu oturacaqda qadın: orta dəri tonu, sağa baxan',
    '👩🏾‍🦼‍➡' => 'motorlu oturacaqda qadın: orta-tünd dəri tonu, sağa baxan',
    '👩🏿‍🦼‍➡' => 'motorlu oturacaqda qadın: tünd dəri tonu, sağa baxan',
    '🧑🏻‍🦽‍➡' => 'əl arabasında adam: açıq dəri tonu, sağa baxan',
    '🧑🏼‍🦽‍➡' => 'əl arabasında adam: orta-açıq dəri tonu, sağa baxan',
    '🧑🏽‍🦽‍➡' => 'əl arabasında adam: orta dəri tonu, sağa baxan',
    '🧑🏾‍🦽‍➡' => 'əl arabasında adam: orta-tünd dəri tonu, sağa baxan',
    '🧑🏿‍🦽‍➡' => 'əl arabasında adam: tünd dəri tonu, sağa baxan',
    '👨🏻‍🦽‍➡' => 'manual oturacaqda kişi: açıq dəri tonu, sağa baxan',
    '👨🏼‍🦽‍➡' => 'manual oturacaqda kişi: orta-açıq dəri tonu, sağa baxan',
    '👨🏽‍🦽‍➡' => 'manual oturacaqda kişi: orta dəri tonu, sağa baxan',
    '👨🏾‍🦽‍➡' => 'manual oturacaqda kişi: orta-tünd dəri tonu, sağa baxan',
    '👨🏿‍🦽‍➡' => 'manual oturacaqda kişi: tünd dəri tonu, sağa baxan',
    '👩🏻‍🦽‍➡' => 'manual oturacaqda qadın: açıq dəri tonu, sağa baxan',
    '👩🏼‍🦽‍➡' => 'manual oturacaqda qadın: orta-açıq dəri tonu, sağa baxan',
    '👩🏽‍🦽‍➡' => 'manual oturacaqda qadın: orta dəri tonu, sağa baxan',
    '👩🏾‍🦽‍➡' => 'manual oturacaqda qadın: orta-tünd dəri tonu, sağa baxan',
    '👩🏿‍🦽‍➡' => 'manual oturacaqda qadın: tünd dəri tonu, sağa baxan',
    '🏃🏻‍♀‍➡' => 'qaçan qadın: açıq dəri tonu, sağa baxan',
    '🏃🏼‍♀‍➡' => 'qaçan qadın: orta-açıq dəri tonu, sağa baxan',
    '🏃🏽‍♀‍➡' => 'qaçan qadın: orta dəri tonu, sağa baxan',
    '🏃🏾‍♀‍➡' => 'qaçan qadın: orta-tünd dəri tonu, sağa baxan',
    '🏃🏿‍♀‍➡' => 'qaçan qadın: tünd dəri tonu, sağa baxan',
    '🏃🏻‍♂‍➡' => 'qaçan kişi: açıq dəri tonu, sağa baxan',
    '🏃🏼‍♂‍➡' => 'qaçan kişi: orta-açıq dəri tonu, sağa baxan',
    '🏃🏽‍♂‍➡' => 'qaçan kişi: orta dəri tonu, sağa baxan',
    '🏃🏾‍♂‍➡' => 'qaçan kişi: orta-tünd dəri tonu, sağa baxan',
    '🏃🏿‍♂‍➡' => 'qaçan kişi: tünd dəri tonu, sağa baxan',
    '🫱🏻‍🫲🏼' => 'salamlaşmaq: açıq dəri tonu, orta-açıq dəri tonu',
    '🫱🏻‍🫲🏽' => 'salamlaşmaq: açıq dəri tonu, orta dəri tonu',
    '🫱🏻‍🫲🏾' => 'salamlaşmaq: açıq dəri tonu, orta-tünd dəri tonu',
    '🫱🏻‍🫲🏿' => 'salamlaşmaq: açıq dəri tonu, tünd dəri tonu',
    '🫱🏼‍🫲🏻' => 'salamlaşmaq: orta-açıq dəri tonu, açıq dəri tonu',
    '🫱🏼‍🫲🏽' => 'salamlaşmaq: orta-açıq dəri tonu, orta dəri tonu',
    '🫱🏼‍🫲🏾' => 'salamlaşmaq: orta-açıq dəri tonu, orta-tünd dəri tonu',
    '🫱🏼‍🫲🏿' => 'salamlaşmaq: orta-açıq dəri tonu, tünd dəri tonu',
    '🫱🏽‍🫲🏻' => 'salamlaşmaq: orta dəri tonu, açıq dəri tonu',
    '🫱🏽‍🫲🏼' => 'salamlaşmaq: orta dəri tonu, orta-açıq dəri tonu',
    '🫱🏽‍🫲🏾' => 'salamlaşmaq: orta dəri tonu, orta-tünd dəri tonu',
    '🫱🏽‍🫲🏿' => 'salamlaşmaq: orta dəri tonu, tünd dəri tonu',
    '🫱🏾‍🫲🏻' => 'salamlaşmaq: orta-tünd dəri tonu, açıq dəri tonu',
    '🫱🏾‍🫲🏼' => 'salamlaşmaq: orta-tünd dəri tonu, orta-açıq dəri tonu',
    '🫱🏾‍🫲🏽' => 'salamlaşmaq: orta-tünd dəri tonu, orta dəri tonu',
    '🫱🏾‍🫲🏿' => 'salamlaşmaq: orta-tünd dəri tonu, tünd dəri tonu',
    '🫱🏿‍🫲🏻' => 'salamlaşmaq: tünd dəri tonu, açıq dəri tonu',
    '🫱🏿‍🫲🏼' => 'salamlaşmaq: tünd dəri tonu, orta-açıq dəri tonu',
    '🫱🏿‍🫲🏽' => 'salamlaşmaq: tünd dəri tonu, orta dəri tonu',
    '🫱🏿‍🫲🏾' => 'salamlaşmaq: tünd dəri tonu, orta-tünd dəri tonu',
    '🚶‍♀‍➡' => 'gəzən qadın: sağa baxan',
    '🚶‍♂‍➡' => 'gəzən kişi: sağa baxan',
    '🧎‍♀‍➡' => 'dizi üstündə qadın: sağa baxan',
    '🧎‍♂‍➡' => 'dizi üstündə kişi: sağa baxan',
    '🧑‍🦯‍➡' => 'zondlayan çəlikli adam: sağa baxan',
    '👨‍🦯‍➡' => 'zond ilə kişi: sağa baxan',
    '👩‍🦯‍➡' => 'zond ilə qadın: sağa baxan',
    '🧑‍🦼‍➡' => 'motorlu kresloda oturmuş adam: sağa baxan',
    '👨‍🦼‍➡' => 'motorlu oturacaqda kişi: sağa baxan',
    '👩‍🦼‍➡' => 'motorlu oturacaqda qadın: sağa baxan',
    '🧑‍🦽‍➡' => 'əl arabasında adam: sağa baxan',
    '👨‍🦽‍➡' => 'manual oturacaqda kişi: sağa baxan',
    '👩‍🦽‍➡' => 'manual oturacaqda qadın: sağa baxan',
    '🏃‍♀‍➡' => 'qaçan qadın: sağa baxan',
    '🏃‍♂‍➡' => 'qaçan kişi: sağa baxan',
    '👩‍❤‍👨' => 'ürəkli cütlük: qadın, kişi',
    '👨‍❤‍👨' => 'ürəkli cütlük: kişi, kişi',
    '👩‍❤‍👩' => 'ürəkli cütlük: qadın, qadın',
    '👨‍👩‍👦' => 'ailə: kişi, qadın, oğlan',
    '👨‍👩‍👧' => 'ailə: kişi, qadın, qız uşağı',
    '👨‍👨‍👦' => 'ailə: kişi, kişi, oğlan',
    '👨‍👨‍👧' => 'ailə: kişi, kişi, qız uşağı',
    '👩‍👩‍👦' => 'ailə: qadın, qadın, oğlan',
    '👩‍👩‍👧' => 'ailə: qadın, qadın, qız uşağı',
    '👨‍👦‍👦' => 'ailə: kişi, oğlan, oğlan',
    '👨‍👧‍👦' => 'ailə: kişi, qız uşağı, oğlan',
    '👨‍👧‍👧' => 'ailə: kişi, qız uşağı, qız uşağı',
    '👩‍👦‍👦' => 'ailə: qadın, oğlan, oğlan',
    '👩‍👧‍👦' => 'ailə: qadın, qız uşağı, oğlan',
    '👩‍👧‍👧' => 'ailə: qadın, qız uşağı, qız uşağı',
    '🧑‍🤝‍🧑' => 'əl-ələ tutan adamlar',
    '🧑‍🧑‍🧒' => 'ailə: yetkin, yetkin, uşaq',
    '🧑‍🧒‍🧒' => 'ailə: yetkin, uşaq, uşaq',
    '🧑🏻‍🦰' => 'böyük: açıq dəri tonu, qırmızı saç',
    '🧑🏼‍🦰' => 'böyük: orta-açıq dəri tonu, qırmızı saç',
    '🧑🏽‍🦰' => 'böyük: orta dəri tonu, qırmızı saç',
    '🧑🏾‍🦰' => 'böyük: orta-tünd dəri tonu, qırmızı saç',
    '🧑🏿‍🦰' => 'böyük: tünd dəri tonu, qırmızı saç',
    '🧑🏻‍🦱' => 'böyük: açıq dəri tonu, buruq saç',
    '🧑🏼‍🦱' => 'böyük: orta-açıq dəri tonu, buruq saç',
    '🧑🏽‍🦱' => 'böyük: orta dəri tonu, buruq saç',
    '🧑🏾‍🦱' => 'böyük: orta-tünd dəri tonu, buruq saç',
    '🧑🏿‍🦱' => 'böyük: tünd dəri tonu, buruq saç',
    '🧑🏻‍🦳' => 'böyük: açıq dəri tonu, ağ saç',
    '🧑🏼‍🦳' => 'böyük: orta-açıq dəri tonu, ağ saç',
    '🧑🏽‍🦳' => 'böyük: orta dəri tonu, ağ saç',
    '🧑🏾‍🦳' => 'böyük: orta-tünd dəri tonu, ağ saç',
    '🧑🏿‍🦳' => 'böyük: tünd dəri tonu, ağ saç',
    '🧑🏻‍🦲' => 'böyük: açıq dəri tonu, keçəl',
    '🧑🏼‍🦲' => 'böyük: orta-açıq dəri tonu, keçəl',
    '🧑🏽‍🦲' => 'böyük: orta dəri tonu, keçəl',
    '🧑🏾‍🦲' => 'böyük: orta-tünd dəri tonu, keçəl',
    '🧑🏿‍🦲' => 'böyük: tünd dəri tonu, keçəl',
    '🧑🏻‍🩰' => 'balet rəqqası: açıq dəri tonu',
    '🧑🏼‍🩰' => 'balet rəqqası: orta-açıq dəri tonu',
    '🧑🏽‍🩰' => 'balet rəqqası: orta dəri tonu',
    '🧑🏾‍🩰' => 'balet rəqqası: orta-tünd dəri tonu',
    '🧑🏿‍🩰' => 'balet rəqqası: tünd dəri tonu',
    '🧔🏻‍♂' => 'kişi; saqqal: açıq dəri tonu',
    '🧔🏼‍♂' => 'kişi; saqqal: orta-açıq dəri tonu',
    '🧔🏽‍♂' => 'kişi; saqqal: orta dəri tonu',
    '🧔🏾‍♂' => 'kişi; saqqal: orta-tünd dəri tonu',
    '🧔🏿‍♂' => 'kişi; saqqal: tünd dəri tonu',
    '👱🏻‍♂' => 'sarışın kişi: açıq dəri tonu',
    '👱🏼‍♂' => 'sarışın kişi: orta-açıq dəri tonu',
    '👱🏽‍♂' => 'sarışın kişi: orta dəri tonu',
    '👱🏾‍♂' => 'sarışın kişi: orta-tünd dəri tonu',
    '👱🏿‍♂' => 'sarışın kişi: tünd dəri tonu',
    '👨🏻‍🦰' => 'kişi: açıq dəri tonu, qırmızı saç',
    '👨🏼‍🦰' => 'kişi: orta-açıq dəri tonu, qırmızı saç',
    '👨🏽‍🦰' => 'kişi: orta dəri tonu, qırmızı saç',
    '👨🏾‍🦰' => 'kişi: orta-tünd dəri tonu, qırmızı saç',
    '👨🏿‍🦰' => 'kişi: tünd dəri tonu, qırmızı saç',
    '👨🏻‍🦱' => 'kişi: açıq dəri tonu, buruq saç',
    '👨🏼‍🦱' => 'kişi: orta-açıq dəri tonu, buruq saç',
    '👨🏽‍🦱' => 'kişi: orta dəri tonu, buruq saç',
    '👨🏾‍🦱' => 'kişi: orta-tünd dəri tonu, buruq saç',
    '👨🏿‍🦱' => 'kişi: tünd dəri tonu, buruq saç',
    '👨🏻‍🦳' => 'kişi: açıq dəri tonu, ağ saç',
    '👨🏼‍🦳' => 'kişi: orta-açıq dəri tonu, ağ saç',
    '👨🏽‍🦳' => 'kişi: orta dəri tonu, ağ saç',
    '👨🏾‍🦳' => 'kişi: orta-tünd dəri tonu, ağ saç',
    '👨🏿‍🦳' => 'kişi: tünd dəri tonu, ağ saç',
    '👨🏻‍🦲' => 'kişi: açıq dəri tonu, keçəl',
    '👨🏼‍🦲' => 'kişi: orta-açıq dəri tonu, keçəl',
    '👨🏽‍🦲' => 'kişi: orta dəri tonu, keçəl',
    '👨🏾‍🦲' => 'kişi: orta-tünd dəri tonu, keçəl',
    '👨🏿‍🦲' => 'kişi: tünd dəri tonu, keçəl',
    '🧔🏻‍♀' => 'qadın: açıq dəri tonu, saqqal',
    '🧔🏼‍♀' => 'qadın: orta-açıq dəri tonu, saqqal',
    '🧔🏽‍♀' => 'qadın: orta dəri tonu, saqqal',
    '🧔🏾‍♀' => 'qadın: orta-tünd dəri tonu, saqqal',
    '🧔🏿‍♀' => 'qadın: tünd dəri tonu, saqqal',
    '👱🏻‍♀' => 'sarışın qadın: açıq dəri tonu',
    '👱🏼‍♀' => 'sarışın qadın: orta-açıq dəri tonu',
    '👱🏽‍♀' => 'sarışın qadın: orta dəri tonu',
    '👱🏾‍♀' => 'sarışın qadın: orta-tünd dəri tonu',
    '👱🏿‍♀' => 'sarışın qadın: tünd dəri tonu',
    '👩🏻‍🦰' => 'qadın: açıq dəri tonu, qırmızı saç',
    '👩🏼‍🦰' => 'qadın: orta-açıq dəri tonu, qırmızı saç',
    '👩🏽‍🦰' => 'qadın: orta dəri tonu, qırmızı saç',
    '👩🏾‍🦰' => 'qadın: orta-tünd dəri tonu, qırmızı saç',
    '👩🏿‍🦰' => 'qadın: tünd dəri tonu, qırmızı saç',
    '👩🏻‍🦱' => 'qadın: açıq dəri tonu, buruq saç',
    '👩🏼‍🦱' => 'qadın: orta-açıq dəri tonu, buruq saç',
    '👩🏽‍🦱' => 'qadın: orta dəri tonu, buruq saç',
    '👩🏾‍🦱' => 'qadın: orta-tünd dəri tonu, buruq saç',
    '👩🏿‍🦱' => 'qadın: tünd dəri tonu, buruq saç',
    '👩🏻‍🦳' => 'qadın: açıq dəri tonu, ağ saç',
    '👩🏼‍🦳' => 'qadın: orta-açıq dəri tonu, ağ saç',
    '👩🏽‍🦳' => 'qadın: orta dəri tonu, ağ saç',
    '👩🏾‍🦳' => 'qadın: orta-tünd dəri tonu, ağ saç',
    '👩🏿‍🦳' => 'qadın: tünd dəri tonu, ağ saç',
    '👩🏻‍🦲' => 'qadın: açıq dəri tonu, keçəl',
    '👩🏼‍🦲' => 'qadın: orta-açıq dəri tonu, keçəl',
    '👩🏽‍🦲' => 'qadın: orta dəri tonu, keçəl',
    '👩🏾‍🦲' => 'qadın: orta-tünd dəri tonu, keçəl',
    '👩🏿‍🦲' => 'qadın: tünd dəri tonu, keçəl',
    '🙍🏻‍♂' => 'kefsiz kişi: açıq dəri tonu',
    '🙍🏼‍♂' => 'kefsiz kişi: orta-açıq dəri tonu',
    '🙍🏽‍♂' => 'kefsiz kişi: orta dəri tonu',
    '🙍🏾‍♂' => 'kefsiz kişi: orta-tünd dəri tonu',
    '🙍🏿‍♂' => 'kefsiz kişi: tünd dəri tonu',
    '🙍🏻‍♀' => 'kefsiz qadın: açıq dəri tonu',
    '🙍🏼‍♀' => 'kefsiz qadın: orta-açıq dəri tonu',
    '🙍🏽‍♀' => 'kefsiz qadın: orta dəri tonu',
    '🙍🏾‍♀' => 'kefsiz qadın: orta-tünd dəri tonu',
    '🙍🏿‍♀' => 'kefsiz qadın: tünd dəri tonu',
    '🙎🏻‍♂' => 'acıqlı kişi: açıq dəri tonu',
    '🙎🏼‍♂' => 'acıqlı kişi: orta-açıq dəri tonu',
    '🙎🏽‍♂' => 'acıqlı kişi: orta dəri tonu',
    '🙎🏾‍♂' => 'acıqlı kişi: orta-tünd dəri tonu',
    '🙎🏿‍♂' => 'acıqlı kişi: tünd dəri tonu',
    '🙎🏻‍♀' => 'acıqlı qadın: açıq dəri tonu',
    '🙎🏼‍♀' => 'acıqlı qadın: orta-açıq dəri tonu',
    '🙎🏽‍♀' => 'acıqlı qadın: orta dəri tonu',
    '🙎🏾‍♀' => 'acıqlı qadın: orta-tünd dəri tonu',
    '🙎🏿‍♀' => 'acıqlı qadın: tünd dəri tonu',
    '🙅🏻‍♂' => 'əleyhinə olan kişi: açıq dəri tonu',
    '🙅🏼‍♂' => 'əleyhinə olan kişi: orta-açıq dəri tonu',
    '🙅🏽‍♂' => 'əleyhinə olan kişi: orta dəri tonu',
    '🙅🏾‍♂' => 'əleyhinə olan kişi: orta-tünd dəri tonu',
    '🙅🏿‍♂' => 'əleyhinə olan kişi: tünd dəri tonu',
    '🙅🏻‍♀' => 'əleyhinə olan qadın: açıq dəri tonu',
    '🙅🏼‍♀' => 'əleyhinə olan qadın: orta-açıq dəri tonu',
    '🙅🏽‍♀' => 'əleyhinə olan qadın: orta dəri tonu',
    '🙅🏾‍♀' => 'əleyhinə olan qadın: orta-tünd dəri tonu',
    '🙅🏿‍♀' => 'əleyhinə olan qadın: tünd dəri tonu',
    '🙆🏻‍♂' => 'lehinə olan kişi: açıq dəri tonu',
    '🙆🏼‍♂' => 'lehinə olan kişi: orta-açıq dəri tonu',
    '🙆🏽‍♂' => 'lehinə olan kişi: orta dəri tonu',
    '🙆🏾‍♂' => 'lehinə olan kişi: orta-tünd dəri tonu',
    '🙆🏿‍♂' => 'lehinə olan kişi: tünd dəri tonu',
    '🙆🏻‍♀' => 'lehinə olan qadın: açıq dəri tonu',
    '🙆🏼‍♀' => 'lehinə olan qadın: orta-açıq dəri tonu',
    '🙆🏽‍♀' => 'lehinə olan qadın: orta dəri tonu',
    '🙆🏾‍♀' => 'lehinə olan qadın: orta-tünd dəri tonu',
    '🙆🏿‍♀' => 'lehinə olan qadın: tünd dəri tonu',
    '💁🏻‍♂' => 'əl uzadan kişi: açıq dəri tonu',
    '💁🏼‍♂' => 'əl uzadan kişi: orta-açıq dəri tonu',
    '💁🏽‍♂' => 'əl uzadan kişi: orta dəri tonu',
    '💁🏾‍♂' => 'əl uzadan kişi: orta-tünd dəri tonu',
    '💁🏿‍♂' => 'əl uzadan kişi: tünd dəri tonu',
    '💁🏻‍♀' => 'əl uzadan qadın: açıq dəri tonu',
    '💁🏼‍♀' => 'əl uzadan qadın: orta-açıq dəri tonu',
    '💁🏽‍♀' => 'əl uzadan qadın: orta dəri tonu',
    '💁🏾‍♀' => 'əl uzadan qadın: orta-tünd dəri tonu',
    '💁🏿‍♀' => 'əl uzadan qadın: tünd dəri tonu',
    '🙋🏻‍♂' => 'əl qaldıran kişi: açıq dəri tonu',
    '🙋🏼‍♂' => 'əl qaldıran kişi: orta-açıq dəri tonu',
    '🙋🏽‍♂' => 'əl qaldıran kişi: orta dəri tonu',
    '🙋🏾‍♂' => 'əl qaldıran kişi: orta-tünd dəri tonu',
    '🙋🏿‍♂' => 'əl qaldıran kişi: tünd dəri tonu',
    '🙋🏻‍♀' => 'əl qaldıran qadın: açıq dəri tonu',
    '🙋🏼‍♀' => 'əl qaldıran qadın: orta-açıq dəri tonu',
    '🙋🏽‍♀' => 'əl qaldıran qadın: orta dəri tonu',
    '🙋🏾‍♀' => 'əl qaldıran qadın: orta-tünd dəri tonu',
    '🙋🏿‍♀' => 'əl qaldıran qadın: tünd dəri tonu',
    '🧏🏻‍♂' => 'kar kişi: açıq dəri tonu',
    '🧏🏼‍♂' => 'kar kişi: orta-açıq dəri tonu',
    '🧏🏽‍♂' => 'kar kişi: orta dəri tonu',
    '🧏🏾‍♂' => 'kar kişi: orta-tünd dəri tonu',
    '🧏🏿‍♂' => 'kar kişi: tünd dəri tonu',
    '🧏🏻‍♀' => 'kar qadın: açıq dəri tonu',
    '🧏🏼‍♀' => 'kar qadın: orta-açıq dəri tonu',
    '🧏🏽‍♀' => 'kar qadın: orta dəri tonu',
    '🧏🏾‍♀' => 'kar qadın: orta-tünd dəri tonu',
    '🧏🏿‍♀' => 'kar qadın: tünd dəri tonu',
    '🙇🏻‍♂' => 'baş əyən kişi: açıq dəri tonu',
    '🙇🏼‍♂' => 'baş əyən kişi: orta-açıq dəri tonu',
    '🙇🏽‍♂' => 'baş əyən kişi: orta dəri tonu',
    '🙇🏾‍♂' => 'baş əyən kişi: orta-tünd dəri tonu',
    '🙇🏿‍♂' => 'baş əyən kişi: tünd dəri tonu',
    '🙇🏻‍♀' => 'baş əyən qadın: açıq dəri tonu',
    '🙇🏼‍♀' => 'baş əyən qadın: orta-açıq dəri tonu',
    '🙇🏽‍♀' => 'baş əyən qadın: orta dəri tonu',
    '🙇🏾‍♀' => 'baş əyən qadın: orta-tünd dəri tonu',
    '🙇🏿‍♀' => 'baş əyən qadın: tünd dəri tonu',
    '🤦🏻‍♂' => 'üzünü tutan kişi: açıq dəri tonu',
    '🤦🏼‍♂' => 'üzünü tutan kişi: orta-açıq dəri tonu',
    '🤦🏽‍♂' => 'üzünü tutan kişi: orta dəri tonu',
    '🤦🏾‍♂' => 'üzünü tutan kişi: orta-tünd dəri tonu',
    '🤦🏿‍♂' => 'üzünü tutan kişi: tünd dəri tonu',
    '🤦🏻‍♀' => 'üzünü tutan qadın: açıq dəri tonu',
    '🤦🏼‍♀' => 'üzünü tutan qadın: orta-açıq dəri tonu',
    '🤦🏽‍♀' => 'üzünü tutan qadın: orta dəri tonu',
    '🤦🏾‍♀' => 'üzünü tutan qadın: orta-tünd dəri tonu',
    '🤦🏿‍♀' => 'üzünü tutan qadın: tünd dəri tonu',
    '🤷🏻‍♂' => 'çiynini çəkən kişi: açıq dəri tonu',
    '🤷🏼‍♂' => 'çiynini çəkən kişi: orta-açıq dəri tonu',
    '🤷🏽‍♂' => 'çiynini çəkən kişi: orta dəri tonu',
    '🤷🏾‍♂' => 'çiynini çəkən kişi: orta-tünd dəri tonu',
    '🤷🏿‍♂' => 'çiynini çəkən kişi: tünd dəri tonu',
    '🤷🏻‍♀' => 'çiynini çəkən qadın: açıq dəri tonu',
    '🤷🏼‍♀' => 'çiynini çəkən qadın: orta-açıq dəri tonu',
    '🤷🏽‍♀' => 'çiynini çəkən qadın: orta dəri tonu',
    '🤷🏾‍♀' => 'çiynini çəkən qadın: orta-tünd dəri tonu',
    '🤷🏿‍♀' => 'çiynini çəkən qadın: tünd dəri tonu',
    '🧑🏻‍⚕' => 'tibb işçisi: açıq dəri tonu',
    '🧑🏼‍⚕' => 'tibb işçisi: orta-açıq dəri tonu',
    '🧑🏽‍⚕' => 'tibb işçisi: orta dəri tonu',
    '🧑🏾‍⚕' => 'tibb işçisi: orta-tünd dəri tonu',
    '🧑🏿‍⚕' => 'tibb işçisi: tünd dəri tonu',
    '👨🏻‍⚕' => 'kişi həkim: açıq dəri tonu',
    '👨🏼‍⚕' => 'kişi həkim: orta-açıq dəri tonu',
    '👨🏽‍⚕' => 'kişi həkim: orta dəri tonu',
    '👨🏾‍⚕' => 'kişi həkim: orta-tünd dəri tonu',
    '👨🏿‍⚕' => 'kişi həkim: tünd dəri tonu',
    '👩🏻‍⚕' => 'qadın həkim: açıq dəri tonu',
    '👩🏼‍⚕' => 'qadın həkim: orta-açıq dəri tonu',
    '👩🏽‍⚕' => 'qadın həkim: orta dəri tonu',
    '👩🏾‍⚕' => 'qadın həkim: orta-tünd dəri tonu',
    '👩🏿‍⚕' => 'qadın həkim: tünd dəri tonu',
    '🧑🏻‍🎓' => 'tələbə: açıq dəri tonu',
    '🧑🏼‍🎓' => 'tələbə: orta-açıq dəri tonu',
    '🧑🏽‍🎓' => 'tələbə: orta dəri tonu',
    '🧑🏾‍🎓' => 'tələbə: orta-tünd dəri tonu',
    '🧑🏿‍🎓' => 'tələbə: tünd dəri tonu',
    '👨🏻‍🎓' => 'oğlan tələbə: açıq dəri tonu',
    '👨🏼‍🎓' => 'oğlan tələbə: orta-açıq dəri tonu',
    '👨🏽‍🎓' => 'oğlan tələbə: orta dəri tonu',
    '👨🏾‍🎓' => 'oğlan tələbə: orta-tünd dəri tonu',
    '👨🏿‍🎓' => 'oğlan tələbə: tünd dəri tonu',
    '👩🏻‍🎓' => 'qız tələbə: açıq dəri tonu',
    '👩🏼‍🎓' => 'qız tələbə: orta-açıq dəri tonu',
    '👩🏽‍🎓' => 'qız tələbə: orta dəri tonu',
    '👩🏾‍🎓' => 'qız tələbə: orta-tünd dəri tonu',
    '👩🏿‍🎓' => 'qız tələbə: tünd dəri tonu',
    '🧑🏻‍🏫' => 'müəllim: açıq dəri tonu',
    '🧑🏼‍🏫' => 'müəllim: orta-açıq dəri tonu',
    '🧑🏽‍🏫' => 'müəllim: orta dəri tonu',
    '🧑🏾‍🏫' => 'müəllim: orta-tünd dəri tonu',
    '🧑🏿‍🏫' => 'müəllim: tünd dəri tonu',
    '👨🏻‍🏫' => 'kişi müəllim: açıq dəri tonu',
    '👨🏼‍🏫' => 'kişi müəllim: orta-açıq dəri tonu',
    '👨🏽‍🏫' => 'kişi müəllim: orta dəri tonu',
    '👨🏾‍🏫' => 'kişi müəllim: orta-tünd dəri tonu',
    '👨🏿‍🏫' => 'kişi müəllim: tünd dəri tonu',
    '👩🏻‍🏫' => 'qadın müəllim: açıq dəri tonu',
    '👩🏼‍🏫' => 'qadın müəllim: orta-açıq dəri tonu',
    '👩🏽‍🏫' => 'qadın müəllim: orta dəri tonu',
    '👩🏾‍🏫' => 'qadın müəllim: orta-tünd dəri tonu',
    '👩🏿‍🏫' => 'qadın müəllim: tünd dəri tonu',
    '🧑🏻‍⚖' => 'hakim: açıq dəri tonu',
    '🧑🏼‍⚖' => 'hakim: orta-açıq dəri tonu',
    '🧑🏽‍⚖' => 'hakim: orta dəri tonu',
    '🧑🏾‍⚖' => 'hakim: orta-tünd dəri tonu',
    '🧑🏿‍⚖' => 'hakim: tünd dəri tonu',
    '👨🏻‍⚖' => 'kişi hakim: açıq dəri tonu',
    '👨🏼‍⚖' => 'kişi hakim: orta-açıq dəri tonu',
    '👨🏽‍⚖' => 'kişi hakim: orta dəri tonu',
    '👨🏾‍⚖' => 'kişi hakim: orta-tünd dəri tonu',
    '👨🏿‍⚖' => 'kişi hakim: tünd dəri tonu',
    '👩🏻‍⚖' => 'qadın hakim: açıq dəri tonu',
    '👩🏼‍⚖' => 'qadın hakim: orta-açıq dəri tonu',
    '👩🏽‍⚖' => 'qadın hakim: orta dəri tonu',
    '👩🏾‍⚖' => 'qadın hakim: orta-tünd dəri tonu',
    '👩🏿‍⚖' => 'qadın hakim: tünd dəri tonu',
    '🧑🏻‍🌾' => 'fermer: açıq dəri tonu',
    '🧑🏼‍🌾' => 'fermer: orta-açıq dəri tonu',
    '🧑🏽‍🌾' => 'fermer: orta dəri tonu',
    '🧑🏾‍🌾' => 'fermer: orta-tünd dəri tonu',
    '🧑🏿‍🌾' => 'fermer: tünd dəri tonu',
    '👨🏻‍🌾' => 'kişi fermer: açıq dəri tonu',
    '👨🏼‍🌾' => 'kişi fermer: orta-açıq dəri tonu',
    '👨🏽‍🌾' => 'kişi fermer: orta dəri tonu',
    '👨🏾‍🌾' => 'kişi fermer: orta-tünd dəri tonu',
    '👨🏿‍🌾' => 'kişi fermer: tünd dəri tonu',
    '👩🏻‍🌾' => 'qadın fermer: açıq dəri tonu',
    '👩🏼‍🌾' => 'qadın fermer: orta-açıq dəri tonu',
    '👩🏽‍🌾' => 'qadın fermer: orta dəri tonu',
    '👩🏾‍🌾' => 'qadın fermer: orta-tünd dəri tonu',
    '👩🏿‍🌾' => 'qadın fermer: tünd dəri tonu',
    '🧑🏻‍🍳' => 'aşpaz: açıq dəri tonu',
    '🧑🏼‍🍳' => 'aşpaz: orta-açıq dəri tonu',
    '🧑🏽‍🍳' => 'aşpaz: orta dəri tonu',
    '🧑🏾‍🍳' => 'aşpaz: orta-tünd dəri tonu',
    '🧑🏿‍🍳' => 'aşpaz: tünd dəri tonu',
    '👨🏻‍🍳' => 'kişi aşbaz: açıq dəri tonu',
    '👨🏼‍🍳' => 'kişi aşbaz: orta-açıq dəri tonu',
    '👨🏽‍🍳' => 'kişi aşbaz: orta dəri tonu',
    '👨🏾‍🍳' => 'kişi aşbaz: orta-tünd dəri tonu',
    '👨🏿‍🍳' => 'kişi aşbaz: tünd dəri tonu',
    '👩🏻‍🍳' => 'qadın aşbaz: açıq dəri tonu',
    '👩🏼‍🍳' => 'qadın aşbaz: orta-açıq dəri tonu',
    '👩🏽‍🍳' => 'qadın aşbaz: orta dəri tonu',
    '👩🏾‍🍳' => 'qadın aşbaz: orta-tünd dəri tonu',
    '👩🏿‍🍳' => 'qadın aşbaz: tünd dəri tonu',
    '🧑🏻‍🔧' => 'mexanik: açıq dəri tonu',
    '🧑🏼‍🔧' => 'mexanik: orta-açıq dəri tonu',
    '🧑🏽‍🔧' => 'mexanik: orta dəri tonu',
    '🧑🏾‍🔧' => 'mexanik: orta-tünd dəri tonu',
    '🧑🏿‍🔧' => 'mexanik: tünd dəri tonu',
    '👨🏻‍🔧' => 'kişi mexanik: açıq dəri tonu',
    '👨🏼‍🔧' => 'kişi mexanik: orta-açıq dəri tonu',
    '👨🏽‍🔧' => 'kişi mexanik: orta dəri tonu',
    '👨🏾‍🔧' => 'kişi mexanik: orta-tünd dəri tonu',
    '👨🏿‍🔧' => 'kişi mexanik: tünd dəri tonu',
    '👩🏻‍🔧' => 'qadın mexanik: açıq dəri tonu',
    '👩🏼‍🔧' => 'qadın mexanik: orta-açıq dəri tonu',
    '👩🏽‍🔧' => 'qadın mexanik: orta dəri tonu',
    '👩🏾‍🔧' => 'qadın mexanik: orta-tünd dəri tonu',
    '👩🏿‍🔧' => 'qadın mexanik: tünd dəri tonu',
    '🧑🏻‍🏭' => 'fabrik işçisi: açıq dəri tonu',
    '🧑🏼‍🏭' => 'fabrik işçisi: orta-açıq dəri tonu',
    '🧑🏽‍🏭' => 'fabrik işçisi: orta dəri tonu',
    '🧑🏾‍🏭' => 'fabrik işçisi: orta-tünd dəri tonu',
    '🧑🏿‍🏭' => 'fabrik işçisi: tünd dəri tonu',
    '👨🏻‍🏭' => 'kişi fabrik işçisi: açıq dəri tonu',
    '👨🏼‍🏭' => 'kişi fabrik işçisi: orta-açıq dəri tonu',
    '👨🏽‍🏭' => 'kişi fabrik işçisi: orta dəri tonu',
    '👨🏾‍🏭' => 'kişi fabrik işçisi: orta-tünd dəri tonu',
    '👨🏿‍🏭' => 'kişi fabrik işçisi: tünd dəri tonu',
    '👩🏻‍🏭' => 'qadın fabrik işçisi: açıq dəri tonu',
    '👩🏼‍🏭' => 'qadın fabrik işçisi: orta-açıq dəri tonu',
    '👩🏽‍🏭' => 'qadın fabrik işçisi: orta dəri tonu',
    '👩🏾‍🏭' => 'qadın fabrik işçisi: orta-tünd dəri tonu',
    '👩🏿‍🏭' => 'qadın fabrik işçisi: tünd dəri tonu',
    '🧑🏻‍💼' => 'ofis işçisi: açıq dəri tonu',
    '🧑🏼‍💼' => 'ofis işçisi: orta-açıq dəri tonu',
    '🧑🏽‍💼' => 'ofis işçisi: orta dəri tonu',
    '🧑🏾‍💼' => 'ofis işçisi: orta-tünd dəri tonu',
    '🧑🏿‍💼' => 'ofis işçisi: tünd dəri tonu',
    '👨🏻‍💼' => 'kişi ofis işçisi: açıq dəri tonu',
    '👨🏼‍💼' => 'kişi ofis işçisi: orta-açıq dəri tonu',
    '👨🏽‍💼' => 'kişi ofis işçisi: orta dəri tonu',
    '👨🏾‍💼' => 'kişi ofis işçisi: orta-tünd dəri tonu',
    '👨🏿‍💼' => 'kişi ofis işçisi: tünd dəri tonu',
    '👩🏻‍💼' => 'qadın ofis işçisi: açıq dəri tonu',
    '👩🏼‍💼' => 'qadın ofis işçisi: orta-açıq dəri tonu',
    '👩🏽‍💼' => 'qadın ofis işçisi: orta dəri tonu',
    '👩🏾‍💼' => 'qadın ofis işçisi: orta-tünd dəri tonu',
    '👩🏿‍💼' => 'qadın ofis işçisi: tünd dəri tonu',
    '🧑🏻‍🔬' => 'alim: açıq dəri tonu',
    '🧑🏼‍🔬' => 'alim: orta-açıq dəri tonu',
    '🧑🏽‍🔬' => 'alim: orta dəri tonu',
    '🧑🏾‍🔬' => 'alim: orta-tünd dəri tonu',
    '🧑🏿‍🔬' => 'alim: tünd dəri tonu',
    '👨🏻‍🔬' => 'kişi alim: açıq dəri tonu',
    '👨🏼‍🔬' => 'kişi alim: orta-açıq dəri tonu',
    '👨🏽‍🔬' => 'kişi alim: orta dəri tonu',
    '👨🏾‍🔬' => 'kişi alim: orta-tünd dəri tonu',
    '👨🏿‍🔬' => 'kişi alim: tünd dəri tonu',
    '👩🏻‍🔬' => 'qadın alim: açıq dəri tonu',
    '👩🏼‍🔬' => 'qadın alim: orta-açıq dəri tonu',
    '👩🏽‍🔬' => 'qadın alim: orta dəri tonu',
    '👩🏾‍🔬' => 'qadın alim: orta-tünd dəri tonu',
    '👩🏿‍🔬' => 'qadın alim: tünd dəri tonu',
    '🧑🏻‍💻' => 'texnoloq: açıq dəri tonu',
    '🧑🏼‍💻' => 'texnoloq: orta-açıq dəri tonu',
    '🧑🏽‍💻' => 'texnoloq: orta dəri tonu',
    '🧑🏾‍💻' => 'texnoloq: orta-tünd dəri tonu',
    '🧑🏿‍💻' => 'texnoloq: tünd dəri tonu',
    '👨🏻‍💻' => 'kişi texnoloq: açıq dəri tonu',
    '👨🏼‍💻' => 'kişi texnoloq: orta-açıq dəri tonu',
    '👨🏽‍💻' => 'kişi texnoloq: orta dəri tonu',
    '👨🏾‍💻' => 'kişi texnoloq: orta-tünd dəri tonu',
    '👨🏿‍💻' => 'kişi texnoloq: tünd dəri tonu',
    '👩🏻‍💻' => 'qadın texnoloq: açıq dəri tonu',
    '👩🏼‍💻' => 'qadın texnoloq: orta-açıq dəri tonu',
    '👩🏽‍💻' => 'qadın texnoloq: orta dəri tonu',
    '👩🏾‍💻' => 'qadın texnoloq: orta-tünd dəri tonu',
    '👩🏿‍💻' => 'qadın texnoloq: tünd dəri tonu',
    '🧑🏻‍🎤' => 'müğənni: açıq dəri tonu',
    '🧑🏼‍🎤' => 'müğənni: orta-açıq dəri tonu',
    '🧑🏽‍🎤' => 'müğənni: orta dəri tonu',
    '🧑🏾‍🎤' => 'müğənni: orta-tünd dəri tonu',
    '🧑🏿‍🎤' => 'müğənni: tünd dəri tonu',
    '👨🏻‍🎤' => 'kişi müğənni: açıq dəri tonu',
    '👨🏼‍🎤' => 'kişi müğənni: orta-açıq dəri tonu',
    '👨🏽‍🎤' => 'kişi müğənni: orta dəri tonu',
    '👨🏾‍🎤' => 'kişi müğənni: orta-tünd dəri tonu',
    '👨🏿‍🎤' => 'kişi müğənni: tünd dəri tonu',
    '👩🏻‍🎤' => 'qadın müğənni: açıq dəri tonu',
    '👩🏼‍🎤' => 'qadın müğənni: orta-açıq dəri tonu',
    '👩🏽‍🎤' => 'qadın müğənni: orta dəri tonu',
    '👩🏾‍🎤' => 'qadın müğənni: orta-tünd dəri tonu',
    '👩🏿‍🎤' => 'qadın müğənni: tünd dəri tonu',
    '🧑🏻‍🎨' => 'aktyor: açıq dəri tonu',
    '🧑🏼‍🎨' => 'aktyor: orta-açıq dəri tonu',
    '🧑🏽‍🎨' => 'aktyor: orta dəri tonu',
    '🧑🏾‍🎨' => 'aktyor: orta-tünd dəri tonu',
    '🧑🏿‍🎨' => 'aktyor: tünd dəri tonu',
    '👨🏻‍🎨' => 'kişi rəssam: açıq dəri tonu',
    '👨🏼‍🎨' => 'kişi rəssam: orta-açıq dəri tonu',
    '👨🏽‍🎨' => 'kişi rəssam: orta dəri tonu',
    '👨🏾‍🎨' => 'kişi rəssam: orta-tünd dəri tonu',
    '👨🏿‍🎨' => 'kişi rəssam: tünd dəri tonu',
    '👩🏻‍🎨' => 'qadın rəssam: açıq dəri tonu',
    '👩🏼‍🎨' => 'qadın rəssam: orta-açıq dəri tonu',
    '👩🏽‍🎨' => 'qadın rəssam: orta dəri tonu',
    '👩🏾‍🎨' => 'qadın rəssam: orta-tünd dəri tonu',
    '👩🏿‍🎨' => 'qadın rəssam: tünd dəri tonu',
    '🧑🏻‍✈' => 'pilot: açıq dəri tonu',
    '🧑🏼‍✈' => 'pilot: orta-açıq dəri tonu',
    '🧑🏽‍✈' => 'pilot: orta dəri tonu',
    '🧑🏾‍✈' => 'pilot: orta-tünd dəri tonu',
    '🧑🏿‍✈' => 'pilot: tünd dəri tonu',
    '👨🏻‍✈' => 'kişi pilot: açıq dəri tonu',
    '👨🏼‍✈' => 'kişi pilot: orta-açıq dəri tonu',
    '👨🏽‍✈' => 'kişi pilot: orta dəri tonu',
    '👨🏾‍✈' => 'kişi pilot: orta-tünd dəri tonu',
    '👨🏿‍✈' => 'kişi pilot: tünd dəri tonu',
    '👩🏻‍✈' => 'qadın pilot: açıq dəri tonu',
    '👩🏼‍✈' => 'qadın pilot: orta-açıq dəri tonu',
    '👩🏽‍✈' => 'qadın pilot: orta dəri tonu',
    '👩🏾‍✈' => 'qadın pilot: orta-tünd dəri tonu',
    '👩🏿‍✈' => 'qadın pilot: tünd dəri tonu',
    '🧑🏻‍🚀' => 'astronavt: açıq dəri tonu',
    '🧑🏼‍🚀' => 'astronavt: orta-açıq dəri tonu',
    '🧑🏽‍🚀' => 'astronavt: orta dəri tonu',
    '🧑🏾‍🚀' => 'astronavt: orta-tünd dəri tonu',
    '🧑🏿‍🚀' => 'astronavt: tünd dəri tonu',
    '👨🏻‍🚀' => 'kişi astronavt: açıq dəri tonu',
    '👨🏼‍🚀' => 'kişi astronavt: orta-açıq dəri tonu',
    '👨🏽‍🚀' => 'kişi astronavt: orta dəri tonu',
    '👨🏾‍🚀' => 'kişi astronavt: orta-tünd dəri tonu',
    '👨🏿‍🚀' => 'kişi astronavt: tünd dəri tonu',
    '👩🏻‍🚀' => 'qadın astronavt: açıq dəri tonu',
    '👩🏼‍🚀' => 'qadın astronavt: orta-açıq dəri tonu',
    '👩🏽‍🚀' => 'qadın astronavt: orta dəri tonu',
    '👩🏾‍🚀' => 'qadın astronavt: orta-tünd dəri tonu',
    '👩🏿‍🚀' => 'qadın astronavt: tünd dəri tonu',
    '🧑🏻‍🚒' => 'yanğınsöndürən maşın: açıq dəri tonu',
    '🧑🏼‍🚒' => 'yanğınsöndürən maşın: orta-açıq dəri tonu',
    '🧑🏽‍🚒' => 'yanğınsöndürən maşın: orta dəri tonu',
    '🧑🏾‍🚒' => 'yanğınsöndürən maşın: orta-tünd dəri tonu',
    '🧑🏿‍🚒' => 'yanğınsöndürən maşın: tünd dəri tonu',
    '👨🏻‍🚒' => 'kişi yanğınsöndürən: açıq dəri tonu',
    '👨🏼‍🚒' => 'kişi yanğınsöndürən: orta-açıq dəri tonu',
    '👨🏽‍🚒' => 'kişi yanğınsöndürən: orta dəri tonu',
    '👨🏾‍🚒' => 'kişi yanğınsöndürən: orta-tünd dəri tonu',
    '👨🏿‍🚒' => 'kişi yanğınsöndürən: tünd dəri tonu',
    '👩🏻‍🚒' => 'qadın yanğınsöndürən: açıq dəri tonu',
    '👩🏼‍🚒' => 'qadın yanğınsöndürən: orta-açıq dəri tonu',
    '👩🏽‍🚒' => 'qadın yanğınsöndürən: orta dəri tonu',
    '👩🏾‍🚒' => 'qadın yanğınsöndürən: orta-tünd dəri tonu',
    '👩🏿‍🚒' => 'qadın yanğınsöndürən: tünd dəri tonu',
    '👮🏻‍♂' => 'kişi polis: açıq dəri tonu',
    '👮🏼‍♂' => 'kişi polis: orta-açıq dəri tonu',
    '👮🏽‍♂' => 'kişi polis: orta dəri tonu',
    '👮🏾‍♂' => 'kişi polis: orta-tünd dəri tonu',
    '👮🏿‍♂' => 'kişi polis: tünd dəri tonu',
    '👮🏻‍♀' => 'qadın polis: açıq dəri tonu',
    '👮🏼‍♀' => 'qadın polis: orta-açıq dəri tonu',
    '👮🏽‍♀' => 'qadın polis: orta dəri tonu',
    '👮🏾‍♀' => 'qadın polis: orta-tünd dəri tonu',
    '👮🏿‍♀' => 'qadın polis: tünd dəri tonu',
    '🕵🏻‍♂' => 'kişi detektiv: açıq dəri tonu',
    '🕵🏼‍♂' => 'kişi detektiv: orta-açıq dəri tonu',
    '🕵🏽‍♂' => 'kişi detektiv: orta dəri tonu',
    '🕵🏾‍♂' => 'kişi detektiv: orta-tünd dəri tonu',
    '🕵🏿‍♂' => 'kişi detektiv: tünd dəri tonu',
    '🕵🏻‍♀' => 'qadın detektiv: açıq dəri tonu',
    '🕵🏼‍♀' => 'qadın detektiv: orta-açıq dəri tonu',
    '🕵🏽‍♀' => 'qadın detektiv: orta dəri tonu',
    '🕵🏾‍♀' => 'qadın detektiv: orta-tünd dəri tonu',
    '🕵🏿‍♀' => 'qadın detektiv: tünd dəri tonu',
    '💂🏻‍♂' => 'kişi keşikçi: açıq dəri tonu',
    '💂🏼‍♂' => 'kişi keşikçi: orta-açıq dəri tonu',
    '💂🏽‍♂' => 'kişi keşikçi: orta dəri tonu',
    '💂🏾‍♂' => 'kişi keşikçi: orta-tünd dəri tonu',
    '💂🏿‍♂' => 'kişi keşikçi: tünd dəri tonu',
    '💂🏻‍♀' => 'qadın keşikçi: açıq dəri tonu',
    '💂🏼‍♀' => 'qadın keşikçi: orta-açıq dəri tonu',
    '💂🏽‍♀' => 'qadın keşikçi: orta dəri tonu',
    '💂🏾‍♀' => 'qadın keşikçi: orta-tünd dəri tonu',
    '💂🏿‍♀' => 'qadın keşikçi: tünd dəri tonu',
    '👷🏻‍♂' => 'kişi bənna: açıq dəri tonu',
    '👷🏼‍♂' => 'kişi bənna: orta-açıq dəri tonu',
    '👷🏽‍♂' => 'kişi bənna: orta dəri tonu',
    '👷🏾‍♂' => 'kişi bənna: orta-tünd dəri tonu',
    '👷🏿‍♂' => 'kişi bənna: tünd dəri tonu',
    '👷🏻‍♀' => 'qadın bənna: açıq dəri tonu',
    '👷🏼‍♀' => 'qadın bənna: orta-açıq dəri tonu',
    '👷🏽‍♀' => 'qadın bənna: orta dəri tonu',
    '👷🏾‍♀' => 'qadın bənna: orta-tünd dəri tonu',
    '👷🏿‍♀' => 'qadın bənna: tünd dəri tonu',
    '👳🏻‍♂' => 'türbanlı kişi: açıq dəri tonu',
    '👳🏼‍♂' => 'türbanlı kişi: orta-açıq dəri tonu',
    '👳🏽‍♂' => 'türbanlı kişi: orta dəri tonu',
    '👳🏾‍♂' => 'türbanlı kişi: orta-tünd dəri tonu',
    '👳🏿‍♂' => 'türbanlı kişi: tünd dəri tonu',
    '👳🏻‍♀' => 'türbanlı qadın: açıq dəri tonu',
    '👳🏼‍♀' => 'türbanlı qadın: orta-açıq dəri tonu',
    '👳🏽‍♀' => 'türbanlı qadın: orta dəri tonu',
    '👳🏾‍♀' => 'türbanlı qadın: orta-tünd dəri tonu',
    '👳🏿‍♀' => 'türbanlı qadın: tünd dəri tonu',
    '🤵🏻‍♂' => 'smokinqli adam: açıq dəri tonu',
    '🤵🏼‍♂' => 'smokinqli adam: orta-açıq dəri tonu',
    '🤵🏽‍♂' => 'smokinqli adam: orta dəri tonu',
    '🤵🏾‍♂' => 'smokinqli adam: orta-tünd dəri tonu',
    '🤵🏿‍♂' => 'smokinqli adam: tünd dəri tonu',
    '🤵🏻‍♀' => 'smokinqli qadın: açıq dəri tonu',
    '🤵🏼‍♀' => 'smokinqli qadın: orta-açıq dəri tonu',
    '🤵🏽‍♀' => 'smokinqli qadın: orta dəri tonu',
    '🤵🏾‍♀' => 'smokinqli qadın: orta-tünd dəri tonu',
    '🤵🏿‍♀' => 'smokinqli qadın: tünd dəri tonu',
    '👰🏻‍♂' => 'duvaqlı adam: açıq dəri tonu',
    '👰🏼‍♂' => 'duvaqlı adam: orta-açıq dəri tonu',
    '👰🏽‍♂' => 'duvaqlı adam: orta dəri tonu',
    '👰🏾‍♂' => 'duvaqlı adam: orta-tünd dəri tonu',
    '👰🏿‍♂' => 'duvaqlı adam: tünd dəri tonu',
    '👰🏻‍♀' => 'duvaqlı qadın: açıq dəri tonu',
    '👰🏼‍♀' => 'duvaqlı qadın: orta-açıq dəri tonu',
    '👰🏽‍♀' => 'duvaqlı qadın: orta dəri tonu',
    '👰🏾‍♀' => 'duvaqlı qadın: orta-tünd dəri tonu',
    '👰🏿‍♀' => 'duvaqlı qadın: tünd dəri tonu',
    '👩🏻‍🍼' => 'körpə əmizdirən qadın: açıq dəri tonu',
    '👩🏼‍🍼' => 'körpə əmizdirən qadın: orta-açıq dəri tonu',
    '👩🏽‍🍼' => 'körpə əmizdirən qadın: orta dəri tonu',
    '👩🏾‍🍼' => 'körpə əmizdirən qadın: orta-tünd dəri tonu',
    '👩🏿‍🍼' => 'körpə əmizdirən qadın: tünd dəri tonu',
    '👨🏻‍🍼' => 'körpə əmizdirən kişi: açıq dəri tonu',
    '👨🏼‍🍼' => 'körpə əmizdirən kişi: orta-açıq dəri tonu',
    '👨🏽‍🍼' => 'körpə əmizdirən kişi: orta dəri tonu',
    '👨🏾‍🍼' => 'körpə əmizdirən kişi: orta-tünd dəri tonu',
    '👨🏿‍🍼' => 'körpə əmizdirən kişi: tünd dəri tonu',
    '🧑🏻‍🍼' => 'körpə əmizdirən şəxs: açıq dəri tonu',
    '🧑🏼‍🍼' => 'körpə əmizdirən şəxs: orta-açıq dəri tonu',
    '🧑🏽‍🍼' => 'körpə əmizdirən şəxs: orta dəri tonu',
    '🧑🏾‍🍼' => 'körpə əmizdirən şəxs: orta-tünd dəri tonu',
    '🧑🏿‍🍼' => 'körpə əmizdirən şəxs: tünd dəri tonu',
    '🧑🏻‍🎄' => 'mx klaus: açıq dəri tonu',
    '🧑🏼‍🎄' => 'mx klaus: orta-açıq dəri tonu',
    '🧑🏽‍🎄' => 'mx klaus: orta dəri tonu',
    '🧑🏾‍🎄' => 'mx klaus: orta-tünd dəri tonu',
    '🧑🏿‍🎄' => 'mx klaus: tünd dəri tonu',
    '🦸🏻‍♂' => 'kişi superqəhrəman: açıq dəri tonu',
    '🦸🏼‍♂' => 'kişi superqəhrəman: orta-açıq dəri tonu',
    '🦸🏽‍♂' => 'kişi superqəhrəman: orta dəri tonu',
    '🦸🏾‍♂' => 'kişi superqəhrəman: orta-tünd dəri tonu',
    '🦸🏿‍♂' => 'kişi superqəhrəman: tünd dəri tonu',
    '🦸🏻‍♀' => 'qadın superqəhrəman: açıq dəri tonu',
    '🦸🏼‍♀' => 'qadın superqəhrəman: orta-açıq dəri tonu',
    '🦸🏽‍♀' => 'qadın superqəhrəman: orta dəri tonu',
    '🦸🏾‍♀' => 'qadın superqəhrəman: orta-tünd dəri tonu',
    '🦸🏿‍♀' => 'qadın superqəhrəman: tünd dəri tonu',
    '🦹🏻‍♂' => 'kişi supercani: açıq dəri tonu',
    '🦹🏼‍♂' => 'kişi supercani: orta-açıq dəri tonu',
    '🦹🏽‍♂' => 'kişi supercani: orta dəri tonu',
    '🦹🏾‍♂' => 'kişi supercani: orta-tünd dəri tonu',
    '🦹🏿‍♂' => 'kişi supercani: tünd dəri tonu',
    '🦹🏻‍♀' => 'qadın supercani: açıq dəri tonu',
    '🦹🏼‍♀' => 'qadın supercani: orta-açıq dəri tonu',
    '🦹🏽‍♀' => 'qadın supercani: orta dəri tonu',
    '🦹🏾‍♀' => 'qadın supercani: orta-tünd dəri tonu',
    '🦹🏿‍♀' => 'qadın supercani: tünd dəri tonu',
    '🧙🏻‍♂' => 'kişi maq: açıq dəri tonu',
    '🧙🏼‍♂' => 'kişi maq: orta-açıq dəri tonu',
    '🧙🏽‍♂' => 'kişi maq: orta dəri tonu',
    '🧙🏾‍♂' => 'kişi maq: orta-tünd dəri tonu',
    '🧙🏿‍♂' => 'kişi maq: tünd dəri tonu',
    '🧙🏻‍♀' => 'qadın maq: açıq dəri tonu',
    '🧙🏼‍♀' => 'qadın maq: orta-açıq dəri tonu',
    '🧙🏽‍♀' => 'qadın maq: orta dəri tonu',
    '🧙🏾‍♀' => 'qadın maq: orta-tünd dəri tonu',
    '🧙🏿‍♀' => 'qadın maq: tünd dəri tonu',
    '🧚🏻‍♂' => 'kişi pəri: açıq dəri tonu',
    '🧚🏼‍♂' => 'kişi pəri: orta-açıq dəri tonu',
    '🧚🏽‍♂' => 'kişi pəri: orta dəri tonu',
    '🧚🏾‍♂' => 'kişi pəri: orta-tünd dəri tonu',
    '🧚🏿‍♂' => 'kişi pəri: tünd dəri tonu',
    '🧚🏻‍♀' => 'qadın pəri: açıq dəri tonu',
    '🧚🏼‍♀' => 'qadın pəri: orta-açıq dəri tonu',
    '🧚🏽‍♀' => 'qadın pəri: orta dəri tonu',
    '🧚🏾‍♀' => 'qadın pəri: orta-tünd dəri tonu',
    '🧚🏿‍♀' => 'qadın pəri: tünd dəri tonu',
    '🧛🏻‍♂' => 'kişi vampir: açıq dəri tonu',
    '🧛🏼‍♂' => 'kişi vampir: orta-açıq dəri tonu',
    '🧛🏽‍♂' => 'kişi vampir: orta dəri tonu',
    '🧛🏾‍♂' => 'kişi vampir: orta-tünd dəri tonu',
    '🧛🏿‍♂' => 'kişi vampir: tünd dəri tonu',
    '🧛🏻‍♀' => 'qadın vampir: açıq dəri tonu',
    '🧛🏼‍♀' => 'qadın vampir: orta-açıq dəri tonu',
    '🧛🏽‍♀' => 'qadın vampir: orta dəri tonu',
    '🧛🏾‍♀' => 'qadın vampir: orta-tünd dəri tonu',
    '🧛🏿‍♀' => 'qadın vampir: tünd dəri tonu',
    '🧜🏻‍♂' => 'dəniz kişisi: açıq dəri tonu',
    '🧜🏼‍♂' => 'dəniz kişisi: orta-açıq dəri tonu',
    '🧜🏽‍♂' => 'dəniz kişisi: orta dəri tonu',
    '🧜🏾‍♂' => 'dəniz kişisi: orta-tünd dəri tonu',
    '🧜🏿‍♂' => 'dəniz kişisi: tünd dəri tonu',
    '🧜🏻‍♀' => 'su pərisi: açıq dəri tonu',
    '🧜🏼‍♀' => 'su pərisi: orta-açıq dəri tonu',
    '🧜🏽‍♀' => 'su pərisi: orta dəri tonu',
    '🧜🏾‍♀' => 'su pərisi: orta-tünd dəri tonu',
    '🧜🏿‍♀' => 'su pərisi: tünd dəri tonu',
    '🧝🏻‍♂' => 'kişi elf: açıq dəri tonu',
    '🧝🏼‍♂' => 'kişi elf: orta-açıq dəri tonu',
    '🧝🏽‍♂' => 'kişi elf: orta dəri tonu',
    '🧝🏾‍♂' => 'kişi elf: orta-tünd dəri tonu',
    '🧝🏿‍♂' => 'kişi elf: tünd dəri tonu',
    '🧝🏻‍♀' => 'qadın elf: açıq dəri tonu',
    '🧝🏼‍♀' => 'qadın elf: orta-açıq dəri tonu',
    '🧝🏽‍♀' => 'qadın elf: orta dəri tonu',
    '🧝🏾‍♀' => 'qadın elf: orta-tünd dəri tonu',
    '🧝🏿‍♀' => 'qadın elf: tünd dəri tonu',
    '💆🏻‍♂' => 'üzünə masaj edən kişi: açıq dəri tonu',
    '💆🏼‍♂' => 'üzünə masaj edən kişi: orta-açıq dəri tonu',
    '💆🏽‍♂' => 'üzünə masaj edən kişi: orta dəri tonu',
    '💆🏾‍♂' => 'üzünə masaj edən kişi: orta-tünd dəri tonu',
    '💆🏿‍♂' => 'üzünə masaj edən kişi: tünd dəri tonu',
    '💆🏻‍♀' => 'üzünə masaj edən qadın: açıq dəri tonu',
    '💆🏼‍♀' => 'üzünə masaj edən qadın: orta-açıq dəri tonu',
    '💆🏽‍♀' => 'üzünə masaj edən qadın: orta dəri tonu',
    '💆🏾‍♀' => 'üzünə masaj edən qadın: orta-tünd dəri tonu',
    '💆🏿‍♀' => 'üzünə masaj edən qadın: tünd dəri tonu',
    '💇🏻‍♂' => 'saçını kəsdirən kişi: açıq dəri tonu',
    '💇🏼‍♂' => 'saçını kəsdirən kişi: orta-açıq dəri tonu',
    '💇🏽‍♂' => 'saçını kəsdirən kişi: orta dəri tonu',
    '💇🏾‍♂' => 'saçını kəsdirən kişi: orta-tünd dəri tonu',
    '💇🏿‍♂' => 'saçını kəsdirən kişi: tünd dəri tonu',
    '💇🏻‍♀' => 'saçını kəsdirən qadın: açıq dəri tonu',
    '💇🏼‍♀' => 'saçını kəsdirən qadın: orta-açıq dəri tonu',
    '💇🏽‍♀' => 'saçını kəsdirən qadın: orta dəri tonu',
    '💇🏾‍♀' => 'saçını kəsdirən qadın: orta-tünd dəri tonu',
    '💇🏿‍♀' => 'saçını kəsdirən qadın: tünd dəri tonu',
    '🚶🏻‍♂' => 'gəzən kişi: açıq dəri tonu',
    '🚶🏼‍♂' => 'gəzən kişi: orta-açıq dəri tonu',
    '🚶🏽‍♂' => 'gəzən kişi: orta dəri tonu',
    '🚶🏾‍♂' => 'gəzən kişi: orta-tünd dəri tonu',
    '🚶🏿‍♂' => 'gəzən kişi: tünd dəri tonu',
    '🚶🏻‍♀' => 'gəzən qadın: açıq dəri tonu',
    '🚶🏼‍♀' => 'gəzən qadın: orta-açıq dəri tonu',
    '🚶🏽‍♀' => 'gəzən qadın: orta dəri tonu',
    '🚶🏾‍♀' => 'gəzən qadın: orta-tünd dəri tonu',
    '🚶🏿‍♀' => 'gəzən qadın: tünd dəri tonu',
    '🚶🏻‍➡' => 'piyada: açıq dəri tonu, sağa baxan',
    '🚶🏼‍➡' => 'piyada: orta-açıq dəri tonu, sağa baxan',
    '🚶🏽‍➡' => 'piyada: orta dəri tonu, sağa baxan',
    '🚶🏾‍➡' => 'piyada: orta-tünd dəri tonu, sağa baxan',
    '🚶🏿‍➡' => 'piyada: tünd dəri tonu, sağa baxan',
    '🧍🏻‍♂' => 'duran kişi: açıq dəri tonu',
    '🧍🏼‍♂' => 'duran kişi: orta-açıq dəri tonu',
    '🧍🏽‍♂' => 'duran kişi: orta dəri tonu',
    '🧍🏾‍♂' => 'duran kişi: orta-tünd dəri tonu',
    '🧍🏿‍♂' => 'duran kişi: tünd dəri tonu',
    '🧍🏻‍♀' => 'duran qadın: açıq dəri tonu',
    '🧍🏼‍♀' => 'duran qadın: orta-açıq dəri tonu',
    '🧍🏽‍♀' => 'duran qadın: orta dəri tonu',
    '🧍🏾‍♀' => 'duran qadın: orta-tünd dəri tonu',
    '🧍🏿‍♀' => 'duran qadın: tünd dəri tonu',
    '🧎🏻‍♂' => 'dizi üstündə kişi: açıq dəri tonu',
    '🧎🏼‍♂' => 'dizi üstündə kişi: orta-açıq dəri tonu',
    '🧎🏽‍♂' => 'dizi üstündə kişi: orta dəri tonu',
    '🧎🏾‍♂' => 'dizi üstündə kişi: orta-tünd dəri tonu',
    '🧎🏿‍♂' => 'dizi üstündə kişi: tünd dəri tonu',
    '🧎🏻‍♀' => 'dizi üstündə qadın: açıq dəri tonu',
    '🧎🏼‍♀' => 'dizi üstündə qadın: orta-açıq dəri tonu',
    '🧎🏽‍♀' => 'dizi üstündə qadın: orta dəri tonu',
    '🧎🏾‍♀' => 'dizi üstündə qadın: orta-tünd dəri tonu',
    '🧎🏿‍♀' => 'dizi üstündə qadın: tünd dəri tonu',
    '🧎🏻‍➡' => 'dizi üstündə adam: açıq dəri tonu, sağa baxan',
    '🧎🏼‍➡' => 'dizi üstündə adam: orta-açıq dəri tonu, sağa baxan',
    '🧎🏽‍➡' => 'dizi üstündə adam: orta dəri tonu, sağa baxan',
    '🧎🏾‍➡' => 'dizi üstündə adam: orta-tünd dəri tonu, sağa baxan',
    '🧎🏿‍➡' => 'dizi üstündə adam: tünd dəri tonu, sağa baxan',
    '🧑🏻‍🦯' => 'zondlayan çəlikli adam: açıq dəri tonu',
    '🧑🏼‍🦯' => 'zondlayan çəlikli adam: orta-açıq dəri tonu',
    '🧑🏽‍🦯' => 'zondlayan çəlikli adam: orta dəri tonu',
    '🧑🏾‍🦯' => 'zondlayan çəlikli adam: orta-tünd dəri tonu',
    '🧑🏿‍🦯' => 'zondlayan çəlikli adam: tünd dəri tonu',
    '👨🏻‍🦯' => 'zond ilə kişi: açıq dəri tonu',
    '👨🏼‍🦯' => 'zond ilə kişi: orta-açıq dəri tonu',
    '👨🏽‍🦯' => 'zond ilə kişi: orta dəri tonu',
    '👨🏾‍🦯' => 'zond ilə kişi: orta-tünd dəri tonu',
    '👨🏿‍🦯' => 'zond ilə kişi: tünd dəri tonu',
    '👩🏻‍🦯' => 'zond ilə qadın: açıq dəri tonu',
    '👩🏼‍🦯' => 'zond ilə qadın: orta-açıq dəri tonu',
    '👩🏽‍🦯' => 'zond ilə qadın: orta dəri tonu',
    '👩🏾‍🦯' => 'zond ilə qadın: orta-tünd dəri tonu',
    '👩🏿‍🦯' => 'zond ilə qadın: tünd dəri tonu',
    '🧑🏻‍🦼' => 'motorlu kresloda oturmuş adam: açıq dəri tonu',
    '🧑🏼‍🦼' => 'motorlu kresloda oturmuş adam: orta-açıq dəri tonu',
    '🧑🏽‍🦼' => 'motorlu kresloda oturmuş adam: orta dəri tonu',
    '🧑🏾‍🦼' => 'motorlu kresloda oturmuş adam: orta-tünd dəri tonu',
    '🧑🏿‍🦼' => 'motorlu kresloda oturmuş adam: tünd dəri tonu',
    '👨🏻‍🦼' => 'motorlu oturacaqda kişi: açıq dəri tonu',
    '👨🏼‍🦼' => 'motorlu oturacaqda kişi: orta-açıq dəri tonu',
    '👨🏽‍🦼' => 'motorlu oturacaqda kişi: orta dəri tonu',
    '👨🏾‍🦼' => 'motorlu oturacaqda kişi: orta-tünd dəri tonu',
    '👨🏿‍🦼' => 'motorlu oturacaqda kişi: tünd dəri tonu',
    '👩🏻‍🦼' => 'motorlu oturacaqda qadın: açıq dəri tonu',
    '👩🏼‍🦼' => 'motorlu oturacaqda qadın: orta-açıq dəri tonu',
    '👩🏽‍🦼' => 'motorlu oturacaqda qadın: orta dəri tonu',
    '👩🏾‍🦼' => 'motorlu oturacaqda qadın: orta-tünd dəri tonu',
    '👩🏿‍🦼' => 'motorlu oturacaqda qadın: tünd dəri tonu',
    '🧑🏻‍🦽' => 'əl arabasında adam: açıq dəri tonu',
    '🧑🏼‍🦽' => 'əl arabasında adam: orta-açıq dəri tonu',
    '🧑🏽‍🦽' => 'əl arabasında adam: orta dəri tonu',
    '🧑🏾‍🦽' => 'əl arabasında adam: orta-tünd dəri tonu',
    '🧑🏿‍🦽' => 'əl arabasında adam: tünd dəri tonu',
    '👨🏻‍🦽' => 'manual oturacaqda kişi: açıq dəri tonu',
    '👨🏼‍🦽' => 'manual oturacaqda kişi: orta-açıq dəri tonu',
    '👨🏽‍🦽' => 'manual oturacaqda kişi: orta dəri tonu',
    '👨🏾‍🦽' => 'manual oturacaqda kişi: orta-tünd dəri tonu',
    '👨🏿‍🦽' => 'manual oturacaqda kişi: tünd dəri tonu',
    '👩🏻‍🦽' => 'manual oturacaqda qadın: açıq dəri tonu',
    '👩🏼‍🦽' => 'manual oturacaqda qadın: orta-açıq dəri tonu',
    '👩🏽‍🦽' => 'manual oturacaqda qadın: orta dəri tonu',
    '👩🏾‍🦽' => 'manual oturacaqda qadın: orta-tünd dəri tonu',
    '👩🏿‍🦽' => 'manual oturacaqda qadın: tünd dəri tonu',
    '🏃🏻‍♂' => 'qaçan kişi: açıq dəri tonu',
    '🏃🏼‍♂' => 'qaçan kişi: orta-açıq dəri tonu',
    '🏃🏽‍♂' => 'qaçan kişi: orta dəri tonu',
    '🏃🏾‍♂' => 'qaçan kişi: orta-tünd dəri tonu',
    '🏃🏿‍♂' => 'qaçan kişi: tünd dəri tonu',
    '🏃🏻‍♀' => 'qaçan qadın: açıq dəri tonu',
    '🏃🏼‍♀' => 'qaçan qadın: orta-açıq dəri tonu',
    '🏃🏽‍♀' => 'qaçan qadın: orta dəri tonu',
    '🏃🏾‍♀' => 'qaçan qadın: orta-tünd dəri tonu',
    '🏃🏿‍♀' => 'qaçan qadın: tünd dəri tonu',
    '🏃🏻‍➡' => 'atlet: açıq dəri tonu, sağa baxan',
    '🏃🏼‍➡' => 'atlet: orta-açıq dəri tonu, sağa baxan',
    '🏃🏽‍➡' => 'atlet: orta dəri tonu, sağa baxan',
    '🏃🏾‍➡' => 'atlet: orta-tünd dəri tonu, sağa baxan',
    '🏃🏿‍➡' => 'atlet: tünd dəri tonu, sağa baxan',
    '👯🏻‍♀' => 'rəqs edən qadınlar: açıq dəri tonu',
    '👯🏼‍♀' => 'rəqs edən qadınlar: orta-açıq dəri tonu',
    '👯🏽‍♀' => 'rəqs edən qadınlar: orta dəri tonu',
    '👯🏾‍♀' => 'rəqs edən qadınlar: orta-tünd dəri tonu',
    '👯🏿‍♀' => 'rəqs edən qadınlar: tünd dəri tonu',
    '👯🏻‍♂' => 'rəqs edən kişi: açıq dəri tonu',
    '👯🏼‍♂' => 'rəqs edən kişi: orta-açıq dəri tonu',
    '👯🏽‍♂' => 'rəqs edən kişi: orta dəri tonu',
    '👯🏾‍♂' => 'rəqs edən kişi: orta-tünd dəri tonu',
    '👯🏿‍♂' => 'rəqs edən kişi: tünd dəri tonu',
    '🧖🏻‍♂' => 'buxarlı otaqda kişi: açıq dəri tonu',
    '🧖🏼‍♂' => 'buxarlı otaqda kişi: orta-açıq dəri tonu',
    '🧖🏽‍♂' => 'buxarlı otaqda kişi: orta dəri tonu',
    '🧖🏾‍♂' => 'buxarlı otaqda kişi: orta-tünd dəri tonu',
    '🧖🏿‍♂' => 'buxarlı otaqda kişi: tünd dəri tonu',
    '🧖🏻‍♀' => 'buxarlı otaqda qadın: açıq dəri tonu',
    '🧖🏼‍♀' => 'buxarlı otaqda qadın: orta-açıq dəri tonu',
    '🧖🏽‍♀' => 'buxarlı otaqda qadın: orta dəri tonu',
    '🧖🏾‍♀' => 'buxarlı otaqda qadın: orta-tünd dəri tonu',
    '🧖🏿‍♀' => 'buxarlı otaqda qadın: tünd dəri tonu',
    '🧗🏻‍♂' => 'dırmaşan kişi: açıq dəri tonu',
    '🧗🏼‍♂' => 'dırmaşan kişi: orta-açıq dəri tonu',
    '🧗🏽‍♂' => 'dırmaşan kişi: orta dəri tonu',
    '🧗🏾‍♂' => 'dırmaşan kişi: orta-tünd dəri tonu',
    '🧗🏿‍♂' => 'dırmaşan kişi: tünd dəri tonu',
    '🧗🏻‍♀' => 'dırmaşan qadın: açıq dəri tonu',
    '🧗🏼‍♀' => 'dırmaşan qadın: orta-açıq dəri tonu',
    '🧗🏽‍♀' => 'dırmaşan qadın: orta dəri tonu',
    '🧗🏾‍♀' => 'dırmaşan qadın: orta-tünd dəri tonu',
    '🧗🏿‍♀' => 'dırmaşan qadın: tünd dəri tonu',
    '🏌🏻‍♂' => 'qolfçu kişi: açıq dəri tonu',
    '🏌🏼‍♂' => 'qolfçu kişi: orta-açıq dəri tonu',
    '🏌🏽‍♂' => 'qolfçu kişi: orta dəri tonu',
    '🏌🏾‍♂' => 'qolfçu kişi: orta-tünd dəri tonu',
    '🏌🏿‍♂' => 'qolfçu kişi: tünd dəri tonu',
    '🏌🏻‍♀' => 'qolfçu qadın: açıq dəri tonu',
    '🏌🏼‍♀' => 'qolfçu qadın: orta-açıq dəri tonu',
    '🏌🏽‍♀' => 'qolfçu qadın: orta dəri tonu',
    '🏌🏾‍♀' => 'qolfçu qadın: orta-tünd dəri tonu',
    '🏌🏿‍♀' => 'qolfçu qadın: tünd dəri tonu',
    '🏄🏻‍♂' => 'sörfçü kişi: açıq dəri tonu',
    '🏄🏼‍♂' => 'sörfçü kişi: orta-açıq dəri tonu',
    '🏄🏽‍♂' => 'sörfçü kişi: orta dəri tonu',
    '🏄🏾‍♂' => 'sörfçü kişi: orta-tünd dəri tonu',
    '🏄🏿‍♂' => 'sörfçü kişi: tünd dəri tonu',
    '🏄🏻‍♀' => 'sörfçü qadın: açıq dəri tonu',
    '🏄🏼‍♀' => 'sörfçü qadın: orta-açıq dəri tonu',
    '🏄🏽‍♀' => 'sörfçü qadın: orta dəri tonu',
    '🏄🏾‍♀' => 'sörfçü qadın: orta-tünd dəri tonu',
    '🏄🏿‍♀' => 'sörfçü qadın: tünd dəri tonu',
    '🚣🏻‍♂' => 'qayıqçı kişi: açıq dəri tonu',
    '🚣🏼‍♂' => 'qayıqçı kişi: orta-açıq dəri tonu',
    '🚣🏽‍♂' => 'qayıqçı kişi: orta dəri tonu',
    '🚣🏾‍♂' => 'qayıqçı kişi: orta-tünd dəri tonu',
    '🚣🏿‍♂' => 'qayıqçı kişi: tünd dəri tonu',
    '🚣🏻‍♀' => 'qayıqçı qadın: açıq dəri tonu',
    '🚣🏼‍♀' => 'qayıqçı qadın: orta-açıq dəri tonu',
    '🚣🏽‍♀' => 'qayıqçı qadın: orta dəri tonu',
    '🚣🏾‍♀' => 'qayıqçı qadın: orta-tünd dəri tonu',
    '🚣🏿‍♀' => 'qayıqçı qadın: tünd dəri tonu',
    '🏊🏻‍♂' => 'üzgüçü kişi: açıq dəri tonu',
    '🏊🏼‍♂' => 'üzgüçü kişi: orta-açıq dəri tonu',
    '🏊🏽‍♂' => 'üzgüçü kişi: orta dəri tonu',
    '🏊🏾‍♂' => 'üzgüçü kişi: orta-tünd dəri tonu',
    '🏊🏿‍♂' => 'üzgüçü kişi: tünd dəri tonu',
    '🏊🏻‍♀' => 'üzgüçü qadın: açıq dəri tonu',
    '🏊🏼‍♀' => 'üzgüçü qadın: orta-açıq dəri tonu',
    '🏊🏽‍♀' => 'üzgüçü qadın: orta dəri tonu',
    '🏊🏾‍♀' => 'üzgüçü qadın: orta-tünd dəri tonu',
    '🏊🏿‍♀' => 'üzgüçü qadın: tünd dəri tonu',
    '⛹🏻‍♂' => 'futbolçu kişi: açıq dəri tonu',
    '⛹🏼‍♂' => 'futbolçu kişi: orta-açıq dəri tonu',
    '⛹🏽‍♂' => 'futbolçu kişi: orta dəri tonu',
    '⛹🏾‍♂' => 'futbolçu kişi: orta-tünd dəri tonu',
    '⛹🏿‍♂' => 'futbolçu kişi: tünd dəri tonu',
    '⛹🏻‍♀' => 'futbolçu qadın: açıq dəri tonu',
    '⛹🏼‍♀' => 'futbolçu qadın: orta-açıq dəri tonu',
    '⛹🏽‍♀' => 'futbolçu qadın: orta dəri tonu',
    '⛹🏾‍♀' => 'futbolçu qadın: orta-tünd dəri tonu',
    '⛹🏿‍♀' => 'futbolçu qadın: tünd dəri tonu',
    '🏋🏻‍♂' => 'ştanqçı kişi: açıq dəri tonu',
    '🏋🏼‍♂' => 'ştanqçı kişi: orta-açıq dəri tonu',
    '🏋🏽‍♂' => 'ştanqçı kişi: orta dəri tonu',
    '🏋🏾‍♂' => 'ştanqçı kişi: orta-tünd dəri tonu',
    '🏋🏿‍♂' => 'ştanqçı kişi: tünd dəri tonu',
    '🏋🏻‍♀' => 'ştanqçı qadın: açıq dəri tonu',
    '🏋🏼‍♀' => 'ştanqçı qadın: orta-açıq dəri tonu',
    '🏋🏽‍♀' => 'ştanqçı qadın: orta dəri tonu',
    '🏋🏾‍♀' => 'ştanqçı qadın: orta-tünd dəri tonu',
    '🏋🏿‍♀' => 'ştanqçı qadın: tünd dəri tonu',
    '🚴🏻‍♂' => 'velosipedçi kişi: açıq dəri tonu',
    '🚴🏼‍♂' => 'velosipedçi kişi: orta-açıq dəri tonu',
    '🚴🏽‍♂' => 'velosipedçi kişi: orta dəri tonu',
    '🚴🏾‍♂' => 'velosipedçi kişi: orta-tünd dəri tonu',
    '🚴🏿‍♂' => 'velosipedçi kişi: tünd dəri tonu',
    '🚴🏻‍♀' => 'velosipedçi qadın: açıq dəri tonu',
    '🚴🏼‍♀' => 'velosipedçi qadın: orta-açıq dəri tonu',
    '🚴🏽‍♀' => 'velosipedçi qadın: orta dəri tonu',
    '🚴🏾‍♀' => 'velosipedçi qadın: orta-tünd dəri tonu',
    '🚴🏿‍♀' => 'velosipedçi qadın: tünd dəri tonu',
    '🚵🏻‍♂' => 'dağ velosipedçisi kişi: açıq dəri tonu',
    '🚵🏼‍♂' => 'dağ velosipedçisi kişi: orta-açıq dəri tonu',
    '🚵🏽‍♂' => 'dağ velosipedçisi kişi: orta dəri tonu',
    '🚵🏾‍♂' => 'dağ velosipedçisi kişi: orta-tünd dəri tonu',
    '🚵🏿‍♂' => 'dağ velosipedçisi kişi: tünd dəri tonu',
    '🚵🏻‍♀' => 'dağ velosipedçisi qadın: açıq dəri tonu',
    '🚵🏼‍♀' => 'dağ velosipedçisi qadın: orta-açıq dəri tonu',
    '🚵🏽‍♀' => 'dağ velosipedçisi qadın: orta dəri tonu',
    '🚵🏾‍♀' => 'dağ velosipedçisi qadın: orta-tünd dəri tonu',
    '🚵🏿‍♀' => 'dağ velosipedçisi qadın: tünd dəri tonu',
    '🤸🏻‍♂' => 'akrobat kişi: açıq dəri tonu',
    '🤸🏼‍♂' => 'akrobat kişi: orta-açıq dəri tonu',
    '🤸🏽‍♂' => 'akrobat kişi: orta dəri tonu',
    '🤸🏾‍♂' => 'akrobat kişi: orta-tünd dəri tonu',
    '🤸🏿‍♂' => 'akrobat kişi: tünd dəri tonu',
    '🤸🏻‍♀' => 'aktobat qadın: açıq dəri tonu',
    '🤸🏼‍♀' => 'aktobat qadın: orta-açıq dəri tonu',
    '🤸🏽‍♀' => 'aktobat qadın: orta dəri tonu',
    '🤸🏾‍♀' => 'aktobat qadın: orta-tünd dəri tonu',
    '🤸🏿‍♀' => 'aktobat qadın: tünd dəri tonu',
    '🤼🏻‍♀' => 'güləşçi qadın: açıq dəri tonu',
    '🤼🏼‍♀' => 'güləşçi qadın: orta-açıq dəri tonu',
    '🤼🏽‍♀' => 'güləşçi qadın: orta dəri tonu',
    '🤼🏾‍♀' => 'güləşçi qadın: orta-tünd dəri tonu',
    '🤼🏿‍♀' => 'güləşçi qadın: tünd dəri tonu',
    '🤼🏻‍♂' => 'güləşçi kişi: açıq dəri tonu',
    '🤼🏼‍♂' => 'güləşçi kişi: orta-açıq dəri tonu',
    '🤼🏽‍♂' => 'güləşçi kişi: orta dəri tonu',
    '🤼🏾‍♂' => 'güləşçi kişi: orta-tünd dəri tonu',
    '🤼🏿‍♂' => 'güləşçi kişi: tünd dəri tonu',
    '🤽🏻‍♂' => 'su poloçusu kişi: açıq dəri tonu',
    '🤽🏼‍♂' => 'su poloçusu kişi: orta-açıq dəri tonu',
    '🤽🏽‍♂' => 'su poloçusu kişi: orta dəri tonu',
    '🤽🏾‍♂' => 'su poloçusu kişi: orta-tünd dəri tonu',
    '🤽🏿‍♂' => 'su poloçusu kişi: tünd dəri tonu',
    '🤽🏻‍♀' => 'su poloçusu qadın: açıq dəri tonu',
    '🤽🏼‍♀' => 'su poloçusu qadın: orta-açıq dəri tonu',
    '🤽🏽‍♀' => 'su poloçusu qadın: orta dəri tonu',
    '🤽🏾‍♀' => 'su poloçusu qadın: orta-tünd dəri tonu',
    '🤽🏿‍♀' => 'su poloçusu qadın: tünd dəri tonu',
    '🤾🏻‍♂' => 'həndbolçu kişi: açıq dəri tonu',
    '🤾🏼‍♂' => 'həndbolçu kişi: orta-açıq dəri tonu',
    '🤾🏽‍♂' => 'həndbolçu kişi: orta dəri tonu',
    '🤾🏾‍♂' => 'həndbolçu kişi: orta-tünd dəri tonu',
    '🤾🏿‍♂' => 'həndbolçu kişi: tünd dəri tonu',
    '🤾🏻‍♀' => 'həndbolçu qadın: açıq dəri tonu',
    '🤾🏼‍♀' => 'həndbolçu qadın: orta-açıq dəri tonu',
    '🤾🏽‍♀' => 'həndbolçu qadın: orta dəri tonu',
    '🤾🏾‍♀' => 'həndbolçu qadın: orta-tünd dəri tonu',
    '🤾🏿‍♀' => 'həndbolçu qadın: tünd dəri tonu',
    '🤹🏻‍♂' => 'jonqlyor kişi: açıq dəri tonu',
    '🤹🏼‍♂' => 'jonqlyor kişi: orta-açıq dəri tonu',
    '🤹🏽‍♂' => 'jonqlyor kişi: orta dəri tonu',
    '🤹🏾‍♂' => 'jonqlyor kişi: orta-tünd dəri tonu',
    '🤹🏿‍♂' => 'jonqlyor kişi: tünd dəri tonu',
    '🤹🏻‍♀' => 'jonqlyor qadın: açıq dəri tonu',
    '🤹🏼‍♀' => 'jonqlyor qadın: orta-açıq dəri tonu',
    '🤹🏽‍♀' => 'jonqlyor qadın: orta dəri tonu',
    '🤹🏾‍♀' => 'jonqlyor qadın: orta-tünd dəri tonu',
    '🤹🏿‍♀' => 'jonqlyor qadın: tünd dəri tonu',
    '🧘🏻‍♂' => 'lotus pozisiyasında kişi: açıq dəri tonu',
    '🧘🏼‍♂' => 'lotus pozisiyasında kişi: orta-açıq dəri tonu',
    '🧘🏽‍♂' => 'lotus pozisiyasında kişi: orta dəri tonu',
    '🧘🏾‍♂' => 'lotus pozisiyasında kişi: orta-tünd dəri tonu',
    '🧘🏿‍♂' => 'lotus pozisiyasında kişi: tünd dəri tonu',
    '🧘🏻‍♀' => 'lotus pozisiyasında qadın: açıq dəri tonu',
    '🧘🏼‍♀' => 'lotus pozisiyasında qadın: orta-açıq dəri tonu',
    '🧘🏽‍♀' => 'lotus pozisiyasında qadın: orta dəri tonu',
    '🧘🏾‍♀' => 'lotus pozisiyasında qadın: orta-tünd dəri tonu',
    '🧘🏿‍♀' => 'lotus pozisiyasında qadın: tünd dəri tonu',
    '🧑‍🦰' => 'böyük: qırmızı saç',
    '🧑‍🦱' => 'böyük: buruq saç',
    '🧑‍🦳' => 'böyük: ağ saç',
    '🧑‍🦲' => 'böyük: keçəl',
    '👨‍🦰' => 'kişi: qırmızı saç',
    '👨‍🦱' => 'kişi: buruq saç',
    '👨‍🦳' => 'kişi: ağ saç',
    '👨‍🦲' => 'kişi: keçəl',
    '👩‍🦰' => 'qadın: qırmızı saç',
    '👩‍🦱' => 'qadın: buruq saç',
    '👩‍🦳' => 'qadın: ağ saç',
    '👩‍🦲' => 'qadın: keçəl',
    '🚶‍➡' => 'piyada: sağa baxan',
    '🧎‍➡' => 'dizi üstündə adam: sağa baxan',
    '🏃‍➡' => 'atlet: sağa baxan',
    '👨‍👦' => 'ailə: kişi, oğlan',
    '👨‍👧' => 'ailə: kişi, qız uşağı',
    '👩‍👦' => 'ailə: qadın, oğlan',
    '👩‍👧' => 'ailə: qadın, qız uşağı',
    '😶‍🌫' => 'buludlu üz',
    '😮‍💨' => 'nəfəs alan üz',
    '🙂‍↕' => 'başı şaquli silkələmək',
    '😵‍💫' => 'spiral gözlü üz',
    '❤‍🔥' => 'alovlu ürək',
    '❤‍🩹' => 'yara bandlı ürək',
    '👁‍🗨' => 'tanıq işarəsi',
    '🧔‍♂' => 'kişi; saqqal',
    '👱‍♂' => 'sarışın kişi',
    '🧔‍♀' => 'qadın: saqqal',
    '👱‍♀' => 'sarışın qadın',
    '🙍‍♂' => 'kefsiz kişi',
    '🙍‍♀' => 'kefsiz qadın',
    '🙎‍♂' => 'acıqlı kişi',
    '🙎‍♀' => 'acıqlı qadın',
    '🙅‍♂' => 'əleyhinə olan kişi',
    '🙅‍♀' => 'əleyhinə olan qadın',
    '🙆‍♂' => 'lehinə olan kişi',
    '🙆‍♀' => 'lehinə olan qadın',
    '💁‍♂' => 'əl uzadan kişi',
    '💁‍♀' => 'əl uzadan qadın',
    '🙋‍♂' => 'əl qaldıran kişi',
    '🙋‍♀' => 'əl qaldıran qadın',
    '🧏‍♂' => 'kar kişi',
    '🧏‍♀' => 'kar qadın',
    '🙇‍♂' => 'baş əyən kişi',
    '🙇‍♀' => 'baş əyən qadın',
    '🤦‍♂' => 'üzünü tutan kişi',
    '🤦‍♀' => 'üzünü tutan qadın',
    '🤷‍♂' => 'çiynini çəkən kişi',
    '🤷‍♀' => 'çiynini çəkən qadın',
    '🧑‍⚕' => 'tibb işçisi',
    '👨‍⚕' => 'kişi həkim',
    '👩‍⚕' => 'qadın həkim',
    '🧑‍🎓' => 'tələbə',
    '👨‍🎓' => 'oğlan tələbə',
    '👩‍🎓' => 'qız tələbə',
    '🧑‍🏫' => 'müəllim',
    '👨‍🏫' => 'kişi müəllim',
    '👩‍🏫' => 'qadın müəllim',
    '🧑‍⚖' => 'hakim',
    '👨‍⚖' => 'kişi hakim',
    '👩‍⚖' => 'qadın hakim',
    '🧑‍🌾' => 'fermer',
    '👨‍🌾' => 'kişi fermer',
    '👩‍🌾' => 'qadın fermer',
    '🧑‍🍳' => 'aşpaz',
    '👨‍🍳' => 'kişi aşbaz',
    '👩‍🍳' => 'qadın aşbaz',
    '🧑‍🔧' => 'mexanik',
    '👨‍🔧' => 'kişi mexanik',
    '👩‍🔧' => 'qadın mexanik',
    '🧑‍🏭' => 'fabrik işçisi',
    '👨‍🏭' => 'kişi fabrik işçisi',
    '👩‍🏭' => 'qadın fabrik işçisi',
    '🧑‍💼' => 'ofis işçisi',
    '👨‍💼' => 'kişi ofis işçisi',
    '👩‍💼' => 'qadın ofis işçisi',
    '🧑‍🔬' => 'alim',
    '👨‍🔬' => 'kişi alim',
    '👩‍🔬' => 'qadın alim',
    '🧑‍💻' => 'texnoloq',
    '👨‍💻' => 'kişi texnoloq',
    '👩‍💻' => 'qadın texnoloq',
    '🧑‍🎤' => 'müğənni',
    '👨‍🎤' => 'kişi müğənni',
    '👩‍🎤' => 'qadın müğənni',
    '🧑‍🎨' => 'aktyor',
    '👨‍🎨' => 'kişi rəssam',
    '👩‍🎨' => 'qadın rəssam',
    '🧑‍✈' => 'pilot',
    '👨‍✈' => 'kişi pilot',
    '👩‍✈' => 'qadın pilot',
    '🧑‍🚀' => 'astronavt',
    '👨‍🚀' => 'kişi astronavt',
    '👩‍🚀' => 'qadın astronavt',
    '🧑‍🚒' => 'yanğınsöndürən maşın',
    '👨‍🚒' => 'kişi yanğınsöndürən',
    '👩‍🚒' => 'qadın yanğınsöndürən',
    '👮‍♂' => 'kişi polis',
    '👮‍♀' => 'qadın polis',
    '🕵‍♂' => 'kişi detektiv',
    '🕵‍♀' => 'qadın detektiv',
    '💂‍♂' => 'kişi keşikçi',
    '💂‍♀' => 'qadın keşikçi',
    '👷‍♂' => 'kişi bənna',
    '👷‍♀' => 'qadın bənna',
    '👳‍♂' => 'türbanlı kişi',
    '👳‍♀' => 'türbanlı qadın',
    '🤵‍♂' => 'smokinqli adam',
    '🤵‍♀' => 'smokinqli qadın',
    '👰‍♂' => 'duvaqlı adam',
    '👰‍♀' => 'duvaqlı qadın',
    '👩‍🍼' => 'körpə əmizdirən qadın',
    '👨‍🍼' => 'körpə əmizdirən kişi',
    '🧑‍🍼' => 'körpə əmizdirən şəxs',
    '🧑‍🎄' => 'mx klaus',
    '🦸‍♂' => 'kişi superqəhrəman',
    '🦸‍♀' => 'qadın superqəhrəman',
    '🦹‍♂' => 'kişi supercani',
    '🦹‍♀' => 'qadın supercani',
    '🧙‍♂' => 'kişi maq',
    '🧙‍♀' => 'qadın maq',
    '🧚‍♂' => 'kişi pəri',
    '🧚‍♀' => 'qadın pəri',
    '🧛‍♂' => 'kişi vampir',
    '🧛‍♀' => 'qadın vampir',
    '🧜‍♂' => 'dəniz kişisi',
    '🧜‍♀' => 'su pərisi',
    '🧝‍♂' => 'kişi elf',
    '🧝‍♀' => 'qadın elf',
    '🧞‍♂' => 'kişi cin',
    '🧞‍♀' => 'qadın cin',
    '🧟‍♂' => 'kişi zombi',
    '🧟‍♀' => 'qadın zombi',
    '💆‍♂' => 'üzünə masaj edən kişi',
    '💆‍♀' => 'üzünə masaj edən qadın',
    '💇‍♂' => 'saçını kəsdirən kişi',
    '💇‍♀' => 'saçını kəsdirən qadın',
    '🚶‍♂' => 'gəzən kişi',
    '🚶‍♀' => 'gəzən qadın',
    '🧍‍♂' => 'duran kişi',
    '🧍‍♀' => 'duran qadın',
    '🧎‍♂' => 'dizi üstündə kişi',
    '🧎‍♀' => 'dizi üstündə qadın',
    '🧑‍🦯' => 'zondlayan çəlikli adam',
    '👨‍🦯' => 'zond ilə kişi',
    '👩‍🦯' => 'zond ilə qadın',
    '🧑‍🦼' => 'motorlu kresloda oturmuş adam',
    '👨‍🦼' => 'motorlu oturacaqda kişi',
    '👩‍🦼' => 'motorlu oturacaqda qadın',
    '🧑‍🦽' => 'əl arabasında adam',
    '👨‍🦽' => 'manual oturacaqda kişi',
    '👩‍🦽' => 'manual oturacaqda qadın',
    '🏃‍♂' => 'qaçan kişi',
    '🏃‍♀' => 'qaçan qadın',
    '🧑‍🩰' => 'balet rəqqası',
    '👯‍♂' => 'rəqs edən kişi',
    '👯‍♀' => 'rəqs edən qadınlar',
    '🧖‍♂' => 'buxarlı otaqda kişi',
    '🧖‍♀' => 'buxarlı otaqda qadın',
    '🧗‍♂' => 'dırmaşan kişi',
    '🧗‍♀' => 'dırmaşan qadın',
    '🏌‍♂' => 'qolfçu kişi',
    '🏌‍♀' => 'qolfçu qadın',
    '🏄‍♂' => 'sörfçü kişi',
    '🏄‍♀' => 'sörfçü qadın',
    '🚣‍♂' => 'qayıqçı kişi',
    '🚣‍♀' => 'qayıqçı qadın',
    '🏊‍♂' => 'üzgüçü kişi',
    '🏊‍♀' => 'üzgüçü qadın',
    '⛹‍♂' => 'futbolçu kişi',
    '⛹‍♀' => 'futbolçu qadın',
    '🏋‍♂' => 'ştanqçı kişi',
    '🏋‍♀' => 'ştanqçı qadın',
    '🚴‍♂' => 'velosipedçi kişi',
    '🚴‍♀' => 'velosipedçi qadın',
    '🚵‍♂' => 'dağ velosipedçisi kişi',
    '🚵‍♀' => 'dağ velosipedçisi qadın',
    '🤸‍♂' => 'akrobat kişi',
    '🤸‍♀' => 'aktobat qadın',
    '🤼‍♂' => 'güləşçi kişi',
    '🤼‍♀' => 'güləşçi qadın',
    '🤽‍♂' => 'su poloçusu kişi',
    '🤽‍♀' => 'su poloçusu qadın',
    '🤾‍♂' => 'həndbolçu kişi',
    '🤾‍♀' => 'həndbolçu qadın',
    '🤹‍♂' => 'jonqlyor kişi',
    '🤹‍♀' => 'jonqlyor qadın',
    '🧘‍♂' => 'lotus pozisiyasında kişi',
    '🧘‍♀' => 'lotus pozisiyasında qadın',
    '🧑‍🧒' => 'ailə: yetkin, uşaq',
    '🐕‍🦺' => 'xidmətçi it',
    '🐈‍⬛' => 'qara pişik',
    '🐻‍❄' => 'qütb ayısı',
    '🐦‍⬛' => 'qara quş',
    '🐦‍🔥' => 'feniks',
    '🍋‍🟩' => 'laym',
    '🍄‍🟫' => 'qəhvəyi göbələk',
    '⛓‍💥' => 'qırılmış zəncir',
    '🏳‍🌈' => 'göy qurşağı bayrağı',
    '🏳‍⚧' => 'göy, çəhrayı və ağ bayraq',
    '🏴‍☠' => 'quldur bayrağı',
    '👋🏻' => 'əl sallayan əllər: açıq dəri tonu',
    '👋🏼' => 'əl sallayan əllər: orta-açıq dəri tonu',
    '👋🏽' => 'əl sallayan əllər: orta dəri tonu',
    '👋🏾' => 'əl sallayan əllər: orta-tünd dəri tonu',
    '👋🏿' => 'əl sallayan əllər: tünd dəri tonu',
    '🤚🏻' => 'yuxarı qalxan əl arxası: açıq dəri tonu',
    '🤚🏼' => 'yuxarı qalxan əl arxası: orta-açıq dəri tonu',
    '🤚🏽' => 'yuxarı qalxan əl arxası: orta dəri tonu',
    '🤚🏾' => 'yuxarı qalxan əl arxası: orta-tünd dəri tonu',
    '🤚🏿' => 'yuxarı qalxan əl arxası: tünd dəri tonu',
    '🖐🏻' => 'barmaqları aralı şəkildə qaldırılmış əl: açıq dəri tonu',
    '🖐🏼' => 'barmaqları aralı şəkildə qaldırılmış əl: orta-açıq dəri tonu',
    '🖐🏽' => 'barmaqları aralı şəkildə qaldırılmış əl: orta dəri tonu',
    '🖐🏾' => 'barmaqları aralı şəkildə qaldırılmış əl: orta-tünd dəri tonu',
    '🖐🏿' => 'barmaqları aralı şəkildə qaldırılmış əl: tünd dəri tonu',
    '✋🏻' => 'qaldırımış əl: açıq dəri tonu',
    '✋🏼' => 'qaldırımış əl: orta-açıq dəri tonu',
    '✋🏽' => 'qaldırımış əl: orta dəri tonu',
    '✋🏾' => 'qaldırımış əl: orta-tünd dəri tonu',
    '✋🏿' => 'qaldırımış əl: tünd dəri tonu',
    '🖖🏻' => 'vulkan salamı: açıq dəri tonu',
    '🖖🏼' => 'vulkan salamı: orta-açıq dəri tonu',
    '🖖🏽' => 'vulkan salamı: orta dəri tonu',
    '🖖🏾' => 'vulkan salamı: orta-tünd dəri tonu',
    '🖖🏿' => 'vulkan salamı: tünd dəri tonu',
    '🫱🏻' => 'sağ əl: açıq dəri tonu',
    '🫱🏼' => 'sağ əl: orta-açıq dəri tonu',
    '🫱🏽' => 'sağ əl: orta dəri tonu',
    '🫱🏾' => 'sağ əl: orta-tünd dəri tonu',
    '🫱🏿' => 'sağ əl: tünd dəri tonu',
    '🫲🏻' => 'sol əl: açıq dəri tonu',
    '🫲🏼' => 'sol əl: orta-açıq dəri tonu',
    '🫲🏽' => 'sol əl: orta dəri tonu',
    '🫲🏾' => 'sol əl: orta-tünd dəri tonu',
    '🫲🏿' => 'sol əl: tünd dəri tonu',
    '🫳🏻' => 'aşağı əl: açıq dəri tonu',
    '🫳🏼' => 'aşağı əl: orta-açıq dəri tonu',
    '🫳🏽' => 'aşağı əl: orta dəri tonu',
    '🫳🏾' => 'aşağı əl: orta-tünd dəri tonu',
    '🫳🏿' => 'aşağı əl: tünd dəri tonu',
    '🫴🏻' => 'yuxarı əl: açıq dəri tonu',
    '🫴🏼' => 'yuxarı əl: orta-açıq dəri tonu',
    '🫴🏽' => 'yuxarı əl: orta dəri tonu',
    '🫴🏾' => 'yuxarı əl: orta-tünd dəri tonu',
    '🫴🏿' => 'yuxarı əl: tünd dəri tonu',
    '🫷🏻' => 'sola itələyən əl: açıq dəri tonu',
    '🫷🏼' => 'sola itələyən əl: orta-açıq dəri tonu',
    '🫷🏽' => 'sola itələyən əl: orta dəri tonu',
    '🫷🏾' => 'sola itələyən əl: orta-tünd dəri tonu',
    '🫷🏿' => 'sola itələyən əl: tünd dəri tonu',
    '🫸🏻' => 'sağa basan əl: açıq dəri tonu',
    '🫸🏼' => 'sağa basan əl: orta-açıq dəri tonu',
    '🫸🏽' => 'sağa basan əl: orta dəri tonu',
    '🫸🏾' => 'sağa basan əl: orta-tünd dəri tonu',
    '🫸🏿' => 'sağa basan əl: tünd dəri tonu',
    '👌🏻' => 'ok işarəsi: açıq dəri tonu',
    '👌🏼' => 'ok işarəsi: orta-açıq dəri tonu',
    '👌🏽' => 'ok işarəsi: orta dəri tonu',
    '👌🏾' => 'ok işarəsi: orta-tünd dəri tonu',
    '👌🏿' => 'ok işarəsi: tünd dəri tonu',
    '🤌🏻' => 'çimdik: açıq dəri tonu',
    '🤌🏼' => 'çimdik: orta-açıq dəri tonu',
    '🤌🏽' => 'çimdik: orta dəri tonu',
    '🤌🏾' => 'çimdik: orta-tünd dəri tonu',
    '🤌🏿' => 'çimdik: tünd dəri tonu',
    '🤏🏻' => 'sıxan əl: açıq dəri tonu',
    '🤏🏼' => 'sıxan əl: orta-açıq dəri tonu',
    '🤏🏽' => 'sıxan əl: orta dəri tonu',
    '🤏🏾' => 'sıxan əl: orta-tünd dəri tonu',
    '🤏🏿' => 'sıxan əl: tünd dəri tonu',
    '✌🏻' => 'qələbə işarəsi: açıq dəri tonu',
    '✌🏼' => 'qələbə işarəsi: orta-açıq dəri tonu',
    '✌🏽' => 'qələbə işarəsi: orta dəri tonu',
    '✌🏾' => 'qələbə işarəsi: orta-tünd dəri tonu',
    '✌🏿' => 'qələbə işarəsi: tünd dəri tonu',
    '🤞🏻' => 'ümid edirəm: açıq dəri tonu',
    '🤞🏼' => 'ümid edirəm: orta-açıq dəri tonu',
    '🤞🏽' => 'ümid edirəm: orta dəri tonu',
    '🤞🏾' => 'ümid edirəm: orta-tünd dəri tonu',
    '🤞🏿' => 'ümid edirəm: tünd dəri tonu',
    '🫰🏻' => 'əl barmağı və baş barmağı çarpazlanmış vəziyyətdə: açıq dəri tonu',
    '🫰🏼' => 'əl barmağı və baş barmağı çarpazlanmış vəziyyətdə: orta-açıq dəri tonu',
    '🫰🏽' => 'əl barmağı və baş barmağı çarpazlanmış vəziyyətdə: orta dəri tonu',
    '🫰🏾' => 'əl barmağı və baş barmağı çarpazlanmış vəziyyətdə: orta-tünd dəri tonu',
    '🫰🏿' => 'əl barmağı və baş barmağı çarpazlanmış vəziyyətdə: tünd dəri tonu',
    '🤟🏻' => 'sevgi jesti: açıq dəri tonu',
    '🤟🏼' => 'sevgi jesti: orta-açıq dəri tonu',
    '🤟🏽' => 'sevgi jesti: orta dəri tonu',
    '🤟🏾' => 'sevgi jesti: orta-tünd dəri tonu',
    '🤟🏿' => 'sevgi jesti: tünd dəri tonu',
    '🤘🏻' => 'buynuz işarəsi: açıq dəri tonu',
    '🤘🏼' => 'buynuz işarəsi: orta-açıq dəri tonu',
    '🤘🏽' => 'buynuz işarəsi: orta dəri tonu',
    '🤘🏾' => 'buynuz işarəsi: orta-tünd dəri tonu',
    '🤘🏿' => 'buynuz işarəsi: tünd dəri tonu',
    '🤙🏻' => 'mənə zəng et: açıq dəri tonu',
    '🤙🏼' => 'mənə zəng et: orta-açıq dəri tonu',
    '🤙🏽' => 'mənə zəng et: orta dəri tonu',
    '🤙🏾' => 'mənə zəng et: orta-tünd dəri tonu',
    '🤙🏿' => 'mənə zəng et: tünd dəri tonu',
    '👈🏻' => 'solu göstərən sol əlin işarə barmağı: açıq dəri tonu',
    '👈🏼' => 'solu göstərən sol əlin işarə barmağı: orta-açıq dəri tonu',
    '👈🏽' => 'solu göstərən sol əlin işarə barmağı: orta dəri tonu',
    '👈🏾' => 'solu göstərən sol əlin işarə barmağı: orta-tünd dəri tonu',
    '👈🏿' => 'solu göstərən sol əlin işarə barmağı: tünd dəri tonu',
    '👉🏻' => 'sağı göstərən sol əlin işarə barmağı: açıq dəri tonu',
    '👉🏼' => 'sağı göstərən sol əlin işarə barmağı: orta-açıq dəri tonu',
    '👉🏽' => 'sağı göstərən sol əlin işarə barmağı: orta dəri tonu',
    '👉🏾' => 'sağı göstərən sol əlin işarə barmağı: orta-tünd dəri tonu',
    '👉🏿' => 'sağı göstərən sol əlin işarə barmağı: tünd dəri tonu',
    '👆🏻' => 'yuxarını göstərən sol əlin işarə barmağı: açıq dəri tonu',
    '👆🏼' => 'yuxarını göstərən sol əlin işarə barmağı: orta-açıq dəri tonu',
    '👆🏽' => 'yuxarını göstərən sol əlin işarə barmağı: orta dəri tonu',
    '👆🏾' => 'yuxarını göstərən sol əlin işarə barmağı: orta-tünd dəri tonu',
    '👆🏿' => 'yuxarını göstərən sol əlin işarə barmağı: tünd dəri tonu',
    '🖕🏻' => 'orta barmaq: açıq dəri tonu',
    '🖕🏼' => 'orta barmaq: orta-açıq dəri tonu',
    '🖕🏽' => 'orta barmaq: orta dəri tonu',
    '🖕🏾' => 'orta barmaq: orta-tünd dəri tonu',
    '🖕🏿' => 'orta barmaq: tünd dəri tonu',
    '👇🏻' => 'aşağını göstərən sol əlin işarə barmağı: açıq dəri tonu',
    '👇🏼' => 'aşağını göstərən sol əlin işarə barmağı: orta-açıq dəri tonu',
    '👇🏽' => 'aşağını göstərən sol əlin işarə barmağı: orta dəri tonu',
    '👇🏾' => 'aşağını göstərən sol əlin işarə barmağı: orta-tünd dəri tonu',
    '👇🏿' => 'aşağını göstərən sol əlin işarə barmağı: tünd dəri tonu',
    '☝🏻' => 'işarə barmağı: açıq dəri tonu',
    '☝🏼' => 'işarə barmağı: orta-açıq dəri tonu',
    '☝🏽' => 'işarə barmağı: orta dəri tonu',
    '☝🏾' => 'işarə barmağı: orta-tünd dəri tonu',
    '☝🏿' => 'işarə barmağı: tünd dəri tonu',
    '🫵🏻' => 'tamaşaçıya işarə edən barmaq: açıq dəri tonu',
    '🫵🏼' => 'tamaşaçıya işarə edən barmaq: orta-açıq dəri tonu',
    '🫵🏽' => 'tamaşaçıya işarə edən barmaq: orta dəri tonu',
    '🫵🏾' => 'tamaşaçıya işarə edən barmaq: orta-tünd dəri tonu',
    '🫵🏿' => 'tamaşaçıya işarə edən barmaq: tünd dəri tonu',
    '👍🏻' => 'baş barmaq yuxarı: açıq dəri tonu',
    '👍🏼' => 'baş barmaq yuxarı: orta-açıq dəri tonu',
    '👍🏽' => 'baş barmaq yuxarı: orta dəri tonu',
    '👍🏾' => 'baş barmaq yuxarı: orta-tünd dəri tonu',
    '👍🏿' => 'baş barmaq yuxarı: tünd dəri tonu',
    '👎🏻' => 'baş barmaq aşağı: açıq dəri tonu',
    '👎🏼' => 'baş barmaq aşağı: orta-açıq dəri tonu',
    '👎🏽' => 'baş barmaq aşağı: orta dəri tonu',
    '👎🏾' => 'baş barmaq aşağı: orta-tünd dəri tonu',
    '👎🏿' => 'baş barmaq aşağı: tünd dəri tonu',
    '✊🏻' => 'qaldırılmış yumruq: açıq dəri tonu',
    '✊🏼' => 'qaldırılmış yumruq: orta-açıq dəri tonu',
    '✊🏽' => 'qaldırılmış yumruq: orta dəri tonu',
    '✊🏾' => 'qaldırılmış yumruq: orta-tünd dəri tonu',
    '✊🏿' => 'qaldırılmış yumruq: tünd dəri tonu',
    '👊🏻' => 'yaxınlaşan yumruq: açıq dəri tonu',
    '👊🏼' => 'yaxınlaşan yumruq: orta-açıq dəri tonu',
    '👊🏽' => 'yaxınlaşan yumruq: orta dəri tonu',
    '👊🏾' => 'yaxınlaşan yumruq: orta-tünd dəri tonu',
    '👊🏿' => 'yaxınlaşan yumruq: tünd dəri tonu',
    '🤛🏻' => 'sola yönələn yumruq: açıq dəri tonu',
    '🤛🏼' => 'sola yönələn yumruq: orta-açıq dəri tonu',
    '🤛🏽' => 'sola yönələn yumruq: orta dəri tonu',
    '🤛🏾' => 'sola yönələn yumruq: orta-tünd dəri tonu',
    '🤛🏿' => 'sola yönələn yumruq: tünd dəri tonu',
    '🤜🏻' => 'sağa yönələn yumruq: açıq dəri tonu',
    '🤜🏼' => 'sağa yönələn yumruq: orta-açıq dəri tonu',
    '🤜🏽' => 'sağa yönələn yumruq: orta dəri tonu',
    '🤜🏾' => 'sağa yönələn yumruq: orta-tünd dəri tonu',
    '🤜🏿' => 'sağa yönələn yumruq: tünd dəri tonu',
    '👏🏻' => 'əl çalan əllər: açıq dəri tonu',
    '👏🏼' => 'əl çalan əllər: orta-açıq dəri tonu',
    '👏🏽' => 'əl çalan əllər: orta dəri tonu',
    '👏🏾' => 'əl çalan əllər: orta-tünd dəri tonu',
    '👏🏿' => 'əl çalan əllər: tünd dəri tonu',
    '🙌🏻' => 'əllərini qaldıran adam: açıq dəri tonu',
    '🙌🏼' => 'əllərini qaldıran adam: orta-açıq dəri tonu',
    '🙌🏽' => 'əllərini qaldıran adam: orta dəri tonu',
    '🙌🏾' => 'əllərini qaldıran adam: orta-tünd dəri tonu',
    '🙌🏿' => 'əllərini qaldıran adam: tünd dəri tonu',
    '🫶🏻' => 'əldən ürək: açıq dəri tonu',
    '🫶🏼' => 'əldən ürək: orta-açıq dəri tonu',
    '🫶🏽' => 'əldən ürək: orta dəri tonu',
    '🫶🏾' => 'əldən ürək: orta-tünd dəri tonu',
    '🫶🏿' => 'əldən ürək: tünd dəri tonu',
    '👐🏻' => 'açıq əllər: açıq dəri tonu',
    '👐🏼' => 'açıq əllər: orta-açıq dəri tonu',
    '👐🏽' => 'açıq əllər: orta dəri tonu',
    '👐🏾' => 'açıq əllər: orta-tünd dəri tonu',
    '👐🏿' => 'açıq əllər: tünd dəri tonu',
    '🤲🏻' => 'əllər yuxarı: açıq dəri tonu',
    '🤲🏼' => 'əllər yuxarı: orta-açıq dəri tonu',
    '🤲🏽' => 'əllər yuxarı: orta dəri tonu',
    '🤲🏾' => 'əllər yuxarı: orta-tünd dəri tonu',
    '🤲🏿' => 'əllər yuxarı: tünd dəri tonu',
    '🤝🏻' => 'salamlaşmaq: açıq dəri tonu',
    '🤝🏼' => 'salamlaşmaq: orta-açıq dəri tonu',
    '🤝🏽' => 'salamlaşmaq: orta dəri tonu',
    '🤝🏾' => 'salamlaşmaq: orta-tünd dəri tonu',
    '🤝🏿' => 'salamlaşmaq: tünd dəri tonu',
    '🙏🏻' => 'qatlanmış əllər: açıq dəri tonu',
    '🙏🏼' => 'qatlanmış əllər: orta-açıq dəri tonu',
    '🙏🏽' => 'qatlanmış əllər: orta dəri tonu',
    '🙏🏾' => 'qatlanmış əllər: orta-tünd dəri tonu',
    '🙏🏿' => 'qatlanmış əllər: tünd dəri tonu',
    '✍🏻' => 'yazı əli: açıq dəri tonu',
    '✍🏼' => 'yazı əli: orta-açıq dəri tonu',
    '✍🏽' => 'yazı əli: orta dəri tonu',
    '✍🏾' => 'yazı əli: orta-tünd dəri tonu',
    '✍🏿' => 'yazı əli: tünd dəri tonu',
    '💅🏻' => 'dırnaq laklamaq: açıq dəri tonu',
    '💅🏼' => 'dırnaq laklamaq: orta-açıq dəri tonu',
    '💅🏽' => 'dırnaq laklamaq: orta dəri tonu',
    '💅🏾' => 'dırnaq laklamaq: orta-tünd dəri tonu',
    '💅🏿' => 'dırnaq laklamaq: tünd dəri tonu',
    '🤳🏻' => 'özçəkim: açıq dəri tonu',
    '🤳🏼' => 'özçəkim: orta-açıq dəri tonu',
    '🤳🏽' => 'özçəkim: orta dəri tonu',
    '🤳🏾' => 'özçəkim: orta-tünd dəri tonu',
    '🤳🏿' => 'özçəkim: tünd dəri tonu',
    '💪🏻' => 'qatlanmış əzələ: açıq dəri tonu',
    '💪🏼' => 'qatlanmış əzələ: orta-açıq dəri tonu',
    '💪🏽' => 'qatlanmış əzələ: orta dəri tonu',
    '💪🏾' => 'qatlanmış əzələ: orta-tünd dəri tonu',
    '💪🏿' => 'qatlanmış əzələ: tünd dəri tonu',
    '🦵🏻' => 'qıç: açıq dəri tonu',
    '🦵🏼' => 'qıç: orta-açıq dəri tonu',
    '🦵🏽' => 'qıç: orta dəri tonu',
    '🦵🏾' => 'qıç: orta-tünd dəri tonu',
    '🦵🏿' => 'qıç: tünd dəri tonu',
    '🦶🏻' => 'ayaq: açıq dəri tonu',
    '🦶🏼' => 'ayaq: orta-açıq dəri tonu',
    '🦶🏽' => 'ayaq: orta dəri tonu',
    '🦶🏾' => 'ayaq: orta-tünd dəri tonu',
    '🦶🏿' => 'ayaq: tünd dəri tonu',
    '👂🏻' => 'qulaq: açıq dəri tonu',
    '👂🏼' => 'qulaq: orta-açıq dəri tonu',
    '👂🏽' => 'qulaq: orta dəri tonu',
    '👂🏾' => 'qulaq: orta-tünd dəri tonu',
    '👂🏿' => 'qulaq: tünd dəri tonu',
    '🦻🏻' => 'eşitmə cihazlı qulaq: açıq dəri tonu',
    '🦻🏼' => 'eşitmə cihazlı qulaq: orta-açıq dəri tonu',
    '🦻🏽' => 'eşitmə cihazlı qulaq: orta dəri tonu',
    '🦻🏾' => 'eşitmə cihazlı qulaq: orta-tünd dəri tonu',
    '🦻🏿' => 'eşitmə cihazlı qulaq: tünd dəri tonu',
    '👃🏻' => 'burun: açıq dəri tonu',
    '👃🏼' => 'burun: orta-açıq dəri tonu',
    '👃🏽' => 'burun: orta dəri tonu',
    '👃🏾' => 'burun: orta-tünd dəri tonu',
    '👃🏿' => 'burun: tünd dəri tonu',
    '👶🏻' => 'körpə: açıq dəri tonu',
    '👶🏼' => 'körpə: orta-açıq dəri tonu',
    '👶🏽' => 'körpə: orta dəri tonu',
    '👶🏾' => 'körpə: orta-tünd dəri tonu',
    '👶🏿' => 'körpə: tünd dəri tonu',
    '🧒🏻' => 'uşaq: açıq dəri tonu',
    '🧒🏼' => 'uşaq: orta-açıq dəri tonu',
    '🧒🏽' => 'uşaq: orta dəri tonu',
    '🧒🏾' => 'uşaq: orta-tünd dəri tonu',
    '🧒🏿' => 'uşaq: tünd dəri tonu',
    '👦🏻' => 'oğlan: açıq dəri tonu',
    '👦🏼' => 'oğlan: orta-açıq dəri tonu',
    '👦🏽' => 'oğlan: orta dəri tonu',
    '👦🏾' => 'oğlan: orta-tünd dəri tonu',
    '👦🏿' => 'oğlan: tünd dəri tonu',
    '👧🏻' => 'qız uşağı: açıq dəri tonu',
    '👧🏼' => 'qız uşağı: orta-açıq dəri tonu',
    '👧🏽' => 'qız uşağı: orta dəri tonu',
    '👧🏾' => 'qız uşağı: orta-tünd dəri tonu',
    '👧🏿' => 'qız uşağı: tünd dəri tonu',
    '🧑🏻' => 'böyük: açıq dəri tonu',
    '🧑🏼' => 'böyük: orta-açıq dəri tonu',
    '🧑🏽' => 'böyük: orta dəri tonu',
    '🧑🏾' => 'böyük: orta-tünd dəri tonu',
    '🧑🏿' => 'böyük: tünd dəri tonu',
    '👱🏻' => 'sarı saçlı adam: açıq dəri tonu',
    '👱🏼' => 'sarı saçlı adam: orta-açıq dəri tonu',
    '👱🏽' => 'sarı saçlı adam: orta dəri tonu',
    '👱🏾' => 'sarı saçlı adam: orta-tünd dəri tonu',
    '👱🏿' => 'sarı saçlı adam: tünd dəri tonu',
    '👨🏻' => 'kişi: açıq dəri tonu',
    '👨🏼' => 'kişi: orta-açıq dəri tonu',
    '👨🏽' => 'kişi: orta dəri tonu',
    '👨🏾' => 'kişi: orta-tünd dəri tonu',
    '👨🏿' => 'kişi: tünd dəri tonu',
    '🧔🏻' => 'saqqallı şəxs: açıq dəri tonu',
    '🧔🏼' => 'saqqallı şəxs: orta-açıq dəri tonu',
    '🧔🏽' => 'saqqallı şəxs: orta dəri tonu',
    '🧔🏾' => 'saqqallı şəxs: orta-tünd dəri tonu',
    '🧔🏿' => 'saqqallı şəxs: tünd dəri tonu',
    '👩🏻' => 'qadın: açıq dəri tonu',
    '👩🏼' => 'qadın: orta-açıq dəri tonu',
    '👩🏽' => 'qadın: orta dəri tonu',
    '👩🏾' => 'qadın: orta-tünd dəri tonu',
    '👩🏿' => 'qadın: tünd dəri tonu',
    '🧓🏻' => 'yaşlı böyük: açıq dəri tonu',
    '🧓🏼' => 'yaşlı böyük: orta-açıq dəri tonu',
    '🧓🏽' => 'yaşlı böyük: orta dəri tonu',
    '🧓🏾' => 'yaşlı böyük: orta-tünd dəri tonu',
    '🧓🏿' => 'yaşlı böyük: tünd dəri tonu',
    '👴🏻' => 'yaşlı kişi: açıq dəri tonu',
    '👴🏼' => 'yaşlı kişi: orta-açıq dəri tonu',
    '👴🏽' => 'yaşlı kişi: orta dəri tonu',
    '👴🏾' => 'yaşlı kişi: orta-tünd dəri tonu',
    '👴🏿' => 'yaşlı kişi: tünd dəri tonu',
    '👵🏻' => 'yaşlı qadın: açıq dəri tonu',
    '👵🏼' => 'yaşlı qadın: orta-açıq dəri tonu',
    '👵🏽' => 'yaşlı qadın: orta dəri tonu',
    '👵🏾' => 'yaşlı qadın: orta-tünd dəri tonu',
    '👵🏿' => 'yaşlı qadın: tünd dəri tonu',
    '🙍🏻' => 'qaşqabaqlı adam: açıq dəri tonu',
    '🙍🏼' => 'qaşqabaqlı adam: orta-açıq dəri tonu',
    '🙍🏽' => 'qaşqabaqlı adam: orta dəri tonu',
    '🙍🏾' => 'qaşqabaqlı adam: orta-tünd dəri tonu',
    '🙍🏿' => 'qaşqabaqlı adam: tünd dəri tonu',
    '🙎🏻' => 'acıq edən adam: açıq dəri tonu',
    '🙎🏼' => 'acıq edən adam: orta-açıq dəri tonu',
    '🙎🏽' => 'acıq edən adam: orta dəri tonu',
    '🙎🏾' => 'acıq edən adam: orta-tünd dəri tonu',
    '🙎🏿' => 'acıq edən adam: tünd dəri tonu',
    '🙅🏻' => 'yox jesti: açıq dəri tonu',
    '🙅🏼' => 'yox jesti: orta-açıq dəri tonu',
    '🙅🏽' => 'yox jesti: orta dəri tonu',
    '🙅🏾' => 'yox jesti: orta-tünd dəri tonu',
    '🙅🏿' => 'yox jesti: tünd dəri tonu',
    '🙆🏻' => 'ok jesti: açıq dəri tonu',
    '🙆🏼' => 'ok jesti: orta-açıq dəri tonu',
    '🙆🏽' => 'ok jesti: orta dəri tonu',
    '🙆🏾' => 'ok jesti: orta-tünd dəri tonu',
    '🙆🏿' => 'ok jesti: tünd dəri tonu',
    '💁🏻' => 'məlumat verən şəxs: açıq dəri tonu',
    '💁🏼' => 'məlumat verən şəxs: orta-açıq dəri tonu',
    '💁🏽' => 'məlumat verən şəxs: orta dəri tonu',
    '💁🏾' => 'məlumat verən şəxs: orta-tünd dəri tonu',
    '💁🏿' => 'məlumat verən şəxs: tünd dəri tonu',
    '🙋🏻' => 'əlini qaldıran xoşbəxt adam: açıq dəri tonu',
    '🙋🏼' => 'əlini qaldıran xoşbəxt adam: orta-açıq dəri tonu',
    '🙋🏽' => 'əlini qaldıran xoşbəxt adam: orta dəri tonu',
    '🙋🏾' => 'əlini qaldıran xoşbəxt adam: orta-tünd dəri tonu',
    '🙋🏿' => 'əlini qaldıran xoşbəxt adam: tünd dəri tonu',
    '🧏🏻' => 'kar şəxs: açıq dəri tonu',
    '🧏🏼' => 'kar şəxs: orta-açıq dəri tonu',
    '🧏🏽' => 'kar şəxs: orta dəri tonu',
    '🧏🏾' => 'kar şəxs: orta-tünd dəri tonu',
    '🧏🏿' => 'kar şəxs: tünd dəri tonu',
    '🙇🏻' => 'tənzim edən adam: açıq dəri tonu',
    '🙇🏼' => 'tənzim edən adam: orta-açıq dəri tonu',
    '🙇🏽' => 'tənzim edən adam: orta dəri tonu',
    '🙇🏾' => 'tənzim edən adam: orta-tünd dəri tonu',
    '🙇🏿' => 'tənzim edən adam: tünd dəri tonu',
    '🤦🏻' => 'inanmaq olmur: açıq dəri tonu',
    '🤦🏼' => 'inanmaq olmur: orta-açıq dəri tonu',
    '🤦🏽' => 'inanmaq olmur: orta dəri tonu',
    '🤦🏾' => 'inanmaq olmur: orta-tünd dəri tonu',
    '🤦🏿' => 'inanmaq olmur: tünd dəri tonu',
    '🤷🏻' => 'çiynini çəkmək: açıq dəri tonu',
    '🤷🏼' => 'çiynini çəkmək: orta-açıq dəri tonu',
    '🤷🏽' => 'çiynini çəkmək: orta dəri tonu',
    '🤷🏾' => 'çiynini çəkmək: orta-tünd dəri tonu',
    '🤷🏿' => 'çiynini çəkmək: tünd dəri tonu',
    '👮🏻' => 'polis məmuru: açıq dəri tonu',
    '👮🏼' => 'polis məmuru: orta-açıq dəri tonu',
    '👮🏽' => 'polis məmuru: orta dəri tonu',
    '👮🏾' => 'polis məmuru: orta-tünd dəri tonu',
    '👮🏿' => 'polis məmuru: tünd dəri tonu',
    '🕵🏻' => 'detektiv: açıq dəri tonu',
    '🕵🏼' => 'detektiv: orta-açıq dəri tonu',
    '🕵🏽' => 'detektiv: orta dəri tonu',
    '🕵🏾' => 'detektiv: orta-tünd dəri tonu',
    '🕵🏿' => 'detektiv: tünd dəri tonu',
    '💂🏻' => 'keşikçi: açıq dəri tonu',
    '💂🏼' => 'keşikçi: orta-açıq dəri tonu',
    '💂🏽' => 'keşikçi: orta dəri tonu',
    '💂🏾' => 'keşikçi: orta-tünd dəri tonu',
    '💂🏿' => 'keşikçi: tünd dəri tonu',
    '🥷🏻' => 'nindza: açıq dəri tonu',
    '🥷🏼' => 'nindza: orta-açıq dəri tonu',
    '🥷🏽' => 'nindza: orta dəri tonu',
    '🥷🏾' => 'nindza: orta-tünd dəri tonu',
    '🥷🏿' => 'nindza: tünd dəri tonu',
    '👷🏻' => 'tikinti işçisi: açıq dəri tonu',
    '👷🏼' => 'tikinti işçisi: orta-açıq dəri tonu',
    '👷🏽' => 'tikinti işçisi: orta dəri tonu',
    '👷🏾' => 'tikinti işçisi: orta-tünd dəri tonu',
    '👷🏿' => 'tikinti işçisi: tünd dəri tonu',
    '🫅🏻' => 'taclı adam: açıq dəri tonu',
    '🫅🏼' => 'taclı adam: orta-açıq dəri tonu',
    '🫅🏽' => 'taclı adam: orta dəri tonu',
    '🫅🏾' => 'taclı adam: orta-tünd dəri tonu',
    '🫅🏿' => 'taclı adam: tünd dəri tonu',
    '🤴🏻' => 'oğlan şahzadə: açıq dəri tonu',
    '🤴🏼' => 'oğlan şahzadə: orta-açıq dəri tonu',
    '🤴🏽' => 'oğlan şahzadə: orta dəri tonu',
    '🤴🏾' => 'oğlan şahzadə: orta-tünd dəri tonu',
    '🤴🏿' => 'oğlan şahzadə: tünd dəri tonu',
    '👸🏻' => 'qız şahzadə: açıq dəri tonu',
    '👸🏼' => 'qız şahzadə: orta-açıq dəri tonu',
    '👸🏽' => 'qız şahzadə: orta dəri tonu',
    '👸🏾' => 'qız şahzadə: orta-tünd dəri tonu',
    '👸🏿' => 'qız şahzadə: tünd dəri tonu',
    '👳🏻' => 'çalmalı kişi: açıq dəri tonu',
    '👳🏼' => 'çalmalı kişi: orta-açıq dəri tonu',
    '👳🏽' => 'çalmalı kişi: orta dəri tonu',
    '👳🏾' => 'çalmalı kişi: orta-tünd dəri tonu',
    '👳🏿' => 'çalmalı kişi: tünd dəri tonu',
    '👲🏻' => 'çin kepkalı kişi: açıq dəri tonu',
    '👲🏼' => 'çin kepkalı kişi: orta-açıq dəri tonu',
    '👲🏽' => 'çin kepkalı kişi: orta dəri tonu',
    '👲🏾' => 'çin kepkalı kişi: orta-tünd dəri tonu',
    '👲🏿' => 'çin kepkalı kişi: tünd dəri tonu',
    '🧕🏻' => 'şərfli qadın: açıq dəri tonu',
    '🧕🏼' => 'şərfli qadın: orta-açıq dəri tonu',
    '🧕🏽' => 'şərfli qadın: orta dəri tonu',
    '🧕🏾' => 'şərfli qadın: orta-tünd dəri tonu',
    '🧕🏿' => 'şərfli qadın: tünd dəri tonu',
    '🤵🏻' => 'smokinqli şəxs: açıq dəri tonu',
    '🤵🏼' => 'smokinqli şəxs: orta-açıq dəri tonu',
    '🤵🏽' => 'smokinqli şəxs: orta dəri tonu',
    '🤵🏾' => 'smokinqli şəxs: orta-tünd dəri tonu',
    '🤵🏿' => 'smokinqli şəxs: tünd dəri tonu',
    '👰🏻' => 'duvaqlı şəxs: açıq dəri tonu',
    '👰🏼' => 'duvaqlı şəxs: orta-açıq dəri tonu',
    '👰🏽' => 'duvaqlı şəxs: orta dəri tonu',
    '👰🏾' => 'duvaqlı şəxs: orta-tünd dəri tonu',
    '👰🏿' => 'duvaqlı şəxs: tünd dəri tonu',
    '🤰🏻' => 'hamilə qadın: açıq dəri tonu',
    '🤰🏼' => 'hamilə qadın: orta-açıq dəri tonu',
    '🤰🏽' => 'hamilə qadın: orta dəri tonu',
    '🤰🏾' => 'hamilə qadın: orta-tünd dəri tonu',
    '🤰🏿' => 'hamilə qadın: tünd dəri tonu',
    '🫃🏻' => 'hamilə kişi: açıq dəri tonu',
    '🫃🏼' => 'hamilə kişi: orta-açıq dəri tonu',
    '🫃🏽' => 'hamilə kişi: orta dəri tonu',
    '🫃🏾' => 'hamilə kişi: orta-tünd dəri tonu',
    '🫃🏿' => 'hamilə kişi: tünd dəri tonu',
    '🫄🏻' => 'hamilə adam: açıq dəri tonu',
    '🫄🏼' => 'hamilə adam: orta-açıq dəri tonu',
    '🫄🏽' => 'hamilə adam: orta dəri tonu',
    '🫄🏾' => 'hamilə adam: orta-tünd dəri tonu',
    '🫄🏿' => 'hamilə adam: tünd dəri tonu',
    '🤱🏻' => 'uşaq əmizdirmə: açıq dəri tonu',
    '🤱🏼' => 'uşaq əmizdirmə: orta-açıq dəri tonu',
    '🤱🏽' => 'uşaq əmizdirmə: orta dəri tonu',
    '🤱🏾' => 'uşaq əmizdirmə: orta-tünd dəri tonu',
    '🤱🏿' => 'uşaq əmizdirmə: tünd dəri tonu',
    '👼🏻' => 'körpə mələk: açıq dəri tonu',
    '👼🏼' => 'körpə mələk: orta-açıq dəri tonu',
    '👼🏽' => 'körpə mələk: orta dəri tonu',
    '👼🏾' => 'körpə mələk: orta-tünd dəri tonu',
    '👼🏿' => 'körpə mələk: tünd dəri tonu',
    '🎅🏻' => 'Santa Klaus: açıq dəri tonu',
    '🎅🏼' => 'Santa Klaus: orta-açıq dəri tonu',
    '🎅🏽' => 'Santa Klaus: orta dəri tonu',
    '🎅🏾' => 'Santa Klaus: orta-tünd dəri tonu',
    '🎅🏿' => 'Santa Klaus: tünd dəri tonu',
    '🤶🏻' => 'xanım Klaus: açıq dəri tonu',
    '🤶🏼' => 'xanım Klaus: orta-açıq dəri tonu',
    '🤶🏽' => 'xanım Klaus: orta dəri tonu',
    '🤶🏾' => 'xanım Klaus: orta-tünd dəri tonu',
    '🤶🏿' => 'xanım Klaus: tünd dəri tonu',
    '🦸🏻' => 'superqəhrəman: açıq dəri tonu',
    '🦸🏼' => 'superqəhrəman: orta-açıq dəri tonu',
    '🦸🏽' => 'superqəhrəman: orta dəri tonu',
    '🦸🏾' => 'superqəhrəman: orta-tünd dəri tonu',
    '🦸🏿' => 'superqəhrəman: tünd dəri tonu',
    '🦹🏻' => 'supercani: açıq dəri tonu',
    '🦹🏼' => 'supercani: orta-açıq dəri tonu',
    '🦹🏽' => 'supercani: orta dəri tonu',
    '🦹🏾' => 'supercani: orta-tünd dəri tonu',
    '🦹🏿' => 'supercani: tünd dəri tonu',
    '🧙🏻' => 'maq: açıq dəri tonu',
    '🧙🏼' => 'maq: orta-açıq dəri tonu',
    '🧙🏽' => 'maq: orta dəri tonu',
    '🧙🏾' => 'maq: orta-tünd dəri tonu',
    '🧙🏿' => 'maq: tünd dəri tonu',
    '🧚🏻' => 'pəri: açıq dəri tonu',
    '🧚🏼' => 'pəri: orta-açıq dəri tonu',
    '🧚🏽' => 'pəri: orta dəri tonu',
    '🧚🏾' => 'pəri: orta-tünd dəri tonu',
    '🧚🏿' => 'pəri: tünd dəri tonu',
    '🧛🏻' => 'vampir: açıq dəri tonu',
    '🧛🏼' => 'vampir: orta-açıq dəri tonu',
    '🧛🏽' => 'vampir: orta dəri tonu',
    '🧛🏾' => 'vampir: orta-tünd dəri tonu',
    '🧛🏿' => 'vampir: tünd dəri tonu',
    '🧜🏻' => 'dəniz adamı: açıq dəri tonu',
    '🧜🏼' => 'dəniz adamı: orta-açıq dəri tonu',
    '🧜🏽' => 'dəniz adamı: orta dəri tonu',
    '🧜🏾' => 'dəniz adamı: orta-tünd dəri tonu',
    '🧜🏿' => 'dəniz adamı: tünd dəri tonu',
    '🧝🏻' => 'elf: açıq dəri tonu',
    '🧝🏼' => 'elf: orta-açıq dəri tonu',
    '🧝🏽' => 'elf: orta dəri tonu',
    '🧝🏾' => 'elf: orta-tünd dəri tonu',
    '🧝🏿' => 'elf: tünd dəri tonu',
    '💆🏻' => 'üz masajı: açıq dəri tonu',
    '💆🏼' => 'üz masajı: orta-açıq dəri tonu',
    '💆🏽' => 'üz masajı: orta dəri tonu',
    '💆🏾' => 'üz masajı: orta-tünd dəri tonu',
    '💆🏿' => 'üz masajı: tünd dəri tonu',
    '💇🏻' => 'saç kəsimi: açıq dəri tonu',
    '💇🏼' => 'saç kəsimi: orta-açıq dəri tonu',
    '💇🏽' => 'saç kəsimi: orta dəri tonu',
    '💇🏾' => 'saç kəsimi: orta-tünd dəri tonu',
    '💇🏿' => 'saç kəsimi: tünd dəri tonu',
    '🚶🏻' => 'piyada: açıq dəri tonu',
    '🚶🏼' => 'piyada: orta-açıq dəri tonu',
    '🚶🏽' => 'piyada: orta dəri tonu',
    '🚶🏾' => 'piyada: orta-tünd dəri tonu',
    '🚶🏿' => 'piyada: tünd dəri tonu',
    '🧍🏻' => 'duran adam: açıq dəri tonu',
    '🧍🏼' => 'duran adam: orta-açıq dəri tonu',
    '🧍🏽' => 'duran adam: orta dəri tonu',
    '🧍🏾' => 'duran adam: orta-tünd dəri tonu',
    '🧍🏿' => 'duran adam: tünd dəri tonu',
    '🧎🏻' => 'dizi üstündə adam: açıq dəri tonu',
    '🧎🏼' => 'dizi üstündə adam: orta-açıq dəri tonu',
    '🧎🏽' => 'dizi üstündə adam: orta dəri tonu',
    '🧎🏾' => 'dizi üstündə adam: orta-tünd dəri tonu',
    '🧎🏿' => 'dizi üstündə adam: tünd dəri tonu',
    '🏃🏻' => 'atlet: açıq dəri tonu',
    '🏃🏼' => 'atlet: orta-açıq dəri tonu',
    '🏃🏽' => 'atlet: orta dəri tonu',
    '🏃🏾' => 'atlet: orta-tünd dəri tonu',
    '🏃🏿' => 'atlet: tünd dəri tonu',
    '💃🏻' => 'rəqs edən qadın: açıq dəri tonu',
    '💃🏼' => 'rəqs edən qadın: orta-açıq dəri tonu',
    '💃🏽' => 'rəqs edən qadın: orta dəri tonu',
    '💃🏾' => 'rəqs edən qadın: orta-tünd dəri tonu',
    '💃🏿' => 'rəqs edən qadın: tünd dəri tonu',
    '🕺🏻' => 'əylənən kişilər: açıq dəri tonu',
    '🕺🏼' => 'əylənən kişilər: orta-açıq dəri tonu',
    '🕺🏽' => 'əylənən kişilər: orta dəri tonu',
    '🕺🏾' => 'əylənən kişilər: orta-tünd dəri tonu',
    '🕺🏿' => 'əylənən kişilər: tünd dəri tonu',
    '🕴🏻' => 'işgüzar kostyumlu kişi: açıq dəri tonu',
    '🕴🏼' => 'işgüzar kostyumlu kişi: orta-açıq dəri tonu',
    '🕴🏽' => 'işgüzar kostyumlu kişi: orta dəri tonu',
    '🕴🏾' => 'işgüzar kostyumlu kişi: orta-tünd dəri tonu',
    '🕴🏿' => 'işgüzar kostyumlu kişi: tünd dəri tonu',
    '👯🏻' => 'şənlənən qadınlar: açıq dəri tonu',
    '👯🏼' => 'şənlənən qadınlar: orta-açıq dəri tonu',
    '👯🏽' => 'şənlənən qadınlar: orta dəri tonu',
    '👯🏾' => 'şənlənən qadınlar: orta-tünd dəri tonu',
    '👯🏿' => 'şənlənən qadınlar: tünd dəri tonu',
    '🧖🏻' => 'buxarlı otaqda adam: açıq dəri tonu',
    '🧖🏼' => 'buxarlı otaqda adam: orta-açıq dəri tonu',
    '🧖🏽' => 'buxarlı otaqda adam: orta dəri tonu',
    '🧖🏾' => 'buxarlı otaqda adam: orta-tünd dəri tonu',
    '🧖🏿' => 'buxarlı otaqda adam: tünd dəri tonu',
    '🧗🏻' => 'dırmaşan adam: açıq dəri tonu',
    '🧗🏼' => 'dırmaşan adam: orta-açıq dəri tonu',
    '🧗🏽' => 'dırmaşan adam: orta dəri tonu',
    '🧗🏾' => 'dırmaşan adam: orta-tünd dəri tonu',
    '🧗🏿' => 'dırmaşan adam: tünd dəri tonu',
    '🏇🏻' => 'at yarışı: açıq dəri tonu',
    '🏇🏼' => 'at yarışı: orta-açıq dəri tonu',
    '🏇🏽' => 'at yarışı: orta dəri tonu',
    '🏇🏾' => 'at yarışı: orta-tünd dəri tonu',
    '🏇🏿' => 'at yarışı: tünd dəri tonu',
    '🏂🏻' => 'snouborder: açıq dəri tonu',
    '🏂🏼' => 'snouborder: orta-açıq dəri tonu',
    '🏂🏽' => 'snouborder: orta dəri tonu',
    '🏂🏾' => 'snouborder: orta-tünd dəri tonu',
    '🏂🏿' => 'snouborder: tünd dəri tonu',
    '🏌🏻' => 'qolf oynayan: açıq dəri tonu',
    '🏌🏼' => 'qolf oynayan: orta-açıq dəri tonu',
    '🏌🏽' => 'qolf oynayan: orta dəri tonu',
    '🏌🏾' => 'qolf oynayan: orta-tünd dəri tonu',
    '🏌🏿' => 'qolf oynayan: tünd dəri tonu',
    '🏄🏻' => 'sörfer: açıq dəri tonu',
    '🏄🏼' => 'sörfer: orta-açıq dəri tonu',
    '🏄🏽' => 'sörfer: orta dəri tonu',
    '🏄🏾' => 'sörfer: orta-tünd dəri tonu',
    '🏄🏿' => 'sörfer: tünd dəri tonu',
    '🚣🏻' => 'avarçəkmə qayığı: açıq dəri tonu',
    '🚣🏼' => 'avarçəkmə qayığı: orta-açıq dəri tonu',
    '🚣🏽' => 'avarçəkmə qayığı: orta dəri tonu',
    '🚣🏾' => 'avarçəkmə qayığı: orta-tünd dəri tonu',
    '🚣🏿' => 'avarçəkmə qayığı: tünd dəri tonu',
    '🏊🏻' => 'üzgüçü: açıq dəri tonu',
    '🏊🏼' => 'üzgüçü: orta-açıq dəri tonu',
    '🏊🏽' => 'üzgüçü: orta dəri tonu',
    '🏊🏾' => 'üzgüçü: orta-tünd dəri tonu',
    '🏊🏿' => 'üzgüçü: tünd dəri tonu',
    '⛹🏻' => 'toplu adam: açıq dəri tonu',
    '⛹🏼' => 'toplu adam: orta-açıq dəri tonu',
    '⛹🏽' => 'toplu adam: orta dəri tonu',
    '⛹🏾' => 'toplu adam: orta-tünd dəri tonu',
    '⛹🏿' => 'toplu adam: tünd dəri tonu',
    '🏋🏻' => 'ştanqçı: açıq dəri tonu',
    '🏋🏼' => 'ştanqçı: orta-açıq dəri tonu',
    '🏋🏽' => 'ştanqçı: orta dəri tonu',
    '🏋🏾' => 'ştanqçı: orta-tünd dəri tonu',
    '🏋🏿' => 'ştanqçı: tünd dəri tonu',
    '🚴🏻' => 'velosipedçi: açıq dəri tonu',
    '🚴🏼' => 'velosipedçi: orta-açıq dəri tonu',
    '🚴🏽' => 'velosipedçi: orta dəri tonu',
    '🚴🏾' => 'velosipedçi: orta-tünd dəri tonu',
    '🚴🏿' => 'velosipedçi: tünd dəri tonu',
    '🚵🏻' => 'dağ velosipedçisi: açıq dəri tonu',
    '🚵🏼' => 'dağ velosipedçisi: orta-açıq dəri tonu',
    '🚵🏽' => 'dağ velosipedçisi: orta dəri tonu',
    '🚵🏾' => 'dağ velosipedçisi: orta-tünd dəri tonu',
    '🚵🏿' => 'dağ velosipedçisi: tünd dəri tonu',
    '🤸🏻' => 'akrobatik hərəkət: açıq dəri tonu',
    '🤸🏼' => 'akrobatik hərəkət: orta-açıq dəri tonu',
    '🤸🏽' => 'akrobatik hərəkət: orta dəri tonu',
    '🤸🏾' => 'akrobatik hərəkət: orta-tünd dəri tonu',
    '🤸🏿' => 'akrobatik hərəkət: tünd dəri tonu',
    '🤼🏻' => 'güləş: açıq dəri tonu',
    '🤼🏼' => 'güləş: orta-açıq dəri tonu',
    '🤼🏽' => 'güləş: orta dəri tonu',
    '🤼🏾' => 'güləş: orta-tünd dəri tonu',
    '🤼🏿' => 'güləş: tünd dəri tonu',
    '🤽🏻' => 'su polosu: açıq dəri tonu',
    '🤽🏼' => 'su polosu: orta-açıq dəri tonu',
    '🤽🏽' => 'su polosu: orta dəri tonu',
    '🤽🏾' => 'su polosu: orta-tünd dəri tonu',
    '🤽🏿' => 'su polosu: tünd dəri tonu',
    '🤾🏻' => 'həndbol: açıq dəri tonu',
    '🤾🏼' => 'həndbol: orta-açıq dəri tonu',
    '🤾🏽' => 'həndbol: orta dəri tonu',
    '🤾🏾' => 'həndbol: orta-tünd dəri tonu',
    '🤾🏿' => 'həndbol: tünd dəri tonu',
    '🤹🏻' => 'janqlyor: açıq dəri tonu',
    '🤹🏼' => 'janqlyor: orta-açıq dəri tonu',
    '🤹🏽' => 'janqlyor: orta dəri tonu',
    '🤹🏾' => 'janqlyor: orta-tünd dəri tonu',
    '🤹🏿' => 'janqlyor: tünd dəri tonu',
    '🧘🏻' => 'lotus pozisiyasında adam: açıq dəri tonu',
    '🧘🏼' => 'lotus pozisiyasında adam: orta-açıq dəri tonu',
    '🧘🏽' => 'lotus pozisiyasında adam: orta dəri tonu',
    '🧘🏾' => 'lotus pozisiyasında adam: orta-tünd dəri tonu',
    '🧘🏿' => 'lotus pozisiyasında adam: tünd dəri tonu',
    '🛀🏻' => 'vanna qəbul edən adam: açıq dəri tonu',
    '🛀🏼' => 'vanna qəbul edən adam: orta-açıq dəri tonu',
    '🛀🏽' => 'vanna qəbul edən adam: orta dəri tonu',
    '🛀🏾' => 'vanna qəbul edən adam: orta-tünd dəri tonu',
    '🛀🏿' => 'vanna qəbul edən adam: tünd dəri tonu',
    '🛌🏻' => 'yataqda uzanmış adam: açıq dəri tonu',
    '🛌🏼' => 'yataqda uzanmış adam: orta-açıq dəri tonu',
    '🛌🏽' => 'yataqda uzanmış adam: orta dəri tonu',
    '🛌🏾' => 'yataqda uzanmış adam: orta-tünd dəri tonu',
    '🛌🏿' => 'yataqda uzanmış adam: tünd dəri tonu',
    '👭🏻' => 'əl-ələ tutan iki qadın: açıq dəri tonu',
    '👭🏼' => 'əl-ələ tutan iki qadın: orta-açıq dəri tonu',
    '👭🏽' => 'əl-ələ tutan iki qadın: orta dəri tonu',
    '👭🏾' => 'əl-ələ tutan iki qadın: orta-tünd dəri tonu',
    '👭🏿' => 'əl-ələ tutan iki qadın: tünd dəri tonu',
    '👫🏻' => 'əl-ələ tutan kişi və qadın: açıq dəri tonu',
    '👫🏼' => 'əl-ələ tutan kişi və qadın: orta-açıq dəri tonu',
    '👫🏽' => 'əl-ələ tutan kişi və qadın: orta dəri tonu',
    '👫🏾' => 'əl-ələ tutan kişi və qadın: orta-tünd dəri tonu',
    '👫🏿' => 'əl-ələ tutan kişi və qadın: tünd dəri tonu',
    '👬🏻' => 'əl-ələ tutan iki kişi: açıq dəri tonu',
    '👬🏼' => 'əl-ələ tutan iki kişi: orta-açıq dəri tonu',
    '👬🏽' => 'əl-ələ tutan iki kişi: orta dəri tonu',
    '👬🏾' => 'əl-ələ tutan iki kişi: orta-tünd dəri tonu',
    '👬🏿' => 'əl-ələ tutan iki kişi: tünd dəri tonu',
    '💏🏻' => 'öpüş: açıq dəri tonu',
    '💏🏼' => 'öpüş: orta-açıq dəri tonu',
    '💏🏽' => 'öpüş: orta dəri tonu',
    '💏🏾' => 'öpüş: orta-tünd dəri tonu',
    '💏🏿' => 'öpüş: tünd dəri tonu',
    '💑🏻' => 'ürəkli cütlük: açıq dəri tonu',
    '💑🏼' => 'ürəkli cütlük: orta-açıq dəri tonu',
    '💑🏽' => 'ürəkli cütlük: orta dəri tonu',
    '💑🏾' => 'ürəkli cütlük: orta-tünd dəri tonu',
    '💑🏿' => 'ürəkli cütlük: tünd dəri tonu',
    '🇦🇨' => 'bayraq: Askenson adası',
    '🇦🇩' => 'bayraq: Andorra',
    '🇦🇪' => 'bayraq: Birləşmiş Ərəb Əmirlikləri',
    '🇦🇫' => 'bayraq: Əfqanıstan',
    '🇦🇬' => 'bayraq: Antiqua və Barbuda',
    '🇦🇮' => 'bayraq: Angilya',
    '🇦🇱' => 'bayraq: Albaniya',
    '🇦🇲' => 'bayraq: Ermənistan',
    '🇦🇴' => 'bayraq: Anqola',
    '🇦🇶' => 'bayraq: Antarktika',
    '🇦🇷' => 'bayraq: Argentina',
    '🇦🇸' => 'bayraq: Amerika Samoası',
    '🇦🇹' => 'bayraq: Avstriya',
    '🇦🇺' => 'bayraq: Avstraliya',
    '🇦🇼' => 'bayraq: Aruba',
    '🇦🇽' => 'bayraq: Aland adaları',
    '🇦🇿' => 'bayraq: Azərbaycan',
    '🇧🇦' => 'bayraq: Bosniya və Herseqovina',
    '🇧🇧' => 'bayraq: Barbados',
    '🇧🇩' => 'bayraq: Banqladeş',
    '🇧🇪' => 'bayraq: Belçika',
    '🇧🇫' => 'bayraq: Burkina Faso',
    '🇧🇬' => 'bayraq: Bolqarıstan',
    '🇧🇭' => 'bayraq: Bəhreyn',
    '🇧🇮' => 'bayraq: Burundi',
    '🇧🇯' => 'bayraq: Benin',
    '🇧🇱' => 'bayraq: Sent-Bartelemi',
    '🇧🇲' => 'bayraq: Bermud adaları',
    '🇧🇳' => 'bayraq: Bruney',
    '🇧🇴' => 'bayraq: Boliviya',
    '🇧🇶' => 'bayraq: Karib Niderlandı',
    '🇧🇷' => 'bayraq: Braziliya',
    '🇧🇸' => 'bayraq: Baham adaları',
    '🇧🇹' => 'bayraq: Butan',
    '🇧🇻' => 'bayraq: Buve adası',
    '🇧🇼' => 'bayraq: Botsvana',
    '🇧🇾' => 'bayraq: Belarus',
    '🇧🇿' => 'bayraq: Beliz',
    '🇨🇦' => 'bayraq: Kanada',
    '🇨🇨' => 'bayraq: Kokos (Kilinq) adaları',
    '🇨🇩' => 'bayraq: Konqo - Kinşasa',
    '🇨🇫' => 'bayraq: Mərkəzi Afrika Respublikası',
    '🇨🇬' => 'bayraq: Konqo - Brazzavil',
    '🇨🇭' => 'bayraq: İsveçrə',
    '🇨🇮' => 'bayraq: Kotd’ivuar',
    '🇨🇰' => 'bayraq: Kuk adaları',
    '🇨🇱' => 'bayraq: Çili',
    '🇨🇲' => 'bayraq: Kamerun',
    '🇨🇳' => 'bayraq: Çin',
    '🇨🇴' => 'bayraq: Kolumbiya',
    '🇨🇵' => 'bayraq: Klipperton adası',
    '🇨🇶' => 'bayraq: sark (ingilis dili) dialekti',
    '🇨🇷' => 'bayraq: Kosta Rika',
    '🇨🇺' => 'bayraq: Kuba',
    '🇨🇻' => 'bayraq: Kabo-Verde',
    '🇨🇼' => 'bayraq: Kurasao',
    '🇨🇽' => 'bayraq: Milad adası',
    '🇨🇾' => 'bayraq: Kipr',
    '🇨🇿' => 'bayraq: Çexiya',
    '🇩🇪' => 'bayraq: Almaniya',
    '🇩🇬' => 'bayraq: Dieqo Qarsiya',
    '🇩🇯' => 'bayraq: Cibuti',
    '🇩🇰' => 'bayraq: Danimarka',
    '🇩🇲' => 'bayraq: Dominika',
    '🇩🇴' => 'bayraq: Dominikan Respublikası',
    '🇩🇿' => 'bayraq: Əlcəzair',
    '🇪🇦' => 'bayraq: Seuta və Melilya',
    '🇪🇨' => 'bayraq: Ekvador',
    '🇪🇪' => 'bayraq: Estoniya',
    '🇪🇬' => 'bayraq: Misir',
    '🇪🇭' => 'bayraq: Qərbi Saxara',
    '🇪🇷' => 'bayraq: Eritreya',
    '🇪🇸' => 'bayraq: İspaniya',
    '🇪🇹' => 'bayraq: Efiopiya',
    '🇪🇺' => 'bayraq: Avropa Birliyi',
    '🇫🇮' => 'bayraq: Finlandiya',
    '🇫🇯' => 'bayraq: Fici',
    '🇫🇰' => 'bayraq: Folklend adaları',
    '🇫🇲' => 'bayraq: Mikroneziya',
    '🇫🇴' => 'bayraq: Farer adaları',
    '🇫🇷' => 'bayraq: Fransa',
    '🇬🇦' => 'bayraq: Qabon',
    '🇬🇧' => 'bayraq: Birləşmiş Krallıq',
    '🇬🇩' => 'bayraq: Qrenada',
    '🇬🇪' => 'bayraq: Gürcüstan',
    '🇬🇫' => 'bayraq: Fransa Qvianası',
    '🇬🇬' => 'bayraq: Gernsi',
    '🇬🇭' => 'bayraq: Qana',
    '🇬🇮' => 'bayraq: Cəbəllütariq',
    '🇬🇱' => 'bayraq: Qrenlandiya',
    '🇬🇲' => 'bayraq: Qambiya',
    '🇬🇳' => 'bayraq: Qvineya',
    '🇬🇵' => 'bayraq: Qvadelupa',
    '🇬🇶' => 'bayraq: Ekvatorial Qvineya',
    '🇬🇷' => 'bayraq: Yunanıstan',
    '🇬🇸' => 'bayraq: Cənubi Corciya və Cənubi Sendviç adaları',
    '🇬🇹' => 'bayraq: Qvatemala',
    '🇬🇺' => 'bayraq: Quam',
    '🇬🇼' => 'bayraq: Qvineya-Bisau',
    '🇬🇾' => 'bayraq: Qayana',
    '🇭🇰' => 'bayraq: Honq Konq Xüsusi İnzibati Rayonu Çin',
    '🇭🇲' => 'bayraq: Herd və Makdonald adaları',
    '🇭🇳' => 'bayraq: Honduras',
    '🇭🇷' => 'bayraq: Xorvatiya',
    '🇭🇹' => 'bayraq: Haiti',
    '🇭🇺' => 'bayraq: Macarıstan',
    '🇮🇨' => 'bayraq: Kanar adaları',
    '🇮🇩' => 'bayraq: İndoneziya',
    '🇮🇪' => 'bayraq: İrlandiya',
    '🇮🇱' => 'bayraq: İsrail',
    '🇮🇲' => 'bayraq: Men adası',
    '🇮🇳' => 'bayraq: Hindistan',
    '🇮🇴' => 'bayraq: Britaniyanın Hind Okeanı Ərazisi',
    '🇮🇶' => 'bayraq: İraq',
    '🇮🇷' => 'bayraq: İran',
    '🇮🇸' => 'bayraq: İslandiya',
    '🇮🇹' => 'bayraq: İtaliya',
    '🇯🇪' => 'bayraq: Cersi',
    '🇯🇲' => 'bayraq: Yamayka',
    '🇯🇴' => 'bayraq: İordaniya',
    '🇯🇵' => 'bayraq: Yaponiya',
    '🇰🇪' => 'bayraq: Keniya',
    '🇰🇬' => 'bayraq: Qırğızıstan',
    '🇰🇭' => 'bayraq: Kamboca',
    '🇰🇮' => 'bayraq: Kiribati',
    '🇰🇲' => 'bayraq: Komor adaları',
    '🇰🇳' => 'bayraq: Sent-Kits və Nevis',
    '🇰🇵' => 'bayraq: Şimali Koreya',
    '🇰🇷' => 'bayraq: Cənubi Koreya',
    '🇰🇼' => 'bayraq: Küveyt',
    '🇰🇾' => 'bayraq: Kayman adaları',
    '🇰🇿' => 'bayraq: Qazaxıstan',
    '🇱🇦' => 'bayraq: Laos',
    '🇱🇧' => 'bayraq: Livan',
    '🇱🇨' => 'bayraq: Sent-Lusiya',
    '🇱🇮' => 'bayraq: Lixtenşteyn',
    '🇱🇰' => 'bayraq: Şri-Lanka',
    '🇱🇷' => 'bayraq: Liberiya',
    '🇱🇸' => 'bayraq: Lesoto',
    '🇱🇹' => 'bayraq: Litva',
    '🇱🇺' => 'bayraq: Lüksemburq',
    '🇱🇻' => 'bayraq: Latviya',
    '🇱🇾' => 'bayraq: Liviya',
    '🇲🇦' => 'bayraq: Mərakeş',
    '🇲🇨' => 'bayraq: Monako',
    '🇲🇩' => 'bayraq: Moldova',
    '🇲🇪' => 'bayraq: Monteneqro',
    '🇲🇫' => 'bayraq: Sent Martin',
    '🇲🇬' => 'bayraq: Madaqaskar',
    '🇲🇭' => 'bayraq: Marşal adaları',
    '🇲🇰' => 'bayraq: Şimali Makedoniya',
    '🇲🇱' => 'bayraq: Mali',
    '🇲🇲' => 'bayraq: Myanma',
    '🇲🇳' => 'bayraq: Monqolustan',
    '🇲🇴' => 'bayraq: Makao XİR Çin',
    '🇲🇵' => 'bayraq: Şimali Marian adaları',
    '🇲🇶' => 'bayraq: Martinik',
    '🇲🇷' => 'bayraq: Mavritaniya',
    '🇲🇸' => 'bayraq: Monserat',
    '🇲🇹' => 'bayraq: Malta',
    '🇲🇺' => 'bayraq: Mavriki',
    '🇲🇻' => 'bayraq: Maldiv adaları',
    '🇲🇼' => 'bayraq: Malavi',
    '🇲🇽' => 'bayraq: Meksika',
    '🇲🇾' => 'bayraq: Malayziya',
    '🇲🇿' => 'bayraq: Mozambik',
    '🇳🇦' => 'bayraq: Namibiya',
    '🇳🇨' => 'bayraq: Yeni Kaledoniya',
    '🇳🇪' => 'bayraq: Niger',
    '🇳🇫' => 'bayraq: Norfolk adası',
    '🇳🇬' => 'bayraq: Nigeriya',
    '🇳🇮' => 'bayraq: Nikaraqua',
    '🇳🇱' => 'bayraq: Niderland',
    '🇳🇴' => 'bayraq: Norveç',
    '🇳🇵' => 'bayraq: Nepal',
    '🇳🇷' => 'bayraq: Nauru',
    '🇳🇺' => 'bayraq: Niue',
    '🇳🇿' => 'bayraq: Yeni Zelandiya',
    '🇴🇲' => 'bayraq: Oman',
    '🇵🇦' => 'bayraq: Panama',
    '🇵🇪' => 'bayraq: Peru',
    '🇵🇫' => 'bayraq: Fransa Polineziyası',
    '🇵🇬' => 'bayraq: Papua-Yeni Qvineya',
    '🇵🇭' => 'bayraq: Filippin',
    '🇵🇰' => 'bayraq: Pakistan',
    '🇵🇱' => 'bayraq: Polşa',
    '🇵🇲' => 'bayraq: Müqəddəs Pyer və Mikelon',
    '🇵🇳' => 'bayraq: Pitkern adaları',
    '🇵🇷' => 'bayraq: Puerto Riko',
    '🇵🇸' => 'bayraq: Fələstin Əraziləri',
    '🇵🇹' => 'bayraq: Portuqaliya',
    '🇵🇼' => 'bayraq: Palau',
    '🇵🇾' => 'bayraq: Paraqvay',
    '🇶🇦' => 'bayraq: Qətər',
    '🇷🇪' => 'bayraq: Reyunyon',
    '🇷🇴' => 'bayraq: Rumıniya',
    '🇷🇸' => 'bayraq: Serbiya',
    '🇷🇺' => 'bayraq: Rusiya',
    '🇷🇼' => 'bayraq: Ruanda',
    '🇸🇦' => 'bayraq: Səudiyyə Ərəbistanı',
    '🇸🇧' => 'bayraq: Solomon adaları',
    '🇸🇨' => 'bayraq: Seyşel adaları',
    '🇸🇩' => 'bayraq: Sudan',
    '🇸🇪' => 'bayraq: İsveç',
    '🇸🇬' => 'bayraq: Sinqapur',
    '🇸🇭' => 'bayraq: Müqəddəs Yelena',
    '🇸🇮' => 'bayraq: Sloveniya',
    '🇸🇯' => 'bayraq: Svalbard və Yan-Mayen',
    '🇸🇰' => 'bayraq: Slovakiya',
    '🇸🇱' => 'bayraq: Syerra-Leone',
    '🇸🇲' => 'bayraq: San-Marino',
    '🇸🇳' => 'bayraq: Seneqal',
    '🇸🇴' => 'bayraq: Somali',
    '🇸🇷' => 'bayraq: Surinam',
    '🇸🇸' => 'bayraq: Cənubi Sudan',
    '🇸🇹' => 'bayraq: San-Tome və Prinsipi',
    '🇸🇻' => 'bayraq: Salvador',
    '🇸🇽' => 'bayraq: Sint-Marten',
    '🇸🇾' => 'bayraq: Suriya',
    '🇸🇿' => 'bayraq: Esvatini',
    '🇹🇦' => 'bayraq: Tristan da Kunya',
    '🇹🇨' => 'bayraq: Törks və Kaykos adaları',
    '🇹🇩' => 'bayraq: Çad',
    '🇹🇫' => 'bayraq: Fransanın Cənub Əraziləri',
    '🇹🇬' => 'bayraq: Toqo',
    '🇹🇭' => 'bayraq: Tailand',
    '🇹🇯' => 'bayraq: Tacikistan',
    '🇹🇰' => 'bayraq: Tokelau',
    '🇹🇱' => 'bayraq: Şərqi Timor',
    '🇹🇲' => 'bayraq: Türkmənistan',
    '🇹🇳' => 'bayraq: Tunis',
    '🇹🇴' => 'bayraq: Tonqa',
    '🇹🇷' => 'bayraq: Türkiyə',
    '🇹🇹' => 'bayraq: Trinidad və Tobaqo',
    '🇹🇻' => 'bayraq: Tuvalu',
    '🇹🇼' => 'bayraq: Tayvan',
    '🇹🇿' => 'bayraq: Tanzaniya',
    '🇺🇦' => 'bayraq: Ukrayna',
    '🇺🇬' => 'bayraq: Uqanda',
    '🇺🇲' => 'bayraq: ABŞ-a bağlı kiçik adacıqlar',
    '🇺🇳' => 'bayraq: Birləşmiş Millətlər Təşkilatı',
    '🇺🇸' => 'bayraq: Amerika Birləşmiş Ştatları',
    '🇺🇾' => 'bayraq: Uruqvay',
    '🇺🇿' => 'bayraq: Özbəkistan',
    '🇻🇦' => 'bayraq: Vatikan',
    '🇻🇨' => 'bayraq: Sent-Vinsent və Qrenadinlər',
    '🇻🇪' => 'bayraq: Venesuela',
    '🇻🇬' => 'bayraq: Britaniyanın Virgin adaları',
    '🇻🇮' => 'bayraq: ABŞ Virgin adaları',
    '🇻🇳' => 'bayraq: Vyetnam',
    '🇻🇺' => 'bayraq: Vanuatu',
    '🇼🇫' => 'bayraq: Uollis və Futuna',
    '🇼🇸' => 'bayraq: Samoa',
    '🇽🇰' => 'bayraq: Kosovo',
    '🇾🇪' => 'bayraq: Yəmən',
    '🇾🇹' => 'bayraq: Mayot',
    '🇿🇦' => 'bayraq: Cənub Afrika',
    '🇿🇲' => 'bayraq: Zambiya',
    '🇿🇼' => 'bayraq: Zimbabve',
    '🔟' => 'klaviatura qapağı: 10',
    '🏻' => 'açıq dəri tonu',
    '🏼' => 'orta-açıq dəri tonu',
    '🏽' => 'orta dəri tonu',
    '🏾' => 'orta-tünd dəri tonu',
    '🏿' => 'tünd dəri tonu',
    '😀' => 'gülən üz',
    '😃' => 'açıq ağızla gülən üz',
    '😄' => 'açıq ağız və gülən gözlərlə gülən üz',
    '😁' => 'gülən gözlərlə gülən üz',
    '😆' => 'açıq ağız və bərk yumulmuş gözlərlə gülən üz',
    '😅' => 'açıq ağız və soyuq tərlə gülən üz',
    '🤣' => 'gülməkdən nəfəsi kəsilmək',
    '😂' => 'sevinc göz yaşları olan üz',
    '🙂' => 'yüngülcə gülümsəyən üz',
    '🙃' => 'başı-aşağı üz',
    '🫠' => 'əriyən üz',
    '😉' => 'göz vuran üz',
    '😊' => 'gülən gözlərlə gülümsəyən üz',
    '😇' => 'başında halə gülmsəyən üz',
    '🥰' => '3 ürəkli təbəssümlü üz',
    '😍' => 'ürək formalı gözləri olan gülən üz',
    '🤩' => 'ulduza heyranlıq',
    '😘' => 'öpüş göndərən üz',
    '😗' => 'öpən üz',
    '☺' => 'gülümsəyən üz',
    '😚' => 'bağlı gözlərlə öpən üz',
    '😙' => 'gülən gözlərlə öpən üz',
    '🥲' => 'göz yaşları ilə gülümsəyən üz',
    '😋' => 'dadlı yeməkdən həzz alan üz',
    '😛' => 'dilini çıxarmış üz',
    '😜' => 'dilini çıxarmış və göz vuran üz',
    '🤪' => 'dəcəl üz',
    '😝' => 'dilini çıxarmış və gözlərini möhkəm bağlamış üz',
    '🤑' => 'ağzı pul olan üz',
    '🤗' => 'qucaqlayan üz',
    '🤭' => 'ağzını əli ilə örtmüş üz',
    '🫢' => 'açıq gözlü üz və ağzı tutmuş əl',
    '🫣' => 'baxan gözlə üz',
    '🤫' => 'tərpənən sifət',
    '🤔' => 'düşünən üz',
    '🫡' => 'salamlayan üz',
    '🤐' => 'ağzı bağlanmış üz',
    '🤨' => 'qaşları qalxmış üz',
    '😐' => 'neytral üz',
    '😑' => 'ifadəsiz üz',
    '😶' => 'ağızsız üz',
    '🫥' => 'nöqtəli xətli üz',
    '😏' => 'özündən razı gülümsəyən üz',
    '😒' => 'kefsiz üz',
    '🙄' => 'gözlərini fırladan üz',
    '😬' => 'üz-gözünü turşudan üz',
    '🤥' => 'yalançı adam üzü',
    '🫨' => 'silkələnən üz',
    '😌' => 'rahat üz',
    '😔' => 'fikirli üz',
    '😪' => 'yuxulu üz',
    '🤤' => 'ağız sulanan üz',
    '😴' => 'yatan üz',
    '🫩' => 'altı torbalanmış gözləri olan üz',
    '😷' => 'tibbi maskalı üz',
    '🤒' => 'termometrli',
    '🤕' => 'baş sarğılı üz',
    '🤢' => 'iyrənən üz',
    '🤮' => 'qusan üz',
    '🤧' => 'asqıran üz',
    '🥵' => 'pörtləmiş üz',
    '🥶' => 'donmuş üz',
    '🥴' => 'gicəllənən üz',
    '😵' => 'başıgicəllənən üz',
    '🤯' => 'partlayan baş',
    '🤠' => 'papaqlı qaqaş üzü',
    '🥳' => 'parti edən üz',
    '🥸' => 'maskalanmış üz',
    '😎' => 'gün eynəyi ilə gülən üz',
    '🤓' => 'axmaq üz',
    '🧐' => 'monokllu üz',
    '😕' => 'çaşqın üz',
    '🫤' => 'diaqonal ağızlı üz',
    '😟' => 'narahat üz',
    '🙁' => 'bir az qaşqabaqlı üz',
    '☹' => 'qaşqabaqlı üz',
    '😮' => 'ağzı açıq üz',
    '😯' => 'heyrətlənmiş üz',
    '😲' => 'təəccüblənmiş üz',
    '😳' => 'qızarmış üz',
    '🫪' => 'əyilmiş üz',
    '🥺' => 'yalvaran üz',
    '🥹' => 'dolmuş gözləri olan üz',
    '😦' => 'ağzı açıq qaşqabaqlı üz',
    '😧' => 'kədərli üz',
    '😨' => 'qorxmuş üz',
    '😰' => 'ağzı açıq və soyuq tər olan üz',
    '😥' => 'məyus lakin rahat üz',
    '😢' => 'ağlayan üz',
    '😭' => 'bərkdən ağlayan üz',
    '😱' => 'qorxudan çığıran üz',
    '😖' => 'utanan üz',
    '😣' => 'inadkar üz',
    '😞' => 'məyus üz',
    '😓' => 'soyuq tərli üz',
    '😩' => 'yorulmuş üz',
    '😫' => 'yorğun üz',
    '🥱' => 'əsnəyən üz',
    '😤' => 'burnundan tüstü çıxan üz',
    '😡' => 'acıqlı üz',
    '😠' => 'hirsli üz',
    '🤬' => 'ağızda simvolları olan üz',
    '😈' => 'buynuzlu gülən üz',
    '👿' => 'şeytan',
    '💀' => 'kəllə',
    '☠' => 'kəllə və sümüklər',
    '💩' => 'pox',
    '🤡' => 'kloun üzü',
    '👹' => 'div',
    '👺' => 'qoblin',
    '👻' => 'ruh',
    '👽' => 'yadplanetli',
    '👾' => 'yadplanetli monstr',
    '🤖' => 'robot üz',
    '😺' => 'ağzı açıq gülən pişik üzü',
    '😸' => 'gözləri gülən dişini ağardan pişik üzü',
    '😹' => 'sevinc göz yaşları olan pişik üzü',
    '😻' => 'ürək formalı gözləri olan gülən pişik üzü',
    '😼' => 'əyri-əyri gülən pişik üzü',
    '😽' => 'bağlı gözlərlə öpən pişik üzü',
    '🙀' => 'təəccüblənmiş pişik üzü',
    '😿' => 'ağlayan pişik üzü',
    '😾' => 'acıqlı pişik üzü',
    '🙈' => 'pisliyi görümürəm',
    '🙉' => 'pisliyi eşitmirəm',
    '🙊' => 'pis danışmıram',
    '💌' => 'sevgi məktubu',
    '💘' => 'oxlu ürək',
    '💝' => 'lentli ürək',
    '💖' => 'qığılcımlı ürək',
    '💗' => 'böyüyıb ürək',
    '💓' => 'döyünən ürək',
    '💞' => 'fırlanan ürəklr',
    '💕' => 'iki ürək',
    '💟' => 'ürək bəzəyi',
    '❣' => 'ürək nida işarəsi ornamenti',
    '💔' => 'sınmış ürək',
    '❤' => 'qırmızı ürək',
    '🩷' => 'çəhrayı ürək',
    '🧡' => 'narıncı ürək',
    '💛' => 'sarı ürək',
    '💚' => 'yaşıl ürək',
    '💙' => 'mavi ürək',
    '🩵' => 'açıq mavi ürək',
    '💜' => 'bənövşəyi ürək',
    '🤎' => 'qəhvəyi ürək',
    '🖤' => 'qara-ürək adam',
    '🩶' => 'boz ürək',
    '🤍' => 'ağ ürək',
    '💋' => 'öpüş işarəsi',
    '💯' => '100 xal',
    '💢' => 'qəzəb simvolu',
    '🫯' => 'savaş buludu',
    '💥' => 'toqquşma',
    '💫' => 'başgicəllənməsi',
    '💦' => 'tər damcıları',
    '💨' => 'sürətli hərəkət',
    '🕳' => 'deşik',
    '💬' => 'nitq şarı',
    '🗨' => 'boş nitq şarı',
    '🗯' => 'sağ qəzəb şarı',
    '💭' => 'düşüncə şarı',
    '💤' => 'zzz',
    '👋' => 'əl sallayan əllər',
    '🤚' => 'yuxarı qalxan əl arxası',
    '🖐' => 'barmaqları aralı şəkildə qaldırılmış əl',
    '✋' => 'qaldırımış əl',
    '🖖' => 'vulkan salamı',
    '🫱' => 'sağ əl',
    '🫲' => 'sol əl',
    '🫳' => 'aşağı əl',
    '🫴' => 'yuxarı əl',
    '🫷' => 'sola itələyən əl',
    '🫸' => 'sağa basan əl',
    '👌' => 'ok işarəsi',
    '🤌' => 'çimdik',
    '🤏' => 'sıxan əl',
    '✌' => 'qələbə işarəsi',
    '🤞' => 'ümid edirəm',
    '🫰' => 'əl barmağı və baş barmağı çarpazlanmış vəziyyətdə',
    '🤟' => 'sevgi jesti',
    '🤘' => 'buynuz işarəsi',
    '🤙' => 'mənə zəng et',
    '👈' => 'solu göstərən sol əlin işarə barmağı',
    '👉' => 'sağı göstərən sol əlin işarə barmağı',
    '👆' => 'yuxarını göstərən sol əlin işarə barmağı',
    '🖕' => 'orta barmaq',
    '👇' => 'aşağını göstərən sol əlin işarə barmağı',
    '☝' => 'işarə barmağı',
    '🫵' => 'tamaşaçıya işarə edən barmaq',
    '👍' => 'baş barmaq yuxarı',
    '👎' => 'baş barmaq aşağı',
    '✊' => 'qaldırılmış yumruq',
    '👊' => 'yaxınlaşan yumruq',
    '🤛' => 'sola yönələn yumruq',
    '🤜' => 'sağa yönələn yumruq',
    '👏' => 'əl çalan əllər',
    '🙌' => 'əllərini qaldıran adam',
    '🫶' => 'əldən ürək',
    '👐' => 'açıq əllər',
    '🤲' => 'əllər yuxarı',
    '🤝' => 'salamlaşmaq',
    '🙏' => 'qatlanmış əllər',
    '✍' => 'yazı əli',
    '💅' => 'dırnaq laklamaq',
    '🤳' => 'özçəkim',
    '💪' => 'qatlanmış əzələ',
    '🦾' => 'mexaniki əl',
    '🦿' => 'mexaniki ayaq',
    '🦵' => 'qıç',
    '🦶' => 'ayaq',
    '👂' => 'qulaq',
    '🦻' => 'eşitmə cihazlı qulaq',
    '👃' => 'burun',
    '🧠' => 'beyin',
    '🫀' => 'ürək',
    '🫁' => 'ağciyərlər',
    '🦷' => 'diş',
    '🦴' => 'sümük',
    '👀' => 'gözlər',
    '👁' => 'göz',
    '👅' => 'dil',
    '👄' => 'ağız',
    '🫦' => 'dişlənən dodaq',
    '👶' => 'körpə',
    '🧒' => 'uşaq',
    '👦' => 'oğlan',
    '👧' => 'qız uşağı',
    '🧑' => 'böyük',
    '👱' => 'sarı saçlı adam',
    '👨' => 'kişi',
    '🧔' => 'saqqallı şəxs',
    '👩' => 'qadın',
    '🧓' => 'yaşlı böyük',
    '👴' => 'yaşlı kişi',
    '👵' => 'yaşlı qadın',
    '🙍' => 'qaşqabaqlı adam',
    '🙎' => 'acıq edən adam',
    '🙅' => 'yox jesti',
    '🙆' => 'ok jesti',
    '💁' => 'məlumat verən şəxs',
    '🙋' => 'əlini qaldıran xoşbəxt adam',
    '🧏' => 'kar şəxs',
    '🙇' => 'tənzim edən adam',
    '🤦' => 'inanmaq olmur',
    '🤷' => 'çiynini çəkmək',
    '👮' => 'polis məmuru',
    '🕵' => 'detektiv',
    '💂' => 'keşikçi',
    '🥷' => 'nindza',
    '👷' => 'tikinti işçisi',
    '🫅' => 'taclı adam',
    '🤴' => 'oğlan şahzadə',
    '👸' => 'qız şahzadə',
    '👳' => 'çalmalı kişi',
    '👲' => 'çin kepkalı kişi',
    '🧕' => 'şərfli qadın',
    '🤵' => 'smokinqli şəxs',
    '👰' => 'duvaqlı şəxs',
    '🤰' => 'hamilə qadın',
    '🫃' => 'hamilə kişi',
    '🫄' => 'hamilə adam',
    '🤱' => 'uşaq əmizdirmə',
    '👼' => 'körpə mələk',
    '🎅' => 'Santa Klaus',
    '🤶' => 'xanım Klaus',
    '🦸' => 'superqəhrəman',
    '🦹' => 'supercani',
    '🧙' => 'maq',
    '🧚' => 'pəri',
    '🧛' => 'vampir',
    '🧜' => 'dəniz adamı',
    '🧝' => 'elf',
    '🧞' => 'cin',
    '🧟' => 'zombi',
    '🧌' => 'troll',
    '🫈' => 'tüklü məxluq',
    '💆' => 'üz masajı',
    '💇' => 'saç kəsimi',
    '🚶' => 'piyada',
    '🧍' => 'duran adam',
    '🧎' => 'dizi üstündə adam',
    '🏃' => 'atlet',
    '💃' => 'rəqs edən qadın',
    '🕺' => 'əylənən kişilər',
    '🕴' => 'işgüzar kostyumlu kişi',
    '👯' => 'şənlənən qadınlar',
    '🧖' => 'buxarlı otaqda adam',
    '🧗' => 'dırmaşan adam',
    '🤺' => 'qılınc oynatma',
    '🏇' => 'at yarışı',
    '⛷' => 'xizəkçi',
    '🏂' => 'snouborder',
    '🏌' => 'qolf oynayan',
    '🏄' => 'sörfer',
    '🚣' => 'avarçəkmə qayığı',
    '🏊' => 'üzgüçü',
    '⛹' => 'toplu adam',
    '🏋' => 'ştanqçı',
    '🚴' => 'velosipedçi',
    '🚵' => 'dağ velosipedçisi',
    '🤸' => 'akrobatik hərəkət',
    '🤼' => 'güləş',
    '🤽' => 'su polosu',
    '🤾' => 'həndbol',
    '🤹' => 'janqlyor',
    '🧘' => 'lotus pozisiyasında adam',
    '🛀' => 'vanna qəbul edən adam',
    '🛌' => 'yataqda uzanmış adam',
    '👭' => 'əl-ələ tutan iki qadın',
    '👫' => 'əl-ələ tutan kişi və qadın',
    '👬' => 'əl-ələ tutan iki kişi',
    '💏' => 'öpüş',
    '💑' => 'ürəkli cütlük',
    '🗣' => 'danışan baş',
    '👤' => 'büst silueti',
    '👥' => 'büst siluetləri',
    '🫂' => 'qucaqlaşan insanlar',
    '👪' => 'ailə',
    '👣' => 'ayaq izləri',
    '🫆' => 'barmaq izi',
    '🦰' => 'qırmızı saç',
    '🦱' => 'buruq saç',
    '🦳' => 'ağ saç',
    '🦲' => 'keçəl',
    '🐵' => 'meymun üzü',
    '🐒' => 'meymun',
    '🦍' => 'qorilla',
    '🦧' => 'oranqutanq',
    '🐶' => 'it üzü',
    '🐕' => 'it',
    '🦮' => 'bələdçi it',
    '🐩' => 'pudel',
    '🐺' => 'canavar',
    '🦊' => 'tülkü',
    '🦝' => 'yenot',
    '🐱' => 'pişik üzü',
    '🐈' => 'pişik',
    '🦁' => 'aslan',
    '🐯' => 'pələng üzü',
    '🐅' => 'pələng',
    '🐆' => 'bəbir',
    '🐴' => 'at üzü',
    '🫎' => 'sığın',
    '🫏' => 'eşşək',
    '🐎' => 'at',
    '🦄' => 'təkbuynuz',
    '🦓' => 'zebra',
    '🦌' => 'maral',
    '🦬' => 'bizon',
    '🐮' => 'inək üzü',
    '🐂' => 'öküz',
    '🐃' => 'su camışı',
    '🐄' => 'inək',
    '🐷' => 'donuz üzü',
    '🐖' => 'donuz',
    '🐗' => 'qaban',
    '🐽' => 'donuz burnu',
    '🐏' => 'qoç',
    '🐑' => 'qoyun',
    '🐐' => 'keçi',
    '🐪' => 'dəvə',
    '🐫' => 'ikihürgüclü dəvə',
    '🦙' => 'lama',
    '🦒' => 'zürafə',
    '🐘' => 'fil',
    '🦣' => 'mamont',
    '🦏' => 'kərgədan',
    '🦛' => 'hippopotam',
    '🐭' => 'siçan üzü',
    '🐁' => 'siçan',
    '🐀' => 'siçovul',
    '🐹' => 'dağsiçanı',
    '🐰' => 'dovşan üzü',
    '🐇' => 'dovşan',
    '🐿' => 'brunduk',
    '🦫' => 'qunduz',
    '🦔' => 'kirpi',
    '🦇' => 'yarasa',
    '🐻' => 'ayı üzü',
    '🐨' => 'koala',
    '🐼' => 'panda üzü',
    '🦥' => 'tənbəl',
    '🦦' => 'samur',
    '🦨' => 'skunsk',
    '🦘' => 'kenquru',
    '🦡' => 'porsuq',
    '🐾' => 'pəncə izləri',
    '🦃' => 'hinduşka',
    '🐔' => 'toyuq',
    '🐓' => 'xoruz',
    '🐣' => 'yumurtadan çıxan cücə',
    '🐤' => 'körpə cücə',
    '🐥' => 'qabağa baxan balaca cücə',
    '🐦' => 'quş',
    '🐧' => 'pinqvin',
    '🕊' => 'göyərçin',
    '🦅' => 'qartal',
    '🦆' => 'ördək',
    '🦢' => 'qu',
    '🦉' => 'bayquş',
    '🦤' => 'dodo',
    '🪶' => 'lələk',
    '🦩' => 'flaminqo',
    '🦚' => 'tovuz',
    '🦜' => 'tutuquşu',
    '🪽' => 'qanad',
    '🪿' => 'qaz',
    '🐸' => 'qurbağa üzü',
    '🐊' => 'timsah',
    '🐢' => 'tısbağa',
    '🦎' => 'kərtənkələ',
    '🐍' => 'ilan',
    '🐲' => 'əjdaha üzü',
    '🐉' => 'əjdaha',
    '🦕' => 'sauropod',
    '🦖' => 'Tireks',
    '🐳' => 'su püskürdən balina',
    '🐋' => 'kit',
    '🐬' => 'delfin',
    '🫍' => 'orka',
    '🦭' => 'suiti',
    '🐟' => 'balıq',
    '🐠' => 'tropik balıq',
    '🐡' => 'iynəqarın balıq',
    '🦈' => 'akula',
    '🐙' => 'osminoq',
    '🐚' => 'spiral balıqqulağı',
    '🪸' => 'mərcan',
    '🪼' => 'meduza',
    '🦀' => 'qırmızı xərçəng',
    '🦞' => 'lobster',
    '🦐' => 'krevet',
    '🦑' => 'səkkiz ayaq',
    '🦪' => 'stridiya',
    '🐌' => 'ilbiz',
    '🦋' => 'kəpənək',
    '🐛' => 'böcək',
    '🐜' => 'qarışqa',
    '🐝' => 'bal arısı',
    '🪲' => 'tarakan',
    '🐞' => 'parabüzən',
    '🦗' => 'cırcırama',
    '🪳' => 'mətbəxqurdu',
    '🕷' => 'hörümçək',
    '🕸' => 'hörümçək toru',
    '🦂' => 'əqrəb',
    '🦟' => 'ağcaqanad',
    '🪰' => 'milçək',
    '🪱' => 'soxulcan',
    '🦠' => 'mikrob',
    '💐' => 'buket',
    '🌸' => 'albalı çiçəyi',
    '💮' => 'ağ gül',
    '🪷' => 'lotus',
    '🏵' => 'rozetka',
    '🌹' => 'qızılgül',
    '🥀' => 'solmuş gül',
    '🌺' => 'hibiskus',
    '🌻' => 'günəbaxan',
    '🌼' => 'çiçək',
    '🌷' => 'liliya',
    '🪻' => 'sümbül',
    '🌱' => 'şitil',
    '🪴' => 'dibçək bitkisi',
    '🌲' => 'həmişəyaşıl',
    '🌳' => 'enliyarpaqlı ağac',
    '🌴' => 'palma ağacı',
    '🌵' => 'kaktus',
    '🌾' => 'düyü sünbülü',
    '🌿' => 'dərman bitkisi',
    '☘' => 'yonca',
    '🍀' => 'dörd yarpaq yonca',
    '🍁' => 'ağcaqayın yarpağı',
    '🍂' => 'tökülən yarpaq',
    '🍃' => 'küləkdə əsən yarpaq',
    '🪹' => 'boş yuva',
    '🪺' => 'yumurtalı yuva',
    '🍄' => 'göbələk',
    '🪾' => 'yarpaqsız ağac',
    '🍇' => 'üzüm',
    '🍈' => 'yemiş',
    '🍉' => 'qarpız',
    '🍊' => 'mandarin',
    '🍋' => 'limon',
    '🍌' => 'banan',
    '🍍' => 'ananas',
    '🥭' => 'manqo',
    '🍎' => 'qırmızı alma',
    '🍏' => 'yaşıl alma',
    '🍐' => 'armud',
    '🍑' => 'şaftalı',
    '🍒' => 'albalı',
    '🍓' => 'çiyələk',
    '🫐' => 'qaragilələr',
    '🥝' => 'kivi',
    '🍅' => 'pomidor',
    '🫒' => 'zeytun',
    '🥥' => 'kokos',
    '🥑' => 'avokado',
    '🍆' => 'badımcan',
    '🥔' => 'kartof',
    '🥕' => 'kök',
    '🌽' => 'qarğıdalı sünbülü',
    '🌶' => 'acı bibər',
    '🫑' => 'bolqar bibəri',
    '🥒' => 'xiyar',
    '🥬' => 'kahı',
    '🥦' => 'brokkoli',
    '🧄' => 'sarımsaq',
    '🧅' => 'soğan',
    '🥜' => 'yer fındığı',
    '🫘' => 'lobya',
    '🌰' => 'şabalıd',
    '🫚' => 'zəncəfil kökü',
    '🫛' => 'noxud qabığı',
    '🫜' => 'meyvəköklü',
    '🍞' => 'çörək',
    '🥐' => 'kruasan',
    '🥖' => 'kərpic çörək',
    '🫓' => 'yumru çörək',
    '🥨' => 'pretsel',
    '🥯' => 'bublik',
    '🥞' => 'blin',
    '🧇' => 'vafli',
    '🧀' => 'pendir',
    '🍖' => 'sümükdə ət',
    '🍗' => 'toyuq budu',
    '🥩' => 'ət tikəsi',
    '🥓' => 'bekon',
    '🍔' => 'hamburger',
    '🍟' => 'kartof qızartması',
    '🍕' => 'pizza',
    '🌭' => 'hot doq',
    '🥪' => 'sendviç',
    '🌮' => 'tako',
    '🌯' => 'buritto',
    '🫔' => 'tamal',
    '🥙' => 'qutab',
    '🧆' => 'falafel',
    '🥚' => 'yumurta',
    '🍳' => 'bişirmək',
    '🥘' => 'dayaz qazan',
    '🍲' => 'yemək qazanı',
    '🫕' => 'fondyu',
    '🥣' => 'qaşıq ilə kasa',
    '🥗' => 'salat',
    '🍿' => 'popkorn',
    '🧈' => 'kərə yağı',
    '🧂' => 'duz',
    '🥫' => 'konserv qida',
    '🍱' => 'bentu qutusu',
    '🍘' => 'düyü krekeri',
    '🍙' => 'düyü küftəsi',
    '🍚' => 'bişmiş düyü',
    '🍛' => 'karri düyüsü',
    '🍜' => 'buxarlanan kasa',
    '🍝' => 'spagetti',
    '🍠' => 'qızardılmış şirin kartof',
    '🍢' => 'oden',
    '🍣' => 'suşi',
    '🍤' => 'qızardılmış krivet',
    '🍥' => 'spiralşəkilli balıq piroqu',
    '🥮' => 'ay piroqu',
    '🍡' => 'danqo',
    '🥟' => 'klyotek',
    '🥠' => 'bəxt peçenyesi',
    '🥡' => 'özünlə aparmaq qutusu',
    '🍦' => 'yumşaq dondurma',
    '🍧' => 'rəndələnmiş dondurma',
    '🍨' => 'dondurma',
    '🍩' => 'ponçik',
    '🍪' => 'peçenye',
    '🎂' => 'ad günü tortu',
    '🍰' => 'bir dilim tort',
    '🧁' => 'keks',
    '🥧' => 'piroq',
    '🍫' => 'şokolad plitkası',
    '🍬' => 'konfet',
    '🍭' => 'şüşəli karamel',
    '🍮' => 'bişirilmiş krem',
    '🍯' => 'bal qabı',
    '🍼' => 'uşaq şüşəsi',
    '🥛' => 'bir stəkan süd',
    '☕' => 'isti içki',
    '🫖' => 'çaynik',
    '🍵' => 'qulpsuz çay fincanı',
    '🍶' => 'sake',
    '🍾' => 'tıxacı çıxan şüşə',
    '🍷' => 'şərab bakalı',
    '🍸' => 'kokteyl bakalı',
    '🍹' => 'tropik içki',
    '🍺' => 'pivə krujkası',
    '🍻' => 'pivə krujkalarını toqquşdurmaq',
    '🥂' => 'badələri qaldırmaq',
    '🥃' => 'viski stəkanı',
    '🫗' => 'maye süzülməsi',
    '🥤' => 'borucuqlu stəkan',
    '🧋' => 'köpüklü çay',
    '🧃' => 'içki qutusu',
    '🧉' => 'mate',
    '🧊' => 'buz kubu',
    '🥢' => 'yemək çubuqları',
    '🍽' => 'çəngəl və bıçaq ilə boşqab',
    '🍴' => 'çəngəl və bıçaq',
    '🥄' => 'qaşıq',
    '🔪' => 'mətbəx bıçağı',
    '🫙' => 'banka',
    '🏺' => 'amfora',
    '🌍' => 'Avropa-Afrikanı göstərən qlobus',
    '🌎' => 'amerika-qitələrini göstərən qlobus',
    '🌏' => 'asiya-avstraliya qitələrini göstərən qlobus',
    '🌐' => 'meridianları olan qlobus',
    '🗺' => 'dünya xəritəsi',
    '🗾' => 'yaponiyanın xəritəsi',
    '🧭' => 'kompas',
    '🏔' => 'başı qarla örtülmüş dağ',
    '⛰' => 'dağ',
    '🛘' => 'torpaq sürüşməsi',
    '🌋' => 'vulkan',
    '🗻' => 'fuji dağı',
    '🏕' => 'kempinq',
    '🏖' => 'çətirli çimərlik',
    '🏜' => 'səhra',
    '🏝' => 'tənha ada',
    '🏞' => 'milli park',
    '🏟' => 'stadion',
    '🏛' => 'klassik bina',
    '🏗' => 'bina tikintisi',
    '🧱' => 'kərpic',
    '🪨' => 'qaya',
    '🪵' => 'odun',
    '🛖' => 'alaçıq',
    '🏘' => 'ev binaları',
    '🏚' => 'baxımsız ev binası',
    '🏠' => 'ev binası',
    '🏡' => 'bağı olan ev',
    '🏢' => 'ofis binası',
    '🏣' => 'yapon poçt idarəsi',
    '🏤' => 'poçt idarəsi',
    '🏥' => 'xəstəxana',
    '🏦' => 'bank',
    '🏨' => 'otel',
    '🏩' => 'sevgi oteli',
    '🏪' => '7/24 açıq olan mağaza',
    '🏫' => 'məktəb',
    '🏬' => 'univermaq',
    '🏭' => 'fabrik',
    '🏯' => 'yapon qəsri',
    '🏰' => 'qəsr',
    '💒' => 'toy',
    '🗼' => 'tokiyo qalası',
    '🗽' => 'azadlıq heykəli',
    '⛪' => 'kilsə',
    '🕌' => 'məscid',
    '🛕' => 'hindu məbədi',
    '🕍' => 'sinaqoq',
    '⛩' => 'sinto məbədi',
    '🕋' => 'kəbə',
    '⛲' => 'fontan',
    '⛺' => 'çadır',
    '🌁' => 'dumanlı',
    '🌃' => 'ulduzlu gecə',
    '🏙' => 'şəhər mənzərəsi',
    '🌄' => 'dağlardan qalxan günəş',
    '🌅' => 'gün doğumu',
    '🌆' => 'hava qaralanda şəhər mənzərəsi',
    '🌇' => 'gün batımı',
    '🌉' => 'gecə körpü',
    '♨' => 'qaynar bulaqlar',
    '🎠' => 'karusel at',
    '🛝' => 'oyun slaydı',
    '🎡' => 'şeytan çarxı',
    '🎢' => 'maneəli dəmir yolu attraksionu',
    '💈' => 'şlaqbaum',
    '🎪' => 'sirk çadırı',
    '🚂' => 'lokomotiv',
    '🚃' => 'dəmir yolu qatarı vaqonu',
    '🚄' => 'yüksək sürətli qatar',
    '🚅' => 'gülləyə bənzər ucluqlu yüksək sürət qatarı',
    '🚆' => 'qatar',
    '🚇' => 'metro',
    '🚈' => 'işıq qatarı',
    '🚉' => 'stansiya',
    '🚊' => 'stritkar',
    '🚝' => 'monorels',
    '🚞' => 'dağ yolu',
    '🚋' => 'tramvay vaqonu',
    '🚌' => 'avtobus',
    '🚍' => 'yaxınlaşan avtobus',
    '🚎' => 'trolleybus',
    '🚐' => 'mini avtobus',
    '🚑' => 'təcili yardım maşını',
    '🚒' => 'yanğınsöndürən',
    '🚓' => 'polis maşını',
    '🚔' => 'yaxınlaşan polis maşını',
    '🚕' => 'taksi',
    '🚖' => 'yaxınlaşan taksi',
    '🚗' => 'avtomobil',
    '🚘' => 'yaxınlaşan avtomobil',
    '🚙' => 'rekreasiya avtomobili',
    '🛻' => 'pikap yüngül avtomobil',
    '🚚' => 'yük maşını',
    '🚛' => 'konteynerli maşın',
    '🚜' => 'traktor',
    '🏎' => 'yarış maşını',
    '🏍' => 'motosiklet',
    '🛵' => 'motorlu skuter',
    '🦽' => 'manual təkərli kreslo',
    '🦼' => 'motorlu təkərli kreslo',
    '🛺' => 'avto-rikşa',
    '🚲' => 'velosiped',
    '🛴' => 'samokat',
    '🛹' => 'skeytbord',
    '🛼' => 'diyircəkli konki',
    '🚏' => 'avtobus dayanacağı',
    '🛣' => 'şosse',
    '🛤' => 'dəmir yolu',
    '🛢' => 'neft silindiri',
    '⛽' => 'yanacaq borusu',
    '🛞' => 'təkər',
    '🚨' => 'polis maşının işığı',
    '🚥' => 'üfüqi işıqfor',
    '🚦' => 'şaquli işıqfor',
    '🛑' => 'dayanmaq işarəsi',
    '🚧' => 'tikinti',
    '⚓' => 'lövbər',
    '🛟' => 'üzük buy',
    '⛵' => 'yelkənli qayıq',
    '🛶' => 'qayıq',
    '🚤' => 'sürətli qayıq',
    '🛳' => 'sərnişin gəmisi',
    '⛴' => 'bərə gəmisi',
    '🛥' => 'motorlu qayıq',
    '🚢' => 'gəmi',
    '✈' => 'təyyarə',
    '🛩' => 'balaca təyyarə',
    '🛫' => 'təyyarə qalxır',
    '🛬' => 'təyyarə enir',
    '🪂' => 'paraşüt',
    '💺' => 'oturacaq',
    '🚁' => 'helikopter',
    '🚟' => 'asma dəmir yolu',
    '🚠' => 'dağ kanatı',
    '🚡' => 'hava tramvayı',
    '🛰' => 'peyk',
    '🚀' => 'raket',
    '🛸' => 'uçan boşqab',
    '🛎' => 'xidmət zəngi',
    '🧳' => 'yük',
    '⌛' => 'qum saatı',
    '⏳' => 'qum tökülən qum saatı',
    '⌚' => 'qol saatı',
    '⏰' => 'zəngli saat',
    '⏱' => 'saniyəölçən',
    '⏲' => 'taymer',
    '🕰' => 'buxarı saat',
    '🕛' => '12 tamam',
    '🕧' => 'birin yarısı',
    '🕐' => 'bir tamam',
    '🕜' => 'ikinin yarısı',
    '🕑' => 'iki tamam',
    '🕝' => 'üçün yarısı',
    '🕒' => 'üç tamam',
    '🕞' => 'dördün yarısı',
    '🕓' => 'dörd tamam',
    '🕟' => 'beşin yarısı',
    '🕔' => 'beş tamam',
    '🕠' => 'altının yarısı',
    '🕕' => 'altı tamam',
    '🕡' => 'yeddinin yarısı',
    '🕖' => 'yeddi tamam',
    '🕢' => 'səkkizin yarısı',
    '🕗' => 'səkkiz tamam',
    '🕣' => 'doqquzun yarısı',
    '🕘' => 'doqquz tamam',
    '🕤' => 'onun yarısı',
    '🕙' => 'on tamam',
    '🕥' => 'on birin yarısı',
    '🕚' => 'on bir tamam',
    '🕦' => 'on ikinin yarısı',
    '🌑' => 'yeni ay',
    '🌒' => 'dörddə bir aypara',
    '🌓' => 'ayın birinci dörrdə bir hissəsi',
    '🌔' => 'dörddə bir böyüyən ay',
    '🌕' => 'tam ay',
    '🌖' => 'sönən böyüyən ay',
    '🌗' => 'ayın sonuncu dörddə bir hissəsi',
    '🌘' => 'sönən aypara',
    '🌙' => 'aypara',
    '🌚' => 'yeni ay üzü',
    '🌛' => 'ayın birinci dörrdə bir hissəsinin üzü',
    '🌜' => 'ayın sonuncu dörddə bir hissəsinin üzü',
    '🌡' => 'termometr',
    '☀' => 'günəş',
    '🌝' => 'üzü olan tam ay',
    '🌞' => 'üzü olan günəş',
    '🪐' => 'üzüklü planet',
    '⭐' => 'ağ orta ulduz',
    '🌟' => 'parıldayan ulduz',
    '🌠' => 'düşən ulduz',
    '🌌' => 'süd yolu',
    '☁' => 'bulud',
    '⛅' => 'buludun arxasında günəş',
    '⛈' => 'ildırım və yağışlı bulud',
    '🌤' => 'balaca buludun arxasına günəş',
    '🌥' => 'böyük buludun arxasında günəş',
    '🌦' => 'yağışlı buludun arxasında günəş',
    '🌧' => 'yağışlı bulud',
    '🌨' => 'qarlı bulud',
    '🌩' => 'ildırımlı bulud',
    '🌪' => 'qasırğa',
    '🌫' => 'duman',
    '🌬' => 'külək üzü',
    '🌀' => 'siklon',
    '🌈' => 'göyqurşağı',
    '🌂' => 'bağlı çətir',
    '☂' => 'çətir',
    '☔' => 'yağış damcıları düşən çətir',
    '⛱' => 'yerdə çətir',
    '⚡' => 'yüksək voltaj',
    '❄' => 'qara dənəciyi',
    '☃' => 'qar adam',
    '⛄' => 'qarsız qar adam',
    '☄' => 'kometa',
    '🔥' => 'alov',
    '💧' => 'damcı',
    '🌊' => 'su dalğası',
    '🎃' => 'Hellouin balqabağı',
    '🎄' => 'milad ağacı',
    '🎆' => 'fişənglər',
    '🎇' => 'qığılclm',
    '🧨' => 'feyerverk',
    '✨' => 'qığılcımlar',
    '🎈' => 'şar',
    '🎉' => 'qonaqlıq stimullaşdırıcısı',
    '🎊' => 'konfetti topu',
    '🎋' => 'tanabata ağacı',
    '🎍' => 'şam ağacı bəzəyi',
    '🎎' => 'yapon gəlincikləri',
    '🎏' => 'karp-uçurtma',
    '🎐' => 'külək zəngi',
    '🎑' => 'ay mərasimi',
    '🧧' => 'qırmızı zərf',
    '🎀' => 'lent',
    '🎁' => 'bükülmüş hədiyyə',
    '🎗' => 'xatırlatma lenti',
    '🎟' => 'giriş biletləri',
    '🎫' => 'bilet',
    '🎖' => 'hərbi medal',
    '🏆' => 'kubok',
    '🏅' => 'idman medalı',
    '🥇' => 'qızıl medal',
    '🥈' => 'gümüş medal',
    '🥉' => 'bürünc medal',
    '⚽' => 'futbol topu',
    '⚾' => 'beysbol',
    '🥎' => 'softbol',
    '🏀' => 'basketbol',
    '🏐' => 'voleybol',
    '🏈' => 'amerikan futbolu',
    '🏉' => 'reqbi',
    '🎾' => 'tennis',
    '🥏' => 'uçan disk',
    '🎳' => 'boulinq',
    '🏏' => 'kriket',
    '🏑' => 'sahə xokkeyi',
    '🏒' => 'buz xokkeyi çubuğu və şaybası',
    '🥍' => 'lakross',
    '🏓' => 'pinq ponq',
    '🏸' => 'badminton',
    '🥊' => 'boks əlcəyi',
    '🥋' => 'döyüş idmanı geyimi',
    '🥅' => 'darvaza',
    '⛳' => 'dəlikdə bayraq',
    '⛸' => 'buz konkisi',
    '🎣' => 'balıq tilovu',
    '🤿' => 'dalğıc maskası',
    '🎽' => 'atlet köynəyi',
    '🎿' => 'xizək',
    '🛷' => 'sanka',
    '🥌' => 'qıvrım daş',
    '🎯' => 'birbaşa atış',
    '🪀' => 'yo-yo',
    '🪁' => 'çərpələng',
    '🔫' => 'tapança',
    '🎱' => 'bilyard',
    '🔮' => 'kristal kürə',
    '🪄' => 'sehrli çubuq',
    '🎮' => 'video oyun',
    '🕹' => 'coystik',
    '🎰' => 'avtomat maşın',
    '🎲' => 'oyun zəri',
    '🧩' => 'pazl',
    '🧸' => 'plüş ayı',
    '🪅' => 'pinyata',
    '🪩' => 'güzgü top',
    '🪆' => 'matryoşkalar',
    '♠' => 'qaratoxmaq dəsti',
    '♥' => 'ürək dəsti',
    '♦' => 'romb dəsti',
    '♣' => 'klub dəsti',
    '♟' => 'şahmat piyadası',
    '🃏' => 'joker',
    '🀄' => 'maconq qırmızı əjdaha',
    '🎴' => 'gül oyun kartları',
    '🎭' => 'teatr incəsənəti',
    '🖼' => 'şəkilli çərçivə',
    '🎨' => 'rəssam palitrası',
    '🧵' => 'sap',
    '🪡' => 'tikiş maşınının iynəsi',
    '🧶' => 'iplik',
    '🪢' => 'düyün',
    '👓' => 'eynək',
    '🕶' => 'gün eynəyi',
    '🥽' => 'qoruyucu eynək',
    '🥼' => 'laboratoriya geyimi',
    '🦺' => 'güvənlik jaketi',
    '👔' => 'qalstuk',
    '👕' => 'qısaqol köynək',
    '👖' => 'cins',
    '🧣' => 'şərf',
    '🧤' => 'əlcəklər',
    '🧥' => 'palto',
    '🧦' => 'corablar',
    '👗' => 'don',
    '👘' => 'kimono',
    '🥻' => 'sari',
    '🩱' => 'bir hissəli üzgüçülük geyimi',
    '🩲' => 'trusik',
    '🩳' => 'şort',
    '👙' => 'bikini',
    '👚' => 'qadın paltarı',
    '🪭' => 'yığılan yelpik',
    '👛' => 'pul kisəsi',
    '👜' => 'əl çantası',
    '👝' => 'torba',
    '🛍' => 'alış-veriş çantaları',
    '🎒' => 'məktəbli bel çantası',
    '🩴' => 'vyetnamka',
    '👞' => 'kişi ayaqqabısı',
    '👟' => 'qaçış ayaqqabısı',
    '🥾' => 'gəzinti botinkası',
    '🥿' => 'yastı ayaqqabı',
    '👠' => 'hündür daban ayaqqabı',
    '👡' => 'qadın səndəli',
    '🩰' => 'balet ayaqqabıları',
    '👢' => 'qadın çəkməsi',
    '🪮' => 'saç düzümü',
    '👑' => 'tac',
    '👒' => 'qadın şlyapası',
    '🎩' => 'silindr şlyapa',
    '🎓' => 'məzuniyyət papağı',
    '🧢' => 'kepka',
    '🪖' => 'hərbi dəbilqə',
    '⛑' => 'ağ xaçlı dəbilqə',
    '📿' => 'təsbeh',
    '💄' => 'dodaq boyası',
    '💍' => 'üzük',
    '💎' => 'qiymətli daş',
    '🔇' => 'səsucaldan sönülüdür',
    '🔈' => 'səsucaldan',
    '🔉' => 'səsucaldan aktivdir',
    '🔊' => 'səsucaldan yüksəkdir',
    '📢' => 'səsucaldıcı',
    '📣' => 'meqafon',
    '📯' => 'poçt şeypuru',
    '🔔' => 'zəng',
    '🔕' => 'üstündən xətt çəkilmiş zəng',
    '🎼' => 'musiqi partiturası',
    '🎵' => 'musiqi notu',
    '🎶' => 'musiqi notları',
    '🎙' => 'studiya mikrafonu',
    '🎚' => 'səviyyə slayderi',
    '🎛' => 'idarə düymələri',
    '🎤' => 'mikrofon',
    '🎧' => 'qulaqlıq',
    '📻' => 'radio',
    '🎷' => 'saksofon',
    '🎺' => 'şeypur',
    '🪊' => 'trombon',
    '🪗' => 'akkordeon',
    '🎸' => 'gitara',
    '🎹' => 'musiqi klaviaturası',
    '🎻' => 'skripka',
    '🪕' => 'banco',
    '🥁' => 'davul',
    '🪘' => 'uzun baraban',
    '🪇' => 'marakas',
    '🪈' => 'fleyta',
    '🪉' => 'arfa',
    '📱' => 'mobil telefon',
    '📲' => 'oxlu mobil telefon',
    '☎' => 'telefon',
    '📞' => 'telefon dəstəyi',
    '📟' => 'peycer',
    '📠' => 'faks aparatı',
    '🔋' => 'batareya',
    '🪫' => 'bitən enerji',
    '🔌' => 'elektrik ştepseli',
    '💻' => 'kompüter',
    '🖥' => 'masaüstü kompüter',
    '🖨' => 'printer',
    '⌨' => 'klaviatura',
    '🖱' => 'kompüter siçanı',
    '🖲' => 'kürəşəkilli manipulyator',
    '💽' => 'mini disk',
    '💾' => 'çevik disk',
    '💿' => 'optik disk',
    '📀' => 'dvd',
    '🧮' => 'çötkə',
    '🎥' => 'kino kamerası',
    '🎞' => 'film kadrları',
    '📽' => 'kino projektoru',
    '🎬' => 'numerator',
    '📺' => 'televizor',
    '📷' => 'kamera',
    '📸' => 'işıqlı kamera',
    '📹' => 'video kamera',
    '📼' => 'video kaset',
    '🔍' => 'sola yönəlmiş böyüdücü şüşə',
    '🔎' => 'sağa yönəlmiş böyüdücü şüşə',
    '🕯' => 'şam',
    '💡' => 'işıq lampası',
    '🔦' => 'fənər',
    '🏮' => 'qırmızı kağız fənər',
    '🪔' => 'yağ lampası',
    '📔' => 'bəzəkli cildli dəftər',
    '📕' => 'bağlı kitab',
    '📖' => 'açıq kitab',
    '📗' => 'yaşıl kitab',
    '📘' => 'mavi kitab',
    '📙' => 'narıncı kitab',
    '📚' => 'kitablar',
    '📓' => 'bloknot',
    '📒' => 'mühasibatlıq kitabı',
    '📃' => 'qatlanmış səhifə',
    '📜' => 'lülə halında bükülmüş kağız',
    '📄' => 'üzüyuxarı səhifə',
    '📰' => 'qəzet',
    '🗞' => 'bükülmüş qəzet',
    '📑' => 'əlfəcin tabları',
    '🔖' => 'əlfəcin',
    '🏷' => 'etiket',
    '🪙' => 'xırda pul',
    '💰' => 'pul torbası',
    '🪎' => 'xəzinə sandığı',
    '💴' => 'iena banknotu',
    '💵' => 'dollar əskinazı',
    '💶' => 'avro əskinazı',
    '💷' => 'funt əskinazı',
    '💸' => 'qanadlı pullar',
    '💳' => 'kredit kartı',
    '🧾' => 'qəbz',
    '💹' => 'ien ilə qalxan qrafik',
    '✉' => 'zərf',
    '📧' => 'e-poçt',
    '📨' => 'gələn zərf',
    '📩' => 'oxlu zərf',
    '📤' => 'gedənlər qutusu',
    '📥' => 'gələnlər qutusu',
    '📦' => 'bağlama',
    '📫' => 'qaldırılmış bayraqlı bağlı poçt qutusu',
    '📪' => 'endirilmiş bayraqlı bağlı poçt qutusu',
    '📬' => 'qaldırılmış bayraqlı açıq poçt qutusu',
    '📭' => 'endirilmiş bayraqlı açıq poçt qutusu',
    '📮' => 'poçt qutusu',
    '🗳' => 'səsvermə kağızı olan seçki qutusu',
    '✏' => 'karandaş',
    '✒' => 'qara qələm',
    '🖋' => 'avto qələm',
    '🖊' => 'qələm',
    '🖌' => 'fırça',
    '🖍' => 'yağlı karandaş',
    '📝' => 'yaddaş qeydi',
    '💼' => 'çemodan',
    '📁' => 'fayl qovluğu',
    '📂' => 'açıq fayl qovluğu',
    '🗂' => 'kart indeksi arakəsmələri',
    '📅' => 'təqvim',
    '📆' => 'təqvimi cırmaq',
    '🗒' => 'spiral dəftər',
    '🗓' => 'spiral təqvim',
    '📇' => 'kart indeksi',
    '📈' => 'qalxan qrafik',
    '📉' => 'düşən qrafik',
    '📊' => 'diaqram',
    '📋' => 'lövhə',
    '📌' => 'löhvə düyməsi',
    '📍' => 'dairəvi sancaq',
    '📎' => 'skrepka',
    '🖇' => 'birləşmiş sancaqlar',
    '📏' => 'düz xətkeş',
    '📐' => 'ücbucaq xətkeş',
    '✂' => 'qayçı',
    '🗃' => 'kart faylı qutusu',
    '🗄' => 'fayl şkafı',
    '🗑' => 'zibilqabı',
    '🔒' => 'kilid',
    '🔓' => 'açıq kilid',
    '🔏' => 'qələmli kilid',
    '🔐' => 'açarla bağlanmış kilid',
    '🔑' => 'açar',
    '🗝' => 'köhnə açar',
    '🔨' => 'çəkic',
    '🪓' => 'balta',
    '⛏' => 'külüng',
    '⚒' => 'çəkic və külüng',
    '🛠' => 'çəkic və açar',
    '🗡' => 'xəncər',
    '⚔' => 'kəsişən qılınclar',
    '💣' => 'bomba',
    '🪃' => 'bumeranq',
    '🏹' => 'ox və kaman',
    '🛡' => 'qalxan',
    '🪚' => 'əl mişarı',
    '🔧' => 'təmir açarı',
    '🪛' => 'vintaçan',
    '🔩' => 'bolt və qayka',
    '⚙' => 'mexanizm',
    '🗜' => 'sıxma',
    '⚖' => 'tarazlıq tərəzisi',
    '🦯' => 'zond',
    '🔗' => 'zəncir',
    '⛓' => 'zəncirlər',
    '🪝' => 'qarmaq',
    '🧰' => 'alətlər qutusu',
    '🧲' => 'maqnit',
    '🪜' => 'nərdivan',
    '🪏' => 'bel',
    '⚗' => 'distillə qazanı',
    '🧪' => 'sınaq şüşəsi',
    '🧫' => 'Petri qabı',
    '🧬' => 'dnt',
    '🔬' => 'mikroskop',
    '🔭' => 'teleskop',
    '📡' => 'peyk antenası',
    '💉' => 'şpris',
    '🩸' => 'qan damlası',
    '💊' => 'həb',
    '🩹' => 'yapışan bandaj',
    '🩼' => 'qoltuqağacı',
    '🩺' => 'stetoskop',
    '🩻' => 'rentgen',
    '🚪' => 'qapı',
    '🛗' => 'lift',
    '🪞' => 'güzgü',
    '🪟' => 'pəncərə',
    '🛏' => 'yataq',
    '🛋' => 'divan və lampa',
    '🪑' => 'stul',
    '🚽' => 'tualet',
    '🪠' => 'porşen',
    '🚿' => 'duş',
    '🛁' => 'vanna',
    '🪤' => 'siçan tələsi',
    '🪒' => 'ülgüc',
    '🧴' => 'losyon şüşəsi',
    '🧷' => 'sancaq',
    '🧹' => 'süpürgə',
    '🧺' => 'səbət',
    '🧻' => 'kağız rulonu',
    '🪣' => 'vedrə',
    '🧼' => 'sabun',
    '🫧' => 'köpüklər',
    '🪥' => 'diş fırçası',
    '🧽' => 'süngər',
    '🧯' => 'alov söndürən',
    '🛒' => 'alış-veriş arabası',
    '🚬' => 'siqaret',
    '⚰' => 'tabut',
    '🪦' => 'başdaşı',
    '⚱' => 'cənazə urnası',
    '🧿' => 'gözmüncuğu',
    '🪬' => 'hamsa',
    '🗿' => 'moai',
    '🪧' => 'plakat',
    '🪪' => 'şəxsiyyət vəsiqəsi',
    '🏧' => 'Bankomat işarəsi',
    '🚮' => 'zibili qutuya atın işarəsi',
    '🚰' => 'içməli su',
    '♿' => 'əlil arabası işarəsi',
    '🚹' => 'kişi tualeti',
    '🚺' => 'qadın tualeti',
    '🚻' => 'ayaqyolu',
    '🚼' => 'körpə simvolu',
    '🚾' => 'wc',
    '🛂' => 'pasport yoxlaması',
    '🛃' => 'gömrük',
    '🛄' => 'baqajın verilməsi',
    '🛅' => 'saxlama kamerası',
    '⚠' => 'xəbərdarlıq',
    '🚸' => 'uşaqlar yol keçir',
    '⛔' => 'giriş yoxdur',
    '🚫' => 'qadağandır',
    '🚳' => 'velosiped sürmək olmaz',
    '🚭' => 'siqaret çəkmək olmaz',
    '🚯' => 'zibil atmaq olmaz',
    '🚱' => 'su içməli deyil',
    '🚷' => 'piyadalara keçmək olmaz',
    '📵' => 'mobil telefondan istifadə etmək olmaz',
    '🔞' => '18 yaşından aşağı olanlara olmaz',
    '☢' => 'radioaktiv',
    '☣' => 'biotəhlükəli',
    '⬆' => 'üzüyuxarı ox',
    '↗' => 'üzüyuxarı sağa yönəlmiş ox',
    '➡' => 'sağa ox',
    '↘' => 'üzüaşağı sağa yönəlmiş ox',
    '⬇' => 'üzüaşağı ox',
    '↙' => 'üzüaşağı sola yönəlmiş ox',
    '⬅' => 'sola ox',
    '↖' => 'üzüyuxarı sola yönəlmiş ox',
    '↕' => 'üzü aşağı-yuxarı ox',
    '↔' => 'sola-sağa ox',
    '↩' => 'sola dönən sağ ox',
    '↪' => 'sağa dönən sol ox',
    '⤴' => 'yuxarı dönən sağ ox',
    '⤵' => 'aşağı dönən sağ ox',
    '🔃' => 'saat istiqamətində yönəlmiş şaquli ox',
    '🔄' => 'saat istiqamətinin əksinə yönəlmiş oxlar düyməsi',
    '🔙' => 'geriyə yönəlmiş ox',
    '🔚' => 'sona yönəlmiş ox',
    '🔛' => 'aktivdir! oxu',
    '🔜' => 'tezliklə oxu',
    '🔝' => 'yuxarı yönəlmiş ox',
    '🛐' => 'tapınaq',
    '⚛' => 'atom simvolu',
    '🕉' => 'om',
    '✡' => 'davud ulduzu',
    '☸' => 'dharma çarxı',
    '☯' => 'in yan',
    '✝' => 'latın xaçı',
    '☦' => 'ortodoks xaçı',
    '☪' => 'ulduz və aypara',
    '☮' => 'sülh simvolu',
    '🕎' => 'hanukiya',
    '🔯' => 'nöqtəli altıguşəli ulduz',
    '🪯' => 'xanda',
    '♈' => 'qoç bürcü',
    '♉' => 'buğa',
    '♊' => 'əkizlər',
    '♋' => 'xərçəng',
    '♌' => 'şir',
    '♍' => 'qız',
    '♎' => 'tərəzi',
    '♏' => 'əqrəb bürcü',
    '♐' => 'oxatan',
    '♑' => 'oğlaq',
    '♒' => 'dolça',
    '♓' => 'balıqlar',
    '⛎' => 'ilandaşıyan',
    '🔀' => 'trekləri qarışdır düyməsi',
    '🔁' => 'təkrarla düyməsi',
    '🔂' => 'bir dəfə təkrarla düyməsi',
    '▶' => 'işə sal düyməsi',
    '⏩' => 'sürətli irəliyə çək düyməsi',
    '⏭' => 'növbəti trek düyməsi',
    '⏯' => 'işə sal və ya fasilə et düyməsi',
    '◀' => 'geriyə düyməsi',
    '⏪' => 'sürətlə geriyə çək düyməsi',
    '⏮' => 'sonuncu trek düyməsi',
    '🔼' => 'yuxarı düyməsi',
    '⏫' => 'sürətlə yuxarı keç düyməsi',
    '🔽' => 'aşağı düyməsi',
    '⏬' => 'sürətlə aşağı keç düyməsi',
    '⏸' => 'fasilə et düyməsi',
    '⏹' => 'dayandır düyməsi',
    '⏺' => 'yaz düyməsi',
    '⏏' => 'çıxart düyməsi',
    '🎦' => 'kino',
    '🔅' => 'tutqunluq düyməsi',
    '🔆' => 'parlaqlıq düyməsi',
    '📶' => 'antena siqnalları',
    '🛜' => 'naqilsiz',
    '📳' => 'vibrasiya rejimi',
    '📴' => 'mobil telefonu söndürün',
    '♀' => 'qadın işarəsi',
    '♂' => 'kişi işarəsi',
    '⚧' => 'transgender simvolu',
    '✖' => 'qalın vurma x',
    '➕' => 'qalın üstəgəl işarəsi',
    '➖' => 'qalın çıxma işarəsi',
    '➗' => 'qalın bölmə işarəsi',
    '🟰' => 'ağır bərabərlik işarəsi',
    '♾' => 'sonsuzluq',
    '‼' => 'qoşa nida işarəsi',
    '⁉' => 'nida və sual işarəsi',
    '❓' => 'qırmızı sual işarəsi',
    '❔' => 'ağ sual işarəsi',
    '❕' => 'ağ nida işarəsi',
    '❗' => 'qırmızı nida işarəsi',
    '〰' => 'dalğalı tire',
    '💱' => 'valyuta mübadiləsi',
    '💲' => 'qalın dollar işarəsi',
    '⚕' => 'tibb işarəsi',
    '♻' => 'təkrar istifadə simvolu',
    '⚜' => 'zanbaq',
    '🔱' => 'üçdiş emblem',
    '📛' => 'ad nişanı',
    '🔰' => 'yaponların başlayan üçün simvolu',
    '⭕' => 'qırmızı qalın dairə',
    '✅' => 'təsdiq işarəsi',
    '☑' => 'təsdiqlənmiş seçim düzbucaqlısı',
    '✔' => 'qalın təsdiq işarəsi',
    '❌' => 'çarpazlamaq işarəsi',
    '❎' => 'çarpazlamaq düyməsi',
    '➰' => 'spiral ilmə',
    '➿' => 'ikiqat spiral ilmə',
    '〽' => 'hissələri bir-birindən ayırmaq işarəsi',
    '✳' => 'səkkiz tərəfli ulduz',
    '✴' => 'səkkiz guşəli ulduz',
    '❇' => 'qığılcım',
    '™' => 'ticarət nişanı',
    '🫟' => 'sıçratmaq',
    '🔠' => 'böyük hərflərlə latın daxiletməsi',
    '🔡' => 'kiçik hərflərlə latın daxiletməsi',
    '🔢' => 'daxiletmə rəqəmləri',
    '🔣' => 'daxiletmə simvolları',
    '🔤' => 'latın hərfləri daxiletməsi',
    '🅰' => 'a düyməsi',
    '🆎' => 'ab düyməsi',
    '🅱' => 'b düyməsi',
    '🆑' => 'kvadrat cl düyməsi',
    '🆒' => 'kvadrat əla düyməsi',
    '🆓' => 'kvadrat ödənişsiz',
    'ℹ' => 'məlumat',
    '🆔' => 'kimlik düyməsi',
    'Ⓜ' => 'dairə içində M',
    '🆕' => 'yeni düyməsi',
    '🆖' => 'NG düyməsi',
    '🅾' => 'o düyməsi',
    '🆗' => 'OK düyməsi',
    '🅿' => 'p düyməsi',
    '🆘' => 'SOS düyməsi',
    '🆙' => 'YUXARI! düyməsi',
    '🆚' => 'QARŞI düyməsi',
    '🈁' => 'kvadrat katakana koko',
    '🈂' => 'kvadrat katakana sa',
    '🈷' => 'yapon "aylıq məbləğ" düyməsi',
    '🈶' => 'yapon "pulsuz deyil" düyməsi',
    '🈯' => 'yapon "məxsusdur" düyməsi',
    '🉐' => 'yapon "yaxşı sövdələşmə" düyməsi',
    '🈹' => 'kvadrat bölmə ideoqramı',
    '🈚' => 'yapon "pulsuzdur" düyməsi',
    '🈲' => 'kvadrat qadağa ideoqramı',
    '🉑' => 'yapon "qəbul edilə bilən" düyməsi',
    '🈸' => 'kvadrat tətbiq ideoqramı',
    '🈴' => 'yapon "keçən qiymət" düyməsi',
    '🈳' => 'kvadrat boş ideoqramı',
    '㊗' => 'yapon "təbriklər" düyməsi',
    '㊙' => 'yapon "məxfi" düyməsi',
    '🈺' => 'yapon "iş" düyməsi',
    '🈵' => 'yapon "tamamilə dolu" düyməsi',
    '🔴' => 'qırmızı dairə',
    '🟠' => 'narıncı dairə',
    '🟡' => 'sarı dairə',
    '🟢' => 'yaşıl dairə',
    '🔵' => 'mavi dairə',
    '🟣' => 'bənövşəyi dairə',
    '🟤' => 'qəhvəyi dairə',
    '⚫' => 'qara dairə',
    '⚪' => 'ağ dairə',
    '🟥' => 'qırmızı kvadrat',
    '🟧' => 'narıncı kvadrat',
    '🟨' => 'sarı kvadrat',
    '🟩' => 'yaşıl kvadrat',
    '🟦' => 'göy kvadrat',
    '🟪' => 'bənövşəyi kvadrat',
    '🟫' => 'qəhvəyi kvadrat',
    '⬛' => 'qara böyük kvadrat',
    '⬜' => 'ağ böyük kvadrat',
    '◼' => 'qara orta ölçülü kvadrat',
    '◻' => 'ağ orta ölçülü kvadrat',
    '◾' => 'qara orta-kiçik kvadrat',
    '◽' => 'ağ orta kiçiklikdə kvadrat',
    '▪' => 'qara balaca kvadrat',
    '▫' => 'ağ balaca kvadrat',
    '🔶' => 'böyük narıncı romb',
    '🔷' => 'böyük mavi romb',
    '🔸' => 'balaca narıncı romb',
    '🔹' => 'balaca mavi romb',
    '🔺' => 'yuxarı yönəlmiş qırmızı üçbucaq',
    '🔻' => 'aşağı yönəlmiş qırmızı üçbucaq',
    '💠' => 'nöqtəli romb',
    '🔘' => 'radio düyməsi',
    '🔳' => 'ağ kvadrat düymə',
    '🔲' => 'qara kvadrat düymə',
    '🏁' => 'damalı bayraq',
    '🚩' => 'üçbucaq bayraq',
    '🎌' => 'kəsişən bayraqlar',
    '🏴' => 'qara bayraq',
    '🏳' => 'ağ bayraq',
];
