<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'مچول: شخص, شخص, د روڼ پوستکي ټون, غنمی-روښانه پوستکۍ',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'مچول: شخص, شخص, د روڼ پوستکي ټون, غنم رنګه',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'مچول: شخص, شخص, د روڼ پوستکي ټون, غنمی-تورنګه پوستکۍ',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'مچول: شخص, شخص, د روڼ پوستکي ټون, تور پوستکۍ',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'مچول: شخص, شخص, غنمی-روښانه پوستکۍ, د روڼ پوستکي ټون',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'مچول: شخص, شخص, غنمی-روښانه پوستکۍ, غنم رنګه',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'مچول: شخص, شخص, غنمی-روښانه پوستکۍ, غنمی-تورنګه پوستکۍ',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'مچول: شخص, شخص, غنمی-روښانه پوستکۍ, تور پوستکۍ',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'مچول: شخص, شخص, غنم رنګه, د روڼ پوستکي ټون',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'مچول: شخص, شخص, غنم رنګه, غنمی-روښانه پوستکۍ',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'مچول: شخص, شخص, غنم رنګه, غنمی-تورنګه پوستکۍ',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'مچول: شخص, شخص, غنم رنګه, تور پوستکۍ',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'مچول: شخص, شخص, غنمی-تورنګه پوستکۍ, د روڼ پوستکي ټون',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'مچول: شخص, شخص, غنمی-تورنګه پوستکۍ, غنمی-روښانه پوستکۍ',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'مچول: شخص, شخص, غنمی-تورنګه پوستکۍ, غنم رنګه',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'مچول: شخص, شخص, غنمی-تورنګه پوستکۍ, تور پوستکۍ',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'مچول: شخص, شخص, تور پوستکۍ, د روڼ پوستکي ټون',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'مچول: شخص, شخص, تور پوستکۍ, غنمی-روښانه پوستکۍ',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'مچول: شخص, شخص, تور پوستکۍ, غنم رنګه',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'مچول: شخص, شخص, تور پوستکۍ, غنمی-تورنګه پوستکۍ',
    '👨🏻‍❤‍💋‍👨🏻' => 'مچول: سړی, سړی, د روڼ پوستکي ټون',
    '👨🏻‍❤‍💋‍👨🏼' => 'مچول: سړی, سړی, د روڼ پوستکي ټون, غنمی-روښانه پوستکۍ',
    '👨🏻‍❤‍💋‍👨🏽' => 'مچول: سړی, سړی, د روڼ پوستکي ټون, غنم رنګه',
    '👨🏻‍❤‍💋‍👨🏾' => 'مچول: سړی, سړی, د روڼ پوستکي ټون, غنمی-تورنګه پوستکۍ',
    '👨🏻‍❤‍💋‍👨🏿' => 'مچول: سړی, سړی, د روڼ پوستکي ټون, تور پوستکۍ',
    '👨🏼‍❤‍💋‍👨🏻' => 'مچول: سړی, سړی, غنمی-روښانه پوستکۍ, د روڼ پوستکي ټون',
    '👨🏼‍❤‍💋‍👨🏼' => 'مچول: سړی, سړی, غنمی-روښانه پوستکۍ',
    '👨🏼‍❤‍💋‍👨🏽' => 'مچول: سړی, سړی, غنمی-روښانه پوستکۍ, غنم رنګه',
    '👨🏼‍❤‍💋‍👨🏾' => 'مچول: سړی, سړی, غنمی-روښانه پوستکۍ, غنمی-تورنګه پوستکۍ',
    '👨🏼‍❤‍💋‍👨🏿' => 'مچول: سړی, سړی, غنمی-روښانه پوستکۍ, تور پوستکۍ',
    '👨🏽‍❤‍💋‍👨🏻' => 'مچول: سړی, سړی, غنم رنګه, د روڼ پوستکي ټون',
    '👨🏽‍❤‍💋‍👨🏼' => 'مچول: سړی, سړی, غنم رنګه, غنمی-روښانه پوستکۍ',
    '👨🏽‍❤‍💋‍👨🏽' => 'مچول: سړی, سړی, غنم رنګه',
    '👨🏽‍❤‍💋‍👨🏾' => 'مچول: سړی, سړی, غنم رنګه, غنمی-تورنګه پوستکۍ',
    '👨🏽‍❤‍💋‍👨🏿' => 'مچول: سړی, سړی, غنم رنګه, تور پوستکۍ',
    '👨🏾‍❤‍💋‍👨🏻' => 'مچول: سړی, سړی, غنمی-تورنګه پوستکۍ, د روڼ پوستکي ټون',
    '👨🏾‍❤‍💋‍👨🏼' => 'مچول: سړی, سړی, غنمی-تورنګه پوستکۍ, غنمی-روښانه پوستکۍ',
    '👨🏾‍❤‍💋‍👨🏽' => 'مچول: سړی, سړی, غنمی-تورنګه پوستکۍ, غنم رنګه',
    '👨🏾‍❤‍💋‍👨🏾' => 'مچول: سړی, سړی, غنمی-تورنګه پوستکۍ',
    '👨🏾‍❤‍💋‍👨🏿' => 'مچول: سړی, سړی, غنمی-تورنګه پوستکۍ, تور پوستکۍ',
    '👨🏿‍❤‍💋‍👨🏻' => 'مچول: سړی, سړی, تور پوستکۍ, د روڼ پوستکي ټون',
    '👨🏿‍❤‍💋‍👨🏼' => 'مچول: سړی, سړی, تور پوستکۍ, غنمی-روښانه پوستکۍ',
    '👨🏿‍❤‍💋‍👨🏽' => 'مچول: سړی, سړی, تور پوستکۍ, غنم رنګه',
    '👨🏿‍❤‍💋‍👨🏾' => 'مچول: سړی, سړی, تور پوستکۍ, غنمی-تورنګه پوستکۍ',
    '👨🏿‍❤‍💋‍👨🏿' => 'مچول: سړی, سړی, تور پوستکۍ',
    '👩🏻‍❤‍💋‍👨🏻' => 'مچول: ښځه, سړی, د روڼ پوستکي ټون',
    '👩🏻‍❤‍💋‍👨🏼' => 'مچول: ښځه, سړی, د روڼ پوستکي ټون, غنمی-روښانه پوستکۍ',
    '👩🏻‍❤‍💋‍👨🏽' => 'مچول: ښځه, سړی, د روڼ پوستکي ټون, غنم رنګه',
    '👩🏻‍❤‍💋‍👨🏾' => 'مچول: ښځه, سړی, د روڼ پوستکي ټون, غنمی-تورنګه پوستکۍ',
    '👩🏻‍❤‍💋‍👨🏿' => 'مچول: ښځه, سړی, د روڼ پوستکي ټون, تور پوستکۍ',
    '👩🏼‍❤‍💋‍👨🏻' => 'مچول: ښځه, سړی, غنمی-روښانه پوستکۍ, د روڼ پوستکي ټون',
    '👩🏼‍❤‍💋‍👨🏼' => 'مچول: ښځه, سړی, غنمی-روښانه پوستکۍ',
    '👩🏼‍❤‍💋‍👨🏽' => 'مچول: ښځه, سړی, غنمی-روښانه پوستکۍ, غنم رنګه',
    '👩🏼‍❤‍💋‍👨🏾' => 'مچول: ښځه, سړی, غنمی-روښانه پوستکۍ, غنمی-تورنګه پوستکۍ',
    '👩🏼‍❤‍💋‍👨🏿' => 'مچول: ښځه, سړی, غنمی-روښانه پوستکۍ, تور پوستکۍ',
    '👩🏽‍❤‍💋‍👨🏻' => 'مچول: ښځه, سړی, غنم رنګه, د روڼ پوستکي ټون',
    '👩🏽‍❤‍💋‍👨🏼' => 'مچول: ښځه, سړی, غنم رنګه, غنمی-روښانه پوستکۍ',
    '👩🏽‍❤‍💋‍👨🏽' => 'مچول: ښځه, سړی, غنم رنګه',
    '👩🏽‍❤‍💋‍👨🏾' => 'مچول: ښځه, سړی, غنم رنګه, غنمی-تورنګه پوستکۍ',
    '👩🏽‍❤‍💋‍👨🏿' => 'مچول: ښځه, سړی, غنم رنګه, تور پوستکۍ',
    '👩🏾‍❤‍💋‍👨🏻' => 'مچول: ښځه, سړی, غنمی-تورنګه پوستکۍ, د روڼ پوستکي ټون',
    '👩🏾‍❤‍💋‍👨🏼' => 'مچول: ښځه, سړی, غنمی-تورنګه پوستکۍ, غنمی-روښانه پوستکۍ',
    '👩🏾‍❤‍💋‍👨🏽' => 'مچول: ښځه, سړی, غنمی-تورنګه پوستکۍ, غنم رنګه',
    '👩🏾‍❤‍💋‍👨🏾' => 'مچول: ښځه, سړی, غنمی-تورنګه پوستکۍ',
    '👩🏾‍❤‍💋‍👨🏿' => 'مچول: ښځه, سړی, غنمی-تورنګه پوستکۍ, تور پوستکۍ',
    '👩🏿‍❤‍💋‍👨🏻' => 'مچول: ښځه, سړی, تور پوستکۍ, د روڼ پوستکي ټون',
    '👩🏿‍❤‍💋‍👨🏼' => 'مچول: ښځه, سړی, تور پوستکۍ, غنمی-روښانه پوستکۍ',
    '👩🏿‍❤‍💋‍👨🏽' => 'مچول: ښځه, سړی, تور پوستکۍ, غنم رنګه',
    '👩🏿‍❤‍💋‍👨🏾' => 'مچول: ښځه, سړی, تور پوستکۍ, غنمی-تورنګه پوستکۍ',
    '👩🏿‍❤‍💋‍👨🏿' => 'مچول: ښځه, سړی, تور پوستکۍ',
    '👩🏻‍❤‍💋‍👩🏻' => 'مچول: ښځه, ښځه, د روڼ پوستکي ټون',
    '👩🏻‍❤‍💋‍👩🏼' => 'مچول: ښځه, ښځه, د روڼ پوستکي ټون, غنمی-روښانه پوستکۍ',
    '👩🏻‍❤‍💋‍👩🏽' => 'مچول: ښځه, ښځه, د روڼ پوستکي ټون, غنم رنګه',
    '👩🏻‍❤‍💋‍👩🏾' => 'مچول: ښځه, ښځه, د روڼ پوستکي ټون, غنمی-تورنګه پوستکۍ',
    '👩🏻‍❤‍💋‍👩🏿' => 'مچول: ښځه, ښځه, د روڼ پوستکي ټون, تور پوستکۍ',
    '👩🏼‍❤‍💋‍👩🏻' => 'مچول: ښځه, ښځه, غنمی-روښانه پوستکۍ, د روڼ پوستکي ټون',
    '👩🏼‍❤‍💋‍👩🏼' => 'مچول: ښځه, ښځه, غنمی-روښانه پوستکۍ',
    '👩🏼‍❤‍💋‍👩🏽' => 'مچول: ښځه, ښځه, غنمی-روښانه پوستکۍ, غنم رنګه',
    '👩🏼‍❤‍💋‍👩🏾' => 'مچول: ښځه, ښځه, غنمی-روښانه پوستکۍ, غنمی-تورنګه پوستکۍ',
    '👩🏼‍❤‍💋‍👩🏿' => 'مچول: ښځه, ښځه, غنمی-روښانه پوستکۍ, تور پوستکۍ',
    '👩🏽‍❤‍💋‍👩🏻' => 'مچول: ښځه, ښځه, غنم رنګه, د روڼ پوستکي ټون',
    '👩🏽‍❤‍💋‍👩🏼' => 'مچول: ښځه, ښځه, غنم رنګه, غنمی-روښانه پوستکۍ',
    '👩🏽‍❤‍💋‍👩🏽' => 'مچول: ښځه, ښځه, غنم رنګه',
    '👩🏽‍❤‍💋‍👩🏾' => 'مچول: ښځه, ښځه, غنم رنګه, غنمی-تورنګه پوستکۍ',
    '👩🏽‍❤‍💋‍👩🏿' => 'مچول: ښځه, ښځه, غنم رنګه, تور پوستکۍ',
    '👩🏾‍❤‍💋‍👩🏻' => 'مچول: ښځه, ښځه, غنمی-تورنګه پوستکۍ, د روڼ پوستکي ټون',
    '👩🏾‍❤‍💋‍👩🏼' => 'مچول: ښځه, ښځه, غنمی-تورنګه پوستکۍ, غنمی-روښانه پوستکۍ',
    '👩🏾‍❤‍💋‍👩🏽' => 'مچول: ښځه, ښځه, غنمی-تورنګه پوستکۍ, غنم رنګه',
    '👩🏾‍❤‍💋‍👩🏾' => 'مچول: ښځه, ښځه, غنمی-تورنګه پوستکۍ',
    '👩🏾‍❤‍💋‍👩🏿' => 'مچول: ښځه, ښځه, غنمی-تورنګه پوستکۍ, تور پوستکۍ',
    '👩🏿‍❤‍💋‍👩🏻' => 'مچول: ښځه, ښځه, تور پوستکۍ, د روڼ پوستکي ټون',
    '👩🏿‍❤‍💋‍👩🏼' => 'مچول: ښځه, ښځه, تور پوستکۍ, غنمی-روښانه پوستکۍ',
    '👩🏿‍❤‍💋‍👩🏽' => 'مچول: ښځه, ښځه, تور پوستکۍ, غنم رنګه',
    '👩🏿‍❤‍💋‍👩🏾' => 'مچول: ښځه, ښځه, تور پوستکۍ, غنمی-تورنګه پوستکۍ',
    '👩🏿‍❤‍💋‍👩🏿' => 'مچول: ښځه, ښځه, تور پوستکۍ',
    '🧑🏻‍🫯‍🧑🏼' => 'خلک پهلواني کوي: د روڼ پوستکي ټون و غنمی-روښانه پوستکۍ',
    '🧑🏻‍🫯‍🧑🏽' => 'خلک پهلواني کوي: د روڼ پوستکي ټون و غنم رنګه',
    '🧑🏻‍🫯‍🧑🏾' => 'خلک پهلواني کوي: د روڼ پوستکي ټون و غنمی-تورنګه پوستکۍ',
    '🧑🏻‍🫯‍🧑🏿' => 'خلک پهلواني کوي: د روڼ پوستکي ټون و تور پوستکۍ',
    '🧑🏼‍🫯‍🧑🏻' => 'خلک پهلواني کوي: غنمی-روښانه پوستکۍ و د روڼ پوستکي ټون',
    '🧑🏼‍🫯‍🧑🏽' => 'خلک پهلواني کوي: غنمی-روښانه پوستکۍ و غنم رنګه',
    '🧑🏼‍🫯‍🧑🏾' => 'خلک پهلواني کوي: غنمی-روښانه پوستکۍ و غنمی-تورنګه پوستکۍ',
    '🧑🏼‍🫯‍🧑🏿' => 'خلک پهلواني کوي: غنمی-روښانه پوستکۍ و تور پوستکۍ',
    '🧑🏽‍🫯‍🧑🏻' => 'خلک پهلواني کوي: غنم رنګه و د روڼ پوستکي ټون',
    '🧑🏽‍🫯‍🧑🏼' => 'خلک پهلواني کوي: غنم رنګه و غنمی-روښانه پوستکۍ',
    '🧑🏽‍🫯‍🧑🏾' => 'خلک پهلواني کوي: غنم رنګه و غنمی-تورنګه پوستکۍ',
    '🧑🏽‍🫯‍🧑🏿' => 'خلک پهلواني کوي: غنم رنګه و تور پوستکۍ',
    '🧑🏾‍🫯‍🧑🏻' => 'خلک پهلواني کوي: غنمی-تورنګه پوستکۍ و د روڼ پوستکي ټون',
    '🧑🏾‍🫯‍🧑🏼' => 'خلک پهلواني کوي: غنمی-تورنګه پوستکۍ و غنمی-روښانه پوستکۍ',
    '🧑🏾‍🫯‍🧑🏽' => 'خلک پهلواني کوي: غنمی-تورنګه پوستکۍ و غنم رنګه',
    '🧑🏾‍🫯‍🧑🏿' => 'خلک پهلواني کوي: غنمی-تورنګه پوستکۍ و تور پوستکۍ',
    '🧑🏿‍🫯‍🧑🏻' => 'خلک پهلواني کوي: تور پوستکۍ و د روڼ پوستکي ټون',
    '🧑🏿‍🫯‍🧑🏼' => 'خلک پهلواني کوي: تور پوستکۍ و غنمی-روښانه پوستکۍ',
    '🧑🏿‍🫯‍🧑🏽' => 'خلک پهلواني کوي: تور پوستکۍ و غنم رنګه',
    '🧑🏿‍🫯‍🧑🏾' => 'خلک پهلواني کوي: تور پوستکۍ و غنمی-تورنګه پوستکۍ',
    '🧑🏻‍❤‍🧑🏼' => 'د زړه سره جوړه: شخص, شخص, د روڼ پوستکي ټون, غنمی-روښانه پوستکۍ',
    '🧑🏻‍❤‍🧑🏽' => 'د زړه سره جوړه: شخص, شخص, د روڼ پوستکي ټون, غنم رنګه',
    '🧑🏻‍❤‍🧑🏾' => 'د زړه سره جوړه: شخص, شخص, د روڼ پوستکي ټون, غنمی-تورنګه پوستکۍ',
    '🧑🏻‍❤‍🧑🏿' => 'د زړه سره جوړه: شخص, شخص, د روڼ پوستکي ټون, تور پوستکۍ',
    '🧑🏼‍❤‍🧑🏻' => 'د زړه سره جوړه: شخص, شخص, غنمی-روښانه پوستکۍ, د روڼ پوستکي ټون',
    '🧑🏼‍❤‍🧑🏽' => 'د زړه سره جوړه: شخص, شخص, غنمی-روښانه پوستکۍ, غنم رنګه',
    '🧑🏼‍❤‍🧑🏾' => 'د زړه سره جوړه: شخص, شخص, غنمی-روښانه پوستکۍ, غنمی-تورنګه پوستکۍ',
    '🧑🏼‍❤‍🧑🏿' => 'د زړه سره جوړه: شخص, شخص, غنمی-روښانه پوستکۍ, تور پوستکۍ',
    '🧑🏽‍❤‍🧑🏻' => 'د زړه سره جوړه: شخص, شخص, غنم رنګه, د روڼ پوستکي ټون',
    '🧑🏽‍❤‍🧑🏼' => 'د زړه سره جوړه: شخص, شخص, غنم رنګه, غنمی-روښانه پوستکۍ',
    '🧑🏽‍❤‍🧑🏾' => 'د زړه سره جوړه: شخص, شخص, غنم رنګه, غنمی-تورنګه پوستکۍ',
    '🧑🏽‍❤‍🧑🏿' => 'د زړه سره جوړه: شخص, شخص, غنم رنګه, تور پوستکۍ',
    '🧑🏾‍❤‍🧑🏻' => 'د زړه سره جوړه: شخص, شخص, غنمی-تورنګه پوستکۍ, د روڼ پوستکي ټون',
    '🧑🏾‍❤‍🧑🏼' => 'د زړه سره جوړه: شخص, شخص, غنمی-تورنګه پوستکۍ, غنمی-روښانه پوستکۍ',
    '🧑🏾‍❤‍🧑🏽' => 'د زړه سره جوړه: شخص, شخص, غنمی-تورنګه پوستکۍ, غنم رنګه',
    '🧑🏾‍❤‍🧑🏿' => 'د زړه سره جوړه: شخص, شخص, غنمی-تورنګه پوستکۍ, تور پوستکۍ',
    '🧑🏿‍❤‍🧑🏻' => 'د زړه سره جوړه: شخص, شخص, تور پوستکۍ, د روڼ پوستکي ټون',
    '🧑🏿‍❤‍🧑🏼' => 'د زړه سره جوړه: شخص, شخص, تور پوستکۍ, غنمی-روښانه پوستکۍ',
    '🧑🏿‍❤‍🧑🏽' => 'د زړه سره جوړه: شخص, شخص, تور پوستکۍ, غنم رنګه',
    '🧑🏿‍❤‍🧑🏾' => 'د زړه سره جوړه: شخص, شخص, تور پوستکۍ, غنمی-تورنګه پوستکۍ',
    '🧑🏻‍🐰‍🧑🏼' => 'خلک د سويې غوږونو سره: د روڼ پوستکي ټون و غنمی-روښانه پوستکۍ',
    '🧑🏻‍🐰‍🧑🏽' => 'خلک د سويې غوږونو سره: د روڼ پوستکي ټون و غنم رنګه',
    '🧑🏻‍🐰‍🧑🏾' => 'خلک د سويې غوږونو سره: د روڼ پوستکي ټون و غنمی-تورنګه پوستکۍ',
    '🧑🏻‍🐰‍🧑🏿' => 'خلک د سويې غوږونو سره: د روڼ پوستکي ټون و تور پوستکۍ',
    '🧑🏼‍🐰‍🧑🏻' => 'خلک د سويې غوږونو سره: غنمی-روښانه پوستکۍ و د روڼ پوستکي ټون',
    '🧑🏼‍🐰‍🧑🏽' => 'خلک د سويې غوږونو سره: غنمی-روښانه پوستکۍ و غنم رنګه',
    '🧑🏼‍🐰‍🧑🏾' => 'خلک د سويې غوږونو سره: غنمی-روښانه پوستکۍ و غنمی-تورنګه پوستکۍ',
    '🧑🏼‍🐰‍🧑🏿' => 'خلک د سويې غوږونو سره: غنمی-روښانه پوستکۍ و تور پوستکۍ',
    '🧑🏽‍🐰‍🧑🏻' => 'خلک د سويې غوږونو سره: غنم رنګه و د روڼ پوستکي ټون',
    '🧑🏽‍🐰‍🧑🏼' => 'خلک د سويې غوږونو سره: غنم رنګه و غنمی-روښانه پوستکۍ',
    '🧑🏽‍🐰‍🧑🏾' => 'خلک د سويې غوږونو سره: غنم رنګه و غنمی-تورنګه پوستکۍ',
    '🧑🏽‍🐰‍🧑🏿' => 'خلک د سويې غوږونو سره: غنم رنګه و تور پوستکۍ',
    '🧑🏾‍🐰‍🧑🏻' => 'خلک د سويې غوږونو سره: غنمی-تورنګه پوستکۍ و د روڼ پوستکي ټون',
    '🧑🏾‍🐰‍🧑🏼' => 'خلک د سويې غوږونو سره: غنمی-تورنګه پوستکۍ و غنمی-روښانه پوستکۍ',
    '🧑🏾‍🐰‍🧑🏽' => 'خلک د سويې غوږونو سره: غنمی-تورنګه پوستکۍ و غنم رنګه',
    '🧑🏾‍🐰‍🧑🏿' => 'خلک د سويې غوږونو سره: غنمی-تورنګه پوستکۍ و تور پوستکۍ',
    '🧑🏿‍🐰‍🧑🏻' => 'خلک د سويې غوږونو سره: تور پوستکۍ و د روڼ پوستکي ټون',
    '🧑🏿‍🐰‍🧑🏼' => 'خلک د سويې غوږونو سره: تور پوستکۍ و غنمی-روښانه پوستکۍ',
    '🧑🏿‍🐰‍🧑🏽' => 'خلک د سويې غوږونو سره: تور پوستکۍ و غنم رنګه',
    '🧑🏿‍🐰‍🧑🏾' => 'خلک د سويې غوږونو سره: تور پوستکۍ و غنمی-تورنګه پوستکۍ',
    '👨🏻‍🫯‍👨🏼' => 'سړي پهلواني کوي: د روڼ پوستکي ټون و غنمی-روښانه پوستکۍ',
    '👨🏻‍🫯‍👨🏽' => 'سړي پهلواني کوي: د روڼ پوستکي ټون و غنم رنګه',
    '👨🏻‍🫯‍👨🏾' => 'سړي پهلواني کوي: د روڼ پوستکي ټون و غنمی-تورنګه پوستکۍ',
    '👨🏻‍🫯‍👨🏿' => 'سړي پهلواني کوي: د روڼ پوستکي ټون و تور پوستکۍ',
    '👨🏼‍🫯‍👨🏻' => 'سړي پهلواني کوي: غنمی-روښانه پوستکۍ و د روڼ پوستکي ټون',
    '👨🏼‍🫯‍👨🏽' => 'سړي پهلواني کوي: غنمی-روښانه پوستکۍ و غنم رنګه',
    '👨🏼‍🫯‍👨🏾' => 'سړي پهلواني کوي: غنمی-روښانه پوستکۍ و غنمی-تورنګه پوستکۍ',
    '👨🏼‍🫯‍👨🏿' => 'سړي پهلواني کوي: غنمی-روښانه پوستکۍ و تور پوستکۍ',
    '👨🏽‍🫯‍👨🏻' => 'سړي پهلواني کوي: غنم رنګه و د روڼ پوستکي ټون',
    '👨🏽‍🫯‍👨🏼' => 'سړي پهلواني کوي: غنم رنګه و غنمی-روښانه پوستکۍ',
    '👨🏽‍🫯‍👨🏾' => 'سړي پهلواني کوي: غنم رنګه و غنمی-تورنګه پوستکۍ',
    '👨🏽‍🫯‍👨🏿' => 'سړي پهلواني کوي: غنم رنګه و تور پوستکۍ',
    '👨🏾‍🫯‍👨🏻' => 'سړي پهلواني کوي: غنمی-تورنګه پوستکۍ و د روڼ پوستکي ټون',
    '👨🏾‍🫯‍👨🏼' => 'سړي پهلواني کوي: غنمی-تورنګه پوستکۍ و غنمی-روښانه پوستکۍ',
    '👨🏾‍🫯‍👨🏽' => 'سړي پهلواني کوي: غنمی-تورنګه پوستکۍ و غنم رنګه',
    '👨🏾‍🫯‍👨🏿' => 'سړي پهلواني کوي: غنمی-تورنګه پوستکۍ و تور پوستکۍ',
    '👨🏿‍🫯‍👨🏻' => 'سړي پهلواني کوي: تور پوستکۍ و د روڼ پوستکي ټون',
    '👨🏿‍🫯‍👨🏼' => 'سړي پهلواني کوي: تور پوستکۍ و غنمی-روښانه پوستکۍ',
    '👨🏿‍🫯‍👨🏽' => 'سړي پهلواني کوي: تور پوستکۍ و غنم رنګه',
    '👨🏿‍🫯‍👨🏾' => 'سړي پهلواني کوي: تور پوستکۍ و غنمی-تورنګه پوستکۍ',
    '👨🏻‍❤‍👨🏻' => 'د زړه سره جوړه: سړی, سړی, د روڼ پوستکي ټون',
    '👨🏻‍❤‍👨🏼' => 'د زړه سره جوړه: سړی, سړی, د روڼ پوستکي ټون, غنمی-روښانه پوستکۍ',
    '👨🏻‍❤‍👨🏽' => 'د زړه سره جوړه: سړی, سړی, د روڼ پوستکي ټون, غنم رنګه',
    '👨🏻‍❤‍👨🏾' => 'د زړه سره جوړه: سړی, سړی, د روڼ پوستکي ټون, غنمی-تورنګه پوستکۍ',
    '👨🏻‍❤‍👨🏿' => 'د زړه سره جوړه: سړی, سړی, د روڼ پوستکي ټون, تور پوستکۍ',
    '👨🏼‍❤‍👨🏻' => 'د زړه سره جوړه: سړی, سړی, غنمی-روښانه پوستکۍ, د روڼ پوستکي ټون',
    '👨🏼‍❤‍👨🏼' => 'د زړه سره جوړه: سړی, سړی, غنمی-روښانه پوستکۍ',
    '👨🏼‍❤‍👨🏽' => 'د زړه سره جوړه: سړی, سړی, غنمی-روښانه پوستکۍ, غنم رنګه',
    '👨🏼‍❤‍👨🏾' => 'د زړه سره جوړه: سړی, سړی, غنمی-روښانه پوستکۍ, غنمی-تورنګه پوستکۍ',
    '👨🏼‍❤‍👨🏿' => 'د زړه سره جوړه: سړی, سړی, غنمی-روښانه پوستکۍ, تور پوستکۍ',
    '👨🏽‍❤‍👨🏻' => 'د زړه سره جوړه: سړی, سړی, غنم رنګه, د روڼ پوستکي ټون',
    '👨🏽‍❤‍👨🏼' => 'د زړه سره جوړه: سړی, سړی, غنم رنګه, غنمی-روښانه پوستکۍ',
    '👨🏽‍❤‍👨🏽' => 'د زړه سره جوړه: سړی, سړی, غنم رنګه',
    '👨🏽‍❤‍👨🏾' => 'د زړه سره جوړه: سړی, سړی, غنم رنګه, غنمی-تورنګه پوستکۍ',
    '👨🏽‍❤‍👨🏿' => 'د زړه سره جوړه: سړی, سړی, غنم رنګه, تور پوستکۍ',
    '👨🏾‍❤‍👨🏻' => 'د زړه سره جوړه: سړی, سړی, غنمی-تورنګه پوستکۍ, د روڼ پوستکي ټون',
    '👨🏾‍❤‍👨🏼' => 'د زړه سره جوړه: سړی, سړی, غنمی-تورنګه پوستکۍ, غنمی-روښانه پوستکۍ',
    '👨🏾‍❤‍👨🏽' => 'د زړه سره جوړه: سړی, سړی, غنمی-تورنګه پوستکۍ, غنم رنګه',
    '👨🏾‍❤‍👨🏾' => 'د زړه سره جوړه: سړی, سړی, غنمی-تورنګه پوستکۍ',
    '👨🏾‍❤‍👨🏿' => 'د زړه سره جوړه: سړی, سړی, غنمی-تورنګه پوستکۍ, تور پوستکۍ',
    '👨🏿‍❤‍👨🏻' => 'د زړه سره جوړه: سړی, سړی, تور پوستکۍ, د روڼ پوستکي ټون',
    '👨🏿‍❤‍👨🏼' => 'د زړه سره جوړه: سړی, سړی, تور پوستکۍ, غنمی-روښانه پوستکۍ',
    '👨🏿‍❤‍👨🏽' => 'د زړه سره جوړه: سړی, سړی, تور پوستکۍ, غنم رنګه',
    '👨🏿‍❤‍👨🏾' => 'د زړه سره جوړه: سړی, سړی, تور پوستکۍ, غنمی-تورنګه پوستکۍ',
    '👨🏿‍❤‍👨🏿' => 'د زړه سره جوړه: سړی, سړی, تور پوستکۍ',
    '👨🏻‍🐰‍👨🏼' => 'سړی د سويې غوږونو سره: د روڼ پوستکي ټون و غنمی-روښانه پوستکۍ',
    '👨🏻‍🐰‍👨🏽' => 'سړی د سويې غوږونو سره: د روڼ پوستکي ټون و غنم رنګه',
    '👨🏻‍🐰‍👨🏾' => 'سړی د سويې غوږونو سره: د روڼ پوستکي ټون و غنمی-تورنګه پوستکۍ',
    '👨🏻‍🐰‍👨🏿' => 'سړی د سويې غوږونو سره: د روڼ پوستکي ټون و تور پوستکۍ',
    '👨🏼‍🐰‍👨🏻' => 'سړی د سويې غوږونو سره: غنمی-روښانه پوستکۍ و د روڼ پوستکي ټون',
    '👨🏼‍🐰‍👨🏽' => 'سړی د سويې غوږونو سره: غنمی-روښانه پوستکۍ و غنم رنګه',
    '👨🏼‍🐰‍👨🏾' => 'سړی د سويې غوږونو سره: غنمی-روښانه پوستکۍ و غنمی-تورنګه پوستکۍ',
    '👨🏼‍🐰‍👨🏿' => 'سړی د سويې غوږونو سره: غنمی-روښانه پوستکۍ و تور پوستکۍ',
    '👨🏽‍🐰‍👨🏻' => 'سړی د سويې غوږونو سره: غنم رنګه و د روڼ پوستکي ټون',
    '👨🏽‍🐰‍👨🏼' => 'سړی د سويې غوږونو سره: غنم رنګه و غنمی-روښانه پوستکۍ',
    '👨🏽‍🐰‍👨🏾' => 'سړی د سويې غوږونو سره: غنم رنګه و غنمی-تورنګه پوستکۍ',
    '👨🏽‍🐰‍👨🏿' => 'سړی د سويې غوږونو سره: غنم رنګه و تور پوستکۍ',
    '👨🏾‍🐰‍👨🏻' => 'سړی د سويې غوږونو سره: غنمی-تورنګه پوستکۍ و د روڼ پوستکي ټون',
    '👨🏾‍🐰‍👨🏼' => 'سړی د سويې غوږونو سره: غنمی-تورنګه پوستکۍ و غنمی-روښانه پوستکۍ',
    '👨🏾‍🐰‍👨🏽' => 'سړی د سويې غوږونو سره: غنمی-تورنګه پوستکۍ و غنم رنګه',
    '👨🏾‍🐰‍👨🏿' => 'سړی د سويې غوږونو سره: غنمی-تورنګه پوستکۍ و تور پوستکۍ',
    '👨🏿‍🐰‍👨🏻' => 'سړی د سويې غوږونو سره: تور پوستکۍ و د روڼ پوستکي ټون',
    '👨🏿‍🐰‍👨🏼' => 'سړی د سويې غوږونو سره: تور پوستکۍ و غنمی-روښانه پوستکۍ',
    '👨🏿‍🐰‍👨🏽' => 'سړی د سويې غوږونو سره: تور پوستکۍ و غنم رنګه',
    '👨🏿‍🐰‍👨🏾' => 'سړی د سويې غوږونو سره: تور پوستکۍ و غنمی-تورنګه پوستکۍ',
    '👩🏻‍🫯‍👩🏼' => 'ښځې پهلواني کوي: د روڼ پوستکي ټون و غنمی-روښانه پوستکۍ',
    '👩🏻‍🫯‍👩🏽' => 'ښځې پهلواني کوي: د روڼ پوستکي ټون و غنم رنګه',
    '👩🏻‍🫯‍👩🏾' => 'ښځې پهلواني کوي: د روڼ پوستکي ټون و غنمی-تورنګه پوستکۍ',
    '👩🏻‍🫯‍👩🏿' => 'ښځې پهلواني کوي: د روڼ پوستکي ټون و تور پوستکۍ',
    '👩🏼‍🫯‍👩🏻' => 'ښځې پهلواني کوي: غنمی-روښانه پوستکۍ و د روڼ پوستکي ټون',
    '👩🏼‍🫯‍👩🏽' => 'ښځې پهلواني کوي: غنمی-روښانه پوستکۍ و غنم رنګه',
    '👩🏼‍🫯‍👩🏾' => 'ښځې پهلواني کوي: غنمی-روښانه پوستکۍ و غنمی-تورنګه پوستکۍ',
    '👩🏼‍🫯‍👩🏿' => 'ښځې پهلواني کوي: غنمی-روښانه پوستکۍ و تور پوستکۍ',
    '👩🏽‍🫯‍👩🏻' => 'ښځې پهلواني کوي: غنم رنګه و د روڼ پوستکي ټون',
    '👩🏽‍🫯‍👩🏼' => 'ښځې پهلواني کوي: غنم رنګه و غنمی-روښانه پوستکۍ',
    '👩🏽‍🫯‍👩🏾' => 'ښځې پهلواني کوي: غنم رنګه و غنمی-تورنګه پوستکۍ',
    '👩🏽‍🫯‍👩🏿' => 'ښځې پهلواني کوي: غنم رنګه و تور پوستکۍ',
    '👩🏾‍🫯‍👩🏻' => 'ښځې پهلواني کوي: غنمی-تورنګه پوستکۍ و د روڼ پوستکي ټون',
    '👩🏾‍🫯‍👩🏼' => 'ښځې پهلواني کوي: غنمی-تورنګه پوستکۍ و غنمی-روښانه پوستکۍ',
    '👩🏾‍🫯‍👩🏽' => 'ښځې پهلواني کوي: غنمی-تورنګه پوستکۍ و غنم رنګه',
    '👩🏾‍🫯‍👩🏿' => 'ښځې پهلواني کوي: غنمی-تورنګه پوستکۍ و تور پوستکۍ',
    '👩🏿‍🫯‍👩🏻' => 'ښځې پهلواني کوي: تور پوستکۍ و د روڼ پوستکي ټون',
    '👩🏿‍🫯‍👩🏼' => 'ښځې پهلواني کوي: تور پوستکۍ و غنمی-روښانه پوستکۍ',
    '👩🏿‍🫯‍👩🏽' => 'ښځې پهلواني کوي: تور پوستکۍ و غنم رنګه',
    '👩🏿‍🫯‍👩🏾' => 'ښځې پهلواني کوي: تور پوستکۍ و غنمی-تورنګه پوستکۍ',
    '👩🏻‍❤‍👨🏻' => 'د زړه سره جوړه: ښځه, سړی, د روڼ پوستکي ټون',
    '👩🏻‍❤‍👨🏼' => 'د زړه سره جوړه: ښځه, سړی, د روڼ پوستکي ټون, غنمی-روښانه پوستکۍ',
    '👩🏻‍❤‍👨🏽' => 'د زړه سره جوړه: ښځه, سړی, د روڼ پوستکي ټون, غنم رنګه',
    '👩🏻‍❤‍👨🏾' => 'د زړه سره جوړه: ښځه, سړی, د روڼ پوستکي ټون, غنمی-تورنګه پوستکۍ',
    '👩🏻‍❤‍👨🏿' => 'د زړه سره جوړه: ښځه, سړی, د روڼ پوستکي ټون, تور پوستکۍ',
    '👩🏼‍❤‍👨🏻' => 'د زړه سره جوړه: ښځه, سړی, غنمی-روښانه پوستکۍ, د روڼ پوستکي ټون',
    '👩🏼‍❤‍👨🏼' => 'د زړه سره جوړه: ښځه, سړی, غنمی-روښانه پوستکۍ',
    '👩🏼‍❤‍👨🏽' => 'د زړه سره جوړه: ښځه, سړی, غنمی-روښانه پوستکۍ, غنم رنګه',
    '👩🏼‍❤‍👨🏾' => 'د زړه سره جوړه: ښځه, سړی, غنمی-روښانه پوستکۍ, غنمی-تورنګه پوستکۍ',
    '👩🏼‍❤‍👨🏿' => 'د زړه سره جوړه: ښځه, سړی, غنمی-روښانه پوستکۍ, تور پوستکۍ',
    '👩🏽‍❤‍👨🏻' => 'د زړه سره جوړه: ښځه, سړی, غنم رنګه, د روڼ پوستکي ټون',
    '👩🏽‍❤‍👨🏼' => 'د زړه سره جوړه: ښځه, سړی, غنم رنګه, غنمی-روښانه پوستکۍ',
    '👩🏽‍❤‍👨🏽' => 'د زړه سره جوړه: ښځه, سړی, غنم رنګه',
    '👩🏽‍❤‍👨🏾' => 'د زړه سره جوړه: ښځه, سړی, غنم رنګه, غنمی-تورنګه پوستکۍ',
    '👩🏽‍❤‍👨🏿' => 'د زړه سره جوړه: ښځه, سړی, غنم رنګه, تور پوستکۍ',
    '👩🏾‍❤‍👨🏻' => 'د زړه سره جوړه: ښځه, سړی, غنمی-تورنګه پوستکۍ, د روڼ پوستکي ټون',
    '👩🏾‍❤‍👨🏼' => 'د زړه سره جوړه: ښځه, سړی, غنمی-تورنګه پوستکۍ, غنمی-روښانه پوستکۍ',
    '👩🏾‍❤‍👨🏽' => 'د زړه سره جوړه: ښځه, سړی, غنمی-تورنګه پوستکۍ, غنم رنګه',
    '👩🏾‍❤‍👨🏾' => 'د زړه سره جوړه: ښځه, سړی, غنمی-تورنګه پوستکۍ',
    '👩🏾‍❤‍👨🏿' => 'د زړه سره جوړه: ښځه, سړی, غنمی-تورنګه پوستکۍ, تور پوستکۍ',
    '👩🏿‍❤‍👨🏻' => 'د زړه سره جوړه: ښځه, سړی, تور پوستکۍ, د روڼ پوستکي ټون',
    '👩🏿‍❤‍👨🏼' => 'د زړه سره جوړه: ښځه, سړی, تور پوستکۍ, غنمی-روښانه پوستکۍ',
    '👩🏿‍❤‍👨🏽' => 'د زړه سره جوړه: ښځه, سړی, تور پوستکۍ, غنم رنګه',
    '👩🏿‍❤‍👨🏾' => 'د زړه سره جوړه: ښځه, سړی, تور پوستکۍ, غنمی-تورنګه پوستکۍ',
    '👩🏿‍❤‍👨🏿' => 'د زړه سره جوړه: ښځه, سړی, تور پوستکۍ',
    '👩🏻‍❤‍👩🏻' => 'د زړه سره جوړه: ښځه, ښځه, د روڼ پوستکي ټون',
    '👩🏻‍❤‍👩🏼' => 'د زړه سره جوړه: ښځه, ښځه, د روڼ پوستکي ټون, غنمی-روښانه پوستکۍ',
    '👩🏻‍❤‍👩🏽' => 'د زړه سره جوړه: ښځه, ښځه, د روڼ پوستکي ټون, غنم رنګه',
    '👩🏻‍❤‍👩🏾' => 'د زړه سره جوړه: ښځه, ښځه, د روڼ پوستکي ټون, غنمی-تورنګه پوستکۍ',
    '👩🏻‍❤‍👩🏿' => 'د زړه سره جوړه: ښځه, ښځه, د روڼ پوستکي ټون, تور پوستکۍ',
    '👩🏼‍❤‍👩🏻' => 'د زړه سره جوړه: ښځه, ښځه, غنمی-روښانه پوستکۍ, د روڼ پوستکي ټون',
    '👩🏼‍❤‍👩🏼' => 'د زړه سره جوړه: ښځه, ښځه, غنمی-روښانه پوستکۍ',
    '👩🏼‍❤‍👩🏽' => 'د زړه سره جوړه: ښځه, ښځه, غنمی-روښانه پوستکۍ, غنم رنګه',
    '👩🏼‍❤‍👩🏾' => 'د زړه سره جوړه: ښځه, ښځه, غنمی-روښانه پوستکۍ, غنمی-تورنګه پوستکۍ',
    '👩🏼‍❤‍👩🏿' => 'د زړه سره جوړه: ښځه, ښځه, غنمی-روښانه پوستکۍ, تور پوستکۍ',
    '👩🏽‍❤‍👩🏻' => 'د زړه سره جوړه: ښځه, ښځه, غنم رنګه, د روڼ پوستکي ټون',
    '👩🏽‍❤‍👩🏼' => 'د زړه سره جوړه: ښځه, ښځه, غنم رنګه, غنمی-روښانه پوستکۍ',
    '👩🏽‍❤‍👩🏽' => 'د زړه سره جوړه: ښځه, ښځه, غنم رنګه',
    '👩🏽‍❤‍👩🏾' => 'د زړه سره جوړه: ښځه, ښځه, غنم رنګه, غنمی-تورنګه پوستکۍ',
    '👩🏽‍❤‍👩🏿' => 'د زړه سره جوړه: ښځه, ښځه, غنم رنګه, تور پوستکۍ',
    '👩🏾‍❤‍👩🏻' => 'د زړه سره جوړه: ښځه, ښځه, غنمی-تورنګه پوستکۍ, د روڼ پوستکي ټون',
    '👩🏾‍❤‍👩🏼' => 'د زړه سره جوړه: ښځه, ښځه, غنمی-تورنګه پوستکۍ, غنمی-روښانه پوستکۍ',
    '👩🏾‍❤‍👩🏽' => 'د زړه سره جوړه: ښځه, ښځه, غنمی-تورنګه پوستکۍ, غنم رنګه',
    '👩🏾‍❤‍👩🏾' => 'د زړه سره جوړه: ښځه, ښځه, غنمی-تورنګه پوستکۍ',
    '👩🏾‍❤‍👩🏿' => 'د زړه سره جوړه: ښځه, ښځه, غنمی-تورنګه پوستکۍ, تور پوستکۍ',
    '👩🏿‍❤‍👩🏻' => 'د زړه سره جوړه: ښځه, ښځه, تور پوستکۍ, د روڼ پوستکي ټون',
    '👩🏿‍❤‍👩🏼' => 'د زړه سره جوړه: ښځه, ښځه, تور پوستکۍ, غنمی-روښانه پوستکۍ',
    '👩🏿‍❤‍👩🏽' => 'د زړه سره جوړه: ښځه, ښځه, تور پوستکۍ, غنم رنګه',
    '👩🏿‍❤‍👩🏾' => 'د زړه سره جوړه: ښځه, ښځه, تور پوستکۍ, غنمی-تورنګه پوستکۍ',
    '👩🏿‍❤‍👩🏿' => 'د زړه سره جوړه: ښځه, ښځه, تور پوستکۍ',
    '👩🏻‍🐰‍👩🏼' => 'ښځې د سويې غوږونو سره: د روڼ پوستکي ټون و غنمی-روښانه پوستکۍ',
    '👩🏻‍🐰‍👩🏽' => 'ښځې د سويې غوږونو سره: د روڼ پوستکي ټون و غنم رنګه',
    '👩🏻‍🐰‍👩🏾' => 'ښځې د سويې غوږونو سره: د روڼ پوستکي ټون و غنمی-تورنګه پوستکۍ',
    '👩🏻‍🐰‍👩🏿' => 'ښځې د سويې غوږونو سره: د روڼ پوستکي ټون و تور پوستکۍ',
    '👩🏼‍🐰‍👩🏻' => 'ښځې د سويې غوږونو سره: غنمی-روښانه پوستکۍ و د روڼ پوستکي ټون',
    '👩🏼‍🐰‍👩🏽' => 'ښځې د سويې غوږونو سره: غنمی-روښانه پوستکۍ و غنم رنګه',
    '👩🏼‍🐰‍👩🏾' => 'ښځې د سويې غوږونو سره: غنمی-روښانه پوستکۍ و غنمی-تورنګه پوستکۍ',
    '👩🏼‍🐰‍👩🏿' => 'ښځې د سويې غوږونو سره: غنمی-روښانه پوستکۍ و تور پوستکۍ',
    '👩🏽‍🐰‍👩🏻' => 'ښځې د سويې غوږونو سره: غنم رنګه و د روڼ پوستکي ټون',
    '👩🏽‍🐰‍👩🏼' => 'ښځې د سويې غوږونو سره: غنم رنګه و غنمی-روښانه پوستکۍ',
    '👩🏽‍🐰‍👩🏾' => 'ښځې د سويې غوږونو سره: غنم رنګه و غنمی-تورنګه پوستکۍ',
    '👩🏽‍🐰‍👩🏿' => 'ښځې د سويې غوږونو سره: غنم رنګه و تور پوستکۍ',
    '👩🏾‍🐰‍👩🏻' => 'ښځې د سويې غوږونو سره: غنمی-تورنګه پوستکۍ و د روڼ پوستکي ټون',
    '👩🏾‍🐰‍👩🏼' => 'ښځې د سويې غوږونو سره: غنمی-تورنګه پوستکۍ و غنمی-روښانه پوستکۍ',
    '👩🏾‍🐰‍👩🏽' => 'ښځې د سويې غوږونو سره: غنمی-تورنګه پوستکۍ و غنم رنګه',
    '👩🏾‍🐰‍👩🏿' => 'ښځې د سويې غوږونو سره: غنمی-تورنګه پوستکۍ و تور پوستکۍ',
    '👩🏿‍🐰‍👩🏻' => 'ښځې د سويې غوږونو سره: تور پوستکۍ و د روڼ پوستکي ټون',
    '👩🏿‍🐰‍👩🏼' => 'ښځې د سويې غوږونو سره: تور پوستکۍ و غنمی-روښانه پوستکۍ',
    '👩🏿‍🐰‍👩🏽' => 'ښځې د سويې غوږونو سره: تور پوستکۍ و غنم رنګه',
    '👩🏿‍🐰‍👩🏾' => 'ښځې د سويې غوږونو سره: تور پوستکۍ و غنمی-تورنګه پوستکۍ',
    '🧑🏻‍🤝‍🧑🏻' => 'خلکو لاسونه نيولي: د روڼ پوستکي ټون',
    '🧑🏻‍🤝‍🧑🏼' => 'خلکو لاسونه نيولي: د روڼ پوستکي ټون و غنمی-روښانه پوستکۍ',
    '🧑🏻‍🤝‍🧑🏽' => 'خلکو لاسونه نيولي: د روڼ پوستکي ټون و غنم رنګه',
    '🧑🏻‍🤝‍🧑🏾' => 'خلکو لاسونه نيولي: د روڼ پوستکي ټون و غنمی-تورنګه پوستکۍ',
    '🧑🏻‍🤝‍🧑🏿' => 'خلکو لاسونه نيولي: د روڼ پوستکي ټون و تور پوستکۍ',
    '🧑🏼‍🤝‍🧑🏻' => 'خلکو لاسونه نيولي: غنمی-روښانه پوستکۍ و د روڼ پوستکي ټون',
    '🧑🏼‍🤝‍🧑🏼' => 'خلکو لاسونه نيولي: غنمی-روښانه پوستکۍ',
    '🧑🏼‍🤝‍🧑🏽' => 'خلکو لاسونه نيولي: غنمی-روښانه پوستکۍ و غنم رنګه',
    '🧑🏼‍🤝‍🧑🏾' => 'خلکو لاسونه نيولي: غنمی-روښانه پوستکۍ و غنمی-تورنګه پوستکۍ',
    '🧑🏼‍🤝‍🧑🏿' => 'خلکو لاسونه نيولي: غنمی-روښانه پوستکۍ و تور پوستکۍ',
    '🧑🏽‍🤝‍🧑🏻' => 'خلکو لاسونه نيولي: غنم رنګه و د روڼ پوستکي ټون',
    '🧑🏽‍🤝‍🧑🏼' => 'خلکو لاسونه نيولي: غنم رنګه و غنمی-روښانه پوستکۍ',
    '🧑🏽‍🤝‍🧑🏽' => 'خلکو لاسونه نيولي: غنم رنګه',
    '🧑🏽‍🤝‍🧑🏾' => 'خلکو لاسونه نيولي: غنم رنګه و غنمی-تورنګه پوستکۍ',
    '🧑🏽‍🤝‍🧑🏿' => 'خلکو لاسونه نيولي: غنم رنګه و تور پوستکۍ',
    '🧑🏾‍🤝‍🧑🏻' => 'خلکو لاسونه نيولي: غنمی-تورنګه پوستکۍ و د روڼ پوستکي ټون',
    '🧑🏾‍🤝‍🧑🏼' => 'خلکو لاسونه نيولي: غنمی-تورنګه پوستکۍ و غنمی-روښانه پوستکۍ',
    '🧑🏾‍🤝‍🧑🏽' => 'خلکو لاسونه نيولي: غنمی-تورنګه پوستکۍ و غنم رنګه',
    '🧑🏾‍🤝‍🧑🏾' => 'خلکو لاسونه نيولي: غنمی-تورنګه پوستکۍ',
    '🧑🏾‍🤝‍🧑🏿' => 'خلکو لاسونه نيولي: غنمی-تورنګه پوستکۍ و تور پوستکۍ',
    '🧑🏿‍🤝‍🧑🏻' => 'خلکو لاسونه نيولي: تور پوستکۍ و د روڼ پوستکي ټون',
    '🧑🏿‍🤝‍🧑🏼' => 'خلکو لاسونه نيولي: تور پوستکۍ و غنمی-روښانه پوستکۍ',
    '🧑🏿‍🤝‍🧑🏽' => 'خلکو لاسونه نيولي: تور پوستکۍ و غنم رنګه',
    '🧑🏿‍🤝‍🧑🏾' => 'خلکو لاسونه نيولي: تور پوستکۍ و غنمی-تورنګه پوستکۍ',
    '🧑🏿‍🤝‍🧑🏿' => 'خلکو لاسونه نيولي: تور پوستکۍ',
    '👩🏻‍🤝‍👩🏼' => 'دوه ښځو لاسونه نيولي: د روڼ پوستکي ټون و غنمی-روښانه پوستکۍ',
    '👩🏻‍🤝‍👩🏽' => 'دوه ښځو لاسونه نيولي: د روڼ پوستکي ټون و غنم رنګه',
    '👩🏻‍🤝‍👩🏾' => 'دوه ښځو لاسونه نيولي: د روڼ پوستکي ټون و غنمی-تورنګه پوستکۍ',
    '👩🏻‍🤝‍👩🏿' => 'دوه ښځو لاسونه نيولي: د روڼ پوستکي ټون و تور پوستکۍ',
    '👩🏼‍🤝‍👩🏻' => 'دوه ښځو لاسونه نيولي: غنمی-روښانه پوستکۍ و د روڼ پوستکي ټون',
    '👩🏼‍🤝‍👩🏽' => 'دوه ښځو لاسونه نيولي: غنمی-روښانه پوستکۍ و غنم رنګه',
    '👩🏼‍🤝‍👩🏾' => 'دوه ښځو لاسونه نيولي: غنمی-روښانه پوستکۍ و غنمی-تورنګه پوستکۍ',
    '👩🏼‍🤝‍👩🏿' => 'دوه ښځو لاسونه نيولي: غنمی-روښانه پوستکۍ و تور پوستکۍ',
    '👩🏽‍🤝‍👩🏻' => 'دوه ښځو لاسونه نيولي: غنم رنګه و د روڼ پوستکي ټون',
    '👩🏽‍🤝‍👩🏼' => 'دوه ښځو لاسونه نيولي: غنم رنګه و غنمی-روښانه پوستکۍ',
    '👩🏽‍🤝‍👩🏾' => 'دوه ښځو لاسونه نيولي: غنم رنګه و غنمی-تورنګه پوستکۍ',
    '👩🏽‍🤝‍👩🏿' => 'دوه ښځو لاسونه نيولي: غنم رنګه و تور پوستکۍ',
    '👩🏾‍🤝‍👩🏻' => 'دوه ښځو لاسونه نيولي: غنمی-تورنګه پوستکۍ و د روڼ پوستکي ټون',
    '👩🏾‍🤝‍👩🏼' => 'دوه ښځو لاسونه نيولي: غنمی-تورنګه پوستکۍ و غنمی-روښانه پوستکۍ',
    '👩🏾‍🤝‍👩🏽' => 'دوه ښځو لاسونه نيولي: غنمی-تورنګه پوستکۍ و غنم رنګه',
    '👩🏾‍🤝‍👩🏿' => 'دوه ښځو لاسونه نيولي: غنمی-تورنګه پوستکۍ و تور پوستکۍ',
    '👩🏿‍🤝‍👩🏻' => 'دوه ښځو لاسونه نيولي: تور پوستکۍ و د روڼ پوستکي ټون',
    '👩🏿‍🤝‍👩🏼' => 'دوه ښځو لاسونه نيولي: تور پوستکۍ و غنمی-روښانه پوستکۍ',
    '👩🏿‍🤝‍👩🏽' => 'دوه ښځو لاسونه نيولي: تور پوستکۍ و غنم رنګه',
    '👩🏿‍🤝‍👩🏾' => 'دوه ښځو لاسونه نيولي: تور پوستکۍ و غنمی-تورنګه پوستکۍ',
    '👩🏻‍🤝‍👨🏼' => 'سړی او ښځه لاس په لاس کې: د روڼ پوستکي ټون و غنمی-روښانه پوستکۍ',
    '👩🏻‍🤝‍👨🏽' => 'سړی او ښځه لاس په لاس کې: د روڼ پوستکي ټون و غنم رنګه',
    '👩🏻‍🤝‍👨🏾' => 'سړی او ښځه لاس په لاس کې: د روڼ پوستکي ټون و غنمی-تورنګه پوستکۍ',
    '👩🏻‍🤝‍👨🏿' => 'سړی او ښځه لاس په لاس کې: د روڼ پوستکي ټون و تور پوستکۍ',
    '👩🏼‍🤝‍👨🏻' => 'سړی او ښځه لاس په لاس کې: غنمی-روښانه پوستکۍ و د روڼ پوستکي ټون',
    '👩🏼‍🤝‍👨🏽' => 'سړی او ښځه لاس په لاس کې: غنمی-روښانه پوستکۍ و غنم رنګه',
    '👩🏼‍🤝‍👨🏾' => 'سړی او ښځه لاس په لاس کې: غنمی-روښانه پوستکۍ و غنمی-تورنګه پوستکۍ',
    '👩🏼‍🤝‍👨🏿' => 'سړی او ښځه لاس په لاس کې: غنمی-روښانه پوستکۍ و تور پوستکۍ',
    '👩🏽‍🤝‍👨🏻' => 'سړی او ښځه لاس په لاس کې: غنم رنګه و د روڼ پوستکي ټون',
    '👩🏽‍🤝‍👨🏼' => 'سړی او ښځه لاس په لاس کې: غنم رنګه و غنمی-روښانه پوستکۍ',
    '👩🏽‍🤝‍👨🏾' => 'سړی او ښځه لاس په لاس کې: غنم رنګه و غنمی-تورنګه پوستکۍ',
    '👩🏽‍🤝‍👨🏿' => 'سړی او ښځه لاس په لاس کې: غنم رنګه و تور پوستکۍ',
    '👩🏾‍🤝‍👨🏻' => 'سړی او ښځه لاس په لاس کې: غنمی-تورنګه پوستکۍ و د روڼ پوستکي ټون',
    '👩🏾‍🤝‍👨🏼' => 'سړی او ښځه لاس په لاس کې: غنمی-تورنګه پوستکۍ و غنمی-روښانه پوستکۍ',
    '👩🏾‍🤝‍👨🏽' => 'سړی او ښځه لاس په لاس کې: غنمی-تورنګه پوستکۍ و غنم رنګه',
    '👩🏾‍🤝‍👨🏿' => 'سړی او ښځه لاس په لاس کې: غنمی-تورنګه پوستکۍ و تور پوستکۍ',
    '👩🏿‍🤝‍👨🏻' => 'سړی او ښځه لاس په لاس کې: تور پوستکۍ و د روڼ پوستکي ټون',
    '👩🏿‍🤝‍👨🏼' => 'سړی او ښځه لاس په لاس کې: تور پوستکۍ و غنمی-روښانه پوستکۍ',
    '👩🏿‍🤝‍👨🏽' => 'سړی او ښځه لاس په لاس کې: تور پوستکۍ و غنم رنګه',
    '👩🏿‍🤝‍👨🏾' => 'سړی او ښځه لاس په لاس کې: تور پوستکۍ و غنمی-تورنګه پوستکۍ',
    '👨🏻‍🤝‍👨🏼' => 'دوه سړو لاسونه نيولي: د روڼ پوستکي ټون و غنمی-روښانه پوستکۍ',
    '👨🏻‍🤝‍👨🏽' => 'دوه سړو لاسونه نيولي: د روڼ پوستکي ټون و غنم رنګه',
    '👨🏻‍🤝‍👨🏾' => 'دوه سړو لاسونه نيولي: د روڼ پوستکي ټون و غنمی-تورنګه پوستکۍ',
    '👨🏻‍🤝‍👨🏿' => 'دوه سړو لاسونه نيولي: د روڼ پوستکي ټون و تور پوستکۍ',
    '👨🏼‍🤝‍👨🏻' => 'دوه سړو لاسونه نيولي: غنمی-روښانه پوستکۍ و د روڼ پوستکي ټون',
    '👨🏼‍🤝‍👨🏽' => 'دوه سړو لاسونه نيولي: غنمی-روښانه پوستکۍ و غنم رنګه',
    '👨🏼‍🤝‍👨🏾' => 'دوه سړو لاسونه نيولي: غنمی-روښانه پوستکۍ و غنمی-تورنګه پوستکۍ',
    '👨🏼‍🤝‍👨🏿' => 'دوه سړو لاسونه نيولي: غنمی-روښانه پوستکۍ و تور پوستکۍ',
    '👨🏽‍🤝‍👨🏻' => 'دوه سړو لاسونه نيولي: غنم رنګه و د روڼ پوستکي ټون',
    '👨🏽‍🤝‍👨🏼' => 'دوه سړو لاسونه نيولي: غنم رنګه و غنمی-روښانه پوستکۍ',
    '👨🏽‍🤝‍👨🏾' => 'دوه سړو لاسونه نيولي: غنم رنګه و غنمی-تورنګه پوستکۍ',
    '👨🏽‍🤝‍👨🏿' => 'دوه سړو لاسونه نيولي: غنم رنګه و تور پوستکۍ',
    '👨🏾‍🤝‍👨🏻' => 'دوه سړو لاسونه نيولي: غنمی-تورنګه پوستکۍ و د روڼ پوستکي ټون',
    '👨🏾‍🤝‍👨🏼' => 'دوه سړو لاسونه نيولي: غنمی-تورنګه پوستکۍ و غنمی-روښانه پوستکۍ',
    '👨🏾‍🤝‍👨🏽' => 'دوه سړو لاسونه نيولي: غنمی-تورنګه پوستکۍ و غنم رنګه',
    '👨🏾‍🤝‍👨🏿' => 'دوه سړو لاسونه نيولي: غنمی-تورنګه پوستکۍ و تور پوستکۍ',
    '👨🏿‍🤝‍👨🏻' => 'دوه سړو لاسونه نيولي: تور پوستکۍ و د روڼ پوستکي ټون',
    '👨🏿‍🤝‍👨🏼' => 'دوه سړو لاسونه نيولي: تور پوستکۍ و غنمی-روښانه پوستکۍ',
    '👨🏿‍🤝‍👨🏽' => 'دوه سړو لاسونه نيولي: تور پوستکۍ و غنم رنګه',
    '👨🏿‍🤝‍👨🏾' => 'دوه سړو لاسونه نيولي: تور پوستکۍ و غنمی-تورنګه پوستکۍ',
    '👩‍❤‍💋‍👨' => 'مچول: ښځه و سړی',
    '👨‍❤‍💋‍👨' => 'مچول: سړی و سړی',
    '👩‍❤‍💋‍👩' => 'مچول: ښځه و ښځه',
    '👨‍👩‍👧‍👦' => 'کورنۍ: سړی, ښځه, نجلۍ, هلک',
    '👨‍👩‍👦‍👦' => 'کورنۍ: سړی, ښځه, هلک, هلک',
    '👨‍👩‍👧‍👧' => 'کورنۍ: سړی, ښځه, نجلۍ, نجلۍ',
    '👨‍👨‍👧‍👦' => 'کورنۍ: سړی, سړی, نجلۍ, هلک',
    '👨‍👨‍👦‍👦' => 'کورنۍ: سړی, سړی, هلک, هلک',
    '👨‍👨‍👧‍👧' => 'کورنۍ: سړی, سړی, نجلۍ, نجلۍ',
    '👩‍👩‍👧‍👦' => 'کورنۍ: ښځه, ښځه, نجلۍ, هلک',
    '👩‍👩‍👦‍👦' => 'کورنۍ: ښځه, ښځه, هلک, هلک',
    '👩‍👩‍👧‍👧' => 'کورنۍ: ښځه, ښځه, نجلۍ, نجلۍ',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'بيرغ: انګلېنډ',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'بيرغ: سکاټ لينډ',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'بيرغ: ولز',
    '🧑‍🧑‍🧒‍🧒' => 'کورنۍ: بالغ، بالغ، ماشوم، ماشوم',
    '🚶🏻‍♀‍➡' => 'روانه ښځه: د روڼ پوستکي ټون و ښي خوا ته مخامخ',
    '🚶🏼‍♀‍➡' => 'روانه ښځه: غنمی-روښانه پوستکۍ و ښي خوا ته مخامخ',
    '🚶🏽‍♀‍➡' => 'روانه ښځه: غنم رنګه و ښي خوا ته مخامخ',
    '🚶🏾‍♀‍➡' => 'روانه ښځه: غنمی-تورنګه پوستکۍ و ښي خوا ته مخامخ',
    '🚶🏿‍♀‍➡' => 'روانه ښځه: تور پوستکۍ و ښي خوا ته مخامخ',
    '🚶🏻‍♂‍➡' => 'روان سړی: د روڼ پوستکي ټون و ښي خوا ته مخامخ',
    '🚶🏼‍♂‍➡' => 'روان سړی: غنمی-روښانه پوستکۍ و ښي خوا ته مخامخ',
    '🚶🏽‍♂‍➡' => 'روان سړی: غنم رنګه و ښي خوا ته مخامخ',
    '🚶🏾‍♂‍➡' => 'روان سړی: غنمی-تورنګه پوستکۍ و ښي خوا ته مخامخ',
    '🚶🏿‍♂‍➡' => 'روان سړی: تور پوستکۍ و ښي خوا ته مخامخ',
    '🧎🏻‍♀‍➡' => 'ښځه چوکېږي: د روڼ پوستکي ټون و ښي خوا ته مخامخ',
    '🧎🏼‍♀‍➡' => 'ښځه چوکېږي: غنمی-روښانه پوستکۍ و ښي خوا ته مخامخ',
    '🧎🏽‍♀‍➡' => 'ښځه چوکېږي: غنم رنګه و ښي خوا ته مخامخ',
    '🧎🏾‍♀‍➡' => 'ښځه چوکېږي: غنمی-تورنګه پوستکۍ و ښي خوا ته مخامخ',
    '🧎🏿‍♀‍➡' => 'ښځه چوکېږي: تور پوستکۍ و ښي خوا ته مخامخ',
    '🧎🏻‍♂‍➡' => 'سړی چوکېږي: د روڼ پوستکي ټون و ښي خوا ته مخامخ',
    '🧎🏼‍♂‍➡' => 'سړی چوکېږي: غنمی-روښانه پوستکۍ و ښي خوا ته مخامخ',
    '🧎🏽‍♂‍➡' => 'سړی چوکېږي: غنم رنګه و ښي خوا ته مخامخ',
    '🧎🏾‍♂‍➡' => 'سړی چوکېږي: غنمی-تورنګه پوستکۍ و ښي خوا ته مخامخ',
    '🧎🏿‍♂‍➡' => 'سړی چوکېږي: تور پوستکۍ و ښي خوا ته مخامخ',
    '🧑🏻‍🦯‍➡' => 'شخص د معلولينو د امسا سره: د روڼ پوستکي ټون و ښي خوا ته مخامخ',
    '🧑🏼‍🦯‍➡' => 'شخص د معلولينو د امسا سره: غنمی-روښانه پوستکۍ و ښي خوا ته مخامخ',
    '🧑🏽‍🦯‍➡' => 'شخص د معلولينو د امسا سره: غنم رنګه و ښي خوا ته مخامخ',
    '🧑🏾‍🦯‍➡' => 'شخص د معلولينو د امسا سره: غنمی-تورنګه پوستکۍ و ښي خوا ته مخامخ',
    '🧑🏿‍🦯‍➡' => 'شخص د معلولينو د امسا سره: تور پوستکۍ و ښي خوا ته مخامخ',
    '👨🏻‍🦯‍➡' => 'سړی د معلولينو د همسا سره: د روڼ پوستکي ټون و ښي خوا ته مخامخ',
    '👨🏼‍🦯‍➡' => 'سړی د معلولينو د همسا سره: غنمی-روښانه پوستکۍ و ښي خوا ته مخامخ',
    '👨🏽‍🦯‍➡' => 'سړی د معلولينو د همسا سره: غنم رنګه و ښي خوا ته مخامخ',
    '👨🏾‍🦯‍➡' => 'سړی د معلولينو د همسا سره: غنمی-تورنګه پوستکۍ و ښي خوا ته مخامخ',
    '👨🏿‍🦯‍➡' => 'سړی د معلولينو د همسا سره: تور پوستکۍ و ښي خوا ته مخامخ',
    '👩🏻‍🦯‍➡' => 'ښځه د معلولينو د همسا سره: د روڼ پوستکي ټون و ښي خوا ته مخامخ',
    '👩🏼‍🦯‍➡' => 'ښځه د معلولينو د همسا سره: غنمی-روښانه پوستکۍ و ښي خوا ته مخامخ',
    '👩🏽‍🦯‍➡' => 'ښځه د معلولينو د همسا سره: غنم رنګه و ښي خوا ته مخامخ',
    '👩🏾‍🦯‍➡' => 'ښځه د معلولينو د همسا سره: غنمی-تورنګه پوستکۍ و ښي خوا ته مخامخ',
    '👩🏿‍🦯‍➡' => 'ښځه د معلولينو د همسا سره: تور پوستکۍ و ښي خوا ته مخامخ',
    '🧑🏻‍🦼‍➡' => 'شخص د معلولينو په موټر چوکۍ کې: د روڼ پوستکي ټون و ښي خوا ته مخامخ',
    '🧑🏼‍🦼‍➡' => 'شخص د معلولينو په موټر چوکۍ کې: غنمی-روښانه پوستکۍ و ښي خوا ته مخامخ',
    '🧑🏽‍🦼‍➡' => 'شخص د معلولينو په موټر چوکۍ کې: غنم رنګه و ښي خوا ته مخامخ',
    '🧑🏾‍🦼‍➡' => 'شخص د معلولينو په موټر چوکۍ کې: غنمی-تورنګه پوستکۍ و ښي خوا ته مخامخ',
    '🧑🏿‍🦼‍➡' => 'شخص د معلولينو په موټر چوکۍ کې: تور پوستکۍ و ښي خوا ته مخامخ',
    '👨🏻‍🦼‍➡' => 'سړی د معلولينو په موټر چوکۍ کې: د روڼ پوستکي ټون و ښي خوا ته مخامخ',
    '👨🏼‍🦼‍➡' => 'سړی د معلولينو په موټر چوکۍ کې: غنمی-روښانه پوستکۍ و ښي خوا ته مخامخ',
    '👨🏽‍🦼‍➡' => 'سړی د معلولينو په موټر چوکۍ کې: غنم رنګه و ښي خوا ته مخامخ',
    '👨🏾‍🦼‍➡' => 'سړی د معلولينو په موټر چوکۍ کې: غنمی-تورنګه پوستکۍ و ښي خوا ته مخامخ',
    '👨🏿‍🦼‍➡' => 'سړی د معلولينو په موټر چوکۍ کې: تور پوستکۍ و ښي خوا ته مخامخ',
    '👩🏻‍🦼‍➡' => 'ښځه د معلولينو په موټر چوکۍ کې: د روڼ پوستکي ټون و ښي خوا ته مخامخ',
    '👩🏼‍🦼‍➡' => 'ښځه د معلولينو په موټر چوکۍ کې: غنمی-روښانه پوستکۍ و ښي خوا ته مخامخ',
    '👩🏽‍🦼‍➡' => 'ښځه د معلولينو په موټر چوکۍ کې: غنم رنګه و ښي خوا ته مخامخ',
    '👩🏾‍🦼‍➡' => 'ښځه د معلولينو په موټر چوکۍ کې: غنمی-تورنګه پوستکۍ و ښي خوا ته مخامخ',
    '👩🏿‍🦼‍➡' => 'ښځه د معلولينو په موټر چوکۍ کې: تور پوستکۍ و ښي خوا ته مخامخ',
    '🧑🏻‍🦽‍➡' => 'شخص د معلولينو په لاسي چوکۍ کې: د روڼ پوستکي ټون و ښي خوا ته مخامخ',
    '🧑🏼‍🦽‍➡' => 'شخص د معلولينو په لاسي چوکۍ کې: غنمی-روښانه پوستکۍ و ښي خوا ته مخامخ',
    '🧑🏽‍🦽‍➡' => 'شخص د معلولينو په لاسي چوکۍ کې: غنم رنګه و ښي خوا ته مخامخ',
    '🧑🏾‍🦽‍➡' => 'شخص د معلولينو په لاسي چوکۍ کې: غنمی-تورنګه پوستکۍ و ښي خوا ته مخامخ',
    '🧑🏿‍🦽‍➡' => 'شخص د معلولينو په لاسي چوکۍ کې: تور پوستکۍ و ښي خوا ته مخامخ',
    '👨🏻‍🦽‍➡' => 'سړی د معلولينو په لاسي چوکۍ کې: د روڼ پوستکي ټون و ښي خوا ته مخامخ',
    '👨🏼‍🦽‍➡' => 'سړی د معلولينو په لاسي چوکۍ کې: غنمی-روښانه پوستکۍ و ښي خوا ته مخامخ',
    '👨🏽‍🦽‍➡' => 'سړی د معلولينو په لاسي چوکۍ کې: غنم رنګه و ښي خوا ته مخامخ',
    '👨🏾‍🦽‍➡' => 'سړی د معلولينو په لاسي چوکۍ کې: غنمی-تورنګه پوستکۍ و ښي خوا ته مخامخ',
    '👨🏿‍🦽‍➡' => 'سړی د معلولينو په لاسي چوکۍ کې: تور پوستکۍ و ښي خوا ته مخامخ',
    '👩🏻‍🦽‍➡' => 'ښځه د معلولينو په لاسي چوکۍ کې: د روڼ پوستکي ټون و ښي خوا ته مخامخ',
    '👩🏼‍🦽‍➡' => 'ښځه د معلولينو په لاسي چوکۍ کې: غنمی-روښانه پوستکۍ و ښي خوا ته مخامخ',
    '👩🏽‍🦽‍➡' => 'ښځه د معلولينو په لاسي چوکۍ کې: غنم رنګه و ښي خوا ته مخامخ',
    '👩🏾‍🦽‍➡' => 'ښځه د معلولينو په لاسي چوکۍ کې: غنمی-تورنګه پوستکۍ و ښي خوا ته مخامخ',
    '👩🏿‍🦽‍➡' => 'ښځه د معلولينو په لاسي چوکۍ کې: تور پوستکۍ و ښي خوا ته مخامخ',
    '🏃🏻‍♀‍➡' => 'ښځه ځغلي: د روڼ پوستکي ټون و ښي خوا ته مخامخ',
    '🏃🏼‍♀‍➡' => 'ښځه ځغلي: غنمی-روښانه پوستکۍ و ښي خوا ته مخامخ',
    '🏃🏽‍♀‍➡' => 'ښځه ځغلي: غنم رنګه و ښي خوا ته مخامخ',
    '🏃🏾‍♀‍➡' => 'ښځه ځغلي: غنمی-تورنګه پوستکۍ و ښي خوا ته مخامخ',
    '🏃🏿‍♀‍➡' => 'ښځه ځغلي: تور پوستکۍ و ښي خوا ته مخامخ',
    '🏃🏻‍♂‍➡' => 'سړی ځغلي: د روڼ پوستکي ټون و ښي خوا ته مخامخ',
    '🏃🏼‍♂‍➡' => 'سړی ځغلي: غنمی-روښانه پوستکۍ و ښي خوا ته مخامخ',
    '🏃🏽‍♂‍➡' => 'سړی ځغلي: غنم رنګه و ښي خوا ته مخامخ',
    '🏃🏾‍♂‍➡' => 'سړی ځغلي: غنمی-تورنګه پوستکۍ و ښي خوا ته مخامخ',
    '🏃🏿‍♂‍➡' => 'سړی ځغلي: تور پوستکۍ و ښي خوا ته مخامخ',
    '🫱🏻‍🫲🏼' => 'ستړې مشي: د روڼ پوستکي ټون و غنمی-روښانه پوستکۍ',
    '🫱🏻‍🫲🏽' => 'ستړې مشي: د روڼ پوستکي ټون و غنم رنګه',
    '🫱🏻‍🫲🏾' => 'ستړې مشي: د روڼ پوستکي ټون و غنمی-تورنګه پوستکۍ',
    '🫱🏻‍🫲🏿' => 'ستړې مشي: د روڼ پوستکي ټون و تور پوستکۍ',
    '🫱🏼‍🫲🏻' => 'ستړې مشي: غنمی-روښانه پوستکۍ و د روڼ پوستکي ټون',
    '🫱🏼‍🫲🏽' => 'ستړې مشي: غنمی-روښانه پوستکۍ و غنم رنګه',
    '🫱🏼‍🫲🏾' => 'ستړې مشي: غنمی-روښانه پوستکۍ و غنمی-تورنګه پوستکۍ',
    '🫱🏼‍🫲🏿' => 'ستړې مشي: غنمی-روښانه پوستکۍ و تور پوستکۍ',
    '🫱🏽‍🫲🏻' => 'ستړې مشي: غنم رنګه و د روڼ پوستکي ټون',
    '🫱🏽‍🫲🏼' => 'ستړې مشي: غنم رنګه و غنمی-روښانه پوستکۍ',
    '🫱🏽‍🫲🏾' => 'ستړې مشي: غنم رنګه و غنمی-تورنګه پوستکۍ',
    '🫱🏽‍🫲🏿' => 'ستړې مشي: غنم رنګه و تور پوستکۍ',
    '🫱🏾‍🫲🏻' => 'ستړې مشي: غنمی-تورنګه پوستکۍ و د روڼ پوستکي ټون',
    '🫱🏾‍🫲🏼' => 'ستړې مشي: غنمی-تورنګه پوستکۍ و غنمی-روښانه پوستکۍ',
    '🫱🏾‍🫲🏽' => 'ستړې مشي: غنمی-تورنګه پوستکۍ و غنم رنګه',
    '🫱🏾‍🫲🏿' => 'ستړې مشي: غنمی-تورنګه پوستکۍ و تور پوستکۍ',
    '🫱🏿‍🫲🏻' => 'ستړې مشي: تور پوستکۍ و د روڼ پوستکي ټون',
    '🫱🏿‍🫲🏼' => 'ستړې مشي: تور پوستکۍ و غنمی-روښانه پوستکۍ',
    '🫱🏿‍🫲🏽' => 'ستړې مشي: تور پوستکۍ و غنم رنګه',
    '🫱🏿‍🫲🏾' => 'ستړې مشي: تور پوستکۍ و غنمی-تورنګه پوستکۍ',
    '🚶‍♀‍➡' => 'روانه ښځه: ښي خوا ته مخامخ',
    '🚶‍♂‍➡' => 'روان سړی: ښي خوا ته مخامخ',
    '🧎‍♀‍➡' => 'ښځه چوکېږي: ښي خوا ته مخامخ',
    '🧎‍♂‍➡' => 'سړی چوکېږي: ښي خوا ته مخامخ',
    '🧑‍🦯‍➡' => 'شخص د معلولينو د امسا سره: ښي خوا ته مخامخ',
    '👨‍🦯‍➡' => 'سړی د معلولينو د همسا سره: ښي خوا ته مخامخ',
    '👩‍🦯‍➡' => 'ښځه د معلولينو د همسا سره: ښي خوا ته مخامخ',
    '🧑‍🦼‍➡' => 'شخص د معلولينو په موټر چوکۍ کې: ښي خوا ته مخامخ',
    '👨‍🦼‍➡' => 'سړی د معلولينو په موټر چوکۍ کې: ښي خوا ته مخامخ',
    '👩‍🦼‍➡' => 'ښځه د معلولينو په موټر چوکۍ کې: ښي خوا ته مخامخ',
    '🧑‍🦽‍➡' => 'شخص د معلولينو په لاسي چوکۍ کې: ښي خوا ته مخامخ',
    '👨‍🦽‍➡' => 'سړی د معلولينو په لاسي چوکۍ کې: ښي خوا ته مخامخ',
    '👩‍🦽‍➡' => 'ښځه د معلولينو په لاسي چوکۍ کې: ښي خوا ته مخامخ',
    '🏃‍♀‍➡' => 'ښځه ځغلي: ښي خوا ته مخامخ',
    '🏃‍♂‍➡' => 'سړی ځغلي: ښي خوا ته مخامخ',
    '👩‍❤‍👨' => 'د زړه سره جوړه: ښځه و سړی',
    '👨‍❤‍👨' => 'د زړه سره جوړه: سړی و سړی',
    '👩‍❤‍👩' => 'د زړه سره جوړه: ښځه و ښځه',
    '👨‍👩‍👦' => 'کورنۍ: سړی, ښځه, هلک',
    '👨‍👩‍👧' => 'کورنۍ: سړی, ښځه, نجلۍ',
    '👨‍👨‍👦' => 'کورنۍ: سړی, سړی, هلک',
    '👨‍👨‍👧' => 'کورنۍ: سړی, سړی, نجلۍ',
    '👩‍👩‍👦' => 'کورنۍ: ښځه, ښځه, هلک',
    '👩‍👩‍👧' => 'کورنۍ: ښځه, ښځه, نجلۍ',
    '👨‍👦‍👦' => 'کورنۍ: سړی, هلک, هلک',
    '👨‍👧‍👦' => 'کورنۍ: سړی, نجلۍ, هلک',
    '👨‍👧‍👧' => 'کورنۍ: سړی, نجلۍ, نجلۍ',
    '👩‍👦‍👦' => 'کورنۍ: ښځه, هلک, هلک',
    '👩‍👧‍👦' => 'کورنۍ: ښځه, نجلۍ, هلک',
    '👩‍👧‍👧' => 'کورنۍ: ښځه, نجلۍ, نجلۍ',
    '🧑‍🤝‍🧑' => 'خلکو لاسونه نيولي',
    '🧑‍🧑‍🧒' => 'کورنۍ: بالغ، بالغ، ماشوم',
    '🧑‍🧒‍🧒' => 'کورنۍ: بالغ، ماشوم، ماشوم',
    '🧑🏻‍🦰' => 'شخص: د روڼ پوستکي ټون و سره ويښتان',
    '🧑🏼‍🦰' => 'شخص: غنمی-روښانه پوستکۍ و سره ويښتان',
    '🧑🏽‍🦰' => 'شخص: غنم رنګه و سره ويښتان',
    '🧑🏾‍🦰' => 'شخص: غنمی-تورنګه پوستکۍ و سره ويښتان',
    '🧑🏿‍🦰' => 'شخص: تور پوستکۍ و سره ويښتان',
    '🧑🏻‍🦱' => 'شخص: د روڼ پوستکي ټون و لوپه ويښتان',
    '🧑🏼‍🦱' => 'شخص: غنمی-روښانه پوستکۍ و لوپه ويښتان',
    '🧑🏽‍🦱' => 'شخص: غنم رنګه و لوپه ويښتان',
    '🧑🏾‍🦱' => 'شخص: غنمی-تورنګه پوستکۍ و لوپه ويښتان',
    '🧑🏿‍🦱' => 'شخص: تور پوستکۍ و لوپه ويښتان',
    '🧑🏻‍🦳' => 'شخص: د روڼ پوستکي ټون و سپين ويښتان',
    '🧑🏼‍🦳' => 'شخص: غنمی-روښانه پوستکۍ و سپين ويښتان',
    '🧑🏽‍🦳' => 'شخص: غنم رنګه و سپين ويښتان',
    '🧑🏾‍🦳' => 'شخص: غنمی-تورنګه پوستکۍ و سپين ويښتان',
    '🧑🏿‍🦳' => 'شخص: تور پوستکۍ و سپين ويښتان',
    '🧑🏻‍🦲' => 'شخص: د روڼ پوستکي ټون و ګنجى',
    '🧑🏼‍🦲' => 'شخص: غنمی-روښانه پوستکۍ و ګنجى',
    '🧑🏽‍🦲' => 'شخص: غنم رنګه و ګنجى',
    '🧑🏾‍🦲' => 'شخص: غنمی-تورنګه پوستکۍ و ګنجى',
    '🧑🏿‍🦲' => 'شخص: تور پوستکۍ و ګنجى',
    '🧑🏻‍🩰' => 'د بالې نڅاګر: د روڼ پوستکي ټون',
    '🧑🏼‍🩰' => 'د بالې نڅاګر: غنمی-روښانه پوستکۍ',
    '🧑🏽‍🩰' => 'د بالې نڅاګر: غنم رنګه',
    '🧑🏾‍🩰' => 'د بالې نڅاګر: غنمی-تورنګه پوستکۍ',
    '🧑🏿‍🩰' => 'د بالې نڅاګر: تور پوستکۍ',
    '🧔🏻‍♂' => 'سړی: د روڼ پوستکي ټون و ږیره',
    '🧔🏼‍♂' => 'سړی: غنمی-روښانه پوستکۍ و ږیره',
    '🧔🏽‍♂' => 'سړی: غنم رنګه و ږیره',
    '🧔🏾‍♂' => 'سړی: غنمی-تورنګه پوستکۍ و ږیره',
    '🧔🏿‍♂' => 'سړی: تور پوستکۍ و ږیره',
    '👱🏻‍♂' => 'سړی: د روڼ پوستکي ټون و د زيړ وېښتانو',
    '👱🏼‍♂' => 'سړی: غنمی-روښانه پوستکۍ و د زيړ وېښتانو',
    '👱🏽‍♂' => 'سړی: غنم رنګه و د زيړ وېښتانو',
    '👱🏾‍♂' => 'سړی: غنمی-تورنګه پوستکۍ و د زيړ وېښتانو',
    '👱🏿‍♂' => 'سړی: تور پوستکۍ و د زيړ وېښتانو',
    '👨🏻‍🦰' => 'سړی: د روڼ پوستکي ټون و سره ويښتان',
    '👨🏼‍🦰' => 'سړی: غنمی-روښانه پوستکۍ و سره ويښتان',
    '👨🏽‍🦰' => 'سړی: غنم رنګه و سره ويښتان',
    '👨🏾‍🦰' => 'سړی: غنمی-تورنګه پوستکۍ و سره ويښتان',
    '👨🏿‍🦰' => 'سړی: تور پوستکۍ و سره ويښتان',
    '👨🏻‍🦱' => 'سړی: د روڼ پوستکي ټون و لوپه ويښتان',
    '👨🏼‍🦱' => 'سړی: غنمی-روښانه پوستکۍ و لوپه ويښتان',
    '👨🏽‍🦱' => 'سړی: غنم رنګه و لوپه ويښتان',
    '👨🏾‍🦱' => 'سړی: غنمی-تورنګه پوستکۍ و لوپه ويښتان',
    '👨🏿‍🦱' => 'سړی: تور پوستکۍ و لوپه ويښتان',
    '👨🏻‍🦳' => 'سړی: د روڼ پوستکي ټون و سپين ويښتان',
    '👨🏼‍🦳' => 'سړی: غنمی-روښانه پوستکۍ و سپين ويښتان',
    '👨🏽‍🦳' => 'سړی: غنم رنګه و سپين ويښتان',
    '👨🏾‍🦳' => 'سړی: غنمی-تورنګه پوستکۍ و سپين ويښتان',
    '👨🏿‍🦳' => 'سړی: تور پوستکۍ و سپين ويښتان',
    '👨🏻‍🦲' => 'سړی: د روڼ پوستکي ټون و ګنجى',
    '👨🏼‍🦲' => 'سړی: غنمی-روښانه پوستکۍ و ګنجى',
    '👨🏽‍🦲' => 'سړی: غنم رنګه و ګنجى',
    '👨🏾‍🦲' => 'سړی: غنمی-تورنګه پوستکۍ و ګنجى',
    '👨🏿‍🦲' => 'سړی: تور پوستکۍ و ګنجى',
    '🧔🏻‍♀' => 'ښځه: د روڼ پوستکي ټون و ږیره',
    '🧔🏼‍♀' => 'ښځه: غنمی-روښانه پوستکۍ و ږیره',
    '🧔🏽‍♀' => 'ښځه: غنم رنګه و ږیره',
    '🧔🏾‍♀' => 'ښځه: غنمی-تورنګه پوستکۍ و ږیره',
    '🧔🏿‍♀' => 'ښځه: تور پوستکۍ و ږیره',
    '👱🏻‍♀' => 'ښځه: د روڼ پوستکي ټون و د زېړ وېښتانو',
    '👱🏼‍♀' => 'ښځه: غنمی-روښانه پوستکۍ و د زېړ وېښتانو',
    '👱🏽‍♀' => 'ښځه: غنم رنګه و د زېړ وېښتانو',
    '👱🏾‍♀' => 'ښځه: غنمی-تورنګه پوستکۍ و د زېړ وېښتانو',
    '👱🏿‍♀' => 'ښځه: تور پوستکۍ و د زېړ وېښتانو',
    '👩🏻‍🦰' => 'ښځه: د روڼ پوستکي ټون و سره ويښتان',
    '👩🏼‍🦰' => 'ښځه: غنمی-روښانه پوستکۍ و سره ويښتان',
    '👩🏽‍🦰' => 'ښځه: غنم رنګه و سره ويښتان',
    '👩🏾‍🦰' => 'ښځه: غنمی-تورنګه پوستکۍ و سره ويښتان',
    '👩🏿‍🦰' => 'ښځه: تور پوستکۍ و سره ويښتان',
    '👩🏻‍🦱' => 'ښځه: د روڼ پوستکي ټون و لوپه ويښتان',
    '👩🏼‍🦱' => 'ښځه: غنمی-روښانه پوستکۍ و لوپه ويښتان',
    '👩🏽‍🦱' => 'ښځه: غنم رنګه و لوپه ويښتان',
    '👩🏾‍🦱' => 'ښځه: غنمی-تورنګه پوستکۍ و لوپه ويښتان',
    '👩🏿‍🦱' => 'ښځه: تور پوستکۍ و لوپه ويښتان',
    '👩🏻‍🦳' => 'ښځه: د روڼ پوستکي ټون و سپين ويښتان',
    '👩🏼‍🦳' => 'ښځه: غنمی-روښانه پوستکۍ و سپين ويښتان',
    '👩🏽‍🦳' => 'ښځه: غنم رنګه و سپين ويښتان',
    '👩🏾‍🦳' => 'ښځه: غنمی-تورنګه پوستکۍ و سپين ويښتان',
    '👩🏿‍🦳' => 'ښځه: تور پوستکۍ و سپين ويښتان',
    '👩🏻‍🦲' => 'ښځه: د روڼ پوستکي ټون و ګنجى',
    '👩🏼‍🦲' => 'ښځه: غنمی-روښانه پوستکۍ و ګنجى',
    '👩🏽‍🦲' => 'ښځه: غنم رنګه و ګنجى',
    '👩🏾‍🦲' => 'ښځه: غنمی-تورنګه پوستکۍ و ګنجى',
    '👩🏿‍🦲' => 'ښځه: تور پوستکۍ و ګنجى',
    '🙍🏻‍♂' => 'سړی وروځې راغورځوي: د روڼ پوستکي ټون',
    '🙍🏼‍♂' => 'سړی وروځې راغورځوي: غنمی-روښانه پوستکۍ',
    '🙍🏽‍♂' => 'سړی وروځې راغورځوي: غنم رنګه',
    '🙍🏾‍♂' => 'سړی وروځې راغورځوي: غنمی-تورنګه پوستکۍ',
    '🙍🏿‍♂' => 'سړی وروځې راغورځوي: تور پوستکۍ',
    '🙍🏻‍♀' => 'ښځه وروځې راغورځوي: د روڼ پوستکي ټون',
    '🙍🏼‍♀' => 'ښځه وروځې راغورځوي: غنمی-روښانه پوستکۍ',
    '🙍🏽‍♀' => 'ښځه وروځې راغورځوي: غنم رنګه',
    '🙍🏾‍♀' => 'ښځه وروځې راغورځوي: غنمی-تورنګه پوستکۍ',
    '🙍🏿‍♀' => 'ښځه وروځې راغورځوي: تور پوستکۍ',
    '🙎🏻‍♂' => 'سړی تندی کوت کوي: د روڼ پوستکي ټون',
    '🙎🏼‍♂' => 'سړی تندی کوت کوي: غنمی-روښانه پوستکۍ',
    '🙎🏽‍♂' => 'سړی تندی کوت کوي: غنم رنګه',
    '🙎🏾‍♂' => 'سړی تندی کوت کوي: غنمی-تورنګه پوستکۍ',
    '🙎🏿‍♂' => 'سړی تندی کوت کوي: تور پوستکۍ',
    '🙎🏻‍♀' => 'ښځه تندی کوت کوي: د روڼ پوستکي ټون',
    '🙎🏼‍♀' => 'ښځه تندی کوت کوي: غنمی-روښانه پوستکۍ',
    '🙎🏽‍♀' => 'ښځه تندی کوت کوي: غنم رنګه',
    '🙎🏾‍♀' => 'ښځه تندی کوت کوي: غنمی-تورنګه پوستکۍ',
    '🙎🏿‍♀' => 'ښځه تندی کوت کوي: تور پوستکۍ',
    '🙅🏻‍♂' => 'سړی د نه اشاره کوي: د روڼ پوستکي ټون',
    '🙅🏼‍♂' => 'سړی د نه اشاره کوي: غنمی-روښانه پوستکۍ',
    '🙅🏽‍♂' => 'سړی د نه اشاره کوي: غنم رنګه',
    '🙅🏾‍♂' => 'سړی د نه اشاره کوي: غنمی-تورنګه پوستکۍ',
    '🙅🏿‍♂' => 'سړی د نه اشاره کوي: تور پوستکۍ',
    '🙅🏻‍♀' => 'ښځه د نه اشاره کوي: د روڼ پوستکي ټون',
    '🙅🏼‍♀' => 'ښځه د نه اشاره کوي: غنمی-روښانه پوستکۍ',
    '🙅🏽‍♀' => 'ښځه د نه اشاره کوي: غنم رنګه',
    '🙅🏾‍♀' => 'ښځه د نه اشاره کوي: غنمی-تورنګه پوستکۍ',
    '🙅🏿‍♀' => 'ښځه د نه اشاره کوي: تور پوستکۍ',
    '🙆🏻‍♂' => 'سړی د او کی اشاره کوي: د روڼ پوستکي ټون',
    '🙆🏼‍♂' => 'سړی د او کی اشاره کوي: غنمی-روښانه پوستکۍ',
    '🙆🏽‍♂' => 'سړی د او کی اشاره کوي: غنم رنګه',
    '🙆🏾‍♂' => 'سړی د او کی اشاره کوي: غنمی-تورنګه پوستکۍ',
    '🙆🏿‍♂' => 'سړی د او کی اشاره کوي: تور پوستکۍ',
    '🙆🏻‍♀' => 'ښځه د او کی اشاره کوي: د روڼ پوستکي ټون',
    '🙆🏼‍♀' => 'ښځه د او کی اشاره کوي: غنمی-روښانه پوستکۍ',
    '🙆🏽‍♀' => 'ښځه د او کی اشاره کوي: غنم رنګه',
    '🙆🏾‍♀' => 'ښځه د او کی اشاره کوي: غنمی-تورنګه پوستکۍ',
    '🙆🏿‍♀' => 'ښځه د او کی اشاره کوي: تور پوستکۍ',
    '💁🏻‍♂' => 'سړی لاس ښايي: د روڼ پوستکي ټون',
    '💁🏼‍♂' => 'سړی لاس ښايي: غنمی-روښانه پوستکۍ',
    '💁🏽‍♂' => 'سړی لاس ښايي: غنم رنګه',
    '💁🏾‍♂' => 'سړی لاس ښايي: غنمی-تورنګه پوستکۍ',
    '💁🏿‍♂' => 'سړی لاس ښايي: تور پوستکۍ',
    '💁🏻‍♀' => 'ښځه لاس ښايي: د روڼ پوستکي ټون',
    '💁🏼‍♀' => 'ښځه لاس ښايي: غنمی-روښانه پوستکۍ',
    '💁🏽‍♀' => 'ښځه لاس ښايي: غنم رنګه',
    '💁🏾‍♀' => 'ښځه لاس ښايي: غنمی-تورنګه پوستکۍ',
    '💁🏿‍♀' => 'ښځه لاس ښايي: تور پوستکۍ',
    '🙋🏻‍♂' => 'سړی لاس اوچتوي: د روڼ پوستکي ټون',
    '🙋🏼‍♂' => 'سړی لاس اوچتوي: غنمی-روښانه پوستکۍ',
    '🙋🏽‍♂' => 'سړی لاس اوچتوي: غنم رنګه',
    '🙋🏾‍♂' => 'سړی لاس اوچتوي: غنمی-تورنګه پوستکۍ',
    '🙋🏿‍♂' => 'سړی لاس اوچتوي: تور پوستکۍ',
    '🙋🏻‍♀' => 'ښځه لاس اوچتوي: د روڼ پوستکي ټون',
    '🙋🏼‍♀' => 'ښځه لاس اوچتوي: غنمی-روښانه پوستکۍ',
    '🙋🏽‍♀' => 'ښځه لاس اوچتوي: غنم رنګه',
    '🙋🏾‍♀' => 'ښځه لاس اوچتوي: غنمی-تورنګه پوستکۍ',
    '🙋🏿‍♀' => 'ښځه لاس اوچتوي: تور پوستکۍ',
    '🧏🏻‍♂' => 'کوڼ سړی: د روڼ پوستکي ټون',
    '🧏🏼‍♂' => 'کوڼ سړی: غنمی-روښانه پوستکۍ',
    '🧏🏽‍♂' => 'کوڼ سړی: غنم رنګه',
    '🧏🏾‍♂' => 'کوڼ سړی: غنمی-تورنګه پوستکۍ',
    '🧏🏿‍♂' => 'کوڼ سړی: تور پوستکۍ',
    '🧏🏻‍♀' => 'کڼه ښځه: د روڼ پوستکي ټون',
    '🧏🏼‍♀' => 'کڼه ښځه: غنمی-روښانه پوستکۍ',
    '🧏🏽‍♀' => 'کڼه ښځه: غنم رنګه',
    '🧏🏾‍♀' => 'کڼه ښځه: غنمی-تورنګه پوستکۍ',
    '🧏🏿‍♀' => 'کڼه ښځه: تور پوستکۍ',
    '🙇🏻‍♂' => 'سړی ښکته کيږي: د روڼ پوستکي ټون',
    '🙇🏼‍♂' => 'سړی ښکته کيږي: غنمی-روښانه پوستکۍ',
    '🙇🏽‍♂' => 'سړی ښکته کيږي: غنم رنګه',
    '🙇🏾‍♂' => 'سړی ښکته کيږي: غنمی-تورنګه پوستکۍ',
    '🙇🏿‍♂' => 'سړی ښکته کيږي: تور پوستکۍ',
    '🙇🏻‍♀' => 'ښځه ښکته کيږې: د روڼ پوستکي ټون',
    '🙇🏼‍♀' => 'ښځه ښکته کيږې: غنمی-روښانه پوستکۍ',
    '🙇🏽‍♀' => 'ښځه ښکته کيږې: غنم رنګه',
    '🙇🏾‍♀' => 'ښځه ښکته کيږې: غنمی-تورنګه پوستکۍ',
    '🙇🏿‍♀' => 'ښځه ښکته کيږې: تور پوستکۍ',
    '🤦🏻‍♂' => 'سړي مخ ته لاس نيولی: د روڼ پوستکي ټون',
    '🤦🏼‍♂' => 'سړي مخ ته لاس نيولی: غنمی-روښانه پوستکۍ',
    '🤦🏽‍♂' => 'سړي مخ ته لاس نيولی: غنم رنګه',
    '🤦🏾‍♂' => 'سړي مخ ته لاس نيولی: غنمی-تورنګه پوستکۍ',
    '🤦🏿‍♂' => 'سړي مخ ته لاس نيولی: تور پوستکۍ',
    '🤦🏻‍♀' => 'ښځې مخ ته لاس نيولی: د روڼ پوستکي ټون',
    '🤦🏼‍♀' => 'ښځې مخ ته لاس نيولی: غنمی-روښانه پوستکۍ',
    '🤦🏽‍♀' => 'ښځې مخ ته لاس نيولی: غنم رنګه',
    '🤦🏾‍♀' => 'ښځې مخ ته لاس نيولی: غنمی-تورنګه پوستکۍ',
    '🤦🏿‍♀' => 'ښځې مخ ته لاس نيولی: تور پوستکۍ',
    '🤷🏻‍♂' => 'سړی اوږې پورته کوي: د روڼ پوستکي ټون',
    '🤷🏼‍♂' => 'سړی اوږې پورته کوي: غنمی-روښانه پوستکۍ',
    '🤷🏽‍♂' => 'سړی اوږې پورته کوي: غنم رنګه',
    '🤷🏾‍♂' => 'سړی اوږې پورته کوي: غنمی-تورنګه پوستکۍ',
    '🤷🏿‍♂' => 'سړی اوږې پورته کوي: تور پوستکۍ',
    '🤷🏻‍♀' => 'ښځه اوږې پورته کوي: د روڼ پوستکي ټون',
    '🤷🏼‍♀' => 'ښځه اوږې پورته کوي: غنمی-روښانه پوستکۍ',
    '🤷🏽‍♀' => 'ښځه اوږې پورته کوي: غنم رنګه',
    '🤷🏾‍♀' => 'ښځه اوږې پورته کوي: غنمی-تورنګه پوستکۍ',
    '🤷🏿‍♀' => 'ښځه اوږې پورته کوي: تور پوستکۍ',
    '🧑🏻‍⚕' => 'روغتيايي کارمند: د روڼ پوستکي ټون',
    '🧑🏼‍⚕' => 'روغتيايي کارمند: غنمی-روښانه پوستکۍ',
    '🧑🏽‍⚕' => 'روغتيايي کارمند: غنم رنګه',
    '🧑🏾‍⚕' => 'روغتيايي کارمند: غنمی-تورنګه پوستکۍ',
    '🧑🏿‍⚕' => 'روغتيايي کارمند: تور پوستکۍ',
    '👨🏻‍⚕' => 'سړی روغتيايي کارکوونکی: د روڼ پوستکي ټون',
    '👨🏼‍⚕' => 'سړی روغتيايي کارکوونکی: غنمی-روښانه پوستکۍ',
    '👨🏽‍⚕' => 'سړی روغتيايي کارکوونکی: غنم رنګه',
    '👨🏾‍⚕' => 'سړی روغتيايي کارکوونکی: غنمی-تورنګه پوستکۍ',
    '👨🏿‍⚕' => 'سړی روغتيايي کارکوونکی: تور پوستکۍ',
    '👩🏻‍⚕' => 'ښځه روغتيايي کارکوونکي: د روڼ پوستکي ټون',
    '👩🏼‍⚕' => 'ښځه روغتيايي کارکوونکي: غنمی-روښانه پوستکۍ',
    '👩🏽‍⚕' => 'ښځه روغتيايي کارکوونکي: غنم رنګه',
    '👩🏾‍⚕' => 'ښځه روغتيايي کارکوونکي: غنمی-تورنګه پوستکۍ',
    '👩🏿‍⚕' => 'ښځه روغتيايي کارکوونکي: تور پوستکۍ',
    '🧑🏻‍🎓' => 'محصل: د روڼ پوستکي ټون',
    '🧑🏼‍🎓' => 'محصل: غنمی-روښانه پوستکۍ',
    '🧑🏽‍🎓' => 'محصل: غنم رنګه',
    '🧑🏾‍🎓' => 'محصل: غنمی-تورنګه پوستکۍ',
    '🧑🏿‍🎓' => 'محصل: تور پوستکۍ',
    '👨🏻‍🎓' => 'سړی محصل: د روڼ پوستکي ټون',
    '👨🏼‍🎓' => 'سړی محصل: غنمی-روښانه پوستکۍ',
    '👨🏽‍🎓' => 'سړی محصل: غنم رنګه',
    '👨🏾‍🎓' => 'سړی محصل: غنمی-تورنګه پوستکۍ',
    '👨🏿‍🎓' => 'سړی محصل: تور پوستکۍ',
    '👩🏻‍🎓' => 'ښځه محصل: د روڼ پوستکي ټون',
    '👩🏼‍🎓' => 'ښځه محصل: غنمی-روښانه پوستکۍ',
    '👩🏽‍🎓' => 'ښځه محصل: غنم رنګه',
    '👩🏾‍🎓' => 'ښځه محصل: غنمی-تورنګه پوستکۍ',
    '👩🏿‍🎓' => 'ښځه محصل: تور پوستکۍ',
    '🧑🏻‍🏫' => 'ښوونکی: د روڼ پوستکي ټون',
    '🧑🏼‍🏫' => 'ښوونکی: غنمی-روښانه پوستکۍ',
    '🧑🏽‍🏫' => 'ښوونکی: غنم رنګه',
    '🧑🏾‍🏫' => 'ښوونکی: غنمی-تورنګه پوستکۍ',
    '🧑🏿‍🏫' => 'ښوونکی: تور پوستکۍ',
    '👨🏻‍🏫' => 'سړی ښوونکی: د روڼ پوستکي ټون',
    '👨🏼‍🏫' => 'سړی ښوونکی: غنمی-روښانه پوستکۍ',
    '👨🏽‍🏫' => 'سړی ښوونکی: غنم رنګه',
    '👨🏾‍🏫' => 'سړی ښوونکی: غنمی-تورنګه پوستکۍ',
    '👨🏿‍🏫' => 'سړی ښوونکی: تور پوستکۍ',
    '👩🏻‍🏫' => 'ښځه ښوونکي: د روڼ پوستکي ټون',
    '👩🏼‍🏫' => 'ښځه ښوونکي: غنمی-روښانه پوستکۍ',
    '👩🏽‍🏫' => 'ښځه ښوونکي: غنم رنګه',
    '👩🏾‍🏫' => 'ښځه ښوونکي: غنمی-تورنګه پوستکۍ',
    '👩🏿‍🏫' => 'ښځه ښوونکي: تور پوستکۍ',
    '🧑🏻‍⚖' => 'قاضي: د روڼ پوستکي ټون',
    '🧑🏼‍⚖' => 'قاضي: غنمی-روښانه پوستکۍ',
    '🧑🏽‍⚖' => 'قاضي: غنم رنګه',
    '🧑🏾‍⚖' => 'قاضي: غنمی-تورنګه پوستکۍ',
    '🧑🏿‍⚖' => 'قاضي: تور پوستکۍ',
    '👨🏻‍⚖' => 'سړی قاضي: د روڼ پوستکي ټون',
    '👨🏼‍⚖' => 'سړی قاضي: غنمی-روښانه پوستکۍ',
    '👨🏽‍⚖' => 'سړی قاضي: غنم رنګه',
    '👨🏾‍⚖' => 'سړی قاضي: غنمی-تورنګه پوستکۍ',
    '👨🏿‍⚖' => 'سړی قاضي: تور پوستکۍ',
    '👩🏻‍⚖' => 'ښځه قاضي: د روڼ پوستکي ټون',
    '👩🏼‍⚖' => 'ښځه قاضي: غنمی-روښانه پوستکۍ',
    '👩🏽‍⚖' => 'ښځه قاضي: غنم رنګه',
    '👩🏾‍⚖' => 'ښځه قاضي: غنمی-تورنګه پوستکۍ',
    '👩🏿‍⚖' => 'ښځه قاضي: تور پوستکۍ',
    '🧑🏻‍🌾' => 'بزګر: د روڼ پوستکي ټون',
    '🧑🏼‍🌾' => 'بزګر: غنمی-روښانه پوستکۍ',
    '🧑🏽‍🌾' => 'بزګر: غنم رنګه',
    '🧑🏾‍🌾' => 'بزګر: غنمی-تورنګه پوستکۍ',
    '🧑🏿‍🌾' => 'بزګر: تور پوستکۍ',
    '👨🏻‍🌾' => 'سړی بزګر: د روڼ پوستکي ټون',
    '👨🏼‍🌾' => 'سړی بزګر: غنمی-روښانه پوستکۍ',
    '👨🏽‍🌾' => 'سړی بزګر: غنم رنګه',
    '👨🏾‍🌾' => 'سړی بزګر: غنمی-تورنګه پوستکۍ',
    '👨🏿‍🌾' => 'سړی بزګر: تور پوستکۍ',
    '👩🏻‍🌾' => 'ښځه د بزګر: د روڼ پوستکي ټون',
    '👩🏼‍🌾' => 'ښځه د بزګر: غنمی-روښانه پوستکۍ',
    '👩🏽‍🌾' => 'ښځه د بزګر: غنم رنګه',
    '👩🏾‍🌾' => 'ښځه د بزګر: غنمی-تورنګه پوستکۍ',
    '👩🏿‍🌾' => 'ښځه د بزګر: تور پوستکۍ',
    '🧑🏻‍🍳' => 'اشپز: د روڼ پوستکي ټون',
    '🧑🏼‍🍳' => 'اشپز: غنمی-روښانه پوستکۍ',
    '🧑🏽‍🍳' => 'اشپز: غنم رنګه',
    '🧑🏾‍🍳' => 'اشپز: غنمی-تورنګه پوستکۍ',
    '🧑🏿‍🍳' => 'اشپز: تور پوستکۍ',
    '👨🏻‍🍳' => 'سړی پخوونکی: د روڼ پوستکي ټون',
    '👨🏼‍🍳' => 'سړی پخوونکی: غنمی-روښانه پوستکۍ',
    '👨🏽‍🍳' => 'سړی پخوونکی: غنم رنګه',
    '👨🏾‍🍳' => 'سړی پخوونکی: غنمی-تورنګه پوستکۍ',
    '👨🏿‍🍳' => 'سړی پخوونکی: تور پوستکۍ',
    '👩🏻‍🍳' => 'ښځه پخوونکی: د روڼ پوستکي ټون',
    '👩🏼‍🍳' => 'ښځه پخوونکی: غنمی-روښانه پوستکۍ',
    '👩🏽‍🍳' => 'ښځه پخوونکی: غنم رنګه',
    '👩🏾‍🍳' => 'ښځه پخوونکی: غنمی-تورنګه پوستکۍ',
    '👩🏿‍🍳' => 'ښځه پخوونکی: تور پوستکۍ',
    '🧑🏻‍🔧' => 'مستري: د روڼ پوستکي ټون',
    '🧑🏼‍🔧' => 'مستري: غنمی-روښانه پوستکۍ',
    '🧑🏽‍🔧' => 'مستري: غنم رنګه',
    '🧑🏾‍🔧' => 'مستري: غنمی-تورنګه پوستکۍ',
    '🧑🏿‍🔧' => 'مستري: تور پوستکۍ',
    '👨🏻‍🔧' => 'سړی مستري: د روڼ پوستکي ټون',
    '👨🏼‍🔧' => 'سړی مستري: غنمی-روښانه پوستکۍ',
    '👨🏽‍🔧' => 'سړی مستري: غنم رنګه',
    '👨🏾‍🔧' => 'سړی مستري: غنمی-تورنګه پوستکۍ',
    '👨🏿‍🔧' => 'سړی مستري: تور پوستکۍ',
    '👩🏻‍🔧' => 'ښځه مستري: د روڼ پوستکي ټون',
    '👩🏼‍🔧' => 'ښځه مستري: غنمی-روښانه پوستکۍ',
    '👩🏽‍🔧' => 'ښځه مستري: غنم رنګه',
    '👩🏾‍🔧' => 'ښځه مستري: غنمی-تورنګه پوستکۍ',
    '👩🏿‍🔧' => 'ښځه مستري: تور پوستکۍ',
    '🧑🏻‍🏭' => 'د فابريکې کارمند: د روڼ پوستکي ټون',
    '🧑🏼‍🏭' => 'د فابريکې کارمند: غنمی-روښانه پوستکۍ',
    '🧑🏽‍🏭' => 'د فابريکې کارمند: غنم رنګه',
    '🧑🏾‍🏭' => 'د فابريکې کارمند: غنمی-تورنګه پوستکۍ',
    '🧑🏿‍🏭' => 'د فابريکې کارمند: تور پوستکۍ',
    '👨🏻‍🏭' => 'سړی د فابريکې کارګر: د روڼ پوستکي ټون',
    '👨🏼‍🏭' => 'سړی د فابريکې کارګر: غنمی-روښانه پوستکۍ',
    '👨🏽‍🏭' => 'سړی د فابريکې کارګر: غنم رنګه',
    '👨🏾‍🏭' => 'سړی د فابريکې کارګر: غنمی-تورنګه پوستکۍ',
    '👨🏿‍🏭' => 'سړی د فابريکې کارګر: تور پوستکۍ',
    '👩🏻‍🏭' => 'ښځه د فابريکې کارګر: د روڼ پوستکي ټون',
    '👩🏼‍🏭' => 'ښځه د فابريکې کارګر: غنمی-روښانه پوستکۍ',
    '👩🏽‍🏭' => 'ښځه د فابريکې کارګر: غنم رنګه',
    '👩🏾‍🏭' => 'ښځه د فابريکې کارګر: غنمی-تورنګه پوستکۍ',
    '👩🏿‍🏭' => 'ښځه د فابريکې کارګر: تور پوستکۍ',
    '🧑🏻‍💼' => 'دفتري کارمند: د روڼ پوستکي ټون',
    '🧑🏼‍💼' => 'دفتري کارمند: غنمی-روښانه پوستکۍ',
    '🧑🏽‍💼' => 'دفتري کارمند: غنم رنګه',
    '🧑🏾‍💼' => 'دفتري کارمند: غنمی-تورنګه پوستکۍ',
    '🧑🏿‍💼' => 'دفتري کارمند: تور پوستکۍ',
    '👨🏻‍💼' => 'سړی دفتري کارګر: د روڼ پوستکي ټون',
    '👨🏼‍💼' => 'سړی دفتري کارګر: غنمی-روښانه پوستکۍ',
    '👨🏽‍💼' => 'سړی دفتري کارګر: غنم رنګه',
    '👨🏾‍💼' => 'سړی دفتري کارګر: غنمی-تورنګه پوستکۍ',
    '👨🏿‍💼' => 'سړی دفتري کارګر: تور پوستکۍ',
    '👩🏻‍💼' => 'ښځه دفتر کارګر: د روڼ پوستکي ټون',
    '👩🏼‍💼' => 'ښځه دفتر کارګر: غنمی-روښانه پوستکۍ',
    '👩🏽‍💼' => 'ښځه دفتر کارګر: غنم رنګه',
    '👩🏾‍💼' => 'ښځه دفتر کارګر: غنمی-تورنګه پوستکۍ',
    '👩🏿‍💼' => 'ښځه دفتر کارګر: تور پوستکۍ',
    '🧑🏻‍🔬' => 'څېړونکی: د روڼ پوستکي ټون',
    '🧑🏼‍🔬' => 'څېړونکی: غنمی-روښانه پوستکۍ',
    '🧑🏽‍🔬' => 'څېړونکی: غنم رنګه',
    '🧑🏾‍🔬' => 'څېړونکی: غنمی-تورنګه پوستکۍ',
    '🧑🏿‍🔬' => 'څېړونکی: تور پوستکۍ',
    '👨🏻‍🔬' => 'سړي څېړونکی: د روڼ پوستکي ټون',
    '👨🏼‍🔬' => 'سړي څېړونکی: غنمی-روښانه پوستکۍ',
    '👨🏽‍🔬' => 'سړي څېړونکی: غنم رنګه',
    '👨🏾‍🔬' => 'سړي څېړونکی: غنمی-تورنګه پوستکۍ',
    '👨🏿‍🔬' => 'سړي څېړونکی: تور پوستکۍ',
    '👩🏻‍🔬' => 'ښځه څېړونکی: د روڼ پوستکي ټون',
    '👩🏼‍🔬' => 'ښځه څېړونکی: غنمی-روښانه پوستکۍ',
    '👩🏽‍🔬' => 'ښځه څېړونکی: غنم رنګه',
    '👩🏾‍🔬' => 'ښځه څېړونکی: غنمی-تورنګه پوستکۍ',
    '👩🏿‍🔬' => 'ښځه څېړونکی: تور پوستکۍ',
    '🧑🏻‍💻' => 'تيکنالوجست: د روڼ پوستکي ټون',
    '🧑🏼‍💻' => 'تيکنالوجست: غنمی-روښانه پوستکۍ',
    '🧑🏽‍💻' => 'تيکنالوجست: غنم رنګه',
    '🧑🏾‍💻' => 'تيکنالوجست: غنمی-تورنګه پوستکۍ',
    '🧑🏿‍💻' => 'تيکنالوجست: تور پوستکۍ',
    '👨🏻‍💻' => 'سړی تکنالوجست: د روڼ پوستکي ټون',
    '👨🏼‍💻' => 'سړی تکنالوجست: غنمی-روښانه پوستکۍ',
    '👨🏽‍💻' => 'سړی تکنالوجست: غنم رنګه',
    '👨🏾‍💻' => 'سړی تکنالوجست: غنمی-تورنګه پوستکۍ',
    '👨🏿‍💻' => 'سړی تکنالوجست: تور پوستکۍ',
    '👩🏻‍💻' => 'ښځه تکنالوجست: د روڼ پوستکي ټون',
    '👩🏼‍💻' => 'ښځه تکنالوجست: غنمی-روښانه پوستکۍ',
    '👩🏽‍💻' => 'ښځه تکنالوجست: غنم رنګه',
    '👩🏾‍💻' => 'ښځه تکنالوجست: غنمی-تورنګه پوستکۍ',
    '👩🏿‍💻' => 'ښځه تکنالوجست: تور پوستکۍ',
    '🧑🏻‍🎤' => 'ښځه سندرغاړی: د روڼ پوستکي ټون',
    '🧑🏼‍🎤' => 'ښځه سندرغاړی: غنمی-روښانه پوستکۍ',
    '🧑🏽‍🎤' => 'ښځه سندرغاړی: غنم رنګه',
    '🧑🏾‍🎤' => 'ښځه سندرغاړی: غنمی-تورنګه پوستکۍ',
    '🧑🏿‍🎤' => 'ښځه سندرغاړی: تور پوستکۍ',
    '👨🏻‍🎤' => 'سړی سندرغاړی: د روڼ پوستکي ټون',
    '👨🏼‍🎤' => 'سړی سندرغاړی: غنمی-روښانه پوستکۍ',
    '👨🏽‍🎤' => 'سړی سندرغاړی: غنم رنګه',
    '👨🏾‍🎤' => 'سړی سندرغاړی: غنمی-تورنګه پوستکۍ',
    '👨🏿‍🎤' => 'سړی سندرغاړی: تور پوستکۍ',
    '👩🏻‍🎤' => 'ښځه سندرغاړې: د روڼ پوستکي ټون',
    '👩🏼‍🎤' => 'ښځه سندرغاړې: غنمی-روښانه پوستکۍ',
    '👩🏽‍🎤' => 'ښځه سندرغاړې: غنم رنګه',
    '👩🏾‍🎤' => 'ښځه سندرغاړې: غنمی-تورنګه پوستکۍ',
    '👩🏿‍🎤' => 'ښځه سندرغاړې: تور پوستکۍ',
    '🧑🏻‍🎨' => 'فنکار: د روڼ پوستکي ټون',
    '🧑🏼‍🎨' => 'فنکار: غنمی-روښانه پوستکۍ',
    '🧑🏽‍🎨' => 'فنکار: غنم رنګه',
    '🧑🏾‍🎨' => 'فنکار: غنمی-تورنګه پوستکۍ',
    '🧑🏿‍🎨' => 'فنکار: تور پوستکۍ',
    '👨🏻‍🎨' => 'سړی فنکار: د روڼ پوستکي ټون',
    '👨🏼‍🎨' => 'سړی فنکار: غنمی-روښانه پوستکۍ',
    '👨🏽‍🎨' => 'سړی فنکار: غنم رنګه',
    '👨🏾‍🎨' => 'سړی فنکار: غنمی-تورنګه پوستکۍ',
    '👨🏿‍🎨' => 'سړی فنکار: تور پوستکۍ',
    '👩🏻‍🎨' => 'ښځه فنکار: د روڼ پوستکي ټون',
    '👩🏼‍🎨' => 'ښځه فنکار: غنمی-روښانه پوستکۍ',
    '👩🏽‍🎨' => 'ښځه فنکار: غنم رنګه',
    '👩🏾‍🎨' => 'ښځه فنکار: غنمی-تورنګه پوستکۍ',
    '👩🏿‍🎨' => 'ښځه فنکار: تور پوستکۍ',
    '🧑🏻‍✈' => 'پيلوټ: د روڼ پوستکي ټون',
    '🧑🏼‍✈' => 'پيلوټ: غنمی-روښانه پوستکۍ',
    '🧑🏽‍✈' => 'پيلوټ: غنم رنګه',
    '🧑🏾‍✈' => 'پيلوټ: غنمی-تورنګه پوستکۍ',
    '🧑🏿‍✈' => 'پيلوټ: تور پوستکۍ',
    '👨🏻‍✈' => 'سړی پيلوټ: د روڼ پوستکي ټون',
    '👨🏼‍✈' => 'سړی پيلوټ: غنمی-روښانه پوستکۍ',
    '👨🏽‍✈' => 'سړی پيلوټ: غنم رنګه',
    '👨🏾‍✈' => 'سړی پيلوټ: غنمی-تورنګه پوستکۍ',
    '👨🏿‍✈' => 'سړی پيلوټ: تور پوستکۍ',
    '👩🏻‍✈' => 'ښځه پيلوټ: د روڼ پوستکي ټون',
    '👩🏼‍✈' => 'ښځه پيلوټ: غنمی-روښانه پوستکۍ',
    '👩🏽‍✈' => 'ښځه پيلوټ: غنم رنګه',
    '👩🏾‍✈' => 'ښځه پيلوټ: غنمی-تورنګه پوستکۍ',
    '👩🏿‍✈' => 'ښځه پيلوټ: تور پوستکۍ',
    '🧑🏻‍🚀' => 'فضانورد: د روڼ پوستکي ټون',
    '🧑🏼‍🚀' => 'فضانورد: غنمی-روښانه پوستکۍ',
    '🧑🏽‍🚀' => 'فضانورد: غنم رنګه',
    '🧑🏾‍🚀' => 'فضانورد: غنمی-تورنګه پوستکۍ',
    '🧑🏿‍🚀' => 'فضانورد: تور پوستکۍ',
    '👨🏻‍🚀' => 'سړی فضانورد: د روڼ پوستکي ټون',
    '👨🏼‍🚀' => 'سړی فضانورد: غنمی-روښانه پوستکۍ',
    '👨🏽‍🚀' => 'سړی فضانورد: غنم رنګه',
    '👨🏾‍🚀' => 'سړی فضانورد: غنمی-تورنګه پوستکۍ',
    '👨🏿‍🚀' => 'سړی فضانورد: تور پوستکۍ',
    '👩🏻‍🚀' => 'ښځه فضانورد: د روڼ پوستکي ټون',
    '👩🏼‍🚀' => 'ښځه فضانورد: غنمی-روښانه پوستکۍ',
    '👩🏽‍🚀' => 'ښځه فضانورد: غنم رنګه',
    '👩🏾‍🚀' => 'ښځه فضانورد: غنمی-تورنګه پوستکۍ',
    '👩🏿‍🚀' => 'ښځه فضانورد: تور پوستکۍ',
    '🧑🏻‍🚒' => 'د اور وژنې کارمند: د روڼ پوستکي ټون',
    '🧑🏼‍🚒' => 'د اور وژنې کارمند: غنمی-روښانه پوستکۍ',
    '🧑🏽‍🚒' => 'د اور وژنې کارمند: غنم رنګه',
    '🧑🏾‍🚒' => 'د اور وژنې کارمند: غنمی-تورنګه پوستکۍ',
    '🧑🏿‍🚒' => 'د اور وژنې کارمند: تور پوستکۍ',
    '👨🏻‍🚒' => 'سړی اور وژونکی: د روڼ پوستکي ټون',
    '👨🏼‍🚒' => 'سړی اور وژونکی: غنمی-روښانه پوستکۍ',
    '👨🏽‍🚒' => 'سړی اور وژونکی: غنم رنګه',
    '👨🏾‍🚒' => 'سړی اور وژونکی: غنمی-تورنګه پوستکۍ',
    '👨🏿‍🚒' => 'سړی اور وژونکی: تور پوستکۍ',
    '👩🏻‍🚒' => 'ښځه اور وژونکی: د روڼ پوستکي ټون',
    '👩🏼‍🚒' => 'ښځه اور وژونکی: غنمی-روښانه پوستکۍ',
    '👩🏽‍🚒' => 'ښځه اور وژونکی: غنم رنګه',
    '👩🏾‍🚒' => 'ښځه اور وژونکی: غنمی-تورنګه پوستکۍ',
    '👩🏿‍🚒' => 'ښځه اور وژونکی: تور پوستکۍ',
    '👮🏻‍♂' => 'سړی د پولیسو افسر: د روڼ پوستکي ټون',
    '👮🏼‍♂' => 'سړی د پولیسو افسر: غنمی-روښانه پوستکۍ',
    '👮🏽‍♂' => 'سړی د پولیسو افسر: غنم رنګه',
    '👮🏾‍♂' => 'سړی د پولیسو افسر: غنمی-تورنګه پوستکۍ',
    '👮🏿‍♂' => 'سړی د پولیسو افسر: تور پوستکۍ',
    '👮🏻‍♀' => 'ښځه د پولیسو افسر: د روڼ پوستکي ټون',
    '👮🏼‍♀' => 'ښځه د پولیسو افسر: غنمی-روښانه پوستکۍ',
    '👮🏽‍♀' => 'ښځه د پولیسو افسر: غنم رنګه',
    '👮🏾‍♀' => 'ښځه د پولیسو افسر: غنمی-تورنګه پوستکۍ',
    '👮🏿‍♀' => 'ښځه د پولیسو افسر: تور پوستکۍ',
    '🕵🏻‍♂' => 'سړی کشفي: د روڼ پوستکي ټون',
    '🕵🏼‍♂' => 'سړی کشفي: غنمی-روښانه پوستکۍ',
    '🕵🏽‍♂' => 'سړی کشفي: غنم رنګه',
    '🕵🏾‍♂' => 'سړی کشفي: غنمی-تورنګه پوستکۍ',
    '🕵🏿‍♂' => 'سړی کشفي: تور پوستکۍ',
    '🕵🏻‍♀' => 'ښځه کشفي: د روڼ پوستکي ټون',
    '🕵🏼‍♀' => 'ښځه کشفي: غنمی-روښانه پوستکۍ',
    '🕵🏽‍♀' => 'ښځه کشفي: غنم رنګه',
    '🕵🏾‍♀' => 'ښځه کشفي: غنمی-تورنګه پوستکۍ',
    '🕵🏿‍♀' => 'ښځه کشفي: تور پوستکۍ',
    '💂🏻‍♂' => 'سړی ساتونکي: د روڼ پوستکي ټون',
    '💂🏼‍♂' => 'سړی ساتونکي: غنمی-روښانه پوستکۍ',
    '💂🏽‍♂' => 'سړی ساتونکي: غنم رنګه',
    '💂🏾‍♂' => 'سړی ساتونکي: غنمی-تورنګه پوستکۍ',
    '💂🏿‍♂' => 'سړی ساتونکي: تور پوستکۍ',
    '💂🏻‍♀' => 'ښځه ساتونکي: د روڼ پوستکي ټون',
    '💂🏼‍♀' => 'ښځه ساتونکي: غنمی-روښانه پوستکۍ',
    '💂🏽‍♀' => 'ښځه ساتونکي: غنم رنګه',
    '💂🏾‍♀' => 'ښځه ساتونکي: غنمی-تورنګه پوستکۍ',
    '💂🏿‍♀' => 'ښځه ساتونکي: تور پوستکۍ',
    '👷🏻‍♂' => 'سړی ساختماني کارګر: د روڼ پوستکي ټون',
    '👷🏼‍♂' => 'سړی ساختماني کارګر: غنمی-روښانه پوستکۍ',
    '👷🏽‍♂' => 'سړی ساختماني کارګر: غنم رنګه',
    '👷🏾‍♂' => 'سړی ساختماني کارګر: غنمی-تورنګه پوستکۍ',
    '👷🏿‍♂' => 'سړی ساختماني کارګر: تور پوستکۍ',
    '👷🏻‍♀' => 'ښځه ساختماني کارګر: د روڼ پوستکي ټون',
    '👷🏼‍♀' => 'ښځه ساختماني کارګر: غنمی-روښانه پوستکۍ',
    '👷🏽‍♀' => 'ښځه ساختماني کارګر: غنم رنګه',
    '👷🏾‍♀' => 'ښځه ساختماني کارګر: غنمی-تورنګه پوستکۍ',
    '👷🏿‍♀' => 'ښځه ساختماني کارګر: تور پوستکۍ',
    '👳🏻‍♂' => 'سړی لونګۍ په سر: د روڼ پوستکي ټون',
    '👳🏼‍♂' => 'سړی لونګۍ په سر: غنمی-روښانه پوستکۍ',
    '👳🏽‍♂' => 'سړی لونګۍ په سر: غنم رنګه',
    '👳🏾‍♂' => 'سړی لونګۍ په سر: غنمی-تورنګه پوستکۍ',
    '👳🏿‍♂' => 'سړی لونګۍ په سر: تور پوستکۍ',
    '👳🏻‍♀' => 'ښځه لونګۍ په سر: د روڼ پوستکي ټون',
    '👳🏼‍♀' => 'ښځه لونګۍ په سر: غنمی-روښانه پوستکۍ',
    '👳🏽‍♀' => 'ښځه لونګۍ په سر: غنم رنګه',
    '👳🏾‍♀' => 'ښځه لونګۍ په سر: غنمی-تورنګه پوستکۍ',
    '👳🏿‍♀' => 'ښځه لونګۍ په سر: تور پوستکۍ',
    '🤵🏻‍♂' => 'سړی په تکزیدو: د روڼ پوستکي ټون',
    '🤵🏼‍♂' => 'سړی په تکزیدو: غنمی-روښانه پوستکۍ',
    '🤵🏽‍♂' => 'سړی په تکزیدو: غنم رنګه',
    '🤵🏾‍♂' => 'سړی په تکزیدو: غنمی-تورنګه پوستکۍ',
    '🤵🏿‍♂' => 'سړی په تکزیدو: تور پوستکۍ',
    '🤵🏻‍♀' => 'ښځه په ټکسیدو: د روڼ پوستکي ټون',
    '🤵🏼‍♀' => 'ښځه په ټکسیدو: غنمی-روښانه پوستکۍ',
    '🤵🏽‍♀' => 'ښځه په ټکسیدو: غنم رنګه',
    '🤵🏾‍♀' => 'ښځه په ټکسیدو: غنمی-تورنګه پوستکۍ',
    '🤵🏿‍♀' => 'ښځه په ټکسیدو: تور پوستکۍ',
    '👰🏻‍♂' => 'سړی د پردې: د روڼ پوستکي ټون',
    '👰🏼‍♂' => 'سړی د پردې: غنمی-روښانه پوستکۍ',
    '👰🏽‍♂' => 'سړی د پردې: غنم رنګه',
    '👰🏾‍♂' => 'سړی د پردې: غنمی-تورنګه پوستکۍ',
    '👰🏿‍♂' => 'سړی د پردې: تور پوستکۍ',
    '👰🏻‍♀' => 'ښځه د پردې سره: د روڼ پوستکي ټون',
    '👰🏼‍♀' => 'ښځه د پردې سره: غنمی-روښانه پوستکۍ',
    '👰🏽‍♀' => 'ښځه د پردې سره: غنم رنګه',
    '👰🏾‍♀' => 'ښځه د پردې سره: غنمی-تورنګه پوستکۍ',
    '👰🏿‍♀' => 'ښځه د پردې سره: تور پوستکۍ',
    '👩🏻‍🍼' => 'ښځه ماشوم تغذیه کوي: د روڼ پوستکي ټون',
    '👩🏼‍🍼' => 'ښځه ماشوم تغذیه کوي: غنمی-روښانه پوستکۍ',
    '👩🏽‍🍼' => 'ښځه ماشوم تغذیه کوي: غنم رنګه',
    '👩🏾‍🍼' => 'ښځه ماشوم تغذیه کوي: غنمی-تورنګه پوستکۍ',
    '👩🏿‍🍼' => 'ښځه ماشوم تغذیه کوي: تور پوستکۍ',
    '👨🏻‍🍼' => 'یو شخص ماشوم ته خواړه ورکوي: د روڼ پوستکي ټون',
    '👨🏼‍🍼' => 'یو شخص ماشوم ته خواړه ورکوي: غنمی-روښانه پوستکۍ',
    '👨🏽‍🍼' => 'یو شخص ماشوم ته خواړه ورکوي: غنم رنګه',
    '👨🏾‍🍼' => 'یو شخص ماشوم ته خواړه ورکوي: غنمی-تورنګه پوستکۍ',
    '👨🏿‍🍼' => 'یو شخص ماشوم ته خواړه ورکوي: تور پوستکۍ',
    '🧑🏻‍🍼' => 'شخص ماشوم ته خواړه ورکوي: د روڼ پوستکي ټون',
    '🧑🏼‍🍼' => 'شخص ماشوم ته خواړه ورکوي: غنمی-روښانه پوستکۍ',
    '🧑🏽‍🍼' => 'شخص ماشوم ته خواړه ورکوي: غنم رنګه',
    '🧑🏾‍🍼' => 'شخص ماشوم ته خواړه ورکوي: غنمی-تورنګه پوستکۍ',
    '🧑🏿‍🍼' => 'شخص ماشوم ته خواړه ورکوي: تور پوستکۍ',
    '🧑🏻‍🎄' => 'میکس کلاز: د روڼ پوستکي ټون',
    '🧑🏼‍🎄' => 'میکس کلاز: غنمی-روښانه پوستکۍ',
    '🧑🏽‍🎄' => 'میکس کلاز: غنم رنګه',
    '🧑🏾‍🎄' => 'میکس کلاز: غنمی-تورنګه پوستکۍ',
    '🧑🏿‍🎄' => 'میکس کلاز: تور پوستکۍ',
    '🦸🏻‍♂' => 'سړی لوي اتل: د روڼ پوستکي ټون',
    '🦸🏼‍♂' => 'سړی لوي اتل: غنمی-روښانه پوستکۍ',
    '🦸🏽‍♂' => 'سړی لوي اتل: غنم رنګه',
    '🦸🏾‍♂' => 'سړی لوي اتل: غنمی-تورنګه پوستکۍ',
    '🦸🏿‍♂' => 'سړی لوي اتل: تور پوستکۍ',
    '🦸🏻‍♀' => 'ښځه لوي اتله: د روڼ پوستکي ټون',
    '🦸🏼‍♀' => 'ښځه لوي اتله: غنمی-روښانه پوستکۍ',
    '🦸🏽‍♀' => 'ښځه لوي اتله: غنم رنګه',
    '🦸🏾‍♀' => 'ښځه لوي اتله: غنمی-تورنګه پوستکۍ',
    '🦸🏿‍♀' => 'ښځه لوي اتله: تور پوستکۍ',
    '🦹🏻‍♂' => 'سړی لوي ورانکاری: د روڼ پوستکي ټون',
    '🦹🏼‍♂' => 'سړی لوي ورانکاری: غنمی-روښانه پوستکۍ',
    '🦹🏽‍♂' => 'سړی لوي ورانکاری: غنم رنګه',
    '🦹🏾‍♂' => 'سړی لوي ورانکاری: غنمی-تورنګه پوستکۍ',
    '🦹🏿‍♂' => 'سړی لوي ورانکاری: تور پوستکۍ',
    '🦹🏻‍♀' => 'ښځه لوي ورانکارې: د روڼ پوستکي ټون',
    '🦹🏼‍♀' => 'ښځه لوي ورانکارې: غنمی-روښانه پوستکۍ',
    '🦹🏽‍♀' => 'ښځه لوي ورانکارې: غنم رنګه',
    '🦹🏾‍♀' => 'ښځه لوي ورانکارې: غنمی-تورنګه پوستکۍ',
    '🦹🏿‍♀' => 'ښځه لوي ورانکارې: تور پوستکۍ',
    '🧙🏻‍♂' => 'سړی جادوګر: د روڼ پوستکي ټون',
    '🧙🏼‍♂' => 'سړی جادوګر: غنمی-روښانه پوستکۍ',
    '🧙🏽‍♂' => 'سړی جادوګر: غنم رنګه',
    '🧙🏾‍♂' => 'سړی جادوګر: غنمی-تورنګه پوستکۍ',
    '🧙🏿‍♂' => 'سړی جادوګر: تور پوستکۍ',
    '🧙🏻‍♀' => 'ښځه جادوګره: د روڼ پوستکي ټون',
    '🧙🏼‍♀' => 'ښځه جادوګره: غنمی-روښانه پوستکۍ',
    '🧙🏽‍♀' => 'ښځه جادوګره: غنم رنګه',
    '🧙🏾‍♀' => 'ښځه جادوګره: غنمی-تورنګه پوستکۍ',
    '🧙🏿‍♀' => 'ښځه جادوګره: تور پوستکۍ',
    '🧚🏻‍♂' => 'سړی خاپېری: د روڼ پوستکي ټون',
    '🧚🏼‍♂' => 'سړی خاپېری: غنمی-روښانه پوستکۍ',
    '🧚🏽‍♂' => 'سړی خاپېری: غنم رنګه',
    '🧚🏾‍♂' => 'سړی خاپېری: غنمی-تورنګه پوستکۍ',
    '🧚🏿‍♂' => 'سړی خاپېری: تور پوستکۍ',
    '🧚🏻‍♀' => 'ښځه ښاپيرۍ: د روڼ پوستکي ټون',
    '🧚🏼‍♀' => 'ښځه ښاپيرۍ: غنمی-روښانه پوستکۍ',
    '🧚🏽‍♀' => 'ښځه ښاپيرۍ: غنم رنګه',
    '🧚🏾‍♀' => 'ښځه ښاپيرۍ: غنمی-تورنګه پوستکۍ',
    '🧚🏿‍♀' => 'ښځه ښاپيرۍ: تور پوستکۍ',
    '🧛🏻‍♂' => 'سړی بلا: د روڼ پوستکي ټون',
    '🧛🏼‍♂' => 'سړی بلا: غنمی-روښانه پوستکۍ',
    '🧛🏽‍♂' => 'سړی بلا: غنم رنګه',
    '🧛🏾‍♂' => 'سړی بلا: غنمی-تورنګه پوستکۍ',
    '🧛🏿‍♂' => 'سړی بلا: تور پوستکۍ',
    '🧛🏻‍♀' => 'ښځه بلا: د روڼ پوستکي ټون',
    '🧛🏼‍♀' => 'ښځه بلا: غنمی-روښانه پوستکۍ',
    '🧛🏽‍♀' => 'ښځه بلا: غنم رنګه',
    '🧛🏾‍♀' => 'ښځه بلا: غنمی-تورنګه پوستکۍ',
    '🧛🏿‍♀' => 'ښځه بلا: تور پوستکۍ',
    '🧜🏻‍♂' => 'مرمین: د روڼ پوستکي ټون',
    '🧜🏼‍♂' => 'مرمین: غنمی-روښانه پوستکۍ',
    '🧜🏽‍♂' => 'مرمین: غنم رنګه',
    '🧜🏾‍♂' => 'مرمین: غنمی-تورنګه پوستکۍ',
    '🧜🏿‍♂' => 'مرمین: تور پوستکۍ',
    '🧜🏻‍♀' => 'مرمیډ: د روڼ پوستکي ټون',
    '🧜🏼‍♀' => 'مرمیډ: غنمی-روښانه پوستکۍ',
    '🧜🏽‍♀' => 'مرمیډ: غنم رنګه',
    '🧜🏾‍♀' => 'مرمیډ: غنمی-تورنګه پوستکۍ',
    '🧜🏿‍♀' => 'مرمیډ: تور پوستکۍ',
    '🧝🏻‍♂' => 'سړی ګوړا: د روڼ پوستکي ټون',
    '🧝🏼‍♂' => 'سړی ګوړا: غنمی-روښانه پوستکۍ',
    '🧝🏽‍♂' => 'سړی ګوړا: غنم رنګه',
    '🧝🏾‍♂' => 'سړی ګوړا: غنمی-تورنګه پوستکۍ',
    '🧝🏿‍♂' => 'سړی ګوړا: تور پوستکۍ',
    '🧝🏻‍♀' => 'ښځه ګوړا: د روڼ پوستکي ټون',
    '🧝🏼‍♀' => 'ښځه ګوړا: غنمی-روښانه پوستکۍ',
    '🧝🏽‍♀' => 'ښځه ګوړا: غنم رنګه',
    '🧝🏾‍♀' => 'ښځه ګوړا: غنمی-تورنګه پوستکۍ',
    '🧝🏿‍♀' => 'ښځه ګوړا: تور پوستکۍ',
    '💆🏻‍♂' => 'سړی مالش ترلاسه کوي: د روڼ پوستکي ټون',
    '💆🏼‍♂' => 'سړی مالش ترلاسه کوي: غنمی-روښانه پوستکۍ',
    '💆🏽‍♂' => 'سړی مالش ترلاسه کوي: غنم رنګه',
    '💆🏾‍♂' => 'سړی مالش ترلاسه کوي: غنمی-تورنګه پوستکۍ',
    '💆🏿‍♂' => 'سړی مالش ترلاسه کوي: تور پوستکۍ',
    '💆🏻‍♀' => 'ښځه مالش ترلاسه کوي: د روڼ پوستکي ټون',
    '💆🏼‍♀' => 'ښځه مالش ترلاسه کوي: غنمی-روښانه پوستکۍ',
    '💆🏽‍♀' => 'ښځه مالش ترلاسه کوي: غنم رنګه',
    '💆🏾‍♀' => 'ښځه مالش ترلاسه کوي: غنمی-تورنګه پوستکۍ',
    '💆🏿‍♀' => 'ښځه مالش ترلاسه کوي: تور پوستکۍ',
    '💇🏻‍♂' => 'سړی پرېټ کوي: د روڼ پوستکي ټون',
    '💇🏼‍♂' => 'سړی پرېټ کوي: غنمی-روښانه پوستکۍ',
    '💇🏽‍♂' => 'سړی پرېټ کوي: غنم رنګه',
    '💇🏾‍♂' => 'سړی پرېټ کوي: غنمی-تورنګه پوستکۍ',
    '💇🏿‍♂' => 'سړی پرېټ کوي: تور پوستکۍ',
    '💇🏻‍♀' => 'ښځه پرېټ کوي: د روڼ پوستکي ټون',
    '💇🏼‍♀' => 'ښځه پرېټ کوي: غنمی-روښانه پوستکۍ',
    '💇🏽‍♀' => 'ښځه پرېټ کوي: غنم رنګه',
    '💇🏾‍♀' => 'ښځه پرېټ کوي: غنمی-تورنګه پوستکۍ',
    '💇🏿‍♀' => 'ښځه پرېټ کوي: تور پوستکۍ',
    '🚶🏻‍♂' => 'روان سړی: د روڼ پوستکي ټون',
    '🚶🏼‍♂' => 'روان سړی: غنمی-روښانه پوستکۍ',
    '🚶🏽‍♂' => 'روان سړی: غنم رنګه',
    '🚶🏾‍♂' => 'روان سړی: غنمی-تورنګه پوستکۍ',
    '🚶🏿‍♂' => 'روان سړی: تور پوستکۍ',
    '🚶🏻‍♀' => 'روانه ښځه: د روڼ پوستکي ټون',
    '🚶🏼‍♀' => 'روانه ښځه: غنمی-روښانه پوستکۍ',
    '🚶🏽‍♀' => 'روانه ښځه: غنم رنګه',
    '🚶🏾‍♀' => 'روانه ښځه: غنمی-تورنګه پوستکۍ',
    '🚶🏿‍♀' => 'روانه ښځه: تور پوستکۍ',
    '🚶🏻‍➡' => 'روان شخص: د روڼ پوستکي ټون و ښي خوا ته مخامخ',
    '🚶🏼‍➡' => 'روان شخص: غنمی-روښانه پوستکۍ و ښي خوا ته مخامخ',
    '🚶🏽‍➡' => 'روان شخص: غنم رنګه و ښي خوا ته مخامخ',
    '🚶🏾‍➡' => 'روان شخص: غنمی-تورنګه پوستکۍ و ښي خوا ته مخامخ',
    '🚶🏿‍➡' => 'روان شخص: تور پوستکۍ و ښي خوا ته مخامخ',
    '🧍🏻‍♂' => 'ولاړ سړی: د روڼ پوستکي ټون',
    '🧍🏼‍♂' => 'ولاړ سړی: غنمی-روښانه پوستکۍ',
    '🧍🏽‍♂' => 'ولاړ سړی: غنم رنګه',
    '🧍🏾‍♂' => 'ولاړ سړی: غنمی-تورنګه پوستکۍ',
    '🧍🏿‍♂' => 'ولاړ سړی: تور پوستکۍ',
    '🧍🏻‍♀' => 'ولاړه ښځه: د روڼ پوستکي ټون',
    '🧍🏼‍♀' => 'ولاړه ښځه: غنمی-روښانه پوستکۍ',
    '🧍🏽‍♀' => 'ولاړه ښځه: غنم رنګه',
    '🧍🏾‍♀' => 'ولاړه ښځه: غنمی-تورنګه پوستکۍ',
    '🧍🏿‍♀' => 'ولاړه ښځه: تور پوستکۍ',
    '🧎🏻‍♂' => 'سړی چوکېږي: د روڼ پوستکي ټون',
    '🧎🏼‍♂' => 'سړی چوکېږي: غنمی-روښانه پوستکۍ',
    '🧎🏽‍♂' => 'سړی چوکېږي: غنم رنګه',
    '🧎🏾‍♂' => 'سړی چوکېږي: غنمی-تورنګه پوستکۍ',
    '🧎🏿‍♂' => 'سړی چوکېږي: تور پوستکۍ',
    '🧎🏻‍♀' => 'ښځه چوکېږي: د روڼ پوستکي ټون',
    '🧎🏼‍♀' => 'ښځه چوکېږي: غنمی-روښانه پوستکۍ',
    '🧎🏽‍♀' => 'ښځه چوکېږي: غنم رنګه',
    '🧎🏾‍♀' => 'ښځه چوکېږي: غنمی-تورنګه پوستکۍ',
    '🧎🏿‍♀' => 'ښځه چوکېږي: تور پوستکۍ',
    '🧎🏻‍➡' => 'شخص چوکېږي: د روڼ پوستکي ټون و ښي خوا ته مخامخ',
    '🧎🏼‍➡' => 'شخص چوکېږي: غنمی-روښانه پوستکۍ و ښي خوا ته مخامخ',
    '🧎🏽‍➡' => 'شخص چوکېږي: غنم رنګه و ښي خوا ته مخامخ',
    '🧎🏾‍➡' => 'شخص چوکېږي: غنمی-تورنګه پوستکۍ و ښي خوا ته مخامخ',
    '🧎🏿‍➡' => 'شخص چوکېږي: تور پوستکۍ و ښي خوا ته مخامخ',
    '🧑🏻‍🦯' => 'شخص د معلولينو د امسا سره: د روڼ پوستکي ټون',
    '🧑🏼‍🦯' => 'شخص د معلولينو د امسا سره: غنمی-روښانه پوستکۍ',
    '🧑🏽‍🦯' => 'شخص د معلولينو د امسا سره: غنم رنګه',
    '🧑🏾‍🦯' => 'شخص د معلولينو د امسا سره: غنمی-تورنګه پوستکۍ',
    '🧑🏿‍🦯' => 'شخص د معلولينو د امسا سره: تور پوستکۍ',
    '👨🏻‍🦯' => 'سړی د معلولينو د همسا سره: د روڼ پوستکي ټون',
    '👨🏼‍🦯' => 'سړی د معلولينو د همسا سره: غنمی-روښانه پوستکۍ',
    '👨🏽‍🦯' => 'سړی د معلولينو د همسا سره: غنم رنګه',
    '👨🏾‍🦯' => 'سړی د معلولينو د همسا سره: غنمی-تورنګه پوستکۍ',
    '👨🏿‍🦯' => 'سړی د معلولينو د همسا سره: تور پوستکۍ',
    '👩🏻‍🦯' => 'ښځه د معلولينو د همسا سره: د روڼ پوستکي ټون',
    '👩🏼‍🦯' => 'ښځه د معلولينو د همسا سره: غنمی-روښانه پوستکۍ',
    '👩🏽‍🦯' => 'ښځه د معلولينو د همسا سره: غنم رنګه',
    '👩🏾‍🦯' => 'ښځه د معلولينو د همسا سره: غنمی-تورنګه پوستکۍ',
    '👩🏿‍🦯' => 'ښځه د معلولينو د همسا سره: تور پوستکۍ',
    '🧑🏻‍🦼' => 'شخص د معلولينو په موټر چوکۍ کې: د روڼ پوستکي ټون',
    '🧑🏼‍🦼' => 'شخص د معلولينو په موټر چوکۍ کې: غنمی-روښانه پوستکۍ',
    '🧑🏽‍🦼' => 'شخص د معلولينو په موټر چوکۍ کې: غنم رنګه',
    '🧑🏾‍🦼' => 'شخص د معلولينو په موټر چوکۍ کې: غنمی-تورنګه پوستکۍ',
    '🧑🏿‍🦼' => 'شخص د معلولينو په موټر چوکۍ کې: تور پوستکۍ',
    '👨🏻‍🦼' => 'سړی د معلولينو په موټر چوکۍ کې: د روڼ پوستکي ټون',
    '👨🏼‍🦼' => 'سړی د معلولينو په موټر چوکۍ کې: غنمی-روښانه پوستکۍ',
    '👨🏽‍🦼' => 'سړی د معلولينو په موټر چوکۍ کې: غنم رنګه',
    '👨🏾‍🦼' => 'سړی د معلولينو په موټر چوکۍ کې: غنمی-تورنګه پوستکۍ',
    '👨🏿‍🦼' => 'سړی د معلولينو په موټر چوکۍ کې: تور پوستکۍ',
    '👩🏻‍🦼' => 'ښځه د معلولينو په موټر چوکۍ کې: د روڼ پوستکي ټون',
    '👩🏼‍🦼' => 'ښځه د معلولينو په موټر چوکۍ کې: غنمی-روښانه پوستکۍ',
    '👩🏽‍🦼' => 'ښځه د معلولينو په موټر چوکۍ کې: غنم رنګه',
    '👩🏾‍🦼' => 'ښځه د معلولينو په موټر چوکۍ کې: غنمی-تورنګه پوستکۍ',
    '👩🏿‍🦼' => 'ښځه د معلولينو په موټر چوکۍ کې: تور پوستکۍ',
    '🧑🏻‍🦽' => 'شخص د معلولينو په لاسي چوکۍ کې: د روڼ پوستکي ټون',
    '🧑🏼‍🦽' => 'شخص د معلولينو په لاسي چوکۍ کې: غنمی-روښانه پوستکۍ',
    '🧑🏽‍🦽' => 'شخص د معلولينو په لاسي چوکۍ کې: غنم رنګه',
    '🧑🏾‍🦽' => 'شخص د معلولينو په لاسي چوکۍ کې: غنمی-تورنګه پوستکۍ',
    '🧑🏿‍🦽' => 'شخص د معلولينو په لاسي چوکۍ کې: تور پوستکۍ',
    '👨🏻‍🦽' => 'سړی د معلولينو په لاسي چوکۍ کې: د روڼ پوستکي ټون',
    '👨🏼‍🦽' => 'سړی د معلولينو په لاسي چوکۍ کې: غنمی-روښانه پوستکۍ',
    '👨🏽‍🦽' => 'سړی د معلولينو په لاسي چوکۍ کې: غنم رنګه',
    '👨🏾‍🦽' => 'سړی د معلولينو په لاسي چوکۍ کې: غنمی-تورنګه پوستکۍ',
    '👨🏿‍🦽' => 'سړی د معلولينو په لاسي چوکۍ کې: تور پوستکۍ',
    '👩🏻‍🦽' => 'ښځه د معلولينو په لاسي چوکۍ کې: د روڼ پوستکي ټون',
    '👩🏼‍🦽' => 'ښځه د معلولينو په لاسي چوکۍ کې: غنمی-روښانه پوستکۍ',
    '👩🏽‍🦽' => 'ښځه د معلولينو په لاسي چوکۍ کې: غنم رنګه',
    '👩🏾‍🦽' => 'ښځه د معلولينو په لاسي چوکۍ کې: غنمی-تورنګه پوستکۍ',
    '👩🏿‍🦽' => 'ښځه د معلولينو په لاسي چوکۍ کې: تور پوستکۍ',
    '🏃🏻‍♂' => 'سړی ځغلي: د روڼ پوستکي ټون',
    '🏃🏼‍♂' => 'سړی ځغلي: غنمی-روښانه پوستکۍ',
    '🏃🏽‍♂' => 'سړی ځغلي: غنم رنګه',
    '🏃🏾‍♂' => 'سړی ځغلي: غنمی-تورنګه پوستکۍ',
    '🏃🏿‍♂' => 'سړی ځغلي: تور پوستکۍ',
    '🏃🏻‍♀' => 'ښځه ځغلي: د روڼ پوستکي ټون',
    '🏃🏼‍♀' => 'ښځه ځغلي: غنمی-روښانه پوستکۍ',
    '🏃🏽‍♀' => 'ښځه ځغلي: غنم رنګه',
    '🏃🏾‍♀' => 'ښځه ځغلي: غنمی-تورنګه پوستکۍ',
    '🏃🏿‍♀' => 'ښځه ځغلي: تور پوستکۍ',
    '🏃🏻‍➡' => 'شخص ځغلي: د روڼ پوستکي ټون و ښي خوا ته مخامخ',
    '🏃🏼‍➡' => 'شخص ځغلي: غنمی-روښانه پوستکۍ و ښي خوا ته مخامخ',
    '🏃🏽‍➡' => 'شخص ځغلي: غنم رنګه و ښي خوا ته مخامخ',
    '🏃🏾‍➡' => 'شخص ځغلي: غنمی-تورنګه پوستکۍ و ښي خوا ته مخامخ',
    '🏃🏿‍➡' => 'شخص ځغلي: تور پوستکۍ و ښي خوا ته مخامخ',
    '👯🏻‍♀' => 'ښځې د سويې غوږونو سره: د روڼ پوستکي ټون',
    '👯🏼‍♀' => 'ښځې د سويې غوږونو سره: غنمی-روښانه پوستکۍ',
    '👯🏽‍♀' => 'ښځې د سويې غوږونو سره: غنم رنګه',
    '👯🏾‍♀' => 'ښځې د سويې غوږونو سره: غنمی-تورنګه پوستکۍ',
    '👯🏿‍♀' => 'ښځې د سويې غوږونو سره: تور پوستکۍ',
    '👯🏻‍♂' => 'سړی د سويې غوږونو سره: د روڼ پوستکي ټون',
    '👯🏼‍♂' => 'سړی د سويې غوږونو سره: غنمی-روښانه پوستکۍ',
    '👯🏽‍♂' => 'سړی د سويې غوږونو سره: غنم رنګه',
    '👯🏾‍♂' => 'سړی د سويې غوږونو سره: غنمی-تورنګه پوستکۍ',
    '👯🏿‍♂' => 'سړی د سويې غوږونو سره: تور پوستکۍ',
    '🧖🏻‍♂' => 'سړی د پخار په خونه کې: د روڼ پوستکي ټون',
    '🧖🏼‍♂' => 'سړی د پخار په خونه کې: غنمی-روښانه پوستکۍ',
    '🧖🏽‍♂' => 'سړی د پخار په خونه کې: غنم رنګه',
    '🧖🏾‍♂' => 'سړی د پخار په خونه کې: غنمی-تورنګه پوستکۍ',
    '🧖🏿‍♂' => 'سړی د پخار په خونه کې: تور پوستکۍ',
    '🧖🏻‍♀' => 'ښځه د پخار په خونه کې: د روڼ پوستکي ټون',
    '🧖🏼‍♀' => 'ښځه د پخار په خونه کې: غنمی-روښانه پوستکۍ',
    '🧖🏽‍♀' => 'ښځه د پخار په خونه کې: غنم رنګه',
    '🧖🏾‍♀' => 'ښځه د پخار په خونه کې: غنمی-تورنګه پوستکۍ',
    '🧖🏿‍♀' => 'ښځه د پخار په خونه کې: تور پوستکۍ',
    '🧗🏻‍♂' => 'سړی هسکېږي: د روڼ پوستکي ټون',
    '🧗🏼‍♂' => 'سړی هسکېږي: غنمی-روښانه پوستکۍ',
    '🧗🏽‍♂' => 'سړی هسکېږي: غنم رنګه',
    '🧗🏾‍♂' => 'سړی هسکېږي: غنمی-تورنګه پوستکۍ',
    '🧗🏿‍♂' => 'سړی هسکېږي: تور پوستکۍ',
    '🧗🏻‍♀' => 'ښځه هسکيږې: د روڼ پوستکي ټون',
    '🧗🏼‍♀' => 'ښځه هسکيږې: غنمی-روښانه پوستکۍ',
    '🧗🏽‍♀' => 'ښځه هسکيږې: غنم رنګه',
    '🧗🏾‍♀' => 'ښځه هسکيږې: غنمی-تورنګه پوستکۍ',
    '🧗🏿‍♀' => 'ښځه هسکيږې: تور پوستکۍ',
    '🏌🏻‍♂' => 'سړی ګالف کوي: د روڼ پوستکي ټون',
    '🏌🏼‍♂' => 'سړی ګالف کوي: غنمی-روښانه پوستکۍ',
    '🏌🏽‍♂' => 'سړی ګالف کوي: غنم رنګه',
    '🏌🏾‍♂' => 'سړی ګالف کوي: غنمی-تورنګه پوستکۍ',
    '🏌🏿‍♂' => 'سړی ګالف کوي: تور پوستکۍ',
    '🏌🏻‍♀' => 'ښځه ګالف کوي: د روڼ پوستکي ټون',
    '🏌🏼‍♀' => 'ښځه ګالف کوي: غنمی-روښانه پوستکۍ',
    '🏌🏽‍♀' => 'ښځه ګالف کوي: غنم رنګه',
    '🏌🏾‍♀' => 'ښځه ګالف کوي: غنمی-تورنګه پوستکۍ',
    '🏌🏿‍♀' => 'ښځه ګالف کوي: تور پوستکۍ',
    '🏄🏻‍♂' => 'سړی سرفنګ: د روڼ پوستکي ټون',
    '🏄🏼‍♂' => 'سړی سرفنګ: غنمی-روښانه پوستکۍ',
    '🏄🏽‍♂' => 'سړی سرفنګ: غنم رنګه',
    '🏄🏾‍♂' => 'سړی سرفنګ: غنمی-تورنګه پوستکۍ',
    '🏄🏿‍♂' => 'سړی سرفنګ: تور پوستکۍ',
    '🏄🏻‍♀' => 'ښځه سرفنګ: د روڼ پوستکي ټون',
    '🏄🏼‍♀' => 'ښځه سرفنګ: غنمی-روښانه پوستکۍ',
    '🏄🏽‍♀' => 'ښځه سرفنګ: غنم رنګه',
    '🏄🏾‍♀' => 'ښځه سرفنګ: غنمی-تورنګه پوستکۍ',
    '🏄🏿‍♀' => 'ښځه سرفنګ: تور پوستکۍ',
    '🚣🏻‍♂' => 'سړی کښتۍ چلوي: د روڼ پوستکي ټون',
    '🚣🏼‍♂' => 'سړی کښتۍ چلوي: غنمی-روښانه پوستکۍ',
    '🚣🏽‍♂' => 'سړی کښتۍ چلوي: غنم رنګه',
    '🚣🏾‍♂' => 'سړی کښتۍ چلوي: غنمی-تورنګه پوستکۍ',
    '🚣🏿‍♂' => 'سړی کښتۍ چلوي: تور پوستکۍ',
    '🚣🏻‍♀' => 'ښځه کښتۍ چلوي: د روڼ پوستکي ټون',
    '🚣🏼‍♀' => 'ښځه کښتۍ چلوي: غنمی-روښانه پوستکۍ',
    '🚣🏽‍♀' => 'ښځه کښتۍ چلوي: غنم رنګه',
    '🚣🏾‍♀' => 'ښځه کښتۍ چلوي: غنمی-تورنګه پوستکۍ',
    '🚣🏿‍♀' => 'ښځه کښتۍ چلوي: تور پوستکۍ',
    '🏊🏻‍♂' => 'سړی لامبو وهي: د روڼ پوستکي ټون',
    '🏊🏼‍♂' => 'سړی لامبو وهي: غنمی-روښانه پوستکۍ',
    '🏊🏽‍♂' => 'سړی لامبو وهي: غنم رنګه',
    '🏊🏾‍♂' => 'سړی لامبو وهي: غنمی-تورنګه پوستکۍ',
    '🏊🏿‍♂' => 'سړی لامبو وهي: تور پوستکۍ',
    '🏊🏻‍♀' => 'ښځه لامبو وهي: د روڼ پوستکي ټون',
    '🏊🏼‍♀' => 'ښځه لامبو وهي: غنمی-روښانه پوستکۍ',
    '🏊🏽‍♀' => 'ښځه لامبو وهي: غنم رنګه',
    '🏊🏾‍♀' => 'ښځه لامبو وهي: غنمی-تورنګه پوستکۍ',
    '🏊🏿‍♀' => 'ښځه لامبو وهي: تور پوستکۍ',
    '⛹🏻‍♂' => 'سړی بال تمبوي: د روڼ پوستکي ټون',
    '⛹🏼‍♂' => 'سړی بال تمبوي: غنمی-روښانه پوستکۍ',
    '⛹🏽‍♂' => 'سړی بال تمبوي: غنم رنګه',
    '⛹🏾‍♂' => 'سړی بال تمبوي: غنمی-تورنګه پوستکۍ',
    '⛹🏿‍♂' => 'سړی بال تمبوي: تور پوستکۍ',
    '⛹🏻‍♀' => 'ښځه بال تمبوي: د روڼ پوستکي ټون',
    '⛹🏼‍♀' => 'ښځه بال تمبوي: غنمی-روښانه پوستکۍ',
    '⛹🏽‍♀' => 'ښځه بال تمبوي: غنم رنګه',
    '⛹🏾‍♀' => 'ښځه بال تمبوي: غنمی-تورنګه پوستکۍ',
    '⛹🏿‍♀' => 'ښځه بال تمبوي: تور پوستکۍ',
    '🏋🏻‍♂' => 'سړی وزن پورته کوي: د روڼ پوستکي ټون',
    '🏋🏼‍♂' => 'سړی وزن پورته کوي: غنمی-روښانه پوستکۍ',
    '🏋🏽‍♂' => 'سړی وزن پورته کوي: غنم رنګه',
    '🏋🏾‍♂' => 'سړی وزن پورته کوي: غنمی-تورنګه پوستکۍ',
    '🏋🏿‍♂' => 'سړی وزن پورته کوي: تور پوستکۍ',
    '🏋🏻‍♀' => 'ښځه وزن پورته کوي: د روڼ پوستکي ټون',
    '🏋🏼‍♀' => 'ښځه وزن پورته کوي: غنمی-روښانه پوستکۍ',
    '🏋🏽‍♀' => 'ښځه وزن پورته کوي: غنم رنګه',
    '🏋🏾‍♀' => 'ښځه وزن پورته کوي: غنمی-تورنګه پوستکۍ',
    '🏋🏿‍♀' => 'ښځه وزن پورته کوي: تور پوستکۍ',
    '🚴🏻‍♂' => 'سړی بايک چلوي: د روڼ پوستکي ټون',
    '🚴🏼‍♂' => 'سړی بايک چلوي: غنمی-روښانه پوستکۍ',
    '🚴🏽‍♂' => 'سړی بايک چلوي: غنم رنګه',
    '🚴🏾‍♂' => 'سړی بايک چلوي: غنمی-تورنګه پوستکۍ',
    '🚴🏿‍♂' => 'سړی بايک چلوي: تور پوستکۍ',
    '🚴🏻‍♀' => 'ښځه بايک چلوي: د روڼ پوستکي ټون',
    '🚴🏼‍♀' => 'ښځه بايک چلوي: غنمی-روښانه پوستکۍ',
    '🚴🏽‍♀' => 'ښځه بايک چلوي: غنم رنګه',
    '🚴🏾‍♀' => 'ښځه بايک چلوي: غنمی-تورنګه پوستکۍ',
    '🚴🏿‍♀' => 'ښځه بايک چلوي: تور پوستکۍ',
    '🚵🏻‍♂' => 'سړی په غر بايک چلوي: د روڼ پوستکي ټون',
    '🚵🏼‍♂' => 'سړی په غر بايک چلوي: غنمی-روښانه پوستکۍ',
    '🚵🏽‍♂' => 'سړی په غر بايک چلوي: غنم رنګه',
    '🚵🏾‍♂' => 'سړی په غر بايک چلوي: غنمی-تورنګه پوستکۍ',
    '🚵🏿‍♂' => 'سړی په غر بايک چلوي: تور پوستکۍ',
    '🚵🏻‍♀' => 'ښځه په غر بايک چلوي: د روڼ پوستکي ټون',
    '🚵🏼‍♀' => 'ښځه په غر بايک چلوي: غنمی-روښانه پوستکۍ',
    '🚵🏽‍♀' => 'ښځه په غر بايک چلوي: غنم رنګه',
    '🚵🏾‍♀' => 'ښځه په غر بايک چلوي: غنمی-تورنګه پوستکۍ',
    '🚵🏿‍♀' => 'ښځه په غر بايک چلوي: تور پوستکۍ',
    '🤸🏻‍♂' => 'سړی کارټ ويلنګ کوي: د روڼ پوستکي ټون',
    '🤸🏼‍♂' => 'سړی کارټ ويلنګ کوي: غنمی-روښانه پوستکۍ',
    '🤸🏽‍♂' => 'سړی کارټ ويلنګ کوي: غنم رنګه',
    '🤸🏾‍♂' => 'سړی کارټ ويلنګ کوي: غنمی-تورنګه پوستکۍ',
    '🤸🏿‍♂' => 'سړی کارټ ويلنګ کوي: تور پوستکۍ',
    '🤸🏻‍♀' => 'ښځه کارټ ويلنګ کوي: د روڼ پوستکي ټون',
    '🤸🏼‍♀' => 'ښځه کارټ ويلنګ کوي: غنمی-روښانه پوستکۍ',
    '🤸🏽‍♀' => 'ښځه کارټ ويلنګ کوي: غنم رنګه',
    '🤸🏾‍♀' => 'ښځه کارټ ويلنګ کوي: غنمی-تورنګه پوستکۍ',
    '🤸🏿‍♀' => 'ښځه کارټ ويلنګ کوي: تور پوستکۍ',
    '🤼🏻‍♀' => 'ښځې پهلواني کوي: د روڼ پوستکي ټون',
    '🤼🏼‍♀' => 'ښځې پهلواني کوي: غنمی-روښانه پوستکۍ',
    '🤼🏽‍♀' => 'ښځې پهلواني کوي: غنم رنګه',
    '🤼🏾‍♀' => 'ښځې پهلواني کوي: غنمی-تورنګه پوستکۍ',
    '🤼🏿‍♀' => 'ښځې پهلواني کوي: تور پوستکۍ',
    '🤼🏻‍♂' => 'سړي پهلواني کوي: د روڼ پوستکي ټون',
    '🤼🏼‍♂' => 'سړي پهلواني کوي: غنمی-روښانه پوستکۍ',
    '🤼🏽‍♂' => 'سړي پهلواني کوي: غنم رنګه',
    '🤼🏾‍♂' => 'سړي پهلواني کوي: غنمی-تورنګه پوستکۍ',
    '🤼🏿‍♂' => 'سړي پهلواني کوي: تور پوستکۍ',
    '🤽🏻‍♂' => 'سړی د اوبو پولو لوبه کوي: د روڼ پوستکي ټون',
    '🤽🏼‍♂' => 'سړی د اوبو پولو لوبه کوي: غنمی-روښانه پوستکۍ',
    '🤽🏽‍♂' => 'سړی د اوبو پولو لوبه کوي: غنم رنګه',
    '🤽🏾‍♂' => 'سړی د اوبو پولو لوبه کوي: غنمی-تورنګه پوستکۍ',
    '🤽🏿‍♂' => 'سړی د اوبو پولو لوبه کوي: تور پوستکۍ',
    '🤽🏻‍♀' => 'ښځه د اوبو پولو لوبه کوي: د روڼ پوستکي ټون',
    '🤽🏼‍♀' => 'ښځه د اوبو پولو لوبه کوي: غنمی-روښانه پوستکۍ',
    '🤽🏽‍♀' => 'ښځه د اوبو پولو لوبه کوي: غنم رنګه',
    '🤽🏾‍♀' => 'ښځه د اوبو پولو لوبه کوي: غنمی-تورنګه پوستکۍ',
    '🤽🏿‍♀' => 'ښځه د اوبو پولو لوبه کوي: تور پوستکۍ',
    '🤾🏻‍♂' => 'سړی د هنډ بال لوبه کوي: د روڼ پوستکي ټون',
    '🤾🏼‍♂' => 'سړی د هنډ بال لوبه کوي: غنمی-روښانه پوستکۍ',
    '🤾🏽‍♂' => 'سړی د هنډ بال لوبه کوي: غنم رنګه',
    '🤾🏾‍♂' => 'سړی د هنډ بال لوبه کوي: غنمی-تورنګه پوستکۍ',
    '🤾🏿‍♂' => 'سړی د هنډ بال لوبه کوي: تور پوستکۍ',
    '🤾🏻‍♀' => 'ښځه د هنډبال لوبه کوي: د روڼ پوستکي ټون',
    '🤾🏼‍♀' => 'ښځه د هنډبال لوبه کوي: غنمی-روښانه پوستکۍ',
    '🤾🏽‍♀' => 'ښځه د هنډبال لوبه کوي: غنم رنګه',
    '🤾🏾‍♀' => 'ښځه د هنډبال لوبه کوي: غنمی-تورنګه پوستکۍ',
    '🤾🏿‍♀' => 'ښځه د هنډبال لوبه کوي: تور پوستکۍ',
    '🤹🏻‍♂' => 'سړی جادو کوي: د روڼ پوستکي ټون',
    '🤹🏼‍♂' => 'سړی جادو کوي: غنمی-روښانه پوستکۍ',
    '🤹🏽‍♂' => 'سړی جادو کوي: غنم رنګه',
    '🤹🏾‍♂' => 'سړی جادو کوي: غنمی-تورنګه پوستکۍ',
    '🤹🏿‍♂' => 'سړی جادو کوي: تور پوستکۍ',
    '🤹🏻‍♀' => 'ښځه جادو کوي: د روڼ پوستکي ټون',
    '🤹🏼‍♀' => 'ښځه جادو کوي: غنمی-روښانه پوستکۍ',
    '🤹🏽‍♀' => 'ښځه جادو کوي: غنم رنګه',
    '🤹🏾‍♀' => 'ښځه جادو کوي: غنمی-تورنګه پوستکۍ',
    '🤹🏿‍♀' => 'ښځه جادو کوي: تور پوستکۍ',
    '🧘🏻‍♂' => 'سړی د پرلت په حالت کې: د روڼ پوستکي ټون',
    '🧘🏼‍♂' => 'سړی د پرلت په حالت کې: غنمی-روښانه پوستکۍ',
    '🧘🏽‍♂' => 'سړی د پرلت په حالت کې: غنم رنګه',
    '🧘🏾‍♂' => 'سړی د پرلت په حالت کې: غنمی-تورنګه پوستکۍ',
    '🧘🏿‍♂' => 'سړی د پرلت په حالت کې: تور پوستکۍ',
    '🧘🏻‍♀' => 'ښځه د پرلت په حالت کې: د روڼ پوستکي ټون',
    '🧘🏼‍♀' => 'ښځه د پرلت په حالت کې: غنمی-روښانه پوستکۍ',
    '🧘🏽‍♀' => 'ښځه د پرلت په حالت کې: غنم رنګه',
    '🧘🏾‍♀' => 'ښځه د پرلت په حالت کې: غنمی-تورنګه پوستکۍ',
    '🧘🏿‍♀' => 'ښځه د پرلت په حالت کې: تور پوستکۍ',
    '🧑‍🦰' => 'شخص: سره ويښتان',
    '🧑‍🦱' => 'شخص: لوپه ويښتان',
    '🧑‍🦳' => 'شخص: سپين ويښتان',
    '🧑‍🦲' => 'شخص: ګنجى',
    '👨‍🦰' => 'سړی: سره ويښتان',
    '👨‍🦱' => 'سړی: لوپه ويښتان',
    '👨‍🦳' => 'سړی: سپين ويښتان',
    '👨‍🦲' => 'سړی: ګنجى',
    '👩‍🦰' => 'ښځه: سره ويښتان',
    '👩‍🦱' => 'ښځه: لوپه ويښتان',
    '👩‍🦳' => 'ښځه: سپين ويښتان',
    '👩‍🦲' => 'ښځه: ګنجى',
    '🚶‍➡' => 'روان شخص: ښي خوا ته مخامخ',
    '🧎‍➡' => 'شخص چوکېږي: ښي خوا ته مخامخ',
    '🏃‍➡' => 'شخص ځغلي: ښي خوا ته مخامخ',
    '👨‍👦' => 'کورنۍ: سړی و هلک',
    '👨‍👧' => 'کورنۍ: سړی و نجلۍ',
    '👩‍👦' => 'کورنۍ: ښځه و هلک',
    '👩‍👧' => 'کورنۍ: ښځه و نجلۍ',
    '😶‍🌫' => 'په وريځو مخ',
    '😮‍💨' => 'د تنفس مخ',
    '🙂‍↕' => 'سر په عمودی توګه لړزول',
    '😵‍💫' => 'مخ سرپل سترګې',
    '❤‍🔥' => 'زړه اور',
    '❤‍🩹' => 'ښه کول زړه',
    '👁‍🗨' => 'غږ پوګاڼه کې سترګه',
    '🧔‍♂' => 'سړی: ږیره',
    '👱‍♂' => 'سړی: د زيړ وېښتانو',
    '🧔‍♀' => 'ښځه: ږیره',
    '👱‍♀' => 'ښځه: د زېړ وېښتانو',
    '🙍‍♂' => 'سړی وروځې راغورځوي',
    '🙍‍♀' => 'ښځه وروځې راغورځوي',
    '🙎‍♂' => 'سړی تندی کوت کوي',
    '🙎‍♀' => 'ښځه تندی کوت کوي',
    '🙅‍♂' => 'سړی د نه اشاره کوي',
    '🙅‍♀' => 'ښځه د نه اشاره کوي',
    '🙆‍♂' => 'سړی د او کی اشاره کوي',
    '🙆‍♀' => 'ښځه د او کی اشاره کوي',
    '💁‍♂' => 'سړی لاس ښايي',
    '💁‍♀' => 'ښځه لاس ښايي',
    '🙋‍♂' => 'سړی لاس اوچتوي',
    '🙋‍♀' => 'ښځه لاس اوچتوي',
    '🧏‍♂' => 'کوڼ سړی',
    '🧏‍♀' => 'کڼه ښځه',
    '🙇‍♂' => 'سړی ښکته کيږي',
    '🙇‍♀' => 'ښځه ښکته کيږې',
    '🤦‍♂' => 'سړي مخ ته لاس نيولی',
    '🤦‍♀' => 'ښځې مخ ته لاس نيولی',
    '🤷‍♂' => 'سړی اوږې پورته کوي',
    '🤷‍♀' => 'ښځه اوږې پورته کوي',
    '🧑‍⚕' => 'روغتيايي کارمند',
    '👨‍⚕' => 'سړی روغتيايي کارکوونکی',
    '👩‍⚕' => 'ښځه روغتيايي کارکوونکي',
    '🧑‍🎓' => 'محصل',
    '👨‍🎓' => 'سړی محصل',
    '👩‍🎓' => 'ښځه محصل',
    '🧑‍🏫' => 'ښوونکی',
    '👨‍🏫' => 'سړی ښوونکی',
    '👩‍🏫' => 'ښځه ښوونکي',
    '🧑‍⚖' => 'قاضي',
    '👨‍⚖' => 'سړی قاضي',
    '👩‍⚖' => 'ښځه قاضي',
    '🧑‍🌾' => 'بزګر',
    '👨‍🌾' => 'سړی بزګر',
    '👩‍🌾' => 'ښځه د بزګر',
    '🧑‍🍳' => 'اشپز',
    '👨‍🍳' => 'سړی پخوونکی',
    '👩‍🍳' => 'ښځه پخوونکی',
    '🧑‍🔧' => 'مستري',
    '👨‍🔧' => 'سړی مستري',
    '👩‍🔧' => 'ښځه مستري',
    '🧑‍🏭' => 'د فابريکې کارمند',
    '👨‍🏭' => 'سړی د فابريکې کارګر',
    '👩‍🏭' => 'ښځه د فابريکې کارګر',
    '🧑‍💼' => 'دفتري کارمند',
    '👨‍💼' => 'سړی دفتري کارګر',
    '👩‍💼' => 'ښځه دفتر کارګر',
    '🧑‍🔬' => 'څېړونکی',
    '👨‍🔬' => 'سړي څېړونکی',
    '👩‍🔬' => 'ښځه څېړونکی',
    '🧑‍💻' => 'تيکنالوجست',
    '👨‍💻' => 'سړی تکنالوجست',
    '👩‍💻' => 'ښځه تکنالوجست',
    '🧑‍🎤' => 'ښځه سندرغاړی',
    '👨‍🎤' => 'سړی سندرغاړی',
    '👩‍🎤' => 'ښځه سندرغاړې',
    '🧑‍🎨' => 'فنکار',
    '👨‍🎨' => 'سړی فنکار',
    '👩‍🎨' => 'ښځه فنکار',
    '🧑‍✈' => 'پيلوټ',
    '👨‍✈' => 'سړی پيلوټ',
    '👩‍✈' => 'ښځه پيلوټ',
    '🧑‍🚀' => 'فضانورد',
    '👨‍🚀' => 'سړی فضانورد',
    '👩‍🚀' => 'ښځه فضانورد',
    '🧑‍🚒' => 'د اور وژنې کارمند',
    '👨‍🚒' => 'سړی اور وژونکی',
    '👩‍🚒' => 'ښځه اور وژونکی',
    '👮‍♂' => 'سړی د پولیسو افسر',
    '👮‍♀' => 'ښځه د پولیسو افسر',
    '🕵‍♂' => 'سړی کشفي',
    '🕵‍♀' => 'ښځه کشفي',
    '💂‍♂' => 'سړی ساتونکي',
    '💂‍♀' => 'ښځه ساتونکي',
    '👷‍♂' => 'سړی ساختماني کارګر',
    '👷‍♀' => 'ښځه ساختماني کارګر',
    '👳‍♂' => 'سړی لونګۍ په سر',
    '👳‍♀' => 'ښځه لونګۍ په سر',
    '🤵‍♂' => 'سړی په تکزیدو',
    '🤵‍♀' => 'ښځه په ټکسیدو',
    '👰‍♂' => 'سړی د پردې',
    '👰‍♀' => 'ښځه د پردې سره',
    '👩‍🍼' => 'ښځه ماشوم تغذیه کوي',
    '👨‍🍼' => 'یو شخص ماشوم ته خواړه ورکوي',
    '🧑‍🍼' => 'شخص ماشوم ته خواړه ورکوي',
    '🧑‍🎄' => 'میکس کلاز',
    '🦸‍♂' => 'سړی لوي اتل',
    '🦸‍♀' => 'ښځه لوي اتله',
    '🦹‍♂' => 'سړی لوي ورانکاری',
    '🦹‍♀' => 'ښځه لوي ورانکارې',
    '🧙‍♂' => 'سړی جادوګر',
    '🧙‍♀' => 'ښځه جادوګره',
    '🧚‍♂' => 'سړی خاپېری',
    '🧚‍♀' => 'ښځه ښاپيرۍ',
    '🧛‍♂' => 'سړی بلا',
    '🧛‍♀' => 'ښځه بلا',
    '🧜‍♂' => 'مرمین',
    '🧜‍♀' => 'مرمیډ',
    '🧝‍♂' => 'سړی ګوړا',
    '🧝‍♀' => 'ښځه ګوړا',
    '🧞‍♂' => 'سړی جینی',
    '🧞‍♀' => 'ښځه جینی',
    '🧟‍♂' => 'سړی زومبی',
    '🧟‍♀' => 'ښځه زومبی',
    '💆‍♂' => 'سړی مالش ترلاسه کوي',
    '💆‍♀' => 'ښځه مالش ترلاسه کوي',
    '💇‍♂' => 'سړی پرېټ کوي',
    '💇‍♀' => 'ښځه پرېټ کوي',
    '🚶‍♂' => 'روان سړی',
    '🚶‍♀' => 'روانه ښځه',
    '🧍‍♂' => 'ولاړ سړی',
    '🧍‍♀' => 'ولاړه ښځه',
    '🧎‍♂' => 'سړی چوکېږي',
    '🧎‍♀' => 'ښځه چوکېږي',
    '🧑‍🦯' => 'شخص د معلولينو د امسا سره',
    '👨‍🦯' => 'سړی د معلولينو د همسا سره',
    '👩‍🦯' => 'ښځه د معلولينو د همسا سره',
    '🧑‍🦼' => 'شخص د معلولينو په موټر چوکۍ کې',
    '👨‍🦼' => 'سړی د معلولينو په موټر چوکۍ کې',
    '👩‍🦼' => 'ښځه د معلولينو په موټر چوکۍ کې',
    '🧑‍🦽' => 'شخص د معلولينو په لاسي چوکۍ کې',
    '👨‍🦽' => 'سړی د معلولينو په لاسي چوکۍ کې',
    '👩‍🦽' => 'ښځه د معلولينو په لاسي چوکۍ کې',
    '🏃‍♂' => 'سړی ځغلي',
    '🏃‍♀' => 'ښځه ځغلي',
    '🧑‍🩰' => 'د بالې نڅاګر',
    '👯‍♂' => 'سړی د سويې غوږونو سره',
    '👯‍♀' => 'ښځې د سويې غوږونو سره',
    '🧖‍♂' => 'سړی د پخار په خونه کې',
    '🧖‍♀' => 'ښځه د پخار په خونه کې',
    '🧗‍♂' => 'سړی هسکېږي',
    '🧗‍♀' => 'ښځه هسکيږې',
    '🏌‍♂' => 'سړی ګالف کوي',
    '🏌‍♀' => 'ښځه ګالف کوي',
    '🏄‍♂' => 'سړی سرفنګ',
    '🏄‍♀' => 'ښځه سرفنګ',
    '🚣‍♂' => 'سړی کښتۍ چلوي',
    '🚣‍♀' => 'ښځه کښتۍ چلوي',
    '🏊‍♂' => 'سړی لامبو وهي',
    '🏊‍♀' => 'ښځه لامبو وهي',
    '⛹‍♂' => 'سړی بال تمبوي',
    '⛹‍♀' => 'ښځه بال تمبوي',
    '🏋‍♂' => 'سړی وزن پورته کوي',
    '🏋‍♀' => 'ښځه وزن پورته کوي',
    '🚴‍♂' => 'سړی بايک چلوي',
    '🚴‍♀' => 'ښځه بايک چلوي',
    '🚵‍♂' => 'سړی په غر بايک چلوي',
    '🚵‍♀' => 'ښځه په غر بايک چلوي',
    '🤸‍♂' => 'سړی کارټ ويلنګ کوي',
    '🤸‍♀' => 'ښځه کارټ ويلنګ کوي',
    '🤼‍♂' => 'سړي پهلواني کوي',
    '🤼‍♀' => 'ښځې پهلواني کوي',
    '🤽‍♂' => 'سړی د اوبو پولو لوبه کوي',
    '🤽‍♀' => 'ښځه د اوبو پولو لوبه کوي',
    '🤾‍♂' => 'سړی د هنډ بال لوبه کوي',
    '🤾‍♀' => 'ښځه د هنډبال لوبه کوي',
    '🤹‍♂' => 'سړی جادو کوي',
    '🤹‍♀' => 'ښځه جادو کوي',
    '🧘‍♂' => 'سړی د پرلت په حالت کې',
    '🧘‍♀' => 'ښځه د پرلت په حالت کې',
    '🧑‍🧒' => 'کورنۍ: بالغ، ماشوم',
    '🐕‍🦺' => 'د خدمت سپی',
    '🐈‍⬛' => 'توره پیشو',
    '🐻‍❄' => 'قطبی خرس',
    '🐦‍⬛' => 'تور مرغۍ',
    '🐦‍🔥' => 'فینکس',
    '🍋‍🟩' => 'لیمو',
    '🍄‍🟫' => 'نسواري مشروم',
    '⛓‍💥' => 'مات شوی زنځیر',
    '🏳‍🌈' => 'د بوډۍ ټال بېرغ',
    '🏳‍⚧' => 'آسماني رنګ، ګلابي، او سپينه بېرغ',
    '🏴‍☠' => 'د بحري ډاکوانو بېرغ',
    '👋🏻' => 'لاس خورول: د روڼ پوستکي ټون',
    '👋🏼' => 'لاس خورول: غنمی-روښانه پوستکۍ',
    '👋🏽' => 'لاس خورول: غنم رنګه',
    '👋🏾' => 'لاس خورول: غنمی-تورنګه پوستکۍ',
    '👋🏿' => 'لاس خورول: تور پوستکۍ',
    '🤚🏻' => 'لاس شاخوا اچوتول: د روڼ پوستکي ټون',
    '🤚🏼' => 'لاس شاخوا اچوتول: غنمی-روښانه پوستکۍ',
    '🤚🏽' => 'لاس شاخوا اچوتول: غنم رنګه',
    '🤚🏾' => 'لاس شاخوا اچوتول: غنمی-تورنګه پوستکۍ',
    '🤚🏿' => 'لاس شاخوا اچوتول: تور پوستکۍ',
    '🖐🏻' => 'پنجه: د روڼ پوستکي ټون',
    '🖐🏼' => 'پنجه: غنمی-روښانه پوستکۍ',
    '🖐🏽' => 'پنجه: غنم رنګه',
    '🖐🏾' => 'پنجه: غنمی-تورنګه پوستکۍ',
    '🖐🏿' => 'پنجه: تور پوستکۍ',
    '✋🏻' => 'اوچت لاس: د روڼ پوستکي ټون',
    '✋🏼' => 'اوچت لاس: غنمی-روښانه پوستکۍ',
    '✋🏽' => 'اوچت لاس: غنم رنګه',
    '✋🏾' => 'اوچت لاس: غنمی-تورنګه پوستکۍ',
    '✋🏿' => 'اوچت لاس: تور پوستکۍ',
    '🖖🏻' => 'ښه راغلاست: د روڼ پوستکي ټون',
    '🖖🏼' => 'ښه راغلاست: غنمی-روښانه پوستکۍ',
    '🖖🏽' => 'ښه راغلاست: غنم رنګه',
    '🖖🏾' => 'ښه راغلاست: غنمی-تورنګه پوستکۍ',
    '🖖🏿' => 'ښه راغلاست: تور پوستکۍ',
    '🫱🏻' => 'ښي لاس: د روڼ پوستکي ټون',
    '🫱🏼' => 'ښي لاس: غنمی-روښانه پوستکۍ',
    '🫱🏽' => 'ښي لاس: غنم رنګه',
    '🫱🏾' => 'ښي لاس: غنمی-تورنګه پوستکۍ',
    '🫱🏿' => 'ښي لاس: تور پوستکۍ',
    '🫲🏻' => 'کیڼ لاس: د روڼ پوستکي ټون',
    '🫲🏼' => 'کیڼ لاس: غنمی-روښانه پوستکۍ',
    '🫲🏽' => 'کیڼ لاس: غنم رنګه',
    '🫲🏾' => 'کیڼ لاس: غنمی-تورنګه پوستکۍ',
    '🫲🏿' => 'کیڼ لاس: تور پوستکۍ',
    '🫳🏻' => 'ورغوې ښکته اړخ لاس: د روڼ پوستکي ټون',
    '🫳🏼' => 'ورغوې ښکته اړخ لاس: غنمی-روښانه پوستکۍ',
    '🫳🏽' => 'ورغوې ښکته اړخ لاس: غنم رنګه',
    '🫳🏾' => 'ورغوې ښکته اړخ لاس: غنمی-تورنګه پوستکۍ',
    '🫳🏿' => 'ورغوې ښکته اړخ لاس: تور پوستکۍ',
    '🫴🏻' => 'ورغوس پورته لاس: د روڼ پوستکي ټون',
    '🫴🏼' => 'ورغوس پورته لاس: غنمی-روښانه پوستکۍ',
    '🫴🏽' => 'ورغوس پورته لاس: غنم رنګه',
    '🫴🏾' => 'ورغوس پورته لاس: غنمی-تورنګه پوستکۍ',
    '🫴🏿' => 'ورغوس پورته لاس: تور پوستکۍ',
    '🫷🏻' => 'کیڼ اړخ ته لاس وهل: د روڼ پوستکي ټون',
    '🫷🏼' => 'کیڼ اړخ ته لاس وهل: غنمی-روښانه پوستکۍ',
    '🫷🏽' => 'کیڼ اړخ ته لاس وهل: غنم رنګه',
    '🫷🏾' => 'کیڼ اړخ ته لاس وهل: غنمی-تورنګه پوستکۍ',
    '🫷🏿' => 'کیڼ اړخ ته لاس وهل: تور پوستکۍ',
    '🫸🏻' => 'ښي خوا ته لاس وهل: د روڼ پوستکي ټون',
    '🫸🏼' => 'ښي خوا ته لاس وهل: غنمی-روښانه پوستکۍ',
    '🫸🏽' => 'ښي خوا ته لاس وهل: غنم رنګه',
    '🫸🏾' => 'ښي خوا ته لاس وهل: غنمی-تورنګه پوستکۍ',
    '🫸🏿' => 'ښي خوا ته لاس وهل: تور پوستکۍ',
    '👌🏻' => 'اوکی لاس: د روڼ پوستکي ټون',
    '👌🏼' => 'اوکی لاس: غنمی-روښانه پوستکۍ',
    '👌🏽' => 'اوکی لاس: غنم رنګه',
    '👌🏾' => 'اوکی لاس: غنمی-تورنګه پوستکۍ',
    '👌🏿' => 'اوکی لاس: تور پوستکۍ',
    '🤌🏻' => 'چونګ ګوتې: د روڼ پوستکي ټون',
    '🤌🏼' => 'چونګ ګوتې: غنمی-روښانه پوستکۍ',
    '🤌🏽' => 'چونګ ګوتې: غنم رنګه',
    '🤌🏾' => 'چونګ ګوتې: غنمی-تورنګه پوستکۍ',
    '🤌🏿' => 'چونګ ګوتې: تور پوستکۍ',
    '🤏🏻' => 'سکونډونکی لاس: د روڼ پوستکي ټون',
    '🤏🏼' => 'سکونډونکی لاس: غنمی-روښانه پوستکۍ',
    '🤏🏽' => 'سکونډونکی لاس: غنم رنګه',
    '🤏🏾' => 'سکونډونکی لاس: غنمی-تورنګه پوستکۍ',
    '🤏🏿' => 'سکونډونکی لاس: تور پوستکۍ',
    '✌🏻' => 'د بریا نښه: د روڼ پوستکي ټون',
    '✌🏼' => 'د بریا نښه: غنمی-روښانه پوستکۍ',
    '✌🏽' => 'د بریا نښه: غنم رنګه',
    '✌🏾' => 'د بریا نښه: غنمی-تورنګه پوستکۍ',
    '✌🏿' => 'د بریا نښه: تور پوستکۍ',
    '🤞🏻' => 'متقاطع ګوتي: د روڼ پوستکي ټون',
    '🤞🏼' => 'متقاطع ګوتي: غنمی-روښانه پوستکۍ',
    '🤞🏽' => 'متقاطع ګوتي: غنم رنګه',
    '🤞🏾' => 'متقاطع ګوتي: غنمی-تورنګه پوستکۍ',
    '🤞🏿' => 'متقاطع ګوتي: تور پوستکۍ',
    '🫰🏻' => 'د شاخص د ګوتو او ګوتو سره لاس تېر شو: د روڼ پوستکي ټون',
    '🫰🏼' => 'د شاخص د ګوتو او ګوتو سره لاس تېر شو: غنمی-روښانه پوستکۍ',
    '🫰🏽' => 'د شاخص د ګوتو او ګوتو سره لاس تېر شو: غنم رنګه',
    '🫰🏾' => 'د شاخص د ګوتو او ګوتو سره لاس تېر شو: غنمی-تورنګه پوستکۍ',
    '🫰🏿' => 'د شاخص د ګوتو او ګوتو سره لاس تېر شو: تور پوستکۍ',
    '🤟🏻' => 'د مینې اشاره: د روڼ پوستکي ټون',
    '🤟🏼' => 'د مینې اشاره: غنمی-روښانه پوستکۍ',
    '🤟🏽' => 'د مینې اشاره: غنم رنګه',
    '🤟🏾' => 'د مینې اشاره: غنمی-تورنګه پوستکۍ',
    '🤟🏿' => 'د مینې اشاره: تور پوستکۍ',
    '🤘🏻' => 'دوشاخه: د روڼ پوستکي ټون',
    '🤘🏼' => 'دوشاخه: غنمی-روښانه پوستکۍ',
    '🤘🏽' => 'دوشاخه: غنم رنګه',
    '🤘🏾' => 'دوشاخه: غنمی-تورنګه پوستکۍ',
    '🤘🏿' => 'دوشاخه: تور پوستکۍ',
    '🤙🏻' => 'زنګ وهلو اشاره: د روڼ پوستکي ټون',
    '🤙🏼' => 'زنګ وهلو اشاره: غنمی-روښانه پوستکۍ',
    '🤙🏽' => 'زنګ وهلو اشاره: غنم رنګه',
    '🤙🏾' => 'زنګ وهلو اشاره: غنمی-تورنګه پوستکۍ',
    '🤙🏿' => 'زنګ وهلو اشاره: تور پوستکۍ',
    '👈🏻' => 'په چپ لاس په شهادت ګوته اشاره کول: د روڼ پوستکي ټون',
    '👈🏼' => 'په چپ لاس په شهادت ګوته اشاره کول: غنمی-روښانه پوستکۍ',
    '👈🏽' => 'په چپ لاس په شهادت ګوته اشاره کول: غنم رنګه',
    '👈🏾' => 'په چپ لاس په شهادت ګوته اشاره کول: غنمی-تورنګه پوستکۍ',
    '👈🏿' => 'په چپ لاس په شهادت ګوته اشاره کول: تور پوستکۍ',
    '👉🏻' => 'په ښي لاس په شهادت ګوته اشاره کول: د روڼ پوستکي ټون',
    '👉🏼' => 'په ښي لاس په شهادت ګوته اشاره کول: غنمی-روښانه پوستکۍ',
    '👉🏽' => 'په ښي لاس په شهادت ګوته اشاره کول: غنم رنګه',
    '👉🏾' => 'په ښي لاس په شهادت ګوته اشاره کول: غنمی-تورنګه پوستکۍ',
    '👉🏿' => 'په ښي لاس په شهادت ګوته اشاره کول: تور پوستکۍ',
    '👆🏻' => 'شهادت ګوته لاس شاخوا پورته نیول: د روڼ پوستکي ټون',
    '👆🏼' => 'شهادت ګوته لاس شاخوا پورته نیول: غنمی-روښانه پوستکۍ',
    '👆🏽' => 'شهادت ګوته لاس شاخوا پورته نیول: غنم رنګه',
    '👆🏾' => 'شهادت ګوته لاس شاخوا پورته نیول: غنمی-تورنګه پوستکۍ',
    '👆🏿' => 'شهادت ګوته لاس شاخوا پورته نیول: تور پوستکۍ',
    '🖕🏻' => 'منځنې ګوته: د روڼ پوستکي ټون',
    '🖕🏼' => 'منځنې ګوته: غنمی-روښانه پوستکۍ',
    '🖕🏽' => 'منځنې ګوته: غنم رنګه',
    '🖕🏾' => 'منځنې ګوته: غنمی-تورنګه پوستکۍ',
    '🖕🏿' => 'منځنې ګوته: تور پوستکۍ',
    '👇🏻' => 'په شهادت ګوته لاس شاخوا لاندي اشاره کول: د روڼ پوستکي ټون',
    '👇🏼' => 'په شهادت ګوته لاس شاخوا لاندي اشاره کول: غنمی-روښانه پوستکۍ',
    '👇🏽' => 'په شهادت ګوته لاس شاخوا لاندي اشاره کول: غنم رنګه',
    '👇🏾' => 'په شهادت ګوته لاس شاخوا لاندي اشاره کول: غنمی-تورنګه پوستکۍ',
    '👇🏿' => 'په شهادت ګوته لاس شاخوا لاندي اشاره کول: تور پوستکۍ',
    '☝🏻' => 'شهادت ګوته پورته نیول: د روڼ پوستکي ټون',
    '☝🏼' => 'شهادت ګوته پورته نیول: غنمی-روښانه پوستکۍ',
    '☝🏽' => 'شهادت ګوته پورته نیول: غنم رنګه',
    '☝🏾' => 'شهادت ګوته پورته نیول: غنمی-تورنګه پوستکۍ',
    '☝🏿' => 'شهادت ګوته پورته نیول: تور پوستکۍ',
    '🫵🏻' => 'شاخص لیدونکی ته اشاره کول: د روڼ پوستکي ټون',
    '🫵🏼' => 'شاخص لیدونکی ته اشاره کول: غنمی-روښانه پوستکۍ',
    '🫵🏽' => 'شاخص لیدونکی ته اشاره کول: غنم رنګه',
    '🫵🏾' => 'شاخص لیدونکی ته اشاره کول: غنمی-تورنګه پوستکۍ',
    '🫵🏿' => 'شاخص لیدونکی ته اشاره کول: تور پوستکۍ',
    '👍🏻' => 'ډیر ښه: د روڼ پوستکي ټون',
    '👍🏼' => 'ډیر ښه: غنمی-روښانه پوستکۍ',
    '👍🏽' => 'ډیر ښه: غنم رنګه',
    '👍🏾' => 'ډیر ښه: غنمی-تورنګه پوستکۍ',
    '👍🏿' => 'ډیر ښه: تور پوستکۍ',
    '👎🏻' => 'ډیر بد: د روڼ پوستکي ټون',
    '👎🏼' => 'ډیر بد: غنمی-روښانه پوستکۍ',
    '👎🏽' => 'ډیر بد: غنم رنګه',
    '👎🏾' => 'ډیر بد: غنمی-تورنګه پوستکۍ',
    '👎🏿' => 'ډیر بد: تور پوستکۍ',
    '✊🏻' => 'موټۍ پورته نیول: د روڼ پوستکي ټون',
    '✊🏼' => 'موټۍ پورته نیول: غنمی-روښانه پوستکۍ',
    '✊🏽' => 'موټۍ پورته نیول: غنم رنګه',
    '✊🏾' => 'موټۍ پورته نیول: غنمی-تورنګه پوستکۍ',
    '✊🏿' => 'موټۍ پورته نیول: تور پوستکۍ',
    '👊🏻' => 'مخامخ موټۍ: د روڼ پوستکي ټون',
    '👊🏼' => 'مخامخ موټۍ: غنمی-روښانه پوستکۍ',
    '👊🏽' => 'مخامخ موټۍ: غنم رنګه',
    '👊🏾' => 'مخامخ موټۍ: غنمی-تورنګه پوستکۍ',
    '👊🏿' => 'مخامخ موټۍ: تور پوستکۍ',
    '🤛🏻' => 'چپ موټۍ: د روڼ پوستکي ټون',
    '🤛🏼' => 'چپ موټۍ: غنمی-روښانه پوستکۍ',
    '🤛🏽' => 'چپ موټۍ: غنم رنګه',
    '🤛🏾' => 'چپ موټۍ: غنمی-تورنګه پوستکۍ',
    '🤛🏿' => 'چپ موټۍ: تور پوستکۍ',
    '🤜🏻' => 'ښۍ موټۍ: د روڼ پوستکي ټون',
    '🤜🏼' => 'ښۍ موټۍ: غنمی-روښانه پوستکۍ',
    '🤜🏽' => 'ښۍ موټۍ: غنم رنګه',
    '🤜🏾' => 'ښۍ موټۍ: غنمی-تورنګه پوستکۍ',
    '🤜🏿' => 'ښۍ موټۍ: تور پوستکۍ',
    '👏🏻' => 'لاسونه پړکول: د روڼ پوستکي ټون',
    '👏🏼' => 'لاسونه پړکول: غنمی-روښانه پوستکۍ',
    '👏🏽' => 'لاسونه پړکول: غنم رنګه',
    '👏🏾' => 'لاسونه پړکول: غنمی-تورنګه پوستکۍ',
    '👏🏿' => 'لاسونه پړکول: تور پوستکۍ',
    '🙌🏻' => 'لاسونه اوچتول: د روڼ پوستکي ټون',
    '🙌🏼' => 'لاسونه اوچتول: غنمی-روښانه پوستکۍ',
    '🙌🏽' => 'لاسونه اوچتول: غنم رنګه',
    '🙌🏾' => 'لاسونه اوچتول: غنمی-تورنګه پوستکۍ',
    '🙌🏿' => 'لاسونه اوچتول: تور پوستکۍ',
    '🫶🏻' => 'زړه لاسونه: د روڼ پوستکي ټون',
    '🫶🏼' => 'زړه لاسونه: غنمی-روښانه پوستکۍ',
    '🫶🏽' => 'زړه لاسونه: غنم رنګه',
    '🫶🏾' => 'زړه لاسونه: غنمی-تورنګه پوستکۍ',
    '🫶🏿' => 'زړه لاسونه: تور پوستکۍ',
    '👐🏻' => 'خلاص لاسونه: د روڼ پوستکي ټون',
    '👐🏼' => 'خلاص لاسونه: غنمی-روښانه پوستکۍ',
    '👐🏽' => 'خلاص لاسونه: غنم رنګه',
    '👐🏾' => 'خلاص لاسونه: غنمی-تورنګه پوستکۍ',
    '👐🏿' => 'خلاص لاسونه: تور پوستکۍ',
    '🤲🏻' => 'لپه لاسونه: د روڼ پوستکي ټون',
    '🤲🏼' => 'لپه لاسونه: غنمی-روښانه پوستکۍ',
    '🤲🏽' => 'لپه لاسونه: غنم رنګه',
    '🤲🏾' => 'لپه لاسونه: غنمی-تورنګه پوستکۍ',
    '🤲🏿' => 'لپه لاسونه: تور پوستکۍ',
    '🤝🏻' => 'ستړې مشي: د روڼ پوستکي ټون',
    '🤝🏼' => 'ستړې مشي: غنمی-روښانه پوستکۍ',
    '🤝🏽' => 'ستړې مشي: غنم رنګه',
    '🤝🏾' => 'ستړې مشي: غنمی-تورنګه پوستکۍ',
    '🤝🏿' => 'ستړې مشي: تور پوستکۍ',
    '🙏🏻' => 'مننې لاسونه: د روڼ پوستکي ټون',
    '🙏🏼' => 'مننې لاسونه: غنمی-روښانه پوستکۍ',
    '🙏🏽' => 'مننې لاسونه: غنم رنګه',
    '🙏🏾' => 'مننې لاسونه: غنمی-تورنګه پوستکۍ',
    '🙏🏿' => 'مننې لاسونه: تور پوستکۍ',
    '✍🏻' => 'لیکونکې لاس: د روڼ پوستکي ټون',
    '✍🏼' => 'لیکونکې لاس: غنمی-روښانه پوستکۍ',
    '✍🏽' => 'لیکونکې لاس: غنم رنګه',
    '✍🏾' => 'لیکونکې لاس: غنمی-تورنګه پوستکۍ',
    '✍🏿' => 'لیکونکې لاس: تور پوستکۍ',
    '💅🏻' => 'نوکانو رنګ: د روڼ پوستکي ټون',
    '💅🏼' => 'نوکانو رنګ: غنمی-روښانه پوستکۍ',
    '💅🏽' => 'نوکانو رنګ: غنم رنګه',
    '💅🏾' => 'نوکانو رنګ: غنمی-تورنګه پوستکۍ',
    '💅🏿' => 'نوکانو رنګ: تور پوستکۍ',
    '🤳🏻' => 'سيلفي: د روڼ پوستکي ټون',
    '🤳🏼' => 'سيلفي: غنمی-روښانه پوستکۍ',
    '🤳🏽' => 'سيلفي: غنم رنګه',
    '🤳🏾' => 'سيلفي: غنمی-تورنګه پوستکۍ',
    '🤳🏿' => 'سيلفي: تور پوستکۍ',
    '💪🏻' => 'انعطافی مټې: د روڼ پوستکي ټون',
    '💪🏼' => 'انعطافی مټې: غنمی-روښانه پوستکۍ',
    '💪🏽' => 'انعطافی مټې: غنم رنګه',
    '💪🏾' => 'انعطافی مټې: غنمی-تورنګه پوستکۍ',
    '💪🏿' => 'انعطافی مټې: تور پوستکۍ',
    '🦵🏻' => 'پنډۍ: د روڼ پوستکي ټون',
    '🦵🏼' => 'پنډۍ: غنمی-روښانه پوستکۍ',
    '🦵🏽' => 'پنډۍ: غنم رنګه',
    '🦵🏾' => 'پنډۍ: غنمی-تورنګه پوستکۍ',
    '🦵🏿' => 'پنډۍ: تور پوستکۍ',
    '🦶🏻' => 'پښه: د روڼ پوستکي ټون',
    '🦶🏼' => 'پښه: غنمی-روښانه پوستکۍ',
    '🦶🏽' => 'پښه: غنم رنګه',
    '🦶🏾' => 'پښه: غنمی-تورنګه پوستکۍ',
    '🦶🏿' => 'پښه: تور پوستکۍ',
    '👂🏻' => 'غوږ: د روڼ پوستکي ټون',
    '👂🏼' => 'غوږ: غنمی-روښانه پوستکۍ',
    '👂🏽' => 'غوږ: غنم رنګه',
    '👂🏾' => 'غوږ: غنمی-تورنګه پوستکۍ',
    '👂🏿' => 'غوږ: تور پوستکۍ',
    '🦻🏻' => 'غوږ د اورېدنې د مرستې سره: د روڼ پوستکي ټون',
    '🦻🏼' => 'غوږ د اورېدنې د مرستې سره: غنمی-روښانه پوستکۍ',
    '🦻🏽' => 'غوږ د اورېدنې د مرستې سره: غنم رنګه',
    '🦻🏾' => 'غوږ د اورېدنې د مرستې سره: غنمی-تورنګه پوستکۍ',
    '🦻🏿' => 'غوږ د اورېدنې د مرستې سره: تور پوستکۍ',
    '👃🏻' => 'پوزه: د روڼ پوستکي ټون',
    '👃🏼' => 'پوزه: غنمی-روښانه پوستکۍ',
    '👃🏽' => 'پوزه: غنم رنګه',
    '👃🏾' => 'پوزه: غنمی-تورنګه پوستکۍ',
    '👃🏿' => 'پوزه: تور پوستکۍ',
    '👶🏻' => 'کوچنی: د روڼ پوستکي ټون',
    '👶🏼' => 'کوچنی: غنمی-روښانه پوستکۍ',
    '👶🏽' => 'کوچنی: غنم رنګه',
    '👶🏾' => 'کوچنی: غنمی-تورنګه پوستکۍ',
    '👶🏿' => 'کوچنی: تور پوستکۍ',
    '🧒🏻' => 'ماشوم: د روڼ پوستکي ټون',
    '🧒🏼' => 'ماشوم: غنمی-روښانه پوستکۍ',
    '🧒🏽' => 'ماشوم: غنم رنګه',
    '🧒🏾' => 'ماشوم: غنمی-تورنګه پوستکۍ',
    '🧒🏿' => 'ماشوم: تور پوستکۍ',
    '👦🏻' => 'هلک: د روڼ پوستکي ټون',
    '👦🏼' => 'هلک: غنمی-روښانه پوستکۍ',
    '👦🏽' => 'هلک: غنم رنګه',
    '👦🏾' => 'هلک: غنمی-تورنګه پوستکۍ',
    '👦🏿' => 'هلک: تور پوستکۍ',
    '👧🏻' => 'نجلۍ: د روڼ پوستکي ټون',
    '👧🏼' => 'نجلۍ: غنمی-روښانه پوستکۍ',
    '👧🏽' => 'نجلۍ: غنم رنګه',
    '👧🏾' => 'نجلۍ: غنمی-تورنګه پوستکۍ',
    '👧🏿' => 'نجلۍ: تور پوستکۍ',
    '🧑🏻' => 'شخص: د روڼ پوستکي ټون',
    '🧑🏼' => 'شخص: غنمی-روښانه پوستکۍ',
    '🧑🏽' => 'شخص: غنم رنګه',
    '🧑🏾' => 'شخص: غنمی-تورنګه پوستکۍ',
    '🧑🏿' => 'شخص: تور پوستکۍ',
    '👱🏻' => 'شخص: د روڼ پوستکي ټون و د سرو ويښتانو',
    '👱🏼' => 'شخص: غنمی-روښانه پوستکۍ و د سرو ويښتانو',
    '👱🏽' => 'شخص: غنم رنګه و د سرو ويښتانو',
    '👱🏾' => 'شخص: غنمی-تورنګه پوستکۍ و د سرو ويښتانو',
    '👱🏿' => 'شخص: تور پوستکۍ و د سرو ويښتانو',
    '👨🏻' => 'سړی: د روڼ پوستکي ټون',
    '👨🏼' => 'سړی: غنمی-روښانه پوستکۍ',
    '👨🏽' => 'سړی: غنم رنګه',
    '👨🏾' => 'سړی: غنمی-تورنګه پوستکۍ',
    '👨🏿' => 'سړی: تور پوستکۍ',
    '🧔🏻' => 'سړی: د روڼ پوستکي ټون و ږيره',
    '🧔🏼' => 'سړی: غنمی-روښانه پوستکۍ و ږيره',
    '🧔🏽' => 'سړی: غنم رنګه و ږيره',
    '🧔🏾' => 'سړی: غنمی-تورنګه پوستکۍ و ږيره',
    '🧔🏿' => 'سړی: تور پوستکۍ و ږيره',
    '👩🏻' => 'ښځه: د روڼ پوستکي ټون',
    '👩🏼' => 'ښځه: غنمی-روښانه پوستکۍ',
    '👩🏽' => 'ښځه: غنم رنګه',
    '👩🏾' => 'ښځه: غنمی-تورنګه پوستکۍ',
    '👩🏿' => 'ښځه: تور پوستکۍ',
    '🧓🏻' => 'زوړ شخص: د روڼ پوستکي ټون',
    '🧓🏼' => 'زوړ شخص: غنمی-روښانه پوستکۍ',
    '🧓🏽' => 'زوړ شخص: غنم رنګه',
    '🧓🏾' => 'زوړ شخص: غنمی-تورنګه پوستکۍ',
    '🧓🏿' => 'زوړ شخص: تور پوستکۍ',
    '👴🏻' => 'زوړ سړی: د روڼ پوستکي ټون',
    '👴🏼' => 'زوړ سړی: غنمی-روښانه پوستکۍ',
    '👴🏽' => 'زوړ سړی: غنم رنګه',
    '👴🏾' => 'زوړ سړی: غنمی-تورنګه پوستکۍ',
    '👴🏿' => 'زوړ سړی: تور پوستکۍ',
    '👵🏻' => 'زړه ښځه: د روڼ پوستکي ټون',
    '👵🏼' => 'زړه ښځه: غنمی-روښانه پوستکۍ',
    '👵🏽' => 'زړه ښځه: غنم رنګه',
    '👵🏾' => 'زړه ښځه: غنمی-تورنګه پوستکۍ',
    '👵🏿' => 'زړه ښځه: تور پوستکۍ',
    '🙍🏻' => 'شخص وروځې راغورځوي: د روڼ پوستکي ټون',
    '🙍🏼' => 'شخص وروځې راغورځوي: غنمی-روښانه پوستکۍ',
    '🙍🏽' => 'شخص وروځې راغورځوي: غنم رنګه',
    '🙍🏾' => 'شخص وروځې راغورځوي: غنمی-تورنګه پوستکۍ',
    '🙍🏿' => 'شخص وروځې راغورځوي: تور پوستکۍ',
    '🙎🏻' => 'شخص تندی کوت کوي: د روڼ پوستکي ټون',
    '🙎🏼' => 'شخص تندی کوت کوي: غنمی-روښانه پوستکۍ',
    '🙎🏽' => 'شخص تندی کوت کوي: غنم رنګه',
    '🙎🏾' => 'شخص تندی کوت کوي: غنمی-تورنګه پوستکۍ',
    '🙎🏿' => 'شخص تندی کوت کوي: تور پوستکۍ',
    '🙅🏻' => 'شخص د نه اشاره کوي: د روڼ پوستکي ټون',
    '🙅🏼' => 'شخص د نه اشاره کوي: غنمی-روښانه پوستکۍ',
    '🙅🏽' => 'شخص د نه اشاره کوي: غنم رنګه',
    '🙅🏾' => 'شخص د نه اشاره کوي: غنمی-تورنګه پوستکۍ',
    '🙅🏿' => 'شخص د نه اشاره کوي: تور پوستکۍ',
    '🙆🏻' => 'شخص د او کی اشاره کوي: د روڼ پوستکي ټون',
    '🙆🏼' => 'شخص د او کی اشاره کوي: غنمی-روښانه پوستکۍ',
    '🙆🏽' => 'شخص د او کی اشاره کوي: غنم رنګه',
    '🙆🏾' => 'شخص د او کی اشاره کوي: غنمی-تورنګه پوستکۍ',
    '🙆🏿' => 'شخص د او کی اشاره کوي: تور پوستکۍ',
    '💁🏻' => 'شخص لاس ښايي: د روڼ پوستکي ټون',
    '💁🏼' => 'شخص لاس ښايي: غنمی-روښانه پوستکۍ',
    '💁🏽' => 'شخص لاس ښايي: غنم رنګه',
    '💁🏾' => 'شخص لاس ښايي: غنمی-تورنګه پوستکۍ',
    '💁🏿' => 'شخص لاس ښايي: تور پوستکۍ',
    '🙋🏻' => 'شخص لاس اوچتوي: د روڼ پوستکي ټون',
    '🙋🏼' => 'شخص لاس اوچتوي: غنمی-روښانه پوستکۍ',
    '🙋🏽' => 'شخص لاس اوچتوي: غنم رنګه',
    '🙋🏾' => 'شخص لاس اوچتوي: غنمی-تورنګه پوستکۍ',
    '🙋🏿' => 'شخص لاس اوچتوي: تور پوستکۍ',
    '🧏🏻' => 'کوڼ شخص: د روڼ پوستکي ټون',
    '🧏🏼' => 'کوڼ شخص: غنمی-روښانه پوستکۍ',
    '🧏🏽' => 'کوڼ شخص: غنم رنګه',
    '🧏🏾' => 'کوڼ شخص: غنمی-تورنګه پوستکۍ',
    '🧏🏿' => 'کوڼ شخص: تور پوستکۍ',
    '🙇🏻' => 'شخص ښکته کيږي: د روڼ پوستکي ټون',
    '🙇🏼' => 'شخص ښکته کيږي: غنمی-روښانه پوستکۍ',
    '🙇🏽' => 'شخص ښکته کيږي: غنم رنګه',
    '🙇🏾' => 'شخص ښکته کيږي: غنمی-تورنګه پوستکۍ',
    '🙇🏿' => 'شخص ښکته کيږي: تور پوستکۍ',
    '🤦🏻' => 'شخص مخ ته لاس نيولي: د روڼ پوستکي ټون',
    '🤦🏼' => 'شخص مخ ته لاس نيولي: غنمی-روښانه پوستکۍ',
    '🤦🏽' => 'شخص مخ ته لاس نيولي: غنم رنګه',
    '🤦🏾' => 'شخص مخ ته لاس نيولي: غنمی-تورنګه پوستکۍ',
    '🤦🏿' => 'شخص مخ ته لاس نيولي: تور پوستکۍ',
    '🤷🏻' => 'شخص اوږې پورته کوي: د روڼ پوستکي ټون',
    '🤷🏼' => 'شخص اوږې پورته کوي: غنمی-روښانه پوستکۍ',
    '🤷🏽' => 'شخص اوږې پورته کوي: غنم رنګه',
    '🤷🏾' => 'شخص اوږې پورته کوي: غنمی-تورنګه پوستکۍ',
    '🤷🏿' => 'شخص اوږې پورته کوي: تور پوستکۍ',
    '👮🏻' => 'د پولیسو افسر: د روڼ پوستکي ټون',
    '👮🏼' => 'د پولیسو افسر: غنمی-روښانه پوستکۍ',
    '👮🏽' => 'د پولیسو افسر: غنم رنګه',
    '👮🏾' => 'د پولیسو افسر: غنمی-تورنګه پوستکۍ',
    '👮🏿' => 'د پولیسو افسر: تور پوستکۍ',
    '🕵🏻' => 'کشفي: د روڼ پوستکي ټون',
    '🕵🏼' => 'کشفي: غنمی-روښانه پوستکۍ',
    '🕵🏽' => 'کشفي: غنم رنګه',
    '🕵🏾' => 'کشفي: غنمی-تورنګه پوستکۍ',
    '🕵🏿' => 'کشفي: تور پوستکۍ',
    '💂🏻' => 'ساتونکی: د روڼ پوستکي ټون',
    '💂🏼' => 'ساتونکی: غنمی-روښانه پوستکۍ',
    '💂🏽' => 'ساتونکی: غنم رنګه',
    '💂🏾' => 'ساتونکی: غنمی-تورنګه پوستکۍ',
    '💂🏿' => 'ساتونکی: تور پوستکۍ',
    '🥷🏻' => 'ننجا: د روڼ پوستکي ټون',
    '🥷🏼' => 'ننجا: غنمی-روښانه پوستکۍ',
    '🥷🏽' => 'ننجا: غنم رنګه',
    '🥷🏾' => 'ننجا: غنمی-تورنګه پوستکۍ',
    '🥷🏿' => 'ننجا: تور پوستکۍ',
    '👷🏻' => 'ساختماني کارکونکي: د روڼ پوستکي ټون',
    '👷🏼' => 'ساختماني کارکونکي: غنمی-روښانه پوستکۍ',
    '👷🏽' => 'ساختماني کارکونکي: غنم رنګه',
    '👷🏾' => 'ساختماني کارکونکي: غنمی-تورنګه پوستکۍ',
    '👷🏿' => 'ساختماني کارکونکي: تور پوستکۍ',
    '🫅🏻' => 'د تاج کس: د روڼ پوستکي ټون',
    '🫅🏼' => 'د تاج کس: غنمی-روښانه پوستکۍ',
    '🫅🏽' => 'د تاج کس: غنم رنګه',
    '🫅🏾' => 'د تاج کس: غنمی-تورنګه پوستکۍ',
    '🫅🏿' => 'د تاج کس: تور پوستکۍ',
    '🤴🏻' => 'شهزاده: د روڼ پوستکي ټون',
    '🤴🏼' => 'شهزاده: غنمی-روښانه پوستکۍ',
    '🤴🏽' => 'شهزاده: غنم رنګه',
    '🤴🏾' => 'شهزاده: غنمی-تورنګه پوستکۍ',
    '🤴🏿' => 'شهزاده: تور پوستکۍ',
    '👸🏻' => 'شهزادګی: د روڼ پوستکي ټون',
    '👸🏼' => 'شهزادګی: غنمی-روښانه پوستکۍ',
    '👸🏽' => 'شهزادګی: غنم رنګه',
    '👸🏾' => 'شهزادګی: غنمی-تورنګه پوستکۍ',
    '👸🏿' => 'شهزادګی: تور پوستکۍ',
    '👳🏻' => 'شخص لونګۍ په سر: د روڼ پوستکي ټون',
    '👳🏼' => 'شخص لونګۍ په سر: غنمی-روښانه پوستکۍ',
    '👳🏽' => 'شخص لونګۍ په سر: غنم رنګه',
    '👳🏾' => 'شخص لونګۍ په سر: غنمی-تورنګه پوستکۍ',
    '👳🏿' => 'شخص لونګۍ په سر: تور پوستکۍ',
    '👲🏻' => 'سړی د چینایی کیپ سره: د روڼ پوستکي ټون',
    '👲🏼' => 'سړی د چینایی کیپ سره: غنمی-روښانه پوستکۍ',
    '👲🏽' => 'سړی د چینایی کیپ سره: غنم رنګه',
    '👲🏾' => 'سړی د چینایی کیپ سره: غنمی-تورنګه پوستکۍ',
    '👲🏿' => 'سړی د چینایی کیپ سره: تور پوستکۍ',
    '🧕🏻' => 'ښځه د سرکوف سره: د روڼ پوستکي ټون',
    '🧕🏼' => 'ښځه د سرکوف سره: غنمی-روښانه پوستکۍ',
    '🧕🏽' => 'ښځه د سرکوف سره: غنم رنګه',
    '🧕🏾' => 'ښځه د سرکوف سره: غنمی-تورنګه پوستکۍ',
    '🧕🏿' => 'ښځه د سرکوف سره: تور پوستکۍ',
    '🤵🏻' => 'سړی په ټکسيډو کې: د روڼ پوستکي ټون',
    '🤵🏼' => 'سړی په ټکسيډو کې: غنمی-روښانه پوستکۍ',
    '🤵🏽' => 'سړی په ټکسيډو کې: غنم رنګه',
    '🤵🏾' => 'سړی په ټکسيډو کې: غنمی-تورنګه پوستکۍ',
    '🤵🏿' => 'سړی په ټکسيډو کې: تور پوستکۍ',
    '👰🏻' => 'ناوي په حجاب کې: د روڼ پوستکي ټون',
    '👰🏼' => 'ناوي په حجاب کې: غنمی-روښانه پوستکۍ',
    '👰🏽' => 'ناوي په حجاب کې: غنم رنګه',
    '👰🏾' => 'ناوي په حجاب کې: غنمی-تورنګه پوستکۍ',
    '👰🏿' => 'ناوي په حجاب کې: تور پوستکۍ',
    '🤰🏻' => 'امیندواره ښځه: د روڼ پوستکي ټون',
    '🤰🏼' => 'امیندواره ښځه: غنمی-روښانه پوستکۍ',
    '🤰🏽' => 'امیندواره ښځه: غنم رنګه',
    '🤰🏾' => 'امیندواره ښځه: غنمی-تورنګه پوستکۍ',
    '🤰🏿' => 'امیندواره ښځه: تور پوستکۍ',
    '🫃🏻' => 'امیندواره سړی: د روڼ پوستکي ټون',
    '🫃🏼' => 'امیندواره سړی: غنمی-روښانه پوستکۍ',
    '🫃🏽' => 'امیندواره سړی: غنم رنګه',
    '🫃🏾' => 'امیندواره سړی: غنمی-تورنګه پوستکۍ',
    '🫃🏿' => 'امیندواره سړی: تور پوستکۍ',
    '🫄🏻' => 'امیندواره کس: د روڼ پوستکي ټون',
    '🫄🏼' => 'امیندواره کس: غنمی-روښانه پوستکۍ',
    '🫄🏽' => 'امیندواره کس: غنم رنګه',
    '🫄🏾' => 'امیندواره کس: غنمی-تورنګه پوستکۍ',
    '🫄🏿' => 'امیندواره کس: تور پوستکۍ',
    '🤱🏻' => 'د سينې شيدې ورکول: د روڼ پوستکي ټون',
    '🤱🏼' => 'د سينې شيدې ورکول: غنمی-روښانه پوستکۍ',
    '🤱🏽' => 'د سينې شيدې ورکول: غنم رنګه',
    '🤱🏾' => 'د سينې شيدې ورکول: غنمی-تورنګه پوستکۍ',
    '🤱🏿' => 'د سينې شيدې ورکول: تور پوستکۍ',
    '👼🏻' => 'ماشوم فرښته: د روڼ پوستکي ټون',
    '👼🏼' => 'ماشوم فرښته: غنمی-روښانه پوستکۍ',
    '👼🏽' => 'ماشوم فرښته: غنم رنګه',
    '👼🏾' => 'ماشوم فرښته: غنمی-تورنګه پوستکۍ',
    '👼🏿' => 'ماشوم فرښته: تور پوستکۍ',
    '🎅🏻' => 'سانټا کلاز: د روڼ پوستکي ټون',
    '🎅🏼' => 'سانټا کلاز: غنمی-روښانه پوستکۍ',
    '🎅🏽' => 'سانټا کلاز: غنم رنګه',
    '🎅🏾' => 'سانټا کلاز: غنمی-تورنګه پوستکۍ',
    '🎅🏿' => 'سانټا کلاز: تور پوستکۍ',
    '🤶🏻' => 'ميرمن کلاز: د روڼ پوستکي ټون',
    '🤶🏼' => 'ميرمن کلاز: غنمی-روښانه پوستکۍ',
    '🤶🏽' => 'ميرمن کلاز: غنم رنګه',
    '🤶🏾' => 'ميرمن کلاز: غنمی-تورنګه پوستکۍ',
    '🤶🏿' => 'ميرمن کلاز: تور پوستکۍ',
    '🦸🏻' => 'لوي اتل: د روڼ پوستکي ټون',
    '🦸🏼' => 'لوي اتل: غنمی-روښانه پوستکۍ',
    '🦸🏽' => 'لوي اتل: غنم رنګه',
    '🦸🏾' => 'لوي اتل: غنمی-تورنګه پوستکۍ',
    '🦸🏿' => 'لوي اتل: تور پوستکۍ',
    '🦹🏻' => 'لوي ورانکاری: د روڼ پوستکي ټون',
    '🦹🏼' => 'لوي ورانکاری: غنمی-روښانه پوستکۍ',
    '🦹🏽' => 'لوي ورانکاری: غنم رنګه',
    '🦹🏾' => 'لوي ورانکاری: غنمی-تورنګه پوستکۍ',
    '🦹🏿' => 'لوي ورانکاری: تور پوستکۍ',
    '🧙🏻' => 'جادوګر: د روڼ پوستکي ټون',
    '🧙🏼' => 'جادوګر: غنمی-روښانه پوستکۍ',
    '🧙🏽' => 'جادوګر: غنم رنګه',
    '🧙🏾' => 'جادوګر: غنمی-تورنګه پوستکۍ',
    '🧙🏿' => 'جادوګر: تور پوستکۍ',
    '🧚🏻' => 'ښاپيرۍ: د روڼ پوستکي ټون',
    '🧚🏼' => 'ښاپيرۍ: غنمی-روښانه پوستکۍ',
    '🧚🏽' => 'ښاپيرۍ: غنم رنګه',
    '🧚🏾' => 'ښاپيرۍ: غنمی-تورنګه پوستکۍ',
    '🧚🏿' => 'ښاپيرۍ: تور پوستکۍ',
    '🧛🏻' => 'بلا: د روڼ پوستکي ټون',
    '🧛🏼' => 'بلا: غنمی-روښانه پوستکۍ',
    '🧛🏽' => 'بلا: غنم رنګه',
    '🧛🏾' => 'بلا: غنمی-تورنګه پوستکۍ',
    '🧛🏿' => 'بلا: تور پوستکۍ',
    '🧜🏻' => 'مرپرسن: د روڼ پوستکي ټون',
    '🧜🏼' => 'مرپرسن: غنمی-روښانه پوستکۍ',
    '🧜🏽' => 'مرپرسن: غنم رنګه',
    '🧜🏾' => 'مرپرسن: غنمی-تورنګه پوستکۍ',
    '🧜🏿' => 'مرپرسن: تور پوستکۍ',
    '🧝🏻' => 'ګوړا: د روڼ پوستکي ټون',
    '🧝🏼' => 'ګوړا: غنمی-روښانه پوستکۍ',
    '🧝🏽' => 'ګوړا: غنم رنګه',
    '🧝🏾' => 'ګوړا: غنمی-تورنګه پوستکۍ',
    '🧝🏿' => 'ګوړا: تور پوستکۍ',
    '💆🏻' => 'شخص مالش ترلاسه کوي: د روڼ پوستکي ټون',
    '💆🏼' => 'شخص مالش ترلاسه کوي: غنمی-روښانه پوستکۍ',
    '💆🏽' => 'شخص مالش ترلاسه کوي: غنم رنګه',
    '💆🏾' => 'شخص مالش ترلاسه کوي: غنمی-تورنګه پوستکۍ',
    '💆🏿' => 'شخص مالش ترلاسه کوي: تور پوستکۍ',
    '💇🏻' => 'شخص پرېټ کوي: د روڼ پوستکي ټون',
    '💇🏼' => 'شخص پرېټ کوي: غنمی-روښانه پوستکۍ',
    '💇🏽' => 'شخص پرېټ کوي: غنم رنګه',
    '💇🏾' => 'شخص پرېټ کوي: غنمی-تورنګه پوستکۍ',
    '💇🏿' => 'شخص پرېټ کوي: تور پوستکۍ',
    '🚶🏻' => 'روان شخص: د روڼ پوستکي ټون',
    '🚶🏼' => 'روان شخص: غنمی-روښانه پوستکۍ',
    '🚶🏽' => 'روان شخص: غنم رنګه',
    '🚶🏾' => 'روان شخص: غنمی-تورنګه پوستکۍ',
    '🚶🏿' => 'روان شخص: تور پوستکۍ',
    '🧍🏻' => 'ولاړ شخص: د روڼ پوستکي ټون',
    '🧍🏼' => 'ولاړ شخص: غنمی-روښانه پوستکۍ',
    '🧍🏽' => 'ولاړ شخص: غنم رنګه',
    '🧍🏾' => 'ولاړ شخص: غنمی-تورنګه پوستکۍ',
    '🧍🏿' => 'ولاړ شخص: تور پوستکۍ',
    '🧎🏻' => 'شخص چوکېږي: د روڼ پوستکي ټون',
    '🧎🏼' => 'شخص چوکېږي: غنمی-روښانه پوستکۍ',
    '🧎🏽' => 'شخص چوکېږي: غنم رنګه',
    '🧎🏾' => 'شخص چوکېږي: غنمی-تورنګه پوستکۍ',
    '🧎🏿' => 'شخص چوکېږي: تور پوستکۍ',
    '🏃🏻' => 'شخص ځغلي: د روڼ پوستکي ټون',
    '🏃🏼' => 'شخص ځغلي: غنمی-روښانه پوستکۍ',
    '🏃🏽' => 'شخص ځغلي: غنم رنګه',
    '🏃🏾' => 'شخص ځغلي: غنمی-تورنګه پوستکۍ',
    '🏃🏿' => 'شخص ځغلي: تور پوستکۍ',
    '💃🏻' => 'ښځه نڅيږې: د روڼ پوستکي ټون',
    '💃🏼' => 'ښځه نڅيږې: غنمی-روښانه پوستکۍ',
    '💃🏽' => 'ښځه نڅيږې: غنم رنګه',
    '💃🏾' => 'ښځه نڅيږې: غنمی-تورنګه پوستکۍ',
    '💃🏿' => 'ښځه نڅيږې: تور پوستکۍ',
    '🕺🏻' => 'سړی نڅيږې: د روڼ پوستکي ټون',
    '🕺🏼' => 'سړی نڅيږې: غنمی-روښانه پوستکۍ',
    '🕺🏽' => 'سړی نڅيږې: غنم رنګه',
    '🕺🏾' => 'سړی نڅيږې: غنمی-تورنګه پوستکۍ',
    '🕺🏿' => 'سړی نڅيږې: تور پوستکۍ',
    '🕴🏻' => 'سړي په کالو کې اوچتيږي: د روڼ پوستکي ټون',
    '🕴🏼' => 'سړي په کالو کې اوچتيږي: غنمی-روښانه پوستکۍ',
    '🕴🏽' => 'سړي په کالو کې اوچتيږي: غنم رنګه',
    '🕴🏾' => 'سړي په کالو کې اوچتيږي: غنمی-تورنګه پوستکۍ',
    '🕴🏿' => 'سړي په کالو کې اوچتيږي: تور پوستکۍ',
    '👯🏻' => 'خلک د سويې غوږونو سره: د روڼ پوستکي ټون',
    '👯🏼' => 'خلک د سويې غوږونو سره: غنمی-روښانه پوستکۍ',
    '👯🏽' => 'خلک د سويې غوږونو سره: غنم رنګه',
    '👯🏾' => 'خلک د سويې غوږونو سره: غنمی-تورنګه پوستکۍ',
    '👯🏿' => 'خلک د سويې غوږونو سره: تور پوستکۍ',
    '🧖🏻' => 'شخص د پخار په خونه کې: د روڼ پوستکي ټون',
    '🧖🏼' => 'شخص د پخار په خونه کې: غنمی-روښانه پوستکۍ',
    '🧖🏽' => 'شخص د پخار په خونه کې: غنم رنګه',
    '🧖🏾' => 'شخص د پخار په خونه کې: غنمی-تورنګه پوستکۍ',
    '🧖🏿' => 'شخص د پخار په خونه کې: تور پوستکۍ',
    '🧗🏻' => 'شخص هسکېږي: د روڼ پوستکي ټون',
    '🧗🏼' => 'شخص هسکېږي: غنمی-روښانه پوستکۍ',
    '🧗🏽' => 'شخص هسکېږي: غنم رنګه',
    '🧗🏾' => 'شخص هسکېږي: غنمی-تورنګه پوستکۍ',
    '🧗🏿' => 'شخص هسکېږي: تور پوستکۍ',
    '🏇🏻' => 'آس ځغلي: د روڼ پوستکي ټون',
    '🏇🏼' => 'آس ځغلي: غنمی-روښانه پوستکۍ',
    '🏇🏽' => 'آس ځغلي: غنم رنګه',
    '🏇🏾' => 'آس ځغلي: غنمی-تورنګه پوستکۍ',
    '🏇🏿' => 'آس ځغلي: تور پوستکۍ',
    '🏂🏻' => 'سنو بورډر: د روڼ پوستکي ټون',
    '🏂🏼' => 'سنو بورډر: غنمی-روښانه پوستکۍ',
    '🏂🏽' => 'سنو بورډر: غنم رنګه',
    '🏂🏾' => 'سنو بورډر: غنمی-تورنګه پوستکۍ',
    '🏂🏿' => 'سنو بورډر: تور پوستکۍ',
    '🏌🏻' => 'شخص ګالف کوي: د روڼ پوستکي ټون',
    '🏌🏼' => 'شخص ګالف کوي: غنمی-روښانه پوستکۍ',
    '🏌🏽' => 'شخص ګالف کوي: غنم رنګه',
    '🏌🏾' => 'شخص ګالف کوي: غنمی-تورنګه پوستکۍ',
    '🏌🏿' => 'شخص ګالف کوي: تور پوستکۍ',
    '🏄🏻' => 'شخص سرفنگ کوي: د روڼ پوستکي ټون',
    '🏄🏼' => 'شخص سرفنگ کوي: غنمی-روښانه پوستکۍ',
    '🏄🏽' => 'شخص سرفنگ کوي: غنم رنګه',
    '🏄🏾' => 'شخص سرفنگ کوي: غنمی-تورنګه پوستکۍ',
    '🏄🏿' => 'شخص سرفنگ کوي: تور پوستکۍ',
    '🚣🏻' => 'شخص کښتۍ چلوي: د روڼ پوستکي ټون',
    '🚣🏼' => 'شخص کښتۍ چلوي: غنمی-روښانه پوستکۍ',
    '🚣🏽' => 'شخص کښتۍ چلوي: غنم رنګه',
    '🚣🏾' => 'شخص کښتۍ چلوي: غنمی-تورنګه پوستکۍ',
    '🚣🏿' => 'شخص کښتۍ چلوي: تور پوستکۍ',
    '🏊🏻' => 'شخص لامبو وهي: د روڼ پوستکي ټون',
    '🏊🏼' => 'شخص لامبو وهي: غنمی-روښانه پوستکۍ',
    '🏊🏽' => 'شخص لامبو وهي: غنم رنګه',
    '🏊🏾' => 'شخص لامبو وهي: غنمی-تورنګه پوستکۍ',
    '🏊🏿' => 'شخص لامبو وهي: تور پوستکۍ',
    '⛹🏻' => 'شخص بال تمبوي: د روڼ پوستکي ټون',
    '⛹🏼' => 'شخص بال تمبوي: غنمی-روښانه پوستکۍ',
    '⛹🏽' => 'شخص بال تمبوي: غنم رنګه',
    '⛹🏾' => 'شخص بال تمبوي: غنمی-تورنګه پوستکۍ',
    '⛹🏿' => 'شخص بال تمبوي: تور پوستکۍ',
    '🏋🏻' => 'شخص وزن پورته کوي: د روڼ پوستکي ټون',
    '🏋🏼' => 'شخص وزن پورته کوي: غنمی-روښانه پوستکۍ',
    '🏋🏽' => 'شخص وزن پورته کوي: غنم رنګه',
    '🏋🏾' => 'شخص وزن پورته کوي: غنمی-تورنګه پوستکۍ',
    '🏋🏿' => 'شخص وزن پورته کوي: تور پوستکۍ',
    '🚴🏻' => 'شخص بايک چلوي: د روڼ پوستکي ټون',
    '🚴🏼' => 'شخص بايک چلوي: غنمی-روښانه پوستکۍ',
    '🚴🏽' => 'شخص بايک چلوي: غنم رنګه',
    '🚴🏾' => 'شخص بايک چلوي: غنمی-تورنګه پوستکۍ',
    '🚴🏿' => 'شخص بايک چلوي: تور پوستکۍ',
    '🚵🏻' => 'شخص په غر بايک چلوي: د روڼ پوستکي ټون',
    '🚵🏼' => 'شخص په غر بايک چلوي: غنمی-روښانه پوستکۍ',
    '🚵🏽' => 'شخص په غر بايک چلوي: غنم رنګه',
    '🚵🏾' => 'شخص په غر بايک چلوي: غنمی-تورنګه پوستکۍ',
    '🚵🏿' => 'شخص په غر بايک چلوي: تور پوستکۍ',
    '🤸🏻' => 'شخص کارټ ويلنګ کوي: د روڼ پوستکي ټون',
    '🤸🏼' => 'شخص کارټ ويلنګ کوي: غنمی-روښانه پوستکۍ',
    '🤸🏽' => 'شخص کارټ ويلنګ کوي: غنم رنګه',
    '🤸🏾' => 'شخص کارټ ويلنګ کوي: غنمی-تورنګه پوستکۍ',
    '🤸🏿' => 'شخص کارټ ويلنګ کوي: تور پوستکۍ',
    '🤼🏻' => 'خلک پهلواني کوي: د روڼ پوستکي ټون',
    '🤼🏼' => 'خلک پهلواني کوي: غنمی-روښانه پوستکۍ',
    '🤼🏽' => 'خلک پهلواني کوي: غنم رنګه',
    '🤼🏾' => 'خلک پهلواني کوي: غنمی-تورنګه پوستکۍ',
    '🤼🏿' => 'خلک پهلواني کوي: تور پوستکۍ',
    '🤽🏻' => 'شخص د اوبو پولو لوبه کوي: د روڼ پوستکي ټون',
    '🤽🏼' => 'شخص د اوبو پولو لوبه کوي: غنمی-روښانه پوستکۍ',
    '🤽🏽' => 'شخص د اوبو پولو لوبه کوي: غنم رنګه',
    '🤽🏾' => 'شخص د اوبو پولو لوبه کوي: غنمی-تورنګه پوستکۍ',
    '🤽🏿' => 'شخص د اوبو پولو لوبه کوي: تور پوستکۍ',
    '🤾🏻' => 'شخص د هنډبال لوبه کوي: د روڼ پوستکي ټون',
    '🤾🏼' => 'شخص د هنډبال لوبه کوي: غنمی-روښانه پوستکۍ',
    '🤾🏽' => 'شخص د هنډبال لوبه کوي: غنم رنګه',
    '🤾🏾' => 'شخص د هنډبال لوبه کوي: غنمی-تورنګه پوستکۍ',
    '🤾🏿' => 'شخص د هنډبال لوبه کوي: تور پوستکۍ',
    '🤹🏻' => 'شخص جادو کوي: د روڼ پوستکي ټون',
    '🤹🏼' => 'شخص جادو کوي: غنمی-روښانه پوستکۍ',
    '🤹🏽' => 'شخص جادو کوي: غنم رنګه',
    '🤹🏾' => 'شخص جادو کوي: غنمی-تورنګه پوستکۍ',
    '🤹🏿' => 'شخص جادو کوي: تور پوستکۍ',
    '🧘🏻' => 'شخص د پرلت په حالت کې: د روڼ پوستکي ټون',
    '🧘🏼' => 'شخص د پرلت په حالت کې: غنمی-روښانه پوستکۍ',
    '🧘🏽' => 'شخص د پرلت په حالت کې: غنم رنګه',
    '🧘🏾' => 'شخص د پرلت په حالت کې: غنمی-تورنګه پوستکۍ',
    '🧘🏿' => 'شخص د پرلت په حالت کې: تور پوستکۍ',
    '🛀🏻' => 'شخص غسل کوي: د روڼ پوستکي ټون',
    '🛀🏼' => 'شخص غسل کوي: غنمی-روښانه پوستکۍ',
    '🛀🏽' => 'شخص غسل کوي: غنم رنګه',
    '🛀🏾' => 'شخص غسل کوي: غنمی-تورنګه پوستکۍ',
    '🛀🏿' => 'شخص غسل کوي: تور پوستکۍ',
    '🛌🏻' => 'شخص په بستره کې: د روڼ پوستکي ټون',
    '🛌🏼' => 'شخص په بستره کې: غنمی-روښانه پوستکۍ',
    '🛌🏽' => 'شخص په بستره کې: غنم رنګه',
    '🛌🏾' => 'شخص په بستره کې: غنمی-تورنګه پوستکۍ',
    '🛌🏿' => 'شخص په بستره کې: تور پوستکۍ',
    '👭🏻' => 'دوه ښځو لاسونه نيولي: د روڼ پوستکي ټون',
    '👭🏼' => 'دوه ښځو لاسونه نيولي: غنمی-روښانه پوستکۍ',
    '👭🏽' => 'دوه ښځو لاسونه نيولي: غنم رنګه',
    '👭🏾' => 'دوه ښځو لاسونه نيولي: غنمی-تورنګه پوستکۍ',
    '👭🏿' => 'دوه ښځو لاسونه نيولي: تور پوستکۍ',
    '👫🏻' => 'سړی او ښځه لاس په لاس کې: د روڼ پوستکي ټون',
    '👫🏼' => 'سړی او ښځه لاس په لاس کې: غنمی-روښانه پوستکۍ',
    '👫🏽' => 'سړی او ښځه لاس په لاس کې: غنم رنګه',
    '👫🏾' => 'سړی او ښځه لاس په لاس کې: غنمی-تورنګه پوستکۍ',
    '👫🏿' => 'سړی او ښځه لاس په لاس کې: تور پوستکۍ',
    '👬🏻' => 'دوه سړو لاسونه نيولي: د روڼ پوستکي ټون',
    '👬🏼' => 'دوه سړو لاسونه نيولي: غنمی-روښانه پوستکۍ',
    '👬🏽' => 'دوه سړو لاسونه نيولي: غنم رنګه',
    '👬🏾' => 'دوه سړو لاسونه نيولي: غنمی-تورنګه پوستکۍ',
    '👬🏿' => 'دوه سړو لاسونه نيولي: تور پوستکۍ',
    '💏🏻' => 'مچول: د روڼ پوستکي ټون',
    '💏🏼' => 'مچول: غنمی-روښانه پوستکۍ',
    '💏🏽' => 'مچول: غنم رنګه',
    '💏🏾' => 'مچول: غنمی-تورنګه پوستکۍ',
    '💏🏿' => 'مچول: تور پوستکۍ',
    '💑🏻' => 'د زړه سره جوړه: د روڼ پوستکي ټون',
    '💑🏼' => 'د زړه سره جوړه: غنمی-روښانه پوستکۍ',
    '💑🏽' => 'د زړه سره جوړه: غنم رنګه',
    '💑🏾' => 'د زړه سره جوړه: غنمی-تورنګه پوستکۍ',
    '💑🏿' => 'د زړه سره جوړه: تور پوستکۍ',
    '🇦🇨' => 'بيرغ: اسينشان ټاپو',
    '🇦🇩' => 'بيرغ: اندورا',
    '🇦🇪' => 'بيرغ: متحده عرب امارات',
    '🇦🇫' => 'بيرغ: افغانستان',
    '🇦🇬' => 'بيرغ: انټيګوا او باربودا',
    '🇦🇮' => 'بيرغ: انګیلا',
    '🇦🇱' => 'بيرغ: البانیه',
    '🇦🇲' => 'بيرغ: ارمنستان',
    '🇦🇴' => 'بيرغ: انګولا',
    '🇦🇶' => 'بيرغ: انتارکتیکا',
    '🇦🇷' => 'بيرغ: ارجنټاين',
    '🇦🇸' => 'بيرغ: امریکایی ساماوا',
    '🇦🇹' => 'بيرغ: اتریش',
    '🇦🇺' => 'بيرغ: آسټرالیا',
    '🇦🇼' => 'بيرغ: آروبا',
    '🇦🇽' => 'بيرغ: الاند ټاپوان',
    '🇦🇿' => 'بيرغ: اذربايجان',
    '🇧🇦' => 'بيرغ: بوسنيا او هېرزګوينا',
    '🇧🇧' => 'بيرغ: باربادوس',
    '🇧🇩' => 'بيرغ: بنگله دېش',
    '🇧🇪' => 'بيرغ: بیلجیم',
    '🇧🇫' => 'بيرغ: بورکینا فاسو',
    '🇧🇬' => 'بيرغ: بلغاریه',
    '🇧🇭' => 'بيرغ: بحرين',
    '🇧🇮' => 'بيرغ: بروندي',
    '🇧🇯' => 'بيرغ: بینن',
    '🇧🇱' => 'بيرغ: سينټ بارتيلمي',
    '🇧🇲' => 'بيرغ: برمودا',
    '🇧🇳' => 'بيرغ: برونائي',
    '🇧🇴' => 'بيرغ: بولیویا',
    '🇧🇶' => 'بيرغ: کیریبین هالینډ',
    '🇧🇷' => 'بيرغ: برازیل',
    '🇧🇸' => 'بيرغ: باهماس',
    '🇧🇹' => 'بيرغ: بهوټان',
    '🇧🇻' => 'بيرغ: بوویټ ټاپو',
    '🇧🇼' => 'بيرغ: بوتسوانه',
    '🇧🇾' => 'بيرغ: بیلاروس',
    '🇧🇿' => 'بيرغ: بلیز',
    '🇨🇦' => 'بيرغ: کاناډا',
    '🇨🇨' => 'بيرغ: کوکوز (کيلنګ) ټاپوګان',
    '🇨🇩' => 'بيرغ: کانګو - کینشاسا',
    '🇨🇫' => 'بيرغ: وسطي افريقا جمهور',
    '🇨🇬' => 'بيرغ: کانګو - بروزوییل',
    '🇨🇭' => 'بيرغ: سویس',
    '🇨🇮' => 'بيرغ: د عاج ساحل',
    '🇨🇰' => 'بيرغ: کوک ټاپوګان',
    '🇨🇱' => 'بيرغ: چیلي',
    '🇨🇲' => 'بيرغ: کامرون',
    '🇨🇳' => 'بيرغ: چین',
    '🇨🇴' => 'بيرغ: کولمبیا',
    '🇨🇵' => 'بيرغ: د کلپرټون ټاپو',
    '🇨🇶' => 'بيرغ: سارک',
    '🇨🇷' => 'بيرغ: کوستاریکا',
    '🇨🇺' => 'بيرغ: کیوبا',
    '🇨🇻' => 'بيرغ: کیپ ورد',
    '🇨🇼' => 'بيرغ: کوراکاو',
    '🇨🇽' => 'بيرغ: د کريسمس ټاپو',
    '🇨🇾' => 'بيرغ: قبرس',
    '🇨🇿' => 'بيرغ: چکیا',
    '🇩🇪' => 'بيرغ: المان',
    '🇩🇬' => 'بيرغ: ډایګو ګارسیا',
    '🇩🇯' => 'بيرغ: جبوتي',
    '🇩🇰' => 'بيرغ: ډنمارک',
    '🇩🇲' => 'بيرغ: دومینیکا',
    '🇩🇴' => 'بيرغ: جمهوريه ډومينيکن',
    '🇩🇿' => 'بيرغ: الجزایر',
    '🇪🇦' => 'بيرغ: سيوتا او ماليلا',
    '🇪🇨' => 'بيرغ: اکوادور',
    '🇪🇪' => 'بيرغ: استونیا',
    '🇪🇬' => 'بيرغ: مصر',
    '🇪🇭' => 'بيرغ: لويديځ صحارا',
    '🇪🇷' => 'بيرغ: اریتره',
    '🇪🇸' => 'بيرغ: هسپانیه',
    '🇪🇹' => 'بيرغ: حبشه',
    '🇪🇺' => 'بيرغ: اروپايي اتحاديه',
    '🇫🇮' => 'بيرغ: فنلینډ',
    '🇫🇯' => 'بيرغ: فجي',
    '🇫🇰' => 'بيرغ: فاکلينډ ټاپوګان',
    '🇫🇲' => 'بيرغ: میکرونیزیا',
    '🇫🇴' => 'بيرغ: فارو ټاپو',
    '🇫🇷' => 'بيرغ: فرانسه',
    '🇬🇦' => 'بيرغ: ګابن',
    '🇬🇧' => 'بيرغ: برتانیه',
    '🇬🇩' => 'بيرغ: ګرنادا',
    '🇬🇪' => 'بيرغ: گورجستان',
    '🇬🇫' => 'بيرغ: فرانسوي ګانا',
    '🇬🇬' => 'بيرغ: ګرنسي',
    '🇬🇭' => 'بيرغ: ګانا',
    '🇬🇮' => 'بيرغ: جبل الطارق',
    '🇬🇱' => 'بيرغ: ګرینلینډ',
    '🇬🇲' => 'بيرغ: ګامبیا',
    '🇬🇳' => 'بيرغ: ګینه',
    '🇬🇵' => 'بيرغ: ګوادلوپ',
    '🇬🇶' => 'بيرغ: استوایی ګیني',
    '🇬🇷' => 'بيرغ: یونان',
    '🇬🇸' => 'بيرغ: سويلي جارجيا او سويلي سېنډوچ ټاپوګان',
    '🇬🇹' => 'بيرغ: ګواتیمالا',
    '🇬🇺' => 'بيرغ: ګوام',
    '🇬🇼' => 'بيرغ: ګینه بیسو',
    '🇬🇾' => 'بيرغ: ګیانا',
    '🇭🇰' => 'بيرغ: هانګ کانګ SAR چین',
    '🇭🇲' => 'بيرغ: هارډ او ميکډانلډ ټاپوګان',
    '🇭🇳' => 'بيرغ: هانډوراس',
    '🇭🇷' => 'بيرغ: کرواشيا',
    '🇭🇹' => 'بيرغ: هایټي',
    '🇭🇺' => 'بيرغ: مجارستان',
    '🇮🇨' => 'بيرغ: د کناري ټاپوګان',
    '🇮🇩' => 'بيرغ: اندونیزیا',
    '🇮🇪' => 'بيرغ: آيرلېنډ',
    '🇮🇱' => 'بيرغ: اسراييل',
    '🇮🇲' => 'بيرغ: د آئل آف مین',
    '🇮🇳' => 'بيرغ: هند',
    '🇮🇴' => 'بيرغ: د برتانوي هند سمندري سيمه',
    '🇮🇶' => 'بيرغ: عراق',
    '🇮🇷' => 'بيرغ: ايران',
    '🇮🇸' => 'بيرغ: آیسلینډ',
    '🇮🇹' => 'بيرغ: ایټالیه',
    '🇯🇪' => 'بيرغ: جرسی',
    '🇯🇲' => 'بيرغ: جمیکا',
    '🇯🇴' => 'بيرغ: اردن',
    '🇯🇵' => 'بيرغ: جاپان',
    '🇰🇪' => 'بيرغ: کینیا',
    '🇰🇬' => 'بيرغ: قرغزستان',
    '🇰🇭' => 'بيرغ: کمبودیا',
    '🇰🇮' => 'بيرغ: کیري باتي',
    '🇰🇲' => 'بيرغ: کوموروس',
    '🇰🇳' => 'بيرغ: سینټ کټس او نیویس',
    '🇰🇵' => 'بيرغ: شمالی کوریا',
    '🇰🇷' => 'بيرغ: سویلي کوریا',
    '🇰🇼' => 'بيرغ: کويت',
    '🇰🇾' => 'بيرغ: کیمان ټاپوګان',
    '🇰🇿' => 'بيرغ: قزاقستان',
    '🇱🇦' => 'بيرغ: لاوس',
    '🇱🇧' => 'بيرغ: لبنان',
    '🇱🇨' => 'بيرغ: سینټ لوسیا',
    '🇱🇮' => 'بيرغ: لیختن اشتاین',
    '🇱🇰' => 'بيرغ: سريلنکا',
    '🇱🇷' => 'بيرغ: لايبيريا',
    '🇱🇸' => 'بيرغ: لسوتو',
    '🇱🇹' => 'بيرغ: لیتوانیا',
    '🇱🇺' => 'بيرغ: لوګزامبورګ',
    '🇱🇻' => 'بيرغ: ليتهويا',
    '🇱🇾' => 'بيرغ: لیبیا',
    '🇲🇦' => 'بيرغ: مراکش',
    '🇲🇨' => 'بيرغ: موناکو',
    '🇲🇩' => 'بيرغ: مولدوا',
    '🇲🇪' => 'بيرغ: مونټینیګرو',
    '🇲🇫' => 'بيرغ: سینټ مارټن',
    '🇲🇬' => 'بيرغ: مدغاسکر',
    '🇲🇭' => 'بيرغ: مارشل ټاپوګان',
    '🇲🇰' => 'بيرغ: شمالي مقدونيه',
    '🇲🇱' => 'بيرغ: مالي',
    '🇲🇲' => 'بيرغ: ميانمار (برما)',
    '🇲🇳' => 'بيرغ: منګوليا',
    '🇲🇴' => 'بيرغ: مکاو SAR چین',
    '🇲🇵' => 'بيرغ: شمالي ماريانا ټاپوګان',
    '🇲🇶' => 'بيرغ: مارټینیک',
    '🇲🇷' => 'بيرغ: موریتانیا',
    '🇲🇸' => 'بيرغ: مانټیسیرت',
    '🇲🇹' => 'بيرغ: مالټا',
    '🇲🇺' => 'بيرغ: موریشیس',
    '🇲🇻' => 'بيرغ: مالديپ',
    '🇲🇼' => 'بيرغ: مالاوي',
    '🇲🇽' => 'بيرغ: میکسیکو',
    '🇲🇾' => 'بيرغ: مالیزیا',
    '🇲🇿' => 'بيرغ: موزمبيق',
    '🇳🇦' => 'بيرغ: نیمبیا',
    '🇳🇨' => 'بيرغ: نوی کالیډونیا',
    '🇳🇪' => 'بيرغ: نايجير',
    '🇳🇫' => 'بيرغ: نارفولک ټاپوګان',
    '🇳🇬' => 'بيرغ: نایجیریا',
    '🇳🇮' => 'بيرغ: نکاراګوا',
    '🇳🇱' => 'بيرغ: هالېنډ',
    '🇳🇴' => 'بيرغ: ناروۍ',
    '🇳🇵' => 'بيرغ: نیپال',
    '🇳🇷' => 'بيرغ: نایرو',
    '🇳🇺' => 'بيرغ: نیوو',
    '🇳🇿' => 'بيرغ: نیوزیلنډ',
    '🇴🇲' => 'بيرغ: عمان',
    '🇵🇦' => 'بيرغ: پاناما',
    '🇵🇪' => 'بيرغ: پیرو',
    '🇵🇫' => 'بيرغ: فرانسوي پولينيسيا',
    '🇵🇬' => 'بيرغ: پاپوا نيو ګيني',
    '🇵🇭' => 'بيرغ: فلپين',
    '🇵🇰' => 'بيرغ: پاکستان',
    '🇵🇱' => 'بيرغ: پولنډ',
    '🇵🇲' => 'بيرغ: سینټ پییر او میکولون',
    '🇵🇳' => 'بيرغ: پيټکيرن ټاپوګان',
    '🇵🇷' => 'بيرغ: پورتو ریکو',
    '🇵🇸' => 'بيرغ: فلسطیني سيمې',
    '🇵🇹' => 'بيرغ: پورتګال',
    '🇵🇼' => 'بيرغ: پلاؤ',
    '🇵🇾' => 'بيرغ: پاراګوی',
    '🇶🇦' => 'بيرغ: قطر',
    '🇷🇪' => 'بيرغ: ریونین',
    '🇷🇴' => 'بيرغ: رومانیا',
    '🇷🇸' => 'بيرغ: سربيا',
    '🇷🇺' => 'بيرغ: روسیه',
    '🇷🇼' => 'بيرغ: روندا',
    '🇸🇦' => 'بيرغ: سعودي عربستان',
    '🇸🇧' => 'بيرغ: سليمان ټاپوګان',
    '🇸🇨' => 'بيرغ: سیچیلیس',
    '🇸🇩' => 'بيرغ: سوډان',
    '🇸🇪' => 'بيرغ: سویډن',
    '🇸🇬' => 'بيرغ: سينگاپور',
    '🇸🇭' => 'بيرغ: سینټ هیلینا',
    '🇸🇮' => 'بيرغ: سلوانیا',
    '🇸🇯' => 'بيرغ: سوالبارد او جان ميين',
    '🇸🇰' => 'بيرغ: سلواکیا',
    '🇸🇱' => 'بيرغ: سییرا لیون',
    '🇸🇲' => 'بيرغ: سان مارینو',
    '🇸🇳' => 'بيرغ: سينيګال',
    '🇸🇴' => 'بيرغ: سومالیا',
    '🇸🇷' => 'بيرغ: سورینام',
    '🇸🇸' => 'بيرغ: سويلي سوډان',
    '🇸🇹' => 'بيرغ: ساو ټیم او پرنسیپ',
    '🇸🇻' => 'بيرغ: سالوېډور',
    '🇸🇽' => 'بيرغ: سینټ مارټین',
    '🇸🇾' => 'بيرغ: سوریه',
    '🇸🇿' => 'بيرغ: اسواټيني',
    '🇹🇦' => 'بيرغ: تریستان دا کنها',
    '🇹🇨' => 'بيرغ: د ترکیې او کیکاسو ټاپو',
    '🇹🇩' => 'بيرغ: چاډ',
    '🇹🇫' => 'بيرغ: د فرانسې جنوبي سیمې',
    '🇹🇬' => 'بيرغ: ټوګو',
    '🇹🇭' => 'بيرغ: تهايلنډ',
    '🇹🇯' => 'بيرغ: تاجکستان',
    '🇹🇰' => 'بيرغ: توکیلو',
    '🇹🇱' => 'بيرغ: تيمور-ليسټ',
    '🇹🇲' => 'بيرغ: تورکمنستان',
    '🇹🇳' => 'بيرغ: تونس',
    '🇹🇴' => 'بيرغ: تونګا',
    '🇹🇷' => 'بيرغ: ترکي',
    '🇹🇹' => 'بيرغ: ټرينيډاډ او ټوباګو',
    '🇹🇻' => 'بيرغ: توالیو',
    '🇹🇼' => 'بيرغ: تائيوان',
    '🇹🇿' => 'بيرغ: تنزانیا',
    '🇺🇦' => 'بيرغ: اوکراین',
    '🇺🇬' => 'بيرغ: یوګانډا',
    '🇺🇲' => 'بيرغ: د متحده ایالاتو ټاپوګان',
    '🇺🇳' => 'بيرغ: ملگري ملتونه',
    '🇺🇸' => 'بيرغ: متحده آيالات',
    '🇺🇾' => 'بيرغ: یوروګوی',
    '🇺🇿' => 'بيرغ: اوزبکستان',
    '🇻🇦' => 'بيرغ: واتیکان ښار',
    '🇻🇨' => 'بيرغ: سینټ ویسنټینټ او ګرینډینز',
    '🇻🇪' => 'بيرغ: وینزویلا',
    '🇻🇬' => 'بيرغ: بریتانوی ویګور ټاپوګان',
    '🇻🇮' => 'بيرغ: د متحده آيالاتو ورجن ټاپوګان',
    '🇻🇳' => 'بيرغ: وېتنام',
    '🇻🇺' => 'بيرغ: واناتو',
    '🇼🇫' => 'بيرغ: والیس او فوتونا',
    '🇼🇸' => 'بيرغ: ساماوا',
    '🇽🇰' => 'بيرغ: کوسوو',
    '🇾🇪' => 'بيرغ: یمن',
    '🇾🇹' => 'بيرغ: مايوټ',
    '🇿🇦' => 'بيرغ: سویلي افریقا',
    '🇿🇲' => 'بيرغ: زیمبیا',
    '🇿🇼' => 'بيرغ: زیمبابوی',
    '🔟' => 'کیکیپ: 10',
    '🏻' => 'د روڼ پوستکي ټون',
    '🏼' => 'غنمی-روښانه پوستکۍ',
    '🏽' => 'غنم رنګه',
    '🏾' => 'غنمی-تورنګه پوستکۍ',
    '🏿' => 'تور پوستکۍ',
    '😀' => 'خندېدلی مخ',
    '😃' => 'مسکېدلی مخ د غټو سترګو سره',
    '😄' => 'مسکېدلی مخ د مسکېدلی سترګو سره',
    '😁' => 'پړقېدونکی مخ دمسکېدلي سترګو سره',
    '😆' => 'مسکېدلی نيمکښ مخ',
    '😅' => 'مسکېدلی مخ د خولو سره',
    '🤣' => 'د خندا نه په فرش رغړېدل',
    '😂' => 'د خوشحالۍ د اوښکو مخ',
    '🙂' => 'لږ مسکېدلی مخ',
    '🙃' => 'نسکور مخ',
    '🫠' => 'خټکی مخ',
    '😉' => 'سترګه وهونکی مخ',
    '😊' => 'مسکېدونکی مخ د مسکېدونکې سترګو',
    '😇' => 'مسکېدونکی مخ د هالې سره',
    '🥰' => 'مسکېدونکی مخ د زړونو سره',
    '😍' => 'مسکېدونکی مخ د زړه سترګو سره',
    '🤩' => 'ستورو وهلی',
    '😘' => 'د الوزونکي مچولو مخ',
    '😗' => 'مچوونکی مخ',
    '☺' => 'مسکېدلی مخ',
    '😚' => 'مچوونکی مخ د بندو سترګو سره',
    '😙' => 'مچوونکی مخ د مسکېدلې سترګو سره',
    '🥲' => 'خندېدونکی مخ د اوښکو سره',
    '😋' => 'له خوړو خوند اخيستونکی مخ',
    '😛' => 'د ژبې مخ',
    '😜' => 'سترګه وهونکی مخ سره د ژبې',
    '🤪' => 'مسخره مخ',
    '😝' => 'د کږو سترګو مخ سره د ژبې',
    '🤑' => 'د پېسو د خولې مخ',
    '🤗' => 'غاړه ورکوونکی مخ',
    '🤭' => 'لاس په خوله مخ',
    '🫢' => 'د خلاص سترګو سره مخ او په خولې لاس',
    '🫣' => 'د راوتلی سترګو سره مخ',
    '🤫' => 'کرارونکی مخ',
    '🤔' => 'فکرمند مخ',
    '🫡' => 'سلام مخ',
    '🤐' => 'د ځنځير د خولې مخ',
    '🤨' => 'د اوچتو شويو وريځو مخ',
    '😐' => 'بې پلوه مخ',
    '😑' => 'بې تاثيره مخ',
    '😶' => 'پرته له خولې مخ',
    '🫥' => 'نخښه شوی لیکې مخ',
    '😏' => 'د ملنډو د خندا مخ',
    '😒' => 'پښيمانه مخ',
    '🙄' => 'د تاوهونکو سترګو مخ',
    '😬' => 'بړوسېدلی مخ',
    '🤥' => 'دروغ مخ',
    '🫨' => 'لړزونکې مخ',
    '😌' => 'خوشحاله مخ',
    '😔' => 'د فکر مخ',
    '😪' => 'خوبيولى مخ',
    '🤤' => 'د خندا وړ مخ',
    '😴' => 'د خوب مخ',
    '🫩' => 'د سترګو لاندې کڅوړې سره مخ',
    '😷' => 'د طبي ماسک سره مخ',
    '🤒' => 'سره ترمامیتر مخ',
    '🤕' => 'سره سر-بنداژ مخ',
    '🤢' => 'زړه بدوالی مخ',
    '🤮' => 'قی کوونکی مخ',
    '🤧' => 'پرنجېدونکی مخ',
    '🥵' => 'تود مخ',
    '🥶' => 'سوړ مخ',
    '🥴' => 'خندور مخ',
    '😵' => 'سرګرزنی مخ',
    '🤯' => 'چاودیدلی سر',
    '🤠' => 'د چروایي خولۍ مخ',
    '🥳' => 'پارټي کوونکی مخ',
    '🥸' => 'اصل ماهيت بدلوونکی مخ',
    '😎' => 'مسکېدونکی مخ د لمر دعينکو سره',
    '🤓' => 'بېګانه مخ',
    '🧐' => 'د يوې سترګې عينکې مخ',
    '😕' => 'وارخطا مخ',
    '🫤' => 'د مثلث خولې سره مخ',
    '😟' => 'اندېښمن مخ',
    '🙁' => 'د لږ تريو تندي مخ',
    '☹' => 'د تريو تندي مخ',
    '😮' => 'د بېرته خولې مخ',
    '😯' => 'د چپې خولې مخ',
    '😲' => 'حيران مخ',
    '😳' => 'سور او تود مخ',
    '🫪' => 'مسخ شوی مخ',
    '🥺' => 'وکالت کوونکی مخ',
    '🥹' => 'د اوښکو شاته نیولو مخ',
    '😦' => 'د تريو تندې او خلاصې خولې مخ',
    '😧' => 'کړوونکی مخ',
    '😨' => 'ډارونکی مخ',
    '😰' => 'اندېښمن مخ د خولې سره',
    '😥' => 'پښيمانه خو دمه مخ',
    '😢' => 'ژړېدونکی مخ',
    '😭' => 'لوړ غږ ژړا مخ',
    '😱' => 'په ډار کې ژړېدونکی مخ',
    '😖' => 'ګډوډ مخ',
    '😣' => 'سخت سری مخ',
    '😞' => 'مايوسه مخ',
    '😓' => 'غمجن مخ سره د خولې',
    '😩' => 'بېزاره مخ',
    '😫' => 'ستړي مخ',
    '🥱' => 'د ارږمي مخ',
    '😤' => 'د پوزې د پخار مخ',
    '😡' => 'د بوڅې شونډې مخ',
    '😠' => 'قهرجن مخ',
    '🤬' => 'په خوله کې د سمبول مخ',
    '😈' => 'مسکېدلی مخ د ښکرو سره',
    '👿' => 'قهرجن مخ د ښکرو سره',
    '💀' => 'کوپړۍ',
    '☠' => 'کوپړۍ او اووښتي هډوکي',
    '💩' => 'پو دا پخی',
    '🤡' => 'ټوکي مخ',
    '👹' => 'ديو',
    '👺' => 'پېری',
    '👻' => 'شيشکه',
    '👽' => 'پردیو',
    '👾' => 'ناشنا بلا',
    '🤖' => 'روبوټ',
    '😺' => 'د پيشو خندېدونکی مخ',
    '😸' => 'خندېدونکی پيشو د مسکېدونکي سترګو ستره',
    '😹' => 'پيشو د خوشالۍ د اوښکو سره',
    '😻' => 'مسکېدلی پيشو د زړه د سترګو سره',
    '😼' => 'پيشو د کږې خندا سره',
    '😽' => 'مچوونکی پيشو',
    '🙀' => 'ستړی پيشو',
    '😿' => 'ژړېدونکی پيشو',
    '😾' => 'ډېوه خولی پيشو',
    '🙈' => 'وګورئ بریښنايي بندر',
    '🙉' => 'اوریدل بریښنايي بندر',
    '🙊' => 'غږېدل بریښنايي بندر',
    '💌' => 'د مینې لیک',
    '💘' => 'تیر وهلۍ زړه',
    '💝' => 'تړلۍ زړه',
    '💖' => 'ځلاداره زړه',
    '💗' => 'غټیدونکې زړه',
    '💓' => 'ضربان زړه',
    '💞' => 'تړلۍ زړونه',
    '💕' => 'دوه زړونه',
    '💟' => 'سینګار زړه',
    '❣' => 'د زړه ندا',
    '💔' => 'مات زړه',
    '❤' => 'سور زړه',
    '🩷' => 'ګلابي زړه',
    '🧡' => 'نارنجی زړه',
    '💛' => 'ژیړ زړه',
    '💚' => 'شین زړه',
    '💙' => 'اسماني زړه',
    '🩵' => 'روښانه ودي زړه',
    '💜' => 'بنفش زړه',
    '🤎' => 'نسواري زړه',
    '🖤' => 'تور زړه',
    '🩶' => 'خړ زړه',
    '🤍' => 'سپين زړه',
    '💋' => 'مچو نښه',
    '💯' => 'سل ټکي',
    '💢' => 'د قهر نښه',
    '🫯' => 'د جګړې ورېځ',
    '💥' => 'تکړ',
    '💫' => 'سربدال',
    '💦' => 'خولو څاڅکی',
    '💨' => 'لري کول',
    '🕳' => 'سورۍ',
    '💬' => 'بیان پوګاڼه',
    '🗨' => 'د بیان چپه پوګاڼه',
    '🗯' => 'ښې خوا قهر پوګاڼه',
    '💭' => 'د خبرو پوقانه',
    '💤' => 'ززز',
    '👋' => 'لاس خورول',
    '🤚' => 'لاس شاخوا اچوتول',
    '🖐' => 'پنجه',
    '✋' => 'اوچت لاس',
    '🖖' => 'ښه راغلاست',
    '🫱' => 'ښي لاس',
    '🫲' => 'کیڼ لاس',
    '🫳' => 'ورغوې ښکته اړخ لاس',
    '🫴' => 'ورغوس پورته لاس',
    '🫷' => 'کیڼ اړخ ته لاس وهل',
    '🫸' => 'ښي خوا ته لاس وهل',
    '👌' => 'اوکی لاس',
    '🤌' => 'چونګ ګوتې',
    '🤏' => 'سکونډونکی لاس',
    '✌' => 'د بریا نښه',
    '🤞' => 'متقاطع ګوتي',
    '🫰' => 'د شاخص د ګوتو او ګوتو سره لاس تېر شو',
    '🤟' => 'د مینې اشاره',
    '🤘' => 'دوشاخه',
    '🤙' => 'زنګ وهلو اشاره',
    '👈' => 'په چپ لاس په شهادت ګوته اشاره کول',
    '👉' => 'په ښي لاس په شهادت ګوته اشاره کول',
    '👆' => 'شهادت ګوته لاس شاخوا پورته نیول',
    '🖕' => 'منځنې ګوته',
    '👇' => 'په شهادت ګوته لاس شاخوا لاندي اشاره کول',
    '☝' => 'شهادت ګوته پورته نیول',
    '🫵' => 'شاخص لیدونکی ته اشاره کول',
    '👍' => 'ډیر ښه',
    '👎' => 'ډیر بد',
    '✊' => 'موټۍ پورته نیول',
    '👊' => 'مخامخ موټۍ',
    '🤛' => 'چپ موټۍ',
    '🤜' => 'ښۍ موټۍ',
    '👏' => 'لاسونه پړکول',
    '🙌' => 'لاسونه اوچتول',
    '🫶' => 'زړه لاسونه',
    '👐' => 'خلاص لاسونه',
    '🤲' => 'لپه لاسونه',
    '🤝' => 'ستړې مشي',
    '🙏' => 'مننې لاسونه',
    '✍' => 'لیکونکې لاس',
    '💅' => 'نوکانو رنګ',
    '🤳' => 'سيلفي',
    '💪' => 'انعطافی مټې',
    '🦾' => 'ميخانيکي مټ',
    '🦿' => 'ميخانيکي پنډۍ',
    '🦵' => 'پنډۍ',
    '🦶' => 'پښه',
    '👂' => 'غوږ',
    '🦻' => 'غوږ د اورېدنې د مرستې سره',
    '👃' => 'پوزه',
    '🧠' => 'مغز',
    '🫀' => 'د زړه عضو',
    '🫁' => 'سګي',
    '🦷' => 'غاښ',
    '🦴' => 'هډوکی',
    '👀' => 'سترګي',
    '👁' => 'سترګه',
    '👅' => 'ژبه',
    '👄' => 'خوله',
    '🫦' => 'د ټي کولو شونډی',
    '👶' => 'کوچنی',
    '🧒' => 'ماشوم',
    '👦' => 'هلک',
    '👧' => 'نجلۍ',
    '🧑' => 'شخص',
    '👱' => 'شخص: د سرو ويښتانو',
    '👨' => 'سړی',
    '🧔' => 'سړی: ږيره',
    '👩' => 'ښځه',
    '🧓' => 'زوړ شخص',
    '👴' => 'زوړ سړی',
    '👵' => 'زړه ښځه',
    '🙍' => 'شخص وروځې راغورځوي',
    '🙎' => 'شخص تندی کوت کوي',
    '🙅' => 'شخص د نه اشاره کوي',
    '🙆' => 'شخص د او کی اشاره کوي',
    '💁' => 'شخص لاس ښايي',
    '🙋' => 'شخص لاس اوچتوي',
    '🧏' => 'کوڼ شخص',
    '🙇' => 'شخص ښکته کيږي',
    '🤦' => 'شخص مخ ته لاس نيولي',
    '🤷' => 'شخص اوږې پورته کوي',
    '👮' => 'د پولیسو افسر',
    '🕵' => 'کشفي',
    '💂' => 'ساتونکی',
    '🥷' => 'ننجا',
    '👷' => 'ساختماني کارکونکي',
    '🫅' => 'د تاج کس',
    '🤴' => 'شهزاده',
    '👸' => 'شهزادګی',
    '👳' => 'شخص لونګۍ په سر',
    '👲' => 'سړی د چینایی کیپ سره',
    '🧕' => 'ښځه د سرکوف سره',
    '🤵' => 'سړی په ټکسيډو کې',
    '👰' => 'ناوي په حجاب کې',
    '🤰' => 'امیندواره ښځه',
    '🫃' => 'امیندواره سړی',
    '🫄' => 'امیندواره کس',
    '🤱' => 'د سينې شيدې ورکول',
    '👼' => 'ماشوم فرښته',
    '🎅' => 'سانټا کلاز',
    '🤶' => 'ميرمن کلاز',
    '🦸' => 'لوي اتل',
    '🦹' => 'لوي ورانکاری',
    '🧙' => 'جادوګر',
    '🧚' => 'ښاپيرۍ',
    '🧛' => 'بلا',
    '🧜' => 'مرپرسن',
    '🧝' => 'ګوړا',
    '🧞' => 'جینی',
    '🧟' => 'زومبی',
    '🧌' => 'پیری',
    '🫈' => 'ویښتان لرونکی مخلوق',
    '💆' => 'شخص مالش ترلاسه کوي',
    '💇' => 'شخص پرېټ کوي',
    '🚶' => 'روان شخص',
    '🧍' => 'ولاړ شخص',
    '🧎' => 'شخص چوکېږي',
    '🏃' => 'شخص ځغلي',
    '💃' => 'ښځه نڅيږې',
    '🕺' => 'سړی نڅيږې',
    '🕴' => 'سړي په کالو کې اوچتيږي',
    '👯' => 'خلک د سويې غوږونو سره',
    '🧖' => 'شخص د پخار په خونه کې',
    '🧗' => 'شخص هسکېږي',
    '🤺' => 'شخص جنګېدل',
    '🏇' => 'آس ځغلي',
    '⛷' => 'سکیر',
    '🏂' => 'سنو بورډر',
    '🏌' => 'شخص ګالف کوي',
    '🏄' => 'شخص سرفنگ کوي',
    '🚣' => 'شخص کښتۍ چلوي',
    '🏊' => 'شخص لامبو وهي',
    '⛹' => 'شخص بال تمبوي',
    '🏋' => 'شخص وزن پورته کوي',
    '🚴' => 'شخص بايک چلوي',
    '🚵' => 'شخص په غر بايک چلوي',
    '🤸' => 'شخص کارټ ويلنګ کوي',
    '🤼' => 'خلک پهلواني کوي',
    '🤽' => 'شخص د اوبو پولو لوبه کوي',
    '🤾' => 'شخص د هنډبال لوبه کوي',
    '🤹' => 'شخص جادو کوي',
    '🧘' => 'شخص د پرلت په حالت کې',
    '🛀' => 'شخص غسل کوي',
    '🛌' => 'شخص په بستره کې',
    '👭' => 'دوه ښځو لاسونه نيولي',
    '👫' => 'سړی او ښځه لاس په لاس کې',
    '👬' => 'دوه سړو لاسونه نيولي',
    '💏' => 'مچول',
    '💑' => 'د زړه سره جوړه',
    '🗣' => 'د خبرو سر',
    '👤' => 'بې مخه سړی',
    '👥' => 'پرته له مخ سړي',
    '🫂' => 'خلک غاړۍ کيږې',
    '👪' => 'کورنۍ',
    '👣' => 'پښو نښي',
    '🫆' => 'د ګوتو نښان',
    '🦰' => 'سره ويښتان',
    '🦱' => 'لوپه ويښتان',
    '🦳' => 'سپين ويښتان',
    '🦲' => 'ګنجى',
    '🐵' => 'د بيزو مخ',
    '🐒' => 'بيزو',
    '🦍' => 'ګوریلا',
    '🦧' => 'وحشي سړى',
    '🐶' => 'سپی مخ',
    '🐕' => 'سپی',
    '🦮' => 'لارښوونی سپی',
    '🐩' => 'ببر سپی',
    '🐺' => 'لېوه',
    '🦊' => 'ګيدړه',
    '🦝' => 'رکون',
    '🐱' => 'پيشو مخ',
    '🐈' => 'پيشو',
    '🦁' => 'شېر',
    '🐯' => 'پړانګ مخ',
    '🐅' => 'پړانګ',
    '🐆' => 'چيته',
    '🐴' => 'د آس مخ',
    '🫎' => 'ګاوزه',
    '🫏' => 'خر',
    '🐎' => 'آس',
    '🦄' => 'يو ښکر لرونکی ژوي',
    '🦓' => 'زبرا',
    '🦌' => 'هوسۍ',
    '🦬' => 'بايسن',
    '🐮' => 'غوا مخ',
    '🐂' => 'غوایی',
    '🐃' => 'د اوبو مېښه',
    '🐄' => 'غوا',
    '🐷' => 'د سور مخ',
    '🐖' => 'سور',
    '🐗' => 'بور',
    '🐽' => 'سور پوزه',
    '🐏' => 'پسه',
    '🐑' => 'مېږه',
    '🐐' => 'وزه',
    '🐪' => 'اوښ',
    '🐫' => 'د دوه بوکو اوښ',
    '🦙' => 'لاما',
    '🦒' => 'زرافه',
    '🐘' => 'هاتي',
    '🦣' => 'لوی',
    '🦏' => 'ګرګدن',
    '🦛' => 'د اوبو آس',
    '🐭' => 'موږک مخ',
    '🐁' => 'موږک',
    '🐀' => 'خاڼی',
    '🐹' => 'موش خرما',
    '🐰' => 'سويه مخ',
    '🐇' => 'سويه',
    '🐿' => 'چپمنک',
    '🦫' => 'داوبو سپى',
    '🦔' => 'شکوڼ',
    '🦇' => 'ماښامی',
    '🐻' => 'اېږ',
    '🐨' => 'کوالا',
    '🐼' => 'پانډا',
    '🦥' => 'دجنوبي امريکا ژوى',
    '🦦' => 'د اوبو ژوى',
    '🦨' => 'يوډول امريکايي پيش پړانګ',
    '🦘' => 'کينګرو',
    '🦡' => 'ګورګښه',
    '🐾' => 'د پنجې نښانونه',
    '🦃' => 'پيل مرغ',
    '🐔' => 'چرګ',
    '🐓' => 'بانګي',
    '🐣' => 'چرګوړی راوتل',
    '🐤' => 'چرګوری',
    '🐥' => 'مخامخ چرګوری',
    '🐦' => 'مرغه',
    '🐧' => 'پینگوین',
    '🕊' => 'کوتره',
    '🦅' => 'عقاب',
    '🦆' => 'هيلۍ',
    '🦢' => 'قو',
    '🦉' => 'کونګ',
    '🦤' => 'ډوډو',
    '🪶' => 'وزرې',
    '🦩' => 'غزى، ډينګ',
    '🦚' => 'طاوس',
    '🦜' => 'طوطي',
    '🪽' => 'وزر',
    '🪿' => 'بته',
    '🐸' => 'ځينګښ',
    '🐊' => 'تمساح',
    '🐢' => 'شمشتۍ',
    '🦎' => 'لټکه',
    '🐍' => 'مار',
    '🐲' => 'ژدهار مخ',
    '🐉' => 'ژدهار',
    '🦕' => 'سوروپډ',
    '🦖' => 'ټي-ریکس',
    '🐳' => 'ګرداوی ويل',
    '🐋' => 'ويل',
    '🐬' => 'دولفين',
    '🫍' => 'اورکا',
    '🦭' => 'سيل',
    '🐟' => 'کب',
    '🐠' => 'ګرمسير کب',
    '🐡' => 'بلوکب',
    '🦈' => 'شارک',
    '🐙' => 'اکتوپس',
    '🐚' => 'ګول سيپۍ',
    '🪸' => 'مرجان',
    '🪼' => 'جیلی فش',
    '🦀' => 'سرطان',
    '🦞' => 'لوبسټر',
    '🦐' => 'چنګاښ',
    '🦑' => 'سکویډ',
    '🦪' => 'سمندري صدف',
    '🐌' => 'شاپېټی',
    '🦋' => 'کمبلۍ',
    '🐛' => 'سپږۍ',
    '🐜' => 'ميږی',
    '🐝' => 'د شاتو مچۍ',
    '🪲' => 'خزدکه',
    '🐞' => 'پالپونکه',
    '🦗' => 'حشره',
    '🪳' => 'ګړندى',
    '🕷' => 'غڼې',
    '🕸' => 'د غڼې ويب',
    '🦂' => 'شوبلکه',
    '🦟' => 'غوماشه',
    '🪰' => 'مچ',
    '🪱' => 'چينجی',
    '🦠' => 'مايکروب',
    '💐' => 'دګلوګېډى',
    '🌸' => 'د سرکۍ ګل',
    '💮' => 'سپين ګل',
    '🪷' => 'نيلو فر',
    '🏵' => 'وريښمين ګلى',
    '🌹' => 'ګلاب',
    '🥀' => 'مړاوي ګل',
    '🌺' => 'هميش ګل',
    '🌻' => 'لمر ګلی',
    '🌼' => 'غوزه',
    '🌷' => 'غاټول',
    '🪻' => 'هایسنت',
    '🌱' => 'تخم',
    '🪴' => 'د ننګرۍ بوټی',
    '🌲' => 'تل زرغون ونه',
    '🌳' => 'غورځونکي ونې',
    '🌴' => 'د خجورې ونه',
    '🌵' => 'کیکټس',
    '🌾' => 'شولې',
    '🌿' => 'بوټی',
    '☘' => 'شفتل',
    '🍀' => 'د څلورو پاڼو شفتل',
    '🍁' => 'میپل پاڼی',
    '🍂' => 'غورځېدلې پاڼه',
    '🍃' => 'په باد کې خوزېدونکې پاڼه',
    '🪹' => 'تش ځاله',
    '🪺' => 'د هګو سره ځاله',
    '🍄' => 'مرخېړى',
    '🪾' => 'بې پاڼې ونه',
    '🍇' => 'انګور',
    '🍈' => 'خټکى',
    '🍉' => 'هندواڼه',
    '🍊' => 'سنتره',
    '🍋' => 'ليمو',
    '🍌' => 'کيله',
    '🍍' => 'انناس',
    '🥭' => 'آم',
    '🍎' => 'سره مڼه',
    '🍏' => 'شنه مڼه',
    '🍐' => 'ناشپاټي',
    '🍑' => 'شفتالو',
    '🍒' => 'سرکۍ',
    '🍓' => 'ځمکنی توت',
    '🫐' => 'بلو بيريز',
    '🥝' => 'کیوی میوه',
    '🍅' => 'رومي',
    '🫒' => 'زيتون',
    '🥥' => 'کو پره',
    '🥑' => 'پاپيته',
    '🍆' => 'توربانجان',
    '🥔' => 'آلو',
    '🥕' => 'زردکه',
    '🌽' => 'د جوار وږی',
    '🌶' => 'ګرم مرچ',
    '🫑' => 'شمله مرچ',
    '🥒' => 'بادرنګ',
    '🥬' => 'سلاد',
    '🥦' => 'ګوپې',
    '🧄' => 'ووږه',
    '🧅' => 'پياز',
    '🥜' => 'مونګ پلي',
    '🫘' => 'لوبيا',
    '🌰' => 'خورماني',
    '🫚' => 'د ادرک ريښه',
    '🫛' => 'د نخود پوزه',
    '🫜' => 'ریښی سبزی',
    '🍞' => 'ډوډۍ',
    '🥐' => 'کلچه',
    '🥖' => 'بګیټ ډوډۍ',
    '🫓' => 'نرۍ ډوډۍ',
    '🥨' => 'تروه کلچه',
    '🥯' => 'يو ډول کلچه',
    '🥞' => 'پینکیکونه',
    '🧇' => 'کولچه',
    '🧀' => 'د پنیر پیښه',
    '🍖' => 'د هډوکي غوښه',
    '🍗' => 'د چرګانو پښه',
    '🥩' => 'د غوښې ټکړه',
    '🥓' => 'د خنځير غوښه',
    '🍔' => 'هامبرګر',
    '🍟' => 'چپس',
    '🍕' => 'پیزا',
    '🌭' => 'هاټ ډاګ',
    '🥪' => 'سانډویچ',
    '🌮' => 'ټکو',
    '🌯' => 'بريټو',
    '🫔' => 'تمالا',
    '🥙' => 'خړوب شوي ډک',
    '🧆' => 'فلافل',
    '🥚' => 'هګۍ',
    '🍳' => 'پخلي',
    '🥘' => 'د خواړو سطحي هرکاره',
    '🍲' => 'د خوړو لوښي',
    '🫕' => 'ارکاره',
    '🥣' => 'پياله د کاچوغې سره',
    '🥗' => 'شنه سلاد',
    '🍿' => 'د جوارونينې',
    '🧈' => 'کوچ',
    '🧂' => 'مالګه',
    '🥫' => 'بند کړل شوي خواړه',
    '🍱' => 'د بینټو بکس',
    '🍘' => 'د وريجو کريکر',
    '🍙' => 'د وريجو بال',
    '🍚' => 'پخې وريجې',
    '🍛' => 'کري وریجی',
    '🍜' => 'بړاس کوونکې پياله',
    '🍝' => 'مکروني',
    '🍠' => 'سور شوی خوږ آلو',
    '🍢' => 'اوډین',
    '🍣' => 'سوشي',
    '🍤' => 'سور شوی چنګاښ',
    '🍥' => 'مچھلی کیک',
    '🥮' => 'سپوږمۍ کيک',
    '🍡' => 'ډانګو',
    '🥟' => 'غونډاری',
    '🥠' => 'د بخت بسکوټ',
    '🥡' => 'وباسل بکس',
    '🍦' => 'نرم آيس کریم',
    '🍧' => 'پالوده',
    '🍨' => 'آیس کریم',
    '🍩' => 'ډونټ',
    '🍪' => 'بسکوټ',
    '🎂' => 'د زېږېدنې کیک',
    '🍰' => 'لنډ کیک',
    '🧁' => 'کپ کيک',
    '🥧' => 'پائی',
    '🍫' => 'د چاکلیټ بار',
    '🍬' => 'پتاسه',
    '🍭' => 'لالیپپ',
    '🍮' => 'فرني',
    '🍯' => 'د شاتو لوښی',
    '🍼' => 'د ماشوم بوتل',
    '🥛' => 'د شيدو ګيلاس',
    '☕' => 'ګرم څښاک',
    '🫖' => 'د چای لوښی',
    '🍵' => 'بې لاستي پياله',
    '🍶' => 'سیک',
    '🍾' => 'د پوپنګ کارک بوتل',
    '🍷' => 'د شرابو ګلاس',
    '🍸' => 'د کاکټیل ګلاس',
    '🍹' => 'ګرمسېر څښاک',
    '🍺' => 'بير پياله',
    '🍻' => 'د بير شړنګېدونکی غټ ګيلاس',
    '🥂' => 'شړنګېدونکی غټ ګيلاس',
    '🥃' => 'جام ګلاس',
    '🫗' => 'د مایع اچول',
    '🥤' => 'پياله د نيچې سره',
    '🧋' => 'ببل چای',
    '🧃' => 'د څښاک دبلی',
    '🧉' => 'يو ډول څښاک',
    '🧊' => 'کنګل',
    '🥢' => 'چوپسټيکس',
    '🍽' => 'ښاخۍ او چاقو د پليټ سره',
    '🍴' => 'ښاخۍ او چاقو',
    '🥄' => 'کاشوغه',
    '🔪' => 'د پخلنځی چاقو',
    '🫙' => 'مرتبان',
    '🏺' => 'امفورا',
    '🌍' => 'نړۍ ښيي اروپا-افریقا',
    '🌎' => 'نړۍ ښيي امریکا',
    '🌏' => 'نړۍ ښيي آسیا - آسټرالیا',
    '🌐' => 'نړۍ د نصف لنهارليکې سره',
    '🗺' => 'د نړۍ نقشه',
    '🗾' => 'د جاپان نقشه',
    '🧭' => 'قطب نما',
    '🏔' => 'د واورې ډک غر',
    '⛰' => 'غر',
    '🛘' => 'د ځمکې ښویدنه',
    '🌋' => 'آتش فشان غر',
    '🗻' => 'د فوجي غر',
    '🏕' => 'کیمپنګ',
    '🏖' => 'ساحل د چتری سره',
    '🏜' => 'دښته',
    '🏝' => 'دښتې ټاپو',
    '🏞' => 'ملي پارک',
    '🏟' => 'لوبغالی',
    '🏛' => 'کلاسیکي ودانۍ',
    '🏗' => 'وداني رغول',
    '🧱' => 'خښته',
    '🪨' => 'ګټ',
    '🪵' => 'لرګی',
    '🛖' => 'کوډله',
    '🏘' => 'کورونه',
    '🏚' => 'متروک کور',
    '🏠' => 'کور',
    '🏡' => 'کور د باغ سره',
    '🏢' => 'دفتري وداني',
    '🏣' => 'د جاپان پوستي دفتر',
    '🏤' => 'پوستي دفتر',
    '🏥' => 'روغتون',
    '🏦' => 'بانک',
    '🏨' => 'هوټل',
    '🏩' => 'د مينې هوټل',
    '🏪' => 'د آسانتيا پلورنځی',
    '🏫' => 'ښوونځی',
    '🏬' => 'د څانګې پلورنځی',
    '🏭' => 'فابریکه',
    '🏯' => 'جاپاني کلا',
    '🏰' => 'کلا',
    '💒' => 'واده',
    '🗼' => 'د توکیو ټاور',
    '🗽' => 'د خپلواکۍ مجسمه',
    '⛪' => 'کلیسا',
    '🕌' => 'جومات',
    '🛕' => 'د هندوانو معبد',
    '🕍' => 'د يهودانو جومات',
    '⛩' => 'شینټو مزار',
    '🕋' => 'کعبه',
    '⛲' => 'مورينه',
    '⛺' => 'خيمه',
    '🌁' => 'دهند',
    '🌃' => 'شپه د ستورو سره',
    '🏙' => 'د ښار منظره',
    '🌄' => 'په غرونو کې لمر',
    '🌅' => 'لمرخاته',
    '🌆' => 'د ښار منظره په ماښام کې',
    '🌇' => 'لمر لوېده',
    '🌉' => 'په شپه کې پل',
    '♨' => 'تودې چينې',
    '🎠' => 'کارطوس آس',
    '🛝' => 'د لوبې ډګر سلایډ',
    '🎡' => 'د فيرس پايه',
    '🎢' => 'رولر کوستر',
    '💈' => 'د نايي نښه',
    '🎪' => 'د سرکس خیمه',
    '🚂' => 'لوکوموتيو',
    '🚃' => 'د اورګاډي موټر',
    '🚄' => 'زیات سرعت ريل',
    '🚅' => 'بلت ريل',
    '🚆' => 'اور ګاډی',
    '🚇' => 'میترو',
    '🚈' => 'کوچنی اور کاډی',
    '🚉' => 'تمځای',
    '🚊' => 'ټرام',
    '🚝' => 'مونوریل',
    '🚞' => 'د غره پټلۍ',
    '🚋' => 'ټرام موټر',
    '🚌' => 'بس',
    '🚍' => 'راتلونکی بس',
    '🚎' => 'ټرالي بس',
    '🚐' => 'کوچنی بس',
    '🚑' => 'امبولانس',
    '🚒' => 'د اور وژونکی انجن',
    '🚓' => 'دپولیس موټر',
    '🚔' => 'راتلونکی پولیس موټر',
    '🚕' => 'ټیکسي',
    '🚖' => 'راتلونکی ټیکسي',
    '🚗' => 'ګاډي',
    '🚘' => 'راتلونکی ګاډي',
    '🚙' => 'د سپورټ د استعمال موټر',
    '🛻' => 'پک اپ',
    '🚚' => 'د وړاندې کولو لارۍ',
    '🚛' => 'دوه سرويسه',
    '🚜' => 'ټراکټور',
    '🏎' => 'ریسنگ موټر',
    '🏍' => 'موټرسیکل',
    '🛵' => 'موټر سکوټر',
    '🦽' => 'د معلولينو لاسي چوکۍ',
    '🦼' => 'د معلولينو موټري چوکۍ',
    '🛺' => 'آټو رکشه',
    '🚲' => 'بايسکل',
    '🛴' => 'کک سکوټر',
    '🛹' => 'سکيټبورډ',
    '🛼' => 'رولر سکيټ',
    '🚏' => 'د بس تم ځای',
    '🛣' => 'لوی سړک',
    '🛤' => 'د اورګاډي پټلۍ',
    '🛢' => 'د تیلو ډرم',
    '⛽' => 'د سونګ پمپ',
    '🛞' => 'څرخ',
    '🚨' => 'د پولیسو موټر رڼا',
    '🚥' => 'افقی ټرافيکي رڼا',
    '🚦' => 'عمودی ټرافيکي رڼا',
    '🛑' => 'تم ځای نښانې',
    '🚧' => 'د جوړولو',
    '⚓' => 'لنګر',
    '🛟' => 'زنګ وهونکی',
    '⛵' => 'سیلبوټ',
    '🛶' => 'وړه بېړۍ',
    '🚤' => 'چټک کښتۍ',
    '🛳' => 'مسافر آبګوټ',
    '⛴' => 'بېړۍ',
    '🛥' => 'موټر کشتۍ',
    '🚢' => 'بيړۍ',
    '✈' => 'هوایی الوتکه',
    '🛩' => 'کوچنی هوایی الوتکه',
    '🛫' => 'د هوايي الوتکې روانېدنه',
    '🛬' => 'هوایی الوتکه راتګ',
    '🪂' => 'پاراشوټ',
    '💺' => 'څوکۍ',
    '🚁' => 'چورلکه',
    '🚟' => 'هوايي اور ګاډی',
    '🚠' => 'د غرونو کیبل وي',
    '🚡' => 'هوای ټرام وی',
    '🛰' => 'سپوږمکۍ',
    '🚀' => 'راکټ',
    '🛸' => 'الوتونکی طشتری',
    '🛎' => 'لاسي زنګ',
    '🧳' => 'سامان',
    '⌛' => 'ګړۍ لوښې ترسره',
    '⏳' => 'کړۍ لوښی ندی ترسره',
    '⌚' => 'ګړۍ',
    '⏰' => 'زنګ وهونکې ګړۍ',
    '⏱' => 'سپورټي ګړۍ',
    '⏲' => 'ټايمر ساعته',
    '🕰' => 'مينټل پيس ساعت',
    '🕛' => 'دولس بجې',
    '🕧' => 'دولس نيمې',
    '🕐' => 'یوه بجې',
    '🕜' => 'يوه نيمه',
    '🕑' => 'دوه بجې',
    '🕝' => 'دوه نيمې',
    '🕒' => 'درې بجې',
    '🕞' => 'درې نيمې',
    '🕓' => 'څلور بجې',
    '🕟' => 'څلور نيمې',
    '🕔' => 'پنځه بجې',
    '🕠' => 'پنځه نيمې',
    '🕕' => 'شپږ بجې',
    '🕡' => 'شپږ نيمې',
    '🕖' => 'اووه بجې',
    '🕢' => 'اووه نيمې',
    '🕗' => 'اته بجې',
    '🕣' => 'اته نيمې',
    '🕘' => 'نهه بجې',
    '🕤' => 'نهه نيمې',
    '🕙' => 'لس بجې',
    '🕥' => 'لس نيمې',
    '🕚' => 'یولس بجې',
    '🕦' => 'يوولس نيمې',
    '🌑' => 'نوې سپوږمۍ',
    '🌒' => 'رغېدونکې هلال سپوږمۍ',
    '🌓' => 'د لومړۍ ربعې سپوږمۍ',
    '🌔' => 'رغېدونکې شاټوغې سپوږمۍ',
    '🌕' => 'بشپړه سپوږمۍ',
    '🌖' => 'کمېدونکې شاټوغې سپوږمۍ',
    '🌗' => 'د ورستۍ ربع سپوږمۍ',
    '🌘' => 'کمېدونکې هلال سپوږمۍ',
    '🌙' => 'هلال سپوږمۍ',
    '🌚' => 'نوې سپوږمۍ مخ',
    '🌛' => 'په لومړۍ ربع سپوږمۍ مخ',
    '🌜' => 'د ورستۍ ربع د سپوږمۍ مخ',
    '🌡' => 'ترمامیتر',
    '☀' => 'لمر',
    '🌝' => 'د بشپړه سپوږمۍ مخ',
    '🌞' => 'لمر د مخ سره',
    '🪐' => 'کړۍ داره سپوږمکۍ',
    '⭐' => 'ستوری',
    '🌟' => 'پړقېدونکی ستوری',
    '🌠' => 'د ډزو ستوري',
    '🌌' => 'کهکشان',
    '☁' => 'وريځ',
    '⛅' => 'لمر د ريځې شا ته',
    '⛈' => 'وريځ د باران او پړقا سره',
    '🌤' => 'لمر د کوچنۍ وريځې شا ته',
    '🌥' => 'لمر د لوی وريځې شا ته',
    '🌦' => 'لمر د باران د وريځ شا ته',
    '🌧' => 'ورېځ سره باران',
    '🌨' => 'ورېځ سره واوره',
    '🌩' => 'وريځ د پړقا سره',
    '🌪' => 'بړبوکۍ',
    '🌫' => 'خوپڼه',
    '🌬' => 'د باد مخ',
    '🌀' => 'سایکلون',
    '🌈' => 'شنه زرغونه',
    '🌂' => 'تړل شوي چترۍ',
    '☂' => 'چترۍ',
    '☔' => 'چترۍ سره د باران څاڅکي',
    '⛱' => 'چترۍ پر ځمکه',
    '⚡' => 'لوړ ولیټیج',
    '❄' => 'سنوفليک',
    '☃' => 'د واورې سړی',
    '⛄' => 'د واورې ښځه پرته له واورې',
    '☄' => 'لکۍ دار ستوری',
    '🔥' => 'اور',
    '💧' => 'اوښکې',
    '🌊' => 'د اوبو څپه',
    '🎃' => 'د کدو لالټين',
    '🎄' => 'د کريسمس ونه',
    '🎆' => 'اورلوبې',
    '🎇' => 'الماس',
    '🧨' => 'پټاکۍ',
    '✨' => 'پړقېدونکي',
    '🎈' => 'پوکاڼۍ',
    '🎉' => 'ګوند پاپر',
    '🎊' => 'کنفټی بال',
    '🎋' => 'د تناباتا ونې',
    '🎍' => 'پائن سجاې',
    '🎎' => 'جاپاني ګوډاګی',
    '🎏' => 'کارپ سټریمر',
    '🎐' => 'د باد زنګ',
    '🎑' => 'د سپوږمۍ لیدنې مراسم',
    '🧧' => 'سره لفافه',
    '🎀' => 'پټۍ',
    '🎁' => 'بسته بندي شوې ډالۍ',
    '🎗' => 'د یادونې پټۍ',
    '🎟' => 'د داخلې ټکټونه',
    '🎫' => 'ټکټ',
    '🎖' => 'پوځي مډال',
    '🏆' => 'مډال',
    '🏅' => 'سپورتي مډال',
    '🥇' => 'د لومړي مقام مډال',
    '🥈' => 'د دوهم مقام مډال',
    '🥉' => 'د دریم مقام مډال',
    '⚽' => 'د فوټبال توپ',
    '⚾' => 'بیسبال',
    '🥎' => 'نرم بال',
    '🏀' => 'باسکیټبال',
    '🏐' => 'والیبال',
    '🏈' => 'امریکايي فوټبال',
    '🏉' => 'د رګبي فوټبال',
    '🎾' => 'ټنیس',
    '🥏' => 'الوتونکی ککوړی',
    '🎳' => 'بالنګ',
    '🏏' => 'د کرکټ لوبه',
    '🏑' => 'د میدان هاکي',
    '🏒' => 'د یخ هاکي',
    '🥍' => 'لوکروس',
    '🏓' => 'پنګ پونګ',
    '🏸' => 'بیډمنټن',
    '🥊' => 'د سوک وهلو دستکشه',
    '🥋' => 'رزمي یونیفورم',
    '🥅' => 'د ګول وهلو جال',
    '⛳' => 'په سوري کې بیرغ',
    '⛸' => 'آیس سکیټ',
    '🎣' => 'د کب نیوني خاده',
    '🤿' => 'د غوټې وهلو څېره',
    '🎽' => 'د منډې وهلو کمیس',
    '🎿' => 'سکي',
    '🛷' => 'ښويېدونی',
    '🥌' => 'د کورلینګ ډبره',
    '🎯' => 'مستقیم ویشتنه',
    '🪀' => 'يو يو',
    '🪁' => 'پتنګ',
    '🔫' => 'طمانچه',
    '🎱' => 'د پول ۸ توپ',
    '🔮' => 'کرسټال بال',
    '🪄' => 'د جادو لښته',
    '🎮' => 'ویډیو لوبې',
    '🕹' => 'جوی سټیک',
    '🎰' => 'سلاټ ماشين',
    '🎲' => 'د کمسايي لوبه',
    '🧩' => 'د معما ټکړه',
    '🧸' => 'ايږ',
    '🪅' => 'پناتا',
    '🪩' => 'ښیښې بال',
    '🪆' => 'ځاله کوونکې نانځکه',
    '♠' => 'د قرې پته',
    '♥' => 'د تپان پته',
    '♦' => 'د الماس پته',
    '♣' => 'د کلب پته',
    '♟' => 'د سترنج ګوټک',
    '🃏' => 'جوکر',
    '🀄' => 'د ماهجونګ سور خامار',
    '🎴' => 'د ګل تاش',
    '🎭' => 'عملي فنون',
    '🖼' => 'چوکاټ شوی انځور',
    '🎨' => 'فنکار تخته',
    '🧵' => 'تار',
    '🪡' => 'د ګنډلو ستن',
    '🧶' => 'مزی',
    '🪢' => 'غوټه',
    '👓' => 'عینکې',
    '🕶' => 'لمر عینکې',
    '🥽' => 'عينکې',
    '🥼' => 'د لابراتور کرتۍ',
    '🦺' => 'حفاظتي ملابند',
    '👔' => 'نیکټائي',
    '👕' => 'ټی شرټ',
    '👖' => 'کاوبای پتلون',
    '🧣' => 'غاړې دسمال',
    '🧤' => 'دستکشی',
    '🧥' => 'جامپر',
    '🧦' => 'جرابي',
    '👗' => 'کمیس',
    '👘' => 'کیمینو',
    '🥻' => 'ساړې',
    '🩱' => 'يو ستوی د لامبو سوټ',
    '🩲' => 'لنډ جانګی',
    '🩳' => 'جانګی',
    '👙' => 'بکینی',
    '👚' => 'ښځینه لباس',
    '🪭' => 'د لاس تړلی پکه',
    '👛' => 'پرس',
    '👜' => 'دسکول',
    '👝' => 'کڅوړي بکسه',
    '🛍' => 'خریدارۍ بکسه',
    '🎒' => 'د مکتب بکسه',
    '🩴' => 'واهه چپلې',
    '👞' => 'نارینه بوټان',
    '👟' => 'د منډي بوټان',
    '🥾' => 'په غره د ختلو بوټ',
    '🥿' => 'هوار پېزار',
    '👠' => 'کوری-بلند بوټان',
    '👡' => 'ښځینه سینډل',
    '🩰' => 'د نڅا پېزار',
    '👢' => 'ښځینه موزي',
    '🪮' => 'ویښتان غوره کول',
    '👑' => 'تاج',
    '👒' => 'ښځینه خولۍ',
    '🎩' => 'تندی خولۍ',
    '🎓' => 'فراغت خولۍ',
    '🧢' => 'پيکداره خولۍ',
    '🪖' => 'پوځي خولۍ',
    '⛑' => 'د ژغورنې کارمندانو هیلمټ',
    '📿' => 'تسبیح',
    '💄' => 'لب شیرین',
    '💍' => 'ګوتې',
    '💎' => 'قیمتي ډبره',
    '🔇' => 'ګونګ شوی سپیکر',
    '🔈' => 'د سپیکر ټیټ غږ',
    '🔉' => 'د سپیکر منځنی غږ',
    '🔊' => 'د سپیکر لوړ غږ',
    '📢' => 'لاوډسپیکر',
    '📣' => 'میګافون',
    '📯' => 'پستي هارن',
    '🔔' => 'زنګ',
    '🔕' => 'سلش لرونکی زنګ',
    '🎼' => 'د موسیقۍ نمرې',
    '🎵' => 'د موسیقۍ یادښت',
    '🎶' => 'د موسیقۍ ساز',
    '🎙' => 'د سټوډیو مایکروفون',
    '🎚' => 'لیول سلایډر',
    '🎛' => 'د کنټرول غوټې',
    '🎤' => 'میکروفون',
    '🎧' => 'غوږۍ ګوشکه',
    '📻' => 'راډیو',
    '🎷' => 'ساکسفون',
    '🎺' => 'سورنی',
    '🪊' => 'ټرومبون',
    '🪗' => 'اکورديون',
    '🎸' => 'ګیتار',
    '🎹' => 'د موسیقي کیبورډ',
    '🎻' => 'ويلون',
    '🪕' => 'بينجو',
    '🥁' => 'ډول',
    '🪘' => 'اوږود ډول',
    '🪇' => 'ماراکاس',
    '🪈' => 'بانسري',
    '🪉' => 'هارپ',
    '📱' => 'ګرځنده ټېلیفون',
    '📲' => 'غشی لرونکی ګرځنده ټېلیفون',
    '☎' => 'ټیلیفون',
    '📞' => 'د ټیلیفون رسیور',
    '📟' => 'پیجر',
    '📠' => 'د فکس ماشین',
    '🔋' => 'بیټري',
    '🪫' => 'ټیټه بیټرۍ',
    '🔌' => 'برېښنايي پلګ',
    '💻' => 'لپټاپ کمپیوټر',
    '🖥' => 'ډیسکټاپ کمپیوټر',
    '🖨' => 'پرنټر',
    '⌨' => 'کیبورډ',
    '🖱' => 'د کمپیوټر موږک',
    '🖲' => 'ټریکبال',
    '💽' => 'د کمپیوټر ډیسک',
    '💾' => 'فلاپي ډیسک',
    '💿' => 'آپتيکي ډسک',
    '📀' => 'ډي وي ډي',
    '🧮' => 'ابيکس',
    '🎥' => 'د فلم کامره',
    '🎞' => 'د فلم چوکاټ',
    '📽' => 'د فلم پروجیکټر',
    '🎬' => 'د کلیپر تخته',
    '📺' => 'تلویزیون',
    '📷' => 'کامره',
    '📸' => 'فلش لرونکې کامره',
    '📹' => 'ویډیو کامره',
    '📼' => 'ویډیو کیسټ',
    '🔍' => 'لويوونکې ښيښه چپ اړخ ته کږه',
    '🔎' => 'ښي لور ته ذره بین لرونکې ښیښه',
    '🕯' => 'شمع',
    '💡' => 'د رڼا بلب',
    '🔦' => 'لاسي څراغ',
    '🏮' => 'د سور کاغذ لاټين',
    '🪔' => 'ډيوه څراغ',
    '📔' => 'د ښايسته جلد کاپي',
    '📕' => 'بند کتاب',
    '📖' => 'خلاص کتاب',
    '📗' => 'شنه کتاب',
    '📘' => 'آسماني رنګ کتاب',
    '📙' => 'نارنجي کتاب',
    '📚' => 'کتابونه',
    '📓' => 'کاپي',
    '📒' => 'ليجر',
    '📃' => 'پاڼه د تاو سره',
    '📜' => 'اڼه اړول',
    '📄' => 'پاڼه سره مخ کړي',
    '📰' => 'ورځپاڼې',
    '🗞' => 'تړل شوی ورځپاڼې',
    '📑' => 'د کتاب نښې ټيبز',
    '🔖' => 'د کتاب نښه',
    '🏷' => 'لیبل',
    '🪙' => 'سکه',
    '💰' => 'د پيسو کڅوړه',
    '🪎' => 'د خزانې صندوق',
    '💴' => 'ين بانک نوټ',
    '💵' => 'ډالر بانک نوټ',
    '💶' => 'يورو بانک نوټ',
    '💷' => 'پونډه بانک نوټ',
    '💸' => 'پیسې د وزرونو',
    '💳' => 'کریډیټ کارت',
    '🧾' => 'رسيد',
    '💹' => 'چارټ د یین سره زیاتیږي',
    '✉' => 'لفافه',
    '📧' => 'برېښناليک',
    '📨' => 'راتلونکی لفافه',
    '📩' => 'لفافه د غشي سره',
    '📤' => 'آوټ باکس ټری',
    '📥' => 'ان باکس ټری',
    '📦' => 'بنډل',
    '📫' => 'تړل شوی میل باکس د هسک بېرغ سره',
    '📪' => 'بند ميل باکس د د ښکته بېرغ سره',
    '📬' => 'خلاص ميل باکس د هسک بېرغ سره',
    '📭' => 'خلاص میل باکس د ښکته بېرغ سره',
    '📮' => 'پوسته بکسه',
    '🗳' => 'د ووټونو بوکسه د ووټ سره',
    '✏' => 'پنسل',
    '✒' => 'تور نب',
    '🖋' => 'د فونټين قلم',
    '🖊' => 'قلم',
    '🖌' => 'د رنګونې برش',
    '🖍' => 'کريان',
    '📝' => 'د يادښت کتابچه',
    '💼' => 'بسته',
    '📁' => 'دوتنې پوښۍ',
    '📂' => 'دوتنه پوښۍ خلاص',
    '🗂' => 'کارت جدول وېشونکي',
    '📅' => 'جنتري',
    '📆' => 'د شلولو جنتري',
    '🗒' => 'حلزوني يادښت پېډ',
    '🗓' => 'حلزوني جنتري',
    '📇' => 'کارت جدول',
    '📈' => 'چارټ زیاتوالی',
    '📉' => 'چارټ کمېدونکی',
    '📊' => 'بار چارټ',
    '📋' => 'کلیپ بورډ',
    '📌' => 'ګل مېخ',
    '📍' => 'ګول ګل مېخ',
    '📎' => 'کاغذ نيوونى',
    '🖇' => 'تړل شوي کاغذ نيووني',
    '📏' => 'سيدها خطکش',
    '📐' => 'درې کنجه خطکش',
    '✂' => 'بياتي',
    '🗃' => 'کارت دوتنې بکس',
    '🗄' => 'د دوتنې کابينټ',
    '🗑' => 'د ضایع ټوکر',
    '🔒' => 'کلپ شوی',
    '🔓' => 'خلاص شوی',
    '🔏' => 'د قلم سره تړل شوی',
    '🔐' => 'د کیلي سره تړل شوی',
    '🔑' => 'کیلي',
    '🗝' => 'زاړه کیلي',
    '🔨' => 'څټک',
    '🪓' => 'تبر',
    '⛏' => 'دوه سري کلنګ',
    '⚒' => 'څټک او کلنګ',
    '🛠' => 'څټک او رنچ',
    '🗡' => 'خنجر',
    '⚔' => 'اوړېدلې تورې',
    '💣' => 'بم',
    '🪃' => 'کږه لکړه',
    '🏹' => 'غشی او لينده',
    '🛡' => 'ډال',
    '🪚' => 'د نجارۍ اره',
    '🔧' => 'رنچ',
    '🪛' => 'پيچ کش',
    '🔩' => 'نټ او بولټ',
    '⚙' => 'ګيرارۍ',
    '🗜' => 'رکاب',
    '⚖' => 'متوازن تله',
    '🦯' => 'د معلولينو همسا',
    '🔗' => 'ربط',
    '⛓' => 'زنځيرونه',
    '🪝' => 'کنډه',
    '🧰' => 'د اوزارو بوکسه',
    '🧲' => 'مقناطيس',
    '🪜' => 'زينه',
    '🪏' => 'بیلچه',
    '⚗' => 'اليمبک',
    '🧪' => 'ټسټ تيوب',
    '🧫' => 'پيټري ډش',
    '🧬' => 'ډي اين ای',
    '🔬' => 'مایکروسکوپ',
    '🔭' => 'ټیلي سکوپ',
    '📡' => 'د سپوږمکۍ انټينا',
    '💉' => 'سرنج',
    '🩸' => 'د وينې څاڅکی',
    '💊' => 'ګولۍ',
    '🩹' => 'نښلېدونکې پټۍ',
    '🩼' => 'چاره',
    '🩺' => 'ستېتوسکوپ',
    '🩻' => 'اکسرې',
    '🚪' => 'دروازه',
    '🛗' => 'لوړګر',
    '🪞' => 'هنداره',
    '🪟' => 'کړکۍ',
    '🛏' => 'بستره',
    '🛋' => 'سوفه او څراغ',
    '🪑' => 'چوکۍ',
    '🚽' => 'تشناب',
    '🪠' => 'پلنجر',
    '🚿' => 'شاور',
    '🛁' => 'د لامبلو ټب',
    '🪤' => 'لټ',
    '🪒' => 'چاړه (د ږيرې)',
    '🧴' => 'د مرهم بوتل',
    '🧷' => 'حفاظتي پن',
    '🧹' => 'جارو',
    '🧺' => 'ټوکرۍ',
    '🧻' => 'د کاغذ بنډل',
    '🪣' => 'ستل',
    '🧼' => 'صابن',
    '🫧' => 'پوکڼۍ',
    '🪥' => 'د غاښو برش',
    '🧽' => 'اسفنج',
    '🧯' => 'اور وژونکی',
    '🛒' => 'د سودا لاس ګاړۍ',
    '🚬' => 'سګريټ',
    '⚰' => 'تابوت',
    '🪦' => 'شناخته',
    '⚱' => 'د جنازې ګلدان',
    '🧿' => 'د نظر تعويذ',
    '🪬' => 'حمصه',
    '🗿' => 'موي',
    '🪧' => 'پلی کارت',
    '🪪' => 'د پیژندنې کارت',
    '🏧' => 'د ای ټي ايم نښه',
    '🚮' => 'ورخړ په فاضلدانۍ کې نښه',
    '🚰' => 'د څښاک اوبه',
    '♿' => 'د ویلچیر نښه',
    '🚹' => 'د نارینه خونه',
    '🚺' => 'د ښځو خونه',
    '🚻' => 'د آرام خونه',
    '🚼' => 'د ماشوم نښه',
    '🚾' => 'د تشناب د اوبو لوښی',
    '🛂' => 'د پاسپورت کنټرول',
    '🛃' => 'ګمرک',
    '🛄' => 'د سامانونو ادعا',
    '🛅' => 'پاتې سامانونو',
    '⚠' => 'خبرداری',
    '🚸' => 'ماشومان تېرېږي',
    '⛔' => 'داخلېدل منع دي',
    '🚫' => 'منع شوی',
    '🚳' => 'بایسکلانو ته اجازه نشته',
    '🚭' => 'سګرټ څکول منع دي',
    '🚯' => 'ورخړ خپرول منع دي',
    '🚱' => 'د څښاک اوبه نه دي',
    '🚷' => 'پیاده منع دي',
    '📵' => 'ګرځنده تیلیفونونه منع دي',
    '🔞' => 'له اتلس کالو څخه کم عمر کسان منع دي',
    '☢' => 'راډيو اکټيو',
    '☣' => 'بایو خطر',
    '⬆' => 'پورته غشی',
    '↗' => 'پورته ښي غشی',
    '➡' => 'ښي غشی',
    '↘' => 'ښکته ښي غشی',
    '⬇' => 'ښکته غشی',
    '↙' => 'ښکته چپ اړخ ته غشی',
    '⬅' => 'چپ غشی',
    '↖' => 'پورته چپ غشی',
    '↕' => 'پورته ښکته غشی',
    '↔' => 'ښۍ چپ غشی',
    '↩' => 'ښۍ غشی چپ اړخ ته کوږ',
    '↪' => 'چپ غشی ښۍ اړخ ته کوږ',
    '⤴' => 'ښۍ غشی پورته کوږ',
    '⤵' => 'ښۍ غشی ښکته کوږ',
    '🔃' => 'کلاک وايز عمودي غشي',
    '🔄' => 'خلاف کلاک وايز غشي بټن',
    '🔙' => 'شاته غشی',
    '🔚' => 'د پای غشی',
    '🔛' => 'چالو! غشی',
    '🔜' => 'ژر غشی',
    '🔝' => 'په سر غشی',
    '🛐' => 'د عبادت ځای',
    '⚛' => 'د ايټم سمبول',
    '🕉' => 'اوم',
    '✡' => 'د ډیویډ ستوری',
    '☸' => 'د دهرما پايه',
    '☯' => 'ین یانگ',
    '✝' => 'لاتیني صلیب',
    '☦' => 'د ارتودکس صلیب',
    '☪' => 'هلال او ستوری',
    '☮' => 'د سولې سمبول',
    '🕎' => 'مینوره',
    '🔯' => 'داغدار شپږ ګوټی ستوری',
    '🪯' => 'خندا',
    '♈' => 'وری',
    '♉' => 'تورس',
    '♊' => 'جمني',
    '♋' => 'د سرطان ناروغي',
    '♌' => 'اسد',
    '♍' => 'زاڼه',
    '♎' => 'تله',
    '♏' => 'لړم',
    '♐' => 'نخښه ويشتونکی',
    '♑' => 'مرغومی',
    '♒' => 'دلو',
    '♓' => 'حوت',
    '⛎' => 'اوفیوچس',
    '🔀' => 'شفل ټريک بټن',
    '🔁' => 'تکرار بټن',
    '🔂' => 'يو ځل تکرار بټن',
    '▶' => 'د غږولو بټن',
    '⏩' => 'چټک مخکی بټن',
    '⏭' => 'راتلونکي ټريک بټن',
    '⏯' => 'د غږولو يا وقفې بټن',
    '◀' => 'د بيرته تلو بټن',
    '⏪' => 'د چټک بيرته تلو بټن',
    '⏮' => 'وروستی ټريک بټن',
    '🔼' => 'د پورته تلو بټن',
    '⏫' => 'چټک پورته بټن',
    '🔽' => 'ښکته بټن',
    '⏬' => 'چټک ښکته بټن',
    '⏸' => 'د وقفې بټن',
    '⏹' => 'د درولو بټن',
    '⏺' => 'د ريکارډ بټن',
    '⏏' => 'د ويستلو بټن',
    '🎦' => 'سنيما',
    '🔅' => 'تته بټن',
    '🔆' => 'روښانه بټن',
    '📶' => 'اینټینا بارونه',
    '🛜' => 'بې سیم',
    '📳' => 'خوځښت موډ',
    '📴' => 'د ګرځنده تلیفون بند',
    '♀' => 'ښځینه نښه',
    '♂' => 'نارينه نښه',
    '⚧' => 'د جنس بدلوونکي سمبول',
    '✖' => 'د ضرب نښه',
    '➕' => 'د جمع نښه',
    '➖' => 'د منفي نښه',
    '➗' => 'د تقسيم نښه',
    '🟰' => 'دروند مساوي نښه',
    '♾' => 'لا محدود',
    '‼' => 'غبرګې ندا نښې',
    '⁉' => 'ندا پوښتنښه',
    '❓' => 'پوښتنښه',
    '❔' => 'سپينه پوښتنښه',
    '❕' => 'سپينه ندا نښه',
    '❗' => 'ندا نښه',
    '〰' => 'کوږ ډيش',
    '💱' => 'د اسعارو تبادله',
    '💲' => 'د دروند ډالر نښان',
    '⚕' => 'طبي سمبول',
    '♻' => 'د ري سايکلنګ سمبول',
    '⚜' => 'فليور دي لوس',
    '🔱' => 'د درې غاښۍ نښه',
    '📛' => 'نوم بیج',
    '🔰' => 'د ابتکار لپاره جاپاني سمبول',
    '⭕' => 'ګوګ سره دايره',
    '✅' => 'د خوښنښې بټن',
    '☑' => 'چيک بوکسه د چيک سره',
    '✔' => 'خوښنښه',
    '❌' => 'د صليب نښه',
    '❎' => 'د کراس نښې بټن',
    '➰' => 'تاو کړۍ',
    '➿' => 'دوه ځل تاو کړۍ',
    '〽' => 'د برخې بدلولو نښه',
    '✳' => 'اته ګوټې اسټيريسک',
    '✴' => 'اته ګوټی ستوري',
    '❇' => 'ځلېدل',
    '™' => 'تجارتي نښان',
    '🫟' => 'څاڅکي',
    '🔠' => 'شاملتوب لاتینې لوړ الفبا',
    '🔡' => 'شاملتوب لاتینې ټيټه الفبا',
    '🔢' => 'شاملتوب شمیرې',
    '🔣' => 'شاملتوب سمبولونه',
    '🔤' => 'شاملتوب لاتینې الفبا',
    '🅰' => 'A بټن (د وینې ډول)',
    '🆎' => 'AB بټن (د وینې ډول)',
    '🅱' => 'B بټن (د وینې ډول)',
    '🆑' => 'سي ايل بټن',
    '🆒' => 'د سوړ بټن',
    '🆓' => 'د آزاد بټن',
    'ℹ' => 'معلومات',
    '🆔' => 'آي ډې بټن',
    'Ⓜ' => 'دايره ايم',
    '🆕' => 'نوې بټن',
    '🆖' => 'اين جي بټن',
    '🅾' => 'او بټن (د وینې ډول)',
    '🆗' => 'او کی بټن',
    '🅿' => 'P بټن',
    '🆘' => 'ايس او ايس بټن',
    '🆙' => 'پورته! بټن',
    '🆚' => 'وي ايس بټن',
    '🈁' => 'جاپاني "دلته" بټن',
    '🈂' => 'د جاپاني "خدمت چارج"بټن',
    '🈷' => 'د جاپان د "میاشتنی پيسې" بټن',
    '🈶' => 'جاپاني "وړیا نه" بټن',
    '🈯' => 'جاپاني "د اضافي" بټن',
    '🉐' => 'جاپاني "جوړ جاړ" بټن',
    '🈹' => 'د جاپاني د "رعایت" بټن',
    '🈚' => 'جاپاني "وړیا"بټن',
    '🈲' => 'جاپاني "منع شوي" بټن',
    '🉑' => 'جاپاني "منلو وړ"بټن',
    '🈸' => 'د جاپاني "غوښتنليک" بټن',
    '🈴' => 'د جاپاني "تیریدو درجه" بټن',
    '🈳' => 'د جاپان د "د خالي ځايونو" بټن',
    '㊗' => 'د جاپان د "مبارکۍ" بټن',
    '㊙' => 'د جاپان د "پټ" بتن',
    '🈺' => 'جاپاني "د سوداګرۍ لپاره پرانستې" بټن',
    '🈵' => 'د جاپان د "خالي ځايونه نشته" بټن',
    '🔴' => 'سره دايره',
    '🟠' => 'نارنجي دايره',
    '🟡' => 'زېړه دايره',
    '🟢' => 'شنه دايره',
    '🔵' => 'آسماني رنګ دايره',
    '🟣' => 'ارغواني دايره',
    '🟤' => 'نسواري دايره',
    '⚫' => 'توره دايره',
    '⚪' => 'سپينه دايره',
    '🟥' => 'سره مربع',
    '🟧' => 'نارنجي مربع',
    '🟨' => 'زېړه مربع',
    '🟩' => 'شنه مربع',
    '🟦' => 'آسماني رنګ مربع',
    '🟪' => 'ارغواني مربع',
    '🟫' => 'نسواري مربع',
    '⬛' => 'توره لوی مربع',
    '⬜' => 'سپينه لوی مربع',
    '◼' => 'توره منځنۍ مربع',
    '◻' => 'سپينه ميانه مربع',
    '◾' => 'توره ميانه کوچنۍ مربع',
    '◽' => 'سپينه ميانه کوچنۍ مربع',
    '▪' => 'توره کوچنۍ مربع',
    '▫' => 'سپينه کوچنۍ مربع',
    '🔶' => 'لوی نارنجي الماس',
    '🔷' => 'لوي آسماني رنګ الماس',
    '🔸' => 'کوچنی نارنجي رنګ الماس',
    '🔹' => 'کوچنی آسماني رنګ الماس',
    '🔺' => 'سور مثلث پورته',
    '🔻' => 'سور مثلث ښکته',
    '💠' => 'الماس د ټکي سره',
    '🔘' => 'د راديو بټن',
    '🔳' => 'سپینه مربع بټن',
    '🔲' => 'توره مربع بټن',
    '🏁' => 'رنګداره بېرغ',
    '🚩' => 'درې کنجه بيراغ',
    '🎌' => 'کراسډ بېرغې',
    '🏴' => 'تور بیراغ',
    '🏳' => 'سپین بیراغ',
];
