<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'قبلة: بالغ، وبالغ، وبشرة بلون فاتح، وبشرة بلون فاتح ومعتدل',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'قبلة: بالغ، وبالغ، وبشرة بلون فاتح، وبشرة بلون معتدل',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'قبلة: بالغ، وبالغ، وبشرة بلون فاتح، وبشرة بلون معتدل مائل للغامق',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'قبلة: بالغ، وبالغ، وبشرة بلون فاتح، وبشرة بلون غامق',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'قبلة: بالغ، وبالغ، وبشرة بلون فاتح ومعتدل، وبشرة بلون فاتح',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'قبلة: بالغ، وبالغ، وبشرة بلون فاتح ومعتدل، وبشرة بلون معتدل',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'قبلة: بالغ، وبالغ، وبشرة بلون فاتح ومعتدل، وبشرة بلون معتدل مائل للغامق',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'قبلة: بالغ، وبالغ، وبشرة بلون فاتح ومعتدل، وبشرة بلون غامق',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'قبلة: بالغ، وبالغ، وبشرة بلون معتدل، وبشرة بلون فاتح',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'قبلة: بالغ، وبالغ، وبشرة بلون معتدل، وبشرة بلون فاتح ومعتدل',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'قبلة: بالغ، وبالغ، وبشرة بلون معتدل، وبشرة بلون معتدل مائل للغامق',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'قبلة: بالغ، وبالغ، وبشرة بلون معتدل، وبشرة بلون غامق',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'قبلة: بالغ، وبالغ، وبشرة بلون معتدل مائل للغامق، وبشرة بلون فاتح',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'قبلة: بالغ، وبالغ، وبشرة بلون معتدل مائل للغامق، وبشرة بلون فاتح ومعتدل',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'قبلة: بالغ، وبالغ، وبشرة بلون معتدل مائل للغامق، وبشرة بلون معتدل',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'قبلة: بالغ، وبالغ، وبشرة بلون معتدل مائل للغامق، وبشرة بلون غامق',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'قبلة: بالغ، وبالغ، وبشرة بلون غامق، وبشرة بلون فاتح',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'قبلة: بالغ، وبالغ، وبشرة بلون غامق، وبشرة بلون فاتح ومعتدل',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'قبلة: بالغ، وبالغ، وبشرة بلون غامق، وبشرة بلون معتدل',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'قبلة: بالغ، وبالغ، وبشرة بلون غامق، وبشرة بلون معتدل مائل للغامق',
    '👨🏻‍❤‍💋‍👨🏻' => 'قبلة: رجل، ورجل، وبشرة بلون فاتح',
    '👨🏻‍❤‍💋‍👨🏼' => 'قبلة: رجل، ورجل، وبشرة بلون فاتح، وبشرة بلون فاتح ومعتدل',
    '👨🏻‍❤‍💋‍👨🏽' => 'قبلة: رجل، ورجل، وبشرة بلون فاتح، وبشرة بلون معتدل',
    '👨🏻‍❤‍💋‍👨🏾' => 'قبلة: رجل، ورجل، وبشرة بلون فاتح، وبشرة بلون معتدل مائل للغامق',
    '👨🏻‍❤‍💋‍👨🏿' => 'قبلة: رجل، ورجل، وبشرة بلون فاتح، وبشرة بلون غامق',
    '👨🏼‍❤‍💋‍👨🏻' => 'قبلة: رجل، ورجل، وبشرة بلون فاتح ومعتدل، وبشرة بلون فاتح',
    '👨🏼‍❤‍💋‍👨🏼' => 'قبلة: رجل، ورجل، وبشرة بلون فاتح ومعتدل',
    '👨🏼‍❤‍💋‍👨🏽' => 'قبلة: رجل، ورجل، وبشرة بلون فاتح ومعتدل، وبشرة بلون معتدل',
    '👨🏼‍❤‍💋‍👨🏾' => 'قبلة: رجل، ورجل، وبشرة بلون فاتح ومعتدل، وبشرة بلون معتدل مائل للغامق',
    '👨🏼‍❤‍💋‍👨🏿' => 'قبلة: رجل، ورجل، وبشرة بلون فاتح ومعتدل، وبشرة بلون غامق',
    '👨🏽‍❤‍💋‍👨🏻' => 'قبلة: رجل، ورجل، وبشرة بلون معتدل، وبشرة بلون فاتح',
    '👨🏽‍❤‍💋‍👨🏼' => 'قبلة: رجل، ورجل، وبشرة بلون معتدل، وبشرة بلون فاتح ومعتدل',
    '👨🏽‍❤‍💋‍👨🏽' => 'قبلة: رجل، ورجل، وبشرة بلون معتدل',
    '👨🏽‍❤‍💋‍👨🏾' => 'قبلة: رجل، ورجل، وبشرة بلون معتدل، وبشرة بلون معتدل مائل للغامق',
    '👨🏽‍❤‍💋‍👨🏿' => 'قبلة: رجل، ورجل، وبشرة بلون معتدل، وبشرة بلون غامق',
    '👨🏾‍❤‍💋‍👨🏻' => 'قبلة: رجل، ورجل، وبشرة بلون معتدل مائل للغامق، وبشرة بلون فاتح',
    '👨🏾‍❤‍💋‍👨🏼' => 'قبلة: رجل، ورجل، وبشرة بلون معتدل مائل للغامق، وبشرة بلون فاتح ومعتدل',
    '👨🏾‍❤‍💋‍👨🏽' => 'قبلة: رجل، ورجل، وبشرة بلون معتدل مائل للغامق، وبشرة بلون معتدل',
    '👨🏾‍❤‍💋‍👨🏾' => 'قبلة: رجل، ورجل، وبشرة بلون معتدل مائل للغامق',
    '👨🏾‍❤‍💋‍👨🏿' => 'قبلة: رجل، ورجل، وبشرة بلون معتدل مائل للغامق، وبشرة بلون غامق',
    '👨🏿‍❤‍💋‍👨🏻' => 'قبلة: رجل، ورجل، وبشرة بلون غامق، وبشرة بلون فاتح',
    '👨🏿‍❤‍💋‍👨🏼' => 'قبلة: رجل، ورجل، وبشرة بلون غامق، وبشرة بلون فاتح ومعتدل',
    '👨🏿‍❤‍💋‍👨🏽' => 'قبلة: رجل، ورجل، وبشرة بلون غامق، وبشرة بلون معتدل',
    '👨🏿‍❤‍💋‍👨🏾' => 'قبلة: رجل، ورجل، وبشرة بلون غامق، وبشرة بلون معتدل مائل للغامق',
    '👨🏿‍❤‍💋‍👨🏿' => 'قبلة: رجل، ورجل، وبشرة بلون غامق',
    '👩🏻‍❤‍💋‍👨🏻' => 'قبلة: سيدة، ورجل، وبشرة بلون فاتح',
    '👩🏻‍❤‍💋‍👨🏼' => 'قبلة: سيدة، ورجل، وبشرة بلون فاتح، وبشرة بلون فاتح ومعتدل',
    '👩🏻‍❤‍💋‍👨🏽' => 'قبلة: سيدة، ورجل، وبشرة بلون فاتح، وبشرة بلون معتدل',
    '👩🏻‍❤‍💋‍👨🏾' => 'قبلة: سيدة، ورجل، وبشرة بلون فاتح، وبشرة بلون معتدل مائل للغامق',
    '👩🏻‍❤‍💋‍👨🏿' => 'قبلة: سيدة، ورجل، وبشرة بلون فاتح، وبشرة بلون غامق',
    '👩🏼‍❤‍💋‍👨🏻' => 'قبلة: سيدة، ورجل، وبشرة بلون فاتح ومعتدل، وبشرة بلون فاتح',
    '👩🏼‍❤‍💋‍👨🏼' => 'قبلة: سيدة، ورجل، وبشرة بلون فاتح ومعتدل',
    '👩🏼‍❤‍💋‍👨🏽' => 'قبلة: سيدة، ورجل، وبشرة بلون فاتح ومعتدل، وبشرة بلون معتدل',
    '👩🏼‍❤‍💋‍👨🏾' => 'قبلة: سيدة، ورجل، وبشرة بلون فاتح ومعتدل، وبشرة بلون معتدل مائل للغامق',
    '👩🏼‍❤‍💋‍👨🏿' => 'قبلة: سيدة، ورجل، وبشرة بلون فاتح ومعتدل، وبشرة بلون غامق',
    '👩🏽‍❤‍💋‍👨🏻' => 'قبلة: سيدة، ورجل، وبشرة بلون معتدل، وبشرة بلون فاتح',
    '👩🏽‍❤‍💋‍👨🏼' => 'قبلة: سيدة، ورجل، وبشرة بلون معتدل، وبشرة بلون فاتح ومعتدل',
    '👩🏽‍❤‍💋‍👨🏽' => 'قبلة: سيدة، ورجل، وبشرة بلون معتدل',
    '👩🏽‍❤‍💋‍👨🏾' => 'قبلة: سيدة، ورجل، وبشرة بلون معتدل، وبشرة بلون معتدل مائل للغامق',
    '👩🏽‍❤‍💋‍👨🏿' => 'قبلة: سيدة، ورجل، وبشرة بلون معتدل، وبشرة بلون غامق',
    '👩🏾‍❤‍💋‍👨🏻' => 'قبلة: سيدة، ورجل، وبشرة بلون معتدل مائل للغامق، وبشرة بلون فاتح',
    '👩🏾‍❤‍💋‍👨🏼' => 'قبلة: سيدة، ورجل، وبشرة بلون معتدل مائل للغامق، وبشرة بلون فاتح ومعتدل',
    '👩🏾‍❤‍💋‍👨🏽' => 'قبلة: سيدة، ورجل، وبشرة بلون معتدل مائل للغامق، وبشرة بلون معتدل',
    '👩🏾‍❤‍💋‍👨🏾' => 'قبلة: سيدة، ورجل، وبشرة بلون معتدل مائل للغامق',
    '👩🏾‍❤‍💋‍👨🏿' => 'قبلة: سيدة، ورجل، وبشرة بلون معتدل مائل للغامق، وبشرة بلون غامق',
    '👩🏿‍❤‍💋‍👨🏻' => 'قبلة: سيدة، ورجل، وبشرة بلون غامق، وبشرة بلون فاتح',
    '👩🏿‍❤‍💋‍👨🏼' => 'قبلة: سيدة، ورجل، وبشرة بلون غامق، وبشرة بلون فاتح ومعتدل',
    '👩🏿‍❤‍💋‍👨🏽' => 'قبلة: سيدة، ورجل، وبشرة بلون غامق، وبشرة بلون معتدل',
    '👩🏿‍❤‍💋‍👨🏾' => 'قبلة: سيدة، ورجل، وبشرة بلون غامق، وبشرة بلون معتدل مائل للغامق',
    '👩🏿‍❤‍💋‍👨🏿' => 'قبلة: سيدة، ورجل، وبشرة بلون غامق',
    '👩🏻‍❤‍💋‍👩🏻' => 'قبلة: سيدة، وسيدة، وبشرة بلون فاتح',
    '👩🏻‍❤‍💋‍👩🏼' => 'قبلة: سيدة، وسيدة، وبشرة بلون فاتح، وبشرة بلون فاتح ومعتدل',
    '👩🏻‍❤‍💋‍👩🏽' => 'قبلة: سيدة، وسيدة، وبشرة بلون فاتح، وبشرة بلون معتدل',
    '👩🏻‍❤‍💋‍👩🏾' => 'قبلة: سيدة، وسيدة، وبشرة بلون فاتح، وبشرة بلون معتدل مائل للغامق',
    '👩🏻‍❤‍💋‍👩🏿' => 'قبلة: سيدة، وسيدة، وبشرة بلون فاتح، وبشرة بلون غامق',
    '👩🏼‍❤‍💋‍👩🏻' => 'قبلة: سيدة، وسيدة، وبشرة بلون فاتح ومعتدل، وبشرة بلون فاتح',
    '👩🏼‍❤‍💋‍👩🏼' => 'قبلة: سيدة، وسيدة، وبشرة بلون فاتح ومعتدل',
    '👩🏼‍❤‍💋‍👩🏽' => 'قبلة: سيدة، وسيدة، وبشرة بلون فاتح ومعتدل، وبشرة بلون معتدل',
    '👩🏼‍❤‍💋‍👩🏾' => 'قبلة: سيدة، وسيدة، وبشرة بلون فاتح ومعتدل، وبشرة بلون معتدل مائل للغامق',
    '👩🏼‍❤‍💋‍👩🏿' => 'قبلة: سيدة، وسيدة، وبشرة بلون فاتح ومعتدل، وبشرة بلون غامق',
    '👩🏽‍❤‍💋‍👩🏻' => 'قبلة: سيدة، وسيدة، وبشرة بلون معتدل، وبشرة بلون فاتح',
    '👩🏽‍❤‍💋‍👩🏼' => 'قبلة: سيدة، وسيدة، وبشرة بلون معتدل، وبشرة بلون فاتح ومعتدل',
    '👩🏽‍❤‍💋‍👩🏽' => 'قبلة: سيدة، وسيدة، وبشرة بلون معتدل',
    '👩🏽‍❤‍💋‍👩🏾' => 'قبلة: سيدة، وسيدة، وبشرة بلون معتدل، وبشرة بلون معتدل مائل للغامق',
    '👩🏽‍❤‍💋‍👩🏿' => 'قبلة: سيدة، وسيدة، وبشرة بلون معتدل، وبشرة بلون غامق',
    '👩🏾‍❤‍💋‍👩🏻' => 'قبلة: سيدة، وسيدة، وبشرة بلون معتدل مائل للغامق، وبشرة بلون فاتح',
    '👩🏾‍❤‍💋‍👩🏼' => 'قبلة: سيدة، وسيدة، وبشرة بلون معتدل مائل للغامق، وبشرة بلون فاتح ومعتدل',
    '👩🏾‍❤‍💋‍👩🏽' => 'قبلة: سيدة، وسيدة، وبشرة بلون معتدل مائل للغامق، وبشرة بلون معتدل',
    '👩🏾‍❤‍💋‍👩🏾' => 'قبلة: سيدة، وسيدة، وبشرة بلون معتدل مائل للغامق',
    '👩🏾‍❤‍💋‍👩🏿' => 'قبلة: سيدة، وسيدة، وبشرة بلون معتدل مائل للغامق، وبشرة بلون غامق',
    '👩🏿‍❤‍💋‍👩🏻' => 'قبلة: سيدة، وسيدة، وبشرة بلون غامق، وبشرة بلون فاتح',
    '👩🏿‍❤‍💋‍👩🏼' => 'قبلة: سيدة، وسيدة، وبشرة بلون غامق، وبشرة بلون فاتح ومعتدل',
    '👩🏿‍❤‍💋‍👩🏽' => 'قبلة: سيدة، وسيدة، وبشرة بلون غامق، وبشرة بلون معتدل',
    '👩🏿‍❤‍💋‍👩🏾' => 'قبلة: سيدة، وسيدة، وبشرة بلون غامق، وبشرة بلون معتدل مائل للغامق',
    '👩🏿‍❤‍💋‍👩🏿' => 'قبلة: سيدة، وسيدة، وبشرة بلون غامق',
    '🧑🏻‍🫯‍🧑🏼' => 'مصارعون: بشرة بلون فاتح وبشرة بلون فاتح ومعتدل',
    '🧑🏻‍🫯‍🧑🏽' => 'مصارعون: بشرة بلون فاتح وبشرة بلون معتدل',
    '🧑🏻‍🫯‍🧑🏾' => 'مصارعون: بشرة بلون فاتح وبشرة بلون معتدل مائل للغامق',
    '🧑🏻‍🫯‍🧑🏿' => 'مصارعون: بشرة بلون فاتح وبشرة بلون غامق',
    '🧑🏼‍🫯‍🧑🏻' => 'مصارعون: بشرة بلون فاتح ومعتدل وبشرة بلون فاتح',
    '🧑🏼‍🫯‍🧑🏽' => 'مصارعون: بشرة بلون فاتح ومعتدل وبشرة بلون معتدل',
    '🧑🏼‍🫯‍🧑🏾' => 'مصارعون: بشرة بلون فاتح ومعتدل وبشرة بلون معتدل مائل للغامق',
    '🧑🏼‍🫯‍🧑🏿' => 'مصارعون: بشرة بلون فاتح ومعتدل وبشرة بلون غامق',
    '🧑🏽‍🫯‍🧑🏻' => 'مصارعون: بشرة بلون معتدل وبشرة بلون فاتح',
    '🧑🏽‍🫯‍🧑🏼' => 'مصارعون: بشرة بلون معتدل وبشرة بلون فاتح ومعتدل',
    '🧑🏽‍🫯‍🧑🏾' => 'مصارعون: بشرة بلون معتدل وبشرة بلون معتدل مائل للغامق',
    '🧑🏽‍🫯‍🧑🏿' => 'مصارعون: بشرة بلون معتدل وبشرة بلون غامق',
    '🧑🏾‍🫯‍🧑🏻' => 'مصارعون: بشرة بلون معتدل مائل للغامق وبشرة بلون فاتح',
    '🧑🏾‍🫯‍🧑🏼' => 'مصارعون: بشرة بلون معتدل مائل للغامق وبشرة بلون فاتح ومعتدل',
    '🧑🏾‍🫯‍🧑🏽' => 'مصارعون: بشرة بلون معتدل مائل للغامق وبشرة بلون معتدل',
    '🧑🏾‍🫯‍🧑🏿' => 'مصارعون: بشرة بلون معتدل مائل للغامق وبشرة بلون غامق',
    '🧑🏿‍🫯‍🧑🏻' => 'مصارعون: بشرة بلون غامق وبشرة بلون فاتح',
    '🧑🏿‍🫯‍🧑🏼' => 'مصارعون: بشرة بلون غامق وبشرة بلون فاتح ومعتدل',
    '🧑🏿‍🫯‍🧑🏽' => 'مصارعون: بشرة بلون غامق وبشرة بلون معتدل',
    '🧑🏿‍🫯‍🧑🏾' => 'مصارعون: بشرة بلون غامق وبشرة بلون معتدل مائل للغامق',
    '🧑🏻‍❤‍🧑🏼' => 'زوج وقلب: بالغ، وبالغ، وبشرة بلون فاتح، وبشرة بلون فاتح ومعتدل',
    '🧑🏻‍❤‍🧑🏽' => 'زوج وقلب: بالغ، وبالغ، وبشرة بلون فاتح، وبشرة بلون معتدل',
    '🧑🏻‍❤‍🧑🏾' => 'زوج وقلب: بالغ، وبالغ، وبشرة بلون فاتح، وبشرة بلون معتدل مائل للغامق',
    '🧑🏻‍❤‍🧑🏿' => 'زوج وقلب: بالغ، وبالغ، وبشرة بلون فاتح، وبشرة بلون غامق',
    '🧑🏼‍❤‍🧑🏻' => 'زوج وقلب: بالغ، وبالغ، وبشرة بلون فاتح ومعتدل، وبشرة بلون فاتح',
    '🧑🏼‍❤‍🧑🏽' => 'زوج وقلب: بالغ، وبالغ، وبشرة بلون فاتح ومعتدل، وبشرة بلون معتدل',
    '🧑🏼‍❤‍🧑🏾' => 'زوج وقلب: بالغ، وبالغ، وبشرة بلون فاتح ومعتدل، وبشرة بلون معتدل مائل للغامق',
    '🧑🏼‍❤‍🧑🏿' => 'زوج وقلب: بالغ، وبالغ، وبشرة بلون فاتح ومعتدل، وبشرة بلون غامق',
    '🧑🏽‍❤‍🧑🏻' => 'زوج وقلب: بالغ، وبالغ، وبشرة بلون معتدل، وبشرة بلون فاتح',
    '🧑🏽‍❤‍🧑🏼' => 'زوج وقلب: بالغ، وبالغ، وبشرة بلون معتدل، وبشرة بلون فاتح ومعتدل',
    '🧑🏽‍❤‍🧑🏾' => 'زوج وقلب: بالغ، وبالغ، وبشرة بلون معتدل، وبشرة بلون معتدل مائل للغامق',
    '🧑🏽‍❤‍🧑🏿' => 'زوج وقلب: بالغ، وبالغ، وبشرة بلون معتدل، وبشرة بلون غامق',
    '🧑🏾‍❤‍🧑🏻' => 'زوج وقلب: بالغ، وبالغ، وبشرة بلون معتدل مائل للغامق، وبشرة بلون فاتح',
    '🧑🏾‍❤‍🧑🏼' => 'زوج وقلب: بالغ، وبالغ، وبشرة بلون معتدل مائل للغامق، وبشرة بلون فاتح ومعتدل',
    '🧑🏾‍❤‍🧑🏽' => 'زوج وقلب: بالغ، وبالغ، وبشرة بلون معتدل مائل للغامق، وبشرة بلون معتدل',
    '🧑🏾‍❤‍🧑🏿' => 'زوج وقلب: بالغ، وبالغ، وبشرة بلون معتدل مائل للغامق، وبشرة بلون غامق',
    '🧑🏿‍❤‍🧑🏻' => 'زوج وقلب: بالغ، وبالغ، وبشرة بلون غامق، وبشرة بلون فاتح',
    '🧑🏿‍❤‍🧑🏼' => 'زوج وقلب: بالغ، وبالغ، وبشرة بلون غامق، وبشرة بلون فاتح ومعتدل',
    '🧑🏿‍❤‍🧑🏽' => 'زوج وقلب: بالغ، وبالغ، وبشرة بلون غامق، وبشرة بلون معتدل',
    '🧑🏿‍❤‍🧑🏾' => 'زوج وقلب: بالغ، وبالغ، وبشرة بلون غامق، وبشرة بلون معتدل مائل للغامق',
    '🧑🏻‍🐰‍🧑🏼' => 'شخصان يرقصان: بشرة بلون فاتح وبشرة بلون فاتح ومعتدل',
    '🧑🏻‍🐰‍🧑🏽' => 'شخصان يرقصان: بشرة بلون فاتح وبشرة بلون معتدل',
    '🧑🏻‍🐰‍🧑🏾' => 'شخصان يرقصان: بشرة بلون فاتح وبشرة بلون معتدل مائل للغامق',
    '🧑🏻‍🐰‍🧑🏿' => 'شخصان يرقصان: بشرة بلون فاتح وبشرة بلون غامق',
    '🧑🏼‍🐰‍🧑🏻' => 'شخصان يرقصان: بشرة بلون فاتح ومعتدل وبشرة بلون فاتح',
    '🧑🏼‍🐰‍🧑🏽' => 'شخصان يرقصان: بشرة بلون فاتح ومعتدل وبشرة بلون معتدل',
    '🧑🏼‍🐰‍🧑🏾' => 'شخصان يرقصان: بشرة بلون فاتح ومعتدل وبشرة بلون معتدل مائل للغامق',
    '🧑🏼‍🐰‍🧑🏿' => 'شخصان يرقصان: بشرة بلون فاتح ومعتدل وبشرة بلون غامق',
    '🧑🏽‍🐰‍🧑🏻' => 'شخصان يرقصان: بشرة بلون معتدل وبشرة بلون فاتح',
    '🧑🏽‍🐰‍🧑🏼' => 'شخصان يرقصان: بشرة بلون معتدل وبشرة بلون فاتح ومعتدل',
    '🧑🏽‍🐰‍🧑🏾' => 'شخصان يرقصان: بشرة بلون معتدل وبشرة بلون معتدل مائل للغامق',
    '🧑🏽‍🐰‍🧑🏿' => 'شخصان يرقصان: بشرة بلون معتدل وبشرة بلون غامق',
    '🧑🏾‍🐰‍🧑🏻' => 'شخصان يرقصان: بشرة بلون معتدل مائل للغامق وبشرة بلون فاتح',
    '🧑🏾‍🐰‍🧑🏼' => 'شخصان يرقصان: بشرة بلون معتدل مائل للغامق وبشرة بلون فاتح ومعتدل',
    '🧑🏾‍🐰‍🧑🏽' => 'شخصان يرقصان: بشرة بلون معتدل مائل للغامق وبشرة بلون معتدل',
    '🧑🏾‍🐰‍🧑🏿' => 'شخصان يرقصان: بشرة بلون معتدل مائل للغامق وبشرة بلون غامق',
    '🧑🏿‍🐰‍🧑🏻' => 'شخصان يرقصان: بشرة بلون غامق وبشرة بلون فاتح',
    '🧑🏿‍🐰‍🧑🏼' => 'شخصان يرقصان: بشرة بلون غامق وبشرة بلون فاتح ومعتدل',
    '🧑🏿‍🐰‍🧑🏽' => 'شخصان يرقصان: بشرة بلون غامق وبشرة بلون معتدل',
    '🧑🏿‍🐰‍🧑🏾' => 'شخصان يرقصان: بشرة بلون غامق وبشرة بلون معتدل مائل للغامق',
    '👨🏻‍🫯‍👨🏼' => 'مصارعة رجال: بشرة بلون فاتح وبشرة بلون فاتح ومعتدل',
    '👨🏻‍🫯‍👨🏽' => 'مصارعة رجال: بشرة بلون فاتح وبشرة بلون معتدل',
    '👨🏻‍🫯‍👨🏾' => 'مصارعة رجال: بشرة بلون فاتح وبشرة بلون معتدل مائل للغامق',
    '👨🏻‍🫯‍👨🏿' => 'مصارعة رجال: بشرة بلون فاتح وبشرة بلون غامق',
    '👨🏼‍🫯‍👨🏻' => 'مصارعة رجال: بشرة بلون فاتح ومعتدل وبشرة بلون فاتح',
    '👨🏼‍🫯‍👨🏽' => 'مصارعة رجال: بشرة بلون فاتح ومعتدل وبشرة بلون معتدل',
    '👨🏼‍🫯‍👨🏾' => 'مصارعة رجال: بشرة بلون فاتح ومعتدل وبشرة بلون معتدل مائل للغامق',
    '👨🏼‍🫯‍👨🏿' => 'مصارعة رجال: بشرة بلون فاتح ومعتدل وبشرة بلون غامق',
    '👨🏽‍🫯‍👨🏻' => 'مصارعة رجال: بشرة بلون معتدل وبشرة بلون فاتح',
    '👨🏽‍🫯‍👨🏼' => 'مصارعة رجال: بشرة بلون معتدل وبشرة بلون فاتح ومعتدل',
    '👨🏽‍🫯‍👨🏾' => 'مصارعة رجال: بشرة بلون معتدل وبشرة بلون معتدل مائل للغامق',
    '👨🏽‍🫯‍👨🏿' => 'مصارعة رجال: بشرة بلون معتدل وبشرة بلون غامق',
    '👨🏾‍🫯‍👨🏻' => 'مصارعة رجال: بشرة بلون معتدل مائل للغامق وبشرة بلون فاتح',
    '👨🏾‍🫯‍👨🏼' => 'مصارعة رجال: بشرة بلون معتدل مائل للغامق وبشرة بلون فاتح ومعتدل',
    '👨🏾‍🫯‍👨🏽' => 'مصارعة رجال: بشرة بلون معتدل مائل للغامق وبشرة بلون معتدل',
    '👨🏾‍🫯‍👨🏿' => 'مصارعة رجال: بشرة بلون معتدل مائل للغامق وبشرة بلون غامق',
    '👨🏿‍🫯‍👨🏻' => 'مصارعة رجال: بشرة بلون غامق وبشرة بلون فاتح',
    '👨🏿‍🫯‍👨🏼' => 'مصارعة رجال: بشرة بلون غامق وبشرة بلون فاتح ومعتدل',
    '👨🏿‍🫯‍👨🏽' => 'مصارعة رجال: بشرة بلون غامق وبشرة بلون معتدل',
    '👨🏿‍🫯‍👨🏾' => 'مصارعة رجال: بشرة بلون غامق وبشرة بلون معتدل مائل للغامق',
    '👨🏻‍❤‍👨🏻' => 'زوج وقلب: رجل، ورجل، وبشرة بلون فاتح',
    '👨🏻‍❤‍👨🏼' => 'زوج وقلب: رجل، ورجل، وبشرة بلون فاتح، وبشرة بلون فاتح ومعتدل',
    '👨🏻‍❤‍👨🏽' => 'زوج وقلب: رجل، ورجل، وبشرة بلون فاتح، وبشرة بلون معتدل',
    '👨🏻‍❤‍👨🏾' => 'زوج وقلب: رجل، ورجل، وبشرة بلون فاتح، وبشرة بلون معتدل مائل للغامق',
    '👨🏻‍❤‍👨🏿' => 'زوج وقلب: رجل، ورجل، وبشرة بلون فاتح، وبشرة بلون غامق',
    '👨🏼‍❤‍👨🏻' => 'زوج وقلب: رجل، ورجل، وبشرة بلون فاتح ومعتدل، وبشرة بلون فاتح',
    '👨🏼‍❤‍👨🏼' => 'زوج وقلب: رجل، ورجل، وبشرة بلون فاتح ومعتدل',
    '👨🏼‍❤‍👨🏽' => 'زوج وقلب: رجل، ورجل، وبشرة بلون فاتح ومعتدل، وبشرة بلون معتدل',
    '👨🏼‍❤‍👨🏾' => 'زوج وقلب: رجل، ورجل، وبشرة بلون فاتح ومعتدل، وبشرة بلون معتدل مائل للغامق',
    '👨🏼‍❤‍👨🏿' => 'زوج وقلب: رجل، ورجل، وبشرة بلون فاتح ومعتدل، وبشرة بلون غامق',
    '👨🏽‍❤‍👨🏻' => 'زوج وقلب: رجل، ورجل، وبشرة بلون معتدل، وبشرة بلون فاتح',
    '👨🏽‍❤‍👨🏼' => 'زوج وقلب: رجل، ورجل، وبشرة بلون معتدل، وبشرة بلون فاتح ومعتدل',
    '👨🏽‍❤‍👨🏽' => 'زوج وقلب: رجل، ورجل، وبشرة بلون معتدل',
    '👨🏽‍❤‍👨🏾' => 'زوج وقلب: رجل، ورجل، وبشرة بلون معتدل، وبشرة بلون معتدل مائل للغامق',
    '👨🏽‍❤‍👨🏿' => 'زوج وقلب: رجل، ورجل، وبشرة بلون معتدل، وبشرة بلون غامق',
    '👨🏾‍❤‍👨🏻' => 'زوج وقلب: رجل، ورجل، وبشرة بلون معتدل مائل للغامق، وبشرة بلون فاتح',
    '👨🏾‍❤‍👨🏼' => 'زوج وقلب: رجل، ورجل، وبشرة بلون معتدل مائل للغامق، وبشرة بلون فاتح ومعتدل',
    '👨🏾‍❤‍👨🏽' => 'زوج وقلب: رجل، ورجل، وبشرة بلون معتدل مائل للغامق، وبشرة بلون معتدل',
    '👨🏾‍❤‍👨🏾' => 'زوج وقلب: رجل، ورجل، وبشرة بلون معتدل مائل للغامق',
    '👨🏾‍❤‍👨🏿' => 'زوج وقلب: رجل، ورجل، وبشرة بلون معتدل مائل للغامق، وبشرة بلون غامق',
    '👨🏿‍❤‍👨🏻' => 'زوج وقلب: رجل، ورجل، وبشرة بلون غامق، وبشرة بلون فاتح',
    '👨🏿‍❤‍👨🏼' => 'زوج وقلب: رجل، ورجل، وبشرة بلون غامق، وبشرة بلون فاتح ومعتدل',
    '👨🏿‍❤‍👨🏽' => 'زوج وقلب: رجل، ورجل، وبشرة بلون غامق، وبشرة بلون معتدل',
    '👨🏿‍❤‍👨🏾' => 'زوج وقلب: رجل، ورجل، وبشرة بلون غامق، وبشرة بلون معتدل مائل للغامق',
    '👨🏿‍❤‍👨🏿' => 'زوج وقلب: رجل، ورجل، وبشرة بلون غامق',
    '👨🏻‍🐰‍👨🏼' => 'رجلان يرقصان: بشرة بلون فاتح وبشرة بلون فاتح ومعتدل',
    '👨🏻‍🐰‍👨🏽' => 'رجلان يرقصان: بشرة بلون فاتح وبشرة بلون معتدل',
    '👨🏻‍🐰‍👨🏾' => 'رجلان يرقصان: بشرة بلون فاتح وبشرة بلون معتدل مائل للغامق',
    '👨🏻‍🐰‍👨🏿' => 'رجلان يرقصان: بشرة بلون فاتح وبشرة بلون غامق',
    '👨🏼‍🐰‍👨🏻' => 'رجلان يرقصان: بشرة بلون فاتح ومعتدل وبشرة بلون فاتح',
    '👨🏼‍🐰‍👨🏽' => 'رجلان يرقصان: بشرة بلون فاتح ومعتدل وبشرة بلون معتدل',
    '👨🏼‍🐰‍👨🏾' => 'رجلان يرقصان: بشرة بلون فاتح ومعتدل وبشرة بلون معتدل مائل للغامق',
    '👨🏼‍🐰‍👨🏿' => 'رجلان يرقصان: بشرة بلون فاتح ومعتدل وبشرة بلون غامق',
    '👨🏽‍🐰‍👨🏻' => 'رجلان يرقصان: بشرة بلون معتدل وبشرة بلون فاتح',
    '👨🏽‍🐰‍👨🏼' => 'رجلان يرقصان: بشرة بلون معتدل وبشرة بلون فاتح ومعتدل',
    '👨🏽‍🐰‍👨🏾' => 'رجلان يرقصان: بشرة بلون معتدل وبشرة بلون معتدل مائل للغامق',
    '👨🏽‍🐰‍👨🏿' => 'رجلان يرقصان: بشرة بلون معتدل وبشرة بلون غامق',
    '👨🏾‍🐰‍👨🏻' => 'رجلان يرقصان: بشرة بلون معتدل مائل للغامق وبشرة بلون فاتح',
    '👨🏾‍🐰‍👨🏼' => 'رجلان يرقصان: بشرة بلون معتدل مائل للغامق وبشرة بلون فاتح ومعتدل',
    '👨🏾‍🐰‍👨🏽' => 'رجلان يرقصان: بشرة بلون معتدل مائل للغامق وبشرة بلون معتدل',
    '👨🏾‍🐰‍👨🏿' => 'رجلان يرقصان: بشرة بلون معتدل مائل للغامق وبشرة بلون غامق',
    '👨🏿‍🐰‍👨🏻' => 'رجلان يرقصان: بشرة بلون غامق وبشرة بلون فاتح',
    '👨🏿‍🐰‍👨🏼' => 'رجلان يرقصان: بشرة بلون غامق وبشرة بلون فاتح ومعتدل',
    '👨🏿‍🐰‍👨🏽' => 'رجلان يرقصان: بشرة بلون غامق وبشرة بلون معتدل',
    '👨🏿‍🐰‍👨🏾' => 'رجلان يرقصان: بشرة بلون غامق وبشرة بلون معتدل مائل للغامق',
    '👩🏻‍🫯‍👩🏼' => 'مصارعة سيدات: بشرة بلون فاتح وبشرة بلون فاتح ومعتدل',
    '👩🏻‍🫯‍👩🏽' => 'مصارعة سيدات: بشرة بلون فاتح وبشرة بلون معتدل',
    '👩🏻‍🫯‍👩🏾' => 'مصارعة سيدات: بشرة بلون فاتح وبشرة بلون معتدل مائل للغامق',
    '👩🏻‍🫯‍👩🏿' => 'مصارعة سيدات: بشرة بلون فاتح وبشرة بلون غامق',
    '👩🏼‍🫯‍👩🏻' => 'مصارعة سيدات: بشرة بلون فاتح ومعتدل وبشرة بلون فاتح',
    '👩🏼‍🫯‍👩🏽' => 'مصارعة سيدات: بشرة بلون فاتح ومعتدل وبشرة بلون معتدل',
    '👩🏼‍🫯‍👩🏾' => 'مصارعة سيدات: بشرة بلون فاتح ومعتدل وبشرة بلون معتدل مائل للغامق',
    '👩🏼‍🫯‍👩🏿' => 'مصارعة سيدات: بشرة بلون فاتح ومعتدل وبشرة بلون غامق',
    '👩🏽‍🫯‍👩🏻' => 'مصارعة سيدات: بشرة بلون معتدل وبشرة بلون فاتح',
    '👩🏽‍🫯‍👩🏼' => 'مصارعة سيدات: بشرة بلون معتدل وبشرة بلون فاتح ومعتدل',
    '👩🏽‍🫯‍👩🏾' => 'مصارعة سيدات: بشرة بلون معتدل وبشرة بلون معتدل مائل للغامق',
    '👩🏽‍🫯‍👩🏿' => 'مصارعة سيدات: بشرة بلون معتدل وبشرة بلون غامق',
    '👩🏾‍🫯‍👩🏻' => 'مصارعة سيدات: بشرة بلون معتدل مائل للغامق وبشرة بلون فاتح',
    '👩🏾‍🫯‍👩🏼' => 'مصارعة سيدات: بشرة بلون معتدل مائل للغامق وبشرة بلون فاتح ومعتدل',
    '👩🏾‍🫯‍👩🏽' => 'مصارعة سيدات: بشرة بلون معتدل مائل للغامق وبشرة بلون معتدل',
    '👩🏾‍🫯‍👩🏿' => 'مصارعة سيدات: بشرة بلون معتدل مائل للغامق وبشرة بلون غامق',
    '👩🏿‍🫯‍👩🏻' => 'مصارعة سيدات: بشرة بلون غامق وبشرة بلون فاتح',
    '👩🏿‍🫯‍👩🏼' => 'مصارعة سيدات: بشرة بلون غامق وبشرة بلون فاتح ومعتدل',
    '👩🏿‍🫯‍👩🏽' => 'مصارعة سيدات: بشرة بلون غامق وبشرة بلون معتدل',
    '👩🏿‍🫯‍👩🏾' => 'مصارعة سيدات: بشرة بلون غامق وبشرة بلون معتدل مائل للغامق',
    '👩🏻‍❤‍👨🏻' => 'زوج وقلب: سيدة، ورجل، وبشرة بلون فاتح',
    '👩🏻‍❤‍👨🏼' => 'زوج وقلب: سيدة، ورجل، وبشرة بلون فاتح، وبشرة بلون فاتح ومعتدل',
    '👩🏻‍❤‍👨🏽' => 'زوج وقلب: سيدة، ورجل، وبشرة بلون فاتح، وبشرة بلون معتدل',
    '👩🏻‍❤‍👨🏾' => 'زوج وقلب: سيدة، ورجل، وبشرة بلون فاتح، وبشرة بلون معتدل مائل للغامق',
    '👩🏻‍❤‍👨🏿' => 'زوج وقلب: سيدة، ورجل، وبشرة بلون فاتح، وبشرة بلون غامق',
    '👩🏼‍❤‍👨🏻' => 'زوج وقلب: سيدة، ورجل، وبشرة بلون فاتح ومعتدل، وبشرة بلون فاتح',
    '👩🏼‍❤‍👨🏼' => 'زوج وقلب: سيدة، ورجل، وبشرة بلون فاتح ومعتدل',
    '👩🏼‍❤‍👨🏽' => 'زوج وقلب: سيدة، ورجل، وبشرة بلون فاتح ومعتدل، وبشرة بلون معتدل',
    '👩🏼‍❤‍👨🏾' => 'زوج وقلب: سيدة، ورجل، وبشرة بلون فاتح ومعتدل، وبشرة بلون معتدل مائل للغامق',
    '👩🏼‍❤‍👨🏿' => 'زوج وقلب: سيدة، ورجل، وبشرة بلون فاتح ومعتدل، وبشرة بلون غامق',
    '👩🏽‍❤‍👨🏻' => 'زوج وقلب: سيدة، ورجل، وبشرة بلون معتدل، وبشرة بلون فاتح',
    '👩🏽‍❤‍👨🏼' => 'زوج وقلب: سيدة، ورجل، وبشرة بلون معتدل، وبشرة بلون فاتح ومعتدل',
    '👩🏽‍❤‍👨🏽' => 'زوج وقلب: سيدة، ورجل، وبشرة بلون معتدل',
    '👩🏽‍❤‍👨🏾' => 'زوج وقلب: سيدة، ورجل، وبشرة بلون معتدل، وبشرة بلون معتدل مائل للغامق',
    '👩🏽‍❤‍👨🏿' => 'زوج وقلب: سيدة، ورجل، وبشرة بلون معتدل، وبشرة بلون غامق',
    '👩🏾‍❤‍👨🏻' => 'زوج وقلب: سيدة، ورجل، وبشرة بلون معتدل مائل للغامق، وبشرة بلون فاتح',
    '👩🏾‍❤‍👨🏼' => 'زوج وقلب: سيدة، ورجل، وبشرة بلون معتدل مائل للغامق، وبشرة بلون فاتح ومعتدل',
    '👩🏾‍❤‍👨🏽' => 'زوج وقلب: سيدة، ورجل، وبشرة بلون معتدل مائل للغامق، وبشرة بلون معتدل',
    '👩🏾‍❤‍👨🏾' => 'زوج وقلب: سيدة، ورجل، وبشرة بلون معتدل مائل للغامق',
    '👩🏾‍❤‍👨🏿' => 'زوج وقلب: سيدة، ورجل، وبشرة بلون معتدل مائل للغامق، وبشرة بلون غامق',
    '👩🏿‍❤‍👨🏻' => 'زوج وقلب: سيدة، ورجل، وبشرة بلون غامق، وبشرة بلون فاتح',
    '👩🏿‍❤‍👨🏼' => 'زوج وقلب: سيدة، ورجل، وبشرة بلون غامق، وبشرة بلون فاتح ومعتدل',
    '👩🏿‍❤‍👨🏽' => 'زوج وقلب: سيدة، ورجل، وبشرة بلون غامق، وبشرة بلون معتدل',
    '👩🏿‍❤‍👨🏾' => 'زوج وقلب: سيدة، ورجل، وبشرة بلون غامق، وبشرة بلون معتدل مائل للغامق',
    '👩🏿‍❤‍👨🏿' => 'زوج وقلب: سيدة، ورجل، وبشرة بلون غامق',
    '👩🏻‍❤‍👩🏻' => 'زوج وقلب: سيدة، وسيدة، وبشرة بلون فاتح',
    '👩🏻‍❤‍👩🏼' => 'زوج وقلب: سيدة، وسيدة، وبشرة بلون فاتح، وبشرة بلون فاتح ومعتدل',
    '👩🏻‍❤‍👩🏽' => 'زوج وقلب: سيدة، وسيدة، وبشرة بلون فاتح، وبشرة بلون معتدل',
    '👩🏻‍❤‍👩🏾' => 'زوج وقلب: سيدة، وسيدة، وبشرة بلون فاتح، وبشرة بلون معتدل مائل للغامق',
    '👩🏻‍❤‍👩🏿' => 'زوج وقلب: سيدة، وسيدة، وبشرة بلون فاتح، وبشرة بلون غامق',
    '👩🏼‍❤‍👩🏻' => 'زوج وقلب: سيدة، وسيدة، وبشرة بلون فاتح ومعتدل، وبشرة بلون فاتح',
    '👩🏼‍❤‍👩🏼' => 'زوج وقلب: سيدة، وسيدة، وبشرة بلون فاتح ومعتدل',
    '👩🏼‍❤‍👩🏽' => 'زوج وقلب: سيدة، وسيدة، وبشرة بلون فاتح ومعتدل، وبشرة بلون معتدل',
    '👩🏼‍❤‍👩🏾' => 'زوج وقلب: سيدة، وسيدة، وبشرة بلون فاتح ومعتدل، وبشرة بلون معتدل مائل للغامق',
    '👩🏼‍❤‍👩🏿' => 'زوج وقلب: سيدة، وسيدة، وبشرة بلون فاتح ومعتدل، وبشرة بلون غامق',
    '👩🏽‍❤‍👩🏻' => 'زوج وقلب: سيدة، وسيدة، وبشرة بلون معتدل، وبشرة بلون فاتح',
    '👩🏽‍❤‍👩🏼' => 'زوج وقلب: سيدة، وسيدة، وبشرة بلون معتدل، وبشرة بلون فاتح ومعتدل',
    '👩🏽‍❤‍👩🏽' => 'زوج وقلب: سيدة، وسيدة، وبشرة بلون معتدل',
    '👩🏽‍❤‍👩🏾' => 'زوج وقلب: سيدة، وسيدة، وبشرة بلون معتدل، وبشرة بلون معتدل مائل للغامق',
    '👩🏽‍❤‍👩🏿' => 'زوج وقلب: سيدة، وسيدة، وبشرة بلون معتدل، وبشرة بلون غامق',
    '👩🏾‍❤‍👩🏻' => 'زوج وقلب: سيدة، وسيدة، وبشرة بلون معتدل مائل للغامق، وبشرة بلون فاتح',
    '👩🏾‍❤‍👩🏼' => 'زوج وقلب: سيدة، وسيدة، وبشرة بلون معتدل مائل للغامق، وبشرة بلون فاتح ومعتدل',
    '👩🏾‍❤‍👩🏽' => 'زوج وقلب: سيدة، وسيدة، وبشرة بلون معتدل مائل للغامق، وبشرة بلون معتدل',
    '👩🏾‍❤‍👩🏾' => 'زوج وقلب: سيدة، وسيدة، وبشرة بلون معتدل مائل للغامق',
    '👩🏾‍❤‍👩🏿' => 'زوج وقلب: سيدة، وسيدة، وبشرة بلون معتدل مائل للغامق، وبشرة بلون غامق',
    '👩🏿‍❤‍👩🏻' => 'زوج وقلب: سيدة، وسيدة، وبشرة بلون غامق، وبشرة بلون فاتح',
    '👩🏿‍❤‍👩🏼' => 'زوج وقلب: سيدة، وسيدة، وبشرة بلون غامق، وبشرة بلون فاتح ومعتدل',
    '👩🏿‍❤‍👩🏽' => 'زوج وقلب: سيدة، وسيدة، وبشرة بلون غامق، وبشرة بلون معتدل',
    '👩🏿‍❤‍👩🏾' => 'زوج وقلب: سيدة، وسيدة، وبشرة بلون غامق، وبشرة بلون معتدل مائل للغامق',
    '👩🏿‍❤‍👩🏿' => 'زوج وقلب: سيدة، وسيدة، وبشرة بلون غامق',
    '👩🏻‍🐰‍👩🏼' => 'امرأتان ترقصان: بشرة بلون فاتح وبشرة بلون فاتح ومعتدل',
    '👩🏻‍🐰‍👩🏽' => 'امرأتان ترقصان: بشرة بلون فاتح وبشرة بلون معتدل',
    '👩🏻‍🐰‍👩🏾' => 'امرأتان ترقصان: بشرة بلون فاتح وبشرة بلون معتدل مائل للغامق',
    '👩🏻‍🐰‍👩🏿' => 'امرأتان ترقصان: بشرة بلون فاتح وبشرة بلون غامق',
    '👩🏼‍🐰‍👩🏻' => 'امرأتان ترقصان: بشرة بلون فاتح ومعتدل وبشرة بلون فاتح',
    '👩🏼‍🐰‍👩🏽' => 'امرأتان ترقصان: بشرة بلون فاتح ومعتدل وبشرة بلون معتدل',
    '👩🏼‍🐰‍👩🏾' => 'امرأتان ترقصان: بشرة بلون فاتح ومعتدل وبشرة بلون معتدل مائل للغامق',
    '👩🏼‍🐰‍👩🏿' => 'امرأتان ترقصان: بشرة بلون فاتح ومعتدل وبشرة بلون غامق',
    '👩🏽‍🐰‍👩🏻' => 'امرأتان ترقصان: بشرة بلون معتدل وبشرة بلون فاتح',
    '👩🏽‍🐰‍👩🏼' => 'امرأتان ترقصان: بشرة بلون معتدل وبشرة بلون فاتح ومعتدل',
    '👩🏽‍🐰‍👩🏾' => 'امرأتان ترقصان: بشرة بلون معتدل وبشرة بلون معتدل مائل للغامق',
    '👩🏽‍🐰‍👩🏿' => 'امرأتان ترقصان: بشرة بلون معتدل وبشرة بلون غامق',
    '👩🏾‍🐰‍👩🏻' => 'امرأتان ترقصان: بشرة بلون معتدل مائل للغامق وبشرة بلون فاتح',
    '👩🏾‍🐰‍👩🏼' => 'امرأتان ترقصان: بشرة بلون معتدل مائل للغامق وبشرة بلون فاتح ومعتدل',
    '👩🏾‍🐰‍👩🏽' => 'امرأتان ترقصان: بشرة بلون معتدل مائل للغامق وبشرة بلون معتدل',
    '👩🏾‍🐰‍👩🏿' => 'امرأتان ترقصان: بشرة بلون معتدل مائل للغامق وبشرة بلون غامق',
    '👩🏿‍🐰‍👩🏻' => 'امرأتان ترقصان: بشرة بلون غامق وبشرة بلون فاتح',
    '👩🏿‍🐰‍👩🏼' => 'امرأتان ترقصان: بشرة بلون غامق وبشرة بلون فاتح ومعتدل',
    '👩🏿‍🐰‍👩🏽' => 'امرأتان ترقصان: بشرة بلون غامق وبشرة بلون معتدل',
    '👩🏿‍🐰‍👩🏾' => 'امرأتان ترقصان: بشرة بلون غامق وبشرة بلون معتدل مائل للغامق',
    '🧑🏻‍🤝‍🧑🏻' => 'أشخاص يمسكون بأيدي بعضهم: بشرة بلون فاتح',
    '🧑🏻‍🤝‍🧑🏼' => 'أشخاص يمسكون بأيدي بعضهم: بشرة بلون فاتح وبشرة بلون فاتح ومعتدل',
    '🧑🏻‍🤝‍🧑🏽' => 'أشخاص يمسكون بأيدي بعضهم: بشرة بلون فاتح وبشرة بلون معتدل',
    '🧑🏻‍🤝‍🧑🏾' => 'أشخاص يمسكون بأيدي بعضهم: بشرة بلون فاتح وبشرة بلون معتدل مائل للغامق',
    '🧑🏻‍🤝‍🧑🏿' => 'أشخاص يمسكون بأيدي بعضهم: بشرة بلون فاتح وبشرة بلون غامق',
    '🧑🏼‍🤝‍🧑🏻' => 'أشخاص يمسكون بأيدي بعضهم: بشرة بلون فاتح ومعتدل وبشرة بلون فاتح',
    '🧑🏼‍🤝‍🧑🏼' => 'أشخاص يمسكون بأيدي بعضهم: بشرة بلون فاتح ومعتدل',
    '🧑🏼‍🤝‍🧑🏽' => 'أشخاص يمسكون بأيدي بعضهم: بشرة بلون فاتح ومعتدل وبشرة بلون معتدل',
    '🧑🏼‍🤝‍🧑🏾' => 'أشخاص يمسكون بأيدي بعضهم: بشرة بلون فاتح ومعتدل وبشرة بلون معتدل مائل للغامق',
    '🧑🏼‍🤝‍🧑🏿' => 'أشخاص يمسكون بأيدي بعضهم: بشرة بلون فاتح ومعتدل وبشرة بلون غامق',
    '🧑🏽‍🤝‍🧑🏻' => 'أشخاص يمسكون بأيدي بعضهم: بشرة بلون معتدل وبشرة بلون فاتح',
    '🧑🏽‍🤝‍🧑🏼' => 'أشخاص يمسكون بأيدي بعضهم: بشرة بلون معتدل وبشرة بلون فاتح ومعتدل',
    '🧑🏽‍🤝‍🧑🏽' => 'أشخاص يمسكون بأيدي بعضهم: بشرة بلون معتدل',
    '🧑🏽‍🤝‍🧑🏾' => 'أشخاص يمسكون بأيدي بعضهم: بشرة بلون معتدل وبشرة بلون معتدل مائل للغامق',
    '🧑🏽‍🤝‍🧑🏿' => 'أشخاص يمسكون بأيدي بعضهم: بشرة بلون معتدل وبشرة بلون غامق',
    '🧑🏾‍🤝‍🧑🏻' => 'أشخاص يمسكون بأيدي بعضهم: بشرة بلون معتدل مائل للغامق وبشرة بلون فاتح',
    '🧑🏾‍🤝‍🧑🏼' => 'أشخاص يمسكون بأيدي بعضهم: بشرة بلون معتدل مائل للغامق وبشرة بلون فاتح ومعتدل',
    '🧑🏾‍🤝‍🧑🏽' => 'أشخاص يمسكون بأيدي بعضهم: بشرة بلون معتدل مائل للغامق وبشرة بلون معتدل',
    '🧑🏾‍🤝‍🧑🏾' => 'أشخاص يمسكون بأيدي بعضهم: بشرة بلون معتدل مائل للغامق',
    '🧑🏾‍🤝‍🧑🏿' => 'أشخاص يمسكون بأيدي بعضهم: بشرة بلون معتدل مائل للغامق وبشرة بلون غامق',
    '🧑🏿‍🤝‍🧑🏻' => 'أشخاص يمسكون بأيدي بعضهم: بشرة بلون غامق وبشرة بلون فاتح',
    '🧑🏿‍🤝‍🧑🏼' => 'أشخاص يمسكون بأيدي بعضهم: بشرة بلون غامق وبشرة بلون فاتح ومعتدل',
    '🧑🏿‍🤝‍🧑🏽' => 'أشخاص يمسكون بأيدي بعضهم: بشرة بلون غامق وبشرة بلون معتدل',
    '🧑🏿‍🤝‍🧑🏾' => 'أشخاص يمسكون بأيدي بعضهم: بشرة بلون غامق وبشرة بلون معتدل مائل للغامق',
    '🧑🏿‍🤝‍🧑🏿' => 'أشخاص يمسكون بأيدي بعضهم: بشرة بلون غامق',
    '👩🏻‍🤝‍👩🏼' => 'امرأتان تمسكان بيد بعضهما: بشرة بلون فاتح وبشرة بلون فاتح ومعتدل',
    '👩🏻‍🤝‍👩🏽' => 'امرأتان تمسكان بيد بعضهما: بشرة بلون فاتح وبشرة بلون معتدل',
    '👩🏻‍🤝‍👩🏾' => 'امرأتان تمسكان بيد بعضهما: بشرة بلون فاتح وبشرة بلون معتدل مائل للغامق',
    '👩🏻‍🤝‍👩🏿' => 'امرأتان تمسكان بيد بعضهما: بشرة بلون فاتح وبشرة بلون غامق',
    '👩🏼‍🤝‍👩🏻' => 'امرأتان تمسكان بيد بعضهما: بشرة بلون فاتح ومعتدل وبشرة بلون فاتح',
    '👩🏼‍🤝‍👩🏽' => 'امرأتان تمسكان بيد بعضهما: بشرة بلون فاتح ومعتدل وبشرة بلون معتدل',
    '👩🏼‍🤝‍👩🏾' => 'امرأتان تمسكان بيد بعضهما: بشرة بلون فاتح ومعتدل وبشرة بلون معتدل مائل للغامق',
    '👩🏼‍🤝‍👩🏿' => 'امرأتان تمسكان بيد بعضهما: بشرة بلون فاتح ومعتدل وبشرة بلون غامق',
    '👩🏽‍🤝‍👩🏻' => 'امرأتان تمسكان بيد بعضهما: بشرة بلون معتدل وبشرة بلون فاتح',
    '👩🏽‍🤝‍👩🏼' => 'امرأتان تمسكان بيد بعضهما: بشرة بلون معتدل وبشرة بلون فاتح ومعتدل',
    '👩🏽‍🤝‍👩🏾' => 'امرأتان تمسكان بيد بعضهما: بشرة بلون معتدل وبشرة بلون معتدل مائل للغامق',
    '👩🏽‍🤝‍👩🏿' => 'امرأتان تمسكان بيد بعضهما: بشرة بلون معتدل وبشرة بلون غامق',
    '👩🏾‍🤝‍👩🏻' => 'امرأتان تمسكان بيد بعضهما: بشرة بلون معتدل مائل للغامق وبشرة بلون فاتح',
    '👩🏾‍🤝‍👩🏼' => 'امرأتان تمسكان بيد بعضهما: بشرة بلون معتدل مائل للغامق وبشرة بلون فاتح ومعتدل',
    '👩🏾‍🤝‍👩🏽' => 'امرأتان تمسكان بيد بعضهما: بشرة بلون معتدل مائل للغامق وبشرة بلون معتدل',
    '👩🏾‍🤝‍👩🏿' => 'امرأتان تمسكان بيد بعضهما: بشرة بلون معتدل مائل للغامق وبشرة بلون غامق',
    '👩🏿‍🤝‍👩🏻' => 'امرأتان تمسكان بيد بعضهما: بشرة بلون غامق وبشرة بلون فاتح',
    '👩🏿‍🤝‍👩🏼' => 'امرأتان تمسكان بيد بعضهما: بشرة بلون غامق وبشرة بلون فاتح ومعتدل',
    '👩🏿‍🤝‍👩🏽' => 'امرأتان تمسكان بيد بعضهما: بشرة بلون غامق وبشرة بلون معتدل',
    '👩🏿‍🤝‍👩🏾' => 'امرأتان تمسكان بيد بعضهما: بشرة بلون غامق وبشرة بلون معتدل مائل للغامق',
    '👩🏻‍🤝‍👨🏼' => 'رجل وامرأة يمسكان بيد بعضهما: بشرة بلون فاتح وبشرة بلون فاتح ومعتدل',
    '👩🏻‍🤝‍👨🏽' => 'رجل وامرأة يمسكان بيد بعضهما: بشرة بلون فاتح وبشرة بلون معتدل',
    '👩🏻‍🤝‍👨🏾' => 'رجل وامرأة يمسكان بيد بعضهما: بشرة بلون فاتح وبشرة بلون معتدل مائل للغامق',
    '👩🏻‍🤝‍👨🏿' => 'رجل وامرأة يمسكان بيد بعضهما: بشرة بلون فاتح وبشرة بلون غامق',
    '👩🏼‍🤝‍👨🏻' => 'رجل وامرأة يمسكان بيد بعضهما: بشرة بلون فاتح ومعتدل وبشرة بلون فاتح',
    '👩🏼‍🤝‍👨🏽' => 'رجل وامرأة يمسكان بيد بعضهما: بشرة بلون فاتح ومعتدل وبشرة بلون معتدل',
    '👩🏼‍🤝‍👨🏾' => 'رجل وامرأة يمسكان بيد بعضهما: بشرة بلون فاتح ومعتدل وبشرة بلون معتدل مائل للغامق',
    '👩🏼‍🤝‍👨🏿' => 'رجل وامرأة يمسكان بيد بعضهما: بشرة بلون فاتح ومعتدل وبشرة بلون غامق',
    '👩🏽‍🤝‍👨🏻' => 'رجل وامرأة يمسكان بيد بعضهما: بشرة بلون معتدل وبشرة بلون فاتح',
    '👩🏽‍🤝‍👨🏼' => 'رجل وامرأة يمسكان بيد بعضهما: بشرة بلون معتدل وبشرة بلون فاتح ومعتدل',
    '👩🏽‍🤝‍👨🏾' => 'رجل وامرأة يمسكان بيد بعضهما: بشرة بلون معتدل وبشرة بلون معتدل مائل للغامق',
    '👩🏽‍🤝‍👨🏿' => 'رجل وامرأة يمسكان بيد بعضهما: بشرة بلون معتدل وبشرة بلون غامق',
    '👩🏾‍🤝‍👨🏻' => 'رجل وامرأة يمسكان بيد بعضهما: بشرة بلون معتدل مائل للغامق وبشرة بلون فاتح',
    '👩🏾‍🤝‍👨🏼' => 'رجل وامرأة يمسكان بيد بعضهما: بشرة بلون معتدل مائل للغامق وبشرة بلون فاتح ومعتدل',
    '👩🏾‍🤝‍👨🏽' => 'رجل وامرأة يمسكان بيد بعضهما: بشرة بلون معتدل مائل للغامق وبشرة بلون معتدل',
    '👩🏾‍🤝‍👨🏿' => 'رجل وامرأة يمسكان بيد بعضهما: بشرة بلون معتدل مائل للغامق وبشرة بلون غامق',
    '👩🏿‍🤝‍👨🏻' => 'رجل وامرأة يمسكان بيد بعضهما: بشرة بلون غامق وبشرة بلون فاتح',
    '👩🏿‍🤝‍👨🏼' => 'رجل وامرأة يمسكان بيد بعضهما: بشرة بلون غامق وبشرة بلون فاتح ومعتدل',
    '👩🏿‍🤝‍👨🏽' => 'رجل وامرأة يمسكان بيد بعضهما: بشرة بلون غامق وبشرة بلون معتدل',
    '👩🏿‍🤝‍👨🏾' => 'رجل وامرأة يمسكان بيد بعضهما: بشرة بلون غامق وبشرة بلون معتدل مائل للغامق',
    '👨🏻‍🤝‍👨🏼' => 'رجلان يمسكان بيد بعضهما: بشرة بلون فاتح وبشرة بلون فاتح ومعتدل',
    '👨🏻‍🤝‍👨🏽' => 'رجلان يمسكان بيد بعضهما: بشرة بلون فاتح وبشرة بلون معتدل',
    '👨🏻‍🤝‍👨🏾' => 'رجلان يمسكان بيد بعضهما: بشرة بلون فاتح وبشرة بلون معتدل مائل للغامق',
    '👨🏻‍🤝‍👨🏿' => 'رجلان يمسكان بيد بعضهما: بشرة بلون فاتح وبشرة بلون غامق',
    '👨🏼‍🤝‍👨🏻' => 'رجلان يمسكان بيد بعضهما: بشرة بلون فاتح ومعتدل وبشرة بلون فاتح',
    '👨🏼‍🤝‍👨🏽' => 'رجلان يمسكان بيد بعضهما: بشرة بلون فاتح ومعتدل وبشرة بلون معتدل',
    '👨🏼‍🤝‍👨🏾' => 'رجلان يمسكان بيد بعضهما: بشرة بلون فاتح ومعتدل وبشرة بلون معتدل مائل للغامق',
    '👨🏼‍🤝‍👨🏿' => 'رجلان يمسكان بيد بعضهما: بشرة بلون فاتح ومعتدل وبشرة بلون غامق',
    '👨🏽‍🤝‍👨🏻' => 'رجلان يمسكان بيد بعضهما: بشرة بلون معتدل وبشرة بلون فاتح',
    '👨🏽‍🤝‍👨🏼' => 'رجلان يمسكان بيد بعضهما: بشرة بلون معتدل وبشرة بلون فاتح ومعتدل',
    '👨🏽‍🤝‍👨🏾' => 'رجلان يمسكان بيد بعضهما: بشرة بلون معتدل وبشرة بلون معتدل مائل للغامق',
    '👨🏽‍🤝‍👨🏿' => 'رجلان يمسكان بيد بعضهما: بشرة بلون معتدل وبشرة بلون غامق',
    '👨🏾‍🤝‍👨🏻' => 'رجلان يمسكان بيد بعضهما: بشرة بلون معتدل مائل للغامق وبشرة بلون فاتح',
    '👨🏾‍🤝‍👨🏼' => 'رجلان يمسكان بيد بعضهما: بشرة بلون معتدل مائل للغامق وبشرة بلون فاتح ومعتدل',
    '👨🏾‍🤝‍👨🏽' => 'رجلان يمسكان بيد بعضهما: بشرة بلون معتدل مائل للغامق وبشرة بلون معتدل',
    '👨🏾‍🤝‍👨🏿' => 'رجلان يمسكان بيد بعضهما: بشرة بلون معتدل مائل للغامق وبشرة بلون غامق',
    '👨🏿‍🤝‍👨🏻' => 'رجلان يمسكان بيد بعضهما: بشرة بلون غامق وبشرة بلون فاتح',
    '👨🏿‍🤝‍👨🏼' => 'رجلان يمسكان بيد بعضهما: بشرة بلون غامق وبشرة بلون فاتح ومعتدل',
    '👨🏿‍🤝‍👨🏽' => 'رجلان يمسكان بيد بعضهما: بشرة بلون غامق وبشرة بلون معتدل',
    '👨🏿‍🤝‍👨🏾' => 'رجلان يمسكان بيد بعضهما: بشرة بلون غامق وبشرة بلون معتدل مائل للغامق',
    '👩‍❤‍💋‍👨' => 'قبلة: سيدة ورجل',
    '👨‍❤‍💋‍👨' => 'قبلة: رجل ورجل',
    '👩‍❤‍💋‍👩' => 'قبلة: سيدة وسيدة',
    '👨‍👩‍👧‍👦' => 'أسرة: رجل، وسيدة، وفتاة، وصبي',
    '👨‍👩‍👦‍👦' => 'أسرة: رجل، وسيدة، وصبي، وصبي',
    '👨‍👩‍👧‍👧' => 'أسرة: رجل، وسيدة، وفتاة، وفتاة',
    '👨‍👨‍👧‍👦' => 'أسرة: رجل، ورجل، وفتاة، وصبي',
    '👨‍👨‍👦‍👦' => 'أسرة: رجل، ورجل، وصبي، وصبي',
    '👨‍👨‍👧‍👧' => 'أسرة: رجل، ورجل، وفتاة، وفتاة',
    '👩‍👩‍👧‍👦' => 'أسرة: سيدة، وسيدة، وفتاة، وصبي',
    '👩‍👩‍👦‍👦' => 'أسرة: سيدة، وسيدة، وصبي، وصبي',
    '👩‍👩‍👧‍👧' => 'أسرة: سيدة، وسيدة، وفتاة، وفتاة',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'علم: إنجلترا',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'علم: اسكتلندا',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'علم: ويلز',
    '🧑‍🧑‍🧒‍🧒' => 'أسرة: بالغ، بالغة، طفل، طفلة',
    '🚶🏻‍♀‍➡' => 'سائرة: بشرة بلون فاتح ومتجه لليمين',
    '🚶🏼‍♀‍➡' => 'سائرة: بشرة بلون فاتح ومعتدل ومتجه لليمين',
    '🚶🏽‍♀‍➡' => 'سائرة: بشرة بلون معتدل ومتجه لليمين',
    '🚶🏾‍♀‍➡' => 'سائرة: بشرة بلون معتدل مائل للغامق ومتجه لليمين',
    '🚶🏿‍♀‍➡' => 'سائرة: بشرة بلون غامق ومتجه لليمين',
    '🚶🏻‍♂‍➡' => 'سائر: بشرة بلون فاتح ومتجه لليمين',
    '🚶🏼‍♂‍➡' => 'سائر: بشرة بلون فاتح ومعتدل ومتجه لليمين',
    '🚶🏽‍♂‍➡' => 'سائر: بشرة بلون معتدل ومتجه لليمين',
    '🚶🏾‍♂‍➡' => 'سائر: بشرة بلون معتدل مائل للغامق ومتجه لليمين',
    '🚶🏿‍♂‍➡' => 'سائر: بشرة بلون غامق ومتجه لليمين',
    '🧎🏻‍♀‍➡' => 'سيدة جالسة على ركبتيها: بشرة بلون فاتح ومتجه لليمين',
    '🧎🏼‍♀‍➡' => 'سيدة جالسة على ركبتيها: بشرة بلون فاتح ومعتدل ومتجه لليمين',
    '🧎🏽‍♀‍➡' => 'سيدة جالسة على ركبتيها: بشرة بلون معتدل ومتجه لليمين',
    '🧎🏾‍♀‍➡' => 'سيدة جالسة على ركبتيها: بشرة بلون معتدل مائل للغامق ومتجه لليمين',
    '🧎🏿‍♀‍➡' => 'سيدة جالسة على ركبتيها: بشرة بلون غامق ومتجه لليمين',
    '🧎🏻‍♂‍➡' => 'رجل جالس على ركبتيه: بشرة بلون فاتح ومتجه لليمين',
    '🧎🏼‍♂‍➡' => 'رجل جالس على ركبتيه: بشرة بلون فاتح ومعتدل ومتجه لليمين',
    '🧎🏽‍♂‍➡' => 'رجل جالس على ركبتيه: بشرة بلون معتدل ومتجه لليمين',
    '🧎🏾‍♂‍➡' => 'رجل جالس على ركبتيه: بشرة بلون معتدل مائل للغامق ومتجه لليمين',
    '🧎🏿‍♂‍➡' => 'رجل جالس على ركبتيه: بشرة بلون غامق ومتجه لليمين',
    '🧑🏻‍🦯‍➡' => 'شخص مع عصا سير: بشرة بلون فاتح ومتجه لليمين',
    '🧑🏼‍🦯‍➡' => 'شخص مع عصا سير: بشرة بلون فاتح ومعتدل ومتجه لليمين',
    '🧑🏽‍🦯‍➡' => 'شخص مع عصا سير: بشرة بلون معتدل ومتجه لليمين',
    '🧑🏾‍🦯‍➡' => 'شخص مع عصا سير: بشرة بلون معتدل مائل للغامق ومتجه لليمين',
    '🧑🏿‍🦯‍➡' => 'شخص مع عصا سير: بشرة بلون غامق ومتجه لليمين',
    '👨🏻‍🦯‍➡' => 'رجل بعصا سير: بشرة بلون فاتح ومتجه لليمين',
    '👨🏼‍🦯‍➡' => 'رجل بعصا سير: بشرة بلون فاتح ومعتدل ومتجه لليمين',
    '👨🏽‍🦯‍➡' => 'رجل بعصا سير: بشرة بلون معتدل ومتجه لليمين',
    '👨🏾‍🦯‍➡' => 'رجل بعصا سير: بشرة بلون معتدل مائل للغامق ومتجه لليمين',
    '👨🏿‍🦯‍➡' => 'رجل بعصا سير: بشرة بلون غامق ومتجه لليمين',
    '👩🏻‍🦯‍➡' => 'سيدة بعصا سير: بشرة بلون فاتح ومتجه لليمين',
    '👩🏼‍🦯‍➡' => 'سيدة بعصا سير: بشرة بلون فاتح ومعتدل ومتجه لليمين',
    '👩🏽‍🦯‍➡' => 'سيدة بعصا سير: بشرة بلون معتدل ومتجه لليمين',
    '👩🏾‍🦯‍➡' => 'سيدة بعصا سير: بشرة بلون معتدل مائل للغامق ومتجه لليمين',
    '👩🏿‍🦯‍➡' => 'سيدة بعصا سير: بشرة بلون غامق ومتجه لليمين',
    '🧑🏻‍🦼‍➡' => 'شخص على كرسي متحرك كهربائي: بشرة بلون فاتح ومتجه لليمين',
    '🧑🏼‍🦼‍➡' => 'شخص على كرسي متحرك كهربائي: بشرة بلون فاتح ومعتدل ومتجه لليمين',
    '🧑🏽‍🦼‍➡' => 'شخص على كرسي متحرك كهربائي: بشرة بلون معتدل ومتجه لليمين',
    '🧑🏾‍🦼‍➡' => 'شخص على كرسي متحرك كهربائي: بشرة بلون معتدل مائل للغامق ومتجه لليمين',
    '🧑🏿‍🦼‍➡' => 'شخص على كرسي متحرك كهربائي: بشرة بلون غامق ومتجه لليمين',
    '👨🏻‍🦼‍➡' => 'رجل على كرسي متحرك كهربائي: بشرة بلون فاتح ومتجه لليمين',
    '👨🏼‍🦼‍➡' => 'رجل على كرسي متحرك كهربائي: بشرة بلون فاتح ومعتدل ومتجه لليمين',
    '👨🏽‍🦼‍➡' => 'رجل على كرسي متحرك كهربائي: بشرة بلون معتدل ومتجه لليمين',
    '👨🏾‍🦼‍➡' => 'رجل على كرسي متحرك كهربائي: بشرة بلون معتدل مائل للغامق ومتجه لليمين',
    '👨🏿‍🦼‍➡' => 'رجل على كرسي متحرك كهربائي: بشرة بلون غامق ومتجه لليمين',
    '👩🏻‍🦼‍➡' => 'سيدة على كرسي متحرك كهربائي: بشرة بلون فاتح ومتجه لليمين',
    '👩🏼‍🦼‍➡' => 'سيدة على كرسي متحرك كهربائي: بشرة بلون فاتح ومعتدل ومتجه لليمين',
    '👩🏽‍🦼‍➡' => 'سيدة على كرسي متحرك كهربائي: بشرة بلون معتدل ومتجه لليمين',
    '👩🏾‍🦼‍➡' => 'سيدة على كرسي متحرك كهربائي: بشرة بلون معتدل مائل للغامق ومتجه لليمين',
    '👩🏿‍🦼‍➡' => 'سيدة على كرسي متحرك كهربائي: بشرة بلون غامق ومتجه لليمين',
    '🧑🏻‍🦽‍➡' => 'شخص على كرسي متحرك يدوي: بشرة بلون فاتح ومتجه لليمين',
    '🧑🏼‍🦽‍➡' => 'شخص على كرسي متحرك يدوي: بشرة بلون فاتح ومعتدل ومتجه لليمين',
    '🧑🏽‍🦽‍➡' => 'شخص على كرسي متحرك يدوي: بشرة بلون معتدل ومتجه لليمين',
    '🧑🏾‍🦽‍➡' => 'شخص على كرسي متحرك يدوي: بشرة بلون معتدل مائل للغامق ومتجه لليمين',
    '🧑🏿‍🦽‍➡' => 'شخص على كرسي متحرك يدوي: بشرة بلون غامق ومتجه لليمين',
    '👨🏻‍🦽‍➡' => 'رجل على كرسي متحرك يدوي: بشرة بلون فاتح ومتجه لليمين',
    '👨🏼‍🦽‍➡' => 'رجل على كرسي متحرك يدوي: بشرة بلون فاتح ومعتدل ومتجه لليمين',
    '👨🏽‍🦽‍➡' => 'رجل على كرسي متحرك يدوي: بشرة بلون معتدل ومتجه لليمين',
    '👨🏾‍🦽‍➡' => 'رجل على كرسي متحرك يدوي: بشرة بلون معتدل مائل للغامق ومتجه لليمين',
    '👨🏿‍🦽‍➡' => 'رجل على كرسي متحرك يدوي: بشرة بلون غامق ومتجه لليمين',
    '👩🏻‍🦽‍➡' => 'سيدة على كرسي متحرك يدوي: بشرة بلون فاتح ومتجه لليمين',
    '👩🏼‍🦽‍➡' => 'سيدة على كرسي متحرك يدوي: بشرة بلون فاتح ومعتدل ومتجه لليمين',
    '👩🏽‍🦽‍➡' => 'سيدة على كرسي متحرك يدوي: بشرة بلون معتدل ومتجه لليمين',
    '👩🏾‍🦽‍➡' => 'سيدة على كرسي متحرك يدوي: بشرة بلون معتدل مائل للغامق ومتجه لليمين',
    '👩🏿‍🦽‍➡' => 'سيدة على كرسي متحرك يدوي: بشرة بلون غامق ومتجه لليمين',
    '🏃🏻‍♀‍➡' => 'راكضة: بشرة بلون فاتح ومتجه لليمين',
    '🏃🏼‍♀‍➡' => 'راكضة: بشرة بلون فاتح ومعتدل ومتجه لليمين',
    '🏃🏽‍♀‍➡' => 'راكضة: بشرة بلون معتدل ومتجه لليمين',
    '🏃🏾‍♀‍➡' => 'راكضة: بشرة بلون معتدل مائل للغامق ومتجه لليمين',
    '🏃🏿‍♀‍➡' => 'راكضة: بشرة بلون غامق ومتجه لليمين',
    '🏃🏻‍♂‍➡' => 'راكض: بشرة بلون فاتح ومتجه لليمين',
    '🏃🏼‍♂‍➡' => 'راكض: بشرة بلون فاتح ومعتدل ومتجه لليمين',
    '🏃🏽‍♂‍➡' => 'راكض: بشرة بلون معتدل ومتجه لليمين',
    '🏃🏾‍♂‍➡' => 'راكض: بشرة بلون معتدل مائل للغامق ومتجه لليمين',
    '🏃🏿‍♂‍➡' => 'راكض: بشرة بلون غامق ومتجه لليمين',
    '🫱🏻‍🫲🏼' => 'مصافحة: بشرة بلون فاتح وبشرة بلون فاتح ومعتدل',
    '🫱🏻‍🫲🏽' => 'مصافحة: بشرة بلون فاتح وبشرة بلون معتدل',
    '🫱🏻‍🫲🏾' => 'مصافحة: بشرة بلون فاتح وبشرة بلون معتدل مائل للغامق',
    '🫱🏻‍🫲🏿' => 'مصافحة: بشرة بلون فاتح وبشرة بلون غامق',
    '🫱🏼‍🫲🏻' => 'مصافحة: بشرة بلون فاتح ومعتدل وبشرة بلون فاتح',
    '🫱🏼‍🫲🏽' => 'مصافحة: بشرة بلون فاتح ومعتدل وبشرة بلون معتدل',
    '🫱🏼‍🫲🏾' => 'مصافحة: بشرة بلون فاتح ومعتدل وبشرة بلون معتدل مائل للغامق',
    '🫱🏼‍🫲🏿' => 'مصافحة: بشرة بلون فاتح ومعتدل وبشرة بلون غامق',
    '🫱🏽‍🫲🏻' => 'مصافحة: بشرة بلون معتدل وبشرة بلون فاتح',
    '🫱🏽‍🫲🏼' => 'مصافحة: بشرة بلون معتدل وبشرة بلون فاتح ومعتدل',
    '🫱🏽‍🫲🏾' => 'مصافحة: بشرة بلون معتدل وبشرة بلون معتدل مائل للغامق',
    '🫱🏽‍🫲🏿' => 'مصافحة: بشرة بلون معتدل وبشرة بلون غامق',
    '🫱🏾‍🫲🏻' => 'مصافحة: بشرة بلون معتدل مائل للغامق وبشرة بلون فاتح',
    '🫱🏾‍🫲🏼' => 'مصافحة: بشرة بلون معتدل مائل للغامق وبشرة بلون فاتح ومعتدل',
    '🫱🏾‍🫲🏽' => 'مصافحة: بشرة بلون معتدل مائل للغامق وبشرة بلون معتدل',
    '🫱🏾‍🫲🏿' => 'مصافحة: بشرة بلون معتدل مائل للغامق وبشرة بلون غامق',
    '🫱🏿‍🫲🏻' => 'مصافحة: بشرة بلون غامق وبشرة بلون فاتح',
    '🫱🏿‍🫲🏼' => 'مصافحة: بشرة بلون غامق وبشرة بلون فاتح ومعتدل',
    '🫱🏿‍🫲🏽' => 'مصافحة: بشرة بلون غامق وبشرة بلون معتدل',
    '🫱🏿‍🫲🏾' => 'مصافحة: بشرة بلون غامق وبشرة بلون معتدل مائل للغامق',
    '🚶‍♀‍➡' => 'سائرة: متجه لليمين',
    '🚶‍♂‍➡' => 'سائر: متجه لليمين',
    '🧎‍♀‍➡' => 'سيدة جالسة على ركبتيها: متجه لليمين',
    '🧎‍♂‍➡' => 'رجل جالس على ركبتيه: متجه لليمين',
    '🧑‍🦯‍➡' => 'شخص مع عصا سير: متجه لليمين',
    '👨‍🦯‍➡' => 'رجل بعصا سير: متجه لليمين',
    '👩‍🦯‍➡' => 'سيدة بعصا سير: متجه لليمين',
    '🧑‍🦼‍➡' => 'شخص على كرسي متحرك كهربائي: متجه لليمين',
    '👨‍🦼‍➡' => 'رجل على كرسي متحرك كهربائي: متجه لليمين',
    '👩‍🦼‍➡' => 'سيدة على كرسي متحرك كهربائي: متجه لليمين',
    '🧑‍🦽‍➡' => 'شخص على كرسي متحرك يدوي: متجه لليمين',
    '👨‍🦽‍➡' => 'رجل على كرسي متحرك يدوي: متجه لليمين',
    '👩‍🦽‍➡' => 'سيدة على كرسي متحرك يدوي: متجه لليمين',
    '🏃‍♀‍➡' => 'راكضة: متجه لليمين',
    '🏃‍♂‍➡' => 'راكض: متجه لليمين',
    '👩‍❤‍👨' => 'زوج وقلب: سيدة ورجل',
    '👨‍❤‍👨' => 'زوج وقلب: رجل ورجل',
    '👩‍❤‍👩' => 'زوج وقلب: سيدة وسيدة',
    '👨‍👩‍👦' => 'أسرة: رجل، وسيدة، وصبي',
    '👨‍👩‍👧' => 'أسرة: رجل، وسيدة، وفتاة',
    '👨‍👨‍👦' => 'أسرة: رجل، ورجل، وصبي',
    '👨‍👨‍👧' => 'أسرة: رجل، ورجل، وفتاة',
    '👩‍👩‍👦' => 'أسرة: سيدة، وسيدة، وصبي',
    '👩‍👩‍👧' => 'أسرة: سيدة، وسيدة، وفتاة',
    '👨‍👦‍👦' => 'أسرة: رجل، وصبي، وصبي',
    '👨‍👧‍👦' => 'أسرة: رجل، وفتاة، وصبي',
    '👨‍👧‍👧' => 'أسرة: رجل، وفتاة، وفتاة',
    '👩‍👦‍👦' => 'أسرة: سيدة، وصبي، وصبي',
    '👩‍👧‍👦' => 'أسرة: سيدة، وفتاة، وصبي',
    '👩‍👧‍👧' => 'أسرة: سيدة، وفتاة، وفتاة',
    '🧑‍🤝‍🧑' => 'أشخاص يمسكون بأيدي بعضهم',
    '🧑‍🧑‍🧒' => 'أسرة: بالغ، بالغة، طفل',
    '🧑‍🧒‍🧒' => 'أسرة: بالغ، طفل، طفلة',
    '🧑🏻‍🦰' => 'بالغ: بشرة بلون فاتح وشعر أحمر',
    '🧑🏼‍🦰' => 'بالغ: بشرة بلون فاتح ومعتدل وشعر أحمر',
    '🧑🏽‍🦰' => 'بالغ: بشرة بلون معتدل وشعر أحمر',
    '🧑🏾‍🦰' => 'بالغ: بشرة بلون معتدل مائل للغامق وشعر أحمر',
    '🧑🏿‍🦰' => 'بالغ: بشرة بلون غامق وشعر أحمر',
    '🧑🏻‍🦱' => 'بالغ: بشرة بلون فاتح وشعر مجعد',
    '🧑🏼‍🦱' => 'بالغ: بشرة بلون فاتح ومعتدل وشعر مجعد',
    '🧑🏽‍🦱' => 'بالغ: بشرة بلون معتدل وشعر مجعد',
    '🧑🏾‍🦱' => 'بالغ: بشرة بلون معتدل مائل للغامق وشعر مجعد',
    '🧑🏿‍🦱' => 'بالغ: بشرة بلون غامق وشعر مجعد',
    '🧑🏻‍🦳' => 'بالغ: بشرة بلون فاتح وشعر أبيض',
    '🧑🏼‍🦳' => 'بالغ: بشرة بلون فاتح ومعتدل وشعر أبيض',
    '🧑🏽‍🦳' => 'بالغ: بشرة بلون معتدل وشعر أبيض',
    '🧑🏾‍🦳' => 'بالغ: بشرة بلون معتدل مائل للغامق وشعر أبيض',
    '🧑🏿‍🦳' => 'بالغ: بشرة بلون غامق وشعر أبيض',
    '🧑🏻‍🦲' => 'بالغ: بشرة بلون فاتح وأصلع',
    '🧑🏼‍🦲' => 'بالغ: بشرة بلون فاتح ومعتدل وأصلع',
    '🧑🏽‍🦲' => 'بالغ: بشرة بلون معتدل وأصلع',
    '🧑🏾‍🦲' => 'بالغ: بشرة بلون معتدل مائل للغامق وأصلع',
    '🧑🏿‍🦲' => 'بالغ: بشرة بلون غامق وأصلع',
    '🧑🏻‍🩰' => 'راقصة باليه: بشرة بلون فاتح',
    '🧑🏼‍🩰' => 'راقصة باليه: بشرة بلون فاتح ومعتدل',
    '🧑🏽‍🩰' => 'راقصة باليه: بشرة بلون معتدل',
    '🧑🏾‍🩰' => 'راقصة باليه: بشرة بلون معتدل مائل للغامق',
    '🧑🏿‍🩰' => 'راقصة باليه: بشرة بلون غامق',
    '🧔🏻‍♂' => 'رجل بلحية: بشرة بلون فاتح',
    '🧔🏼‍♂' => 'رجل بلحية: بشرة بلون فاتح ومعتدل',
    '🧔🏽‍♂' => 'رجل بلحية: بشرة بلون معتدل',
    '🧔🏾‍♂' => 'رجل بلحية: بشرة بلون معتدل مائل للغامق',
    '🧔🏿‍♂' => 'رجل بلحية: بشرة بلون غامق',
    '👱🏻‍♂' => 'رجل أشقر: بشرة بلون فاتح',
    '👱🏼‍♂' => 'رجل أشقر: بشرة بلون فاتح ومعتدل',
    '👱🏽‍♂' => 'رجل أشقر: بشرة بلون معتدل',
    '👱🏾‍♂' => 'رجل أشقر: بشرة بلون معتدل مائل للغامق',
    '👱🏿‍♂' => 'رجل أشقر: بشرة بلون غامق',
    '👨🏻‍🦰' => 'رجل: بشرة بلون فاتح وشعر أحمر',
    '👨🏼‍🦰' => 'رجل: بشرة بلون فاتح ومعتدل وشعر أحمر',
    '👨🏽‍🦰' => 'رجل: بشرة بلون معتدل وشعر أحمر',
    '👨🏾‍🦰' => 'رجل: بشرة بلون معتدل مائل للغامق وشعر أحمر',
    '👨🏿‍🦰' => 'رجل: بشرة بلون غامق وشعر أحمر',
    '👨🏻‍🦱' => 'رجل: بشرة بلون فاتح وشعر مجعد',
    '👨🏼‍🦱' => 'رجل: بشرة بلون فاتح ومعتدل وشعر مجعد',
    '👨🏽‍🦱' => 'رجل: بشرة بلون معتدل وشعر مجعد',
    '👨🏾‍🦱' => 'رجل: بشرة بلون معتدل مائل للغامق وشعر مجعد',
    '👨🏿‍🦱' => 'رجل: بشرة بلون غامق وشعر مجعد',
    '👨🏻‍🦳' => 'رجل: بشرة بلون فاتح وشعر أبيض',
    '👨🏼‍🦳' => 'رجل: بشرة بلون فاتح ومعتدل وشعر أبيض',
    '👨🏽‍🦳' => 'رجل: بشرة بلون معتدل وشعر أبيض',
    '👨🏾‍🦳' => 'رجل: بشرة بلون معتدل مائل للغامق وشعر أبيض',
    '👨🏿‍🦳' => 'رجل: بشرة بلون غامق وشعر أبيض',
    '👨🏻‍🦲' => 'رجل: بشرة بلون فاتح وأصلع',
    '👨🏼‍🦲' => 'رجل: بشرة بلون فاتح ومعتدل وأصلع',
    '👨🏽‍🦲' => 'رجل: بشرة بلون معتدل وأصلع',
    '👨🏾‍🦲' => 'رجل: بشرة بلون معتدل مائل للغامق وأصلع',
    '👨🏿‍🦲' => 'رجل: بشرة بلون غامق وأصلع',
    '🧔🏻‍♀' => 'امرأة بلحية: بشرة بلون فاتح',
    '🧔🏼‍♀' => 'امرأة بلحية: بشرة بلون فاتح ومعتدل',
    '🧔🏽‍♀' => 'امرأة بلحية: بشرة بلون معتدل',
    '🧔🏾‍♀' => 'امرأة بلحية: بشرة بلون معتدل مائل للغامق',
    '🧔🏿‍♀' => 'امرأة بلحية: بشرة بلون غامق',
    '👱🏻‍♀' => 'امرأة شقراء: بشرة بلون فاتح',
    '👱🏼‍♀' => 'امرأة شقراء: بشرة بلون فاتح ومعتدل',
    '👱🏽‍♀' => 'امرأة شقراء: بشرة بلون معتدل',
    '👱🏾‍♀' => 'امرأة شقراء: بشرة بلون معتدل مائل للغامق',
    '👱🏿‍♀' => 'امرأة شقراء: بشرة بلون غامق',
    '👩🏻‍🦰' => 'سيدة: بشرة بلون فاتح وشعر أحمر',
    '👩🏼‍🦰' => 'سيدة: بشرة بلون فاتح ومعتدل وشعر أحمر',
    '👩🏽‍🦰' => 'سيدة: بشرة بلون معتدل وشعر أحمر',
    '👩🏾‍🦰' => 'سيدة: بشرة بلون معتدل مائل للغامق وشعر أحمر',
    '👩🏿‍🦰' => 'سيدة: بشرة بلون غامق وشعر أحمر',
    '👩🏻‍🦱' => 'سيدة: بشرة بلون فاتح وشعر مجعد',
    '👩🏼‍🦱' => 'سيدة: بشرة بلون فاتح ومعتدل وشعر مجعد',
    '👩🏽‍🦱' => 'سيدة: بشرة بلون معتدل وشعر مجعد',
    '👩🏾‍🦱' => 'سيدة: بشرة بلون معتدل مائل للغامق وشعر مجعد',
    '👩🏿‍🦱' => 'سيدة: بشرة بلون غامق وشعر مجعد',
    '👩🏻‍🦳' => 'سيدة: بشرة بلون فاتح وشعر أبيض',
    '👩🏼‍🦳' => 'سيدة: بشرة بلون فاتح ومعتدل وشعر أبيض',
    '👩🏽‍🦳' => 'سيدة: بشرة بلون معتدل وشعر أبيض',
    '👩🏾‍🦳' => 'سيدة: بشرة بلون معتدل مائل للغامق وشعر أبيض',
    '👩🏿‍🦳' => 'سيدة: بشرة بلون غامق وشعر أبيض',
    '👩🏻‍🦲' => 'سيدة: بشرة بلون فاتح وأصلع',
    '👩🏼‍🦲' => 'سيدة: بشرة بلون فاتح ومعتدل وأصلع',
    '👩🏽‍🦲' => 'سيدة: بشرة بلون معتدل وأصلع',
    '👩🏾‍🦲' => 'سيدة: بشرة بلون معتدل مائل للغامق وأصلع',
    '👩🏿‍🦲' => 'سيدة: بشرة بلون غامق وأصلع',
    '🙍🏻‍♂' => 'متجهم: بشرة بلون فاتح',
    '🙍🏼‍♂' => 'متجهم: بشرة بلون فاتح ومعتدل',
    '🙍🏽‍♂' => 'متجهم: بشرة بلون معتدل',
    '🙍🏾‍♂' => 'متجهم: بشرة بلون معتدل مائل للغامق',
    '🙍🏿‍♂' => 'متجهم: بشرة بلون غامق',
    '🙍🏻‍♀' => 'متجهمة: بشرة بلون فاتح',
    '🙍🏼‍♀' => 'متجهمة: بشرة بلون فاتح ومعتدل',
    '🙍🏽‍♀' => 'متجهمة: بشرة بلون معتدل',
    '🙍🏾‍♀' => 'متجهمة: بشرة بلون معتدل مائل للغامق',
    '🙍🏿‍♀' => 'متجهمة: بشرة بلون غامق',
    '🙎🏻‍♂' => 'رجل عابس: بشرة بلون فاتح',
    '🙎🏼‍♂' => 'رجل عابس: بشرة بلون فاتح ومعتدل',
    '🙎🏽‍♂' => 'رجل عابس: بشرة بلون معتدل',
    '🙎🏾‍♂' => 'رجل عابس: بشرة بلون معتدل مائل للغامق',
    '🙎🏿‍♂' => 'رجل عابس: بشرة بلون غامق',
    '🙎🏻‍♀' => 'سيدة عابسة: بشرة بلون فاتح',
    '🙎🏼‍♀' => 'سيدة عابسة: بشرة بلون فاتح ومعتدل',
    '🙎🏽‍♀' => 'سيدة عابسة: بشرة بلون معتدل',
    '🙎🏾‍♀' => 'سيدة عابسة: بشرة بلون معتدل مائل للغامق',
    '🙎🏿‍♀' => 'سيدة عابسة: بشرة بلون غامق',
    '🙅🏻‍♂' => 'غير موافق: بشرة بلون فاتح',
    '🙅🏼‍♂' => 'غير موافق: بشرة بلون فاتح ومعتدل',
    '🙅🏽‍♂' => 'غير موافق: بشرة بلون معتدل',
    '🙅🏾‍♂' => 'غير موافق: بشرة بلون معتدل مائل للغامق',
    '🙅🏿‍♂' => 'غير موافق: بشرة بلون غامق',
    '🙅🏻‍♀' => 'غير موافقة: بشرة بلون فاتح',
    '🙅🏼‍♀' => 'غير موافقة: بشرة بلون فاتح ومعتدل',
    '🙅🏽‍♀' => 'غير موافقة: بشرة بلون معتدل',
    '🙅🏾‍♀' => 'غير موافقة: بشرة بلون معتدل مائل للغامق',
    '🙅🏿‍♀' => 'غير موافقة: بشرة بلون غامق',
    '🙆🏻‍♂' => 'موافق: بشرة بلون فاتح',
    '🙆🏼‍♂' => 'موافق: بشرة بلون فاتح ومعتدل',
    '🙆🏽‍♂' => 'موافق: بشرة بلون معتدل',
    '🙆🏾‍♂' => 'موافق: بشرة بلون معتدل مائل للغامق',
    '🙆🏿‍♂' => 'موافق: بشرة بلون غامق',
    '🙆🏻‍♀' => 'موافقة: بشرة بلون فاتح',
    '🙆🏼‍♀' => 'موافقة: بشرة بلون فاتح ومعتدل',
    '🙆🏽‍♀' => 'موافقة: بشرة بلون معتدل',
    '🙆🏾‍♀' => 'موافقة: بشرة بلون معتدل مائل للغامق',
    '🙆🏿‍♀' => 'موافقة: بشرة بلون غامق',
    '💁🏻‍♂' => 'رجل بيد مائلة: بشرة بلون فاتح',
    '💁🏼‍♂' => 'رجل بيد مائلة: بشرة بلون فاتح ومعتدل',
    '💁🏽‍♂' => 'رجل بيد مائلة: بشرة بلون معتدل',
    '💁🏾‍♂' => 'رجل بيد مائلة: بشرة بلون معتدل مائل للغامق',
    '💁🏿‍♂' => 'رجل بيد مائلة: بشرة بلون غامق',
    '💁🏻‍♀' => 'سيدة بيد مائلة: بشرة بلون فاتح',
    '💁🏼‍♀' => 'سيدة بيد مائلة: بشرة بلون فاتح ومعتدل',
    '💁🏽‍♀' => 'سيدة بيد مائلة: بشرة بلون معتدل',
    '💁🏾‍♀' => 'سيدة بيد مائلة: بشرة بلون معتدل مائل للغامق',
    '💁🏿‍♀' => 'سيدة بيد مائلة: بشرة بلون غامق',
    '🙋🏻‍♂' => 'رجل يرفع يده: بشرة بلون فاتح',
    '🙋🏼‍♂' => 'رجل يرفع يده: بشرة بلون فاتح ومعتدل',
    '🙋🏽‍♂' => 'رجل يرفع يده: بشرة بلون معتدل',
    '🙋🏾‍♂' => 'رجل يرفع يده: بشرة بلون معتدل مائل للغامق',
    '🙋🏿‍♂' => 'رجل يرفع يده: بشرة بلون غامق',
    '🙋🏻‍♀' => 'سيدة ترفع يدها: بشرة بلون فاتح',
    '🙋🏼‍♀' => 'سيدة ترفع يدها: بشرة بلون فاتح ومعتدل',
    '🙋🏽‍♀' => 'سيدة ترفع يدها: بشرة بلون معتدل',
    '🙋🏾‍♀' => 'سيدة ترفع يدها: بشرة بلون معتدل مائل للغامق',
    '🙋🏿‍♀' => 'سيدة ترفع يدها: بشرة بلون غامق',
    '🧏🏻‍♂' => 'رجل أصم: بشرة بلون فاتح',
    '🧏🏼‍♂' => 'رجل أصم: بشرة بلون فاتح ومعتدل',
    '🧏🏽‍♂' => 'رجل أصم: بشرة بلون معتدل',
    '🧏🏾‍♂' => 'رجل أصم: بشرة بلون معتدل مائل للغامق',
    '🧏🏿‍♂' => 'رجل أصم: بشرة بلون غامق',
    '🧏🏻‍♀' => 'سيدة صماء: بشرة بلون فاتح',
    '🧏🏼‍♀' => 'سيدة صماء: بشرة بلون فاتح ومعتدل',
    '🧏🏽‍♀' => 'سيدة صماء: بشرة بلون معتدل',
    '🧏🏾‍♀' => 'سيدة صماء: بشرة بلون معتدل مائل للغامق',
    '🧏🏿‍♀' => 'سيدة صماء: بشرة بلون غامق',
    '🙇🏻‍♂' => 'رجل ينحني اعتذارًا: بشرة بلون فاتح',
    '🙇🏼‍♂' => 'رجل ينحني اعتذارًا: بشرة بلون فاتح ومعتدل',
    '🙇🏽‍♂' => 'رجل ينحني اعتذارًا: بشرة بلون معتدل',
    '🙇🏾‍♂' => 'رجل ينحني اعتذارًا: بشرة بلون معتدل مائل للغامق',
    '🙇🏿‍♂' => 'رجل ينحني اعتذارًا: بشرة بلون غامق',
    '🙇🏻‍♀' => 'سيدة تنحني اعتذارًا: بشرة بلون فاتح',
    '🙇🏼‍♀' => 'سيدة تنحني اعتذارًا: بشرة بلون فاتح ومعتدل',
    '🙇🏽‍♀' => 'سيدة تنحني اعتذارًا: بشرة بلون معتدل',
    '🙇🏾‍♀' => 'سيدة تنحني اعتذارًا: بشرة بلون معتدل مائل للغامق',
    '🙇🏿‍♀' => 'سيدة تنحني اعتذارًا: بشرة بلون غامق',
    '🤦🏻‍♂' => 'رجل يشعر بإحباط: بشرة بلون فاتح',
    '🤦🏼‍♂' => 'رجل يشعر بإحباط: بشرة بلون فاتح ومعتدل',
    '🤦🏽‍♂' => 'رجل يشعر بإحباط: بشرة بلون معتدل',
    '🤦🏾‍♂' => 'رجل يشعر بإحباط: بشرة بلون معتدل مائل للغامق',
    '🤦🏿‍♂' => 'رجل يشعر بإحباط: بشرة بلون غامق',
    '🤦🏻‍♀' => 'سيدة تشعر بإحباط: بشرة بلون فاتح',
    '🤦🏼‍♀' => 'سيدة تشعر بإحباط: بشرة بلون فاتح ومعتدل',
    '🤦🏽‍♀' => 'سيدة تشعر بإحباط: بشرة بلون معتدل',
    '🤦🏾‍♀' => 'سيدة تشعر بإحباط: بشرة بلون معتدل مائل للغامق',
    '🤦🏿‍♀' => 'سيدة تشعر بإحباط: بشرة بلون غامق',
    '🤷🏻‍♂' => 'رجل لا يبالي: بشرة بلون فاتح',
    '🤷🏼‍♂' => 'رجل لا يبالي: بشرة بلون فاتح ومعتدل',
    '🤷🏽‍♂' => 'رجل لا يبالي: بشرة بلون معتدل',
    '🤷🏾‍♂' => 'رجل لا يبالي: بشرة بلون معتدل مائل للغامق',
    '🤷🏿‍♂' => 'رجل لا يبالي: بشرة بلون غامق',
    '🤷🏻‍♀' => 'سيدة لا تبالي: بشرة بلون فاتح',
    '🤷🏼‍♀' => 'سيدة لا تبالي: بشرة بلون فاتح ومعتدل',
    '🤷🏽‍♀' => 'سيدة لا تبالي: بشرة بلون معتدل',
    '🤷🏾‍♀' => 'سيدة لا تبالي: بشرة بلون معتدل مائل للغامق',
    '🤷🏿‍♀' => 'سيدة لا تبالي: بشرة بلون غامق',
    '🧑🏻‍⚕' => 'موظف بقطاع الصحة: بشرة بلون فاتح',
    '🧑🏼‍⚕' => 'موظف بقطاع الصحة: بشرة بلون فاتح ومعتدل',
    '🧑🏽‍⚕' => 'موظف بقطاع الصحة: بشرة بلون معتدل',
    '🧑🏾‍⚕' => 'موظف بقطاع الصحة: بشرة بلون معتدل مائل للغامق',
    '🧑🏿‍⚕' => 'موظف بقطاع الصحة: بشرة بلون غامق',
    '👨🏻‍⚕' => 'عامل بقطاع الصحة: بشرة بلون فاتح',
    '👨🏼‍⚕' => 'عامل بقطاع الصحة: بشرة بلون فاتح ومعتدل',
    '👨🏽‍⚕' => 'عامل بقطاع الصحة: بشرة بلون معتدل',
    '👨🏾‍⚕' => 'عامل بقطاع الصحة: بشرة بلون معتدل مائل للغامق',
    '👨🏿‍⚕' => 'عامل بقطاع الصحة: بشرة بلون غامق',
    '👩🏻‍⚕' => 'عاملة بقطاع الصحة: بشرة بلون فاتح',
    '👩🏼‍⚕' => 'عاملة بقطاع الصحة: بشرة بلون فاتح ومعتدل',
    '👩🏽‍⚕' => 'عاملة بقطاع الصحة: بشرة بلون معتدل',
    '👩🏾‍⚕' => 'عاملة بقطاع الصحة: بشرة بلون معتدل مائل للغامق',
    '👩🏿‍⚕' => 'عاملة بقطاع الصحة: بشرة بلون غامق',
    '🧑🏻‍🎓' => 'طالِب: بشرة بلون فاتح',
    '🧑🏼‍🎓' => 'طالِب: بشرة بلون فاتح ومعتدل',
    '🧑🏽‍🎓' => 'طالِب: بشرة بلون معتدل',
    '🧑🏾‍🎓' => 'طالِب: بشرة بلون معتدل مائل للغامق',
    '🧑🏿‍🎓' => 'طالِب: بشرة بلون غامق',
    '👨🏻‍🎓' => 'طالب: بشرة بلون فاتح',
    '👨🏼‍🎓' => 'طالب: بشرة بلون فاتح ومعتدل',
    '👨🏽‍🎓' => 'طالب: بشرة بلون معتدل',
    '👨🏾‍🎓' => 'طالب: بشرة بلون معتدل مائل للغامق',
    '👨🏿‍🎓' => 'طالب: بشرة بلون غامق',
    '👩🏻‍🎓' => 'طالبة: بشرة بلون فاتح',
    '👩🏼‍🎓' => 'طالبة: بشرة بلون فاتح ومعتدل',
    '👩🏽‍🎓' => 'طالبة: بشرة بلون معتدل',
    '👩🏾‍🎓' => 'طالبة: بشرة بلون معتدل مائل للغامق',
    '👩🏿‍🎓' => 'طالبة: بشرة بلون غامق',
    '🧑🏻‍🏫' => 'أستاذ: بشرة بلون فاتح',
    '🧑🏼‍🏫' => 'أستاذ: بشرة بلون فاتح ومعتدل',
    '🧑🏽‍🏫' => 'أستاذ: بشرة بلون معتدل',
    '🧑🏾‍🏫' => 'أستاذ: بشرة بلون معتدل مائل للغامق',
    '🧑🏿‍🏫' => 'أستاذ: بشرة بلون غامق',
    '👨🏻‍🏫' => 'معلم: بشرة بلون فاتح',
    '👨🏼‍🏫' => 'معلم: بشرة بلون فاتح ومعتدل',
    '👨🏽‍🏫' => 'معلم: بشرة بلون معتدل',
    '👨🏾‍🏫' => 'معلم: بشرة بلون معتدل مائل للغامق',
    '👨🏿‍🏫' => 'معلم: بشرة بلون غامق',
    '👩🏻‍🏫' => 'معلمة: بشرة بلون فاتح',
    '👩🏼‍🏫' => 'معلمة: بشرة بلون فاتح ومعتدل',
    '👩🏽‍🏫' => 'معلمة: بشرة بلون معتدل',
    '👩🏾‍🏫' => 'معلمة: بشرة بلون معتدل مائل للغامق',
    '👩🏿‍🏫' => 'معلمة: بشرة بلون غامق',
    '🧑🏻‍⚖' => 'قاضي: بشرة بلون فاتح',
    '🧑🏼‍⚖' => 'قاضي: بشرة بلون فاتح ومعتدل',
    '🧑🏽‍⚖' => 'قاضي: بشرة بلون معتدل',
    '🧑🏾‍⚖' => 'قاضي: بشرة بلون معتدل مائل للغامق',
    '🧑🏿‍⚖' => 'قاضي: بشرة بلون غامق',
    '👨🏻‍⚖' => 'قاضٍ: بشرة بلون فاتح',
    '👨🏼‍⚖' => 'قاضٍ: بشرة بلون فاتح ومعتدل',
    '👨🏽‍⚖' => 'قاضٍ: بشرة بلون معتدل',
    '👨🏾‍⚖' => 'قاضٍ: بشرة بلون معتدل مائل للغامق',
    '👨🏿‍⚖' => 'قاضٍ: بشرة بلون غامق',
    '👩🏻‍⚖' => 'قاضية: بشرة بلون فاتح',
    '👩🏼‍⚖' => 'قاضية: بشرة بلون فاتح ومعتدل',
    '👩🏽‍⚖' => 'قاضية: بشرة بلون معتدل',
    '👩🏾‍⚖' => 'قاضية: بشرة بلون معتدل مائل للغامق',
    '👩🏿‍⚖' => 'قاضية: بشرة بلون غامق',
    '🧑🏻‍🌾' => 'مُزارع: بشرة بلون فاتح',
    '🧑🏼‍🌾' => 'مُزارع: بشرة بلون فاتح ومعتدل',
    '🧑🏽‍🌾' => 'مُزارع: بشرة بلون معتدل',
    '🧑🏾‍🌾' => 'مُزارع: بشرة بلون معتدل مائل للغامق',
    '🧑🏿‍🌾' => 'مُزارع: بشرة بلون غامق',
    '👨🏻‍🌾' => 'مزارع: بشرة بلون فاتح',
    '👨🏼‍🌾' => 'مزارع: بشرة بلون فاتح ومعتدل',
    '👨🏽‍🌾' => 'مزارع: بشرة بلون معتدل',
    '👨🏾‍🌾' => 'مزارع: بشرة بلون معتدل مائل للغامق',
    '👨🏿‍🌾' => 'مزارع: بشرة بلون غامق',
    '👩🏻‍🌾' => 'مزارعة: بشرة بلون فاتح',
    '👩🏼‍🌾' => 'مزارعة: بشرة بلون فاتح ومعتدل',
    '👩🏽‍🌾' => 'مزارعة: بشرة بلون معتدل',
    '👩🏾‍🌾' => 'مزارعة: بشرة بلون معتدل مائل للغامق',
    '👩🏿‍🌾' => 'مزارعة: بشرة بلون غامق',
    '🧑🏻‍🍳' => 'طاهي: بشرة بلون فاتح',
    '🧑🏼‍🍳' => 'طاهي: بشرة بلون فاتح ومعتدل',
    '🧑🏽‍🍳' => 'طاهي: بشرة بلون معتدل',
    '🧑🏾‍🍳' => 'طاهي: بشرة بلون معتدل مائل للغامق',
    '🧑🏿‍🍳' => 'طاهي: بشرة بلون غامق',
    '👨🏻‍🍳' => 'طباخ: بشرة بلون فاتح',
    '👨🏼‍🍳' => 'طباخ: بشرة بلون فاتح ومعتدل',
    '👨🏽‍🍳' => 'طباخ: بشرة بلون معتدل',
    '👨🏾‍🍳' => 'طباخ: بشرة بلون معتدل مائل للغامق',
    '👨🏿‍🍳' => 'طباخ: بشرة بلون غامق',
    '👩🏻‍🍳' => 'طباخة: بشرة بلون فاتح',
    '👩🏼‍🍳' => 'طباخة: بشرة بلون فاتح ومعتدل',
    '👩🏽‍🍳' => 'طباخة: بشرة بلون معتدل',
    '👩🏾‍🍳' => 'طباخة: بشرة بلون معتدل مائل للغامق',
    '👩🏿‍🍳' => 'طباخة: بشرة بلون غامق',
    '🧑🏻‍🔧' => 'خبير ميكانيكي: بشرة بلون فاتح',
    '🧑🏼‍🔧' => 'خبير ميكانيكي: بشرة بلون فاتح ومعتدل',
    '🧑🏽‍🔧' => 'خبير ميكانيكي: بشرة بلون معتدل',
    '🧑🏾‍🔧' => 'خبير ميكانيكي: بشرة بلون معتدل مائل للغامق',
    '🧑🏿‍🔧' => 'خبير ميكانيكي: بشرة بلون غامق',
    '👨🏻‍🔧' => 'ميكانيكي: بشرة بلون فاتح',
    '👨🏼‍🔧' => 'ميكانيكي: بشرة بلون فاتح ومعتدل',
    '👨🏽‍🔧' => 'ميكانيكي: بشرة بلون معتدل',
    '👨🏾‍🔧' => 'ميكانيكي: بشرة بلون معتدل مائل للغامق',
    '👨🏿‍🔧' => 'ميكانيكي: بشرة بلون غامق',
    '👩🏻‍🔧' => 'ميكانيكية: بشرة بلون فاتح',
    '👩🏼‍🔧' => 'ميكانيكية: بشرة بلون فاتح ومعتدل',
    '👩🏽‍🔧' => 'ميكانيكية: بشرة بلون معتدل',
    '👩🏾‍🔧' => 'ميكانيكية: بشرة بلون معتدل مائل للغامق',
    '👩🏿‍🔧' => 'ميكانيكية: بشرة بلون غامق',
    '🧑🏻‍🏭' => 'عامل في مصنع: بشرة بلون فاتح',
    '🧑🏼‍🏭' => 'عامل في مصنع: بشرة بلون فاتح ومعتدل',
    '🧑🏽‍🏭' => 'عامل في مصنع: بشرة بلون معتدل',
    '🧑🏾‍🏭' => 'عامل في مصنع: بشرة بلون معتدل مائل للغامق',
    '🧑🏿‍🏭' => 'عامل في مصنع: بشرة بلون غامق',
    '👨🏻‍🏭' => 'عامل مصنع: بشرة بلون فاتح',
    '👨🏼‍🏭' => 'عامل مصنع: بشرة بلون فاتح ومعتدل',
    '👨🏽‍🏭' => 'عامل مصنع: بشرة بلون معتدل',
    '👨🏾‍🏭' => 'عامل مصنع: بشرة بلون معتدل مائل للغامق',
    '👨🏿‍🏭' => 'عامل مصنع: بشرة بلون غامق',
    '👩🏻‍🏭' => 'عاملة مصنع: بشرة بلون فاتح',
    '👩🏼‍🏭' => 'عاملة مصنع: بشرة بلون فاتح ومعتدل',
    '👩🏽‍🏭' => 'عاملة مصنع: بشرة بلون معتدل',
    '👩🏾‍🏭' => 'عاملة مصنع: بشرة بلون معتدل مائل للغامق',
    '👩🏿‍🏭' => 'عاملة مصنع: بشرة بلون غامق',
    '🧑🏻‍💼' => 'موظف مكتب: بشرة بلون فاتح',
    '🧑🏼‍💼' => 'موظف مكتب: بشرة بلون فاتح ومعتدل',
    '🧑🏽‍💼' => 'موظف مكتب: بشرة بلون معتدل',
    '🧑🏾‍💼' => 'موظف مكتب: بشرة بلون معتدل مائل للغامق',
    '🧑🏿‍💼' => 'موظف مكتب: بشرة بلون غامق',
    '👨🏻‍💼' => 'موظف: بشرة بلون فاتح',
    '👨🏼‍💼' => 'موظف: بشرة بلون فاتح ومعتدل',
    '👨🏽‍💼' => 'موظف: بشرة بلون معتدل',
    '👨🏾‍💼' => 'موظف: بشرة بلون معتدل مائل للغامق',
    '👨🏿‍💼' => 'موظف: بشرة بلون غامق',
    '👩🏻‍💼' => 'موظفة: بشرة بلون فاتح',
    '👩🏼‍💼' => 'موظفة: بشرة بلون فاتح ومعتدل',
    '👩🏽‍💼' => 'موظفة: بشرة بلون معتدل',
    '👩🏾‍💼' => 'موظفة: بشرة بلون معتدل مائل للغامق',
    '👩🏿‍💼' => 'موظفة: بشرة بلون غامق',
    '🧑🏻‍🔬' => 'عالِم: بشرة بلون فاتح',
    '🧑🏼‍🔬' => 'عالِم: بشرة بلون فاتح ومعتدل',
    '🧑🏽‍🔬' => 'عالِم: بشرة بلون معتدل',
    '🧑🏾‍🔬' => 'عالِم: بشرة بلون معتدل مائل للغامق',
    '🧑🏿‍🔬' => 'عالِم: بشرة بلون غامق',
    '👨🏻‍🔬' => 'عالم: بشرة بلون فاتح',
    '👨🏼‍🔬' => 'عالم: بشرة بلون فاتح ومعتدل',
    '👨🏽‍🔬' => 'عالم: بشرة بلون معتدل',
    '👨🏾‍🔬' => 'عالم: بشرة بلون معتدل مائل للغامق',
    '👨🏿‍🔬' => 'عالم: بشرة بلون غامق',
    '👩🏻‍🔬' => 'عالِمة: بشرة بلون فاتح',
    '👩🏼‍🔬' => 'عالِمة: بشرة بلون فاتح ومعتدل',
    '👩🏽‍🔬' => 'عالِمة: بشرة بلون معتدل',
    '👩🏾‍🔬' => 'عالِمة: بشرة بلون معتدل مائل للغامق',
    '👩🏿‍🔬' => 'عالِمة: بشرة بلون غامق',
    '🧑🏻‍💻' => 'خبير تكنولوجيا: بشرة بلون فاتح',
    '🧑🏼‍💻' => 'خبير تكنولوجيا: بشرة بلون فاتح ومعتدل',
    '🧑🏽‍💻' => 'خبير تكنولوجيا: بشرة بلون معتدل',
    '🧑🏾‍💻' => 'خبير تكنولوجيا: بشرة بلون معتدل مائل للغامق',
    '🧑🏿‍💻' => 'خبير تكنولوجيا: بشرة بلون غامق',
    '👨🏻‍💻' => 'عالم تكنولوجيا: بشرة بلون فاتح',
    '👨🏼‍💻' => 'عالم تكنولوجيا: بشرة بلون فاتح ومعتدل',
    '👨🏽‍💻' => 'عالم تكنولوجيا: بشرة بلون معتدل',
    '👨🏾‍💻' => 'عالم تكنولوجيا: بشرة بلون معتدل مائل للغامق',
    '👨🏿‍💻' => 'عالم تكنولوجيا: بشرة بلون غامق',
    '👩🏻‍💻' => 'عالِمة تكنولوجيا: بشرة بلون فاتح',
    '👩🏼‍💻' => 'عالِمة تكنولوجيا: بشرة بلون فاتح ومعتدل',
    '👩🏽‍💻' => 'عالِمة تكنولوجيا: بشرة بلون معتدل',
    '👩🏾‍💻' => 'عالِمة تكنولوجيا: بشرة بلون معتدل مائل للغامق',
    '👩🏿‍💻' => 'عالِمة تكنولوجيا: بشرة بلون غامق',
    '🧑🏻‍🎤' => 'مغنّي: بشرة بلون فاتح',
    '🧑🏼‍🎤' => 'مغنّي: بشرة بلون فاتح ومعتدل',
    '🧑🏽‍🎤' => 'مغنّي: بشرة بلون معتدل',
    '🧑🏾‍🎤' => 'مغنّي: بشرة بلون معتدل مائل للغامق',
    '🧑🏿‍🎤' => 'مغنّي: بشرة بلون غامق',
    '👨🏻‍🎤' => 'مطرب: بشرة بلون فاتح',
    '👨🏼‍🎤' => 'مطرب: بشرة بلون فاتح ومعتدل',
    '👨🏽‍🎤' => 'مطرب: بشرة بلون معتدل',
    '👨🏾‍🎤' => 'مطرب: بشرة بلون معتدل مائل للغامق',
    '👨🏿‍🎤' => 'مطرب: بشرة بلون غامق',
    '👩🏻‍🎤' => 'مطربة: بشرة بلون فاتح',
    '👩🏼‍🎤' => 'مطربة: بشرة بلون فاتح ومعتدل',
    '👩🏽‍🎤' => 'مطربة: بشرة بلون معتدل',
    '👩🏾‍🎤' => 'مطربة: بشرة بلون معتدل مائل للغامق',
    '👩🏿‍🎤' => 'مطربة: بشرة بلون غامق',
    '🧑🏻‍🎨' => 'فنان رسم: بشرة بلون فاتح',
    '🧑🏼‍🎨' => 'فنان رسم: بشرة بلون فاتح ومعتدل',
    '🧑🏽‍🎨' => 'فنان رسم: بشرة بلون معتدل',
    '🧑🏾‍🎨' => 'فنان رسم: بشرة بلون معتدل مائل للغامق',
    '🧑🏿‍🎨' => 'فنان رسم: بشرة بلون غامق',
    '👨🏻‍🎨' => 'رسام: بشرة بلون فاتح',
    '👨🏼‍🎨' => 'رسام: بشرة بلون فاتح ومعتدل',
    '👨🏽‍🎨' => 'رسام: بشرة بلون معتدل',
    '👨🏾‍🎨' => 'رسام: بشرة بلون معتدل مائل للغامق',
    '👨🏿‍🎨' => 'رسام: بشرة بلون غامق',
    '👩🏻‍🎨' => 'رسامة: بشرة بلون فاتح',
    '👩🏼‍🎨' => 'رسامة: بشرة بلون فاتح ومعتدل',
    '👩🏽‍🎨' => 'رسامة: بشرة بلون معتدل',
    '👩🏾‍🎨' => 'رسامة: بشرة بلون معتدل مائل للغامق',
    '👩🏿‍🎨' => 'رسامة: بشرة بلون غامق',
    '🧑🏻‍✈' => 'ربان طائرة: بشرة بلون فاتح',
    '🧑🏼‍✈' => 'ربان طائرة: بشرة بلون فاتح ومعتدل',
    '🧑🏽‍✈' => 'ربان طائرة: بشرة بلون معتدل',
    '🧑🏾‍✈' => 'ربان طائرة: بشرة بلون معتدل مائل للغامق',
    '🧑🏿‍✈' => 'ربان طائرة: بشرة بلون غامق',
    '👨🏻‍✈' => 'طيار: بشرة بلون فاتح',
    '👨🏼‍✈' => 'طيار: بشرة بلون فاتح ومعتدل',
    '👨🏽‍✈' => 'طيار: بشرة بلون معتدل',
    '👨🏾‍✈' => 'طيار: بشرة بلون معتدل مائل للغامق',
    '👨🏿‍✈' => 'طيار: بشرة بلون غامق',
    '👩🏻‍✈' => 'ربّانة طائرة: بشرة بلون فاتح',
    '👩🏼‍✈' => 'ربّانة طائرة: بشرة بلون فاتح ومعتدل',
    '👩🏽‍✈' => 'ربّانة طائرة: بشرة بلون معتدل',
    '👩🏾‍✈' => 'ربّانة طائرة: بشرة بلون معتدل مائل للغامق',
    '👩🏿‍✈' => 'ربّانة طائرة: بشرة بلون غامق',
    '🧑🏻‍🚀' => 'رائد الفضاء: بشرة بلون فاتح',
    '🧑🏼‍🚀' => 'رائد الفضاء: بشرة بلون فاتح ومعتدل',
    '🧑🏽‍🚀' => 'رائد الفضاء: بشرة بلون معتدل',
    '🧑🏾‍🚀' => 'رائد الفضاء: بشرة بلون معتدل مائل للغامق',
    '🧑🏿‍🚀' => 'رائد الفضاء: بشرة بلون غامق',
    '👨🏻‍🚀' => 'رائد فضاء: بشرة بلون فاتح',
    '👨🏼‍🚀' => 'رائد فضاء: بشرة بلون فاتح ومعتدل',
    '👨🏽‍🚀' => 'رائد فضاء: بشرة بلون معتدل',
    '👨🏾‍🚀' => 'رائد فضاء: بشرة بلون معتدل مائل للغامق',
    '👨🏿‍🚀' => 'رائد فضاء: بشرة بلون غامق',
    '👩🏻‍🚀' => 'رائدة فضاء: بشرة بلون فاتح',
    '👩🏼‍🚀' => 'رائدة فضاء: بشرة بلون فاتح ومعتدل',
    '👩🏽‍🚀' => 'رائدة فضاء: بشرة بلون معتدل',
    '👩🏾‍🚀' => 'رائدة فضاء: بشرة بلون معتدل مائل للغامق',
    '👩🏿‍🚀' => 'رائدة فضاء: بشرة بلون غامق',
    '🧑🏻‍🚒' => 'إطفائي: بشرة بلون فاتح',
    '🧑🏼‍🚒' => 'إطفائي: بشرة بلون فاتح ومعتدل',
    '🧑🏽‍🚒' => 'إطفائي: بشرة بلون معتدل',
    '🧑🏾‍🚒' => 'إطفائي: بشرة بلون معتدل مائل للغامق',
    '🧑🏿‍🚒' => 'إطفائي: بشرة بلون غامق',
    '👨🏻‍🚒' => 'رجل إطفاء: بشرة بلون فاتح',
    '👨🏼‍🚒' => 'رجل إطفاء: بشرة بلون فاتح ومعتدل',
    '👨🏽‍🚒' => 'رجل إطفاء: بشرة بلون معتدل',
    '👨🏾‍🚒' => 'رجل إطفاء: بشرة بلون معتدل مائل للغامق',
    '👨🏿‍🚒' => 'رجل إطفاء: بشرة بلون غامق',
    '👩🏻‍🚒' => 'سيدة إطفاء: بشرة بلون فاتح',
    '👩🏼‍🚒' => 'سيدة إطفاء: بشرة بلون فاتح ومعتدل',
    '👩🏽‍🚒' => 'سيدة إطفاء: بشرة بلون معتدل',
    '👩🏾‍🚒' => 'سيدة إطفاء: بشرة بلون معتدل مائل للغامق',
    '👩🏿‍🚒' => 'سيدة إطفاء: بشرة بلون غامق',
    '👮🏻‍♂' => 'شرطي: بشرة بلون فاتح',
    '👮🏼‍♂' => 'شرطي: بشرة بلون فاتح ومعتدل',
    '👮🏽‍♂' => 'شرطي: بشرة بلون معتدل',
    '👮🏾‍♂' => 'شرطي: بشرة بلون معتدل مائل للغامق',
    '👮🏿‍♂' => 'شرطي: بشرة بلون غامق',
    '👮🏻‍♀' => 'شرطية: بشرة بلون فاتح',
    '👮🏼‍♀' => 'شرطية: بشرة بلون فاتح ومعتدل',
    '👮🏽‍♀' => 'شرطية: بشرة بلون معتدل',
    '👮🏾‍♀' => 'شرطية: بشرة بلون معتدل مائل للغامق',
    '👮🏿‍♀' => 'شرطية: بشرة بلون غامق',
    '🕵🏻‍♂' => 'محقّق: بشرة بلون فاتح',
    '🕵🏼‍♂' => 'محقّق: بشرة بلون فاتح ومعتدل',
    '🕵🏽‍♂' => 'محقّق: بشرة بلون معتدل',
    '🕵🏾‍♂' => 'محقّق: بشرة بلون معتدل مائل للغامق',
    '🕵🏿‍♂' => 'محقّق: بشرة بلون غامق',
    '🕵🏻‍♀' => 'محقّقة: بشرة بلون فاتح',
    '🕵🏼‍♀' => 'محقّقة: بشرة بلون فاتح ومعتدل',
    '🕵🏽‍♀' => 'محقّقة: بشرة بلون معتدل',
    '🕵🏾‍♀' => 'محقّقة: بشرة بلون معتدل مائل للغامق',
    '🕵🏿‍♀' => 'محقّقة: بشرة بلون غامق',
    '💂🏻‍♂' => 'رجل حراسة: بشرة بلون فاتح',
    '💂🏼‍♂' => 'رجل حراسة: بشرة بلون فاتح ومعتدل',
    '💂🏽‍♂' => 'رجل حراسة: بشرة بلون معتدل',
    '💂🏾‍♂' => 'رجل حراسة: بشرة بلون معتدل مائل للغامق',
    '💂🏿‍♂' => 'رجل حراسة: بشرة بلون غامق',
    '💂🏻‍♀' => 'حارسة: بشرة بلون فاتح',
    '💂🏼‍♀' => 'حارسة: بشرة بلون فاتح ومعتدل',
    '💂🏽‍♀' => 'حارسة: بشرة بلون معتدل',
    '💂🏾‍♀' => 'حارسة: بشرة بلون معتدل مائل للغامق',
    '💂🏿‍♀' => 'حارسة: بشرة بلون غامق',
    '👷🏻‍♂' => 'عامل بناء: بشرة بلون فاتح',
    '👷🏼‍♂' => 'عامل بناء: بشرة بلون فاتح ومعتدل',
    '👷🏽‍♂' => 'عامل بناء: بشرة بلون معتدل',
    '👷🏾‍♂' => 'عامل بناء: بشرة بلون معتدل مائل للغامق',
    '👷🏿‍♂' => 'عامل بناء: بشرة بلون غامق',
    '👷🏻‍♀' => 'عاملة بناء: بشرة بلون فاتح',
    '👷🏼‍♀' => 'عاملة بناء: بشرة بلون فاتح ومعتدل',
    '👷🏽‍♀' => 'عاملة بناء: بشرة بلون معتدل',
    '👷🏾‍♀' => 'عاملة بناء: بشرة بلون معتدل مائل للغامق',
    '👷🏿‍♀' => 'عاملة بناء: بشرة بلون غامق',
    '👳🏻‍♂' => 'رجل يرتدي عمامة: بشرة بلون فاتح',
    '👳🏼‍♂' => 'رجل يرتدي عمامة: بشرة بلون فاتح ومعتدل',
    '👳🏽‍♂' => 'رجل يرتدي عمامة: بشرة بلون معتدل',
    '👳🏾‍♂' => 'رجل يرتدي عمامة: بشرة بلون معتدل مائل للغامق',
    '👳🏿‍♂' => 'رجل يرتدي عمامة: بشرة بلون غامق',
    '👳🏻‍♀' => 'سيدة ترتدي عمامة: بشرة بلون فاتح',
    '👳🏼‍♀' => 'سيدة ترتدي عمامة: بشرة بلون فاتح ومعتدل',
    '👳🏽‍♀' => 'سيدة ترتدي عمامة: بشرة بلون معتدل',
    '👳🏾‍♀' => 'سيدة ترتدي عمامة: بشرة بلون معتدل مائل للغامق',
    '👳🏿‍♀' => 'سيدة ترتدي عمامة: بشرة بلون غامق',
    '🤵🏻‍♂' => 'رجل يرتدي بدلة رسمية: بشرة بلون فاتح',
    '🤵🏼‍♂' => 'رجل يرتدي بدلة رسمية: بشرة بلون فاتح ومعتدل',
    '🤵🏽‍♂' => 'رجل يرتدي بدلة رسمية: بشرة بلون معتدل',
    '🤵🏾‍♂' => 'رجل يرتدي بدلة رسمية: بشرة بلون معتدل مائل للغامق',
    '🤵🏿‍♂' => 'رجل يرتدي بدلة رسمية: بشرة بلون غامق',
    '🤵🏻‍♀' => 'امرأة ببدلة رسمية: بشرة بلون فاتح',
    '🤵🏼‍♀' => 'امرأة ببدلة رسمية: بشرة بلون فاتح ومعتدل',
    '🤵🏽‍♀' => 'امرأة ببدلة رسمية: بشرة بلون معتدل',
    '🤵🏾‍♀' => 'امرأة ببدلة رسمية: بشرة بلون معتدل مائل للغامق',
    '🤵🏿‍♀' => 'امرأة ببدلة رسمية: بشرة بلون غامق',
    '👰🏻‍♂' => 'رجل بطرحة: بشرة بلون فاتح',
    '👰🏼‍♂' => 'رجل بطرحة: بشرة بلون فاتح ومعتدل',
    '👰🏽‍♂' => 'رجل بطرحة: بشرة بلون معتدل',
    '👰🏾‍♂' => 'رجل بطرحة: بشرة بلون معتدل مائل للغامق',
    '👰🏿‍♂' => 'رجل بطرحة: بشرة بلون غامق',
    '👰🏻‍♀' => 'امرأة بطرحة: بشرة بلون فاتح',
    '👰🏼‍♀' => 'امرأة بطرحة: بشرة بلون فاتح ومعتدل',
    '👰🏽‍♀' => 'امرأة بطرحة: بشرة بلون معتدل',
    '👰🏾‍♀' => 'امرأة بطرحة: بشرة بلون معتدل مائل للغامق',
    '👰🏿‍♀' => 'امرأة بطرحة: بشرة بلون غامق',
    '👩🏻‍🍼' => 'امرأة تُرضع طفلاً: بشرة بلون فاتح',
    '👩🏼‍🍼' => 'امرأة تُرضع طفلاً: بشرة بلون فاتح ومعتدل',
    '👩🏽‍🍼' => 'امرأة تُرضع طفلاً: بشرة بلون معتدل',
    '👩🏾‍🍼' => 'امرأة تُرضع طفلاً: بشرة بلون معتدل مائل للغامق',
    '👩🏿‍🍼' => 'امرأة تُرضع طفلاً: بشرة بلون غامق',
    '👨🏻‍🍼' => 'رجل يُرضع طفلاً: بشرة بلون فاتح',
    '👨🏼‍🍼' => 'رجل يُرضع طفلاً: بشرة بلون فاتح ومعتدل',
    '👨🏽‍🍼' => 'رجل يُرضع طفلاً: بشرة بلون معتدل',
    '👨🏾‍🍼' => 'رجل يُرضع طفلاً: بشرة بلون معتدل مائل للغامق',
    '👨🏿‍🍼' => 'رجل يُرضع طفلاً: بشرة بلون غامق',
    '🧑🏻‍🍼' => 'شخص يُرضع طفلاً: بشرة بلون فاتح',
    '🧑🏼‍🍼' => 'شخص يُرضع طفلاً: بشرة بلون فاتح ومعتدل',
    '🧑🏽‍🍼' => 'شخص يُرضع طفلاً: بشرة بلون معتدل',
    '🧑🏾‍🍼' => 'شخص يُرضع طفلاً: بشرة بلون معتدل مائل للغامق',
    '🧑🏿‍🍼' => 'شخص يُرضع طفلاً: بشرة بلون غامق',
    '🧑🏻‍🎄' => 'كلوز: بشرة بلون فاتح',
    '🧑🏼‍🎄' => 'كلوز: بشرة بلون فاتح ومعتدل',
    '🧑🏽‍🎄' => 'كلوز: بشرة بلون معتدل',
    '🧑🏾‍🎄' => 'كلوز: بشرة بلون معتدل مائل للغامق',
    '🧑🏿‍🎄' => 'كلوز: بشرة بلون غامق',
    '🦸🏻‍♂' => 'بطل خارق رجل: بشرة بلون فاتح',
    '🦸🏼‍♂' => 'بطل خارق رجل: بشرة بلون فاتح ومعتدل',
    '🦸🏽‍♂' => 'بطل خارق رجل: بشرة بلون معتدل',
    '🦸🏾‍♂' => 'بطل خارق رجل: بشرة بلون معتدل مائل للغامق',
    '🦸🏿‍♂' => 'بطل خارق رجل: بشرة بلون غامق',
    '🦸🏻‍♀' => 'بطلة خارقة: بشرة بلون فاتح',
    '🦸🏼‍♀' => 'بطلة خارقة: بشرة بلون فاتح ومعتدل',
    '🦸🏽‍♀' => 'بطلة خارقة: بشرة بلون معتدل',
    '🦸🏾‍♀' => 'بطلة خارقة: بشرة بلون معتدل مائل للغامق',
    '🦸🏿‍♀' => 'بطلة خارقة: بشرة بلون غامق',
    '🦹🏻‍♂' => 'شرير خارق رجل: بشرة بلون فاتح',
    '🦹🏼‍♂' => 'شرير خارق رجل: بشرة بلون فاتح ومعتدل',
    '🦹🏽‍♂' => 'شرير خارق رجل: بشرة بلون معتدل',
    '🦹🏾‍♂' => 'شرير خارق رجل: بشرة بلون معتدل مائل للغامق',
    '🦹🏿‍♂' => 'شرير خارق رجل: بشرة بلون غامق',
    '🦹🏻‍♀' => 'شريرة خارقة: بشرة بلون فاتح',
    '🦹🏼‍♀' => 'شريرة خارقة: بشرة بلون فاتح ومعتدل',
    '🦹🏽‍♀' => 'شريرة خارقة: بشرة بلون معتدل',
    '🦹🏾‍♀' => 'شريرة خارقة: بشرة بلون معتدل مائل للغامق',
    '🦹🏿‍♀' => 'شريرة خارقة: بشرة بلون غامق',
    '🧙🏻‍♂' => 'ساحر: بشرة بلون فاتح',
    '🧙🏼‍♂' => 'ساحر: بشرة بلون فاتح ومعتدل',
    '🧙🏽‍♂' => 'ساحر: بشرة بلون معتدل',
    '🧙🏾‍♂' => 'ساحر: بشرة بلون معتدل مائل للغامق',
    '🧙🏿‍♂' => 'ساحر: بشرة بلون غامق',
    '🧙🏻‍♀' => 'ساحرة: بشرة بلون فاتح',
    '🧙🏼‍♀' => 'ساحرة: بشرة بلون فاتح ومعتدل',
    '🧙🏽‍♀' => 'ساحرة: بشرة بلون معتدل',
    '🧙🏾‍♀' => 'ساحرة: بشرة بلون معتدل مائل للغامق',
    '🧙🏿‍♀' => 'ساحرة: بشرة بلون غامق',
    '🧚🏻‍♂' => 'جنّي: بشرة بلون فاتح',
    '🧚🏼‍♂' => 'جنّي: بشرة بلون فاتح ومعتدل',
    '🧚🏽‍♂' => 'جنّي: بشرة بلون معتدل',
    '🧚🏾‍♂' => 'جنّي: بشرة بلون معتدل مائل للغامق',
    '🧚🏿‍♂' => 'جنّي: بشرة بلون غامق',
    '🧚🏻‍♀' => 'جنّية: بشرة بلون فاتح',
    '🧚🏼‍♀' => 'جنّية: بشرة بلون فاتح ومعتدل',
    '🧚🏽‍♀' => 'جنّية: بشرة بلون معتدل',
    '🧚🏾‍♀' => 'جنّية: بشرة بلون معتدل مائل للغامق',
    '🧚🏿‍♀' => 'جنّية: بشرة بلون غامق',
    '🧛🏻‍♂' => 'مصاص دماء: بشرة بلون فاتح',
    '🧛🏼‍♂' => 'مصاص دماء: بشرة بلون فاتح ومعتدل',
    '🧛🏽‍♂' => 'مصاص دماء: بشرة بلون معتدل',
    '🧛🏾‍♂' => 'مصاص دماء: بشرة بلون معتدل مائل للغامق',
    '🧛🏿‍♂' => 'مصاص دماء: بشرة بلون غامق',
    '🧛🏻‍♀' => 'مصّاصة دماء: بشرة بلون فاتح',
    '🧛🏼‍♀' => 'مصّاصة دماء: بشرة بلون فاتح ومعتدل',
    '🧛🏽‍♀' => 'مصّاصة دماء: بشرة بلون معتدل',
    '🧛🏾‍♀' => 'مصّاصة دماء: بشرة بلون معتدل مائل للغامق',
    '🧛🏿‍♀' => 'مصّاصة دماء: بشرة بلون غامق',
    '🧜🏻‍♂' => 'مخلوق له جسد رجل وذيل سمكة: بشرة بلون فاتح',
    '🧜🏼‍♂' => 'مخلوق له جسد رجل وذيل سمكة: بشرة بلون فاتح ومعتدل',
    '🧜🏽‍♂' => 'مخلوق له جسد رجل وذيل سمكة: بشرة بلون معتدل',
    '🧜🏾‍♂' => 'مخلوق له جسد رجل وذيل سمكة: بشرة بلون معتدل مائل للغامق',
    '🧜🏿‍♂' => 'مخلوق له جسد رجل وذيل سمكة: بشرة بلون غامق',
    '🧜🏻‍♀' => 'حورية بحر: بشرة بلون فاتح',
    '🧜🏼‍♀' => 'حورية بحر: بشرة بلون فاتح ومعتدل',
    '🧜🏽‍♀' => 'حورية بحر: بشرة بلون معتدل',
    '🧜🏾‍♀' => 'حورية بحر: بشرة بلون معتدل مائل للغامق',
    '🧜🏿‍♀' => 'حورية بحر: بشرة بلون غامق',
    '🧝🏻‍♂' => 'جنّي صغير ذكر: بشرة بلون فاتح',
    '🧝🏼‍♂' => 'جنّي صغير ذكر: بشرة بلون فاتح ومعتدل',
    '🧝🏽‍♂' => 'جنّي صغير ذكر: بشرة بلون معتدل',
    '🧝🏾‍♂' => 'جنّي صغير ذكر: بشرة بلون معتدل مائل للغامق',
    '🧝🏿‍♂' => 'جنّي صغير ذكر: بشرة بلون غامق',
    '🧝🏻‍♀' => 'جنيّة صغيرة: بشرة بلون فاتح',
    '🧝🏼‍♀' => 'جنيّة صغيرة: بشرة بلون فاتح ومعتدل',
    '🧝🏽‍♀' => 'جنيّة صغيرة: بشرة بلون معتدل',
    '🧝🏾‍♀' => 'جنيّة صغيرة: بشرة بلون معتدل مائل للغامق',
    '🧝🏿‍♀' => 'جنيّة صغيرة: بشرة بلون غامق',
    '💆🏻‍♂' => 'تدليك لرجل: بشرة بلون فاتح',
    '💆🏼‍♂' => 'تدليك لرجل: بشرة بلون فاتح ومعتدل',
    '💆🏽‍♂' => 'تدليك لرجل: بشرة بلون معتدل',
    '💆🏾‍♂' => 'تدليك لرجل: بشرة بلون معتدل مائل للغامق',
    '💆🏿‍♂' => 'تدليك لرجل: بشرة بلون غامق',
    '💆🏻‍♀' => 'تدليك لسيدة: بشرة بلون فاتح',
    '💆🏼‍♀' => 'تدليك لسيدة: بشرة بلون فاتح ومعتدل',
    '💆🏽‍♀' => 'تدليك لسيدة: بشرة بلون معتدل',
    '💆🏾‍♀' => 'تدليك لسيدة: بشرة بلون معتدل مائل للغامق',
    '💆🏿‍♀' => 'تدليك لسيدة: بشرة بلون غامق',
    '💇🏻‍♂' => 'يقص شعره: بشرة بلون فاتح',
    '💇🏼‍♂' => 'يقص شعره: بشرة بلون فاتح ومعتدل',
    '💇🏽‍♂' => 'يقص شعره: بشرة بلون معتدل',
    '💇🏾‍♂' => 'يقص شعره: بشرة بلون معتدل مائل للغامق',
    '💇🏿‍♂' => 'يقص شعره: بشرة بلون غامق',
    '💇🏻‍♀' => 'تقص شعرها: بشرة بلون فاتح',
    '💇🏼‍♀' => 'تقص شعرها: بشرة بلون فاتح ومعتدل',
    '💇🏽‍♀' => 'تقص شعرها: بشرة بلون معتدل',
    '💇🏾‍♀' => 'تقص شعرها: بشرة بلون معتدل مائل للغامق',
    '💇🏿‍♀' => 'تقص شعرها: بشرة بلون غامق',
    '🚶🏻‍♂' => 'سائر: بشرة بلون فاتح',
    '🚶🏼‍♂' => 'سائر: بشرة بلون فاتح ومعتدل',
    '🚶🏽‍♂' => 'سائر: بشرة بلون معتدل',
    '🚶🏾‍♂' => 'سائر: بشرة بلون معتدل مائل للغامق',
    '🚶🏿‍♂' => 'سائر: بشرة بلون غامق',
    '🚶🏻‍♀' => 'سائرة: بشرة بلون فاتح',
    '🚶🏼‍♀' => 'سائرة: بشرة بلون فاتح ومعتدل',
    '🚶🏽‍♀' => 'سائرة: بشرة بلون معتدل',
    '🚶🏾‍♀' => 'سائرة: بشرة بلون معتدل مائل للغامق',
    '🚶🏿‍♀' => 'سائرة: بشرة بلون غامق',
    '🚶🏻‍➡' => 'شخص يسير: بشرة بلون فاتح ومتجه لليمين',
    '🚶🏼‍➡' => 'شخص يسير: بشرة بلون فاتح ومعتدل ومتجه لليمين',
    '🚶🏽‍➡' => 'شخص يسير: بشرة بلون معتدل ومتجه لليمين',
    '🚶🏾‍➡' => 'شخص يسير: بشرة بلون معتدل مائل للغامق ومتجه لليمين',
    '🚶🏿‍➡' => 'شخص يسير: بشرة بلون غامق ومتجه لليمين',
    '🧍🏻‍♂' => 'رجل واقف: بشرة بلون فاتح',
    '🧍🏼‍♂' => 'رجل واقف: بشرة بلون فاتح ومعتدل',
    '🧍🏽‍♂' => 'رجل واقف: بشرة بلون معتدل',
    '🧍🏾‍♂' => 'رجل واقف: بشرة بلون معتدل مائل للغامق',
    '🧍🏿‍♂' => 'رجل واقف: بشرة بلون غامق',
    '🧍🏻‍♀' => 'سيدة واقفة: بشرة بلون فاتح',
    '🧍🏼‍♀' => 'سيدة واقفة: بشرة بلون فاتح ومعتدل',
    '🧍🏽‍♀' => 'سيدة واقفة: بشرة بلون معتدل',
    '🧍🏾‍♀' => 'سيدة واقفة: بشرة بلون معتدل مائل للغامق',
    '🧍🏿‍♀' => 'سيدة واقفة: بشرة بلون غامق',
    '🧎🏻‍♂' => 'رجل جالس على ركبتيه: بشرة بلون فاتح',
    '🧎🏼‍♂' => 'رجل جالس على ركبتيه: بشرة بلون فاتح ومعتدل',
    '🧎🏽‍♂' => 'رجل جالس على ركبتيه: بشرة بلون معتدل',
    '🧎🏾‍♂' => 'رجل جالس على ركبتيه: بشرة بلون معتدل مائل للغامق',
    '🧎🏿‍♂' => 'رجل جالس على ركبتيه: بشرة بلون غامق',
    '🧎🏻‍♀' => 'سيدة جالسة على ركبتيها: بشرة بلون فاتح',
    '🧎🏼‍♀' => 'سيدة جالسة على ركبتيها: بشرة بلون فاتح ومعتدل',
    '🧎🏽‍♀' => 'سيدة جالسة على ركبتيها: بشرة بلون معتدل',
    '🧎🏾‍♀' => 'سيدة جالسة على ركبتيها: بشرة بلون معتدل مائل للغامق',
    '🧎🏿‍♀' => 'سيدة جالسة على ركبتيها: بشرة بلون غامق',
    '🧎🏻‍➡' => 'شخص جالس على ركبتيه: بشرة بلون فاتح ومتجه لليمين',
    '🧎🏼‍➡' => 'شخص جالس على ركبتيه: بشرة بلون فاتح ومعتدل ومتجه لليمين',
    '🧎🏽‍➡' => 'شخص جالس على ركبتيه: بشرة بلون معتدل ومتجه لليمين',
    '🧎🏾‍➡' => 'شخص جالس على ركبتيه: بشرة بلون معتدل مائل للغامق ومتجه لليمين',
    '🧎🏿‍➡' => 'شخص جالس على ركبتيه: بشرة بلون غامق ومتجه لليمين',
    '🧑🏻‍🦯' => 'شخص مع عصا سير: بشرة بلون فاتح',
    '🧑🏼‍🦯' => 'شخص مع عصا سير: بشرة بلون فاتح ومعتدل',
    '🧑🏽‍🦯' => 'شخص مع عصا سير: بشرة بلون معتدل',
    '🧑🏾‍🦯' => 'شخص مع عصا سير: بشرة بلون معتدل مائل للغامق',
    '🧑🏿‍🦯' => 'شخص مع عصا سير: بشرة بلون غامق',
    '👨🏻‍🦯' => 'رجل بعصا سير: بشرة بلون فاتح',
    '👨🏼‍🦯' => 'رجل بعصا سير: بشرة بلون فاتح ومعتدل',
    '👨🏽‍🦯' => 'رجل بعصا سير: بشرة بلون معتدل',
    '👨🏾‍🦯' => 'رجل بعصا سير: بشرة بلون معتدل مائل للغامق',
    '👨🏿‍🦯' => 'رجل بعصا سير: بشرة بلون غامق',
    '👩🏻‍🦯' => 'سيدة بعصا سير: بشرة بلون فاتح',
    '👩🏼‍🦯' => 'سيدة بعصا سير: بشرة بلون فاتح ومعتدل',
    '👩🏽‍🦯' => 'سيدة بعصا سير: بشرة بلون معتدل',
    '👩🏾‍🦯' => 'سيدة بعصا سير: بشرة بلون معتدل مائل للغامق',
    '👩🏿‍🦯' => 'سيدة بعصا سير: بشرة بلون غامق',
    '🧑🏻‍🦼' => 'شخص على كرسي متحرك كهربائي: بشرة بلون فاتح',
    '🧑🏼‍🦼' => 'شخص على كرسي متحرك كهربائي: بشرة بلون فاتح ومعتدل',
    '🧑🏽‍🦼' => 'شخص على كرسي متحرك كهربائي: بشرة بلون معتدل',
    '🧑🏾‍🦼' => 'شخص على كرسي متحرك كهربائي: بشرة بلون معتدل مائل للغامق',
    '🧑🏿‍🦼' => 'شخص على كرسي متحرك كهربائي: بشرة بلون غامق',
    '👨🏻‍🦼' => 'رجل على كرسي متحرك كهربائي: بشرة بلون فاتح',
    '👨🏼‍🦼' => 'رجل على كرسي متحرك كهربائي: بشرة بلون فاتح ومعتدل',
    '👨🏽‍🦼' => 'رجل على كرسي متحرك كهربائي: بشرة بلون معتدل',
    '👨🏾‍🦼' => 'رجل على كرسي متحرك كهربائي: بشرة بلون معتدل مائل للغامق',
    '👨🏿‍🦼' => 'رجل على كرسي متحرك كهربائي: بشرة بلون غامق',
    '👩🏻‍🦼' => 'سيدة على كرسي متحرك كهربائي: بشرة بلون فاتح',
    '👩🏼‍🦼' => 'سيدة على كرسي متحرك كهربائي: بشرة بلون فاتح ومعتدل',
    '👩🏽‍🦼' => 'سيدة على كرسي متحرك كهربائي: بشرة بلون معتدل',
    '👩🏾‍🦼' => 'سيدة على كرسي متحرك كهربائي: بشرة بلون معتدل مائل للغامق',
    '👩🏿‍🦼' => 'سيدة على كرسي متحرك كهربائي: بشرة بلون غامق',
    '🧑🏻‍🦽' => 'شخص على كرسي متحرك يدوي: بشرة بلون فاتح',
    '🧑🏼‍🦽' => 'شخص على كرسي متحرك يدوي: بشرة بلون فاتح ومعتدل',
    '🧑🏽‍🦽' => 'شخص على كرسي متحرك يدوي: بشرة بلون معتدل',
    '🧑🏾‍🦽' => 'شخص على كرسي متحرك يدوي: بشرة بلون معتدل مائل للغامق',
    '🧑🏿‍🦽' => 'شخص على كرسي متحرك يدوي: بشرة بلون غامق',
    '👨🏻‍🦽' => 'رجل على كرسي متحرك يدوي: بشرة بلون فاتح',
    '👨🏼‍🦽' => 'رجل على كرسي متحرك يدوي: بشرة بلون فاتح ومعتدل',
    '👨🏽‍🦽' => 'رجل على كرسي متحرك يدوي: بشرة بلون معتدل',
    '👨🏾‍🦽' => 'رجل على كرسي متحرك يدوي: بشرة بلون معتدل مائل للغامق',
    '👨🏿‍🦽' => 'رجل على كرسي متحرك يدوي: بشرة بلون غامق',
    '👩🏻‍🦽' => 'سيدة على كرسي متحرك يدوي: بشرة بلون فاتح',
    '👩🏼‍🦽' => 'سيدة على كرسي متحرك يدوي: بشرة بلون فاتح ومعتدل',
    '👩🏽‍🦽' => 'سيدة على كرسي متحرك يدوي: بشرة بلون معتدل',
    '👩🏾‍🦽' => 'سيدة على كرسي متحرك يدوي: بشرة بلون معتدل مائل للغامق',
    '👩🏿‍🦽' => 'سيدة على كرسي متحرك يدوي: بشرة بلون غامق',
    '🏃🏻‍♂' => 'راكض: بشرة بلون فاتح',
    '🏃🏼‍♂' => 'راكض: بشرة بلون فاتح ومعتدل',
    '🏃🏽‍♂' => 'راكض: بشرة بلون معتدل',
    '🏃🏾‍♂' => 'راكض: بشرة بلون معتدل مائل للغامق',
    '🏃🏿‍♂' => 'راكض: بشرة بلون غامق',
    '🏃🏻‍♀' => 'راكضة: بشرة بلون فاتح',
    '🏃🏼‍♀' => 'راكضة: بشرة بلون فاتح ومعتدل',
    '🏃🏽‍♀' => 'راكضة: بشرة بلون معتدل',
    '🏃🏾‍♀' => 'راكضة: بشرة بلون معتدل مائل للغامق',
    '🏃🏿‍♀' => 'راكضة: بشرة بلون غامق',
    '🏃🏻‍➡' => 'شخص يجري: بشرة بلون فاتح ومتجه لليمين',
    '🏃🏼‍➡' => 'شخص يجري: بشرة بلون فاتح ومعتدل ومتجه لليمين',
    '🏃🏽‍➡' => 'شخص يجري: بشرة بلون معتدل ومتجه لليمين',
    '🏃🏾‍➡' => 'شخص يجري: بشرة بلون معتدل مائل للغامق ومتجه لليمين',
    '🏃🏿‍➡' => 'شخص يجري: بشرة بلون غامق ومتجه لليمين',
    '👯🏻‍♀' => 'امرأتان ترقصان: بشرة بلون فاتح',
    '👯🏼‍♀' => 'امرأتان ترقصان: بشرة بلون فاتح ومعتدل',
    '👯🏽‍♀' => 'امرأتان ترقصان: بشرة بلون معتدل',
    '👯🏾‍♀' => 'امرأتان ترقصان: بشرة بلون معتدل مائل للغامق',
    '👯🏿‍♀' => 'امرأتان ترقصان: بشرة بلون غامق',
    '👯🏻‍♂' => 'رجلان يرقصان: بشرة بلون فاتح',
    '👯🏼‍♂' => 'رجلان يرقصان: بشرة بلون فاتح ومعتدل',
    '👯🏽‍♂' => 'رجلان يرقصان: بشرة بلون معتدل',
    '👯🏾‍♂' => 'رجلان يرقصان: بشرة بلون معتدل مائل للغامق',
    '👯🏿‍♂' => 'رجلان يرقصان: بشرة بلون غامق',
    '🧖🏻‍♂' => 'رجل في حمّام بخار: بشرة بلون فاتح',
    '🧖🏼‍♂' => 'رجل في حمّام بخار: بشرة بلون فاتح ومعتدل',
    '🧖🏽‍♂' => 'رجل في حمّام بخار: بشرة بلون معتدل',
    '🧖🏾‍♂' => 'رجل في حمّام بخار: بشرة بلون معتدل مائل للغامق',
    '🧖🏿‍♂' => 'رجل في حمّام بخار: بشرة بلون غامق',
    '🧖🏻‍♀' => 'امرأة في حمّام بخار: بشرة بلون فاتح',
    '🧖🏼‍♀' => 'امرأة في حمّام بخار: بشرة بلون فاتح ومعتدل',
    '🧖🏽‍♀' => 'امرأة في حمّام بخار: بشرة بلون معتدل',
    '🧖🏾‍♀' => 'امرأة في حمّام بخار: بشرة بلون معتدل مائل للغامق',
    '🧖🏿‍♀' => 'امرأة في حمّام بخار: بشرة بلون غامق',
    '🧗🏻‍♂' => 'رجل يتسلّق: بشرة بلون فاتح',
    '🧗🏼‍♂' => 'رجل يتسلّق: بشرة بلون فاتح ومعتدل',
    '🧗🏽‍♂' => 'رجل يتسلّق: بشرة بلون معتدل',
    '🧗🏾‍♂' => 'رجل يتسلّق: بشرة بلون معتدل مائل للغامق',
    '🧗🏿‍♂' => 'رجل يتسلّق: بشرة بلون غامق',
    '🧗🏻‍♀' => 'امرأة تتسلّق: بشرة بلون فاتح',
    '🧗🏼‍♀' => 'امرأة تتسلّق: بشرة بلون فاتح ومعتدل',
    '🧗🏽‍♀' => 'امرأة تتسلّق: بشرة بلون معتدل',
    '🧗🏾‍♀' => 'امرأة تتسلّق: بشرة بلون معتدل مائل للغامق',
    '🧗🏿‍♀' => 'امرأة تتسلّق: بشرة بلون غامق',
    '🏌🏻‍♂' => 'لاعب غولف: بشرة بلون فاتح',
    '🏌🏼‍♂' => 'لاعب غولف: بشرة بلون فاتح ومعتدل',
    '🏌🏽‍♂' => 'لاعب غولف: بشرة بلون معتدل',
    '🏌🏾‍♂' => 'لاعب غولف: بشرة بلون معتدل مائل للغامق',
    '🏌🏿‍♂' => 'لاعب غولف: بشرة بلون غامق',
    '🏌🏻‍♀' => 'لاعبة غولف: بشرة بلون فاتح',
    '🏌🏼‍♀' => 'لاعبة غولف: بشرة بلون فاتح ومعتدل',
    '🏌🏽‍♀' => 'لاعبة غولف: بشرة بلون معتدل',
    '🏌🏾‍♀' => 'لاعبة غولف: بشرة بلون معتدل مائل للغامق',
    '🏌🏿‍♀' => 'لاعبة غولف: بشرة بلون غامق',
    '🏄🏻‍♂' => 'راكب أمواج: بشرة بلون فاتح',
    '🏄🏼‍♂' => 'راكب أمواج: بشرة بلون فاتح ومعتدل',
    '🏄🏽‍♂' => 'راكب أمواج: بشرة بلون معتدل',
    '🏄🏾‍♂' => 'راكب أمواج: بشرة بلون معتدل مائل للغامق',
    '🏄🏿‍♂' => 'راكب أمواج: بشرة بلون غامق',
    '🏄🏻‍♀' => 'راكبة أمواج: بشرة بلون فاتح',
    '🏄🏼‍♀' => 'راكبة أمواج: بشرة بلون فاتح ومعتدل',
    '🏄🏽‍♀' => 'راكبة أمواج: بشرة بلون معتدل',
    '🏄🏾‍♀' => 'راكبة أمواج: بشرة بلون معتدل مائل للغامق',
    '🏄🏿‍♀' => 'راكبة أمواج: بشرة بلون غامق',
    '🚣🏻‍♂' => 'رجل يجدف بقارب: بشرة بلون فاتح',
    '🚣🏼‍♂' => 'رجل يجدف بقارب: بشرة بلون فاتح ومعتدل',
    '🚣🏽‍♂' => 'رجل يجدف بقارب: بشرة بلون معتدل',
    '🚣🏾‍♂' => 'رجل يجدف بقارب: بشرة بلون معتدل مائل للغامق',
    '🚣🏿‍♂' => 'رجل يجدف بقارب: بشرة بلون غامق',
    '🚣🏻‍♀' => 'سيدة تجدف بقارب: بشرة بلون فاتح',
    '🚣🏼‍♀' => 'سيدة تجدف بقارب: بشرة بلون فاتح ومعتدل',
    '🚣🏽‍♀' => 'سيدة تجدف بقارب: بشرة بلون معتدل',
    '🚣🏾‍♀' => 'سيدة تجدف بقارب: بشرة بلون معتدل مائل للغامق',
    '🚣🏿‍♀' => 'سيدة تجدف بقارب: بشرة بلون غامق',
    '🏊🏻‍♂' => 'سباح: بشرة بلون فاتح',
    '🏊🏼‍♂' => 'سباح: بشرة بلون فاتح ومعتدل',
    '🏊🏽‍♂' => 'سباح: بشرة بلون معتدل',
    '🏊🏾‍♂' => 'سباح: بشرة بلون معتدل مائل للغامق',
    '🏊🏿‍♂' => 'سباح: بشرة بلون غامق',
    '🏊🏻‍♀' => 'سبَّاحة: بشرة بلون فاتح',
    '🏊🏼‍♀' => 'سبَّاحة: بشرة بلون فاتح ومعتدل',
    '🏊🏽‍♀' => 'سبَّاحة: بشرة بلون معتدل',
    '🏊🏾‍♀' => 'سبَّاحة: بشرة بلون معتدل مائل للغامق',
    '🏊🏿‍♀' => 'سبَّاحة: بشرة بلون غامق',
    '⛹🏻‍♂' => 'رجل وكرة: بشرة بلون فاتح',
    '⛹🏼‍♂' => 'رجل وكرة: بشرة بلون فاتح ومعتدل',
    '⛹🏽‍♂' => 'رجل وكرة: بشرة بلون معتدل',
    '⛹🏾‍♂' => 'رجل وكرة: بشرة بلون معتدل مائل للغامق',
    '⛹🏿‍♂' => 'رجل وكرة: بشرة بلون غامق',
    '⛹🏻‍♀' => 'سيدة وكرة: بشرة بلون فاتح',
    '⛹🏼‍♀' => 'سيدة وكرة: بشرة بلون فاتح ومعتدل',
    '⛹🏽‍♀' => 'سيدة وكرة: بشرة بلون معتدل',
    '⛹🏾‍♀' => 'سيدة وكرة: بشرة بلون معتدل مائل للغامق',
    '⛹🏿‍♀' => 'سيدة وكرة: بشرة بلون غامق',
    '🏋🏻‍♂' => 'رافع أثقال: بشرة بلون فاتح',
    '🏋🏼‍♂' => 'رافع أثقال: بشرة بلون فاتح ومعتدل',
    '🏋🏽‍♂' => 'رافع أثقال: بشرة بلون معتدل',
    '🏋🏾‍♂' => 'رافع أثقال: بشرة بلون معتدل مائل للغامق',
    '🏋🏿‍♂' => 'رافع أثقال: بشرة بلون غامق',
    '🏋🏻‍♀' => 'رافعة أثقال: بشرة بلون فاتح',
    '🏋🏼‍♀' => 'رافعة أثقال: بشرة بلون فاتح ومعتدل',
    '🏋🏽‍♀' => 'رافعة أثقال: بشرة بلون معتدل',
    '🏋🏾‍♀' => 'رافعة أثقال: بشرة بلون معتدل مائل للغامق',
    '🏋🏿‍♀' => 'رافعة أثقال: بشرة بلون غامق',
    '🚴🏻‍♂' => 'راكب دراجة: بشرة بلون فاتح',
    '🚴🏼‍♂' => 'راكب دراجة: بشرة بلون فاتح ومعتدل',
    '🚴🏽‍♂' => 'راكب دراجة: بشرة بلون معتدل',
    '🚴🏾‍♂' => 'راكب دراجة: بشرة بلون معتدل مائل للغامق',
    '🚴🏿‍♂' => 'راكب دراجة: بشرة بلون غامق',
    '🚴🏻‍♀' => 'راكبة دراجة: بشرة بلون فاتح',
    '🚴🏼‍♀' => 'راكبة دراجة: بشرة بلون فاتح ومعتدل',
    '🚴🏽‍♀' => 'راكبة دراجة: بشرة بلون معتدل',
    '🚴🏾‍♀' => 'راكبة دراجة: بشرة بلون معتدل مائل للغامق',
    '🚴🏿‍♀' => 'راكبة دراجة: بشرة بلون غامق',
    '🚵🏻‍♂' => 'متسلق جبال بدراجة: بشرة بلون فاتح',
    '🚵🏼‍♂' => 'متسلق جبال بدراجة: بشرة بلون فاتح ومعتدل',
    '🚵🏽‍♂' => 'متسلق جبال بدراجة: بشرة بلون معتدل',
    '🚵🏾‍♂' => 'متسلق جبال بدراجة: بشرة بلون معتدل مائل للغامق',
    '🚵🏿‍♂' => 'متسلق جبال بدراجة: بشرة بلون غامق',
    '🚵🏻‍♀' => 'متسلقة جبال بدراجة: بشرة بلون فاتح',
    '🚵🏼‍♀' => 'متسلقة جبال بدراجة: بشرة بلون فاتح ومعتدل',
    '🚵🏽‍♀' => 'متسلقة جبال بدراجة: بشرة بلون معتدل',
    '🚵🏾‍♀' => 'متسلقة جبال بدراجة: بشرة بلون معتدل مائل للغامق',
    '🚵🏿‍♀' => 'متسلقة جبال بدراجة: بشرة بلون غامق',
    '🤸🏻‍♂' => 'رجل يفعل حركة العجلة: بشرة بلون فاتح',
    '🤸🏼‍♂' => 'رجل يفعل حركة العجلة: بشرة بلون فاتح ومعتدل',
    '🤸🏽‍♂' => 'رجل يفعل حركة العجلة: بشرة بلون معتدل',
    '🤸🏾‍♂' => 'رجل يفعل حركة العجلة: بشرة بلون معتدل مائل للغامق',
    '🤸🏿‍♂' => 'رجل يفعل حركة العجلة: بشرة بلون غامق',
    '🤸🏻‍♀' => 'سيدة تفعل حركة العجلة: بشرة بلون فاتح',
    '🤸🏼‍♀' => 'سيدة تفعل حركة العجلة: بشرة بلون فاتح ومعتدل',
    '🤸🏽‍♀' => 'سيدة تفعل حركة العجلة: بشرة بلون معتدل',
    '🤸🏾‍♀' => 'سيدة تفعل حركة العجلة: بشرة بلون معتدل مائل للغامق',
    '🤸🏿‍♀' => 'سيدة تفعل حركة العجلة: بشرة بلون غامق',
    '🤼🏻‍♀' => 'مصارعة سيدات: بشرة بلون فاتح',
    '🤼🏼‍♀' => 'مصارعة سيدات: بشرة بلون فاتح ومعتدل',
    '🤼🏽‍♀' => 'مصارعة سيدات: بشرة بلون معتدل',
    '🤼🏾‍♀' => 'مصارعة سيدات: بشرة بلون معتدل مائل للغامق',
    '🤼🏿‍♀' => 'مصارعة سيدات: بشرة بلون غامق',
    '🤼🏻‍♂' => 'مصارعة رجال: بشرة بلون فاتح',
    '🤼🏼‍♂' => 'مصارعة رجال: بشرة بلون فاتح ومعتدل',
    '🤼🏽‍♂' => 'مصارعة رجال: بشرة بلون معتدل',
    '🤼🏾‍♂' => 'مصارعة رجال: بشرة بلون معتدل مائل للغامق',
    '🤼🏿‍♂' => 'مصارعة رجال: بشرة بلون غامق',
    '🤽🏻‍♂' => 'لاعب كرة ماء: بشرة بلون فاتح',
    '🤽🏼‍♂' => 'لاعب كرة ماء: بشرة بلون فاتح ومعتدل',
    '🤽🏽‍♂' => 'لاعب كرة ماء: بشرة بلون معتدل',
    '🤽🏾‍♂' => 'لاعب كرة ماء: بشرة بلون معتدل مائل للغامق',
    '🤽🏿‍♂' => 'لاعب كرة ماء: بشرة بلون غامق',
    '🤽🏻‍♀' => 'لاعبة كرة ماء: بشرة بلون فاتح',
    '🤽🏼‍♀' => 'لاعبة كرة ماء: بشرة بلون فاتح ومعتدل',
    '🤽🏽‍♀' => 'لاعبة كرة ماء: بشرة بلون معتدل',
    '🤽🏾‍♀' => 'لاعبة كرة ماء: بشرة بلون معتدل مائل للغامق',
    '🤽🏿‍♀' => 'لاعبة كرة ماء: بشرة بلون غامق',
    '🤾🏻‍♂' => 'لاعب كرة يد: بشرة بلون فاتح',
    '🤾🏼‍♂' => 'لاعب كرة يد: بشرة بلون فاتح ومعتدل',
    '🤾🏽‍♂' => 'لاعب كرة يد: بشرة بلون معتدل',
    '🤾🏾‍♂' => 'لاعب كرة يد: بشرة بلون معتدل مائل للغامق',
    '🤾🏿‍♂' => 'لاعب كرة يد: بشرة بلون غامق',
    '🤾🏻‍♀' => 'لاعبة كرة يد: بشرة بلون فاتح',
    '🤾🏼‍♀' => 'لاعبة كرة يد: بشرة بلون فاتح ومعتدل',
    '🤾🏽‍♀' => 'لاعبة كرة يد: بشرة بلون معتدل',
    '🤾🏾‍♀' => 'لاعبة كرة يد: بشرة بلون معتدل مائل للغامق',
    '🤾🏿‍♀' => 'لاعبة كرة يد: بشرة بلون غامق',
    '🤹🏻‍♂' => 'لاعب قذف الكرات: بشرة بلون فاتح',
    '🤹🏼‍♂' => 'لاعب قذف الكرات: بشرة بلون فاتح ومعتدل',
    '🤹🏽‍♂' => 'لاعب قذف الكرات: بشرة بلون معتدل',
    '🤹🏾‍♂' => 'لاعب قذف الكرات: بشرة بلون معتدل مائل للغامق',
    '🤹🏿‍♂' => 'لاعب قذف الكرات: بشرة بلون غامق',
    '🤹🏻‍♀' => 'لاعبة قذف كرات: بشرة بلون فاتح',
    '🤹🏼‍♀' => 'لاعبة قذف كرات: بشرة بلون فاتح ومعتدل',
    '🤹🏽‍♀' => 'لاعبة قذف كرات: بشرة بلون معتدل',
    '🤹🏾‍♀' => 'لاعبة قذف كرات: بشرة بلون معتدل مائل للغامق',
    '🤹🏿‍♀' => 'لاعبة قذف كرات: بشرة بلون غامق',
    '🧘🏻‍♂' => 'رجل متربّع: بشرة بلون فاتح',
    '🧘🏼‍♂' => 'رجل متربّع: بشرة بلون فاتح ومعتدل',
    '🧘🏽‍♂' => 'رجل متربّع: بشرة بلون معتدل',
    '🧘🏾‍♂' => 'رجل متربّع: بشرة بلون معتدل مائل للغامق',
    '🧘🏿‍♂' => 'رجل متربّع: بشرة بلون غامق',
    '🧘🏻‍♀' => 'امرأة متربّعة: بشرة بلون فاتح',
    '🧘🏼‍♀' => 'امرأة متربّعة: بشرة بلون فاتح ومعتدل',
    '🧘🏽‍♀' => 'امرأة متربّعة: بشرة بلون معتدل',
    '🧘🏾‍♀' => 'امرأة متربّعة: بشرة بلون معتدل مائل للغامق',
    '🧘🏿‍♀' => 'امرأة متربّعة: بشرة بلون غامق',
    '🧑‍🦰' => 'بالغ: شعر أحمر',
    '🧑‍🦱' => 'بالغ: شعر مجعد',
    '🧑‍🦳' => 'بالغ: شعر أبيض',
    '🧑‍🦲' => 'بالغ: أصلع',
    '👨‍🦰' => 'رجل: شعر أحمر',
    '👨‍🦱' => 'رجل: شعر مجعد',
    '👨‍🦳' => 'رجل: شعر أبيض',
    '👨‍🦲' => 'رجل: أصلع',
    '👩‍🦰' => 'سيدة: شعر أحمر',
    '👩‍🦱' => 'سيدة: شعر مجعد',
    '👩‍🦳' => 'سيدة: شعر أبيض',
    '👩‍🦲' => 'سيدة: أصلع',
    '🚶‍➡' => 'شخص يسير: متجه لليمين',
    '🧎‍➡' => 'شخص جالس على ركبتيه: متجه لليمين',
    '🏃‍➡' => 'شخص يجري: متجه لليمين',
    '👨‍👦' => 'أسرة: رجل وصبي',
    '👨‍👧' => 'أسرة: رجل وفتاة',
    '👩‍👦' => 'أسرة: سيدة وصبي',
    '👩‍👧' => 'أسرة: سيدة وفتاة',
    '😶‍🌫' => 'وجه في الغيوم',
    '😮‍💨' => 'وجه يزفر الهواء',
    '🙂‍↕' => 'رأس يهتز عمودياً',
    '😵‍💫' => 'وجه بعينين دائختين',
    '❤‍🔥' => 'قلب يحترق',
    '❤‍🩹' => 'قلب يتعافى',
    '👁‍🗨' => 'عين في فقاعة كلام',
    '🧔‍♂' => 'رجل بلحية',
    '👱‍♂' => 'رجل أشقر',
    '🧔‍♀' => 'امرأة بلحية',
    '👱‍♀' => 'امرأة شقراء',
    '🙍‍♂' => 'متجهم',
    '🙍‍♀' => 'متجهمة',
    '🙎‍♂' => 'رجل عابس',
    '🙎‍♀' => 'سيدة عابسة',
    '🙅‍♂' => 'غير موافق',
    '🙅‍♀' => 'غير موافقة',
    '🙆‍♂' => 'موافق',
    '🙆‍♀' => 'موافقة',
    '💁‍♂' => 'رجل بيد مائلة',
    '💁‍♀' => 'سيدة بيد مائلة',
    '🙋‍♂' => 'رجل يرفع يده',
    '🙋‍♀' => 'سيدة ترفع يدها',
    '🧏‍♂' => 'رجل أصم',
    '🧏‍♀' => 'سيدة صماء',
    '🙇‍♂' => 'رجل ينحني اعتذارًا',
    '🙇‍♀' => 'سيدة تنحني اعتذارًا',
    '🤦‍♂' => 'رجل يشعر بإحباط',
    '🤦‍♀' => 'سيدة تشعر بإحباط',
    '🤷‍♂' => 'رجل لا يبالي',
    '🤷‍♀' => 'سيدة لا تبالي',
    '🧑‍⚕' => 'موظف بقطاع الصحة',
    '👨‍⚕' => 'عامل بقطاع الصحة',
    '👩‍⚕' => 'عاملة بقطاع الصحة',
    '🧑‍🎓' => 'طالِب',
    '👨‍🎓' => 'طالب',
    '👩‍🎓' => 'طالبة',
    '🧑‍🏫' => 'أستاذ',
    '👨‍🏫' => 'معلم',
    '👩‍🏫' => 'معلمة',
    '🧑‍⚖' => 'قاضي',
    '👨‍⚖' => 'قاضٍ',
    '👩‍⚖' => 'قاضية',
    '🧑‍🌾' => 'مُزارع',
    '👨‍🌾' => 'مزارع',
    '👩‍🌾' => 'مزارعة',
    '🧑‍🍳' => 'طاهي',
    '👨‍🍳' => 'طباخ',
    '👩‍🍳' => 'طباخة',
    '🧑‍🔧' => 'خبير ميكانيكي',
    '👨‍🔧' => 'ميكانيكي',
    '👩‍🔧' => 'ميكانيكية',
    '🧑‍🏭' => 'عامل في مصنع',
    '👨‍🏭' => 'عامل مصنع',
    '👩‍🏭' => 'عاملة مصنع',
    '🧑‍💼' => 'موظف مكتب',
    '👨‍💼' => 'موظف',
    '👩‍💼' => 'موظفة',
    '🧑‍🔬' => 'عالِم',
    '👨‍🔬' => 'عالم',
    '👩‍🔬' => 'عالِمة',
    '🧑‍💻' => 'خبير تكنولوجيا',
    '👨‍💻' => 'عالم تكنولوجيا',
    '👩‍💻' => 'عالِمة تكنولوجيا',
    '🧑‍🎤' => 'مغنّي',
    '👨‍🎤' => 'مطرب',
    '👩‍🎤' => 'مطربة',
    '🧑‍🎨' => 'فنان رسم',
    '👨‍🎨' => 'رسام',
    '👩‍🎨' => 'رسامة',
    '🧑‍✈' => 'ربان طائرة',
    '👨‍✈' => 'طيار',
    '👩‍✈' => 'ربّانة طائرة',
    '🧑‍🚀' => 'رائد الفضاء',
    '👨‍🚀' => 'رائد فضاء',
    '👩‍🚀' => 'رائدة فضاء',
    '🧑‍🚒' => 'إطفائي',
    '👨‍🚒' => 'رجل إطفاء',
    '👩‍🚒' => 'سيدة إطفاء',
    '👮‍♂' => 'شرطي',
    '👮‍♀' => 'شرطية',
    '🕵‍♂' => 'محقّق',
    '🕵‍♀' => 'محقّقة',
    '💂‍♂' => 'رجل حراسة',
    '💂‍♀' => 'حارسة',
    '👷‍♂' => 'عامل بناء',
    '👷‍♀' => 'عاملة بناء',
    '👳‍♂' => 'رجل يرتدي عمامة',
    '👳‍♀' => 'سيدة ترتدي عمامة',
    '🤵‍♂' => 'رجل يرتدي بدلة رسمية',
    '🤵‍♀' => 'امرأة ببدلة رسمية',
    '👰‍♂' => 'رجل بطرحة',
    '👰‍♀' => 'امرأة بطرحة',
    '👩‍🍼' => 'امرأة تُرضع طفلاً',
    '👨‍🍼' => 'رجل يُرضع طفلاً',
    '🧑‍🍼' => 'شخص يُرضع طفلاً',
    '🧑‍🎄' => 'كلوز',
    '🦸‍♂' => 'بطل خارق رجل',
    '🦸‍♀' => 'بطلة خارقة',
    '🦹‍♂' => 'شرير خارق رجل',
    '🦹‍♀' => 'شريرة خارقة',
    '🧙‍♂' => 'ساحر',
    '🧙‍♀' => 'ساحرة',
    '🧚‍♂' => 'جنّي',
    '🧚‍♀' => 'جنّية',
    '🧛‍♂' => 'مصاص دماء',
    '🧛‍♀' => 'مصّاصة دماء',
    '🧜‍♂' => 'مخلوق له جسد رجل وذيل سمكة',
    '🧜‍♀' => 'حورية بحر',
    '🧝‍♂' => 'جنّي صغير ذكر',
    '🧝‍♀' => 'جنيّة صغيرة',
    '🧞‍♂' => 'مارد',
    '🧞‍♀' => 'ماردة',
    '🧟‍♂' => 'رجل زومبي',
    '🧟‍♀' => 'امرأة زومبي',
    '💆‍♂' => 'تدليك لرجل',
    '💆‍♀' => 'تدليك لسيدة',
    '💇‍♂' => 'يقص شعره',
    '💇‍♀' => 'تقص شعرها',
    '🚶‍♂' => 'سائر',
    '🚶‍♀' => 'سائرة',
    '🧍‍♂' => 'رجل واقف',
    '🧍‍♀' => 'سيدة واقفة',
    '🧎‍♂' => 'رجل جالس على ركبتيه',
    '🧎‍♀' => 'سيدة جالسة على ركبتيها',
    '🧑‍🦯' => 'شخص مع عصا سير',
    '👨‍🦯' => 'رجل بعصا سير',
    '👩‍🦯' => 'سيدة بعصا سير',
    '🧑‍🦼' => 'شخص على كرسي متحرك كهربائي',
    '👨‍🦼' => 'رجل على كرسي متحرك كهربائي',
    '👩‍🦼' => 'سيدة على كرسي متحرك كهربائي',
    '🧑‍🦽' => 'شخص على كرسي متحرك يدوي',
    '👨‍🦽' => 'رجل على كرسي متحرك يدوي',
    '👩‍🦽' => 'سيدة على كرسي متحرك يدوي',
    '🏃‍♂' => 'راكض',
    '🏃‍♀' => 'راكضة',
    '🧑‍🩰' => 'راقصة باليه',
    '👯‍♂' => 'رجلان يرقصان',
    '👯‍♀' => 'امرأتان ترقصان',
    '🧖‍♂' => 'رجل في حمّام بخار',
    '🧖‍♀' => 'امرأة في حمّام بخار',
    '🧗‍♂' => 'رجل يتسلّق',
    '🧗‍♀' => 'امرأة تتسلّق',
    '🏌‍♂' => 'لاعب غولف',
    '🏌‍♀' => 'لاعبة غولف',
    '🏄‍♂' => 'راكب أمواج',
    '🏄‍♀' => 'راكبة أمواج',
    '🚣‍♂' => 'رجل يجدف بقارب',
    '🚣‍♀' => 'سيدة تجدف بقارب',
    '🏊‍♂' => 'سباح',
    '🏊‍♀' => 'سبَّاحة',
    '⛹‍♂' => 'رجل وكرة',
    '⛹‍♀' => 'سيدة وكرة',
    '🏋‍♂' => 'رافع أثقال',
    '🏋‍♀' => 'رافعة أثقال',
    '🚴‍♂' => 'راكب دراجة',
    '🚴‍♀' => 'راكبة دراجة',
    '🚵‍♂' => 'متسلق جبال بدراجة',
    '🚵‍♀' => 'متسلقة جبال بدراجة',
    '🤸‍♂' => 'رجل يفعل حركة العجلة',
    '🤸‍♀' => 'سيدة تفعل حركة العجلة',
    '🤼‍♂' => 'مصارعة رجال',
    '🤼‍♀' => 'مصارعة سيدات',
    '🤽‍♂' => 'لاعب كرة ماء',
    '🤽‍♀' => 'لاعبة كرة ماء',
    '🤾‍♂' => 'لاعب كرة يد',
    '🤾‍♀' => 'لاعبة كرة يد',
    '🤹‍♂' => 'لاعب قذف الكرات',
    '🤹‍♀' => 'لاعبة قذف كرات',
    '🧘‍♂' => 'رجل متربّع',
    '🧘‍♀' => 'امرأة متربّعة',
    '🧑‍🧒' => 'أسرة: بالغ، طفل',
    '🐕‍🦺' => 'كلب مساعدة',
    '🐈‍⬛' => 'هرّ أسود',
    '🐻‍❄' => 'دب قطبي',
    '🐦‍⬛' => 'طائر أسود',
    '🐦‍🔥' => 'العنقاء',
    '🍋‍🟩' => 'الليم',
    '🍄‍🟫' => 'فطر بني',
    '⛓‍💥' => 'سلسلة مكسورة',
    '🏳‍🌈' => 'علم ألوان طيف',
    '🏳‍⚧' => 'علم المتحولين جنسيًا',
    '🏴‍☠' => 'علم قراصنة',
    '👋🏻' => 'تلويح باليد: بشرة بلون فاتح',
    '👋🏼' => 'تلويح باليد: بشرة بلون فاتح ومعتدل',
    '👋🏽' => 'تلويح باليد: بشرة بلون معتدل',
    '👋🏾' => 'تلويح باليد: بشرة بلون معتدل مائل للغامق',
    '👋🏿' => 'تلويح باليد: بشرة بلون غامق',
    '🤚🏻' => 'ظهر يد مرفوعة: بشرة بلون فاتح',
    '🤚🏼' => 'ظهر يد مرفوعة: بشرة بلون فاتح ومعتدل',
    '🤚🏽' => 'ظهر يد مرفوعة: بشرة بلون معتدل',
    '🤚🏾' => 'ظهر يد مرفوعة: بشرة بلون معتدل مائل للغامق',
    '🤚🏿' => 'ظهر يد مرفوعة: بشرة بلون غامق',
    '🖐🏻' => 'يد مرفوعة بأصابع متفرقة: بشرة بلون فاتح',
    '🖐🏼' => 'يد مرفوعة بأصابع متفرقة: بشرة بلون فاتح ومعتدل',
    '🖐🏽' => 'يد مرفوعة بأصابع متفرقة: بشرة بلون معتدل',
    '🖐🏾' => 'يد مرفوعة بأصابع متفرقة: بشرة بلون معتدل مائل للغامق',
    '🖐🏿' => 'يد مرفوعة بأصابع متفرقة: بشرة بلون غامق',
    '✋🏻' => 'يد مرفوعة: بشرة بلون فاتح',
    '✋🏼' => 'يد مرفوعة: بشرة بلون فاتح ومعتدل',
    '✋🏽' => 'يد مرفوعة: بشرة بلون معتدل',
    '✋🏾' => 'يد مرفوعة: بشرة بلون معتدل مائل للغامق',
    '✋🏿' => 'يد مرفوعة: بشرة بلون غامق',
    '🖖🏻' => 'تحية فولكان: بشرة بلون فاتح',
    '🖖🏼' => 'تحية فولكان: بشرة بلون فاتح ومعتدل',
    '🖖🏽' => 'تحية فولكان: بشرة بلون معتدل',
    '🖖🏾' => 'تحية فولكان: بشرة بلون معتدل مائل للغامق',
    '🖖🏿' => 'تحية فولكان: بشرة بلون غامق',
    '🫱🏻' => 'يد باتجاه اليمين: بشرة بلون فاتح',
    '🫱🏼' => 'يد باتجاه اليمين: بشرة بلون فاتح ومعتدل',
    '🫱🏽' => 'يد باتجاه اليمين: بشرة بلون معتدل',
    '🫱🏾' => 'يد باتجاه اليمين: بشرة بلون معتدل مائل للغامق',
    '🫱🏿' => 'يد باتجاه اليمين: بشرة بلون غامق',
    '🫲🏻' => 'يد باتجاه اليسار: بشرة بلون فاتح',
    '🫲🏼' => 'يد باتجاه اليسار: بشرة بلون فاتح ومعتدل',
    '🫲🏽' => 'يد باتجاه اليسار: بشرة بلون معتدل',
    '🫲🏾' => 'يد باتجاه اليسار: بشرة بلون معتدل مائل للغامق',
    '🫲🏿' => 'يد باتجاه اليسار: بشرة بلون غامق',
    '🫳🏻' => 'راحة يد للأسفل: بشرة بلون فاتح',
    '🫳🏼' => 'راحة يد للأسفل: بشرة بلون فاتح ومعتدل',
    '🫳🏽' => 'راحة يد للأسفل: بشرة بلون معتدل',
    '🫳🏾' => 'راحة يد للأسفل: بشرة بلون معتدل مائل للغامق',
    '🫳🏿' => 'راحة يد للأسفل: بشرة بلون غامق',
    '🫴🏻' => 'راحة يد للأعلى: بشرة بلون فاتح',
    '🫴🏼' => 'راحة يد للأعلى: بشرة بلون فاتح ومعتدل',
    '🫴🏽' => 'راحة يد للأعلى: بشرة بلون معتدل',
    '🫴🏾' => 'راحة يد للأعلى: بشرة بلون معتدل مائل للغامق',
    '🫴🏿' => 'راحة يد للأعلى: بشرة بلون غامق',
    '🫷🏻' => 'يد تدفع يسارًا: بشرة بلون فاتح',
    '🫷🏼' => 'يد تدفع يسارًا: بشرة بلون فاتح ومعتدل',
    '🫷🏽' => 'يد تدفع يسارًا: بشرة بلون معتدل',
    '🫷🏾' => 'يد تدفع يسارًا: بشرة بلون معتدل مائل للغامق',
    '🫷🏿' => 'يد تدفع يسارًا: بشرة بلون غامق',
    '🫸🏻' => 'يد تدفع يمينًا: بشرة بلون فاتح',
    '🫸🏼' => 'يد تدفع يمينًا: بشرة بلون فاتح ومعتدل',
    '🫸🏽' => 'يد تدفع يمينًا: بشرة بلون معتدل',
    '🫸🏾' => 'يد تدفع يمينًا: بشرة بلون معتدل مائل للغامق',
    '🫸🏿' => 'يد تدفع يمينًا: بشرة بلون غامق',
    '👌🏻' => 'يد تشير للموافقة: بشرة بلون فاتح',
    '👌🏼' => 'يد تشير للموافقة: بشرة بلون فاتح ومعتدل',
    '👌🏽' => 'يد تشير للموافقة: بشرة بلون معتدل',
    '👌🏾' => 'يد تشير للموافقة: بشرة بلون معتدل مائل للغامق',
    '👌🏿' => 'يد تشير للموافقة: بشرة بلون غامق',
    '🤌🏻' => 'أصابع مضمومة: بشرة بلون فاتح',
    '🤌🏼' => 'أصابع مضمومة: بشرة بلون فاتح ومعتدل',
    '🤌🏽' => 'أصابع مضمومة: بشرة بلون معتدل',
    '🤌🏾' => 'أصابع مضمومة: بشرة بلون معتدل مائل للغامق',
    '🤌🏿' => 'أصابع مضمومة: بشرة بلون غامق',
    '🤏🏻' => 'يد تشير بمقدار ضئيل: بشرة بلون فاتح',
    '🤏🏼' => 'يد تشير بمقدار ضئيل: بشرة بلون فاتح ومعتدل',
    '🤏🏽' => 'يد تشير بمقدار ضئيل: بشرة بلون معتدل',
    '🤏🏾' => 'يد تشير بمقدار ضئيل: بشرة بلون معتدل مائل للغامق',
    '🤏🏿' => 'يد تشير بمقدار ضئيل: بشرة بلون غامق',
    '✌🏻' => 'علامة النصر: بشرة بلون فاتح',
    '✌🏼' => 'علامة النصر: بشرة بلون فاتح ومعتدل',
    '✌🏽' => 'علامة النصر: بشرة بلون معتدل',
    '✌🏾' => 'علامة النصر: بشرة بلون معتدل مائل للغامق',
    '✌🏿' => 'علامة النصر: بشرة بلون غامق',
    '🤞🏻' => 'أصابع مشبكة: بشرة بلون فاتح',
    '🤞🏼' => 'أصابع مشبكة: بشرة بلون فاتح ومعتدل',
    '🤞🏽' => 'أصابع مشبكة: بشرة بلون معتدل',
    '🤞🏾' => 'أصابع مشبكة: بشرة بلون معتدل مائل للغامق',
    '🤞🏿' => 'أصابع مشبكة: بشرة بلون غامق',
    '🫰🏻' => 'يد مع تقاطع السبابة والإبهام: بشرة بلون فاتح',
    '🫰🏼' => 'يد مع تقاطع السبابة والإبهام: بشرة بلون فاتح ومعتدل',
    '🫰🏽' => 'يد مع تقاطع السبابة والإبهام: بشرة بلون معتدل',
    '🫰🏾' => 'يد مع تقاطع السبابة والإبهام: بشرة بلون معتدل مائل للغامق',
    '🫰🏿' => 'يد مع تقاطع السبابة والإبهام: بشرة بلون غامق',
    '🤟🏻' => 'إشارة أحبك: بشرة بلون فاتح',
    '🤟🏼' => 'إشارة أحبك: بشرة بلون فاتح ومعتدل',
    '🤟🏽' => 'إشارة أحبك: بشرة بلون معتدل',
    '🤟🏾' => 'إشارة أحبك: بشرة بلون معتدل مائل للغامق',
    '🤟🏿' => 'إشارة أحبك: بشرة بلون غامق',
    '🤘🏻' => 'إشارة قرون: بشرة بلون فاتح',
    '🤘🏼' => 'إشارة قرون: بشرة بلون فاتح ومعتدل',
    '🤘🏽' => 'إشارة قرون: بشرة بلون معتدل',
    '🤘🏾' => 'إشارة قرون: بشرة بلون معتدل مائل للغامق',
    '🤘🏿' => 'إشارة قرون: بشرة بلون غامق',
    '🤙🏻' => 'إشارة للاتصال: بشرة بلون فاتح',
    '🤙🏼' => 'إشارة للاتصال: بشرة بلون فاتح ومعتدل',
    '🤙🏽' => 'إشارة للاتصال: بشرة بلون معتدل',
    '🤙🏾' => 'إشارة للاتصال: بشرة بلون معتدل مائل للغامق',
    '🤙🏿' => 'إشارة للاتصال: بشرة بلون غامق',
    '👈🏻' => 'إصبع لليسار: بشرة بلون فاتح',
    '👈🏼' => 'إصبع لليسار: بشرة بلون فاتح ومعتدل',
    '👈🏽' => 'إصبع لليسار: بشرة بلون معتدل',
    '👈🏾' => 'إصبع لليسار: بشرة بلون معتدل مائل للغامق',
    '👈🏿' => 'إصبع لليسار: بشرة بلون غامق',
    '👉🏻' => 'إصبع لليمين: بشرة بلون فاتح',
    '👉🏼' => 'إصبع لليمين: بشرة بلون فاتح ومعتدل',
    '👉🏽' => 'إصبع لليمين: بشرة بلون معتدل',
    '👉🏾' => 'إصبع لليمين: بشرة بلون معتدل مائل للغامق',
    '👉🏿' => 'إصبع لليمين: بشرة بلون غامق',
    '👆🏻' => 'إصبع لأعلى: بشرة بلون فاتح',
    '👆🏼' => 'إصبع لأعلى: بشرة بلون فاتح ومعتدل',
    '👆🏽' => 'إصبع لأعلى: بشرة بلون معتدل',
    '👆🏾' => 'إصبع لأعلى: بشرة بلون معتدل مائل للغامق',
    '👆🏿' => 'إصبع لأعلى: بشرة بلون غامق',
    '🖕🏻' => 'إصبع الوسطى: بشرة بلون فاتح',
    '🖕🏼' => 'إصبع الوسطى: بشرة بلون فاتح ومعتدل',
    '🖕🏽' => 'إصبع الوسطى: بشرة بلون معتدل',
    '🖕🏾' => 'إصبع الوسطى: بشرة بلون معتدل مائل للغامق',
    '🖕🏿' => 'إصبع الوسطى: بشرة بلون غامق',
    '👇🏻' => 'إصبع لأسفل: بشرة بلون فاتح',
    '👇🏼' => 'إصبع لأسفل: بشرة بلون فاتح ومعتدل',
    '👇🏽' => 'إصبع لأسفل: بشرة بلون معتدل',
    '👇🏾' => 'إصبع لأسفل: بشرة بلون معتدل مائل للغامق',
    '👇🏿' => 'إصبع لأسفل: بشرة بلون غامق',
    '☝🏻' => 'سبابة يشير لأعلى: بشرة بلون فاتح',
    '☝🏼' => 'سبابة يشير لأعلى: بشرة بلون فاتح ومعتدل',
    '☝🏽' => 'سبابة يشير لأعلى: بشرة بلون معتدل',
    '☝🏾' => 'سبابة يشير لأعلى: بشرة بلون معتدل مائل للغامق',
    '☝🏿' => 'سبابة يشير لأعلى: بشرة بلون غامق',
    '🫵🏻' => 'إصبع السبابة يشير إلى الناظر: بشرة بلون فاتح',
    '🫵🏼' => 'إصبع السبابة يشير إلى الناظر: بشرة بلون فاتح ومعتدل',
    '🫵🏽' => 'إصبع السبابة يشير إلى الناظر: بشرة بلون معتدل',
    '🫵🏾' => 'إصبع السبابة يشير إلى الناظر: بشرة بلون معتدل مائل للغامق',
    '🫵🏿' => 'إصبع السبابة يشير إلى الناظر: بشرة بلون غامق',
    '👍🏻' => 'قبول: بشرة بلون فاتح',
    '👍🏼' => 'قبول: بشرة بلون فاتح ومعتدل',
    '👍🏽' => 'قبول: بشرة بلون معتدل',
    '👍🏾' => 'قبول: بشرة بلون معتدل مائل للغامق',
    '👍🏿' => 'قبول: بشرة بلون غامق',
    '👎🏻' => 'رفض: بشرة بلون فاتح',
    '👎🏼' => 'رفض: بشرة بلون فاتح ومعتدل',
    '👎🏽' => 'رفض: بشرة بلون معتدل',
    '👎🏾' => 'رفض: بشرة بلون معتدل مائل للغامق',
    '👎🏿' => 'رفض: بشرة بلون غامق',
    '✊🏻' => 'قبضة يد مرفوعة: بشرة بلون فاتح',
    '✊🏼' => 'قبضة يد مرفوعة: بشرة بلون فاتح ومعتدل',
    '✊🏽' => 'قبضة يد مرفوعة: بشرة بلون معتدل',
    '✊🏾' => 'قبضة يد مرفوعة: بشرة بلون معتدل مائل للغامق',
    '✊🏿' => 'قبضة يد مرفوعة: بشرة بلون غامق',
    '👊🏻' => 'قبضة يد: بشرة بلون فاتح',
    '👊🏼' => 'قبضة يد: بشرة بلون فاتح ومعتدل',
    '👊🏽' => 'قبضة يد: بشرة بلون معتدل',
    '👊🏾' => 'قبضة يد: بشرة بلون معتدل مائل للغامق',
    '👊🏿' => 'قبضة يد: بشرة بلون غامق',
    '🤛🏻' => 'قبضة لليسار: بشرة بلون فاتح',
    '🤛🏼' => 'قبضة لليسار: بشرة بلون فاتح ومعتدل',
    '🤛🏽' => 'قبضة لليسار: بشرة بلون معتدل',
    '🤛🏾' => 'قبضة لليسار: بشرة بلون معتدل مائل للغامق',
    '🤛🏿' => 'قبضة لليسار: بشرة بلون غامق',
    '🤜🏻' => 'قبضة لليمين: بشرة بلون فاتح',
    '🤜🏼' => 'قبضة لليمين: بشرة بلون فاتح ومعتدل',
    '🤜🏽' => 'قبضة لليمين: بشرة بلون معتدل',
    '🤜🏾' => 'قبضة لليمين: بشرة بلون معتدل مائل للغامق',
    '🤜🏿' => 'قبضة لليمين: بشرة بلون غامق',
    '👏🏻' => 'يدان تصفقان: بشرة بلون فاتح',
    '👏🏼' => 'يدان تصفقان: بشرة بلون فاتح ومعتدل',
    '👏🏽' => 'يدان تصفقان: بشرة بلون معتدل',
    '👏🏾' => 'يدان تصفقان: بشرة بلون معتدل مائل للغامق',
    '👏🏿' => 'يدان تصفقان: بشرة بلون غامق',
    '🙌🏻' => 'تشجيع: بشرة بلون فاتح',
    '🙌🏼' => 'تشجيع: بشرة بلون فاتح ومعتدل',
    '🙌🏽' => 'تشجيع: بشرة بلون معتدل',
    '🙌🏾' => 'تشجيع: بشرة بلون معتدل مائل للغامق',
    '🙌🏿' => 'تشجيع: بشرة بلون غامق',
    '🫶🏻' => 'أيدي متشابكة على شكل قلب: بشرة بلون فاتح',
    '🫶🏼' => 'أيدي متشابكة على شكل قلب: بشرة بلون فاتح ومعتدل',
    '🫶🏽' => 'أيدي متشابكة على شكل قلب: بشرة بلون معتدل',
    '🫶🏾' => 'أيدي متشابكة على شكل قلب: بشرة بلون معتدل مائل للغامق',
    '🫶🏿' => 'أيدي متشابكة على شكل قلب: بشرة بلون غامق',
    '👐🏻' => 'يدان مفتوحتان: بشرة بلون فاتح',
    '👐🏼' => 'يدان مفتوحتان: بشرة بلون فاتح ومعتدل',
    '👐🏽' => 'يدان مفتوحتان: بشرة بلون معتدل',
    '👐🏾' => 'يدان مفتوحتان: بشرة بلون معتدل مائل للغامق',
    '👐🏿' => 'يدان مفتوحتان: بشرة بلون غامق',
    '🤲🏻' => 'راحتان مفتوحتان: بشرة بلون فاتح',
    '🤲🏼' => 'راحتان مفتوحتان: بشرة بلون فاتح ومعتدل',
    '🤲🏽' => 'راحتان مفتوحتان: بشرة بلون معتدل',
    '🤲🏾' => 'راحتان مفتوحتان: بشرة بلون معتدل مائل للغامق',
    '🤲🏿' => 'راحتان مفتوحتان: بشرة بلون غامق',
    '🤝🏻' => 'مصافحة: بشرة بلون فاتح',
    '🤝🏼' => 'مصافحة: بشرة بلون فاتح ومعتدل',
    '🤝🏽' => 'مصافحة: بشرة بلون معتدل',
    '🤝🏾' => 'مصافحة: بشرة بلون معتدل مائل للغامق',
    '🤝🏿' => 'مصافحة: بشرة بلون غامق',
    '🙏🏻' => 'يدان مضمومتان: بشرة بلون فاتح',
    '🙏🏼' => 'يدان مضمومتان: بشرة بلون فاتح ومعتدل',
    '🙏🏽' => 'يدان مضمومتان: بشرة بلون معتدل',
    '🙏🏾' => 'يدان مضمومتان: بشرة بلون معتدل مائل للغامق',
    '🙏🏿' => 'يدان مضمومتان: بشرة بلون غامق',
    '✍🏻' => 'يد تكتب: بشرة بلون فاتح',
    '✍🏼' => 'يد تكتب: بشرة بلون فاتح ومعتدل',
    '✍🏽' => 'يد تكتب: بشرة بلون معتدل',
    '✍🏾' => 'يد تكتب: بشرة بلون معتدل مائل للغامق',
    '✍🏿' => 'يد تكتب: بشرة بلون غامق',
    '💅🏻' => 'طلاء أظافر: بشرة بلون فاتح',
    '💅🏼' => 'طلاء أظافر: بشرة بلون فاتح ومعتدل',
    '💅🏽' => 'طلاء أظافر: بشرة بلون معتدل',
    '💅🏾' => 'طلاء أظافر: بشرة بلون معتدل مائل للغامق',
    '💅🏿' => 'طلاء أظافر: بشرة بلون غامق',
    '🤳🏻' => 'صورة سيلفي: بشرة بلون فاتح',
    '🤳🏼' => 'صورة سيلفي: بشرة بلون فاتح ومعتدل',
    '🤳🏽' => 'صورة سيلفي: بشرة بلون معتدل',
    '🤳🏾' => 'صورة سيلفي: بشرة بلون معتدل مائل للغامق',
    '🤳🏿' => 'صورة سيلفي: بشرة بلون غامق',
    '💪🏻' => 'عضلة الذراع: بشرة بلون فاتح',
    '💪🏼' => 'عضلة الذراع: بشرة بلون فاتح ومعتدل',
    '💪🏽' => 'عضلة الذراع: بشرة بلون معتدل',
    '💪🏾' => 'عضلة الذراع: بشرة بلون معتدل مائل للغامق',
    '💪🏿' => 'عضلة الذراع: بشرة بلون غامق',
    '🦵🏻' => 'ساق: بشرة بلون فاتح',
    '🦵🏼' => 'ساق: بشرة بلون فاتح ومعتدل',
    '🦵🏽' => 'ساق: بشرة بلون معتدل',
    '🦵🏾' => 'ساق: بشرة بلون معتدل مائل للغامق',
    '🦵🏿' => 'ساق: بشرة بلون غامق',
    '🦶🏻' => 'قدم: بشرة بلون فاتح',
    '🦶🏼' => 'قدم: بشرة بلون فاتح ومعتدل',
    '🦶🏽' => 'قدم: بشرة بلون معتدل',
    '🦶🏾' => 'قدم: بشرة بلون معتدل مائل للغامق',
    '🦶🏿' => 'قدم: بشرة بلون غامق',
    '👂🏻' => 'أذن: بشرة بلون فاتح',
    '👂🏼' => 'أذن: بشرة بلون فاتح ومعتدل',
    '👂🏽' => 'أذن: بشرة بلون معتدل',
    '👂🏾' => 'أذن: بشرة بلون معتدل مائل للغامق',
    '👂🏿' => 'أذن: بشرة بلون غامق',
    '🦻🏻' => 'أذن مع جهاز سمعي: بشرة بلون فاتح',
    '🦻🏼' => 'أذن مع جهاز سمعي: بشرة بلون فاتح ومعتدل',
    '🦻🏽' => 'أذن مع جهاز سمعي: بشرة بلون معتدل',
    '🦻🏾' => 'أذن مع جهاز سمعي: بشرة بلون معتدل مائل للغامق',
    '🦻🏿' => 'أذن مع جهاز سمعي: بشرة بلون غامق',
    '👃🏻' => 'أنف: بشرة بلون فاتح',
    '👃🏼' => 'أنف: بشرة بلون فاتح ومعتدل',
    '👃🏽' => 'أنف: بشرة بلون معتدل',
    '👃🏾' => 'أنف: بشرة بلون معتدل مائل للغامق',
    '👃🏿' => 'أنف: بشرة بلون غامق',
    '👶🏻' => 'رضيع: بشرة بلون فاتح',
    '👶🏼' => 'رضيع: بشرة بلون فاتح ومعتدل',
    '👶🏽' => 'رضيع: بشرة بلون معتدل',
    '👶🏾' => 'رضيع: بشرة بلون معتدل مائل للغامق',
    '👶🏿' => 'رضيع: بشرة بلون غامق',
    '🧒🏻' => 'طفل: بشرة بلون فاتح',
    '🧒🏼' => 'طفل: بشرة بلون فاتح ومعتدل',
    '🧒🏽' => 'طفل: بشرة بلون معتدل',
    '🧒🏾' => 'طفل: بشرة بلون معتدل مائل للغامق',
    '🧒🏿' => 'طفل: بشرة بلون غامق',
    '👦🏻' => 'صبي: بشرة بلون فاتح',
    '👦🏼' => 'صبي: بشرة بلون فاتح ومعتدل',
    '👦🏽' => 'صبي: بشرة بلون معتدل',
    '👦🏾' => 'صبي: بشرة بلون معتدل مائل للغامق',
    '👦🏿' => 'صبي: بشرة بلون غامق',
    '👧🏻' => 'فتاة: بشرة بلون فاتح',
    '👧🏼' => 'فتاة: بشرة بلون فاتح ومعتدل',
    '👧🏽' => 'فتاة: بشرة بلون معتدل',
    '👧🏾' => 'فتاة: بشرة بلون معتدل مائل للغامق',
    '👧🏿' => 'فتاة: بشرة بلون غامق',
    '🧑🏻' => 'بالغ: بشرة بلون فاتح',
    '🧑🏼' => 'بالغ: بشرة بلون فاتح ومعتدل',
    '🧑🏽' => 'بالغ: بشرة بلون معتدل',
    '🧑🏾' => 'بالغ: بشرة بلون معتدل مائل للغامق',
    '🧑🏿' => 'بالغ: بشرة بلون غامق',
    '👱🏻' => 'شخص أشقر: بشرة بلون فاتح',
    '👱🏼' => 'شخص أشقر: بشرة بلون فاتح ومعتدل',
    '👱🏽' => 'شخص أشقر: بشرة بلون معتدل',
    '👱🏾' => 'شخص أشقر: بشرة بلون معتدل مائل للغامق',
    '👱🏿' => 'شخص أشقر: بشرة بلون غامق',
    '👨🏻' => 'رجل: بشرة بلون فاتح',
    '👨🏼' => 'رجل: بشرة بلون فاتح ومعتدل',
    '👨🏽' => 'رجل: بشرة بلون معتدل',
    '👨🏾' => 'رجل: بشرة بلون معتدل مائل للغامق',
    '👨🏿' => 'رجل: بشرة بلون غامق',
    '🧔🏻' => 'شخص بلحية: بشرة بلون فاتح',
    '🧔🏼' => 'شخص بلحية: بشرة بلون فاتح ومعتدل',
    '🧔🏽' => 'شخص بلحية: بشرة بلون معتدل',
    '🧔🏾' => 'شخص بلحية: بشرة بلون معتدل مائل للغامق',
    '🧔🏿' => 'شخص بلحية: بشرة بلون غامق',
    '👩🏻' => 'سيدة: بشرة بلون فاتح',
    '👩🏼' => 'سيدة: بشرة بلون فاتح ومعتدل',
    '👩🏽' => 'سيدة: بشرة بلون معتدل',
    '👩🏾' => 'سيدة: بشرة بلون معتدل مائل للغامق',
    '👩🏿' => 'سيدة: بشرة بلون غامق',
    '🧓🏻' => 'بالغ أكبر في السن: بشرة بلون فاتح',
    '🧓🏼' => 'بالغ أكبر في السن: بشرة بلون فاتح ومعتدل',
    '🧓🏽' => 'بالغ أكبر في السن: بشرة بلون معتدل',
    '🧓🏾' => 'بالغ أكبر في السن: بشرة بلون معتدل مائل للغامق',
    '🧓🏿' => 'بالغ أكبر في السن: بشرة بلون غامق',
    '👴🏻' => 'رجل عجوز: بشرة بلون فاتح',
    '👴🏼' => 'رجل عجوز: بشرة بلون فاتح ومعتدل',
    '👴🏽' => 'رجل عجوز: بشرة بلون معتدل',
    '👴🏾' => 'رجل عجوز: بشرة بلون معتدل مائل للغامق',
    '👴🏿' => 'رجل عجوز: بشرة بلون غامق',
    '👵🏻' => 'سيدة عجوز: بشرة بلون فاتح',
    '👵🏼' => 'سيدة عجوز: بشرة بلون فاتح ومعتدل',
    '👵🏽' => 'سيدة عجوز: بشرة بلون معتدل',
    '👵🏾' => 'سيدة عجوز: بشرة بلون معتدل مائل للغامق',
    '👵🏿' => 'سيدة عجوز: بشرة بلون غامق',
    '🙍🏻' => 'شخص عابس: بشرة بلون فاتح',
    '🙍🏼' => 'شخص عابس: بشرة بلون فاتح ومعتدل',
    '🙍🏽' => 'شخص عابس: بشرة بلون معتدل',
    '🙍🏾' => 'شخص عابس: بشرة بلون معتدل مائل للغامق',
    '🙍🏿' => 'شخص عابس: بشرة بلون غامق',
    '🙎🏻' => 'شخص متجهم: بشرة بلون فاتح',
    '🙎🏼' => 'شخص متجهم: بشرة بلون فاتح ومعتدل',
    '🙎🏽' => 'شخص متجهم: بشرة بلون معتدل',
    '🙎🏾' => 'شخص متجهم: بشرة بلون معتدل مائل للغامق',
    '🙎🏿' => 'شخص متجهم: بشرة بلون غامق',
    '🙅🏻' => 'إشارة رفض: بشرة بلون فاتح',
    '🙅🏼' => 'إشارة رفض: بشرة بلون فاتح ومعتدل',
    '🙅🏽' => 'إشارة رفض: بشرة بلون معتدل',
    '🙅🏾' => 'إشارة رفض: بشرة بلون معتدل مائل للغامق',
    '🙅🏿' => 'إشارة رفض: بشرة بلون غامق',
    '🙆🏻' => 'إشارة موافقة: بشرة بلون فاتح',
    '🙆🏼' => 'إشارة موافقة: بشرة بلون فاتح ومعتدل',
    '🙆🏽' => 'إشارة موافقة: بشرة بلون معتدل',
    '🙆🏾' => 'إشارة موافقة: بشرة بلون معتدل مائل للغامق',
    '🙆🏿' => 'إشارة موافقة: بشرة بلون غامق',
    '💁🏻' => 'شخص بيد مائلة: بشرة بلون فاتح',
    '💁🏼' => 'شخص بيد مائلة: بشرة بلون فاتح ومعتدل',
    '💁🏽' => 'شخص بيد مائلة: بشرة بلون معتدل',
    '💁🏾' => 'شخص بيد مائلة: بشرة بلون معتدل مائل للغامق',
    '💁🏿' => 'شخص بيد مائلة: بشرة بلون غامق',
    '🙋🏻' => 'شخص يرفع يده: بشرة بلون فاتح',
    '🙋🏼' => 'شخص يرفع يده: بشرة بلون فاتح ومعتدل',
    '🙋🏽' => 'شخص يرفع يده: بشرة بلون معتدل',
    '🙋🏾' => 'شخص يرفع يده: بشرة بلون معتدل مائل للغامق',
    '🙋🏿' => 'شخص يرفع يده: بشرة بلون غامق',
    '🧏🏻' => 'شخص أصم: بشرة بلون فاتح',
    '🧏🏼' => 'شخص أصم: بشرة بلون فاتح ومعتدل',
    '🧏🏽' => 'شخص أصم: بشرة بلون معتدل',
    '🧏🏾' => 'شخص أصم: بشرة بلون معتدل مائل للغامق',
    '🧏🏿' => 'شخص أصم: بشرة بلون غامق',
    '🙇🏻' => 'شخص ينحني اعتذارًا: بشرة بلون فاتح',
    '🙇🏼' => 'شخص ينحني اعتذارًا: بشرة بلون فاتح ومعتدل',
    '🙇🏽' => 'شخص ينحني اعتذارًا: بشرة بلون معتدل',
    '🙇🏾' => 'شخص ينحني اعتذارًا: بشرة بلون معتدل مائل للغامق',
    '🙇🏿' => 'شخص ينحني اعتذارًا: بشرة بلون غامق',
    '🤦🏻' => 'شخص محبط: بشرة بلون فاتح',
    '🤦🏼' => 'شخص محبط: بشرة بلون فاتح ومعتدل',
    '🤦🏽' => 'شخص محبط: بشرة بلون معتدل',
    '🤦🏾' => 'شخص محبط: بشرة بلون معتدل مائل للغامق',
    '🤦🏿' => 'شخص محبط: بشرة بلون غامق',
    '🤷🏻' => 'لا مبالاة: بشرة بلون فاتح',
    '🤷🏼' => 'لا مبالاة: بشرة بلون فاتح ومعتدل',
    '🤷🏽' => 'لا مبالاة: بشرة بلون معتدل',
    '🤷🏾' => 'لا مبالاة: بشرة بلون معتدل مائل للغامق',
    '🤷🏿' => 'لا مبالاة: بشرة بلون غامق',
    '👮🏻' => 'ضابط شرطة: بشرة بلون فاتح',
    '👮🏼' => 'ضابط شرطة: بشرة بلون فاتح ومعتدل',
    '👮🏽' => 'ضابط شرطة: بشرة بلون معتدل',
    '👮🏾' => 'ضابط شرطة: بشرة بلون معتدل مائل للغامق',
    '👮🏿' => 'ضابط شرطة: بشرة بلون غامق',
    '🕵🏻' => 'شخص يحقّق: بشرة بلون فاتح',
    '🕵🏼' => 'شخص يحقّق: بشرة بلون فاتح ومعتدل',
    '🕵🏽' => 'شخص يحقّق: بشرة بلون معتدل',
    '🕵🏾' => 'شخص يحقّق: بشرة بلون معتدل مائل للغامق',
    '🕵🏿' => 'شخص يحقّق: بشرة بلون غامق',
    '💂🏻' => 'حارس: بشرة بلون فاتح',
    '💂🏼' => 'حارس: بشرة بلون فاتح ومعتدل',
    '💂🏽' => 'حارس: بشرة بلون معتدل',
    '💂🏾' => 'حارس: بشرة بلون معتدل مائل للغامق',
    '💂🏿' => 'حارس: بشرة بلون غامق',
    '🥷🏻' => 'نينجا: بشرة بلون فاتح',
    '🥷🏼' => 'نينجا: بشرة بلون فاتح ومعتدل',
    '🥷🏽' => 'نينجا: بشرة بلون معتدل',
    '🥷🏾' => 'نينجا: بشرة بلون معتدل مائل للغامق',
    '🥷🏿' => 'نينجا: بشرة بلون غامق',
    '👷🏻' => 'شخص يعمل في البناء: بشرة بلون فاتح',
    '👷🏼' => 'شخص يعمل في البناء: بشرة بلون فاتح ومعتدل',
    '👷🏽' => 'شخص يعمل في البناء: بشرة بلون معتدل',
    '👷🏾' => 'شخص يعمل في البناء: بشرة بلون معتدل مائل للغامق',
    '👷🏿' => 'شخص يعمل في البناء: بشرة بلون غامق',
    '🫅🏻' => 'شخص يرتدي تاجاً: بشرة بلون فاتح',
    '🫅🏼' => 'شخص يرتدي تاجاً: بشرة بلون فاتح ومعتدل',
    '🫅🏽' => 'شخص يرتدي تاجاً: بشرة بلون معتدل',
    '🫅🏾' => 'شخص يرتدي تاجاً: بشرة بلون معتدل مائل للغامق',
    '🫅🏿' => 'شخص يرتدي تاجاً: بشرة بلون غامق',
    '🤴🏻' => 'أمير: بشرة بلون فاتح',
    '🤴🏼' => 'أمير: بشرة بلون فاتح ومعتدل',
    '🤴🏽' => 'أمير: بشرة بلون معتدل',
    '🤴🏾' => 'أمير: بشرة بلون معتدل مائل للغامق',
    '🤴🏿' => 'أمير: بشرة بلون غامق',
    '👸🏻' => 'أميرة: بشرة بلون فاتح',
    '👸🏼' => 'أميرة: بشرة بلون فاتح ومعتدل',
    '👸🏽' => 'أميرة: بشرة بلون معتدل',
    '👸🏾' => 'أميرة: بشرة بلون معتدل مائل للغامق',
    '👸🏿' => 'أميرة: بشرة بلون غامق',
    '👳🏻' => 'رجل بعمامة: بشرة بلون فاتح',
    '👳🏼' => 'رجل بعمامة: بشرة بلون فاتح ومعتدل',
    '👳🏽' => 'رجل بعمامة: بشرة بلون معتدل',
    '👳🏾' => 'رجل بعمامة: بشرة بلون معتدل مائل للغامق',
    '👳🏿' => 'رجل بعمامة: بشرة بلون غامق',
    '👲🏻' => 'رجل بعمامة صينية: بشرة بلون فاتح',
    '👲🏼' => 'رجل بعمامة صينية: بشرة بلون فاتح ومعتدل',
    '👲🏽' => 'رجل بعمامة صينية: بشرة بلون معتدل',
    '👲🏾' => 'رجل بعمامة صينية: بشرة بلون معتدل مائل للغامق',
    '👲🏿' => 'رجل بعمامة صينية: بشرة بلون غامق',
    '🧕🏻' => 'امرأة محجّبة: بشرة بلون فاتح',
    '🧕🏼' => 'امرأة محجّبة: بشرة بلون فاتح ومعتدل',
    '🧕🏽' => 'امرأة محجّبة: بشرة بلون معتدل',
    '🧕🏾' => 'امرأة محجّبة: بشرة بلون معتدل مائل للغامق',
    '🧕🏿' => 'امرأة محجّبة: بشرة بلون غامق',
    '🤵🏻' => 'شخص ببدلة رسمية: بشرة بلون فاتح',
    '🤵🏼' => 'شخص ببدلة رسمية: بشرة بلون فاتح ومعتدل',
    '🤵🏽' => 'شخص ببدلة رسمية: بشرة بلون معتدل',
    '🤵🏾' => 'شخص ببدلة رسمية: بشرة بلون معتدل مائل للغامق',
    '🤵🏿' => 'شخص ببدلة رسمية: بشرة بلون غامق',
    '👰🏻' => 'عروس بطرحة: بشرة بلون فاتح',
    '👰🏼' => 'عروس بطرحة: بشرة بلون فاتح ومعتدل',
    '👰🏽' => 'عروس بطرحة: بشرة بلون معتدل',
    '👰🏾' => 'عروس بطرحة: بشرة بلون معتدل مائل للغامق',
    '👰🏿' => 'عروس بطرحة: بشرة بلون غامق',
    '🤰🏻' => 'امرأة حامل: بشرة بلون فاتح',
    '🤰🏼' => 'امرأة حامل: بشرة بلون فاتح ومعتدل',
    '🤰🏽' => 'امرأة حامل: بشرة بلون معتدل',
    '🤰🏾' => 'امرأة حامل: بشرة بلون معتدل مائل للغامق',
    '🤰🏿' => 'امرأة حامل: بشرة بلون غامق',
    '🫃🏻' => 'رجل حامل: بشرة بلون فاتح',
    '🫃🏼' => 'رجل حامل: بشرة بلون فاتح ومعتدل',
    '🫃🏽' => 'رجل حامل: بشرة بلون معتدل',
    '🫃🏾' => 'رجل حامل: بشرة بلون معتدل مائل للغامق',
    '🫃🏿' => 'رجل حامل: بشرة بلون غامق',
    '🫄🏻' => 'شخص حامل: بشرة بلون فاتح',
    '🫄🏼' => 'شخص حامل: بشرة بلون فاتح ومعتدل',
    '🫄🏽' => 'شخص حامل: بشرة بلون معتدل',
    '🫄🏾' => 'شخص حامل: بشرة بلون معتدل مائل للغامق',
    '🫄🏿' => 'شخص حامل: بشرة بلون غامق',
    '🤱🏻' => 'رضاعة: بشرة بلون فاتح',
    '🤱🏼' => 'رضاعة: بشرة بلون فاتح ومعتدل',
    '🤱🏽' => 'رضاعة: بشرة بلون معتدل',
    '🤱🏾' => 'رضاعة: بشرة بلون معتدل مائل للغامق',
    '🤱🏿' => 'رضاعة: بشرة بلون غامق',
    '👼🏻' => 'طفل ملاك: بشرة بلون فاتح',
    '👼🏼' => 'طفل ملاك: بشرة بلون فاتح ومعتدل',
    '👼🏽' => 'طفل ملاك: بشرة بلون معتدل',
    '👼🏾' => 'طفل ملاك: بشرة بلون معتدل مائل للغامق',
    '👼🏿' => 'طفل ملاك: بشرة بلون غامق',
    '🎅🏻' => 'بابا نويل: بشرة بلون فاتح',
    '🎅🏼' => 'بابا نويل: بشرة بلون فاتح ومعتدل',
    '🎅🏽' => 'بابا نويل: بشرة بلون معتدل',
    '🎅🏾' => 'بابا نويل: بشرة بلون معتدل مائل للغامق',
    '🎅🏿' => 'بابا نويل: بشرة بلون غامق',
    '🤶🏻' => 'سيدة سانتا كلوز: بشرة بلون فاتح',
    '🤶🏼' => 'سيدة سانتا كلوز: بشرة بلون فاتح ومعتدل',
    '🤶🏽' => 'سيدة سانتا كلوز: بشرة بلون معتدل',
    '🤶🏾' => 'سيدة سانتا كلوز: بشرة بلون معتدل مائل للغامق',
    '🤶🏿' => 'سيدة سانتا كلوز: بشرة بلون غامق',
    '🦸🏻' => 'بطل خارق: بشرة بلون فاتح',
    '🦸🏼' => 'بطل خارق: بشرة بلون فاتح ومعتدل',
    '🦸🏽' => 'بطل خارق: بشرة بلون معتدل',
    '🦸🏾' => 'بطل خارق: بشرة بلون معتدل مائل للغامق',
    '🦸🏿' => 'بطل خارق: بشرة بلون غامق',
    '🦹🏻' => 'شرير خارق: بشرة بلون فاتح',
    '🦹🏼' => 'شرير خارق: بشرة بلون فاتح ومعتدل',
    '🦹🏽' => 'شرير خارق: بشرة بلون معتدل',
    '🦹🏾' => 'شرير خارق: بشرة بلون معتدل مائل للغامق',
    '🦹🏿' => 'شرير خارق: بشرة بلون غامق',
    '🧙🏻' => 'سحرة: بشرة بلون فاتح',
    '🧙🏼' => 'سحرة: بشرة بلون فاتح ومعتدل',
    '🧙🏽' => 'سحرة: بشرة بلون معتدل',
    '🧙🏾' => 'سحرة: بشرة بلون معتدل مائل للغامق',
    '🧙🏿' => 'سحرة: بشرة بلون غامق',
    '🧚🏻' => 'جنيّة خيالية: بشرة بلون فاتح',
    '🧚🏼' => 'جنيّة خيالية: بشرة بلون فاتح ومعتدل',
    '🧚🏽' => 'جنيّة خيالية: بشرة بلون معتدل',
    '🧚🏾' => 'جنيّة خيالية: بشرة بلون معتدل مائل للغامق',
    '🧚🏿' => 'جنيّة خيالية: بشرة بلون غامق',
    '🧛🏻' => 'مصّاص دماء: بشرة بلون فاتح',
    '🧛🏼' => 'مصّاص دماء: بشرة بلون فاتح ومعتدل',
    '🧛🏽' => 'مصّاص دماء: بشرة بلون معتدل',
    '🧛🏾' => 'مصّاص دماء: بشرة بلون معتدل مائل للغامق',
    '🧛🏿' => 'مصّاص دماء: بشرة بلون غامق',
    '🧜🏻' => 'مخلوق بحري بجسد بشري وذيل سمكة: بشرة بلون فاتح',
    '🧜🏼' => 'مخلوق بحري بجسد بشري وذيل سمكة: بشرة بلون فاتح ومعتدل',
    '🧜🏽' => 'مخلوق بحري بجسد بشري وذيل سمكة: بشرة بلون معتدل',
    '🧜🏾' => 'مخلوق بحري بجسد بشري وذيل سمكة: بشرة بلون معتدل مائل للغامق',
    '🧜🏿' => 'مخلوق بحري بجسد بشري وذيل سمكة: بشرة بلون غامق',
    '🧝🏻' => 'جنّي صغير: بشرة بلون فاتح',
    '🧝🏼' => 'جنّي صغير: بشرة بلون فاتح ومعتدل',
    '🧝🏽' => 'جنّي صغير: بشرة بلون معتدل',
    '🧝🏾' => 'جنّي صغير: بشرة بلون معتدل مائل للغامق',
    '🧝🏿' => 'جنّي صغير: بشرة بلون غامق',
    '💆🏻' => 'شخص يحصل على مساج: بشرة بلون فاتح',
    '💆🏼' => 'شخص يحصل على مساج: بشرة بلون فاتح ومعتدل',
    '💆🏽' => 'شخص يحصل على مساج: بشرة بلون معتدل',
    '💆🏾' => 'شخص يحصل على مساج: بشرة بلون معتدل مائل للغامق',
    '💆🏿' => 'شخص يحصل على مساج: بشرة بلون غامق',
    '💇🏻' => 'شخص يُقص شعره: بشرة بلون فاتح',
    '💇🏼' => 'شخص يُقص شعره: بشرة بلون فاتح ومعتدل',
    '💇🏽' => 'شخص يُقص شعره: بشرة بلون معتدل',
    '💇🏾' => 'شخص يُقص شعره: بشرة بلون معتدل مائل للغامق',
    '💇🏿' => 'شخص يُقص شعره: بشرة بلون غامق',
    '🚶🏻' => 'شخص يسير: بشرة بلون فاتح',
    '🚶🏼' => 'شخص يسير: بشرة بلون فاتح ومعتدل',
    '🚶🏽' => 'شخص يسير: بشرة بلون معتدل',
    '🚶🏾' => 'شخص يسير: بشرة بلون معتدل مائل للغامق',
    '🚶🏿' => 'شخص يسير: بشرة بلون غامق',
    '🧍🏻' => 'شخص واقف: بشرة بلون فاتح',
    '🧍🏼' => 'شخص واقف: بشرة بلون فاتح ومعتدل',
    '🧍🏽' => 'شخص واقف: بشرة بلون معتدل',
    '🧍🏾' => 'شخص واقف: بشرة بلون معتدل مائل للغامق',
    '🧍🏿' => 'شخص واقف: بشرة بلون غامق',
    '🧎🏻' => 'شخص جالس على ركبتيه: بشرة بلون فاتح',
    '🧎🏼' => 'شخص جالس على ركبتيه: بشرة بلون فاتح ومعتدل',
    '🧎🏽' => 'شخص جالس على ركبتيه: بشرة بلون معتدل',
    '🧎🏾' => 'شخص جالس على ركبتيه: بشرة بلون معتدل مائل للغامق',
    '🧎🏿' => 'شخص جالس على ركبتيه: بشرة بلون غامق',
    '🏃🏻' => 'شخص يجري: بشرة بلون فاتح',
    '🏃🏼' => 'شخص يجري: بشرة بلون فاتح ومعتدل',
    '🏃🏽' => 'شخص يجري: بشرة بلون معتدل',
    '🏃🏾' => 'شخص يجري: بشرة بلون معتدل مائل للغامق',
    '🏃🏿' => 'شخص يجري: بشرة بلون غامق',
    '💃🏻' => 'راقصة: بشرة بلون فاتح',
    '💃🏼' => 'راقصة: بشرة بلون فاتح ومعتدل',
    '💃🏽' => 'راقصة: بشرة بلون معتدل',
    '💃🏾' => 'راقصة: بشرة بلون معتدل مائل للغامق',
    '💃🏿' => 'راقصة: بشرة بلون غامق',
    '🕺🏻' => 'رجل يرقص: بشرة بلون فاتح',
    '🕺🏼' => 'رجل يرقص: بشرة بلون فاتح ومعتدل',
    '🕺🏽' => 'رجل يرقص: بشرة بلون معتدل',
    '🕺🏾' => 'رجل يرقص: بشرة بلون معتدل مائل للغامق',
    '🕺🏿' => 'رجل يرقص: بشرة بلون غامق',
    '🕴🏻' => 'رجل أعمال يرتقي: بشرة بلون فاتح',
    '🕴🏼' => 'رجل أعمال يرتقي: بشرة بلون فاتح ومعتدل',
    '🕴🏽' => 'رجل أعمال يرتقي: بشرة بلون معتدل',
    '🕴🏾' => 'رجل أعمال يرتقي: بشرة بلون معتدل مائل للغامق',
    '🕴🏿' => 'رجل أعمال يرتقي: بشرة بلون غامق',
    '👯🏻' => 'شخصان يرقصان: بشرة بلون فاتح',
    '👯🏼' => 'شخصان يرقصان: بشرة بلون فاتح ومعتدل',
    '👯🏽' => 'شخصان يرقصان: بشرة بلون معتدل',
    '👯🏾' => 'شخصان يرقصان: بشرة بلون معتدل مائل للغامق',
    '👯🏿' => 'شخصان يرقصان: بشرة بلون غامق',
    '🧖🏻' => 'شخص في حمّام بخار: بشرة بلون فاتح',
    '🧖🏼' => 'شخص في حمّام بخار: بشرة بلون فاتح ومعتدل',
    '🧖🏽' => 'شخص في حمّام بخار: بشرة بلون معتدل',
    '🧖🏾' => 'شخص في حمّام بخار: بشرة بلون معتدل مائل للغامق',
    '🧖🏿' => 'شخص في حمّام بخار: بشرة بلون غامق',
    '🧗🏻' => 'شخص يتسلّق: بشرة بلون فاتح',
    '🧗🏼' => 'شخص يتسلّق: بشرة بلون فاتح ومعتدل',
    '🧗🏽' => 'شخص يتسلّق: بشرة بلون معتدل',
    '🧗🏾' => 'شخص يتسلّق: بشرة بلون معتدل مائل للغامق',
    '🧗🏿' => 'شخص يتسلّق: بشرة بلون غامق',
    '🏇🏻' => 'سباق خيول: بشرة بلون فاتح',
    '🏇🏼' => 'سباق خيول: بشرة بلون فاتح ومعتدل',
    '🏇🏽' => 'سباق خيول: بشرة بلون معتدل',
    '🏇🏾' => 'سباق خيول: بشرة بلون معتدل مائل للغامق',
    '🏇🏿' => 'سباق خيول: بشرة بلون غامق',
    '🏂🏻' => 'متزلج: بشرة بلون فاتح',
    '🏂🏼' => 'متزلج: بشرة بلون فاتح ومعتدل',
    '🏂🏽' => 'متزلج: بشرة بلون معتدل',
    '🏂🏾' => 'متزلج: بشرة بلون معتدل مائل للغامق',
    '🏂🏿' => 'متزلج: بشرة بلون غامق',
    '🏌🏻' => 'شخص يلعب غولف: بشرة بلون فاتح',
    '🏌🏼' => 'شخص يلعب غولف: بشرة بلون فاتح ومعتدل',
    '🏌🏽' => 'شخص يلعب غولف: بشرة بلون معتدل',
    '🏌🏾' => 'شخص يلعب غولف: بشرة بلون معتدل مائل للغامق',
    '🏌🏿' => 'شخص يلعب غولف: بشرة بلون غامق',
    '🏄🏻' => 'شخص يركب الأمواج: بشرة بلون فاتح',
    '🏄🏼' => 'شخص يركب الأمواج: بشرة بلون فاتح ومعتدل',
    '🏄🏽' => 'شخص يركب الأمواج: بشرة بلون معتدل',
    '🏄🏾' => 'شخص يركب الأمواج: بشرة بلون معتدل مائل للغامق',
    '🏄🏿' => 'شخص يركب الأمواج: بشرة بلون غامق',
    '🚣🏻' => 'شخص يجدف بزورق: بشرة بلون فاتح',
    '🚣🏼' => 'شخص يجدف بزورق: بشرة بلون فاتح ومعتدل',
    '🚣🏽' => 'شخص يجدف بزورق: بشرة بلون معتدل',
    '🚣🏾' => 'شخص يجدف بزورق: بشرة بلون معتدل مائل للغامق',
    '🚣🏿' => 'شخص يجدف بزورق: بشرة بلون غامق',
    '🏊🏻' => 'شخص يسبح: بشرة بلون فاتح',
    '🏊🏼' => 'شخص يسبح: بشرة بلون فاتح ومعتدل',
    '🏊🏽' => 'شخص يسبح: بشرة بلون معتدل',
    '🏊🏾' => 'شخص يسبح: بشرة بلون معتدل مائل للغامق',
    '🏊🏿' => 'شخص يسبح: بشرة بلون غامق',
    '⛹🏻' => 'شخص وكرة: بشرة بلون فاتح',
    '⛹🏼' => 'شخص وكرة: بشرة بلون فاتح ومعتدل',
    '⛹🏽' => 'شخص وكرة: بشرة بلون معتدل',
    '⛹🏾' => 'شخص وكرة: بشرة بلون معتدل مائل للغامق',
    '⛹🏿' => 'شخص وكرة: بشرة بلون غامق',
    '🏋🏻' => 'شخص يرفع أثقال: بشرة بلون فاتح',
    '🏋🏼' => 'شخص يرفع أثقال: بشرة بلون فاتح ومعتدل',
    '🏋🏽' => 'شخص يرفع أثقال: بشرة بلون معتدل',
    '🏋🏾' => 'شخص يرفع أثقال: بشرة بلون معتدل مائل للغامق',
    '🏋🏿' => 'شخص يرفع أثقال: بشرة بلون غامق',
    '🚴🏻' => 'شخص يركب دراجة: بشرة بلون فاتح',
    '🚴🏼' => 'شخص يركب دراجة: بشرة بلون فاتح ومعتدل',
    '🚴🏽' => 'شخص يركب دراجة: بشرة بلون معتدل',
    '🚴🏾' => 'شخص يركب دراجة: بشرة بلون معتدل مائل للغامق',
    '🚴🏿' => 'شخص يركب دراجة: بشرة بلون غامق',
    '🚵🏻' => 'شخص يركب دراجة في الجبال: بشرة بلون فاتح',
    '🚵🏼' => 'شخص يركب دراجة في الجبال: بشرة بلون فاتح ومعتدل',
    '🚵🏽' => 'شخص يركب دراجة في الجبال: بشرة بلون معتدل',
    '🚵🏾' => 'شخص يركب دراجة في الجبال: بشرة بلون معتدل مائل للغامق',
    '🚵🏿' => 'شخص يركب دراجة في الجبال: بشرة بلون غامق',
    '🤸🏻' => 'شخص يؤدي حركة العجلة: بشرة بلون فاتح',
    '🤸🏼' => 'شخص يؤدي حركة العجلة: بشرة بلون فاتح ومعتدل',
    '🤸🏽' => 'شخص يؤدي حركة العجلة: بشرة بلون معتدل',
    '🤸🏾' => 'شخص يؤدي حركة العجلة: بشرة بلون معتدل مائل للغامق',
    '🤸🏿' => 'شخص يؤدي حركة العجلة: بشرة بلون غامق',
    '🤼🏻' => 'مصارعون: بشرة بلون فاتح',
    '🤼🏼' => 'مصارعون: بشرة بلون فاتح ومعتدل',
    '🤼🏽' => 'مصارعون: بشرة بلون معتدل',
    '🤼🏾' => 'مصارعون: بشرة بلون معتدل مائل للغامق',
    '🤼🏿' => 'مصارعون: بشرة بلون غامق',
    '🤽🏻' => 'شخص يلعب كرة ماء: بشرة بلون فاتح',
    '🤽🏼' => 'شخص يلعب كرة ماء: بشرة بلون فاتح ومعتدل',
    '🤽🏽' => 'شخص يلعب كرة ماء: بشرة بلون معتدل',
    '🤽🏾' => 'شخص يلعب كرة ماء: بشرة بلون معتدل مائل للغامق',
    '🤽🏿' => 'شخص يلعب كرة ماء: بشرة بلون غامق',
    '🤾🏻' => 'شخص يلعب كرة يد: بشرة بلون فاتح',
    '🤾🏼' => 'شخص يلعب كرة يد: بشرة بلون فاتح ومعتدل',
    '🤾🏽' => 'شخص يلعب كرة يد: بشرة بلون معتدل',
    '🤾🏾' => 'شخص يلعب كرة يد: بشرة بلون معتدل مائل للغامق',
    '🤾🏿' => 'شخص يلعب كرة يد: بشرة بلون غامق',
    '🤹🏻' => 'شخص يؤدي ألعابًا بهلوانية: بشرة بلون فاتح',
    '🤹🏼' => 'شخص يؤدي ألعابًا بهلوانية: بشرة بلون فاتح ومعتدل',
    '🤹🏽' => 'شخص يؤدي ألعابًا بهلوانية: بشرة بلون معتدل',
    '🤹🏾' => 'شخص يؤدي ألعابًا بهلوانية: بشرة بلون معتدل مائل للغامق',
    '🤹🏿' => 'شخص يؤدي ألعابًا بهلوانية: بشرة بلون غامق',
    '🧘🏻' => 'شخص متربّع: بشرة بلون فاتح',
    '🧘🏼' => 'شخص متربّع: بشرة بلون فاتح ومعتدل',
    '🧘🏽' => 'شخص متربّع: بشرة بلون معتدل',
    '🧘🏾' => 'شخص متربّع: بشرة بلون معتدل مائل للغامق',
    '🧘🏿' => 'شخص متربّع: بشرة بلون غامق',
    '🛀🏻' => 'شخص يستحم: بشرة بلون فاتح',
    '🛀🏼' => 'شخص يستحم: بشرة بلون فاتح ومعتدل',
    '🛀🏽' => 'شخص يستحم: بشرة بلون معتدل',
    '🛀🏾' => 'شخص يستحم: بشرة بلون معتدل مائل للغامق',
    '🛀🏿' => 'شخص يستحم: بشرة بلون غامق',
    '🛌🏻' => 'شخص على سرير: بشرة بلون فاتح',
    '🛌🏼' => 'شخص على سرير: بشرة بلون فاتح ومعتدل',
    '🛌🏽' => 'شخص على سرير: بشرة بلون معتدل',
    '🛌🏾' => 'شخص على سرير: بشرة بلون معتدل مائل للغامق',
    '🛌🏿' => 'شخص على سرير: بشرة بلون غامق',
    '👭🏻' => 'امرأتان تمسكان بيد بعضهما: بشرة بلون فاتح',
    '👭🏼' => 'امرأتان تمسكان بيد بعضهما: بشرة بلون فاتح ومعتدل',
    '👭🏽' => 'امرأتان تمسكان بيد بعضهما: بشرة بلون معتدل',
    '👭🏾' => 'امرأتان تمسكان بيد بعضهما: بشرة بلون معتدل مائل للغامق',
    '👭🏿' => 'امرأتان تمسكان بيد بعضهما: بشرة بلون غامق',
    '👫🏻' => 'رجل وامرأة يمسكان بيد بعضهما: بشرة بلون فاتح',
    '👫🏼' => 'رجل وامرأة يمسكان بيد بعضهما: بشرة بلون فاتح ومعتدل',
    '👫🏽' => 'رجل وامرأة يمسكان بيد بعضهما: بشرة بلون معتدل',
    '👫🏾' => 'رجل وامرأة يمسكان بيد بعضهما: بشرة بلون معتدل مائل للغامق',
    '👫🏿' => 'رجل وامرأة يمسكان بيد بعضهما: بشرة بلون غامق',
    '👬🏻' => 'رجلان يمسكان بيد بعضهما: بشرة بلون فاتح',
    '👬🏼' => 'رجلان يمسكان بيد بعضهما: بشرة بلون فاتح ومعتدل',
    '👬🏽' => 'رجلان يمسكان بيد بعضهما: بشرة بلون معتدل',
    '👬🏾' => 'رجلان يمسكان بيد بعضهما: بشرة بلون معتدل مائل للغامق',
    '👬🏿' => 'رجلان يمسكان بيد بعضهما: بشرة بلون غامق',
    '💏🏻' => 'قبلة: بشرة بلون فاتح',
    '💏🏼' => 'قبلة: بشرة بلون فاتح ومعتدل',
    '💏🏽' => 'قبلة: بشرة بلون معتدل',
    '💏🏾' => 'قبلة: بشرة بلون معتدل مائل للغامق',
    '💏🏿' => 'قبلة: بشرة بلون غامق',
    '💑🏻' => 'زوج وقلب: بشرة بلون فاتح',
    '💑🏼' => 'زوج وقلب: بشرة بلون فاتح ومعتدل',
    '💑🏽' => 'زوج وقلب: بشرة بلون معتدل',
    '💑🏾' => 'زوج وقلب: بشرة بلون معتدل مائل للغامق',
    '💑🏿' => 'زوج وقلب: بشرة بلون غامق',
    '🇦🇨' => 'علم: جزيرة أسينشين',
    '🇦🇩' => 'علم: أندورا',
    '🇦🇪' => 'علم: الإمارات العربية المتحدة',
    '🇦🇫' => 'علم: أفغانستان',
    '🇦🇬' => 'علم: أنتيغوا وبربودا',
    '🇦🇮' => 'علم: أنغويلا',
    '🇦🇱' => 'علم: ألبانيا',
    '🇦🇲' => 'علم: أرمينيا',
    '🇦🇴' => 'علم: أنغولا',
    '🇦🇶' => 'علم: أنتاركتيكا',
    '🇦🇷' => 'علم: الأرجنتين',
    '🇦🇸' => 'علم: ساموا الأمريكية',
    '🇦🇹' => 'علم: النمسا',
    '🇦🇺' => 'علم: أستراليا',
    '🇦🇼' => 'علم: أروبا',
    '🇦🇽' => 'علم: جزر آلاند',
    '🇦🇿' => 'علم: أذربيجان',
    '🇧🇦' => 'علم: البوسنة والهرسك',
    '🇧🇧' => 'علم: بربادوس',
    '🇧🇩' => 'علم: بنغلاديش',
    '🇧🇪' => 'علم: بلجيكا',
    '🇧🇫' => 'علم: بوركينا فاسو',
    '🇧🇬' => 'علم: بلغاريا',
    '🇧🇭' => 'علم: البحرين',
    '🇧🇮' => 'علم: بوروندي',
    '🇧🇯' => 'علم: بنين',
    '🇧🇱' => 'علم: سان بارتليمي',
    '🇧🇲' => 'علم: برمودا',
    '🇧🇳' => 'علم: بروناي',
    '🇧🇴' => 'علم: بوليفيا',
    '🇧🇶' => 'علم: هولندا الكاريبية',
    '🇧🇷' => 'علم: البرازيل',
    '🇧🇸' => 'علم: جزر البهاما',
    '🇧🇹' => 'علم: بوتان',
    '🇧🇻' => 'علم: جزيرة بوفيه',
    '🇧🇼' => 'علم: بوتسوانا',
    '🇧🇾' => 'علم: بيلاروس',
    '🇧🇿' => 'علم: بليز',
    '🇨🇦' => 'علم: كندا',
    '🇨🇨' => 'علم: جزر كوكوس (كيلينغ)',
    '🇨🇩' => 'علم: الكونغو - كينشاسا',
    '🇨🇫' => 'علم: جمهورية أفريقيا الوسطى',
    '🇨🇬' => 'علم: الكونغو - برازافيل',
    '🇨🇭' => 'علم: سويسرا',
    '🇨🇮' => 'علم: ساحل العاج',
    '🇨🇰' => 'علم: جزر كوك',
    '🇨🇱' => 'علم: تشيلي',
    '🇨🇲' => 'علم: الكاميرون',
    '🇨🇳' => 'علم: الصين',
    '🇨🇴' => 'علم: كولومبيا',
    '🇨🇵' => 'علم: جزيرة كليبيرتون',
    '🇨🇶' => 'علم: سارك',
    '🇨🇷' => 'علم: كوستاريكا',
    '🇨🇺' => 'علم: كوبا',
    '🇨🇻' => 'علم: الرأس الأخضر',
    '🇨🇼' => 'علم: كوراساو',
    '🇨🇽' => 'علم: جزيرة كريسماس',
    '🇨🇾' => 'علم: قبرص',
    '🇨🇿' => 'علم: التشيك',
    '🇩🇪' => 'علم: ألمانيا',
    '🇩🇬' => 'علم: دييغو غارسيا',
    '🇩🇯' => 'علم: جيبوتي',
    '🇩🇰' => 'علم: الدانمرك',
    '🇩🇲' => 'علم: دومينيكا',
    '🇩🇴' => 'علم: جمهورية الدومينيكان',
    '🇩🇿' => 'علم: الجزائر',
    '🇪🇦' => 'علم: سبتة ومليلية',
    '🇪🇨' => 'علم: الإكوادور',
    '🇪🇪' => 'علم: إستونيا',
    '🇪🇬' => 'علم: مصر',
    '🇪🇭' => 'علم: الصحراء الغربية',
    '🇪🇷' => 'علم: إريتريا',
    '🇪🇸' => 'علم: إسبانيا',
    '🇪🇹' => 'علم: إثيوبيا',
    '🇪🇺' => 'علم: الاتحاد الأوروبي',
    '🇫🇮' => 'علم: فنلندا',
    '🇫🇯' => 'علم: فيجي',
    '🇫🇰' => 'علم: جزر فوكلاند',
    '🇫🇲' => 'علم: ميكرونيزيا',
    '🇫🇴' => 'علم: جزر فارو',
    '🇫🇷' => 'علم: فرنسا',
    '🇬🇦' => 'علم: الغابون',
    '🇬🇧' => 'علم: المملكة المتحدة',
    '🇬🇩' => 'علم: غرينادا',
    '🇬🇪' => 'علم: جورجيا',
    '🇬🇫' => 'علم: غويانا الفرنسية',
    '🇬🇬' => 'علم: غيرنزي',
    '🇬🇭' => 'علم: غانا',
    '🇬🇮' => 'علم: جبل طارق',
    '🇬🇱' => 'علم: غرينلاند',
    '🇬🇲' => 'علم: غامبيا',
    '🇬🇳' => 'علم: غينيا',
    '🇬🇵' => 'علم: غوادلوب',
    '🇬🇶' => 'علم: غينيا الاستوائية',
    '🇬🇷' => 'علم: اليونان',
    '🇬🇸' => 'علم: جورجيا الجنوبية وجزر ساندويتش الجنوبية',
    '🇬🇹' => 'علم: غواتيمالا',
    '🇬🇺' => 'علم: غوام',
    '🇬🇼' => 'علم: غينيا بيساو',
    '🇬🇾' => 'علم: غيانا',
    '🇭🇰' => 'علم: هونغ كونغ الصينية (منطقة إدارية خاصة)',
    '🇭🇲' => 'علم: جزيرة هيرد وجزر ماكدونالد',
    '🇭🇳' => 'علم: هندوراس',
    '🇭🇷' => 'علم: كرواتيا',
    '🇭🇹' => 'علم: هايتي',
    '🇭🇺' => 'علم: هنغاريا',
    '🇮🇨' => 'علم: جزر الكناري',
    '🇮🇩' => 'علم: إندونيسيا',
    '🇮🇪' => 'علم: أيرلندا',
    '🇮🇱' => 'علم: إسرائيل',
    '🇮🇲' => 'علم: جزيرة مان',
    '🇮🇳' => 'علم: الهند',
    '🇮🇴' => 'علم: الإقليم البريطاني في المحيط الهندي',
    '🇮🇶' => 'علم: العراق',
    '🇮🇷' => 'علم: إيران',
    '🇮🇸' => 'علم: آيسلندا',
    '🇮🇹' => 'علم: إيطاليا',
    '🇯🇪' => 'علم: جيرسي',
    '🇯🇲' => 'علم: جامايكا',
    '🇯🇴' => 'علم: الأردن',
    '🇯🇵' => 'علم: اليابان',
    '🇰🇪' => 'علم: كينيا',
    '🇰🇬' => 'علم: قيرغيزستان',
    '🇰🇭' => 'علم: كمبوديا',
    '🇰🇮' => 'علم: كيريباتي',
    '🇰🇲' => 'علم: جزر القمر',
    '🇰🇳' => 'علم: سانت كيتس ونيفيس',
    '🇰🇵' => 'علم: كوريا الشمالية',
    '🇰🇷' => 'علم: كوريا الجنوبية',
    '🇰🇼' => 'علم: الكويت',
    '🇰🇾' => 'علم: جزر كايمان',
    '🇰🇿' => 'علم: كازاخستان',
    '🇱🇦' => 'علم: لاوس',
    '🇱🇧' => 'علم: لبنان',
    '🇱🇨' => 'علم: سانت لوسيا',
    '🇱🇮' => 'علم: ليختنشتاين',
    '🇱🇰' => 'علم: سريلانكا',
    '🇱🇷' => 'علم: ليبيريا',
    '🇱🇸' => 'علم: ليسوتو',
    '🇱🇹' => 'علم: ليتوانيا',
    '🇱🇺' => 'علم: لوكسمبورغ',
    '🇱🇻' => 'علم: لاتفيا',
    '🇱🇾' => 'علم: ليبيا',
    '🇲🇦' => 'علم: المغرب',
    '🇲🇨' => 'علم: موناكو',
    '🇲🇩' => 'علم: مولدوفا',
    '🇲🇪' => 'علم: الجبل الأسود',
    '🇲🇫' => 'علم: سان مارتن',
    '🇲🇬' => 'علم: مدغشقر',
    '🇲🇭' => 'علم: جزر مارشال',
    '🇲🇰' => 'علم: مقدونيا الشمالية',
    '🇲🇱' => 'علم: مالي',
    '🇲🇲' => 'علم: ميانمار (بورما)',
    '🇲🇳' => 'علم: منغوليا',
    '🇲🇴' => 'علم: ماكاو الصينية (منطقة إدارية خاصة)',
    '🇲🇵' => 'علم: جزر ماريانا الشمالية',
    '🇲🇶' => 'علم: جزر المارتينيك',
    '🇲🇷' => 'علم: موريتانيا',
    '🇲🇸' => 'علم: مونتيسيرات',
    '🇲🇹' => 'علم: مالطا',
    '🇲🇺' => 'علم: موريشيوس',
    '🇲🇻' => 'علم: جزر المالديف',
    '🇲🇼' => 'علم: ملاوي',
    '🇲🇽' => 'علم: المكسيك',
    '🇲🇾' => 'علم: ماليزيا',
    '🇲🇿' => 'علم: موزمبيق',
    '🇳🇦' => 'علم: ناميبيا',
    '🇳🇨' => 'علم: كاليدونيا الجديدة',
    '🇳🇪' => 'علم: النيجر',
    '🇳🇫' => 'علم: جزيرة نورفولك',
    '🇳🇬' => 'علم: نيجيريا',
    '🇳🇮' => 'علم: نيكاراغوا',
    '🇳🇱' => 'علم: هولندا',
    '🇳🇴' => 'علم: النرويج',
    '🇳🇵' => 'علم: نيبال',
    '🇳🇷' => 'علم: ناورو',
    '🇳🇺' => 'علم: نيوي',
    '🇳🇿' => 'علم: نيوزيلندا',
    '🇴🇲' => 'علم: عُمان',
    '🇵🇦' => 'علم: بنما',
    '🇵🇪' => 'علم: بيرو',
    '🇵🇫' => 'علم: بولينيزيا الفرنسية',
    '🇵🇬' => 'علم: بابوا غينيا الجديدة',
    '🇵🇭' => 'علم: الفلبين',
    '🇵🇰' => 'علم: باكستان',
    '🇵🇱' => 'علم: بولندا',
    '🇵🇲' => 'علم: سان بيير ومكويلون',
    '🇵🇳' => 'علم: جزر بيتكيرن',
    '🇵🇷' => 'علم: بورتوريكو',
    '🇵🇸' => 'علم: الأراضي الفلسطينية',
    '🇵🇹' => 'علم: البرتغال',
    '🇵🇼' => 'علم: بالاو',
    '🇵🇾' => 'علم: باراغواي',
    '🇶🇦' => 'علم: قطر',
    '🇷🇪' => 'علم: روينيون',
    '🇷🇴' => 'علم: رومانيا',
    '🇷🇸' => 'علم: صربيا',
    '🇷🇺' => 'علم: روسيا',
    '🇷🇼' => 'علم: رواندا',
    '🇸🇦' => 'علم: المملكة العربية السعودية',
    '🇸🇧' => 'علم: جزر سليمان',
    '🇸🇨' => 'علم: سيشل',
    '🇸🇩' => 'علم: السودان',
    '🇸🇪' => 'علم: السويد',
    '🇸🇬' => 'علم: سنغافورة',
    '🇸🇭' => 'علم: سانت هيلينا',
    '🇸🇮' => 'علم: سلوفينيا',
    '🇸🇯' => 'علم: سفالبارد وجان ماين',
    '🇸🇰' => 'علم: سلوفاكيا',
    '🇸🇱' => 'علم: سيراليون',
    '🇸🇲' => 'علم: سان مارينو',
    '🇸🇳' => 'علم: السنغال',
    '🇸🇴' => 'علم: الصومال',
    '🇸🇷' => 'علم: سورينام',
    '🇸🇸' => 'علم: جنوب السودان',
    '🇸🇹' => 'علم: ساو تومي وبرينسيبي',
    '🇸🇻' => 'علم: السلفادور',
    '🇸🇽' => 'علم: سانت مارتن',
    '🇸🇾' => 'علم: سوريا',
    '🇸🇿' => 'علم: إسواتيني',
    '🇹🇦' => 'علم: تريستان دا كونا',
    '🇹🇨' => 'علم: جزر توركس وكايكوس',
    '🇹🇩' => 'علم: تشاد',
    '🇹🇫' => 'علم: الأقاليم الجنوبية الفرنسية',
    '🇹🇬' => 'علم: توغو',
    '🇹🇭' => 'علم: تايلاند',
    '🇹🇯' => 'علم: طاجيكستان',
    '🇹🇰' => 'علم: توكيلاو',
    '🇹🇱' => 'علم: تيمور - ليشتي',
    '🇹🇲' => 'علم: تركمانستان',
    '🇹🇳' => 'علم: تونس',
    '🇹🇴' => 'علم: تونغا',
    '🇹🇷' => 'علم: تركيا',
    '🇹🇹' => 'علم: ترينيداد وتوباغو',
    '🇹🇻' => 'علم: توفالو',
    '🇹🇼' => 'علم: تايوان',
    '🇹🇿' => 'علم: تنزانيا',
    '🇺🇦' => 'علم: أوكرانيا',
    '🇺🇬' => 'علم: أوغندا',
    '🇺🇲' => 'علم: جزر الولايات المتحدة النائية',
    '🇺🇳' => 'علم: الأمم المتحدة',
    '🇺🇸' => 'علم: الولايات المتحدة',
    '🇺🇾' => 'علم: أوروغواي',
    '🇺🇿' => 'علم: أوزبكستان',
    '🇻🇦' => 'علم: الفاتيكان',
    '🇻🇨' => 'علم: سانت فنسنت وجزر غرينادين',
    '🇻🇪' => 'علم: فنزويلا',
    '🇻🇬' => 'علم: جزر فيرجن البريطانية',
    '🇻🇮' => 'علم: جزر فيرجن الأمريكية',
    '🇻🇳' => 'علم: فيتنام',
    '🇻🇺' => 'علم: فانواتو',
    '🇼🇫' => 'علم: جزر والس وفوتونا',
    '🇼🇸' => 'علم: ساموا',
    '🇽🇰' => 'علم: كوسوفو',
    '🇾🇪' => 'علم: اليمن',
    '🇾🇹' => 'علم: مايوت',
    '🇿🇦' => 'علم: جنوب أفريقيا',
    '🇿🇲' => 'علم: زامبيا',
    '🇿🇼' => 'علم: زيمبابوي',
    '🔟' => 'مفتاح: 10',
    '🏻' => 'بشرة بلون فاتح',
    '🏼' => 'بشرة بلون فاتح ومعتدل',
    '🏽' => 'بشرة بلون معتدل',
    '🏾' => 'بشرة بلون معتدل مائل للغامق',
    '🏿' => 'بشرة بلون غامق',
    '😀' => 'وجه بابتسامة عريضة',
    '😃' => 'وجه مبتسم بعينين كبيرتين',
    '😄' => 'وجه مبتسم بعينين باسمتين',
    '😁' => 'وجه مشرق بعينين باسمتين',
    '😆' => 'وجه مبتسم بعينين مغلقتين',
    '😅' => 'وجه مبتسم بفم مفتوح وعرق بارد',
    '🤣' => 'وجه ضاحك يتدحرج على الأرض',
    '😂' => 'وجه بدموع فرح',
    '🙂' => 'وجه بابتسامة بسيطة',
    '🙃' => 'وجه مقلوب',
    '🫠' => 'وجه يذوب',
    '😉' => 'وجه يغمز',
    '😊' => 'وجه باسم بعينين باسمتين',
    '😇' => 'وجه مبتسم بهالة',
    '🥰' => 'وجه مبتسم مع ثلاثة قلوب',
    '😍' => 'وجه مبتسم مع عينين على شكل قلب',
    '🤩' => 'وجه بعينين على شكل نجمة',
    '😘' => 'وجه يرسل قبلة',
    '😗' => 'وجه يقبّل',
    '☺' => 'وجه مبتسم',
    '😚' => 'وجه يقبّل بعينين مغلقتين',
    '😙' => 'وجه يقبّل بعينين باسمتين',
    '🥲' => 'وجه مبتسم مع دمعة',
    '😋' => 'وجه يتلذذ بالطعام',
    '😛' => 'وجه بلسان متدلٍ',
    '😜' => 'وجه بلسان متدلٍ وعين غامزة',
    '🤪' => 'وجه غريب الشكل',
    '😝' => 'وجه بعينين مغلقتين ولسان متدلٍ',
    '🤑' => 'وجه بلسان من مال',
    '🤗' => 'وجه يعانق بابتسامة',
    '🤭' => 'وجه ضاحك مع يد تغطّي الفم',
    '🫢' => 'وجه بعينين مفتوحتين ويد تغطّي الفم',
    '🫣' => 'وجه يختلس النظر',
    '🤫' => 'وجه يطلب الصمت',
    '🤔' => 'وجه يفكر',
    '🫡' => 'وجه يلقي التحيّة',
    '🤐' => 'وجه بفم مقفل',
    '🤨' => 'وجه بحاجب مرفوع',
    '😐' => 'وجه محايد',
    '😑' => 'وجه بدون تعبير',
    '😶' => 'وجه بدون فم',
    '🫥' => 'وجه محدّد بنقاط',
    '😏' => 'وجه بابتسامة متكلفة',
    '😒' => 'وجه غير مستمتع',
    '🙄' => 'وجه بعينين تدوران',
    '😬' => 'وجه متجهم',
    '🤥' => 'وجه كاذب',
    '🫨' => 'وجه يهتز',
    '😌' => 'وجه مرتاح',
    '😔' => 'وجه متأمل',
    '😪' => 'وجه ناعس',
    '🤤' => 'وجه بلعاب سائل',
    '😴' => 'وجه نائم',
    '🫩' => 'وجه بانتفاخ تحت العين',
    '😷' => 'وجه بكمامة',
    '🤒' => 'وجه مع ميزان للحرارة',
    '🤕' => 'وجه بعصابة رأس',
    '🤢' => 'وجه مشمئز',
    '🤮' => 'وجه يتقيّأ',
    '🤧' => 'وجه يعطس',
    '🥵' => 'وجه حار',
    '🥶' => 'وجه بارد',
    '🥴' => 'وجه مصاب بدوار',
    '😵' => 'وجه دائخ',
    '🤯' => 'وجه برأس منفجر',
    '🤠' => 'وجه بقبعة راعي بقر',
    '🥳' => 'وجه محتفل',
    '🥸' => 'وجع مقنّع',
    '😎' => 'وجه مبتسم بنظارة شمس',
    '🤓' => 'وجه عبقري',
    '🧐' => 'وجه مع نظارة لعين واحدة',
    '😕' => 'وجه حائر',
    '🫤' => 'وجه بفم مائل',
    '😟' => 'وجه قلق',
    '🙁' => 'وجه عابس قليلاً',
    '☹' => 'وجه عابس',
    '😮' => 'وجه بفم مفتوح',
    '😯' => 'وجه مخفوت الصوت',
    '😲' => 'وجه مندهش',
    '😳' => 'وجه متورد',
    '🫪' => 'وجه بأعين زائعة',
    '🥺' => 'وجه ملتمس',
    '🥹' => 'وجه يحبس دموعه',
    '😦' => 'وجه عابس بفم مفتوح',
    '😧' => 'وجه مكروب',
    '😨' => 'وجه خائف',
    '😰' => 'وجه بفم مفتوح وعرق بارد',
    '😥' => 'وجه خيبة أمل',
    '😢' => 'وجه يبكي',
    '😭' => 'وجه يبكي بكاءً مرتفعًا',
    '😱' => 'وجه خائف يصرخ',
    '😖' => 'وجه مرتبك',
    '😣' => 'وجه جاد',
    '😞' => 'وجه محبط',
    '😓' => 'وجه بعرق بارد',
    '😩' => 'وجه مجهد',
    '😫' => 'وجه متعب',
    '🥱' => 'وجه متثائب',
    '😤' => 'وجه بأنف يصدر بخارًا',
    '😡' => 'وجه مشتاط غضبًا',
    '😠' => 'وجه غاضب',
    '🤬' => 'وجه مع رموز على الفم',
    '😈' => 'وجه مبتسم بقرنين',
    '👿' => 'وجه غاضب بقرنين',
    '💀' => 'جمجمة',
    '☠' => 'جمجمة بعظمتين متصالبتين',
    '💩' => 'فضلات',
    '🤡' => 'وجه مهرج',
    '👹' => 'غول',
    '👺' => 'عفريت',
    '👻' => 'شبح',
    '👽' => 'كائن فضائي',
    '👾' => 'وحش غريب',
    '🤖' => 'وجه روبوت',
    '😺' => 'وجه قطة مبتسم بفم مفتوح',
    '😸' => 'وجه قطة مبتسم بعينين باسمتين',
    '😹' => 'وجه قطة بدموع فرح',
    '😻' => 'وجه قطة مبتسم بعينين على شكل قلب',
    '😼' => 'وجه قطة بابتسامة ممتعضة',
    '😽' => 'وجه قطة تقبّل',
    '🙀' => 'وجه قطة مجهد',
    '😿' => 'وجه قطة يبكي',
    '😾' => 'وجه قطة عابس',
    '🙈' => 'قرد يحجب عينيه',
    '🙉' => 'قرد يحجب أذنيه',
    '🙊' => 'قرد يحجب الكلام',
    '💌' => 'خطاب حب',
    '💘' => 'قلب وسهم',
    '💝' => 'قلب عليه شريط',
    '💖' => 'قلب لامع',
    '💗' => 'قلب ينمو',
    '💓' => 'قلب يخفق',
    '💞' => 'قلوب تدور حول بعضها',
    '💕' => 'قلبان',
    '💟' => 'زخرفة قلب',
    '❣' => 'قلب على شكل علامة تعجب',
    '💔' => 'قلب مكسور',
    '❤' => 'قلب أحمر',
    '🩷' => 'قلب وردي',
    '🧡' => 'قلب برتقالي',
    '💛' => 'قلب أصفر',
    '💚' => 'قلب أخضر',
    '💙' => 'قلب أزرق',
    '🩵' => 'قلب أزرق فاتح',
    '💜' => 'قلب أرجواني',
    '🤎' => 'قلب بني',
    '🖤' => 'قلب أسود',
    '🩶' => 'قلب رمادي',
    '🤍' => 'قلب أبيض',
    '💋' => 'علامة قبلة',
    '💯' => '100 درجة',
    '💢' => 'رمز الغضب',
    '🫯' => 'سحابة اقتتال',
    '💥' => 'تصادم',
    '💫' => 'دوار',
    '💦' => 'عرق يتصبب',
    '💨' => 'انطلاقة جري',
    '🕳' => 'ثقب',
    '💬' => 'فقاعة كلام',
    '🗨' => 'فقاعة كلام يسرى',
    '🗯' => 'فقاعة غضب يمنى',
    '💭' => 'فقاعة أفكار',
    '💤' => 'نعسان',
    '👋' => 'تلويح باليد',
    '🤚' => 'ظهر يد مرفوعة',
    '🖐' => 'يد مرفوعة بأصابع متفرقة',
    '✋' => 'يد مرفوعة',
    '🖖' => 'تحية فولكان',
    '🫱' => 'يد باتجاه اليمين',
    '🫲' => 'يد باتجاه اليسار',
    '🫳' => 'راحة يد للأسفل',
    '🫴' => 'راحة يد للأعلى',
    '🫷' => 'يد تدفع يسارًا',
    '🫸' => 'يد تدفع يمينًا',
    '👌' => 'يد تشير للموافقة',
    '🤌' => 'أصابع مضمومة',
    '🤏' => 'يد تشير بمقدار ضئيل',
    '✌' => 'علامة النصر',
    '🤞' => 'أصابع مشبكة',
    '🫰' => 'يد مع تقاطع السبابة والإبهام',
    '🤟' => 'إشارة أحبك',
    '🤘' => 'إشارة قرون',
    '🤙' => 'إشارة للاتصال',
    '👈' => 'إصبع لليسار',
    '👉' => 'إصبع لليمين',
    '👆' => 'إصبع لأعلى',
    '🖕' => 'إصبع الوسطى',
    '👇' => 'إصبع لأسفل',
    '☝' => 'سبابة يشير لأعلى',
    '🫵' => 'إصبع السبابة يشير إلى الناظر',
    '👍' => 'قبول',
    '👎' => 'رفض',
    '✊' => 'قبضة يد مرفوعة',
    '👊' => 'قبضة يد',
    '🤛' => 'قبضة لليسار',
    '🤜' => 'قبضة لليمين',
    '👏' => 'يدان تصفقان',
    '🙌' => 'تشجيع',
    '🫶' => 'أيدي متشابكة على شكل قلب',
    '👐' => 'يدان مفتوحتان',
    '🤲' => 'راحتان مفتوحتان',
    '🤝' => 'مصافحة',
    '🙏' => 'يدان مضمومتان',
    '✍' => 'يد تكتب',
    '💅' => 'طلاء أظافر',
    '🤳' => 'صورة سيلفي',
    '💪' => 'عضلة الذراع',
    '🦾' => 'ذراع اصطناعية',
    '🦿' => 'ساق اصطناعية',
    '🦵' => 'ساق',
    '🦶' => 'قدم',
    '👂' => 'أذن',
    '🦻' => 'أذن مع جهاز سمعي',
    '👃' => 'أنف',
    '🧠' => 'دماغ',
    '🫀' => 'عضو القلب',
    '🫁' => 'رئتان',
    '🦷' => 'سن',
    '🦴' => 'عظمة',
    '👀' => 'عينان',
    '👁' => 'عين',
    '👅' => 'لسان',
    '👄' => 'فم',
    '🫦' => 'عض الشفاه',
    '👶' => 'رضيع',
    '🧒' => 'طفل',
    '👦' => 'صبي',
    '👧' => 'فتاة',
    '🧑' => 'بالغ',
    '👱' => 'شخص أشقر',
    '👨' => 'رجل',
    '🧔' => 'شخص بلحية',
    '👩' => 'سيدة',
    '🧓' => 'بالغ أكبر في السن',
    '👴' => 'رجل عجوز',
    '👵' => 'سيدة عجوز',
    '🙍' => 'شخص عابس',
    '🙎' => 'شخص متجهم',
    '🙅' => 'إشارة رفض',
    '🙆' => 'إشارة موافقة',
    '💁' => 'شخص بيد مائلة',
    '🙋' => 'شخص يرفع يده',
    '🧏' => 'شخص أصم',
    '🙇' => 'شخص ينحني اعتذارًا',
    '🤦' => 'شخص محبط',
    '🤷' => 'لا مبالاة',
    '👮' => 'ضابط شرطة',
    '🕵' => 'شخص يحقّق',
    '💂' => 'حارس',
    '🥷' => 'نينجا',
    '👷' => 'شخص يعمل في البناء',
    '🫅' => 'شخص يرتدي تاجاً',
    '🤴' => 'أمير',
    '👸' => 'أميرة',
    '👳' => 'رجل بعمامة',
    '👲' => 'رجل بعمامة صينية',
    '🧕' => 'امرأة محجّبة',
    '🤵' => 'شخص ببدلة رسمية',
    '👰' => 'عروس بطرحة',
    '🤰' => 'امرأة حامل',
    '🫃' => 'رجل حامل',
    '🫄' => 'شخص حامل',
    '🤱' => 'رضاعة',
    '👼' => 'طفل ملاك',
    '🎅' => 'بابا نويل',
    '🤶' => 'سيدة سانتا كلوز',
    '🦸' => 'بطل خارق',
    '🦹' => 'شرير خارق',
    '🧙' => 'سحرة',
    '🧚' => 'جنيّة خيالية',
    '🧛' => 'مصّاص دماء',
    '🧜' => 'مخلوق بحري بجسد بشري وذيل سمكة',
    '🧝' => 'جنّي صغير',
    '🧞' => 'مارد سحري',
    '🧟' => 'زومبي',
    '🧌' => 'الترول',
    '🫈' => 'كائن مشعر',
    '💆' => 'شخص يحصل على مساج',
    '💇' => 'شخص يُقص شعره',
    '🚶' => 'شخص يسير',
    '🧍' => 'شخص واقف',
    '🧎' => 'شخص جالس على ركبتيه',
    '🏃' => 'شخص يجري',
    '💃' => 'راقصة',
    '🕺' => 'رجل يرقص',
    '🕴' => 'رجل أعمال يرتقي',
    '👯' => 'شخصان يرقصان',
    '🧖' => 'شخص في حمّام بخار',
    '🧗' => 'شخص يتسلّق',
    '🤺' => 'مبارز',
    '🏇' => 'سباق خيول',
    '⛷' => 'متزلّج على الثلج',
    '🏂' => 'متزلج',
    '🏌' => 'شخص يلعب غولف',
    '🏄' => 'شخص يركب الأمواج',
    '🚣' => 'شخص يجدف بزورق',
    '🏊' => 'شخص يسبح',
    '⛹' => 'شخص وكرة',
    '🏋' => 'شخص يرفع أثقال',
    '🚴' => 'شخص يركب دراجة',
    '🚵' => 'شخص يركب دراجة في الجبال',
    '🤸' => 'شخص يؤدي حركة العجلة',
    '🤼' => 'مصارعون',
    '🤽' => 'شخص يلعب كرة ماء',
    '🤾' => 'شخص يلعب كرة يد',
    '🤹' => 'شخص يؤدي ألعابًا بهلوانية',
    '🧘' => 'شخص متربّع',
    '🛀' => 'شخص يستحم',
    '🛌' => 'شخص على سرير',
    '👭' => 'امرأتان تمسكان بيد بعضهما',
    '👫' => 'رجل وامرأة يمسكان بيد بعضهما',
    '👬' => 'رجلان يمسكان بيد بعضهما',
    '💏' => 'قبلة',
    '💑' => 'زوج وقلب',
    '🗣' => 'رأس تتحدث',
    '👤' => 'صورة ظلية',
    '👥' => 'صورتان ظليتان',
    '🫂' => 'شخصان يتعانقان',
    '👪' => 'أسرة',
    '👣' => 'أثر قدمين',
    '🫆' => 'بصمة',
    '🦰' => 'شعر أحمر',
    '🦱' => 'شعر مجعد',
    '🦳' => 'شعر أبيض',
    '🦲' => 'أصلع',
    '🐵' => 'وجه قرد',
    '🐒' => 'قرد',
    '🦍' => 'غوريلا',
    '🦧' => 'إنسان الغاب',
    '🐶' => 'وجه كلب',
    '🐕' => 'كلب',
    '🦮' => 'كلب دليل',
    '🐩' => 'بودل',
    '🐺' => 'وجه ذئب',
    '🦊' => 'وجه ثعلب',
    '🦝' => 'راكون',
    '🐱' => 'وجه قطة',
    '🐈' => 'قطة',
    '🦁' => 'وجه أسد',
    '🐯' => 'وجه نمر',
    '🐅' => 'نمر',
    '🐆' => 'فهد',
    '🐴' => 'وجه حصان',
    '🫎' => 'أيّل',
    '🫏' => 'حمار',
    '🐎' => 'حصان',
    '🦄' => 'وجه أحادي قرن',
    '🦓' => 'حمار وحشي',
    '🦌' => 'غزال',
    '🦬' => 'ثور أمريكي',
    '🐮' => 'وجه بقرة',
    '🐂' => 'ثور',
    '🐃' => 'جاموس مائي',
    '🐄' => 'بقرة',
    '🐷' => 'وجه خنزير',
    '🐖' => 'خنزير',
    '🐗' => 'خنزير بري',
    '🐽' => 'أنف خنزير',
    '🐏' => 'كبش',
    '🐑' => 'خروف',
    '🐐' => 'معزة',
    '🐪' => 'جمل وحيد السنام',
    '🐫' => 'جمل ثنائي السنام',
    '🦙' => 'لاما',
    '🦒' => 'زرافة',
    '🐘' => 'فيل',
    '🦣' => 'ماموث',
    '🦏' => 'وحيد القرن',
    '🦛' => 'فرس النهر',
    '🐭' => 'وجه فأر',
    '🐁' => 'فأر',
    '🐀' => 'جرذ',
    '🐹' => 'وجه حيوان الهمستر',
    '🐰' => 'وجه أرنب',
    '🐇' => 'أرنب',
    '🐿' => 'سنجاب',
    '🦫' => 'سمّور',
    '🦔' => 'قنفد',
    '🦇' => 'خفاش',
    '🐻' => 'وجه دب',
    '🐨' => 'دب كوالا',
    '🐼' => 'وجه باندا',
    '🦥' => 'كسلان',
    '🦦' => 'قندس',
    '🦨' => 'ظربان',
    '🦘' => 'كنغر',
    '🦡' => 'غرير',
    '🐾' => 'آثار حوافر',
    '🦃' => 'ديك رومي',
    '🐔' => 'دجاجة',
    '🐓' => 'ديك',
    '🐣' => 'كتكوت خارج البيضة',
    '🐤' => 'كتكوت صغير',
    '🐥' => 'كتكوت صغير بوجه للأمام',
    '🐦' => 'طائر',
    '🐧' => 'بطريق',
    '🕊' => 'حمامة',
    '🦅' => 'نسر',
    '🦆' => 'بطة',
    '🦢' => 'إوزة',
    '🦉' => 'بومة',
    '🦤' => 'طائر الدودو',
    '🪶' => 'ريشة',
    '🦩' => 'فلامينغو',
    '🦚' => 'طاووس',
    '🦜' => 'ببغاء',
    '🪽' => 'جناح',
    '🪿' => 'إوزّة',
    '🐸' => 'وجه ضفدع',
    '🐊' => 'تمساح',
    '🐢' => 'سلحفاة',
    '🦎' => 'سحلية',
    '🐍' => 'ثعبان',
    '🐲' => 'وجه تنين',
    '🐉' => 'تنين',
    '🦕' => 'ديناصور صوروبودا',
    '🦖' => 'التيرانوصور',
    '🐳' => 'حوت بنافورة',
    '🐋' => 'حوت',
    '🐬' => 'دولفين',
    '🫍' => 'الحوت القاتل',
    '🦭' => 'فقمة',
    '🐟' => 'سمكة',
    '🐠' => 'سمكة استوائية',
    '🐡' => 'سمكة منتفخة',
    '🦈' => 'سمكة قرش',
    '🐙' => 'أخطبوط',
    '🐚' => 'صدفة حلزونية',
    '🪸' => 'مرجان',
    '🪼' => 'قنديل بحر',
    '🦀' => 'سرطان',
    '🦞' => 'كركند',
    '🦐' => 'جمبري',
    '🦑' => 'حبار',
    '🦪' => 'محار',
    '🐌' => 'حلزون',
    '🦋' => 'فراشة',
    '🐛' => 'بق',
    '🐜' => 'نملة',
    '🐝' => 'نحلة',
    '🪲' => 'خنفساء',
    '🐞' => 'دعسوقة',
    '🦗' => 'جدجد',
    '🪳' => 'صرصور',
    '🕷' => 'عنكبوت',
    '🕸' => 'شبكة عنكبوت',
    '🦂' => 'عقرب',
    '🦟' => 'بعوضة',
    '🪰' => 'ذبابة',
    '🪱' => 'دودة',
    '🦠' => 'جرثومة',
    '💐' => 'باقة زهور',
    '🌸' => 'زهرة الكرز',
    '💮' => 'وردة بيضاء',
    '🪷' => 'لوتس',
    '🏵' => 'وردية',
    '🌹' => 'وردة',
    '🥀' => 'وردة ذابلة',
    '🌺' => 'كركديه',
    '🌻' => 'دوار الشمس',
    '🌼' => 'زهرة',
    '🌷' => 'زهرة التوليب',
    '🪻' => 'زهرة الياقوتية',
    '🌱' => 'شتلة',
    '🪴' => 'نبتة في وعاء',
    '🌲' => 'شجرة دائمة الخضرة',
    '🌳' => 'شجرة زائلة الخضرة',
    '🌴' => 'نخلة',
    '🌵' => 'صبار',
    '🌾' => 'حزمة من الأرز',
    '🌿' => 'عشب',
    '☘' => 'نبات النفل',
    '🍀' => 'ورقة برسيم رباعية',
    '🍁' => 'ورقة شجر القيقب',
    '🍂' => 'أوراق متساقطة',
    '🍃' => 'ورقة متطايرة',
    '🪹' => 'عش فارغ',
    '🪺' => 'عش به بيض',
    '🍄' => 'عيش الغراب',
    '🪾' => 'شجرة بلا أوراق',
    '🍇' => 'عنب',
    '🍈' => 'شمام',
    '🍉' => 'بطيخ',
    '🍊' => 'يوسفي',
    '🍋' => 'ليمون',
    '🍌' => 'موز',
    '🍍' => 'أناناس',
    '🥭' => 'مانجو',
    '🍎' => 'تفاح أحمر',
    '🍏' => 'تفاح أخضر',
    '🍐' => 'كمثرى',
    '🍑' => 'خوخ',
    '🍒' => 'كرز',
    '🍓' => 'فراولة',
    '🫐' => 'توت برّي',
    '🥝' => 'كيوي',
    '🍅' => 'طماطم',
    '🫒' => 'زيتون',
    '🥥' => 'جوز الهند',
    '🥑' => 'أفوكادو',
    '🍆' => 'باذنجان',
    '🥔' => 'بطاطس',
    '🥕' => 'جزر',
    '🌽' => 'ذرة',
    '🌶' => 'فلفل حار',
    '🫑' => 'فلفل حلو',
    '🥒' => 'خيار',
    '🥬' => 'خضار ورقي',
    '🥦' => 'بروكولي',
    '🧄' => 'ثوم',
    '🧅' => 'بصل',
    '🥜' => 'فول سوداني',
    '🫘' => 'بقول',
    '🌰' => 'كستناء',
    '🫚' => 'جذر الزنجبيل',
    '🫛' => 'قرن بازلاء',
    '🫜' => 'خضراوات جذرية',
    '🍞' => 'خبز',
    '🥐' => 'كرواسون',
    '🥖' => 'الخبز الفرنسي',
    '🫓' => 'خبز مفرود',
    '🥨' => 'بريتزل',
    '🥯' => 'خبز البيغل',
    '🥞' => 'فطائر',
    '🧇' => 'وافل',
    '🧀' => 'قطعة جبن',
    '🍖' => 'لحم بعظم',
    '🍗' => 'ساق دجاجة',
    '🥩' => 'قطعة لحم',
    '🥓' => 'لحم مقدد',
    '🍔' => 'همبرغر',
    '🍟' => 'بطاطس مقلية',
    '🍕' => 'بيتزا',
    '🌭' => 'هوت دوغ',
    '🥪' => 'ساندوتش',
    '🌮' => 'تاكو',
    '🌯' => 'بوريتو',
    '🫔' => 'تامال',
    '🥙' => 'خبز مفرود محشو',
    '🧆' => 'فلافل',
    '🥚' => 'بيض',
    '🍳' => 'مقلاة',
    '🥘' => 'مقلاة مسطحة بها طعام',
    '🍲' => 'وعاء طعام',
    '🫕' => 'فوندو',
    '🥣' => 'طبق وملعقة',
    '🥗' => 'سلطة خضراء',
    '🍿' => 'فشار',
    '🧈' => 'زبد',
    '🧂' => 'ملح',
    '🥫' => 'طعام معلّب',
    '🍱' => 'علبة طعام',
    '🍘' => 'مقرمشات أرز',
    '🍙' => 'كرة أرز',
    '🍚' => 'أرز مطبوخ',
    '🍛' => 'أرز وكاري',
    '🍜' => 'سلطانية البخار',
    '🍝' => 'سباغتي',
    '🍠' => 'بطاطا حلوة مشوية',
    '🍢' => 'طعام مشكل',
    '🍣' => 'سوشي',
    '🍤' => 'جمبري مقلي',
    '🍥' => 'كعكة سمك بشكل حلزوني',
    '🥮' => 'كعكة القمر',
    '🍡' => 'حلوى الدانغو',
    '🥟' => 'زلابية صينية',
    '🥠' => 'كعكة الحظ',
    '🥡' => 'علبة طعام للخارج',
    '🍦' => 'آيس كريم مخفف',
    '🍧' => 'آيس كريم مجروش',
    '🍨' => 'آيس كريم',
    '🍩' => 'كعكة محلاة',
    '🍪' => 'كعكة',
    '🎂' => 'كعكة عيد ميلاد',
    '🍰' => 'قطعة من الكعك',
    '🧁' => 'كعكة صغيرة',
    '🥧' => 'فطيرة',
    '🍫' => 'لوح شوكولاتة',
    '🍬' => 'حلوى',
    '🍭' => 'مصاصة',
    '🍮' => 'كريم كراميل',
    '🍯' => 'جرة عسل',
    '🍼' => 'زجاجة الرضاعة',
    '🥛' => 'كوب حليب',
    '☕' => 'مشروب ساخن',
    '🫖' => 'إبريق شاي',
    '🍵' => 'فنجان شاي بدون مقبض',
    '🍶' => 'زجاجة وفنجان',
    '🍾' => 'زجاجة بسدادة مفرقعة',
    '🍷' => 'كأس عصير',
    '🍸' => 'كأس عصير كوكتيل',
    '🍹' => 'مشروب استوائي',
    '🍺' => 'كأس بيرة',
    '🍻' => 'كأسا بيرة',
    '🥂' => 'كأسان يرتطمان',
    '🥃' => 'كوب زجاجي',
    '🫗' => 'سكب السائل',
    '🥤' => 'كأس وقشة للشرب',
    '🧋' => 'شاي الفقاعات',
    '🧃' => 'علبة عصير',
    '🧉' => 'متة',
    '🧊' => 'مكعب ثلج',
    '🥢' => 'عيدان للأكل',
    '🍽' => 'طبق وشوكة وسكينة',
    '🍴' => 'شوكة وسكينة',
    '🥄' => 'ملعقة',
    '🔪' => 'سكين طهي',
    '🫙' => 'برطمان',
    '🏺' => 'جرة',
    '🌍' => 'كرة أرضية تعرض أوروبا وإفريقيا',
    '🌎' => 'كرة أرضية تعرض الأمريكتين',
    '🌏' => 'كرة أرضية تعرض آسيا وأستراليا',
    '🌐' => 'كرة أرضية بخطوط طول',
    '🗺' => 'خريطة العالم',
    '🗾' => 'خريطة اليابان',
    '🧭' => 'بوصلة',
    '🏔' => 'جبل بقمة ثلجية',
    '⛰' => 'جبل',
    '🛘' => 'انزلاق أرضي',
    '🌋' => 'بركان',
    '🗻' => 'جبل فوجي',
    '🏕' => 'تخييم',
    '🏖' => 'شاطئ وشمسية',
    '🏜' => 'صحراء',
    '🏝' => 'جزيرة صحراوية',
    '🏞' => 'حديقة وطنية',
    '🏟' => 'استاد',
    '🏛' => 'مبنى أثري',
    '🏗' => 'إنشاءات',
    '🧱' => 'طوبة',
    '🪨' => 'صخرة',
    '🪵' => 'خشب',
    '🛖' => 'كوخ',
    '🏘' => 'منازل',
    '🏚' => 'مبنى مهجور',
    '🏠' => 'منزل',
    '🏡' => 'منزل بحديقة',
    '🏢' => 'مبنى إداري',
    '🏣' => 'مكتب بريد ياباني',
    '🏤' => 'مكتب بريد',
    '🏥' => 'مستشفى',
    '🏦' => 'بنك',
    '🏨' => 'فندق',
    '🏩' => 'فندق حب',
    '🏪' => 'متجر بقالة',
    '🏫' => 'مدرسة',
    '🏬' => 'متجر شامل',
    '🏭' => 'مصنع',
    '🏯' => 'قلعة يابانية',
    '🏰' => 'قلعة',
    '💒' => 'كنيسة زفاف',
    '🗼' => 'برج طوكيو',
    '🗽' => 'تمثال الحرية',
    '⛪' => 'كنيسة',
    '🕌' => 'مسجد',
    '🛕' => 'معبد هندوسي',
    '🕍' => 'معبد يهودي',
    '⛩' => 'ضريح',
    '🕋' => 'الكعبة',
    '⛲' => 'نافورة',
    '⛺' => 'خيمة',
    '🌁' => 'ضباب',
    '🌃' => 'ليل مع نجوم',
    '🏙' => 'ناطحات سحاب',
    '🌄' => 'شروق على جبل',
    '🌅' => 'شروق',
    '🌆' => 'غروب مدينة',
    '🌇' => 'غسق',
    '🌉' => 'جسر في الليل',
    '♨' => 'ينابيع ساخنة',
    '🎠' => 'حصان الدوامة',
    '🛝' => 'منزلق اللعب',
    '🎡' => 'عجلة دوارة',
    '🎢' => 'قطار ملاهي',
    '💈' => 'محل حلاقة',
    '🎪' => 'خيمة سيرك',
    '🚂' => 'جرار بخار',
    '🚃' => 'عربة قطار',
    '🚄' => 'قطار سريع',
    '🚅' => 'قطار سريع بوجه محدب',
    '🚆' => 'قطار',
    '🚇' => 'مترو',
    '🚈' => 'نقل خفيف',
    '🚉' => 'محطة قطار',
    '🚊' => 'ترام',
    '🚝' => 'خط سكة حديد أحادي',
    '🚞' => 'سكة حديد جبلية',
    '🚋' => 'سيارة ترام',
    '🚌' => 'حافلة',
    '🚍' => 'حافلة مقتربة',
    '🚎' => 'أتوبيس ترولي',
    '🚐' => 'حافلة صغيرة',
    '🚑' => 'سيارة إسعاف',
    '🚒' => 'سيارة إطفاء',
    '🚓' => 'سيارة شرطة',
    '🚔' => 'سيارة شرطة مقتربة',
    '🚕' => 'تاكسي',
    '🚖' => 'تاكسي مقترب',
    '🚗' => 'سيارة',
    '🚘' => 'سيارة مقتربة',
    '🚙' => 'مركبة رياضية',
    '🛻' => 'شاحنة خفيفة',
    '🚚' => 'شاحنة توصيل طلبات',
    '🚛' => 'لوري',
    '🚜' => 'جرار',
    '🏎' => 'سيارة سباق',
    '🏍' => 'دراجة بخارية',
    '🛵' => 'سكوتر بمحرك',
    '🦽' => 'كرسي متحرك يدوي',
    '🦼' => 'كرسي متحرك كهربائي',
    '🛺' => 'توكتوك',
    '🚲' => 'دراجة',
    '🛴' => 'سكوتر بدون محرك',
    '🛹' => 'لوح التزلج',
    '🛼' => 'حذاء مع عجلات',
    '🚏' => 'موقف حافلات',
    '🛣' => 'طريق سريع',
    '🛤' => 'سكة حديد',
    '🛢' => 'برميل نفط',
    '⛽' => 'مضخة وقود',
    '🛞' => 'عجلة',
    '🚨' => 'إضاءة سيارة شرطة دوارة',
    '🚥' => 'إشارة مرور أفقية',
    '🚦' => 'إشارة مرور رأسية',
    '🛑' => 'علامة توقف',
    '🚧' => 'تحت الإنشاء',
    '⚓' => 'مرساة',
    '🛟' => 'عوامة',
    '⛵' => 'مركب شراعي',
    '🛶' => 'زورق',
    '🚤' => 'قارب سريع',
    '🛳' => 'سفينة ركاب',
    '⛴' => 'عبّارة',
    '🛥' => 'زورق بخاري',
    '🚢' => 'سفينة',
    '✈' => 'طائرة',
    '🛩' => 'طائرة صغيرة',
    '🛫' => 'مغادرة طائرة',
    '🛬' => 'وصول طائرة',
    '🪂' => 'باراشوت',
    '💺' => 'مقعد',
    '🚁' => 'هليكوبتر',
    '🚟' => 'سكة حديد معلقة',
    '🚠' => 'قطار جبلي',
    '🚡' => 'عربة قطار هوائي',
    '🛰' => 'قمر صناعي',
    '🚀' => 'صاروخ',
    '🛸' => 'صحن طائر',
    '🛎' => 'جرس فندق',
    '🧳' => 'حقائب السفر',
    '⌛' => 'مؤقت رملي مكتمل',
    '⏳' => 'مؤقت رملي غير مكتمل',
    '⌚' => 'ساعة',
    '⏰' => 'ساعة منبه',
    '⏱' => 'ساعة توقف',
    '⏲' => 'ساعة مؤقت',
    '🕰' => 'ساعة موقد',
    '🕛' => 'الساعة الثانية عشرة',
    '🕧' => 'الثانية عشرة والنصف',
    '🕐' => 'الساعة الواحدة',
    '🕜' => 'الواحدة والنصف',
    '🕑' => 'الساعة الثانية',
    '🕝' => 'الثانية والنصف',
    '🕒' => 'الساعة الثالثة',
    '🕞' => 'الثالثة والنصف',
    '🕓' => 'الساعة الرابعة',
    '🕟' => 'الرابعة والنصف',
    '🕔' => 'الساعة الخامسة',
    '🕠' => 'الخامسة والنصف',
    '🕕' => 'الساعة السادسة',
    '🕡' => 'السادسة والنصف',
    '🕖' => 'الساعة السابعة',
    '🕢' => 'السابعة والنصف',
    '🕗' => 'الساعة الثامنة',
    '🕣' => 'الثامنة والنصف',
    '🕘' => 'الساعة التاسعة',
    '🕤' => 'التاسعة والنصف',
    '🕙' => 'الساعة العاشرة',
    '🕥' => 'العاشرة والنصف',
    '🕚' => 'الساعة الحادية عشرة',
    '🕦' => 'الحادية عشر ونصف',
    '🌑' => 'محاق',
    '🌒' => 'هلال بداية الشهر',
    '🌓' => 'تربيع أول',
    '🌔' => 'قمر أحدب متزايد',
    '🌕' => 'بدر',
    '🌖' => 'قمر أحدب متناقص',
    '🌗' => 'تربيع ثان',
    '🌘' => 'هلال آخر الشهر',
    '🌙' => 'هلال',
    '🌚' => 'وجه محاق',
    '🌛' => 'وجه تربيع أول',
    '🌜' => 'وجه تربيع ثانٍ',
    '🌡' => 'ترمومتر',
    '☀' => 'شمس',
    '🌝' => 'وجه البدر',
    '🌞' => 'وجه الشمس',
    '🪐' => 'كوكب داخل حلقة',
    '⭐' => 'نجم متوسط أبيض',
    '🌟' => 'نجم ساطع',
    '🌠' => 'شهاب',
    '🌌' => 'درب التبانة',
    '☁' => 'سحابة',
    '⛅' => 'شمس خلف السحب',
    '⛈' => 'سحابة وبرق ورعد',
    '🌤' => 'شمس خلف سحابة صغيرة',
    '🌥' => 'شمس خلف سحابة كبيرة',
    '🌦' => 'شمس خلف سحابة ومطر',
    '🌧' => 'سحابة ومطر',
    '🌨' => 'سحابة وثلج',
    '🌩' => 'سحابة وبرق',
    '🌪' => 'إعصار',
    '🌫' => 'ضبابي',
    '🌬' => 'رياح',
    '🌀' => 'عاصفة',
    '🌈' => 'ألوان الطيف',
    '🌂' => 'شمسية مغلقة',
    '☂' => 'شمسية',
    '☔' => 'شمسية وقطرات مطر',
    '⛱' => 'شمسية على الأرض',
    '⚡' => 'جهد كهربي عالٍ',
    '❄' => 'كتلة ثلج',
    '☃' => 'رجل ثلج',
    '⛄' => 'رجل ثلج بدون ثلج متساقط',
    '☄' => 'مذنّب',
    '🔥' => 'حريق',
    '💧' => 'قطرة',
    '🌊' => 'موجة',
    '🎃' => 'هالوين',
    '🎄' => 'شجرة عيد الميلاد',
    '🎆' => 'ألعاب نارية',
    '🎇' => 'ماسة نارية',
    '🧨' => 'مفرقعات',
    '✨' => 'ومضات',
    '🎈' => 'بالون',
    '🎉' => 'فرقعة حفلة',
    '🎊' => 'كرة أوراق ملونة',
    '🎋' => 'شجرة احتفال',
    '🎍' => 'ديكور صنوبر',
    '🎎' => 'دميتان يابانيتان',
    '🎏' => 'قصاصات ملونة',
    '🎐' => 'جرس الريح',
    '🎑' => 'احتفال برؤية القمر',
    '🧧' => 'ظرف أحمر بكتابة صينية',
    '🎀' => 'شريط',
    '🎁' => 'هدية ملفوفة',
    '🎗' => 'شريطة تذكير',
    '🎟' => 'تذكرتا دخول',
    '🎫' => 'تذكرة',
    '🎖' => 'ميدالية عسكرية',
    '🏆' => 'كأس',
    '🏅' => 'ميدالية رياضية',
    '🥇' => 'ميدالية مركز أول',
    '🥈' => 'ميدالية مركز ثانٍ',
    '🥉' => 'ميدالية مركز ثالث',
    '⚽' => 'كرة قدم',
    '⚾' => 'بيسبول',
    '🥎' => 'كرة ليّنة',
    '🏀' => 'كرة سلة',
    '🏐' => 'كرة طائرة',
    '🏈' => 'كرة قدم أمريكية',
    '🏉' => 'كرة رجبي',
    '🎾' => 'تنس',
    '🥏' => 'قرص طائر',
    '🎳' => 'بولينغ',
    '🏏' => 'كريكيت',
    '🏑' => 'هوكي أرضي',
    '🏒' => 'عصا هوكي جليد',
    '🥍' => 'لاكروس',
    '🏓' => 'تنس الطاولة',
    '🏸' => 'تنس الريشة',
    '🥊' => 'قفاز ملاكمة',
    '🥋' => 'زي فنون قتالية',
    '🥅' => 'شبكة المرمى',
    '⛳' => 'علم على حفرة',
    '⛸' => 'حذاء تزلج',
    '🎣' => 'صنارة صيد',
    '🤿' => 'قناع غطس',
    '🎽' => 'قميص رياضي',
    '🎿' => 'تزلج',
    '🛷' => 'مزلجة',
    '🥌' => 'حجرة لعبة الكرلنغ',
    '🎯' => 'نشان',
    '🪀' => 'يويو',
    '🪁' => 'طائرة ورقية',
    '🔫' => 'مسدس ماء',
    '🎱' => 'بلياردو',
    '🔮' => 'كرة كريستال',
    '🪄' => 'عصا سحرية',
    '🎮' => 'لعبة فيديو',
    '🕹' => 'ذراع تحكم',
    '🎰' => 'جهاز قمار',
    '🎲' => 'زهر',
    '🧩' => 'أحجية الصور المقطوعة',
    '🧸' => 'لعبة محشوة بشكل دب',
    '🪅' => 'بنياتا',
    '🪩' => 'الكرة المضيئة',
    '🪆' => 'دمية روسية',
    '♠' => 'ورقة البستوني',
    '♥' => 'ورقة قلب أحمر',
    '♦' => 'ورقة لعب بشكل ماسة',
    '♣' => 'ورقة لعب بشكل شجرة',
    '♟' => 'بيدق',
    '🃏' => 'جوكر',
    '🀄' => 'لعبة ورق يابانية',
    '🎴' => 'بطاقات لعب',
    '🎭' => 'قناع وجه',
    '🖼' => 'إطار وصورة',
    '🎨' => 'لوحة ألوان الرسام',
    '🧵' => 'بكرة خيط',
    '🪡' => 'إبرة خياطة',
    '🧶' => 'خيط حياكة',
    '🪢' => 'عُقدة',
    '👓' => 'نظارة',
    '🕶' => 'نظارة شمس',
    '🥽' => 'نظارة واقية',
    '🥼' => 'معطف مختبر',
    '🦺' => 'سترة سلامة',
    '👔' => 'رابطة عنق',
    '👕' => 'تي شيرت',
    '👖' => 'بنطلون جينز',
    '🧣' => 'وشاح',
    '🧤' => 'قفّازان',
    '🧥' => 'معطف',
    '🧦' => 'جورب',
    '👗' => 'فستان',
    '👘' => 'كيمونو ياباني',
    '🥻' => 'ساري',
    '🩱' => 'مايوه من قطعة واحدة',
    '🩲' => 'ملابس تحتية',
    '🩳' => 'شورت',
    '👙' => 'ملابس البحر',
    '👚' => 'ملابس حريمي',
    '🪭' => 'مروحة يدوية',
    '👛' => 'كيس نقود',
    '👜' => 'شنطة يد',
    '👝' => 'محفظة يد',
    '🛍' => 'حقائب تسوق',
    '🎒' => 'حقيبة مدرسة',
    '🩴' => 'صندل إصبع',
    '👞' => 'حذاء رجالي',
    '👟' => 'حذاء رياضي',
    '🥾' => 'حذاء لرحلات المشي',
    '🥿' => 'حذاء نسائي بدون كعب',
    '👠' => 'حذاء بكعب عالٍ',
    '👡' => 'صندل حريمي',
    '🩰' => 'حذاء باليه',
    '👢' => 'حذاء طويل الساق حريمي',
    '🪮' => 'مشط عريض',
    '👑' => 'تاج',
    '👒' => 'قبعة نسائية',
    '🎩' => 'قبعة رسمية',
    '🎓' => 'قبعة تخرج',
    '🧢' => 'قبعة رياضية',
    '🪖' => 'خوذة عسكرية',
    '⛑' => 'خوذة رجل إنقاذ',
    '📿' => 'مسبحة صلاة',
    '💄' => 'أحمر شفاه',
    '💍' => 'خاتم',
    '💎' => 'جوهرة',
    '🔇' => 'ممنوع الحديث',
    '🔈' => 'صوت سماعة منخفض',
    '🔉' => 'صوت معتدل',
    '🔊' => 'صوت سماعة مرتفع',
    '📢' => 'مكبر صوت',
    '📣' => 'مضخم الصوت',
    '📯' => 'جرس بريد',
    '🔔' => 'جرس',
    '🔕' => 'ممنوع استخدام الجرس',
    '🎼' => 'علامة موسيقية',
    '🎵' => 'نوتة موسيقية',
    '🎶' => 'نوتات موسيقية',
    '🎙' => 'ميكروفون استوديو',
    '🎚' => 'شريط منسوب',
    '🎛' => 'أزرار تحكم',
    '🎤' => 'ميكروفون',
    '🎧' => 'سماعة رأس',
    '📻' => 'راديو',
    '🎷' => 'ساكسفون',
    '🎺' => 'آلة نفخ',
    '🪊' => 'ترومبون',
    '🪗' => 'أكورديون',
    '🎸' => 'غيتار',
    '🎹' => 'بيانو',
    '🎻' => 'كمان',
    '🪕' => 'آلة بانجو',
    '🥁' => 'طبلة',
    '🪘' => 'طبل طويل',
    '🪇' => 'مركاس',
    '🪈' => 'فلوت',
    '🪉' => 'قيثارة',
    '📱' => 'هاتف جوال',
    '📲' => 'هاتف جوال مع سهم',
    '☎' => 'هاتف أرضي',
    '📞' => 'سماعة هاتف',
    '📟' => 'جهاز نداء آلي',
    '📠' => 'فاكس',
    '🔋' => 'بطارية',
    '🪫' => 'بطارية ضعيفة',
    '🔌' => 'فيشة كهرباء',
    '💻' => 'كمبيوتر محمول',
    '🖥' => 'كمبيوتر',
    '🖨' => 'طابعة',
    '⌨' => 'لوحة مفاتيح',
    '🖱' => 'ماوس',
    '🖲' => 'كرة مسار',
    '💽' => 'قرص كمبيوتر',
    '💾' => 'قرص مرن',
    '💿' => 'سي دي',
    '📀' => 'قرص Dvd',
    '🧮' => 'معداد',
    '🎥' => 'كاميرا أفلام',
    '🎞' => 'شريط سينمائي',
    '📽' => 'جهاز عرض أفلام',
    '🎬' => 'كلاكيت',
    '📺' => 'تليفزيون',
    '📷' => 'كاميرا',
    '📸' => 'كاميرا بفلاش',
    '📹' => 'كاميرا فيديو',
    '📼' => 'شريط فيديو',
    '🔍' => 'عدسة مكبرة اتجاه اليسار',
    '🔎' => 'عدسة مكبرة اتجاه اليمين',
    '🕯' => 'شمعة',
    '💡' => 'مصباح مضاء',
    '🔦' => 'ضوء فلاش',
    '🏮' => 'فانوس بورق أحمر',
    '🪔' => 'مصباح ضياء',
    '📔' => 'دفتر مزين',
    '📕' => 'كتاب مغلق',
    '📖' => 'كتاب مفتوح',
    '📗' => 'كتاب أخضر',
    '📘' => 'كتاب أزرق',
    '📙' => 'كتاب برتقالي',
    '📚' => 'كتب',
    '📓' => 'دفتر ملاحظات',
    '📒' => 'دفتر',
    '📃' => 'صفحة ملفوفة',
    '📜' => 'ورقة ملفوفة',
    '📄' => 'مستند',
    '📰' => 'جريدة',
    '🗞' => 'صحيفة مطوية',
    '📑' => 'لصاقات علامات توقف قراءة',
    '🔖' => 'علامة توقف قراءة',
    '🏷' => 'ملصق',
    '🪙' => 'عملة معدنية',
    '💰' => 'حقيبة نقود',
    '🪎' => 'صندوق كنز',
    '💴' => 'ورقة ين',
    '💵' => 'ورقة دولار',
    '💶' => 'ورقة يورو',
    '💷' => 'ورقة جنيه',
    '💸' => 'أموال تطير',
    '💳' => 'بطاقة ائتمان',
    '🧾' => 'إيصال',
    '💹' => 'مخطط لبيانات متزايدة مع الين',
    '✉' => 'ظرف',
    '📧' => 'بريد إلكتروني',
    '📨' => 'بريد وارد',
    '📩' => 'بريد صادر',
    '📤' => 'صندوق صادر',
    '📥' => 'صندوق وارد',
    '📦' => 'طرد',
    '📫' => 'صندوق بريد مغلق بإشارة مرفوعة',
    '📪' => 'صندوق بريد مغلق بإشارة لأسفل',
    '📬' => 'صندوق بريد مفتوح بإشارة مرفوعة',
    '📭' => 'صندوق بريد مفتوح بإشارة لأسفل',
    '📮' => 'صندوق بريد',
    '🗳' => 'صندوق اقتراع وورقة اقتراع',
    '✏' => 'قلم رصاص',
    '✒' => 'سن قلم أسود',
    '🖋' => 'قلم حبر',
    '🖊' => 'قلم',
    '🖌' => 'فرشاة ألوان',
    '🖍' => 'قلم شمع ملون',
    '📝' => 'مذكرة',
    '💼' => 'حقيبة كتب',
    '📁' => 'مجلد ملفات',
    '📂' => 'مجلد مفتوح',
    '🗂' => 'حاجز بطاقات',
    '📅' => 'تقويم',
    '📆' => 'تقويم بأوراق للقطع',
    '🗒' => 'ورقة ملاحظات',
    '🗓' => 'تقويم حلزوني',
    '📇' => 'فهرس بطاقات',
    '📈' => 'اتجاه لأعلى',
    '📉' => 'مخطط بياني لأسفل',
    '📊' => 'مخطط بياني شريطي',
    '📋' => 'لوح كتابة مشبكي',
    '📌' => 'دبوس ضغط',
    '📍' => 'دبوس مستدير',
    '📎' => 'مشبك ورق',
    '🖇' => 'مشبك ورق مقترن',
    '📏' => 'مسطرة',
    '📐' => 'مسطرة مثلثة',
    '✂' => 'مقص',
    '🗃' => 'صندوق بطاقات',
    '🗄' => 'خزانة ملفات',
    '🗑' => 'سلة نفايات',
    '🔒' => 'قفل',
    '🔓' => 'قفل مفتوح',
    '🔏' => 'قفل مغلق بقلم',
    '🔐' => 'قفل مغلق بمفتاح',
    '🔑' => 'مفتاح',
    '🗝' => 'مفتاح قديم',
    '🔨' => 'مطرقة',
    '🪓' => 'بلطة',
    '⛏' => 'فأس',
    '⚒' => 'مطرقة ومثقاب',
    '🛠' => 'شاكوش ومفتاح',
    '🗡' => 'خنجر',
    '⚔' => 'سيفان متصالبان',
    '💣' => 'قنبلة',
    '🪃' => 'خذوف مرتد',
    '🏹' => 'قوس وسهم',
    '🛡' => 'درع',
    '🪚' => 'منشار يدوي',
    '🔧' => 'مفتاح ربط',
    '🪛' => 'مفك براغي',
    '🔩' => 'صامولة ومسمار',
    '⚙' => 'ترس',
    '🗜' => 'آلة ضغط',
    '⚖' => 'ميزان',
    '🦯' => 'عصا سير',
    '🔗' => 'علامة رابط',
    '⛓' => 'سلاسل',
    '🪝' => 'خطاف',
    '🧰' => 'صندوق أدوات',
    '🧲' => 'مغناطيس',
    '🪜' => 'سلّم',
    '🪏' => 'جاروف',
    '⚗' => 'أمبيق',
    '🧪' => 'أنبوب اختبار',
    '🧫' => 'صحفة بتري',
    '🧬' => 'الحامض النووي',
    '🔬' => 'ميكروسكوب',
    '🔭' => 'تليسكوب',
    '📡' => 'طبق قمر صناعي',
    '💉' => 'إبرة حقن',
    '🩸' => 'قطرة دم',
    '💊' => 'حبوب',
    '🩹' => 'ضمادة لاصقة',
    '🩼' => 'عكاز',
    '🩺' => 'سماعة طبيب',
    '🩻' => 'أشعة سينية',
    '🚪' => 'باب',
    '🛗' => 'مصعد',
    '🪞' => 'مرآة',
    '🪟' => 'نافذة',
    '🛏' => 'سرير',
    '🛋' => 'كنبة ومصباح',
    '🪑' => 'كرسي',
    '🚽' => 'مرحاض',
    '🪠' => 'مكبس غطاس',
    '🚿' => 'دوش',
    '🛁' => 'حوض استحمام',
    '🪤' => 'مصيدة فئران',
    '🪒' => 'موس حلاقة',
    '🧴' => 'زجاجة غسول',
    '🧷' => 'دبوس أمان',
    '🧹' => 'مكنسة',
    '🧺' => 'سلة',
    '🧻' => 'لفة ورق',
    '🪣' => 'دلو',
    '🧼' => 'صابون',
    '🫧' => 'فقاعات',
    '🪥' => 'فرشاة أسنان',
    '🧽' => 'اسفنجة',
    '🧯' => 'مطفأة حريق',
    '🛒' => 'عربة التسوق',
    '🚬' => 'سيجارة',
    '⚰' => 'تابوت',
    '🪦' => 'حجر مقبرة',
    '⚱' => 'رماد موتى',
    '🧿' => 'الخرزة الزرقاء',
    '🪬' => 'خمسة',
    '🗿' => 'تمثال',
    '🪧' => 'يافطة',
    '🪪' => 'بطاقة الهوية',
    '🏧' => 'علامة ماكينة صرف آلي',
    '🚮' => 'إشارة صندوق النفايات',
    '🚰' => 'مياه صالحة للشرب',
    '♿' => 'كرسي متحرك',
    '🚹' => 'للرجال',
    '🚺' => 'للسيدات',
    '🚻' => 'دورة مياه',
    '🚼' => 'إشارة طفل',
    '🚾' => 'حمام',
    '🛂' => 'مراقبة جوازات السفر',
    '🛃' => 'جمارك',
    '🛄' => 'استرداد الحقائب',
    '🛅' => 'أمتعة',
    '⚠' => 'إشارة تحذير',
    '🚸' => 'عبور أطفال',
    '⛔' => 'ممنوع الدخول',
    '🚫' => 'ممنوع',
    '🚳' => 'ممنوع ركوب الدراجات',
    '🚭' => 'ممنوع التدخين',
    '🚯' => 'ممنوع وضع النفايات',
    '🚱' => 'مياه غير صالحة للشرب',
    '🚷' => 'ممنوع سير المشاة',
    '📵' => 'ممنوع استخدام الهاتف الجوال',
    '🔞' => 'ممنوع لأقل من 18 عامًا',
    '☢' => 'إشعاع',
    '☣' => 'خطورة بيولوجية',
    '⬆' => 'سهم لأعلى',
    '↗' => 'سهم لأعلى اليمين',
    '➡' => 'سهم لليمين',
    '↘' => 'سهم لأسفل اليمين',
    '⬇' => 'سهم لأسفل',
    '↙' => 'سهم لأسفل اليسار',
    '⬅' => 'سهم لليسار',
    '↖' => 'سهم لأعلى اليسار',
    '↕' => 'سهم لأعلى وأسفل',
    '↔' => 'سهم لليسار واليمين',
    '↩' => 'سهم أيمن بانحناء أيسر',
    '↪' => 'سهم أيسر بانحناء أيمن',
    '⤴' => 'سهم لأعلى من اليسار',
    '⤵' => 'سهم لأسفل من اليسار',
    '🔃' => 'سهمان رأسيان مع عقارب الساعة',
    '🔄' => 'زر عكس اتجاه عقارب الساعة',
    '🔙' => 'سهم رجوع',
    '🔚' => 'سهم النهاية',
    '🔛' => 'سهم تشغيل',
    '🔜' => 'سهم علامة قريبًا',
    '🔝' => 'السهم لأعلى',
    '🛐' => 'مكان عبادة',
    '⚛' => 'نووي',
    '🕉' => 'دين هندوسي',
    '✡' => 'نجمة داوود',
    '☸' => 'عجلة دارما',
    '☯' => 'نصفان متكاملان',
    '✝' => 'صليب لاتيني',
    '☦' => 'صليب أرثوزوكس',
    '☪' => 'هلال ونجمة',
    '☮' => 'رمز سلام',
    '🕎' => 'شمعدان شعار اليهودية',
    '🔯' => 'نجمة سداسية',
    '🪯' => 'خندا',
    '♈' => 'الحمل',
    '♉' => 'الثور',
    '♊' => 'الجوزاء',
    '♋' => 'السرطان',
    '♌' => 'الأسد',
    '♍' => 'العذراء',
    '♎' => 'الميزان',
    '♏' => 'العقرب',
    '♐' => 'القوس',
    '♑' => 'الجدي',
    '♒' => 'الدلو',
    '♓' => 'الحوت',
    '⛎' => 'الحواء',
    '🔀' => 'زر أسهم متداخلة',
    '🔁' => 'زر تكرار',
    '🔂' => 'زر تكرار مرة واحدة',
    '▶' => 'زر تشغيل',
    '⏩' => 'زر تقديم سريع',
    '⏭' => 'زر التالي',
    '⏯' => 'زر تشغيل أو إيقاف مؤقت',
    '◀' => 'زر ترجيع',
    '⏪' => 'زر ترجيع سريع',
    '⏮' => 'زر آخر مقطع',
    '🔼' => 'زر لأعلى',
    '⏫' => 'زر سريع لأعلى',
    '🔽' => 'زر لأسفل',
    '⏬' => 'زر سريع لأسفل',
    '⏸' => 'زر إيقاف مؤقت',
    '⏹' => 'زر إيقاف',
    '⏺' => 'زر تسجيل',
    '⏏' => 'زر إخراج',
    '🎦' => 'سينما',
    '🔅' => 'زر سطوع منخفض',
    '🔆' => 'زر سطوع مرتفع',
    '📶' => 'إشارات هوائي',
    '🛜' => 'اتصال لاسلكي',
    '📳' => 'وضع اهتزاز',
    '📴' => 'إغلاق الجوال',
    '♀' => 'رمز أنثى',
    '♂' => 'رمز ذكر',
    '⚧' => 'رمز المتحوّلين جنسيًا',
    '✖' => 'علامة ضرب',
    '➕' => 'علامة جمع',
    '➖' => 'علامة طرح',
    '➗' => 'علامة قسمة',
    '🟰' => 'علامة يساوي قاتمة',
    '♾' => 'اللا نهاية',
    '‼' => 'تعجب مزدوج',
    '⁉' => 'تعجب واستفهام',
    '❓' => 'علامة استفهام حمراء',
    '❔' => 'علامة استفهام بيضاء',
    '❕' => 'علامة تعجب بيضاء',
    '❗' => 'علامة تعجب حمراء',
    '〰' => 'شرطة مموجة',
    '💱' => 'صرف عملة',
    '💲' => 'علامة دولار',
    '⚕' => 'رمز طبي',
    '♻' => 'رمز تدوير',
    '⚜' => 'زنبقة',
    '🔱' => 'رمز ثلاثي الشعب',
    '📛' => 'ملصق اسم',
    '🔰' => 'ورقة خضراء وصفراء',
    '⭕' => 'دائرة كبيرة سميكة',
    '✅' => 'زر علامة تحديد',
    '☑' => 'مربع اختيار محدد',
    '✔' => 'علامة صح',
    '❌' => 'علامة X',
    '❎' => 'علامة X في مربع',
    '➰' => 'عقدة',
    '➿' => 'عقدة مزدوجة',
    '〽' => 'بديل',
    '✳' => 'نجمة ثمانية',
    '✴' => 'نجمة بثمان نقاط',
    '❇' => 'ومضة',
    '™' => 'إشارة علامة تجارية',
    '🫟' => 'بقعة',
    '🔠' => 'أحرف كبيرة',
    '🔡' => 'أحرف صغيرة',
    '🔢' => 'أرقام',
    '🔣' => 'رموز',
    '🔤' => 'أبجدية لاتينية',
    '🅰' => 'زر A',
    '🆎' => 'زر AB (فئة الدم)',
    '🅱' => 'زر B',
    '🆑' => 'مسح داخل مربع',
    '🆒' => 'بارد داخل مربع',
    '🆓' => 'زر "مجاني"',
    'ℹ' => 'مصدر معلومات',
    '🆔' => 'زر "معرّف الهويّة"',
    'Ⓜ' => 'حرف إم',
    '🆕' => 'زر "جديد"',
    '🆖' => 'زر "غير جيد"',
    '🅾' => 'زر O',
    '🆗' => 'زر "موافق"',
    '🅿' => 'انتظار سيارات',
    '🆘' => 'زر "طوارئ"',
    '🆙' => 'أعلى',
    '🆚' => 'ضد',
    '🈁' => 'هنا بالياباني في مربع',
    '🈂' => 'الزر /خدمة برسوم/ باليابانية',
    '🈷' => 'الزر /مبلغ شهري/ باليابانية',
    '🈶' => 'الزر /غير مجاني/ باليابانية',
    '🈯' => 'الزر /محجوز/ باليابانية',
    '🉐' => 'الزر /صفقة/ باليابانية',
    '🈹' => 'الزر /خصم/ باليابانية',
    '🈚' => 'الزر /مجاناً/ باليابانية',
    '🈲' => 'الزر /ممنوع/ باليابانية',
    '🉑' => 'الزر /مقبول/ باليابانية',
    '🈸' => 'الزر /تطبيق/ باليابانية',
    '🈴' => 'الزر /درجة النجاح/ باليابانية',
    '🈳' => 'الزر /خالٍ/ باليابانية',
    '㊗' => 'الزر /تهانينا/ باليابانية',
    '㊙' => 'الزر /سر/ باليابانية',
    '🈺' => 'الزر /عمل/ باليابانية',
    '🈵' => 'الزر /غير خالٍ/ باليابانية',
    '🔴' => 'دائرة حمراء',
    '🟠' => 'دائرة برتقالية',
    '🟡' => 'دائرة صفراء',
    '🟢' => 'دائرة خضراء',
    '🔵' => 'دائرة زرقاء',
    '🟣' => 'دائرة بنفسجية',
    '🟤' => 'دائرة بنية',
    '⚫' => 'دائرة سوداء',
    '⚪' => 'دائرة بيضاء',
    '🟥' => 'مربع أحمر',
    '🟧' => 'مربع برتقالي',
    '🟨' => 'مربع أصفر',
    '🟩' => 'مربع أخضر',
    '🟦' => 'مربع أزرق',
    '🟪' => 'مربع بنفسجي',
    '🟫' => 'مربع بني',
    '⬛' => 'مربع كبير أسود',
    '⬜' => 'مربع كبير أبيض',
    '◼' => 'مربع متوسط أسود',
    '◻' => 'مربع متوسط أبيض',
    '◾' => 'مربع صغير متوسط أسود',
    '◽' => 'مربع صغير متوسط أبيض',
    '▪' => 'مربع صغير أسود',
    '▫' => 'مربع صغير أبيض',
    '🔶' => 'ماسة برتقالي كبيرة',
    '🔷' => 'ماسة زرقاء كبيرة',
    '🔸' => 'ماسة برتقالي صغيرة',
    '🔹' => 'ماسة زرقاء صغيرة',
    '🔺' => 'مثلث لأعلى أحمر',
    '🔻' => 'مثلث لأسفل أحمر',
    '💠' => 'ماسة مع نقطة',
    '🔘' => 'زر تبادلي',
    '🔳' => 'زر مربع أبيض',
    '🔲' => 'زر مربع أسود',
    '🏁' => 'علم مربعات',
    '🚩' => 'علم مثلث',
    '🎌' => 'علمان متقاطعان',
    '🏴' => 'علم أسود يرفرف',
    '🏳' => 'علم أبيض يرفرف',
];
