<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'سۆيۈش: چوڭلار, چوڭلار, ئاچ تېرە رەڭ, and ئارا ئاچ تېرە رەڭگى',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'سۆيۈش: چوڭلار, چوڭلار, ئاچ تېرە رەڭ, and ئارا تېرە رەڭگى',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'سۆيۈش: چوڭلار, چوڭلار, ئاچ تېرە رەڭ, and ئارا توق تېرە رەڭگى',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'سۆيۈش: چوڭلار, چوڭلار, ئاچ تېرە رەڭ, and توق تېرە رەڭ',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'سۆيۈش: چوڭلار, چوڭلار, ئارا ئاچ تېرە رەڭگى, and ئاچ تېرە رەڭ',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'سۆيۈش: چوڭلار, چوڭلار, ئارا ئاچ تېرە رەڭگى, and ئارا تېرە رەڭگى',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'سۆيۈش: چوڭلار, چوڭلار, ئارا ئاچ تېرە رەڭگى, and ئارا توق تېرە رەڭگى',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'سۆيۈش: چوڭلار, چوڭلار, ئارا ئاچ تېرە رەڭگى, and توق تېرە رەڭ',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'سۆيۈش: چوڭلار, چوڭلار, ئارا تېرە رەڭگى, and ئاچ تېرە رەڭ',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'سۆيۈش: چوڭلار, چوڭلار, ئارا تېرە رەڭگى, and ئارا ئاچ تېرە رەڭگى',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'سۆيۈش: چوڭلار, چوڭلار, ئارا تېرە رەڭگى, and ئارا توق تېرە رەڭگى',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'سۆيۈش: چوڭلار, چوڭلار, ئارا تېرە رەڭگى, and توق تېرە رەڭ',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'سۆيۈش: چوڭلار, چوڭلار, ئارا توق تېرە رەڭگى, and ئاچ تېرە رەڭ',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'سۆيۈش: چوڭلار, چوڭلار, ئارا توق تېرە رەڭگى, and ئارا ئاچ تېرە رەڭگى',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'سۆيۈش: چوڭلار, چوڭلار, ئارا توق تېرە رەڭگى, and ئارا تېرە رەڭگى',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'سۆيۈش: چوڭلار, چوڭلار, ئارا توق تېرە رەڭگى, and توق تېرە رەڭ',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'سۆيۈش: چوڭلار, چوڭلار, توق تېرە رەڭ, and ئاچ تېرە رەڭ',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'سۆيۈش: چوڭلار, چوڭلار, توق تېرە رەڭ, and ئارا ئاچ تېرە رەڭگى',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'سۆيۈش: چوڭلار, چوڭلار, توق تېرە رەڭ, and ئارا تېرە رەڭگى',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'سۆيۈش: چوڭلار, چوڭلار, توق تېرە رەڭ, and ئارا توق تېرە رەڭگى',
    '👨🏻‍❤‍💋‍👨🏻' => 'سۆيۈش: ئەر, ئەر, and ئاچ تېرە رەڭ',
    '👨🏻‍❤‍💋‍👨🏼' => 'سۆيۈش: ئەر, ئەر, ئاچ تېرە رەڭ, and ئارا ئاچ تېرە رەڭگى',
    '👨🏻‍❤‍💋‍👨🏽' => 'سۆيۈش: ئەر, ئەر, ئاچ تېرە رەڭ, and ئارا تېرە رەڭگى',
    '👨🏻‍❤‍💋‍👨🏾' => 'سۆيۈش: ئەر, ئەر, ئاچ تېرە رەڭ, and ئارا توق تېرە رەڭگى',
    '👨🏻‍❤‍💋‍👨🏿' => 'سۆيۈش: ئەر, ئەر, ئاچ تېرە رەڭ, and توق تېرە رەڭ',
    '👨🏼‍❤‍💋‍👨🏻' => 'سۆيۈش: ئەر, ئەر, ئارا ئاچ تېرە رەڭگى, and ئاچ تېرە رەڭ',
    '👨🏼‍❤‍💋‍👨🏼' => 'سۆيۈش: ئەر, ئەر, and ئارا ئاچ تېرە رەڭگى',
    '👨🏼‍❤‍💋‍👨🏽' => 'سۆيۈش: ئەر, ئەر, ئارا ئاچ تېرە رەڭگى, and ئارا تېرە رەڭگى',
    '👨🏼‍❤‍💋‍👨🏾' => 'سۆيۈش: ئەر, ئەر, ئارا ئاچ تېرە رەڭگى, and ئارا توق تېرە رەڭگى',
    '👨🏼‍❤‍💋‍👨🏿' => 'سۆيۈش: ئەر, ئەر, ئارا ئاچ تېرە رەڭگى, and توق تېرە رەڭ',
    '👨🏽‍❤‍💋‍👨🏻' => 'سۆيۈش: ئەر, ئەر, ئارا تېرە رەڭگى, and ئاچ تېرە رەڭ',
    '👨🏽‍❤‍💋‍👨🏼' => 'سۆيۈش: ئەر, ئەر, ئارا تېرە رەڭگى, and ئارا ئاچ تېرە رەڭگى',
    '👨🏽‍❤‍💋‍👨🏽' => 'سۆيۈش: ئەر, ئەر, and ئارا تېرە رەڭگى',
    '👨🏽‍❤‍💋‍👨🏾' => 'سۆيۈش: ئەر, ئەر, ئارا تېرە رەڭگى, and ئارا توق تېرە رەڭگى',
    '👨🏽‍❤‍💋‍👨🏿' => 'سۆيۈش: ئەر, ئەر, ئارا تېرە رەڭگى, and توق تېرە رەڭ',
    '👨🏾‍❤‍💋‍👨🏻' => 'سۆيۈش: ئەر, ئەر, ئارا توق تېرە رەڭگى, and ئاچ تېرە رەڭ',
    '👨🏾‍❤‍💋‍👨🏼' => 'سۆيۈش: ئەر, ئەر, ئارا توق تېرە رەڭگى, and ئارا ئاچ تېرە رەڭگى',
    '👨🏾‍❤‍💋‍👨🏽' => 'سۆيۈش: ئەر, ئەر, ئارا توق تېرە رەڭگى, and ئارا تېرە رەڭگى',
    '👨🏾‍❤‍💋‍👨🏾' => 'سۆيۈش: ئەر, ئەر, and ئارا توق تېرە رەڭگى',
    '👨🏾‍❤‍💋‍👨🏿' => 'سۆيۈش: ئەر, ئەر, ئارا توق تېرە رەڭگى, and توق تېرە رەڭ',
    '👨🏿‍❤‍💋‍👨🏻' => 'سۆيۈش: ئەر, ئەر, توق تېرە رەڭ, and ئاچ تېرە رەڭ',
    '👨🏿‍❤‍💋‍👨🏼' => 'سۆيۈش: ئەر, ئەر, توق تېرە رەڭ, and ئارا ئاچ تېرە رەڭگى',
    '👨🏿‍❤‍💋‍👨🏽' => 'سۆيۈش: ئەر, ئەر, توق تېرە رەڭ, and ئارا تېرە رەڭگى',
    '👨🏿‍❤‍💋‍👨🏾' => 'سۆيۈش: ئەر, ئەر, توق تېرە رەڭ, and ئارا توق تېرە رەڭگى',
    '👨🏿‍❤‍💋‍👨🏿' => 'سۆيۈش: ئەر, ئەر, and توق تېرە رەڭ',
    '👩🏻‍❤‍💋‍👨🏻' => 'سۆيۈش: ئايال, ئەر, and ئاچ تېرە رەڭ',
    '👩🏻‍❤‍💋‍👨🏼' => 'سۆيۈش: ئايال, ئەر, ئاچ تېرە رەڭ, and ئارا ئاچ تېرە رەڭگى',
    '👩🏻‍❤‍💋‍👨🏽' => 'سۆيۈش: ئايال, ئەر, ئاچ تېرە رەڭ, and ئارا تېرە رەڭگى',
    '👩🏻‍❤‍💋‍👨🏾' => 'سۆيۈش: ئايال, ئەر, ئاچ تېرە رەڭ, and ئارا توق تېرە رەڭگى',
    '👩🏻‍❤‍💋‍👨🏿' => 'سۆيۈش: ئايال, ئەر, ئاچ تېرە رەڭ, and توق تېرە رەڭ',
    '👩🏼‍❤‍💋‍👨🏻' => 'سۆيۈش: ئايال, ئەر, ئارا ئاچ تېرە رەڭگى, and ئاچ تېرە رەڭ',
    '👩🏼‍❤‍💋‍👨🏼' => 'سۆيۈش: ئايال, ئەر, and ئارا ئاچ تېرە رەڭگى',
    '👩🏼‍❤‍💋‍👨🏽' => 'سۆيۈش: ئايال, ئەر, ئارا ئاچ تېرە رەڭگى, and ئارا تېرە رەڭگى',
    '👩🏼‍❤‍💋‍👨🏾' => 'سۆيۈش: ئايال, ئەر, ئارا ئاچ تېرە رەڭگى, and ئارا توق تېرە رەڭگى',
    '👩🏼‍❤‍💋‍👨🏿' => 'سۆيۈش: ئايال, ئەر, ئارا ئاچ تېرە رەڭگى, and توق تېرە رەڭ',
    '👩🏽‍❤‍💋‍👨🏻' => 'سۆيۈش: ئايال, ئەر, ئارا تېرە رەڭگى, and ئاچ تېرە رەڭ',
    '👩🏽‍❤‍💋‍👨🏼' => 'سۆيۈش: ئايال, ئەر, ئارا تېرە رەڭگى, and ئارا ئاچ تېرە رەڭگى',
    '👩🏽‍❤‍💋‍👨🏽' => 'سۆيۈش: ئايال, ئەر, and ئارا تېرە رەڭگى',
    '👩🏽‍❤‍💋‍👨🏾' => 'سۆيۈش: ئايال, ئەر, ئارا تېرە رەڭگى, and ئارا توق تېرە رەڭگى',
    '👩🏽‍❤‍💋‍👨🏿' => 'سۆيۈش: ئايال, ئەر, ئارا تېرە رەڭگى, and توق تېرە رەڭ',
    '👩🏾‍❤‍💋‍👨🏻' => 'سۆيۈش: ئايال, ئەر, ئارا توق تېرە رەڭگى, and ئاچ تېرە رەڭ',
    '👩🏾‍❤‍💋‍👨🏼' => 'سۆيۈش: ئايال, ئەر, ئارا توق تېرە رەڭگى, and ئارا ئاچ تېرە رەڭگى',
    '👩🏾‍❤‍💋‍👨🏽' => 'سۆيۈش: ئايال, ئەر, ئارا توق تېرە رەڭگى, and ئارا تېرە رەڭگى',
    '👩🏾‍❤‍💋‍👨🏾' => 'سۆيۈش: ئايال, ئەر, and ئارا توق تېرە رەڭگى',
    '👩🏾‍❤‍💋‍👨🏿' => 'سۆيۈش: ئايال, ئەر, ئارا توق تېرە رەڭگى, and توق تېرە رەڭ',
    '👩🏿‍❤‍💋‍👨🏻' => 'سۆيۈش: ئايال, ئەر, توق تېرە رەڭ, and ئاچ تېرە رەڭ',
    '👩🏿‍❤‍💋‍👨🏼' => 'سۆيۈش: ئايال, ئەر, توق تېرە رەڭ, and ئارا ئاچ تېرە رەڭگى',
    '👩🏿‍❤‍💋‍👨🏽' => 'سۆيۈش: ئايال, ئەر, توق تېرە رەڭ, and ئارا تېرە رەڭگى',
    '👩🏿‍❤‍💋‍👨🏾' => 'سۆيۈش: ئايال, ئەر, توق تېرە رەڭ, and ئارا توق تېرە رەڭگى',
    '👩🏿‍❤‍💋‍👨🏿' => 'سۆيۈش: ئايال, ئەر, and توق تېرە رەڭ',
    '👩🏻‍❤‍💋‍👩🏻' => 'سۆيۈش: ئايال, ئايال, and ئاچ تېرە رەڭ',
    '👩🏻‍❤‍💋‍👩🏼' => 'سۆيۈش: ئايال, ئايال, ئاچ تېرە رەڭ, and ئارا ئاچ تېرە رەڭگى',
    '👩🏻‍❤‍💋‍👩🏽' => 'سۆيۈش: ئايال, ئايال, ئاچ تېرە رەڭ, and ئارا تېرە رەڭگى',
    '👩🏻‍❤‍💋‍👩🏾' => 'سۆيۈش: ئايال, ئايال, ئاچ تېرە رەڭ, and ئارا توق تېرە رەڭگى',
    '👩🏻‍❤‍💋‍👩🏿' => 'سۆيۈش: ئايال, ئايال, ئاچ تېرە رەڭ, and توق تېرە رەڭ',
    '👩🏼‍❤‍💋‍👩🏻' => 'سۆيۈش: ئايال, ئايال, ئارا ئاچ تېرە رەڭگى, and ئاچ تېرە رەڭ',
    '👩🏼‍❤‍💋‍👩🏼' => 'سۆيۈش: ئايال, ئايال, and ئارا ئاچ تېرە رەڭگى',
    '👩🏼‍❤‍💋‍👩🏽' => 'سۆيۈش: ئايال, ئايال, ئارا ئاچ تېرە رەڭگى, and ئارا تېرە رەڭگى',
    '👩🏼‍❤‍💋‍👩🏾' => 'سۆيۈش: ئايال, ئايال, ئارا ئاچ تېرە رەڭگى, and ئارا توق تېرە رەڭگى',
    '👩🏼‍❤‍💋‍👩🏿' => 'سۆيۈش: ئايال, ئايال, ئارا ئاچ تېرە رەڭگى, and توق تېرە رەڭ',
    '👩🏽‍❤‍💋‍👩🏻' => 'سۆيۈش: ئايال, ئايال, ئارا تېرە رەڭگى, and ئاچ تېرە رەڭ',
    '👩🏽‍❤‍💋‍👩🏼' => 'سۆيۈش: ئايال, ئايال, ئارا تېرە رەڭگى, and ئارا ئاچ تېرە رەڭگى',
    '👩🏽‍❤‍💋‍👩🏽' => 'سۆيۈش: ئايال, ئايال, and ئارا تېرە رەڭگى',
    '👩🏽‍❤‍💋‍👩🏾' => 'سۆيۈش: ئايال, ئايال, ئارا تېرە رەڭگى, and ئارا توق تېرە رەڭگى',
    '👩🏽‍❤‍💋‍👩🏿' => 'سۆيۈش: ئايال, ئايال, ئارا تېرە رەڭگى, and توق تېرە رەڭ',
    '👩🏾‍❤‍💋‍👩🏻' => 'سۆيۈش: ئايال, ئايال, ئارا توق تېرە رەڭگى, and ئاچ تېرە رەڭ',
    '👩🏾‍❤‍💋‍👩🏼' => 'سۆيۈش: ئايال, ئايال, ئارا توق تېرە رەڭگى, and ئارا ئاچ تېرە رەڭگى',
    '👩🏾‍❤‍💋‍👩🏽' => 'سۆيۈش: ئايال, ئايال, ئارا توق تېرە رەڭگى, and ئارا تېرە رەڭگى',
    '👩🏾‍❤‍💋‍👩🏾' => 'سۆيۈش: ئايال, ئايال, and ئارا توق تېرە رەڭگى',
    '👩🏾‍❤‍💋‍👩🏿' => 'سۆيۈش: ئايال, ئايال, ئارا توق تېرە رەڭگى, and توق تېرە رەڭ',
    '👩🏿‍❤‍💋‍👩🏻' => 'سۆيۈش: ئايال, ئايال, توق تېرە رەڭ, and ئاچ تېرە رەڭ',
    '👩🏿‍❤‍💋‍👩🏼' => 'سۆيۈش: ئايال, ئايال, توق تېرە رەڭ, and ئارا ئاچ تېرە رەڭگى',
    '👩🏿‍❤‍💋‍👩🏽' => 'سۆيۈش: ئايال, ئايال, توق تېرە رەڭ, and ئارا تېرە رەڭگى',
    '👩🏿‍❤‍💋‍👩🏾' => 'سۆيۈش: ئايال, ئايال, توق تېرە رەڭ, and ئارا توق تېرە رەڭگى',
    '👩🏿‍❤‍💋‍👩🏿' => 'سۆيۈش: ئايال, ئايال, and توق تېرە رەڭ',
    '🧑🏻‍🫯‍🧑🏼' => 'چېلىشچى: ئاچ تېرە رەڭ and ئارا ئاچ تېرە رەڭگى',
    '🧑🏻‍🫯‍🧑🏽' => 'چېلىشچى: ئاچ تېرە رەڭ and ئارا تېرە رەڭگى',
    '🧑🏻‍🫯‍🧑🏾' => 'چېلىشچى: ئاچ تېرە رەڭ and ئارا توق تېرە رەڭگى',
    '🧑🏻‍🫯‍🧑🏿' => 'چېلىشچى: ئاچ تېرە رەڭ and توق تېرە رەڭ',
    '🧑🏼‍🫯‍🧑🏻' => 'چېلىشچى: ئارا ئاچ تېرە رەڭگى and ئاچ تېرە رەڭ',
    '🧑🏼‍🫯‍🧑🏽' => 'چېلىشچى: ئارا ئاچ تېرە رەڭگى and ئارا تېرە رەڭگى',
    '🧑🏼‍🫯‍🧑🏾' => 'چېلىشچى: ئارا ئاچ تېرە رەڭگى and ئارا توق تېرە رەڭگى',
    '🧑🏼‍🫯‍🧑🏿' => 'چېلىشچى: ئارا ئاچ تېرە رەڭگى and توق تېرە رەڭ',
    '🧑🏽‍🫯‍🧑🏻' => 'چېلىشچى: ئارا تېرە رەڭگى and ئاچ تېرە رەڭ',
    '🧑🏽‍🫯‍🧑🏼' => 'چېلىشچى: ئارا تېرە رەڭگى and ئارا ئاچ تېرە رەڭگى',
    '🧑🏽‍🫯‍🧑🏾' => 'چېلىشچى: ئارا تېرە رەڭگى and ئارا توق تېرە رەڭگى',
    '🧑🏽‍🫯‍🧑🏿' => 'چېلىشچى: ئارا تېرە رەڭگى and توق تېرە رەڭ',
    '🧑🏾‍🫯‍🧑🏻' => 'چېلىشچى: ئارا توق تېرە رەڭگى and ئاچ تېرە رەڭ',
    '🧑🏾‍🫯‍🧑🏼' => 'چېلىشچى: ئارا توق تېرە رەڭگى and ئارا ئاچ تېرە رەڭگى',
    '🧑🏾‍🫯‍🧑🏽' => 'چېلىشچى: ئارا توق تېرە رەڭگى and ئارا تېرە رەڭگى',
    '🧑🏾‍🫯‍🧑🏿' => 'چېلىشچى: ئارا توق تېرە رەڭگى and توق تېرە رەڭ',
    '🧑🏿‍🫯‍🧑🏻' => 'چېلىشچى: توق تېرە رەڭ and ئاچ تېرە رەڭ',
    '🧑🏿‍🫯‍🧑🏼' => 'چېلىشچى: توق تېرە رەڭ and ئارا ئاچ تېرە رەڭگى',
    '🧑🏿‍🫯‍🧑🏽' => 'چېلىشچى: توق تېرە رەڭ and ئارا تېرە رەڭگى',
    '🧑🏿‍🫯‍🧑🏾' => 'چېلىشچى: توق تېرە رەڭ and ئارا توق تېرە رەڭگى',
    '🧑🏻‍❤‍🧑🏼' => 'يۈرەكلىك جۈپلەر: چوڭلار, چوڭلار, ئاچ تېرە رەڭ, and ئارا ئاچ تېرە رەڭگى',
    '🧑🏻‍❤‍🧑🏽' => 'يۈرەكلىك جۈپلەر: چوڭلار, چوڭلار, ئاچ تېرە رەڭ, and ئارا تېرە رەڭگى',
    '🧑🏻‍❤‍🧑🏾' => 'يۈرەكلىك جۈپلەر: چوڭلار, چوڭلار, ئاچ تېرە رەڭ, and ئارا توق تېرە رەڭگى',
    '🧑🏻‍❤‍🧑🏿' => 'يۈرەكلىك جۈپلەر: چوڭلار, چوڭلار, ئاچ تېرە رەڭ, and توق تېرە رەڭ',
    '🧑🏼‍❤‍🧑🏻' => 'يۈرەكلىك جۈپلەر: چوڭلار, چوڭلار, ئارا ئاچ تېرە رەڭگى, and ئاچ تېرە رەڭ',
    '🧑🏼‍❤‍🧑🏽' => 'يۈرەكلىك جۈپلەر: چوڭلار, چوڭلار, ئارا ئاچ تېرە رەڭگى, and ئارا تېرە رەڭگى',
    '🧑🏼‍❤‍🧑🏾' => 'يۈرەكلىك جۈپلەر: چوڭلار, چوڭلار, ئارا ئاچ تېرە رەڭگى, and ئارا توق تېرە رەڭگى',
    '🧑🏼‍❤‍🧑🏿' => 'يۈرەكلىك جۈپلەر: چوڭلار, چوڭلار, ئارا ئاچ تېرە رەڭگى, and توق تېرە رەڭ',
    '🧑🏽‍❤‍🧑🏻' => 'يۈرەكلىك جۈپلەر: چوڭلار, چوڭلار, ئارا تېرە رەڭگى, and ئاچ تېرە رەڭ',
    '🧑🏽‍❤‍🧑🏼' => 'يۈرەكلىك جۈپلەر: چوڭلار, چوڭلار, ئارا تېرە رەڭگى, and ئارا ئاچ تېرە رەڭگى',
    '🧑🏽‍❤‍🧑🏾' => 'يۈرەكلىك جۈپلەر: چوڭلار, چوڭلار, ئارا تېرە رەڭگى, and ئارا توق تېرە رەڭگى',
    '🧑🏽‍❤‍🧑🏿' => 'يۈرەكلىك جۈپلەر: چوڭلار, چوڭلار, ئارا تېرە رەڭگى, and توق تېرە رەڭ',
    '🧑🏾‍❤‍🧑🏻' => 'يۈرەكلىك جۈپلەر: چوڭلار, چوڭلار, ئارا توق تېرە رەڭگى, and ئاچ تېرە رەڭ',
    '🧑🏾‍❤‍🧑🏼' => 'يۈرەكلىك جۈپلەر: چوڭلار, چوڭلار, ئارا توق تېرە رەڭگى, and ئارا ئاچ تېرە رەڭگى',
    '🧑🏾‍❤‍🧑🏽' => 'يۈرەكلىك جۈپلەر: چوڭلار, چوڭلار, ئارا توق تېرە رەڭگى, and ئارا تېرە رەڭگى',
    '🧑🏾‍❤‍🧑🏿' => 'يۈرەكلىك جۈپلەر: چوڭلار, چوڭلار, ئارا توق تېرە رەڭگى, and توق تېرە رەڭ',
    '🧑🏿‍❤‍🧑🏻' => 'يۈرەكلىك جۈپلەر: چوڭلار, چوڭلار, توق تېرە رەڭ, and ئاچ تېرە رەڭ',
    '🧑🏿‍❤‍🧑🏼' => 'يۈرەكلىك جۈپلەر: چوڭلار, چوڭلار, توق تېرە رەڭ, and ئارا ئاچ تېرە رەڭگى',
    '🧑🏿‍❤‍🧑🏽' => 'يۈرەكلىك جۈپلەر: چوڭلار, چوڭلار, توق تېرە رەڭ, and ئارا تېرە رەڭگى',
    '🧑🏿‍❤‍🧑🏾' => 'يۈرەكلىك جۈپلەر: چوڭلار, چوڭلار, توق تېرە رەڭ, and ئارا توق تېرە رەڭگى',
    '🧑🏻‍🐰‍🧑🏼' => 'سورۇندىكى ئۇزۇن قۇلاق كىشىلەر: ئاچ تېرە رەڭ and ئارا ئاچ تېرە رەڭگى',
    '🧑🏻‍🐰‍🧑🏽' => 'سورۇندىكى ئۇزۇن قۇلاق كىشىلەر: ئاچ تېرە رەڭ and ئارا تېرە رەڭگى',
    '🧑🏻‍🐰‍🧑🏾' => 'سورۇندىكى ئۇزۇن قۇلاق كىشىلەر: ئاچ تېرە رەڭ and ئارا توق تېرە رەڭگى',
    '🧑🏻‍🐰‍🧑🏿' => 'سورۇندىكى ئۇزۇن قۇلاق كىشىلەر: ئاچ تېرە رەڭ and توق تېرە رەڭ',
    '🧑🏼‍🐰‍🧑🏻' => 'سورۇندىكى ئۇزۇن قۇلاق كىشىلەر: ئارا ئاچ تېرە رەڭگى and ئاچ تېرە رەڭ',
    '🧑🏼‍🐰‍🧑🏽' => 'سورۇندىكى ئۇزۇن قۇلاق كىشىلەر: ئارا ئاچ تېرە رەڭگى and ئارا تېرە رەڭگى',
    '🧑🏼‍🐰‍🧑🏾' => 'سورۇندىكى ئۇزۇن قۇلاق كىشىلەر: ئارا ئاچ تېرە رەڭگى and ئارا توق تېرە رەڭگى',
    '🧑🏼‍🐰‍🧑🏿' => 'سورۇندىكى ئۇزۇن قۇلاق كىشىلەر: ئارا ئاچ تېرە رەڭگى and توق تېرە رەڭ',
    '🧑🏽‍🐰‍🧑🏻' => 'سورۇندىكى ئۇزۇن قۇلاق كىشىلەر: ئارا تېرە رەڭگى and ئاچ تېرە رەڭ',
    '🧑🏽‍🐰‍🧑🏼' => 'سورۇندىكى ئۇزۇن قۇلاق كىشىلەر: ئارا تېرە رەڭگى and ئارا ئاچ تېرە رەڭگى',
    '🧑🏽‍🐰‍🧑🏾' => 'سورۇندىكى ئۇزۇن قۇلاق كىشىلەر: ئارا تېرە رەڭگى and ئارا توق تېرە رەڭگى',
    '🧑🏽‍🐰‍🧑🏿' => 'سورۇندىكى ئۇزۇن قۇلاق كىشىلەر: ئارا تېرە رەڭگى and توق تېرە رەڭ',
    '🧑🏾‍🐰‍🧑🏻' => 'سورۇندىكى ئۇزۇن قۇلاق كىشىلەر: ئارا توق تېرە رەڭگى and ئاچ تېرە رەڭ',
    '🧑🏾‍🐰‍🧑🏼' => 'سورۇندىكى ئۇزۇن قۇلاق كىشىلەر: ئارا توق تېرە رەڭگى and ئارا ئاچ تېرە رەڭگى',
    '🧑🏾‍🐰‍🧑🏽' => 'سورۇندىكى ئۇزۇن قۇلاق كىشىلەر: ئارا توق تېرە رەڭگى and ئارا تېرە رەڭگى',
    '🧑🏾‍🐰‍🧑🏿' => 'سورۇندىكى ئۇزۇن قۇلاق كىشىلەر: ئارا توق تېرە رەڭگى and توق تېرە رەڭ',
    '🧑🏿‍🐰‍🧑🏻' => 'سورۇندىكى ئۇزۇن قۇلاق كىشىلەر: توق تېرە رەڭ and ئاچ تېرە رەڭ',
    '🧑🏿‍🐰‍🧑🏼' => 'سورۇندىكى ئۇزۇن قۇلاق كىشىلەر: توق تېرە رەڭ and ئارا ئاچ تېرە رەڭگى',
    '🧑🏿‍🐰‍🧑🏽' => 'سورۇندىكى ئۇزۇن قۇلاق كىشىلەر: توق تېرە رەڭ and ئارا تېرە رەڭگى',
    '🧑🏿‍🐰‍🧑🏾' => 'سورۇندىكى ئۇزۇن قۇلاق كىشىلەر: توق تېرە رەڭ and ئارا توق تېرە رەڭگى',
    '👨🏻‍🫯‍👨🏼' => 'ئەر چېلىشچى: ئاچ تېرە رەڭ and ئارا ئاچ تېرە رەڭگى',
    '👨🏻‍🫯‍👨🏽' => 'ئەر چېلىشچى: ئاچ تېرە رەڭ and ئارا تېرە رەڭگى',
    '👨🏻‍🫯‍👨🏾' => 'ئەر چېلىشچى: ئاچ تېرە رەڭ and ئارا توق تېرە رەڭگى',
    '👨🏻‍🫯‍👨🏿' => 'ئەر چېلىشچى: ئاچ تېرە رەڭ and توق تېرە رەڭ',
    '👨🏼‍🫯‍👨🏻' => 'ئەر چېلىشچى: ئارا ئاچ تېرە رەڭگى and ئاچ تېرە رەڭ',
    '👨🏼‍🫯‍👨🏽' => 'ئەر چېلىشچى: ئارا ئاچ تېرە رەڭگى and ئارا تېرە رەڭگى',
    '👨🏼‍🫯‍👨🏾' => 'ئەر چېلىشچى: ئارا ئاچ تېرە رەڭگى and ئارا توق تېرە رەڭگى',
    '👨🏼‍🫯‍👨🏿' => 'ئەر چېلىشچى: ئارا ئاچ تېرە رەڭگى and توق تېرە رەڭ',
    '👨🏽‍🫯‍👨🏻' => 'ئەر چېلىشچى: ئارا تېرە رەڭگى and ئاچ تېرە رەڭ',
    '👨🏽‍🫯‍👨🏼' => 'ئەر چېلىشچى: ئارا تېرە رەڭگى and ئارا ئاچ تېرە رەڭگى',
    '👨🏽‍🫯‍👨🏾' => 'ئەر چېلىشچى: ئارا تېرە رەڭگى and ئارا توق تېرە رەڭگى',
    '👨🏽‍🫯‍👨🏿' => 'ئەر چېلىشچى: ئارا تېرە رەڭگى and توق تېرە رەڭ',
    '👨🏾‍🫯‍👨🏻' => 'ئەر چېلىشچى: ئارا توق تېرە رەڭگى and ئاچ تېرە رەڭ',
    '👨🏾‍🫯‍👨🏼' => 'ئەر چېلىشچى: ئارا توق تېرە رەڭگى and ئارا ئاچ تېرە رەڭگى',
    '👨🏾‍🫯‍👨🏽' => 'ئەر چېلىشچى: ئارا توق تېرە رەڭگى and ئارا تېرە رەڭگى',
    '👨🏾‍🫯‍👨🏿' => 'ئەر چېلىشچى: ئارا توق تېرە رەڭگى and توق تېرە رەڭ',
    '👨🏿‍🫯‍👨🏻' => 'ئەر چېلىشچى: توق تېرە رەڭ and ئاچ تېرە رەڭ',
    '👨🏿‍🫯‍👨🏼' => 'ئەر چېلىشچى: توق تېرە رەڭ and ئارا ئاچ تېرە رەڭگى',
    '👨🏿‍🫯‍👨🏽' => 'ئەر چېلىشچى: توق تېرە رەڭ and ئارا تېرە رەڭگى',
    '👨🏿‍🫯‍👨🏾' => 'ئەر چېلىشچى: توق تېرە رەڭ and ئارا توق تېرە رەڭگى',
    '👨🏻‍❤‍👨🏻' => 'يۈرەكلىك جۈپلەر: ئەر, ئەر, and ئاچ تېرە رەڭ',
    '👨🏻‍❤‍👨🏼' => 'يۈرەكلىك جۈپلەر: ئەر, ئەر, ئاچ تېرە رەڭ, and ئارا ئاچ تېرە رەڭگى',
    '👨🏻‍❤‍👨🏽' => 'يۈرەكلىك جۈپلەر: ئەر, ئەر, ئاچ تېرە رەڭ, and ئارا تېرە رەڭگى',
    '👨🏻‍❤‍👨🏾' => 'يۈرەكلىك جۈپلەر: ئەر, ئەر, ئاچ تېرە رەڭ, and ئارا توق تېرە رەڭگى',
    '👨🏻‍❤‍👨🏿' => 'يۈرەكلىك جۈپلەر: ئەر, ئەر, ئاچ تېرە رەڭ, and توق تېرە رەڭ',
    '👨🏼‍❤‍👨🏻' => 'يۈرەكلىك جۈپلەر: ئەر, ئەر, ئارا ئاچ تېرە رەڭگى, and ئاچ تېرە رەڭ',
    '👨🏼‍❤‍👨🏼' => 'يۈرەكلىك جۈپلەر: ئەر, ئەر, and ئارا ئاچ تېرە رەڭگى',
    '👨🏼‍❤‍👨🏽' => 'يۈرەكلىك جۈپلەر: ئەر, ئەر, ئارا ئاچ تېرە رەڭگى, and ئارا تېرە رەڭگى',
    '👨🏼‍❤‍👨🏾' => 'يۈرەكلىك جۈپلەر: ئەر, ئەر, ئارا ئاچ تېرە رەڭگى, and ئارا توق تېرە رەڭگى',
    '👨🏼‍❤‍👨🏿' => 'يۈرەكلىك جۈپلەر: ئەر, ئەر, ئارا ئاچ تېرە رەڭگى, and توق تېرە رەڭ',
    '👨🏽‍❤‍👨🏻' => 'يۈرەكلىك جۈپلەر: ئەر, ئەر, ئارا تېرە رەڭگى, and ئاچ تېرە رەڭ',
    '👨🏽‍❤‍👨🏼' => 'يۈرەكلىك جۈپلەر: ئەر, ئەر, ئارا تېرە رەڭگى, and ئارا ئاچ تېرە رەڭگى',
    '👨🏽‍❤‍👨🏽' => 'يۈرەكلىك جۈپلەر: ئەر, ئەر, and ئارا تېرە رەڭگى',
    '👨🏽‍❤‍👨🏾' => 'يۈرەكلىك جۈپلەر: ئەر, ئەر, ئارا تېرە رەڭگى, and ئارا توق تېرە رەڭگى',
    '👨🏽‍❤‍👨🏿' => 'يۈرەكلىك جۈپلەر: ئەر, ئەر, ئارا تېرە رەڭگى, and توق تېرە رەڭ',
    '👨🏾‍❤‍👨🏻' => 'يۈرەكلىك جۈپلەر: ئەر, ئەر, ئارا توق تېرە رەڭگى, and ئاچ تېرە رەڭ',
    '👨🏾‍❤‍👨🏼' => 'يۈرەكلىك جۈپلەر: ئەر, ئەر, ئارا توق تېرە رەڭگى, and ئارا ئاچ تېرە رەڭگى',
    '👨🏾‍❤‍👨🏽' => 'يۈرەكلىك جۈپلەر: ئەر, ئەر, ئارا توق تېرە رەڭگى, and ئارا تېرە رەڭگى',
    '👨🏾‍❤‍👨🏾' => 'يۈرەكلىك جۈپلەر: ئەر, ئەر, and ئارا توق تېرە رەڭگى',
    '👨🏾‍❤‍👨🏿' => 'يۈرەكلىك جۈپلەر: ئەر, ئەر, ئارا توق تېرە رەڭگى, and توق تېرە رەڭ',
    '👨🏿‍❤‍👨🏻' => 'يۈرەكلىك جۈپلەر: ئەر, ئەر, توق تېرە رەڭ, and ئاچ تېرە رەڭ',
    '👨🏿‍❤‍👨🏼' => 'يۈرەكلىك جۈپلەر: ئەر, ئەر, توق تېرە رەڭ, and ئارا ئاچ تېرە رەڭگى',
    '👨🏿‍❤‍👨🏽' => 'يۈرەكلىك جۈپلەر: ئەر, ئەر, توق تېرە رەڭ, and ئارا تېرە رەڭگى',
    '👨🏿‍❤‍👨🏾' => 'يۈرەكلىك جۈپلەر: ئەر, ئەر, توق تېرە رەڭ, and ئارا توق تېرە رەڭگى',
    '👨🏿‍❤‍👨🏿' => 'يۈرەكلىك جۈپلەر: ئەر, ئەر, and توق تېرە رەڭ',
    '👨🏻‍🐰‍👨🏼' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئەر: ئاچ تېرە رەڭ and ئارا ئاچ تېرە رەڭگى',
    '👨🏻‍🐰‍👨🏽' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئەر: ئاچ تېرە رەڭ and ئارا تېرە رەڭگى',
    '👨🏻‍🐰‍👨🏾' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئەر: ئاچ تېرە رەڭ and ئارا توق تېرە رەڭگى',
    '👨🏻‍🐰‍👨🏿' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئەر: ئاچ تېرە رەڭ and توق تېرە رەڭ',
    '👨🏼‍🐰‍👨🏻' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئەر: ئارا ئاچ تېرە رەڭگى and ئاچ تېرە رەڭ',
    '👨🏼‍🐰‍👨🏽' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئەر: ئارا ئاچ تېرە رەڭگى and ئارا تېرە رەڭگى',
    '👨🏼‍🐰‍👨🏾' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئەر: ئارا ئاچ تېرە رەڭگى and ئارا توق تېرە رەڭگى',
    '👨🏼‍🐰‍👨🏿' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئەر: ئارا ئاچ تېرە رەڭگى and توق تېرە رەڭ',
    '👨🏽‍🐰‍👨🏻' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئەر: ئارا تېرە رەڭگى and ئاچ تېرە رەڭ',
    '👨🏽‍🐰‍👨🏼' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئەر: ئارا تېرە رەڭگى and ئارا ئاچ تېرە رەڭگى',
    '👨🏽‍🐰‍👨🏾' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئەر: ئارا تېرە رەڭگى and ئارا توق تېرە رەڭگى',
    '👨🏽‍🐰‍👨🏿' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئەر: ئارا تېرە رەڭگى and توق تېرە رەڭ',
    '👨🏾‍🐰‍👨🏻' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئەر: ئارا توق تېرە رەڭگى and ئاچ تېرە رەڭ',
    '👨🏾‍🐰‍👨🏼' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئەر: ئارا توق تېرە رەڭگى and ئارا ئاچ تېرە رەڭگى',
    '👨🏾‍🐰‍👨🏽' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئەر: ئارا توق تېرە رەڭگى and ئارا تېرە رەڭگى',
    '👨🏾‍🐰‍👨🏿' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئەر: ئارا توق تېرە رەڭگى and توق تېرە رەڭ',
    '👨🏿‍🐰‍👨🏻' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئەر: توق تېرە رەڭ and ئاچ تېرە رەڭ',
    '👨🏿‍🐰‍👨🏼' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئەر: توق تېرە رەڭ and ئارا ئاچ تېرە رەڭگى',
    '👨🏿‍🐰‍👨🏽' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئەر: توق تېرە رەڭ and ئارا تېرە رەڭگى',
    '👨🏿‍🐰‍👨🏾' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئەر: توق تېرە رەڭ and ئارا توق تېرە رەڭگى',
    '👩🏻‍🫯‍👩🏼' => 'ئايال چېلىشچى: ئاچ تېرە رەڭ and ئارا ئاچ تېرە رەڭگى',
    '👩🏻‍🫯‍👩🏽' => 'ئايال چېلىشچى: ئاچ تېرە رەڭ and ئارا تېرە رەڭگى',
    '👩🏻‍🫯‍👩🏾' => 'ئايال چېلىشچى: ئاچ تېرە رەڭ and ئارا توق تېرە رەڭگى',
    '👩🏻‍🫯‍👩🏿' => 'ئايال چېلىشچى: ئاچ تېرە رەڭ and توق تېرە رەڭ',
    '👩🏼‍🫯‍👩🏻' => 'ئايال چېلىشچى: ئارا ئاچ تېرە رەڭگى and ئاچ تېرە رەڭ',
    '👩🏼‍🫯‍👩🏽' => 'ئايال چېلىشچى: ئارا ئاچ تېرە رەڭگى and ئارا تېرە رەڭگى',
    '👩🏼‍🫯‍👩🏾' => 'ئايال چېلىشچى: ئارا ئاچ تېرە رەڭگى and ئارا توق تېرە رەڭگى',
    '👩🏼‍🫯‍👩🏿' => 'ئايال چېلىشچى: ئارا ئاچ تېرە رەڭگى and توق تېرە رەڭ',
    '👩🏽‍🫯‍👩🏻' => 'ئايال چېلىشچى: ئارا تېرە رەڭگى and ئاچ تېرە رەڭ',
    '👩🏽‍🫯‍👩🏼' => 'ئايال چېلىشچى: ئارا تېرە رەڭگى and ئارا ئاچ تېرە رەڭگى',
    '👩🏽‍🫯‍👩🏾' => 'ئايال چېلىشچى: ئارا تېرە رەڭگى and ئارا توق تېرە رەڭگى',
    '👩🏽‍🫯‍👩🏿' => 'ئايال چېلىشچى: ئارا تېرە رەڭگى and توق تېرە رەڭ',
    '👩🏾‍🫯‍👩🏻' => 'ئايال چېلىشچى: ئارا توق تېرە رەڭگى and ئاچ تېرە رەڭ',
    '👩🏾‍🫯‍👩🏼' => 'ئايال چېلىشچى: ئارا توق تېرە رەڭگى and ئارا ئاچ تېرە رەڭگى',
    '👩🏾‍🫯‍👩🏽' => 'ئايال چېلىشچى: ئارا توق تېرە رەڭگى and ئارا تېرە رەڭگى',
    '👩🏾‍🫯‍👩🏿' => 'ئايال چېلىشچى: ئارا توق تېرە رەڭگى and توق تېرە رەڭ',
    '👩🏿‍🫯‍👩🏻' => 'ئايال چېلىشچى: توق تېرە رەڭ and ئاچ تېرە رەڭ',
    '👩🏿‍🫯‍👩🏼' => 'ئايال چېلىشچى: توق تېرە رەڭ and ئارا ئاچ تېرە رەڭگى',
    '👩🏿‍🫯‍👩🏽' => 'ئايال چېلىشچى: توق تېرە رەڭ and ئارا تېرە رەڭگى',
    '👩🏿‍🫯‍👩🏾' => 'ئايال چېلىشچى: توق تېرە رەڭ and ئارا توق تېرە رەڭگى',
    '👩🏻‍❤‍👨🏻' => 'يۈرەكلىك جۈپلەر: ئايال, ئەر, and ئاچ تېرە رەڭ',
    '👩🏻‍❤‍👨🏼' => 'يۈرەكلىك جۈپلەر: ئايال, ئەر, ئاچ تېرە رەڭ, and ئارا ئاچ تېرە رەڭگى',
    '👩🏻‍❤‍👨🏽' => 'يۈرەكلىك جۈپلەر: ئايال, ئەر, ئاچ تېرە رەڭ, and ئارا تېرە رەڭگى',
    '👩🏻‍❤‍👨🏾' => 'يۈرەكلىك جۈپلەر: ئايال, ئەر, ئاچ تېرە رەڭ, and ئارا توق تېرە رەڭگى',
    '👩🏻‍❤‍👨🏿' => 'يۈرەكلىك جۈپلەر: ئايال, ئەر, ئاچ تېرە رەڭ, and توق تېرە رەڭ',
    '👩🏼‍❤‍👨🏻' => 'يۈرەكلىك جۈپلەر: ئايال, ئەر, ئارا ئاچ تېرە رەڭگى, and ئاچ تېرە رەڭ',
    '👩🏼‍❤‍👨🏼' => 'يۈرەكلىك جۈپلەر: ئايال, ئەر, and ئارا ئاچ تېرە رەڭگى',
    '👩🏼‍❤‍👨🏽' => 'يۈرەكلىك جۈپلەر: ئايال, ئەر, ئارا ئاچ تېرە رەڭگى, and ئارا تېرە رەڭگى',
    '👩🏼‍❤‍👨🏾' => 'يۈرەكلىك جۈپلەر: ئايال, ئەر, ئارا ئاچ تېرە رەڭگى, and ئارا توق تېرە رەڭگى',
    '👩🏼‍❤‍👨🏿' => 'يۈرەكلىك جۈپلەر: ئايال, ئەر, ئارا ئاچ تېرە رەڭگى, and توق تېرە رەڭ',
    '👩🏽‍❤‍👨🏻' => 'يۈرەكلىك جۈپلەر: ئايال, ئەر, ئارا تېرە رەڭگى, and ئاچ تېرە رەڭ',
    '👩🏽‍❤‍👨🏼' => 'يۈرەكلىك جۈپلەر: ئايال, ئەر, ئارا تېرە رەڭگى, and ئارا ئاچ تېرە رەڭگى',
    '👩🏽‍❤‍👨🏽' => 'يۈرەكلىك جۈپلەر: ئايال, ئەر, and ئارا تېرە رەڭگى',
    '👩🏽‍❤‍👨🏾' => 'يۈرەكلىك جۈپلەر: ئايال, ئەر, ئارا تېرە رەڭگى, and ئارا توق تېرە رەڭگى',
    '👩🏽‍❤‍👨🏿' => 'يۈرەكلىك جۈپلەر: ئايال, ئەر, ئارا تېرە رەڭگى, and توق تېرە رەڭ',
    '👩🏾‍❤‍👨🏻' => 'يۈرەكلىك جۈپلەر: ئايال, ئەر, ئارا توق تېرە رەڭگى, and ئاچ تېرە رەڭ',
    '👩🏾‍❤‍👨🏼' => 'يۈرەكلىك جۈپلەر: ئايال, ئەر, ئارا توق تېرە رەڭگى, and ئارا ئاچ تېرە رەڭگى',
    '👩🏾‍❤‍👨🏽' => 'يۈرەكلىك جۈپلەر: ئايال, ئەر, ئارا توق تېرە رەڭگى, and ئارا تېرە رەڭگى',
    '👩🏾‍❤‍👨🏾' => 'يۈرەكلىك جۈپلەر: ئايال, ئەر, and ئارا توق تېرە رەڭگى',
    '👩🏾‍❤‍👨🏿' => 'يۈرەكلىك جۈپلەر: ئايال, ئەر, ئارا توق تېرە رەڭگى, and توق تېرە رەڭ',
    '👩🏿‍❤‍👨🏻' => 'يۈرەكلىك جۈپلەر: ئايال, ئەر, توق تېرە رەڭ, and ئاچ تېرە رەڭ',
    '👩🏿‍❤‍👨🏼' => 'يۈرەكلىك جۈپلەر: ئايال, ئەر, توق تېرە رەڭ, and ئارا ئاچ تېرە رەڭگى',
    '👩🏿‍❤‍👨🏽' => 'يۈرەكلىك جۈپلەر: ئايال, ئەر, توق تېرە رەڭ, and ئارا تېرە رەڭگى',
    '👩🏿‍❤‍👨🏾' => 'يۈرەكلىك جۈپلەر: ئايال, ئەر, توق تېرە رەڭ, and ئارا توق تېرە رەڭگى',
    '👩🏿‍❤‍👨🏿' => 'يۈرەكلىك جۈپلەر: ئايال, ئەر, and توق تېرە رەڭ',
    '👩🏻‍❤‍👩🏻' => 'يۈرەكلىك جۈپلەر: ئايال, ئايال, and ئاچ تېرە رەڭ',
    '👩🏻‍❤‍👩🏼' => 'يۈرەكلىك جۈپلەر: ئايال, ئايال, ئاچ تېرە رەڭ, and ئارا ئاچ تېرە رەڭگى',
    '👩🏻‍❤‍👩🏽' => 'يۈرەكلىك جۈپلەر: ئايال, ئايال, ئاچ تېرە رەڭ, and ئارا تېرە رەڭگى',
    '👩🏻‍❤‍👩🏾' => 'يۈرەكلىك جۈپلەر: ئايال, ئايال, ئاچ تېرە رەڭ, and ئارا توق تېرە رەڭگى',
    '👩🏻‍❤‍👩🏿' => 'يۈرەكلىك جۈپلەر: ئايال, ئايال, ئاچ تېرە رەڭ, and توق تېرە رەڭ',
    '👩🏼‍❤‍👩🏻' => 'يۈرەكلىك جۈپلەر: ئايال, ئايال, ئارا ئاچ تېرە رەڭگى, and ئاچ تېرە رەڭ',
    '👩🏼‍❤‍👩🏼' => 'يۈرەكلىك جۈپلەر: ئايال, ئايال, and ئارا ئاچ تېرە رەڭگى',
    '👩🏼‍❤‍👩🏽' => 'يۈرەكلىك جۈپلەر: ئايال, ئايال, ئارا ئاچ تېرە رەڭگى, and ئارا تېرە رەڭگى',
    '👩🏼‍❤‍👩🏾' => 'يۈرەكلىك جۈپلەر: ئايال, ئايال, ئارا ئاچ تېرە رەڭگى, and ئارا توق تېرە رەڭگى',
    '👩🏼‍❤‍👩🏿' => 'يۈرەكلىك جۈپلەر: ئايال, ئايال, ئارا ئاچ تېرە رەڭگى, and توق تېرە رەڭ',
    '👩🏽‍❤‍👩🏻' => 'يۈرەكلىك جۈپلەر: ئايال, ئايال, ئارا تېرە رەڭگى, and ئاچ تېرە رەڭ',
    '👩🏽‍❤‍👩🏼' => 'يۈرەكلىك جۈپلەر: ئايال, ئايال, ئارا تېرە رەڭگى, and ئارا ئاچ تېرە رەڭگى',
    '👩🏽‍❤‍👩🏽' => 'يۈرەكلىك جۈپلەر: ئايال, ئايال, and ئارا تېرە رەڭگى',
    '👩🏽‍❤‍👩🏾' => 'يۈرەكلىك جۈپلەر: ئايال, ئايال, ئارا تېرە رەڭگى, and ئارا توق تېرە رەڭگى',
    '👩🏽‍❤‍👩🏿' => 'يۈرەكلىك جۈپلەر: ئايال, ئايال, ئارا تېرە رەڭگى, and توق تېرە رەڭ',
    '👩🏾‍❤‍👩🏻' => 'يۈرەكلىك جۈپلەر: ئايال, ئايال, ئارا توق تېرە رەڭگى, and ئاچ تېرە رەڭ',
    '👩🏾‍❤‍👩🏼' => 'يۈرەكلىك جۈپلەر: ئايال, ئايال, ئارا توق تېرە رەڭگى, and ئارا ئاچ تېرە رەڭگى',
    '👩🏾‍❤‍👩🏽' => 'يۈرەكلىك جۈپلەر: ئايال, ئايال, ئارا توق تېرە رەڭگى, and ئارا تېرە رەڭگى',
    '👩🏾‍❤‍👩🏾' => 'يۈرەكلىك جۈپلەر: ئايال, ئايال, and ئارا توق تېرە رەڭگى',
    '👩🏾‍❤‍👩🏿' => 'يۈرەكلىك جۈپلەر: ئايال, ئايال, ئارا توق تېرە رەڭگى, and توق تېرە رەڭ',
    '👩🏿‍❤‍👩🏻' => 'يۈرەكلىك جۈپلەر: ئايال, ئايال, توق تېرە رەڭ, and ئاچ تېرە رەڭ',
    '👩🏿‍❤‍👩🏼' => 'يۈرەكلىك جۈپلەر: ئايال, ئايال, توق تېرە رەڭ, and ئارا ئاچ تېرە رەڭگى',
    '👩🏿‍❤‍👩🏽' => 'يۈرەكلىك جۈپلەر: ئايال, ئايال, توق تېرە رەڭ, and ئارا تېرە رەڭگى',
    '👩🏿‍❤‍👩🏾' => 'يۈرەكلىك جۈپلەر: ئايال, ئايال, توق تېرە رەڭ, and ئارا توق تېرە رەڭگى',
    '👩🏿‍❤‍👩🏿' => 'يۈرەكلىك جۈپلەر: ئايال, ئايال, and توق تېرە رەڭ',
    '👩🏻‍🐰‍👩🏼' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئايال: ئاچ تېرە رەڭ and ئارا ئاچ تېرە رەڭگى',
    '👩🏻‍🐰‍👩🏽' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئايال: ئاچ تېرە رەڭ and ئارا تېرە رەڭگى',
    '👩🏻‍🐰‍👩🏾' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئايال: ئاچ تېرە رەڭ and ئارا توق تېرە رەڭگى',
    '👩🏻‍🐰‍👩🏿' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئايال: ئاچ تېرە رەڭ and توق تېرە رەڭ',
    '👩🏼‍🐰‍👩🏻' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئايال: ئارا ئاچ تېرە رەڭگى and ئاچ تېرە رەڭ',
    '👩🏼‍🐰‍👩🏽' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئايال: ئارا ئاچ تېرە رەڭگى and ئارا تېرە رەڭگى',
    '👩🏼‍🐰‍👩🏾' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئايال: ئارا ئاچ تېرە رەڭگى and ئارا توق تېرە رەڭگى',
    '👩🏼‍🐰‍👩🏿' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئايال: ئارا ئاچ تېرە رەڭگى and توق تېرە رەڭ',
    '👩🏽‍🐰‍👩🏻' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئايال: ئارا تېرە رەڭگى and ئاچ تېرە رەڭ',
    '👩🏽‍🐰‍👩🏼' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئايال: ئارا تېرە رەڭگى and ئارا ئاچ تېرە رەڭگى',
    '👩🏽‍🐰‍👩🏾' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئايال: ئارا تېرە رەڭگى and ئارا توق تېرە رەڭگى',
    '👩🏽‍🐰‍👩🏿' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئايال: ئارا تېرە رەڭگى and توق تېرە رەڭ',
    '👩🏾‍🐰‍👩🏻' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئايال: ئارا توق تېرە رەڭگى and ئاچ تېرە رەڭ',
    '👩🏾‍🐰‍👩🏼' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئايال: ئارا توق تېرە رەڭگى and ئارا ئاچ تېرە رەڭگى',
    '👩🏾‍🐰‍👩🏽' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئايال: ئارا توق تېرە رەڭگى and ئارا تېرە رەڭگى',
    '👩🏾‍🐰‍👩🏿' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئايال: ئارا توق تېرە رەڭگى and توق تېرە رەڭ',
    '👩🏿‍🐰‍👩🏻' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئايال: توق تېرە رەڭ and ئاچ تېرە رەڭ',
    '👩🏿‍🐰‍👩🏼' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئايال: توق تېرە رەڭ and ئارا ئاچ تېرە رەڭگى',
    '👩🏿‍🐰‍👩🏽' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئايال: توق تېرە رەڭ and ئارا تېرە رەڭگى',
    '👩🏿‍🐰‍👩🏾' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئايال: توق تېرە رەڭ and ئارا توق تېرە رەڭگى',
    '👩🏻‍🤝‍👩🏼' => 'قول تۇتۇشقان ئاياللار: ئاچ تېرە رەڭ and ئارا ئاچ تېرە رەڭگى',
    '👩🏻‍🤝‍👩🏽' => 'قول تۇتۇشقان ئاياللار: ئاچ تېرە رەڭ and ئارا تېرە رەڭگى',
    '👩🏻‍🤝‍👩🏾' => 'قول تۇتۇشقان ئاياللار: ئاچ تېرە رەڭ and ئارا توق تېرە رەڭگى',
    '👩🏻‍🤝‍👩🏿' => 'قول تۇتۇشقان ئاياللار: ئاچ تېرە رەڭ and توق تېرە رەڭ',
    '👩🏼‍🤝‍👩🏻' => 'قول تۇتۇشقان ئاياللار: ئارا ئاچ تېرە رەڭگى and ئاچ تېرە رەڭ',
    '👩🏼‍🤝‍👩🏽' => 'قول تۇتۇشقان ئاياللار: ئارا ئاچ تېرە رەڭگى and ئارا تېرە رەڭگى',
    '👩🏼‍🤝‍👩🏾' => 'قول تۇتۇشقان ئاياللار: ئارا ئاچ تېرە رەڭگى and ئارا توق تېرە رەڭگى',
    '👩🏼‍🤝‍👩🏿' => 'قول تۇتۇشقان ئاياللار: ئارا ئاچ تېرە رەڭگى and توق تېرە رەڭ',
    '👩🏽‍🤝‍👩🏻' => 'قول تۇتۇشقان ئاياللار: ئارا تېرە رەڭگى and ئاچ تېرە رەڭ',
    '👩🏽‍🤝‍👩🏼' => 'قول تۇتۇشقان ئاياللار: ئارا تېرە رەڭگى and ئارا ئاچ تېرە رەڭگى',
    '👩🏽‍🤝‍👩🏾' => 'قول تۇتۇشقان ئاياللار: ئارا تېرە رەڭگى and ئارا توق تېرە رەڭگى',
    '👩🏽‍🤝‍👩🏿' => 'قول تۇتۇشقان ئاياللار: ئارا تېرە رەڭگى and توق تېرە رەڭ',
    '👩🏾‍🤝‍👩🏻' => 'قول تۇتۇشقان ئاياللار: ئارا توق تېرە رەڭگى and ئاچ تېرە رەڭ',
    '👩🏾‍🤝‍👩🏼' => 'قول تۇتۇشقان ئاياللار: ئارا توق تېرە رەڭگى and ئارا ئاچ تېرە رەڭگى',
    '👩🏾‍🤝‍👩🏽' => 'قول تۇتۇشقان ئاياللار: ئارا توق تېرە رەڭگى and ئارا تېرە رەڭگى',
    '👩🏾‍🤝‍👩🏿' => 'قول تۇتۇشقان ئاياللار: ئارا توق تېرە رەڭگى and توق تېرە رەڭ',
    '👩🏿‍🤝‍👩🏻' => 'قول تۇتۇشقان ئاياللار: توق تېرە رەڭ and ئاچ تېرە رەڭ',
    '👩🏿‍🤝‍👩🏼' => 'قول تۇتۇشقان ئاياللار: توق تېرە رەڭ and ئارا ئاچ تېرە رەڭگى',
    '👩🏿‍🤝‍👩🏽' => 'قول تۇتۇشقان ئاياللار: توق تېرە رەڭ and ئارا تېرە رەڭگى',
    '👩🏿‍🤝‍👩🏾' => 'قول تۇتۇشقان ئاياللار: توق تېرە رەڭ and ئارا توق تېرە رەڭگى',
    '👩🏻‍🤝‍👨🏼' => 'قول تۇتۇشقان ئەر-ئايال: ئاچ تېرە رەڭ and ئارا ئاچ تېرە رەڭگى',
    '👩🏻‍🤝‍👨🏽' => 'قول تۇتۇشقان ئەر-ئايال: ئاچ تېرە رەڭ and ئارا تېرە رەڭگى',
    '👩🏻‍🤝‍👨🏾' => 'قول تۇتۇشقان ئەر-ئايال: ئاچ تېرە رەڭ and ئارا توق تېرە رەڭگى',
    '👩🏻‍🤝‍👨🏿' => 'قول تۇتۇشقان ئەر-ئايال: ئاچ تېرە رەڭ and توق تېرە رەڭ',
    '👩🏼‍🤝‍👨🏻' => 'قول تۇتۇشقان ئەر-ئايال: ئارا ئاچ تېرە رەڭگى and ئاچ تېرە رەڭ',
    '👩🏼‍🤝‍👨🏽' => 'قول تۇتۇشقان ئەر-ئايال: ئارا ئاچ تېرە رەڭگى and ئارا تېرە رەڭگى',
    '👩🏼‍🤝‍👨🏾' => 'قول تۇتۇشقان ئەر-ئايال: ئارا ئاچ تېرە رەڭگى and ئارا توق تېرە رەڭگى',
    '👩🏼‍🤝‍👨🏿' => 'قول تۇتۇشقان ئەر-ئايال: ئارا ئاچ تېرە رەڭگى and توق تېرە رەڭ',
    '👩🏽‍🤝‍👨🏻' => 'قول تۇتۇشقان ئەر-ئايال: ئارا تېرە رەڭگى and ئاچ تېرە رەڭ',
    '👩🏽‍🤝‍👨🏼' => 'قول تۇتۇشقان ئەر-ئايال: ئارا تېرە رەڭگى and ئارا ئاچ تېرە رەڭگى',
    '👩🏽‍🤝‍👨🏾' => 'قول تۇتۇشقان ئەر-ئايال: ئارا تېرە رەڭگى and ئارا توق تېرە رەڭگى',
    '👩🏽‍🤝‍👨🏿' => 'قول تۇتۇشقان ئەر-ئايال: ئارا تېرە رەڭگى and توق تېرە رەڭ',
    '👩🏾‍🤝‍👨🏻' => 'قول تۇتۇشقان ئەر-ئايال: ئارا توق تېرە رەڭگى and ئاچ تېرە رەڭ',
    '👩🏾‍🤝‍👨🏼' => 'قول تۇتۇشقان ئەر-ئايال: ئارا توق تېرە رەڭگى and ئارا ئاچ تېرە رەڭگى',
    '👩🏾‍🤝‍👨🏽' => 'قول تۇتۇشقان ئەر-ئايال: ئارا توق تېرە رەڭگى and ئارا تېرە رەڭگى',
    '👩🏾‍🤝‍👨🏿' => 'قول تۇتۇشقان ئەر-ئايال: ئارا توق تېرە رەڭگى and توق تېرە رەڭ',
    '👩🏿‍🤝‍👨🏻' => 'قول تۇتۇشقان ئەر-ئايال: توق تېرە رەڭ and ئاچ تېرە رەڭ',
    '👩🏿‍🤝‍👨🏼' => 'قول تۇتۇشقان ئەر-ئايال: توق تېرە رەڭ and ئارا ئاچ تېرە رەڭگى',
    '👩🏿‍🤝‍👨🏽' => 'قول تۇتۇشقان ئەر-ئايال: توق تېرە رەڭ and ئارا تېرە رەڭگى',
    '👩🏿‍🤝‍👨🏾' => 'قول تۇتۇشقان ئەر-ئايال: توق تېرە رەڭ and ئارا توق تېرە رەڭگى',
    '👨🏻‍🤝‍👨🏼' => 'قول تۇتۇشقان ئەرلەر: ئاچ تېرە رەڭ and ئارا ئاچ تېرە رەڭگى',
    '👨🏻‍🤝‍👨🏽' => 'قول تۇتۇشقان ئەرلەر: ئاچ تېرە رەڭ and ئارا تېرە رەڭگى',
    '👨🏻‍🤝‍👨🏾' => 'قول تۇتۇشقان ئەرلەر: ئاچ تېرە رەڭ and ئارا توق تېرە رەڭگى',
    '👨🏻‍🤝‍👨🏿' => 'قول تۇتۇشقان ئەرلەر: ئاچ تېرە رەڭ and توق تېرە رەڭ',
    '👨🏼‍🤝‍👨🏻' => 'قول تۇتۇشقان ئەرلەر: ئارا ئاچ تېرە رەڭگى and ئاچ تېرە رەڭ',
    '👨🏼‍🤝‍👨🏽' => 'قول تۇتۇشقان ئەرلەر: ئارا ئاچ تېرە رەڭگى and ئارا تېرە رەڭگى',
    '👨🏼‍🤝‍👨🏾' => 'قول تۇتۇشقان ئەرلەر: ئارا ئاچ تېرە رەڭگى and ئارا توق تېرە رەڭگى',
    '👨🏼‍🤝‍👨🏿' => 'قول تۇتۇشقان ئەرلەر: ئارا ئاچ تېرە رەڭگى and توق تېرە رەڭ',
    '👨🏽‍🤝‍👨🏻' => 'قول تۇتۇشقان ئەرلەر: ئارا تېرە رەڭگى and ئاچ تېرە رەڭ',
    '👨🏽‍🤝‍👨🏼' => 'قول تۇتۇشقان ئەرلەر: ئارا تېرە رەڭگى and ئارا ئاچ تېرە رەڭگى',
    '👨🏽‍🤝‍👨🏾' => 'قول تۇتۇشقان ئەرلەر: ئارا تېرە رەڭگى and ئارا توق تېرە رەڭگى',
    '👨🏽‍🤝‍👨🏿' => 'قول تۇتۇشقان ئەرلەر: ئارا تېرە رەڭگى and توق تېرە رەڭ',
    '👨🏾‍🤝‍👨🏻' => 'قول تۇتۇشقان ئەرلەر: ئارا توق تېرە رەڭگى and ئاچ تېرە رەڭ',
    '👨🏾‍🤝‍👨🏼' => 'قول تۇتۇشقان ئەرلەر: ئارا توق تېرە رەڭگى and ئارا ئاچ تېرە رەڭگى',
    '👨🏾‍🤝‍👨🏽' => 'قول تۇتۇشقان ئەرلەر: ئارا توق تېرە رەڭگى and ئارا تېرە رەڭگى',
    '👨🏾‍🤝‍👨🏿' => 'قول تۇتۇشقان ئەرلەر: ئارا توق تېرە رەڭگى and توق تېرە رەڭ',
    '👨🏿‍🤝‍👨🏻' => 'قول تۇتۇشقان ئەرلەر: توق تېرە رەڭ and ئاچ تېرە رەڭ',
    '👨🏿‍🤝‍👨🏼' => 'قول تۇتۇشقان ئەرلەر: توق تېرە رەڭ and ئارا ئاچ تېرە رەڭگى',
    '👨🏿‍🤝‍👨🏽' => 'قول تۇتۇشقان ئەرلەر: توق تېرە رەڭ and ئارا تېرە رەڭگى',
    '👨🏿‍🤝‍👨🏾' => 'قول تۇتۇشقان ئەرلەر: توق تېرە رەڭ and ئارا توق تېرە رەڭگى',
    '👩‍❤‍💋‍👨' => 'سۆيۈش: ئايال and ئەر',
    '👨‍❤‍💋‍👨' => 'سۆيۈش: ئەر and ئەر',
    '👩‍❤‍💋‍👩' => 'سۆيۈش: ئايال and ئايال',
    '👨‍👩‍👧‍👦' => 'ئائىلە: ئەر, ئايال, قىز, and ئوغۇل',
    '👨‍👩‍👦‍👦' => 'ئائىلە: ئەر, ئايال, ئوغۇل, and ئوغۇل',
    '👨‍👩‍👧‍👧' => 'ئائىلە: ئەر, ئايال, قىز, and قىز',
    '👨‍👨‍👧‍👦' => 'ئائىلە: ئەر, ئەر, قىز, and ئوغۇل',
    '👨‍👨‍👦‍👦' => 'ئائىلە: ئەر, ئەر, ئوغۇل, and ئوغۇل',
    '👨‍👨‍👧‍👧' => 'ئائىلە: ئەر, ئەر, قىز, and قىز',
    '👩‍👩‍👧‍👦' => 'ئائىلە: ئايال, ئايال, قىز, and ئوغۇل',
    '👩‍👩‍👦‍👦' => 'ئائىلە: ئايال, ئايال, ئوغۇل, and ئوغۇل',
    '👩‍👩‍👧‍👧' => 'ئائىلە: ئايال, ئايال, قىز, and قىز',
    '🫱🏻‍🫲🏼' => 'قول قىسىش: ئاچ تېرە رەڭ and ئارا ئاچ تېرە رەڭگى',
    '🫱🏻‍🫲🏽' => 'قول قىسىش: ئاچ تېرە رەڭ and ئارا تېرە رەڭگى',
    '🫱🏻‍🫲🏾' => 'قول قىسىش: ئاچ تېرە رەڭ and ئارا توق تېرە رەڭگى',
    '🫱🏻‍🫲🏿' => 'قول قىسىش: ئاچ تېرە رەڭ and توق تېرە رەڭ',
    '🫱🏼‍🫲🏻' => 'قول قىسىش: ئارا ئاچ تېرە رەڭگى and ئاچ تېرە رەڭ',
    '🫱🏼‍🫲🏽' => 'قول قىسىش: ئارا ئاچ تېرە رەڭگى and ئارا تېرە رەڭگى',
    '🫱🏼‍🫲🏾' => 'قول قىسىش: ئارا ئاچ تېرە رەڭگى and ئارا توق تېرە رەڭگى',
    '🫱🏼‍🫲🏿' => 'قول قىسىش: ئارا ئاچ تېرە رەڭگى and توق تېرە رەڭ',
    '🫱🏽‍🫲🏻' => 'قول قىسىش: ئارا تېرە رەڭگى and ئاچ تېرە رەڭ',
    '🫱🏽‍🫲🏼' => 'قول قىسىش: ئارا تېرە رەڭگى and ئارا ئاچ تېرە رەڭگى',
    '🫱🏽‍🫲🏾' => 'قول قىسىش: ئارا تېرە رەڭگى and ئارا توق تېرە رەڭگى',
    '🫱🏽‍🫲🏿' => 'قول قىسىش: ئارا تېرە رەڭگى and توق تېرە رەڭ',
    '🫱🏾‍🫲🏻' => 'قول قىسىش: ئارا توق تېرە رەڭگى and ئاچ تېرە رەڭ',
    '🫱🏾‍🫲🏼' => 'قول قىسىش: ئارا توق تېرە رەڭگى and ئارا ئاچ تېرە رەڭگى',
    '🫱🏾‍🫲🏽' => 'قول قىسىش: ئارا توق تېرە رەڭگى and ئارا تېرە رەڭگى',
    '🫱🏾‍🫲🏿' => 'قول قىسىش: ئارا توق تېرە رەڭگى and توق تېرە رەڭ',
    '🫱🏿‍🫲🏻' => 'قول قىسىش: توق تېرە رەڭ and ئاچ تېرە رەڭ',
    '🫱🏿‍🫲🏼' => 'قول قىسىش: توق تېرە رەڭ and ئارا ئاچ تېرە رەڭگى',
    '🫱🏿‍🫲🏽' => 'قول قىسىش: توق تېرە رەڭ and ئارا تېرە رەڭگى',
    '🫱🏿‍🫲🏾' => 'قول قىسىش: توق تېرە رەڭ and ئارا توق تېرە رەڭگى',
    '👩‍❤‍👨' => 'يۈرەكلىك جۈپلەر: ئايال and ئەر',
    '👨‍❤‍👨' => 'يۈرەكلىك جۈپلەر: ئەر and ئەر',
    '👩‍❤‍👩' => 'يۈرەكلىك جۈپلەر: ئايال and ئايال',
    '👨‍👩‍👦' => 'ئائىلە: ئەر, ئايال, and ئوغۇل',
    '👨‍👩‍👧' => 'ئائىلە: ئەر, ئايال, and قىز',
    '👨‍👨‍👦' => 'ئائىلە: ئەر, ئەر, and ئوغۇل',
    '👨‍👨‍👧' => 'ئائىلە: ئەر, ئەر, and قىز',
    '👩‍👩‍👦' => 'ئائىلە: ئايال, ئايال, and ئوغۇل',
    '👩‍👩‍👧' => 'ئائىلە: ئايال, ئايال, and قىز',
    '👨‍👦‍👦' => 'ئائىلە: ئەر, ئوغۇل, and ئوغۇل',
    '👨‍👧‍👦' => 'ئائىلە: ئەر, قىز, and ئوغۇل',
    '👨‍👧‍👧' => 'ئائىلە: ئەر, قىز, and قىز',
    '👩‍👦‍👦' => 'ئائىلە: ئايال, ئوغۇل, and ئوغۇل',
    '👩‍👧‍👦' => 'ئائىلە: ئايال, قىز, and ئوغۇل',
    '👩‍👧‍👧' => 'ئائىلە: ئايال, قىز, and قىز',
    '👱🏻‍♂' => 'ئالتۇن چاچ ئەر: ئاچ تېرە رەڭ',
    '👱🏼‍♂' => 'ئالتۇن چاچ ئەر: ئارا ئاچ تېرە رەڭگى',
    '👱🏽‍♂' => 'ئالتۇن چاچ ئەر: ئارا تېرە رەڭگى',
    '👱🏾‍♂' => 'ئالتۇن چاچ ئەر: ئارا توق تېرە رەڭگى',
    '👱🏿‍♂' => 'ئالتۇن چاچ ئەر: توق تېرە رەڭ',
    '👱🏻‍♀' => 'ئالتۇن چاچ ئايال: ئاچ تېرە رەڭ',
    '👱🏼‍♀' => 'ئالتۇن چاچ ئايال: ئارا ئاچ تېرە رەڭگى',
    '👱🏽‍♀' => 'ئالتۇن چاچ ئايال: ئارا تېرە رەڭگى',
    '👱🏾‍♀' => 'ئالتۇن چاچ ئايال: ئارا توق تېرە رەڭگى',
    '👱🏿‍♀' => 'ئالتۇن چاچ ئايال: توق تېرە رەڭ',
    '🙍🏻‍♂' => 'قوشۇمىسىنى تۈرگەن ئەر: ئاچ تېرە رەڭ',
    '🙍🏼‍♂' => 'قوشۇمىسىنى تۈرگەن ئەر: ئارا ئاچ تېرە رەڭگى',
    '🙍🏽‍♂' => 'قوشۇمىسىنى تۈرگەن ئەر: ئارا تېرە رەڭگى',
    '🙍🏾‍♂' => 'قوشۇمىسىنى تۈرگەن ئەر: ئارا توق تېرە رەڭگى',
    '🙍🏿‍♂' => 'قوشۇمىسىنى تۈرگەن ئەر: توق تېرە رەڭ',
    '🙍🏻‍♀' => 'قوشۇمىسىنى تۈرگەن ئايال: ئاچ تېرە رەڭ',
    '🙍🏼‍♀' => 'قوشۇمىسىنى تۈرگەن ئايال: ئارا ئاچ تېرە رەڭگى',
    '🙍🏽‍♀' => 'قوشۇمىسىنى تۈرگەن ئايال: ئارا تېرە رەڭگى',
    '🙍🏾‍♀' => 'قوشۇمىسىنى تۈرگەن ئايال: ئارا توق تېرە رەڭگى',
    '🙍🏿‍♀' => 'قوشۇمىسىنى تۈرگەن ئايال: توق تېرە رەڭ',
    '🙎🏻‍♂' => 'ھومايغان ئەر: ئاچ تېرە رەڭ',
    '🙎🏼‍♂' => 'ھومايغان ئەر: ئارا ئاچ تېرە رەڭگى',
    '🙎🏽‍♂' => 'ھومايغان ئەر: ئارا تېرە رەڭگى',
    '🙎🏾‍♂' => 'ھومايغان ئەر: ئارا توق تېرە رەڭگى',
    '🙎🏿‍♂' => 'ھومايغان ئەر: توق تېرە رەڭ',
    '🙎🏻‍♀' => 'ھومايغان ئايال: ئاچ تېرە رەڭ',
    '🙎🏼‍♀' => 'ھومايغان ئايال: ئارا ئاچ تېرە رەڭگى',
    '🙎🏽‍♀' => 'ھومايغان ئايال: ئارا تېرە رەڭگى',
    '🙎🏾‍♀' => 'ھومايغان ئايال: ئارا توق تېرە رەڭگى',
    '🙎🏿‍♀' => 'ھومايغان ئايال: توق تېرە رەڭ',
    '🙅🏻‍♂' => 'ياق دەپ ئىشارە قىلغان ئەر: ئاچ تېرە رەڭ',
    '🙅🏼‍♂' => 'ياق دەپ ئىشارە قىلغان ئەر: ئارا ئاچ تېرە رەڭگى',
    '🙅🏽‍♂' => 'ياق دەپ ئىشارە قىلغان ئەر: ئارا تېرە رەڭگى',
    '🙅🏾‍♂' => 'ياق دەپ ئىشارە قىلغان ئەر: ئارا توق تېرە رەڭگى',
    '🙅🏿‍♂' => 'ياق دەپ ئىشارە قىلغان ئەر: توق تېرە رەڭ',
    '🙅🏻‍♀' => 'ياق دەپ ئىشارە قىلغان ئايال: ئاچ تېرە رەڭ',
    '🙅🏼‍♀' => 'ياق دەپ ئىشارە قىلغان ئايال: ئارا ئاچ تېرە رەڭگى',
    '🙅🏽‍♀' => 'ياق دەپ ئىشارە قىلغان ئايال: ئارا تېرە رەڭگى',
    '🙅🏾‍♀' => 'ياق دەپ ئىشارە قىلغان ئايال: ئارا توق تېرە رەڭگى',
    '🙅🏿‍♀' => 'ياق دەپ ئىشارە قىلغان ئايال: توق تېرە رەڭ',
    '🙆🏻‍♂' => 'ماقۇل دەپ ئىشارە قىلغان ئەر: ئاچ تېرە رەڭ',
    '🙆🏼‍♂' => 'ماقۇل دەپ ئىشارە قىلغان ئەر: ئارا ئاچ تېرە رەڭگى',
    '🙆🏽‍♂' => 'ماقۇل دەپ ئىشارە قىلغان ئەر: ئارا تېرە رەڭگى',
    '🙆🏾‍♂' => 'ماقۇل دەپ ئىشارە قىلغان ئەر: ئارا توق تېرە رەڭگى',
    '🙆🏿‍♂' => 'ماقۇل دەپ ئىشارە قىلغان ئەر: توق تېرە رەڭ',
    '🙆🏻‍♀' => 'ماقۇل دەپ ئىشارە قىلغان ئايال: ئاچ تېرە رەڭ',
    '🙆🏼‍♀' => 'ماقۇل دەپ ئىشارە قىلغان ئايال: ئارا ئاچ تېرە رەڭگى',
    '🙆🏽‍♀' => 'ماقۇل دەپ ئىشارە قىلغان ئايال: ئارا تېرە رەڭگى',
    '🙆🏾‍♀' => 'ماقۇل دەپ ئىشارە قىلغان ئايال: ئارا توق تېرە رەڭگى',
    '🙆🏿‍♀' => 'ماقۇل دەپ ئىشارە قىلغان ئايال: توق تېرە رەڭ',
    '💁🏻‍♂' => 'تاپان ھەققى بەرگەن ئەر: ئاچ تېرە رەڭ',
    '💁🏼‍♂' => 'تاپان ھەققى بەرگەن ئەر: ئارا ئاچ تېرە رەڭگى',
    '💁🏽‍♂' => 'تاپان ھەققى بەرگەن ئەر: ئارا تېرە رەڭگى',
    '💁🏾‍♂' => 'تاپان ھەققى بەرگەن ئەر: ئارا توق تېرە رەڭگى',
    '💁🏿‍♂' => 'تاپان ھەققى بەرگەن ئەر: توق تېرە رەڭ',
    '💁🏻‍♀' => 'تاپان ھەققى بەرگەن ئايال: ئاچ تېرە رەڭ',
    '💁🏼‍♀' => 'تاپان ھەققى بەرگەن ئايال: ئارا ئاچ تېرە رەڭگى',
    '💁🏽‍♀' => 'تاپان ھەققى بەرگەن ئايال: ئارا تېرە رەڭگى',
    '💁🏾‍♀' => 'تاپان ھەققى بەرگەن ئايال: ئارا توق تېرە رەڭگى',
    '💁🏿‍♀' => 'تاپان ھەققى بەرگەن ئايال: توق تېرە رەڭ',
    '🙋🏻‍♂' => 'قول كۆتۈرگەن ئەر: ئاچ تېرە رەڭ',
    '🙋🏼‍♂' => 'قول كۆتۈرگەن ئەر: ئارا ئاچ تېرە رەڭگى',
    '🙋🏽‍♂' => 'قول كۆتۈرگەن ئەر: ئارا تېرە رەڭگى',
    '🙋🏾‍♂' => 'قول كۆتۈرگەن ئەر: ئارا توق تېرە رەڭگى',
    '🙋🏿‍♂' => 'قول كۆتۈرگەن ئەر: توق تېرە رەڭ',
    '🙋🏻‍♀' => 'قول كۆتۈرگەن ئايال: ئاچ تېرە رەڭ',
    '🙋🏼‍♀' => 'قول كۆتۈرگەن ئايال: ئارا ئاچ تېرە رەڭگى',
    '🙋🏽‍♀' => 'قول كۆتۈرگەن ئايال: ئارا تېرە رەڭگى',
    '🙋🏾‍♀' => 'قول كۆتۈرگەن ئايال: ئارا توق تېرە رەڭگى',
    '🙋🏿‍♀' => 'قول كۆتۈرگەن ئايال: توق تېرە رەڭ',
    '🙇🏻‍♂' => 'ئېگىلگەن ئەر: ئاچ تېرە رەڭ',
    '🙇🏼‍♂' => 'ئېگىلگەن ئەر: ئارا ئاچ تېرە رەڭگى',
    '🙇🏽‍♂' => 'ئېگىلگەن ئەر: ئارا تېرە رەڭگى',
    '🙇🏾‍♂' => 'ئېگىلگەن ئەر: ئارا توق تېرە رەڭگى',
    '🙇🏿‍♂' => 'ئېگىلگەن ئەر: توق تېرە رەڭ',
    '🙇🏻‍♀' => 'ئېگىلگەن ئايال: ئاچ تېرە رەڭ',
    '🙇🏼‍♀' => 'ئېگىلگەن ئايال: ئارا ئاچ تېرە رەڭگى',
    '🙇🏽‍♀' => 'ئېگىلگەن ئايال: ئارا تېرە رەڭگى',
    '🙇🏾‍♀' => 'ئېگىلگەن ئايال: ئارا توق تېرە رەڭگى',
    '🙇🏿‍♀' => 'ئېگىلگەن ئايال: توق تېرە رەڭ',
    '🤦🏻‍♂' => 'يۈزىنى تۇتقان ئەر: ئاچ تېرە رەڭ',
    '🤦🏼‍♂' => 'يۈزىنى تۇتقان ئەر: ئارا ئاچ تېرە رەڭگى',
    '🤦🏽‍♂' => 'يۈزىنى تۇتقان ئەر: ئارا تېرە رەڭگى',
    '🤦🏾‍♂' => 'يۈزىنى تۇتقان ئەر: ئارا توق تېرە رەڭگى',
    '🤦🏿‍♂' => 'يۈزىنى تۇتقان ئەر: توق تېرە رەڭ',
    '🤦🏻‍♀' => 'يۈزىنى تۇتقان ئايال: ئاچ تېرە رەڭ',
    '🤦🏼‍♀' => 'يۈزىنى تۇتقان ئايال: ئارا ئاچ تېرە رەڭگى',
    '🤦🏽‍♀' => 'يۈزىنى تۇتقان ئايال: ئارا تېرە رەڭگى',
    '🤦🏾‍♀' => 'يۈزىنى تۇتقان ئايال: ئارا توق تېرە رەڭگى',
    '🤦🏿‍♀' => 'يۈزىنى تۇتقان ئايال: توق تېرە رەڭ',
    '🤷🏻‍♂' => 'قىسىلغان ئەر: ئاچ تېرە رەڭ',
    '🤷🏼‍♂' => 'قىسىلغان ئەر: ئارا ئاچ تېرە رەڭگى',
    '🤷🏽‍♂' => 'قىسىلغان ئەر: ئارا تېرە رەڭگى',
    '🤷🏾‍♂' => 'قىسىلغان ئەر: ئارا توق تېرە رەڭگى',
    '🤷🏿‍♂' => 'قىسىلغان ئەر: توق تېرە رەڭ',
    '🤷🏻‍♀' => 'قىسىلغان ئايال: ئاچ تېرە رەڭ',
    '🤷🏼‍♀' => 'قىسىلغان ئايال: ئارا ئاچ تېرە رەڭگى',
    '🤷🏽‍♀' => 'قىسىلغان ئايال: ئارا تېرە رەڭگى',
    '🤷🏾‍♀' => 'قىسىلغان ئايال: ئارا توق تېرە رەڭگى',
    '🤷🏿‍♀' => 'قىسىلغان ئايال: توق تېرە رەڭ',
    '👨🏻‍⚕' => 'ساغلاملىق خىزمەتچىسى ئەر: ئاچ تېرە رەڭ',
    '👨🏼‍⚕' => 'ساغلاملىق خىزمەتچىسى ئەر: ئارا ئاچ تېرە رەڭگى',
    '👨🏽‍⚕' => 'ساغلاملىق خىزمەتچىسى ئەر: ئارا تېرە رەڭگى',
    '👨🏾‍⚕' => 'ساغلاملىق خىزمەتچىسى ئەر: ئارا توق تېرە رەڭگى',
    '👨🏿‍⚕' => 'ساغلاملىق خىزمەتچىسى ئەر: توق تېرە رەڭ',
    '👩🏻‍⚕' => 'ساغلاملىق خىزمەتچىسى ئايال: ئاچ تېرە رەڭ',
    '👩🏼‍⚕' => 'ساغلاملىق خىزمەتچىسى ئايال: ئارا ئاچ تېرە رەڭگى',
    '👩🏽‍⚕' => 'ساغلاملىق خىزمەتچىسى ئايال: ئارا تېرە رەڭگى',
    '👩🏾‍⚕' => 'ساغلاملىق خىزمەتچىسى ئايال: ئارا توق تېرە رەڭگى',
    '👩🏿‍⚕' => 'ساغلاملىق خىزمەتچىسى ئايال: توق تېرە رەڭ',
    '👨🏻‍🎓' => 'ئوغۇل ئوقۇغۇچى: ئاچ تېرە رەڭ',
    '👨🏼‍🎓' => 'ئوغۇل ئوقۇغۇچى: ئارا ئاچ تېرە رەڭگى',
    '👨🏽‍🎓' => 'ئوغۇل ئوقۇغۇچى: ئارا تېرە رەڭگى',
    '👨🏾‍🎓' => 'ئوغۇل ئوقۇغۇچى: ئارا توق تېرە رەڭگى',
    '👨🏿‍🎓' => 'ئوغۇل ئوقۇغۇچى: توق تېرە رەڭ',
    '👩🏻‍🎓' => 'قىز ئوقۇغۇچى: ئاچ تېرە رەڭ',
    '👩🏼‍🎓' => 'قىز ئوقۇغۇچى: ئارا ئاچ تېرە رەڭگى',
    '👩🏽‍🎓' => 'قىز ئوقۇغۇچى: ئارا تېرە رەڭگى',
    '👩🏾‍🎓' => 'قىز ئوقۇغۇچى: ئارا توق تېرە رەڭگى',
    '👩🏿‍🎓' => 'قىز ئوقۇغۇچى: توق تېرە رەڭ',
    '👨🏻‍🏫' => 'ئەر ئوقۇتقۇچى: ئاچ تېرە رەڭ',
    '👨🏼‍🏫' => 'ئەر ئوقۇتقۇچى: ئارا ئاچ تېرە رەڭگى',
    '👨🏽‍🏫' => 'ئەر ئوقۇتقۇچى: ئارا تېرە رەڭگى',
    '👨🏾‍🏫' => 'ئەر ئوقۇتقۇچى: ئارا توق تېرە رەڭگى',
    '👨🏿‍🏫' => 'ئەر ئوقۇتقۇچى: توق تېرە رەڭ',
    '👩🏻‍🏫' => 'ئايال ئوقۇتقۇچى: ئاچ تېرە رەڭ',
    '👩🏼‍🏫' => 'ئايال ئوقۇتقۇچى: ئارا ئاچ تېرە رەڭگى',
    '👩🏽‍🏫' => 'ئايال ئوقۇتقۇچى: ئارا تېرە رەڭگى',
    '👩🏾‍🏫' => 'ئايال ئوقۇتقۇچى: ئارا توق تېرە رەڭگى',
    '👩🏿‍🏫' => 'ئايال ئوقۇتقۇچى: توق تېرە رەڭ',
    '👨🏻‍⚖' => 'ئەر سوتچى: ئاچ تېرە رەڭ',
    '👨🏼‍⚖' => 'ئەر سوتچى: ئارا ئاچ تېرە رەڭگى',
    '👨🏽‍⚖' => 'ئەر سوتچى: ئارا تېرە رەڭگى',
    '👨🏾‍⚖' => 'ئەر سوتچى: ئارا توق تېرە رەڭگى',
    '👨🏿‍⚖' => 'ئەر سوتچى: توق تېرە رەڭ',
    '👩🏻‍⚖' => 'ئايال سوتچى: ئاچ تېرە رەڭ',
    '👩🏼‍⚖' => 'ئايال سوتچى: ئارا ئاچ تېرە رەڭگى',
    '👩🏽‍⚖' => 'ئايال سوتچى: ئارا تېرە رەڭگى',
    '👩🏾‍⚖' => 'ئايال سوتچى: ئارا توق تېرە رەڭگى',
    '👩🏿‍⚖' => 'ئايال سوتچى: توق تېرە رەڭ',
    '👨🏻‍🌾' => 'ئەر دېھقان: ئاچ تېرە رەڭ',
    '👨🏼‍🌾' => 'ئەر دېھقان: ئارا ئاچ تېرە رەڭگى',
    '👨🏽‍🌾' => 'ئەر دېھقان: ئارا تېرە رەڭگى',
    '👨🏾‍🌾' => 'ئەر دېھقان: ئارا توق تېرە رەڭگى',
    '👨🏿‍🌾' => 'ئەر دېھقان: توق تېرە رەڭ',
    '👩🏻‍🌾' => 'ئايال دېھقان: ئاچ تېرە رەڭ',
    '👩🏼‍🌾' => 'ئايال دېھقان: ئارا ئاچ تېرە رەڭگى',
    '👩🏽‍🌾' => 'ئايال دېھقان: ئارا تېرە رەڭگى',
    '👩🏾‍🌾' => 'ئايال دېھقان: ئارا توق تېرە رەڭگى',
    '👩🏿‍🌾' => 'ئايال دېھقان: توق تېرە رەڭ',
    '👨🏻‍🍳' => 'ئەر ئاشپەز: ئاچ تېرە رەڭ',
    '👨🏼‍🍳' => 'ئەر ئاشپەز: ئارا ئاچ تېرە رەڭگى',
    '👨🏽‍🍳' => 'ئەر ئاشپەز: ئارا تېرە رەڭگى',
    '👨🏾‍🍳' => 'ئەر ئاشپەز: ئارا توق تېرە رەڭگى',
    '👨🏿‍🍳' => 'ئەر ئاشپەز: توق تېرە رەڭ',
    '👩🏻‍🍳' => 'ئايال ئاشپەز: ئاچ تېرە رەڭ',
    '👩🏼‍🍳' => 'ئايال ئاشپەز: ئارا ئاچ تېرە رەڭگى',
    '👩🏽‍🍳' => 'ئايال ئاشپەز: ئارا تېرە رەڭگى',
    '👩🏾‍🍳' => 'ئايال ئاشپەز: ئارا توق تېرە رەڭگى',
    '👩🏿‍🍳' => 'ئايال ئاشپەز: توق تېرە رەڭ',
    '👨🏻‍🔧' => 'ئەر رېمونتچى: ئاچ تېرە رەڭ',
    '👨🏼‍🔧' => 'ئەر رېمونتچى: ئارا ئاچ تېرە رەڭگى',
    '👨🏽‍🔧' => 'ئەر رېمونتچى: ئارا تېرە رەڭگى',
    '👨🏾‍🔧' => 'ئەر رېمونتچى: ئارا توق تېرە رەڭگى',
    '👨🏿‍🔧' => 'ئەر رېمونتچى: توق تېرە رەڭ',
    '👩🏻‍🔧' => 'ئايال رېمونتچى: ئاچ تېرە رەڭ',
    '👩🏼‍🔧' => 'ئايال رېمونتچى: ئارا ئاچ تېرە رەڭگى',
    '👩🏽‍🔧' => 'ئايال رېمونتچى: ئارا تېرە رەڭگى',
    '👩🏾‍🔧' => 'ئايال رېمونتچى: ئارا توق تېرە رەڭگى',
    '👩🏿‍🔧' => 'ئايال رېمونتچى: توق تېرە رەڭ',
    '👨🏻‍🏭' => 'ئەر زاۋۇت ئىشچىسى: ئاچ تېرە رەڭ',
    '👨🏼‍🏭' => 'ئەر زاۋۇت ئىشچىسى: ئارا ئاچ تېرە رەڭگى',
    '👨🏽‍🏭' => 'ئەر زاۋۇت ئىشچىسى: ئارا تېرە رەڭگى',
    '👨🏾‍🏭' => 'ئەر زاۋۇت ئىشچىسى: ئارا توق تېرە رەڭگى',
    '👨🏿‍🏭' => 'ئەر زاۋۇت ئىشچىسى: توق تېرە رەڭ',
    '👩🏻‍🏭' => 'ئايال زاۋۇت ئىشچىسى: ئاچ تېرە رەڭ',
    '👩🏼‍🏭' => 'ئايال زاۋۇت ئىشچىسى: ئارا ئاچ تېرە رەڭگى',
    '👩🏽‍🏭' => 'ئايال زاۋۇت ئىشچىسى: ئارا تېرە رەڭگى',
    '👩🏾‍🏭' => 'ئايال زاۋۇت ئىشچىسى: ئارا توق تېرە رەڭگى',
    '👩🏿‍🏭' => 'ئايال زاۋۇت ئىشچىسى: توق تېرە رەڭ',
    '👨🏻‍💼' => 'ئىشخانا خىزمەتچىسى ئەر: ئاچ تېرە رەڭ',
    '👨🏼‍💼' => 'ئىشخانا خىزمەتچىسى ئەر: ئارا ئاچ تېرە رەڭگى',
    '👨🏽‍💼' => 'ئىشخانا خىزمەتچىسى ئەر: ئارا تېرە رەڭگى',
    '👨🏾‍💼' => 'ئىشخانا خىزمەتچىسى ئەر: ئارا توق تېرە رەڭگى',
    '👨🏿‍💼' => 'ئىشخانا خىزمەتچىسى ئەر: توق تېرە رەڭ',
    '👩🏻‍💼' => 'ئىشخانا خىزمەتچىسى ئايال: ئاچ تېرە رەڭ',
    '👩🏼‍💼' => 'ئىشخانا خىزمەتچىسى ئايال: ئارا ئاچ تېرە رەڭگى',
    '👩🏽‍💼' => 'ئىشخانا خىزمەتچىسى ئايال: ئارا تېرە رەڭگى',
    '👩🏾‍💼' => 'ئىشخانا خىزمەتچىسى ئايال: ئارا توق تېرە رەڭگى',
    '👩🏿‍💼' => 'ئىشخانا خىزمەتچىسى ئايال: توق تېرە رەڭ',
    '👨🏻‍🔬' => 'ئەر ئالىم: ئاچ تېرە رەڭ',
    '👨🏼‍🔬' => 'ئەر ئالىم: ئارا ئاچ تېرە رەڭگى',
    '👨🏽‍🔬' => 'ئەر ئالىم: ئارا تېرە رەڭگى',
    '👨🏾‍🔬' => 'ئەر ئالىم: ئارا توق تېرە رەڭگى',
    '👨🏿‍🔬' => 'ئەر ئالىم: توق تېرە رەڭ',
    '👩🏻‍🔬' => 'ئايال ئالىم: ئاچ تېرە رەڭ',
    '👩🏼‍🔬' => 'ئايال ئالىم: ئارا ئاچ تېرە رەڭگى',
    '👩🏽‍🔬' => 'ئايال ئالىم: ئارا تېرە رەڭگى',
    '👩🏾‍🔬' => 'ئايال ئالىم: ئارا توق تېرە رەڭگى',
    '👩🏿‍🔬' => 'ئايال ئالىم: توق تېرە رەڭ',
    '👨🏻‍💻' => 'ئەر تېخنىك: ئاچ تېرە رەڭ',
    '👨🏼‍💻' => 'ئەر تېخنىك: ئارا ئاچ تېرە رەڭگى',
    '👨🏽‍💻' => 'ئەر تېخنىك: ئارا تېرە رەڭگى',
    '👨🏾‍💻' => 'ئەر تېخنىك: ئارا توق تېرە رەڭگى',
    '👨🏿‍💻' => 'ئەر تېخنىك: توق تېرە رەڭ',
    '👩🏻‍💻' => 'ئايال تېخنىك: ئاچ تېرە رەڭ',
    '👩🏼‍💻' => 'ئايال تېخنىك: ئارا ئاچ تېرە رەڭگى',
    '👩🏽‍💻' => 'ئايال تېخنىك: ئارا تېرە رەڭگى',
    '👩🏾‍💻' => 'ئايال تېخنىك: ئارا توق تېرە رەڭگى',
    '👩🏿‍💻' => 'ئايال تېخنىك: توق تېرە رەڭ',
    '👨🏻‍🎤' => 'ئەر ناخشىچى: ئاچ تېرە رەڭ',
    '👨🏼‍🎤' => 'ئەر ناخشىچى: ئارا ئاچ تېرە رەڭگى',
    '👨🏽‍🎤' => 'ئەر ناخشىچى: ئارا تېرە رەڭگى',
    '👨🏾‍🎤' => 'ئەر ناخشىچى: ئارا توق تېرە رەڭگى',
    '👨🏿‍🎤' => 'ئەر ناخشىچى: توق تېرە رەڭ',
    '👩🏻‍🎤' => 'ئايال ناخشىچى: ئاچ تېرە رەڭ',
    '👩🏼‍🎤' => 'ئايال ناخشىچى: ئارا ئاچ تېرە رەڭگى',
    '👩🏽‍🎤' => 'ئايال ناخشىچى: ئارا تېرە رەڭگى',
    '👩🏾‍🎤' => 'ئايال ناخشىچى: ئارا توق تېرە رەڭگى',
    '👩🏿‍🎤' => 'ئايال ناخشىچى: توق تېرە رەڭ',
    '👨🏻‍🎨' => 'ئەر سەنئەتكار: ئاچ تېرە رەڭ',
    '👨🏼‍🎨' => 'ئەر سەنئەتكار: ئارا ئاچ تېرە رەڭگى',
    '👨🏽‍🎨' => 'ئەر سەنئەتكار: ئارا تېرە رەڭگى',
    '👨🏾‍🎨' => 'ئەر سەنئەتكار: ئارا توق تېرە رەڭگى',
    '👨🏿‍🎨' => 'ئەر سەنئەتكار: توق تېرە رەڭ',
    '👩🏻‍🎨' => 'ئايال سەنئەتكار: ئاچ تېرە رەڭ',
    '👩🏼‍🎨' => 'ئايال سەنئەتكار: ئارا ئاچ تېرە رەڭگى',
    '👩🏽‍🎨' => 'ئايال سەنئەتكار: ئارا تېرە رەڭگى',
    '👩🏾‍🎨' => 'ئايال سەنئەتكار: ئارا توق تېرە رەڭگى',
    '👩🏿‍🎨' => 'ئايال سەنئەتكار: توق تېرە رەڭ',
    '👨🏻‍✈' => 'ئەر ئۇچقۇچى: ئاچ تېرە رەڭ',
    '👨🏼‍✈' => 'ئەر ئۇچقۇچى: ئارا ئاچ تېرە رەڭگى',
    '👨🏽‍✈' => 'ئەر ئۇچقۇچى: ئارا تېرە رەڭگى',
    '👨🏾‍✈' => 'ئەر ئۇچقۇچى: ئارا توق تېرە رەڭگى',
    '👨🏿‍✈' => 'ئەر ئۇچقۇچى: توق تېرە رەڭ',
    '👩🏻‍✈' => 'ئايال ئۇچقۇچى: ئاچ تېرە رەڭ',
    '👩🏼‍✈' => 'ئايال ئۇچقۇچى: ئارا ئاچ تېرە رەڭگى',
    '👩🏽‍✈' => 'ئايال ئۇچقۇچى: ئارا تېرە رەڭگى',
    '👩🏾‍✈' => 'ئايال ئۇچقۇچى: ئارا توق تېرە رەڭگى',
    '👩🏿‍✈' => 'ئايال ئۇچقۇچى: توق تېرە رەڭ',
    '👨🏻‍🚀' => 'ئەر ئالەم ئۇچقۇچىسى: ئاچ تېرە رەڭ',
    '👨🏼‍🚀' => 'ئەر ئالەم ئۇچقۇچىسى: ئارا ئاچ تېرە رەڭگى',
    '👨🏽‍🚀' => 'ئەر ئالەم ئۇچقۇچىسى: ئارا تېرە رەڭگى',
    '👨🏾‍🚀' => 'ئەر ئالەم ئۇچقۇچىسى: ئارا توق تېرە رەڭگى',
    '👨🏿‍🚀' => 'ئەر ئالەم ئۇچقۇچىسى: توق تېرە رەڭ',
    '👩🏻‍🚀' => 'ئالەم ئۇچقۇچىسى ئايال: ئاچ تېرە رەڭ',
    '👩🏼‍🚀' => 'ئالەم ئۇچقۇچىسى ئايال: ئارا ئاچ تېرە رەڭگى',
    '👩🏽‍🚀' => 'ئالەم ئۇچقۇچىسى ئايال: ئارا تېرە رەڭگى',
    '👩🏾‍🚀' => 'ئالەم ئۇچقۇچىسى ئايال: ئارا توق تېرە رەڭگى',
    '👩🏿‍🚀' => 'ئالەم ئۇچقۇچىسى ئايال: توق تېرە رەڭ',
    '👨🏻‍🚒' => 'ئوت ئۆچۈرگۈچى ئەر: ئاچ تېرە رەڭ',
    '👨🏼‍🚒' => 'ئوت ئۆچۈرگۈچى ئەر: ئارا ئاچ تېرە رەڭگى',
    '👨🏽‍🚒' => 'ئوت ئۆچۈرگۈچى ئەر: ئارا تېرە رەڭگى',
    '👨🏾‍🚒' => 'ئوت ئۆچۈرگۈچى ئەر: ئارا توق تېرە رەڭگى',
    '👨🏿‍🚒' => 'ئوت ئۆچۈرگۈچى ئەر: توق تېرە رەڭ',
    '👩🏻‍🚒' => 'ئايال ئوت ئۆچۈرگۈچى: ئاچ تېرە رەڭ',
    '👩🏼‍🚒' => 'ئايال ئوت ئۆچۈرگۈچى: ئارا ئاچ تېرە رەڭگى',
    '👩🏽‍🚒' => 'ئايال ئوت ئۆچۈرگۈچى: ئارا تېرە رەڭگى',
    '👩🏾‍🚒' => 'ئايال ئوت ئۆچۈرگۈچى: ئارا توق تېرە رەڭگى',
    '👩🏿‍🚒' => 'ئايال ئوت ئۆچۈرگۈچى: توق تېرە رەڭ',
    '👮🏻‍♂' => 'ئەر ساقچى: ئاچ تېرە رەڭ',
    '👮🏼‍♂' => 'ئەر ساقچى: ئارا ئاچ تېرە رەڭگى',
    '👮🏽‍♂' => 'ئەر ساقچى: ئارا تېرە رەڭگى',
    '👮🏾‍♂' => 'ئەر ساقچى: ئارا توق تېرە رەڭگى',
    '👮🏿‍♂' => 'ئەر ساقچى: توق تېرە رەڭ',
    '👮🏻‍♀' => 'ئايال ساقچى: ئاچ تېرە رەڭ',
    '👮🏼‍♀' => 'ئايال ساقچى: ئارا ئاچ تېرە رەڭگى',
    '👮🏽‍♀' => 'ئايال ساقچى: ئارا تېرە رەڭگى',
    '👮🏾‍♀' => 'ئايال ساقچى: ئارا توق تېرە رەڭگى',
    '👮🏿‍♀' => 'ئايال ساقچى: توق تېرە رەڭ',
    '🕵🏻‍♂' => 'ئەر رازۋېدچىك: ئاچ تېرە رەڭ',
    '🕵🏼‍♂' => 'ئەر رازۋېدچىك: ئارا ئاچ تېرە رەڭگى',
    '🕵🏽‍♂' => 'ئەر رازۋېدچىك: ئارا تېرە رەڭگى',
    '🕵🏾‍♂' => 'ئەر رازۋېدچىك: ئارا توق تېرە رەڭگى',
    '🕵🏿‍♂' => 'ئەر رازۋېدچىك: توق تېرە رەڭ',
    '🕵🏻‍♀' => 'ئايال رازۋېدچىك: ئاچ تېرە رەڭ',
    '🕵🏼‍♀' => 'ئايال رازۋېدچىك: ئارا ئاچ تېرە رەڭگى',
    '🕵🏽‍♀' => 'ئايال رازۋېدچىك: ئارا تېرە رەڭگى',
    '🕵🏾‍♀' => 'ئايال رازۋېدچىك: ئارا توق تېرە رەڭگى',
    '🕵🏿‍♀' => 'ئايال رازۋېدچىك: توق تېرە رەڭ',
    '💂🏻‍♂' => 'ئەر قاراۋۇل: ئاچ تېرە رەڭ',
    '💂🏼‍♂' => 'ئەر قاراۋۇل: ئارا ئاچ تېرە رەڭگى',
    '💂🏽‍♂' => 'ئەر قاراۋۇل: ئارا تېرە رەڭگى',
    '💂🏾‍♂' => 'ئەر قاراۋۇل: ئارا توق تېرە رەڭگى',
    '💂🏿‍♂' => 'ئەر قاراۋۇل: توق تېرە رەڭ',
    '💂🏻‍♀' => 'ئايال قاراۋۇل: ئاچ تېرە رەڭ',
    '💂🏼‍♀' => 'ئايال قاراۋۇل: ئارا ئاچ تېرە رەڭگى',
    '💂🏽‍♀' => 'ئايال قاراۋۇل: ئارا تېرە رەڭگى',
    '💂🏾‍♀' => 'ئايال قاراۋۇل: ئارا توق تېرە رەڭگى',
    '💂🏿‍♀' => 'ئايال قاراۋۇل: توق تېرە رەڭ',
    '👷🏻‍♂' => 'قۇرۇلۇش ئىشچىسى ئەر: ئاچ تېرە رەڭ',
    '👷🏼‍♂' => 'قۇرۇلۇش ئىشچىسى ئەر: ئارا ئاچ تېرە رەڭگى',
    '👷🏽‍♂' => 'قۇرۇلۇش ئىشچىسى ئەر: ئارا تېرە رەڭگى',
    '👷🏾‍♂' => 'قۇرۇلۇش ئىشچىسى ئەر: ئارا توق تېرە رەڭگى',
    '👷🏿‍♂' => 'قۇرۇلۇش ئىشچىسى ئەر: توق تېرە رەڭ',
    '👷🏻‍♀' => 'قۇرۇلۇش ئىشچىسى ئايال: ئاچ تېرە رەڭ',
    '👷🏼‍♀' => 'قۇرۇلۇش ئىشچىسى ئايال: ئارا ئاچ تېرە رەڭگى',
    '👷🏽‍♀' => 'قۇرۇلۇش ئىشچىسى ئايال: ئارا تېرە رەڭگى',
    '👷🏾‍♀' => 'قۇرۇلۇش ئىشچىسى ئايال: ئارا توق تېرە رەڭگى',
    '👷🏿‍♀' => 'قۇرۇلۇش ئىشچىسى ئايال: توق تېرە رەڭ',
    '👳🏻‍♂' => 'سەللىلىك ئەر: ئاچ تېرە رەڭ',
    '👳🏼‍♂' => 'سەللىلىك ئەر: ئارا ئاچ تېرە رەڭگى',
    '👳🏽‍♂' => 'سەللىلىك ئەر: ئارا تېرە رەڭگى',
    '👳🏾‍♂' => 'سەللىلىك ئەر: ئارا توق تېرە رەڭگى',
    '👳🏿‍♂' => 'سەللىلىك ئەر: توق تېرە رەڭ',
    '👳🏻‍♀' => 'سەللىلىك ئايال: ئاچ تېرە رەڭ',
    '👳🏼‍♀' => 'سەللىلىك ئايال: ئارا ئاچ تېرە رەڭگى',
    '👳🏽‍♀' => 'سەللىلىك ئايال: ئارا تېرە رەڭگى',
    '👳🏾‍♀' => 'سەللىلىك ئايال: ئارا توق تېرە رەڭگى',
    '👳🏿‍♀' => 'سەللىلىك ئايال: توق تېرە رەڭ',
    '🧙🏻‍♂' => 'ئەر سېھرىگەر: ئاچ تېرە رەڭ',
    '🧙🏼‍♂' => 'ئەر سېھرىگەر: ئارا ئاچ تېرە رەڭگى',
    '🧙🏽‍♂' => 'ئەر سېھرىگەر: ئارا تېرە رەڭگى',
    '🧙🏾‍♂' => 'ئەر سېھرىگەر: ئارا توق تېرە رەڭگى',
    '🧙🏿‍♂' => 'ئەر سېھرىگەر: توق تېرە رەڭ',
    '🧙🏻‍♀' => 'ئايال سېھرىگەر: ئاچ تېرە رەڭ',
    '🧙🏼‍♀' => 'ئايال سېھرىگەر: ئارا ئاچ تېرە رەڭگى',
    '🧙🏽‍♀' => 'ئايال سېھرىگەر: ئارا تېرە رەڭگى',
    '🧙🏾‍♀' => 'ئايال سېھرىگەر: ئارا توق تېرە رەڭگى',
    '🧙🏿‍♀' => 'ئايال سېھرىگەر: توق تېرە رەڭ',
    '🧚🏻‍♂' => 'ئەر ئەرۋاھ: ئاچ تېرە رەڭ',
    '🧚🏼‍♂' => 'ئەر ئەرۋاھ: ئارا ئاچ تېرە رەڭگى',
    '🧚🏽‍♂' => 'ئەر ئەرۋاھ: ئارا تېرە رەڭگى',
    '🧚🏾‍♂' => 'ئەر ئەرۋاھ: ئارا توق تېرە رەڭگى',
    '🧚🏿‍♂' => 'ئەر ئەرۋاھ: توق تېرە رەڭ',
    '🧚🏻‍♀' => 'ئايال ئەرۋاھ: ئاچ تېرە رەڭ',
    '🧚🏼‍♀' => 'ئايال ئەرۋاھ: ئارا ئاچ تېرە رەڭگى',
    '🧚🏽‍♀' => 'ئايال ئەرۋاھ: ئارا تېرە رەڭگى',
    '🧚🏾‍♀' => 'ئايال ئەرۋاھ: ئارا توق تېرە رەڭگى',
    '🧚🏿‍♀' => 'ئايال ئەرۋاھ: توق تېرە رەڭ',
    '🧛🏻‍♂' => 'ئەر مۇردا: ئاچ تېرە رەڭ',
    '🧛🏼‍♂' => 'ئەر مۇردا: ئارا ئاچ تېرە رەڭگى',
    '🧛🏽‍♂' => 'ئەر مۇردا: ئارا تېرە رەڭگى',
    '🧛🏾‍♂' => 'ئەر مۇردا: ئارا توق تېرە رەڭگى',
    '🧛🏿‍♂' => 'ئەر مۇردا: توق تېرە رەڭ',
    '🧛🏻‍♀' => 'ئايال مۇردا: ئاچ تېرە رەڭ',
    '🧛🏼‍♀' => 'ئايال مۇردا: ئارا ئاچ تېرە رەڭگى',
    '🧛🏽‍♀' => 'ئايال مۇردا: ئارا تېرە رەڭگى',
    '🧛🏾‍♀' => 'ئايال مۇردا: ئارا توق تېرە رەڭگى',
    '🧛🏿‍♀' => 'ئايال مۇردا: توق تېرە رەڭ',
    '🧜🏻‍♂' => 'بېلىق ئەر: ئاچ تېرە رەڭ',
    '🧜🏼‍♂' => 'بېلىق ئەر: ئارا ئاچ تېرە رەڭگى',
    '🧜🏽‍♂' => 'بېلىق ئەر: ئارا تېرە رەڭگى',
    '🧜🏾‍♂' => 'بېلىق ئەر: ئارا توق تېرە رەڭگى',
    '🧜🏿‍♂' => 'بېلىق ئەر: توق تېرە رەڭ',
    '🧜🏻‍♀' => 'بېلىق قىز: ئاچ تېرە رەڭ',
    '🧜🏼‍♀' => 'بېلىق قىز: ئارا ئاچ تېرە رەڭگى',
    '🧜🏽‍♀' => 'بېلىق قىز: ئارا تېرە رەڭگى',
    '🧜🏾‍♀' => 'بېلىق قىز: ئارا توق تېرە رەڭگى',
    '🧜🏿‍♀' => 'بېلىق قىز: توق تېرە رەڭ',
    '🧝🏻‍♂' => 'ئەر پىر: ئاچ تېرە رەڭ',
    '🧝🏼‍♂' => 'ئەر پىر: ئارا ئاچ تېرە رەڭگى',
    '🧝🏽‍♂' => 'ئەر پىر: ئارا تېرە رەڭگى',
    '🧝🏾‍♂' => 'ئەر پىر: ئارا توق تېرە رەڭگى',
    '🧝🏿‍♂' => 'ئەر پىر: توق تېرە رەڭ',
    '🧝🏻‍♀' => 'ئايال پىر: ئاچ تېرە رەڭ',
    '🧝🏼‍♀' => 'ئايال پىر: ئارا ئاچ تېرە رەڭگى',
    '🧝🏽‍♀' => 'ئايال پىر: ئارا تېرە رەڭگى',
    '🧝🏾‍♀' => 'ئايال پىر: ئارا توق تېرە رەڭگى',
    '🧝🏿‍♀' => 'ئايال پىر: توق تېرە رەڭ',
    '💆🏻‍♂' => 'ئۇۋىلانغان ئەر: ئاچ تېرە رەڭ',
    '💆🏼‍♂' => 'ئۇۋىلانغان ئەر: ئارا ئاچ تېرە رەڭگى',
    '💆🏽‍♂' => 'ئۇۋىلانغان ئەر: ئارا تېرە رەڭگى',
    '💆🏾‍♂' => 'ئۇۋىلانغان ئەر: ئارا توق تېرە رەڭگى',
    '💆🏿‍♂' => 'ئۇۋىلانغان ئەر: توق تېرە رەڭ',
    '💆🏻‍♀' => 'ئۇۋىلانغان ئايال: ئاچ تېرە رەڭ',
    '💆🏼‍♀' => 'ئۇۋىلانغان ئايال: ئارا ئاچ تېرە رەڭگى',
    '💆🏽‍♀' => 'ئۇۋىلانغان ئايال: ئارا تېرە رەڭگى',
    '💆🏾‍♀' => 'ئۇۋىلانغان ئايال: ئارا توق تېرە رەڭگى',
    '💆🏿‍♀' => 'ئۇۋىلانغان ئايال: توق تېرە رەڭ',
    '💇🏻‍♂' => 'چاچ ياساتقان ئەر: ئاچ تېرە رەڭ',
    '💇🏼‍♂' => 'چاچ ياساتقان ئەر: ئارا ئاچ تېرە رەڭگى',
    '💇🏽‍♂' => 'چاچ ياساتقان ئەر: ئارا تېرە رەڭگى',
    '💇🏾‍♂' => 'چاچ ياساتقان ئەر: ئارا توق تېرە رەڭگى',
    '💇🏿‍♂' => 'چاچ ياساتقان ئەر: توق تېرە رەڭ',
    '💇🏻‍♀' => 'چاچ ياساتقان ئايال: ئاچ تېرە رەڭ',
    '💇🏼‍♀' => 'چاچ ياساتقان ئايال: ئارا ئاچ تېرە رەڭگى',
    '💇🏽‍♀' => 'چاچ ياساتقان ئايال: ئارا تېرە رەڭگى',
    '💇🏾‍♀' => 'چاچ ياساتقان ئايال: ئارا توق تېرە رەڭگى',
    '💇🏿‍♀' => 'چاچ ياساتقان ئايال: توق تېرە رەڭ',
    '🚶🏻‍♂' => 'ماڭغان ئەر: ئاچ تېرە رەڭ',
    '🚶🏼‍♂' => 'ماڭغان ئەر: ئارا ئاچ تېرە رەڭگى',
    '🚶🏽‍♂' => 'ماڭغان ئەر: ئارا تېرە رەڭگى',
    '🚶🏾‍♂' => 'ماڭغان ئەر: ئارا توق تېرە رەڭگى',
    '🚶🏿‍♂' => 'ماڭغان ئەر: توق تېرە رەڭ',
    '🚶🏻‍♀' => 'ماڭغان ئايال: ئاچ تېرە رەڭ',
    '🚶🏼‍♀' => 'ماڭغان ئايال: ئارا ئاچ تېرە رەڭگى',
    '🚶🏽‍♀' => 'ماڭغان ئايال: ئارا تېرە رەڭگى',
    '🚶🏾‍♀' => 'ماڭغان ئايال: ئارا توق تېرە رەڭگى',
    '🚶🏿‍♀' => 'ماڭغان ئايال: توق تېرە رەڭ',
    '🏃🏻‍♂' => 'يۈگۈرگەن ئەر: ئاچ تېرە رەڭ',
    '🏃🏼‍♂' => 'يۈگۈرگەن ئەر: ئارا ئاچ تېرە رەڭگى',
    '🏃🏽‍♂' => 'يۈگۈرگەن ئەر: ئارا تېرە رەڭگى',
    '🏃🏾‍♂' => 'يۈگۈرگەن ئەر: ئارا توق تېرە رەڭگى',
    '🏃🏿‍♂' => 'يۈگۈرگەن ئەر: توق تېرە رەڭ',
    '🏃🏻‍♀' => 'يۈگۈرگەن ئايال: ئاچ تېرە رەڭ',
    '🏃🏼‍♀' => 'يۈگۈرگەن ئايال: ئارا ئاچ تېرە رەڭگى',
    '🏃🏽‍♀' => 'يۈگۈرگەن ئايال: ئارا تېرە رەڭگى',
    '🏃🏾‍♀' => 'يۈگۈرگەن ئايال: ئارا توق تېرە رەڭگى',
    '🏃🏿‍♀' => 'يۈگۈرگەن ئايال: توق تېرە رەڭ',
    '👯🏻‍♀' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئايال: ئاچ تېرە رەڭ',
    '👯🏼‍♀' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئايال: ئارا ئاچ تېرە رەڭگى',
    '👯🏽‍♀' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئايال: ئارا تېرە رەڭگى',
    '👯🏾‍♀' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئايال: ئارا توق تېرە رەڭگى',
    '👯🏿‍♀' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئايال: توق تېرە رەڭ',
    '👯🏻‍♂' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئەر: ئاچ تېرە رەڭ',
    '👯🏼‍♂' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئەر: ئارا ئاچ تېرە رەڭگى',
    '👯🏽‍♂' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئەر: ئارا تېرە رەڭگى',
    '👯🏾‍♂' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئەر: ئارا توق تېرە رەڭگى',
    '👯🏿‍♂' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئەر: توق تېرە رەڭ',
    '🧖🏻‍♂' => 'ھورداقتىكى ئەر: ئاچ تېرە رەڭ',
    '🧖🏼‍♂' => 'ھورداقتىكى ئەر: ئارا ئاچ تېرە رەڭگى',
    '🧖🏽‍♂' => 'ھورداقتىكى ئەر: ئارا تېرە رەڭگى',
    '🧖🏾‍♂' => 'ھورداقتىكى ئەر: ئارا توق تېرە رەڭگى',
    '🧖🏿‍♂' => 'ھورداقتىكى ئەر: توق تېرە رەڭ',
    '🧖🏻‍♀' => 'ھورداقتىكى ئايال: ئاچ تېرە رەڭ',
    '🧖🏼‍♀' => 'ھورداقتىكى ئايال: ئارا ئاچ تېرە رەڭگى',
    '🧖🏽‍♀' => 'ھورداقتىكى ئايال: ئارا تېرە رەڭگى',
    '🧖🏾‍♀' => 'ھورداقتىكى ئايال: ئارا توق تېرە رەڭگى',
    '🧖🏿‍♀' => 'ھورداقتىكى ئايال: توق تېرە رەڭ',
    '🧗🏻‍♂' => 'ياماشقان ئەر: ئاچ تېرە رەڭ',
    '🧗🏼‍♂' => 'ياماشقان ئەر: ئارا ئاچ تېرە رەڭگى',
    '🧗🏽‍♂' => 'ياماشقان ئەر: ئارا تېرە رەڭگى',
    '🧗🏾‍♂' => 'ياماشقان ئەر: ئارا توق تېرە رەڭگى',
    '🧗🏿‍♂' => 'ياماشقان ئەر: توق تېرە رەڭ',
    '🧗🏻‍♀' => 'ياماشقان ئايال: ئاچ تېرە رەڭ',
    '🧗🏼‍♀' => 'ياماشقان ئايال: ئارا ئاچ تېرە رەڭگى',
    '🧗🏽‍♀' => 'ياماشقان ئايال: ئارا تېرە رەڭگى',
    '🧗🏾‍♀' => 'ياماشقان ئايال: ئارا توق تېرە رەڭگى',
    '🧗🏿‍♀' => 'ياماشقان ئايال: توق تېرە رەڭ',
    '🏌🏻‍♂' => 'گولفچى ئەر: ئاچ تېرە رەڭ',
    '🏌🏼‍♂' => 'گولفچى ئەر: ئارا ئاچ تېرە رەڭگى',
    '🏌🏽‍♂' => 'گولفچى ئەر: ئارا تېرە رەڭگى',
    '🏌🏾‍♂' => 'گولفچى ئەر: ئارا توق تېرە رەڭگى',
    '🏌🏿‍♂' => 'گولفچى ئەر: توق تېرە رەڭ',
    '🏌🏻‍♀' => 'گولفچى ئايال: ئاچ تېرە رەڭ',
    '🏌🏼‍♀' => 'گولفچى ئايال: ئارا ئاچ تېرە رەڭگى',
    '🏌🏽‍♀' => 'گولفچى ئايال: ئارا تېرە رەڭگى',
    '🏌🏾‍♀' => 'گولفچى ئايال: ئارا توق تېرە رەڭگى',
    '🏌🏿‍♀' => 'گولفچى ئايال: توق تېرە رەڭ',
    '🏄🏻‍♂' => 'دولقۇن كەزگۈچى ئەر: ئاچ تېرە رەڭ',
    '🏄🏼‍♂' => 'دولقۇن كەزگۈچى ئەر: ئارا ئاچ تېرە رەڭگى',
    '🏄🏽‍♂' => 'دولقۇن كەزگۈچى ئەر: ئارا تېرە رەڭگى',
    '🏄🏾‍♂' => 'دولقۇن كەزگۈچى ئەر: ئارا توق تېرە رەڭگى',
    '🏄🏿‍♂' => 'دولقۇن كەزگۈچى ئەر: توق تېرە رەڭ',
    '🏄🏻‍♀' => 'دولقۇن كەزگۈچى ئايال: ئاچ تېرە رەڭ',
    '🏄🏼‍♀' => 'دولقۇن كەزگۈچى ئايال: ئارا ئاچ تېرە رەڭگى',
    '🏄🏽‍♀' => 'دولقۇن كەزگۈچى ئايال: ئارا تېرە رەڭگى',
    '🏄🏾‍♀' => 'دولقۇن كەزگۈچى ئايال: ئارا توق تېرە رەڭگى',
    '🏄🏿‍♀' => 'دولقۇن كەزگۈچى ئايال: توق تېرە رەڭ',
    '🚣🏻‍♂' => 'قېيىقچى ئەر: ئاچ تېرە رەڭ',
    '🚣🏼‍♂' => 'قېيىقچى ئەر: ئارا ئاچ تېرە رەڭگى',
    '🚣🏽‍♂' => 'قېيىقچى ئەر: ئارا تېرە رەڭگى',
    '🚣🏾‍♂' => 'قېيىقچى ئەر: ئارا توق تېرە رەڭگى',
    '🚣🏿‍♂' => 'قېيىقچى ئەر: توق تېرە رەڭ',
    '🚣🏻‍♀' => 'قېيىقچى ئايال: ئاچ تېرە رەڭ',
    '🚣🏼‍♀' => 'قېيىقچى ئايال: ئارا ئاچ تېرە رەڭگى',
    '🚣🏽‍♀' => 'قېيىقچى ئايال: ئارا تېرە رەڭگى',
    '🚣🏾‍♀' => 'قېيىقچى ئايال: ئارا توق تېرە رەڭگى',
    '🚣🏿‍♀' => 'قېيىقچى ئايال: توق تېرە رەڭ',
    '🏊🏻‍♂' => 'ئۈزۈۋاتقان ئەر: ئاچ تېرە رەڭ',
    '🏊🏼‍♂' => 'ئۈزۈۋاتقان ئەر: ئارا ئاچ تېرە رەڭگى',
    '🏊🏽‍♂' => 'ئۈزۈۋاتقان ئەر: ئارا تېرە رەڭگى',
    '🏊🏾‍♂' => 'ئۈزۈۋاتقان ئەر: ئارا توق تېرە رەڭگى',
    '🏊🏿‍♂' => 'ئۈزۈۋاتقان ئەر: توق تېرە رەڭ',
    '🏊🏻‍♀' => 'ئۈزۈۋاتقان ئايال: ئاچ تېرە رەڭ',
    '🏊🏼‍♀' => 'ئۈزۈۋاتقان ئايال: ئارا ئاچ تېرە رەڭگى',
    '🏊🏽‍♀' => 'ئۈزۈۋاتقان ئايال: ئارا تېرە رەڭگى',
    '🏊🏾‍♀' => 'ئۈزۈۋاتقان ئايال: ئارا توق تېرە رەڭگى',
    '🏊🏿‍♀' => 'ئۈزۈۋاتقان ئايال: توق تېرە رەڭ',
    '⛹🏻‍♂' => 'توپ ئويناۋاتقان ئەر: ئاچ تېرە رەڭ',
    '⛹🏼‍♂' => 'توپ ئويناۋاتقان ئەر: ئارا ئاچ تېرە رەڭگى',
    '⛹🏽‍♂' => 'توپ ئويناۋاتقان ئەر: ئارا تېرە رەڭگى',
    '⛹🏾‍♂' => 'توپ ئويناۋاتقان ئەر: ئارا توق تېرە رەڭگى',
    '⛹🏿‍♂' => 'توپ ئويناۋاتقان ئەر: توق تېرە رەڭ',
    '⛹🏻‍♀' => 'توپ ئويناۋاتقان ئايال: ئاچ تېرە رەڭ',
    '⛹🏼‍♀' => 'توپ ئويناۋاتقان ئايال: ئارا ئاچ تېرە رەڭگى',
    '⛹🏽‍♀' => 'توپ ئويناۋاتقان ئايال: ئارا تېرە رەڭگى',
    '⛹🏾‍♀' => 'توپ ئويناۋاتقان ئايال: ئارا توق تېرە رەڭگى',
    '⛹🏿‍♀' => 'توپ ئويناۋاتقان ئايال: توق تېرە رەڭ',
    '🏋🏻‍♂' => 'ئېغىرلىق كۆتۈرگۈچى ئەر: ئاچ تېرە رەڭ',
    '🏋🏼‍♂' => 'ئېغىرلىق كۆتۈرگۈچى ئەر: ئارا ئاچ تېرە رەڭگى',
    '🏋🏽‍♂' => 'ئېغىرلىق كۆتۈرگۈچى ئەر: ئارا تېرە رەڭگى',
    '🏋🏾‍♂' => 'ئېغىرلىق كۆتۈرگۈچى ئەر: ئارا توق تېرە رەڭگى',
    '🏋🏿‍♂' => 'ئېغىرلىق كۆتۈرگۈچى ئەر: توق تېرە رەڭ',
    '🏋🏻‍♀' => 'ئېغىرلىق كۆتۈرگۈچى ئايال: ئاچ تېرە رەڭ',
    '🏋🏼‍♀' => 'ئېغىرلىق كۆتۈرگۈچى ئايال: ئارا ئاچ تېرە رەڭگى',
    '🏋🏽‍♀' => 'ئېغىرلىق كۆتۈرگۈچى ئايال: ئارا تېرە رەڭگى',
    '🏋🏾‍♀' => 'ئېغىرلىق كۆتۈرگۈچى ئايال: ئارا توق تېرە رەڭگى',
    '🏋🏿‍♀' => 'ئېغىرلىق كۆتۈرگۈچى ئايال: توق تېرە رەڭ',
    '🚴🏻‍♂' => 'ۋېلىسىپىتلىك ئەر: ئاچ تېرە رەڭ',
    '🚴🏼‍♂' => 'ۋېلىسىپىتلىك ئەر: ئارا ئاچ تېرە رەڭگى',
    '🚴🏽‍♂' => 'ۋېلىسىپىتلىك ئەر: ئارا تېرە رەڭگى',
    '🚴🏾‍♂' => 'ۋېلىسىپىتلىك ئەر: ئارا توق تېرە رەڭگى',
    '🚴🏿‍♂' => 'ۋېلىسىپىتلىك ئەر: توق تېرە رەڭ',
    '🚴🏻‍♀' => 'ۋېلىسىپىتلىك ئايال: ئاچ تېرە رەڭ',
    '🚴🏼‍♀' => 'ۋېلىسىپىتلىك ئايال: ئارا ئاچ تېرە رەڭگى',
    '🚴🏽‍♀' => 'ۋېلىسىپىتلىك ئايال: ئارا تېرە رەڭگى',
    '🚴🏾‍♀' => 'ۋېلىسىپىتلىك ئايال: ئارا توق تېرە رەڭگى',
    '🚴🏿‍♀' => 'ۋېلىسىپىتلىك ئايال: توق تېرە رەڭ',
    '🚵🏻‍♂' => 'تاغ ۋېلىسىپىتى مىنگەن ئەر: ئاچ تېرە رەڭ',
    '🚵🏼‍♂' => 'تاغ ۋېلىسىپىتى مىنگەن ئەر: ئارا ئاچ تېرە رەڭگى',
    '🚵🏽‍♂' => 'تاغ ۋېلىسىپىتى مىنگەن ئەر: ئارا تېرە رەڭگى',
    '🚵🏾‍♂' => 'تاغ ۋېلىسىپىتى مىنگەن ئەر: ئارا توق تېرە رەڭگى',
    '🚵🏿‍♂' => 'تاغ ۋېلىسىپىتى مىنگەن ئەر: توق تېرە رەڭ',
    '🚵🏻‍♀' => 'تاغ ۋېلىسىپىتى مىنگەن ئايال: ئاچ تېرە رەڭ',
    '🚵🏼‍♀' => 'تاغ ۋېلىسىپىتى مىنگەن ئايال: ئارا ئاچ تېرە رەڭگى',
    '🚵🏽‍♀' => 'تاغ ۋېلىسىپىتى مىنگەن ئايال: ئارا تېرە رەڭگى',
    '🚵🏾‍♀' => 'تاغ ۋېلىسىپىتى مىنگەن ئايال: ئارا توق تېرە رەڭگى',
    '🚵🏿‍♀' => 'تاغ ۋېلىسىپىتى مىنگەن ئايال: توق تېرە رەڭ',
    '🤸🏻‍♂' => 'پەي سوزۇۋاتقان ئەر: ئاچ تېرە رەڭ',
    '🤸🏼‍♂' => 'پەي سوزۇۋاتقان ئەر: ئارا ئاچ تېرە رەڭگى',
    '🤸🏽‍♂' => 'پەي سوزۇۋاتقان ئەر: ئارا تېرە رەڭگى',
    '🤸🏾‍♂' => 'پەي سوزۇۋاتقان ئەر: ئارا توق تېرە رەڭگى',
    '🤸🏿‍♂' => 'پەي سوزۇۋاتقان ئەر: توق تېرە رەڭ',
    '🤸🏻‍♀' => 'پەي سوزۇۋاتقان ئايال: ئاچ تېرە رەڭ',
    '🤸🏼‍♀' => 'پەي سوزۇۋاتقان ئايال: ئارا ئاچ تېرە رەڭگى',
    '🤸🏽‍♀' => 'پەي سوزۇۋاتقان ئايال: ئارا تېرە رەڭگى',
    '🤸🏾‍♀' => 'پەي سوزۇۋاتقان ئايال: ئارا توق تېرە رەڭگى',
    '🤸🏿‍♀' => 'پەي سوزۇۋاتقان ئايال: توق تېرە رەڭ',
    '🤼🏻‍♀' => 'ئايال چېلىشچى: ئاچ تېرە رەڭ',
    '🤼🏼‍♀' => 'ئايال چېلىشچى: ئارا ئاچ تېرە رەڭگى',
    '🤼🏽‍♀' => 'ئايال چېلىشچى: ئارا تېرە رەڭگى',
    '🤼🏾‍♀' => 'ئايال چېلىشچى: ئارا توق تېرە رەڭگى',
    '🤼🏿‍♀' => 'ئايال چېلىشچى: توق تېرە رەڭ',
    '🤼🏻‍♂' => 'ئەر چېلىشچى: ئاچ تېرە رەڭ',
    '🤼🏼‍♂' => 'ئەر چېلىشچى: ئارا ئاچ تېرە رەڭگى',
    '🤼🏽‍♂' => 'ئەر چېلىشچى: ئارا تېرە رەڭگى',
    '🤼🏾‍♂' => 'ئەر چېلىشچى: ئارا توق تېرە رەڭگى',
    '🤼🏿‍♂' => 'ئەر چېلىشچى: توق تېرە رەڭ',
    '🤽🏻‍♂' => 'سۇ توپى ئويناۋاتقان ئەر: ئاچ تېرە رەڭ',
    '🤽🏼‍♂' => 'سۇ توپى ئويناۋاتقان ئەر: ئارا ئاچ تېرە رەڭگى',
    '🤽🏽‍♂' => 'سۇ توپى ئويناۋاتقان ئەر: ئارا تېرە رەڭگى',
    '🤽🏾‍♂' => 'سۇ توپى ئويناۋاتقان ئەر: ئارا توق تېرە رەڭگى',
    '🤽🏿‍♂' => 'سۇ توپى ئويناۋاتقان ئەر: توق تېرە رەڭ',
    '🤽🏻‍♀' => 'سۇ توپى ئويناۋاتقان ئايال: ئاچ تېرە رەڭ',
    '🤽🏼‍♀' => 'سۇ توپى ئويناۋاتقان ئايال: ئارا ئاچ تېرە رەڭگى',
    '🤽🏽‍♀' => 'سۇ توپى ئويناۋاتقان ئايال: ئارا تېرە رەڭگى',
    '🤽🏾‍♀' => 'سۇ توپى ئويناۋاتقان ئايال: ئارا توق تېرە رەڭگى',
    '🤽🏿‍♀' => 'سۇ توپى ئويناۋاتقان ئايال: توق تېرە رەڭ',
    '🤾🏻‍♂' => 'قولتوپ ئويناۋاتقان ئەر: ئاچ تېرە رەڭ',
    '🤾🏼‍♂' => 'قولتوپ ئويناۋاتقان ئەر: ئارا ئاچ تېرە رەڭگى',
    '🤾🏽‍♂' => 'قولتوپ ئويناۋاتقان ئەر: ئارا تېرە رەڭگى',
    '🤾🏾‍♂' => 'قولتوپ ئويناۋاتقان ئەر: ئارا توق تېرە رەڭگى',
    '🤾🏿‍♂' => 'قولتوپ ئويناۋاتقان ئەر: توق تېرە رەڭ',
    '🤾🏻‍♀' => 'قولتوپ ئويناۋاتقان ئايال: ئاچ تېرە رەڭ',
    '🤾🏼‍♀' => 'قولتوپ ئويناۋاتقان ئايال: ئارا ئاچ تېرە رەڭگى',
    '🤾🏽‍♀' => 'قولتوپ ئويناۋاتقان ئايال: ئارا تېرە رەڭگى',
    '🤾🏾‍♀' => 'قولتوپ ئويناۋاتقان ئايال: ئارا توق تېرە رەڭگى',
    '🤾🏿‍♀' => 'قولتوپ ئويناۋاتقان ئايال: توق تېرە رەڭ',
    '🤹🏻‍♂' => 'شار ئويناۋاتقان ئەر: ئاچ تېرە رەڭ',
    '🤹🏼‍♂' => 'شار ئويناۋاتقان ئەر: ئارا ئاچ تېرە رەڭگى',
    '🤹🏽‍♂' => 'شار ئويناۋاتقان ئەر: ئارا تېرە رەڭگى',
    '🤹🏾‍♂' => 'شار ئويناۋاتقان ئەر: ئارا توق تېرە رەڭگى',
    '🤹🏿‍♂' => 'شار ئويناۋاتقان ئەر: توق تېرە رەڭ',
    '🤹🏻‍♀' => 'شار ئويناۋاتقان ئايال: ئاچ تېرە رەڭ',
    '🤹🏼‍♀' => 'شار ئويناۋاتقان ئايال: ئارا ئاچ تېرە رەڭگى',
    '🤹🏽‍♀' => 'شار ئويناۋاتقان ئايال: ئارا تېرە رەڭگى',
    '🤹🏾‍♀' => 'شار ئويناۋاتقان ئايال: ئارا توق تېرە رەڭگى',
    '🤹🏿‍♀' => 'شار ئويناۋاتقان ئايال: توق تېرە رەڭ',
    '🧘🏻‍♂' => 'گىياھ ھەرىكەتلىك ئەر: ئاچ تېرە رەڭ',
    '🧘🏼‍♂' => 'گىياھ ھەرىكەتلىك ئەر: ئارا ئاچ تېرە رەڭگى',
    '🧘🏽‍♂' => 'گىياھ ھەرىكەتلىك ئەر: ئارا تېرە رەڭگى',
    '🧘🏾‍♂' => 'گىياھ ھەرىكەتلىك ئەر: ئارا توق تېرە رەڭگى',
    '🧘🏿‍♂' => 'گىياھ ھەرىكەتلىك ئەر: توق تېرە رەڭ',
    '🧘🏻‍♀' => 'گىياھ ھەرىكەتلىك ئايال: ئاچ تېرە رەڭ',
    '🧘🏼‍♀' => 'گىياھ ھەرىكەتلىك ئايال: ئارا ئاچ تېرە رەڭگى',
    '🧘🏽‍♀' => 'گىياھ ھەرىكەتلىك ئايال: ئارا تېرە رەڭگى',
    '🧘🏾‍♀' => 'گىياھ ھەرىكەتلىك ئايال: ئارا توق تېرە رەڭگى',
    '🧘🏿‍♀' => 'گىياھ ھەرىكەتلىك ئايال: توق تېرە رەڭ',
    '👨‍👦' => 'ئائىلە: ئەر and ئوغۇل',
    '👨‍👧' => 'ئائىلە: ئەر and قىز',
    '👩‍👦' => 'ئائىلە: ئايال and ئوغۇل',
    '👩‍👧' => 'ئائىلە: ئايال and قىز',
    '👁‍🗨' => 'شاردىكى كۆز',
    '👱‍♂' => 'ئالتۇن چاچ ئەر',
    '👱‍♀' => 'ئالتۇن چاچ ئايال',
    '🙍‍♂' => 'قوشۇمىسىنى تۈرگەن ئەر',
    '🙍‍♀' => 'قوشۇمىسىنى تۈرگەن ئايال',
    '🙎‍♂' => 'ھومايغان ئەر',
    '🙎‍♀' => 'ھومايغان ئايال',
    '🙅‍♂' => 'ياق دەپ ئىشارە قىلغان ئەر',
    '🙅‍♀' => 'ياق دەپ ئىشارە قىلغان ئايال',
    '🙆‍♂' => 'ماقۇل دەپ ئىشارە قىلغان ئەر',
    '🙆‍♀' => 'ماقۇل دەپ ئىشارە قىلغان ئايال',
    '💁‍♂' => 'تاپان ھەققى بەرگەن ئەر',
    '💁‍♀' => 'تاپان ھەققى بەرگەن ئايال',
    '🙋‍♂' => 'قول كۆتۈرگەن ئەر',
    '🙋‍♀' => 'قول كۆتۈرگەن ئايال',
    '🙇‍♂' => 'ئېگىلگەن ئەر',
    '🙇‍♀' => 'ئېگىلگەن ئايال',
    '🤦‍♂' => 'يۈزىنى تۇتقان ئەر',
    '🤦‍♀' => 'يۈزىنى تۇتقان ئايال',
    '🤷‍♂' => 'قىسىلغان ئەر',
    '🤷‍♀' => 'قىسىلغان ئايال',
    '👨‍⚕' => 'ساغلاملىق خىزمەتچىسى ئەر',
    '👩‍⚕' => 'ساغلاملىق خىزمەتچىسى ئايال',
    '👨‍🎓' => 'ئوغۇل ئوقۇغۇچى',
    '👩‍🎓' => 'قىز ئوقۇغۇچى',
    '👨‍🏫' => 'ئەر ئوقۇتقۇچى',
    '👩‍🏫' => 'ئايال ئوقۇتقۇچى',
    '👨‍⚖' => 'ئەر سوتچى',
    '👩‍⚖' => 'ئايال سوتچى',
    '👨‍🌾' => 'ئەر دېھقان',
    '👩‍🌾' => 'ئايال دېھقان',
    '👨‍🍳' => 'ئەر ئاشپەز',
    '👩‍🍳' => 'ئايال ئاشپەز',
    '👨‍🔧' => 'ئەر رېمونتچى',
    '👩‍🔧' => 'ئايال رېمونتچى',
    '👨‍🏭' => 'ئەر زاۋۇت ئىشچىسى',
    '👩‍🏭' => 'ئايال زاۋۇت ئىشچىسى',
    '👨‍💼' => 'ئىشخانا خىزمەتچىسى ئەر',
    '👩‍💼' => 'ئىشخانا خىزمەتچىسى ئايال',
    '👨‍🔬' => 'ئەر ئالىم',
    '👩‍🔬' => 'ئايال ئالىم',
    '👨‍💻' => 'ئەر تېخنىك',
    '👩‍💻' => 'ئايال تېخنىك',
    '👨‍🎤' => 'ئەر ناخشىچى',
    '👩‍🎤' => 'ئايال ناخشىچى',
    '👨‍🎨' => 'ئەر سەنئەتكار',
    '👩‍🎨' => 'ئايال سەنئەتكار',
    '👨‍✈' => 'ئەر ئۇچقۇچى',
    '👩‍✈' => 'ئايال ئۇچقۇچى',
    '👨‍🚀' => 'ئەر ئالەم ئۇچقۇچىسى',
    '👩‍🚀' => 'ئالەم ئۇچقۇچىسى ئايال',
    '👨‍🚒' => 'ئوت ئۆچۈرگۈچى ئەر',
    '👩‍🚒' => 'ئايال ئوت ئۆچۈرگۈچى',
    '👮‍♂' => 'ئەر ساقچى',
    '👮‍♀' => 'ئايال ساقچى',
    '🕵‍♂' => 'ئەر رازۋېدچىك',
    '🕵‍♀' => 'ئايال رازۋېدچىك',
    '💂‍♂' => 'ئەر قاراۋۇل',
    '💂‍♀' => 'ئايال قاراۋۇل',
    '👷‍♂' => 'قۇرۇلۇش ئىشچىسى ئەر',
    '👷‍♀' => 'قۇرۇلۇش ئىشچىسى ئايال',
    '👳‍♂' => 'سەللىلىك ئەر',
    '👳‍♀' => 'سەللىلىك ئايال',
    '🧙‍♂' => 'ئەر سېھرىگەر',
    '🧙‍♀' => 'ئايال سېھرىگەر',
    '🧚‍♂' => 'ئەر ئەرۋاھ',
    '🧚‍♀' => 'ئايال ئەرۋاھ',
    '🧛‍♂' => 'ئەر مۇردا',
    '🧛‍♀' => 'ئايال مۇردا',
    '🧜‍♂' => 'بېلىق ئەر',
    '🧜‍♀' => 'بېلىق قىز',
    '🧝‍♂' => 'ئەر پىر',
    '🧝‍♀' => 'ئايال پىر',
    '🧞‍♂' => 'ئەر جىن',
    '🧞‍♀' => 'ئايال جىن',
    '🧟‍♂' => 'ئەر زومبى',
    '🧟‍♀' => 'ئايال زومبى',
    '💆‍♂' => 'ئۇۋىلانغان ئەر',
    '💆‍♀' => 'ئۇۋىلانغان ئايال',
    '💇‍♂' => 'چاچ ياساتقان ئەر',
    '💇‍♀' => 'چاچ ياساتقان ئايال',
    '🚶‍♂' => 'ماڭغان ئەر',
    '🚶‍♀' => 'ماڭغان ئايال',
    '🏃‍♂' => 'يۈگۈرگەن ئەر',
    '🏃‍♀' => 'يۈگۈرگەن ئايال',
    '👯‍♂' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئەر',
    '👯‍♀' => 'سورۇندىكى ئۇزۇن قۇلاق ئۇسسۇلچى ئايال',
    '🧖‍♂' => 'ھورداقتىكى ئەر',
    '🧖‍♀' => 'ھورداقتىكى ئايال',
    '🧗‍♂' => 'ياماشقان ئەر',
    '🧗‍♀' => 'ياماشقان ئايال',
    '🏌‍♂' => 'گولفچى ئەر',
    '🏌‍♀' => 'گولفچى ئايال',
    '🏄‍♂' => 'دولقۇن كەزگۈچى ئەر',
    '🏄‍♀' => 'دولقۇن كەزگۈچى ئايال',
    '🚣‍♂' => 'قېيىقچى ئەر',
    '🚣‍♀' => 'قېيىقچى ئايال',
    '🏊‍♂' => 'ئۈزۈۋاتقان ئەر',
    '🏊‍♀' => 'ئۈزۈۋاتقان ئايال',
    '⛹‍♂' => 'توپ ئويناۋاتقان ئەر',
    '⛹‍♀' => 'توپ ئويناۋاتقان ئايال',
    '🏋‍♂' => 'ئېغىرلىق كۆتۈرگۈچى ئەر',
    '🏋‍♀' => 'ئېغىرلىق كۆتۈرگۈچى ئايال',
    '🚴‍♂' => 'ۋېلىسىپىتلىك ئەر',
    '🚴‍♀' => 'ۋېلىسىپىتلىك ئايال',
    '🚵‍♂' => 'تاغ ۋېلىسىپىتى مىنگەن ئەر',
    '🚵‍♀' => 'تاغ ۋېلىسىپىتى مىنگەن ئايال',
    '🤸‍♂' => 'پەي سوزۇۋاتقان ئەر',
    '🤸‍♀' => 'پەي سوزۇۋاتقان ئايال',
    '🤼‍♂' => 'ئەر چېلىشچى',
    '🤼‍♀' => 'ئايال چېلىشچى',
    '🤽‍♂' => 'سۇ توپى ئويناۋاتقان ئەر',
    '🤽‍♀' => 'سۇ توپى ئويناۋاتقان ئايال',
    '🤾‍♂' => 'قولتوپ ئويناۋاتقان ئەر',
    '🤾‍♀' => 'قولتوپ ئويناۋاتقان ئايال',
    '🤹‍♂' => 'شار ئويناۋاتقان ئەر',
    '🤹‍♀' => 'شار ئويناۋاتقان ئايال',
    '🧘‍♂' => 'گىياھ ھەرىكەتلىك ئەر',
    '🧘‍♀' => 'گىياھ ھەرىكەتلىك ئايال',
    '🏳‍🌈' => 'ھەسەن-ھۈسەن بايراق',
    '👋🏻' => 'قول پۇلاڭلىتىش: ئاچ تېرە رەڭ',
    '👋🏼' => 'قول پۇلاڭلىتىش: ئارا ئاچ تېرە رەڭگى',
    '👋🏽' => 'قول پۇلاڭلىتىش: ئارا تېرە رەڭگى',
    '👋🏾' => 'قول پۇلاڭلىتىش: ئارا توق تېرە رەڭگى',
    '👋🏿' => 'قول پۇلاڭلىتىش: توق تېرە رەڭ',
    '🤚🏻' => 'كۆتۈرگەن قولنىڭ ئارقىسى: ئاچ تېرە رەڭ',
    '🤚🏼' => 'كۆتۈرگەن قولنىڭ ئارقىسى: ئارا ئاچ تېرە رەڭگى',
    '🤚🏽' => 'كۆتۈرگەن قولنىڭ ئارقىسى: ئارا تېرە رەڭگى',
    '🤚🏾' => 'كۆتۈرگەن قولنىڭ ئارقىسى: ئارا توق تېرە رەڭگى',
    '🤚🏿' => 'كۆتۈرگەن قولنىڭ ئارقىسى: توق تېرە رەڭ',
    '🖐🏻' => 'بارماقلىرىنى يېيىپ كۆتۈرگەن قول: ئاچ تېرە رەڭ',
    '🖐🏼' => 'بارماقلىرىنى يېيىپ كۆتۈرگەن قول: ئارا ئاچ تېرە رەڭگى',
    '🖐🏽' => 'بارماقلىرىنى يېيىپ كۆتۈرگەن قول: ئارا تېرە رەڭگى',
    '🖐🏾' => 'بارماقلىرىنى يېيىپ كۆتۈرگەن قول: ئارا توق تېرە رەڭگى',
    '🖐🏿' => 'بارماقلىرىنى يېيىپ كۆتۈرگەن قول: توق تېرە رەڭ',
    '✋🏻' => 'كۆتۈرگەن قول: ئاچ تېرە رەڭ',
    '✋🏼' => 'كۆتۈرگەن قول: ئارا ئاچ تېرە رەڭگى',
    '✋🏽' => 'كۆتۈرگەن قول: ئارا تېرە رەڭگى',
    '✋🏾' => 'كۆتۈرگەن قول: ئارا توق تېرە رەڭگى',
    '✋🏿' => 'كۆتۈرگەن قول: توق تېرە رەڭ',
    '🖖🏻' => 'ۋولقان سالام: ئاچ تېرە رەڭ',
    '🖖🏼' => 'ۋولقان سالام: ئارا ئاچ تېرە رەڭگى',
    '🖖🏽' => 'ۋولقان سالام: ئارا تېرە رەڭگى',
    '🖖🏾' => 'ۋولقان سالام: ئارا توق تېرە رەڭگى',
    '🖖🏿' => 'ۋولقان سالام: توق تېرە رەڭ',
    '👌🏻' => 'ماقۇل بەلگىسى: ئاچ تېرە رەڭ',
    '👌🏼' => 'ماقۇل بەلگىسى: ئارا ئاچ تېرە رەڭگى',
    '👌🏽' => 'ماقۇل بەلگىسى: ئارا تېرە رەڭگى',
    '👌🏾' => 'ماقۇل بەلگىسى: ئارا توق تېرە رەڭگى',
    '👌🏿' => 'ماقۇل بەلگىسى: توق تېرە رەڭ',
    '✌🏻' => 'غەلبە ئىشارىسى: ئاچ تېرە رەڭ',
    '✌🏼' => 'غەلبە ئىشارىسى: ئارا ئاچ تېرە رەڭگى',
    '✌🏽' => 'غەلبە ئىشارىسى: ئارا تېرە رەڭگى',
    '✌🏾' => 'غەلبە ئىشارىسى: ئارا توق تېرە رەڭگى',
    '✌🏿' => 'غەلبە ئىشارىسى: توق تېرە رەڭ',
    '🤞🏻' => 'كېسىشكەن بارماقلار: ئاچ تېرە رەڭ',
    '🤞🏼' => 'كېسىشكەن بارماقلار: ئارا ئاچ تېرە رەڭگى',
    '🤞🏽' => 'كېسىشكەن بارماقلار: ئارا تېرە رەڭگى',
    '🤞🏾' => 'كېسىشكەن بارماقلار: ئارا توق تېرە رەڭگى',
    '🤞🏿' => 'كېسىشكەن بارماقلار: توق تېرە رەڭ',
    '🤟🏻' => 'سۆيىمەن دېگەن ئىشارە: ئاچ تېرە رەڭ',
    '🤟🏼' => 'سۆيىمەن دېگەن ئىشارە: ئارا ئاچ تېرە رەڭگى',
    '🤟🏽' => 'سۆيىمەن دېگەن ئىشارە: ئارا تېرە رەڭگى',
    '🤟🏾' => 'سۆيىمەن دېگەن ئىشارە: ئارا توق تېرە رەڭگى',
    '🤟🏿' => 'سۆيىمەن دېگەن ئىشارە: توق تېرە رەڭ',
    '🤘🏻' => 'مۈڭگۈز بەلگىسى: ئاچ تېرە رەڭ',
    '🤘🏼' => 'مۈڭگۈز بەلگىسى: ئارا ئاچ تېرە رەڭگى',
    '🤘🏽' => 'مۈڭگۈز بەلگىسى: ئارا تېرە رەڭگى',
    '🤘🏾' => 'مۈڭگۈز بەلگىسى: ئارا توق تېرە رەڭگى',
    '🤘🏿' => 'مۈڭگۈز بەلگىسى: توق تېرە رەڭ',
    '🤙🏻' => 'تېلېفون قىلىڭ: ئاچ تېرە رەڭ',
    '🤙🏼' => 'تېلېفون قىلىڭ: ئارا ئاچ تېرە رەڭگى',
    '🤙🏽' => 'تېلېفون قىلىڭ: ئارا تېرە رەڭگى',
    '🤙🏾' => 'تېلېفون قىلىڭ: ئارا توق تېرە رەڭگى',
    '🤙🏿' => 'تېلېفون قىلىڭ: توق تېرە رەڭ',
    '👈🏻' => 'ئارقىچە سولنى كۆرسەتكەن كۆرسەتكۈچ بارماق: ئاچ تېرە رەڭ',
    '👈🏼' => 'ئارقىچە سولنى كۆرسەتكەن كۆرسەتكۈچ بارماق: ئارا ئاچ تېرە رەڭگى',
    '👈🏽' => 'ئارقىچە سولنى كۆرسەتكەن كۆرسەتكۈچ بارماق: ئارا تېرە رەڭگى',
    '👈🏾' => 'ئارقىچە سولنى كۆرسەتكەن كۆرسەتكۈچ بارماق: ئارا توق تېرە رەڭگى',
    '👈🏿' => 'ئارقىچە سولنى كۆرسەتكەن كۆرسەتكۈچ بارماق: توق تېرە رەڭ',
    '👉🏻' => 'ئارقىچە ئوڭنى كۆرسەتكەن كۆرسەتكۈچ بارماق: ئاچ تېرە رەڭ',
    '👉🏼' => 'ئارقىچە ئوڭنى كۆرسەتكەن كۆرسەتكۈچ بارماق: ئارا ئاچ تېرە رەڭگى',
    '👉🏽' => 'ئارقىچە ئوڭنى كۆرسەتكەن كۆرسەتكۈچ بارماق: ئارا تېرە رەڭگى',
    '👉🏾' => 'ئارقىچە ئوڭنى كۆرسەتكەن كۆرسەتكۈچ بارماق: ئارا توق تېرە رەڭگى',
    '👉🏿' => 'ئارقىچە ئوڭنى كۆرسەتكەن كۆرسەتكۈچ بارماق: توق تېرە رەڭ',
    '👆🏻' => 'ئارقىچە ئۈستىنى كۆرسەتكەن كۆرسەتكۈچ بارماق: ئاچ تېرە رەڭ',
    '👆🏼' => 'ئارقىچە ئۈستىنى كۆرسەتكەن كۆرسەتكۈچ بارماق: ئارا ئاچ تېرە رەڭگى',
    '👆🏽' => 'ئارقىچە ئۈستىنى كۆرسەتكەن كۆرسەتكۈچ بارماق: ئارا تېرە رەڭگى',
    '👆🏾' => 'ئارقىچە ئۈستىنى كۆرسەتكەن كۆرسەتكۈچ بارماق: ئارا توق تېرە رەڭگى',
    '👆🏿' => 'ئارقىچە ئۈستىنى كۆرسەتكەن كۆرسەتكۈچ بارماق: توق تېرە رەڭ',
    '🖕🏻' => 'ئوتتۇرا بارماق: ئاچ تېرە رەڭ',
    '🖕🏼' => 'ئوتتۇرا بارماق: ئارا ئاچ تېرە رەڭگى',
    '🖕🏽' => 'ئوتتۇرا بارماق: ئارا تېرە رەڭگى',
    '🖕🏾' => 'ئوتتۇرا بارماق: ئارا توق تېرە رەڭگى',
    '🖕🏿' => 'ئوتتۇرا بارماق: توق تېرە رەڭ',
    '👇🏻' => 'ئارقىچە ئاستىنى كۆرسەتكەن كۆرسەتكۈچ بارماق: ئاچ تېرە رەڭ',
    '👇🏼' => 'ئارقىچە ئاستىنى كۆرسەتكەن كۆرسەتكۈچ بارماق: ئارا ئاچ تېرە رەڭگى',
    '👇🏽' => 'ئارقىچە ئاستىنى كۆرسەتكەن كۆرسەتكۈچ بارماق: ئارا تېرە رەڭگى',
    '👇🏾' => 'ئارقىچە ئاستىنى كۆرسەتكەن كۆرسەتكۈچ بارماق: ئارا توق تېرە رەڭگى',
    '👇🏿' => 'ئارقىچە ئاستىنى كۆرسەتكەن كۆرسەتكۈچ بارماق: توق تېرە رەڭ',
    '☝🏻' => 'ئۈستىنى كۆرسەتكەن كۆرسەتكۈچ بارماق: ئاچ تېرە رەڭ',
    '☝🏼' => 'ئۈستىنى كۆرسەتكەن كۆرسەتكۈچ بارماق: ئارا ئاچ تېرە رەڭگى',
    '☝🏽' => 'ئۈستىنى كۆرسەتكەن كۆرسەتكۈچ بارماق: ئارا تېرە رەڭگى',
    '☝🏾' => 'ئۈستىنى كۆرسەتكەن كۆرسەتكۈچ بارماق: ئارا توق تېرە رەڭگى',
    '☝🏿' => 'ئۈستىنى كۆرسەتكەن كۆرسەتكۈچ بارماق: توق تېرە رەڭ',
    '👍🏻' => 'قوللاش: ئاچ تېرە رەڭ',
    '👍🏼' => 'قوللاش: ئارا ئاچ تېرە رەڭگى',
    '👍🏽' => 'قوللاش: ئارا تېرە رەڭگى',
    '👍🏾' => 'قوللاش: ئارا توق تېرە رەڭگى',
    '👍🏿' => 'قوللاش: توق تېرە رەڭ',
    '👎🏻' => 'پۇتلاش: ئاچ تېرە رەڭ',
    '👎🏼' => 'پۇتلاش: ئارا ئاچ تېرە رەڭگى',
    '👎🏽' => 'پۇتلاش: ئارا تېرە رەڭگى',
    '👎🏾' => 'پۇتلاش: ئارا توق تېرە رەڭگى',
    '👎🏿' => 'پۇتلاش: توق تېرە رەڭ',
    '✊🏻' => 'كۆتۈرگەن مۇشت: ئاچ تېرە رەڭ',
    '✊🏼' => 'كۆتۈرگەن مۇشت: ئارا ئاچ تېرە رەڭگى',
    '✊🏽' => 'كۆتۈرگەن مۇشت: ئارا تېرە رەڭگى',
    '✊🏾' => 'كۆتۈرگەن مۇشت: ئارا توق تېرە رەڭگى',
    '✊🏿' => 'كۆتۈرگەن مۇشت: توق تېرە رەڭ',
    '👊🏻' => 'كەلگەن مۇشت: ئاچ تېرە رەڭ',
    '👊🏼' => 'كەلگەن مۇشت: ئارا ئاچ تېرە رەڭگى',
    '👊🏽' => 'كەلگەن مۇشت: ئارا تېرە رەڭگى',
    '👊🏾' => 'كەلگەن مۇشت: ئارا توق تېرە رەڭگى',
    '👊🏿' => 'كەلگەن مۇشت: توق تېرە رەڭ',
    '🤛🏻' => 'سول مۇشت: ئاچ تېرە رەڭ',
    '🤛🏼' => 'سول مۇشت: ئارا ئاچ تېرە رەڭگى',
    '🤛🏽' => 'سول مۇشت: ئارا تېرە رەڭگى',
    '🤛🏾' => 'سول مۇشت: ئارا توق تېرە رەڭگى',
    '🤛🏿' => 'سول مۇشت: توق تېرە رەڭ',
    '🤜🏻' => 'ئوڭ مۇشت: ئاچ تېرە رەڭ',
    '🤜🏼' => 'ئوڭ مۇشت: ئارا ئاچ تېرە رەڭگى',
    '🤜🏽' => 'ئوڭ مۇشت: ئارا تېرە رەڭگى',
    '🤜🏾' => 'ئوڭ مۇشت: ئارا توق تېرە رەڭگى',
    '🤜🏿' => 'ئوڭ مۇشت: توق تېرە رەڭ',
    '👏🏻' => 'چاۋاك: ئاچ تېرە رەڭ',
    '👏🏼' => 'چاۋاك: ئارا ئاچ تېرە رەڭگى',
    '👏🏽' => 'چاۋاك: ئارا تېرە رەڭگى',
    '👏🏾' => 'چاۋاك: ئارا توق تېرە رەڭگى',
    '👏🏿' => 'چاۋاك: توق تېرە رەڭ',
    '🙌🏻' => 'قول كۆتۈرۈش: ئاچ تېرە رەڭ',
    '🙌🏼' => 'قول كۆتۈرۈش: ئارا ئاچ تېرە رەڭگى',
    '🙌🏽' => 'قول كۆتۈرۈش: ئارا تېرە رەڭگى',
    '🙌🏾' => 'قول كۆتۈرۈش: ئارا توق تېرە رەڭگى',
    '🙌🏿' => 'قول كۆتۈرۈش: توق تېرە رەڭ',
    '👐🏻' => 'ئوچۇق قول: ئاچ تېرە رەڭ',
    '👐🏼' => 'ئوچۇق قول: ئارا ئاچ تېرە رەڭگى',
    '👐🏽' => 'ئوچۇق قول: ئارا تېرە رەڭگى',
    '👐🏾' => 'ئوچۇق قول: ئارا توق تېرە رەڭگى',
    '👐🏿' => 'ئوچۇق قول: توق تېرە رەڭ',
    '🤲🏻' => 'ئوچۇم: ئاچ تېرە رەڭ',
    '🤲🏼' => 'ئوچۇم: ئارا ئاچ تېرە رەڭگى',
    '🤲🏽' => 'ئوچۇم: ئارا تېرە رەڭگى',
    '🤲🏾' => 'ئوچۇم: ئارا توق تېرە رەڭگى',
    '🤲🏿' => 'ئوچۇم: توق تېرە رەڭ',
    '🤝🏻' => 'قول قىسىش: ئاچ تېرە رەڭ',
    '🤝🏼' => 'قول قىسىش: ئارا ئاچ تېرە رەڭگى',
    '🤝🏽' => 'قول قىسىش: ئارا تېرە رەڭگى',
    '🤝🏾' => 'قول قىسىش: ئارا توق تېرە رەڭگى',
    '🤝🏿' => 'قول قىسىش: توق تېرە رەڭ',
    '🙏🏻' => 'قوۋۇشقان قول: ئاچ تېرە رەڭ',
    '🙏🏼' => 'قوۋۇشقان قول: ئارا ئاچ تېرە رەڭگى',
    '🙏🏽' => 'قوۋۇشقان قول: ئارا تېرە رەڭگى',
    '🙏🏾' => 'قوۋۇشقان قول: ئارا توق تېرە رەڭگى',
    '🙏🏿' => 'قوۋۇشقان قول: توق تېرە رەڭ',
    '✍🏻' => 'يېزىۋاتقان قول: ئاچ تېرە رەڭ',
    '✍🏼' => 'يېزىۋاتقان قول: ئارا ئاچ تېرە رەڭگى',
    '✍🏽' => 'يېزىۋاتقان قول: ئارا تېرە رەڭگى',
    '✍🏾' => 'يېزىۋاتقان قول: ئارا توق تېرە رەڭگى',
    '✍🏿' => 'يېزىۋاتقان قول: توق تېرە رەڭ',
    '💅🏻' => 'تىرناق بوياش: ئاچ تېرە رەڭ',
    '💅🏼' => 'تىرناق بوياش: ئارا ئاچ تېرە رەڭگى',
    '💅🏽' => 'تىرناق بوياش: ئارا تېرە رەڭگى',
    '💅🏾' => 'تىرناق بوياش: ئارا توق تېرە رەڭگى',
    '💅🏿' => 'تىرناق بوياش: توق تېرە رەڭ',
    '🤳🏻' => 'ئۆزتارتىم: ئاچ تېرە رەڭ',
    '🤳🏼' => 'ئۆزتارتىم: ئارا ئاچ تېرە رەڭگى',
    '🤳🏽' => 'ئۆزتارتىم: ئارا تېرە رەڭگى',
    '🤳🏾' => 'ئۆزتارتىم: ئارا توق تېرە رەڭگى',
    '🤳🏿' => 'ئۆزتارتىم: توق تېرە رەڭ',
    '💪🏻' => 'ئېگىلگەن بىلەك: ئاچ تېرە رەڭ',
    '💪🏼' => 'ئېگىلگەن بىلەك: ئارا ئاچ تېرە رەڭگى',
    '💪🏽' => 'ئېگىلگەن بىلەك: ئارا تېرە رەڭگى',
    '💪🏾' => 'ئېگىلگەن بىلەك: ئارا توق تېرە رەڭگى',
    '💪🏿' => 'ئېگىلگەن بىلەك: توق تېرە رەڭ',
    '👂🏻' => 'قۇلاق: ئاچ تېرە رەڭ',
    '👂🏼' => 'قۇلاق: ئارا ئاچ تېرە رەڭگى',
    '👂🏽' => 'قۇلاق: ئارا تېرە رەڭگى',
    '👂🏾' => 'قۇلاق: ئارا توق تېرە رەڭگى',
    '👂🏿' => 'قۇلاق: توق تېرە رەڭ',
    '👃🏻' => 'بۇرۇن: ئاچ تېرە رەڭ',
    '👃🏼' => 'بۇرۇن: ئارا ئاچ تېرە رەڭگى',
    '👃🏽' => 'بۇرۇن: ئارا تېرە رەڭگى',
    '👃🏾' => 'بۇرۇن: ئارا توق تېرە رەڭگى',
    '👃🏿' => 'بۇرۇن: توق تېرە رەڭ',
    '👶🏻' => 'بوۋاق: ئاچ تېرە رەڭ',
    '👶🏼' => 'بوۋاق: ئارا ئاچ تېرە رەڭگى',
    '👶🏽' => 'بوۋاق: ئارا تېرە رەڭگى',
    '👶🏾' => 'بوۋاق: ئارا توق تېرە رەڭگى',
    '👶🏿' => 'بوۋاق: توق تېرە رەڭ',
    '🧒🏻' => 'بالا: ئاچ تېرە رەڭ',
    '🧒🏼' => 'بالا: ئارا ئاچ تېرە رەڭگى',
    '🧒🏽' => 'بالا: ئارا تېرە رەڭگى',
    '🧒🏾' => 'بالا: ئارا توق تېرە رەڭگى',
    '🧒🏿' => 'بالا: توق تېرە رەڭ',
    '👦🏻' => 'ئوغۇل: ئاچ تېرە رەڭ',
    '👦🏼' => 'ئوغۇل: ئارا ئاچ تېرە رەڭگى',
    '👦🏽' => 'ئوغۇل: ئارا تېرە رەڭگى',
    '👦🏾' => 'ئوغۇل: ئارا توق تېرە رەڭگى',
    '👦🏿' => 'ئوغۇل: توق تېرە رەڭ',
    '👧🏻' => 'قىز: ئاچ تېرە رەڭ',
    '👧🏼' => 'قىز: ئارا ئاچ تېرە رەڭگى',
    '👧🏽' => 'قىز: ئارا تېرە رەڭگى',
    '👧🏾' => 'قىز: ئارا توق تېرە رەڭگى',
    '👧🏿' => 'قىز: توق تېرە رەڭ',
    '🧑🏻' => 'چوڭلار: ئاچ تېرە رەڭ',
    '🧑🏼' => 'چوڭلار: ئارا ئاچ تېرە رەڭگى',
    '🧑🏽' => 'چوڭلار: ئارا تېرە رەڭگى',
    '🧑🏾' => 'چوڭلار: ئارا توق تېرە رەڭگى',
    '🧑🏿' => 'چوڭلار: توق تېرە رەڭ',
    '👱🏻' => 'ئالتۇن چاچ كىشى: ئاچ تېرە رەڭ',
    '👱🏼' => 'ئالتۇن چاچ كىشى: ئارا ئاچ تېرە رەڭگى',
    '👱🏽' => 'ئالتۇن چاچ كىشى: ئارا تېرە رەڭگى',
    '👱🏾' => 'ئالتۇن چاچ كىشى: ئارا توق تېرە رەڭگى',
    '👱🏿' => 'ئالتۇن چاچ كىشى: توق تېرە رەڭ',
    '👨🏻' => 'ئەر: ئاچ تېرە رەڭ',
    '👨🏼' => 'ئەر: ئارا ئاچ تېرە رەڭگى',
    '👨🏽' => 'ئەر: ئارا تېرە رەڭگى',
    '👨🏾' => 'ئەر: ئارا توق تېرە رەڭگى',
    '👨🏿' => 'ئەر: توق تېرە رەڭ',
    '🧔🏻' => 'ساقاللىق كىشى: ئاچ تېرە رەڭ',
    '🧔🏼' => 'ساقاللىق كىشى: ئارا ئاچ تېرە رەڭگى',
    '🧔🏽' => 'ساقاللىق كىشى: ئارا تېرە رەڭگى',
    '🧔🏾' => 'ساقاللىق كىشى: ئارا توق تېرە رەڭگى',
    '🧔🏿' => 'ساقاللىق كىشى: توق تېرە رەڭ',
    '👩🏻' => 'ئايال: ئاچ تېرە رەڭ',
    '👩🏼' => 'ئايال: ئارا ئاچ تېرە رەڭگى',
    '👩🏽' => 'ئايال: ئارا تېرە رەڭگى',
    '👩🏾' => 'ئايال: ئارا توق تېرە رەڭگى',
    '👩🏿' => 'ئايال: توق تېرە رەڭ',
    '🧓🏻' => 'قېرىلار: ئاچ تېرە رەڭ',
    '🧓🏼' => 'قېرىلار: ئارا ئاچ تېرە رەڭگى',
    '🧓🏽' => 'قېرىلار: ئارا تېرە رەڭگى',
    '🧓🏾' => 'قېرىلار: ئارا توق تېرە رەڭگى',
    '🧓🏿' => 'قېرىلار: توق تېرە رەڭ',
    '👴🏻' => 'بوۋاي: ئاچ تېرە رەڭ',
    '👴🏼' => 'بوۋاي: ئارا ئاچ تېرە رەڭگى',
    '👴🏽' => 'بوۋاي: ئارا تېرە رەڭگى',
    '👴🏾' => 'بوۋاي: ئارا توق تېرە رەڭگى',
    '👴🏿' => 'بوۋاي: توق تېرە رەڭ',
    '👵🏻' => 'موماي: ئاچ تېرە رەڭ',
    '👵🏼' => 'موماي: ئارا ئاچ تېرە رەڭگى',
    '👵🏽' => 'موماي: ئارا تېرە رەڭگى',
    '👵🏾' => 'موماي: ئارا توق تېرە رەڭگى',
    '👵🏿' => 'موماي: توق تېرە رەڭ',
    '🙍🏻' => 'قوشۇمىسىنى تۈرگەن كىشى: ئاچ تېرە رەڭ',
    '🙍🏼' => 'قوشۇمىسىنى تۈرگەن كىشى: ئارا ئاچ تېرە رەڭگى',
    '🙍🏽' => 'قوشۇمىسىنى تۈرگەن كىشى: ئارا تېرە رەڭگى',
    '🙍🏾' => 'قوشۇمىسىنى تۈرگەن كىشى: ئارا توق تېرە رەڭگى',
    '🙍🏿' => 'قوشۇمىسىنى تۈرگەن كىشى: توق تېرە رەڭ',
    '🙎🏻' => 'ھومايغان كىشى: ئاچ تېرە رەڭ',
    '🙎🏼' => 'ھومايغان كىشى: ئارا ئاچ تېرە رەڭگى',
    '🙎🏽' => 'ھومايغان كىشى: ئارا تېرە رەڭگى',
    '🙎🏾' => 'ھومايغان كىشى: ئارا توق تېرە رەڭگى',
    '🙎🏿' => 'ھومايغان كىشى: توق تېرە رەڭ',
    '🙅🏻' => 'ياق دەپ ئىشارە قىلغان كىشى: ئاچ تېرە رەڭ',
    '🙅🏼' => 'ياق دەپ ئىشارە قىلغان كىشى: ئارا ئاچ تېرە رەڭگى',
    '🙅🏽' => 'ياق دەپ ئىشارە قىلغان كىشى: ئارا تېرە رەڭگى',
    '🙅🏾' => 'ياق دەپ ئىشارە قىلغان كىشى: ئارا توق تېرە رەڭگى',
    '🙅🏿' => 'ياق دەپ ئىشارە قىلغان كىشى: توق تېرە رەڭ',
    '🙆🏻' => 'ماقۇل دەپ ئىشارە قىلغان كىشى: ئاچ تېرە رەڭ',
    '🙆🏼' => 'ماقۇل دەپ ئىشارە قىلغان كىشى: ئارا ئاچ تېرە رەڭگى',
    '🙆🏽' => 'ماقۇل دەپ ئىشارە قىلغان كىشى: ئارا تېرە رەڭگى',
    '🙆🏾' => 'ماقۇل دەپ ئىشارە قىلغان كىشى: ئارا توق تېرە رەڭگى',
    '🙆🏿' => 'ماقۇل دەپ ئىشارە قىلغان كىشى: توق تېرە رەڭ',
    '💁🏻' => 'تاپان ھەققى بەرگەن كىشى: ئاچ تېرە رەڭ',
    '💁🏼' => 'تاپان ھەققى بەرگەن كىشى: ئارا ئاچ تېرە رەڭگى',
    '💁🏽' => 'تاپان ھەققى بەرگەن كىشى: ئارا تېرە رەڭگى',
    '💁🏾' => 'تاپان ھەققى بەرگەن كىشى: ئارا توق تېرە رەڭگى',
    '💁🏿' => 'تاپان ھەققى بەرگەن كىشى: توق تېرە رەڭ',
    '🙋🏻' => 'قول كۆتۈرگەن كىشى: ئاچ تېرە رەڭ',
    '🙋🏼' => 'قول كۆتۈرگەن كىشى: ئارا ئاچ تېرە رەڭگى',
    '🙋🏽' => 'قول كۆتۈرگەن كىشى: ئارا تېرە رەڭگى',
    '🙋🏾' => 'قول كۆتۈرگەن كىشى: ئارا توق تېرە رەڭگى',
    '🙋🏿' => 'قول كۆتۈرگەن كىشى: توق تېرە رەڭ',
    '🙇🏻' => 'ئېگىلگەن كىشى: ئاچ تېرە رەڭ',
    '🙇🏼' => 'ئېگىلگەن كىشى: ئارا ئاچ تېرە رەڭگى',
    '🙇🏽' => 'ئېگىلگەن كىشى: ئارا تېرە رەڭگى',
    '🙇🏾' => 'ئېگىلگەن كىشى: ئارا توق تېرە رەڭگى',
    '🙇🏿' => 'ئېگىلگەن كىشى: توق تېرە رەڭ',
    '🤦🏻' => 'يۈزىنى تۇتقان كىشى: ئاچ تېرە رەڭ',
    '🤦🏼' => 'يۈزىنى تۇتقان كىشى: ئارا ئاچ تېرە رەڭگى',
    '🤦🏽' => 'يۈزىنى تۇتقان كىشى: ئارا تېرە رەڭگى',
    '🤦🏾' => 'يۈزىنى تۇتقان كىشى: ئارا توق تېرە رەڭگى',
    '🤦🏿' => 'يۈزىنى تۇتقان كىشى: توق تېرە رەڭ',
    '🤷🏻' => 'قىسىلغان كىشى: ئاچ تېرە رەڭ',
    '🤷🏼' => 'قىسىلغان كىشى: ئارا ئاچ تېرە رەڭگى',
    '🤷🏽' => 'قىسىلغان كىشى: ئارا تېرە رەڭگى',
    '🤷🏾' => 'قىسىلغان كىشى: ئارا توق تېرە رەڭگى',
    '🤷🏿' => 'قىسىلغان كىشى: توق تېرە رەڭ',
    '👮🏻' => 'ساقچى: ئاچ تېرە رەڭ',
    '👮🏼' => 'ساقچى: ئارا ئاچ تېرە رەڭگى',
    '👮🏽' => 'ساقچى: ئارا تېرە رەڭگى',
    '👮🏾' => 'ساقچى: ئارا توق تېرە رەڭگى',
    '👮🏿' => 'ساقچى: توق تېرە رەڭ',
    '🕵🏻' => 'رازۋېدچىك: ئاچ تېرە رەڭ',
    '🕵🏼' => 'رازۋېدچىك: ئارا ئاچ تېرە رەڭگى',
    '🕵🏽' => 'رازۋېدچىك: ئارا تېرە رەڭگى',
    '🕵🏾' => 'رازۋېدچىك: ئارا توق تېرە رەڭگى',
    '🕵🏿' => 'رازۋېدچىك: توق تېرە رەڭ',
    '💂🏻' => 'قاراۋۇل: ئاچ تېرە رەڭ',
    '💂🏼' => 'قاراۋۇل: ئارا ئاچ تېرە رەڭگى',
    '💂🏽' => 'قاراۋۇل: ئارا تېرە رەڭگى',
    '💂🏾' => 'قاراۋۇل: ئارا توق تېرە رەڭگى',
    '💂🏿' => 'قاراۋۇل: توق تېرە رەڭ',
    '👷🏻' => 'قۇرۇلۇشچى: ئاچ تېرە رەڭ',
    '👷🏼' => 'قۇرۇلۇشچى: ئارا ئاچ تېرە رەڭگى',
    '👷🏽' => 'قۇرۇلۇشچى: ئارا تېرە رەڭگى',
    '👷🏾' => 'قۇرۇلۇشچى: ئارا توق تېرە رەڭگى',
    '👷🏿' => 'قۇرۇلۇشچى: توق تېرە رەڭ',
    '🤴🏻' => 'شاھزادە: ئاچ تېرە رەڭ',
    '🤴🏼' => 'شاھزادە: ئارا ئاچ تېرە رەڭگى',
    '🤴🏽' => 'شاھزادە: ئارا تېرە رەڭگى',
    '🤴🏾' => 'شاھزادە: ئارا توق تېرە رەڭگى',
    '🤴🏿' => 'شاھزادە: توق تېرە رەڭ',
    '👸🏻' => 'مەلىكە: ئاچ تېرە رەڭ',
    '👸🏼' => 'مەلىكە: ئارا ئاچ تېرە رەڭگى',
    '👸🏽' => 'مەلىكە: ئارا تېرە رەڭگى',
    '👸🏾' => 'مەلىكە: ئارا توق تېرە رەڭگى',
    '👸🏿' => 'مەلىكە: توق تېرە رەڭ',
    '👳🏻' => 'سەللىلىك كىشى: ئاچ تېرە رەڭ',
    '👳🏼' => 'سەللىلىك كىشى: ئارا ئاچ تېرە رەڭگى',
    '👳🏽' => 'سەللىلىك كىشى: ئارا تېرە رەڭگى',
    '👳🏾' => 'سەللىلىك كىشى: ئارا توق تېرە رەڭگى',
    '👳🏿' => 'سەللىلىك كىشى: توق تېرە رەڭ',
    '👲🏻' => 'جۇڭگوچە تۇماق كىيگەن ئەر: ئاچ تېرە رەڭ',
    '👲🏼' => 'جۇڭگوچە تۇماق كىيگەن ئەر: ئارا ئاچ تېرە رەڭگى',
    '👲🏽' => 'جۇڭگوچە تۇماق كىيگەن ئەر: ئارا تېرە رەڭگى',
    '👲🏾' => 'جۇڭگوچە تۇماق كىيگەن ئەر: ئارا توق تېرە رەڭگى',
    '👲🏿' => 'جۇڭگوچە تۇماق كىيگەن ئەر: توق تېرە رەڭ',
    '🧕🏻' => 'ياغلىقلىق ئايال: ئاچ تېرە رەڭ',
    '🧕🏼' => 'ياغلىقلىق ئايال: ئارا ئاچ تېرە رەڭگى',
    '🧕🏽' => 'ياغلىقلىق ئايال: ئارا تېرە رەڭگى',
    '🧕🏾' => 'ياغلىقلىق ئايال: ئارا توق تېرە رەڭگى',
    '🧕🏿' => 'ياغلىقلىق ئايال: توق تېرە رەڭ',
    '🤵🏻' => 'تاكسىدولۇق ئەر: ئاچ تېرە رەڭ',
    '🤵🏼' => 'تاكسىدولۇق ئەر: ئارا ئاچ تېرە رەڭگى',
    '🤵🏽' => 'تاكسىدولۇق ئەر: ئارا تېرە رەڭگى',
    '🤵🏾' => 'تاكسىدولۇق ئەر: ئارا توق تېرە رەڭگى',
    '🤵🏿' => 'تاكسىدولۇق ئەر: توق تېرە رەڭ',
    '👰🏻' => 'چۈمبەللىك كېلىن: ئاچ تېرە رەڭ',
    '👰🏼' => 'چۈمبەللىك كېلىن: ئارا ئاچ تېرە رەڭگى',
    '👰🏽' => 'چۈمبەللىك كېلىن: ئارا تېرە رەڭگى',
    '👰🏾' => 'چۈمبەللىك كېلىن: ئارا توق تېرە رەڭگى',
    '👰🏿' => 'چۈمبەللىك كېلىن: توق تېرە رەڭ',
    '🤰🏻' => 'ھامىلدار ئايال: ئاچ تېرە رەڭ',
    '🤰🏼' => 'ھامىلدار ئايال: ئارا ئاچ تېرە رەڭگى',
    '🤰🏽' => 'ھامىلدار ئايال: ئارا تېرە رەڭگى',
    '🤰🏾' => 'ھامىلدار ئايال: ئارا توق تېرە رەڭگى',
    '🤰🏿' => 'ھامىلدار ئايال: توق تېرە رەڭ',
    '🤱🏻' => 'ئېمىش: ئاچ تېرە رەڭ',
    '🤱🏼' => 'ئېمىش: ئارا ئاچ تېرە رەڭگى',
    '🤱🏽' => 'ئېمىش: ئارا تېرە رەڭگى',
    '🤱🏾' => 'ئېمىش: ئارا توق تېرە رەڭگى',
    '🤱🏿' => 'ئېمىش: توق تېرە رەڭ',
    '👼🏻' => 'بوۋاق پەرىشتە: ئاچ تېرە رەڭ',
    '👼🏼' => 'بوۋاق پەرىشتە: ئارا ئاچ تېرە رەڭگى',
    '👼🏽' => 'بوۋاق پەرىشتە: ئارا تېرە رەڭگى',
    '👼🏾' => 'بوۋاق پەرىشتە: ئارا توق تېرە رەڭگى',
    '👼🏿' => 'بوۋاق پەرىشتە: توق تېرە رەڭ',
    '🎅🏻' => 'مىلاد بوۋاي: ئاچ تېرە رەڭ',
    '🎅🏼' => 'مىلاد بوۋاي: ئارا ئاچ تېرە رەڭگى',
    '🎅🏽' => 'مىلاد بوۋاي: ئارا تېرە رەڭگى',
    '🎅🏾' => 'مىلاد بوۋاي: ئارا توق تېرە رەڭگى',
    '🎅🏿' => 'مىلاد بوۋاي: توق تېرە رەڭ',
    '🤶🏻' => 'مىلاد موماي: ئاچ تېرە رەڭ',
    '🤶🏼' => 'مىلاد موماي: ئارا ئاچ تېرە رەڭگى',
    '🤶🏽' => 'مىلاد موماي: ئارا تېرە رەڭگى',
    '🤶🏾' => 'مىلاد موماي: ئارا توق تېرە رەڭگى',
    '🤶🏿' => 'مىلاد موماي: توق تېرە رەڭ',
    '🧙🏻' => 'سېھرىگەر: ئاچ تېرە رەڭ',
    '🧙🏼' => 'سېھرىگەر: ئارا ئاچ تېرە رەڭگى',
    '🧙🏽' => 'سېھرىگەر: ئارا تېرە رەڭگى',
    '🧙🏾' => 'سېھرىگەر: ئارا توق تېرە رەڭگى',
    '🧙🏿' => 'سېھرىگەر: توق تېرە رەڭ',
    '🧚🏻' => 'ئەرۋاھ: ئاچ تېرە رەڭ',
    '🧚🏼' => 'ئەرۋاھ: ئارا ئاچ تېرە رەڭگى',
    '🧚🏽' => 'ئەرۋاھ: ئارا تېرە رەڭگى',
    '🧚🏾' => 'ئەرۋاھ: ئارا توق تېرە رەڭگى',
    '🧚🏿' => 'ئەرۋاھ: توق تېرە رەڭ',
    '🧛🏻' => 'قانخور مۇردا: ئاچ تېرە رەڭ',
    '🧛🏼' => 'قانخور مۇردا: ئارا ئاچ تېرە رەڭگى',
    '🧛🏽' => 'قانخور مۇردا: ئارا تېرە رەڭگى',
    '🧛🏾' => 'قانخور مۇردا: ئارا توق تېرە رەڭگى',
    '🧛🏿' => 'قانخور مۇردا: توق تېرە رەڭ',
    '🧜🏻' => 'بېلىق ئادەم: ئاچ تېرە رەڭ',
    '🧜🏼' => 'بېلىق ئادەم: ئارا ئاچ تېرە رەڭگى',
    '🧜🏽' => 'بېلىق ئادەم: ئارا تېرە رەڭگى',
    '🧜🏾' => 'بېلىق ئادەم: ئارا توق تېرە رەڭگى',
    '🧜🏿' => 'بېلىق ئادەم: توق تېرە رەڭ',
    '🧝🏻' => 'پىر: ئاچ تېرە رەڭ',
    '🧝🏼' => 'پىر: ئارا ئاچ تېرە رەڭگى',
    '🧝🏽' => 'پىر: ئارا تېرە رەڭگى',
    '🧝🏾' => 'پىر: ئارا توق تېرە رەڭگى',
    '🧝🏿' => 'پىر: توق تېرە رەڭ',
    '💆🏻' => 'ئۇۋىلانغان كىشى: ئاچ تېرە رەڭ',
    '💆🏼' => 'ئۇۋىلانغان كىشى: ئارا ئاچ تېرە رەڭگى',
    '💆🏽' => 'ئۇۋىلانغان كىشى: ئارا تېرە رەڭگى',
    '💆🏾' => 'ئۇۋىلانغان كىشى: ئارا توق تېرە رەڭگى',
    '💆🏿' => 'ئۇۋىلانغان كىشى: توق تېرە رەڭ',
    '💇🏻' => 'چاچ ياساتقان كىشى: ئاچ تېرە رەڭ',
    '💇🏼' => 'چاچ ياساتقان كىشى: ئارا ئاچ تېرە رەڭگى',
    '💇🏽' => 'چاچ ياساتقان كىشى: ئارا تېرە رەڭگى',
    '💇🏾' => 'چاچ ياساتقان كىشى: ئارا توق تېرە رەڭگى',
    '💇🏿' => 'چاچ ياساتقان كىشى: توق تېرە رەڭ',
    '🚶🏻' => 'ماڭغان كىشى: ئاچ تېرە رەڭ',
    '🚶🏼' => 'ماڭغان كىشى: ئارا ئاچ تېرە رەڭگى',
    '🚶🏽' => 'ماڭغان كىشى: ئارا تېرە رەڭگى',
    '🚶🏾' => 'ماڭغان كىشى: ئارا توق تېرە رەڭگى',
    '🚶🏿' => 'ماڭغان كىشى: توق تېرە رەڭ',
    '🏃🏻' => 'يۈگۈرگەن كىشى: ئاچ تېرە رەڭ',
    '🏃🏼' => 'يۈگۈرگەن كىشى: ئارا ئاچ تېرە رەڭگى',
    '🏃🏽' => 'يۈگۈرگەن كىشى: ئارا تېرە رەڭگى',
    '🏃🏾' => 'يۈگۈرگەن كىشى: ئارا توق تېرە رەڭگى',
    '🏃🏿' => 'يۈگۈرگەن كىشى: توق تېرە رەڭ',
    '💃🏻' => 'ئۇسسۇل ئويناۋاتقان ئايال: ئاچ تېرە رەڭ',
    '💃🏼' => 'ئۇسسۇل ئويناۋاتقان ئايال: ئارا ئاچ تېرە رەڭگى',
    '💃🏽' => 'ئۇسسۇل ئويناۋاتقان ئايال: ئارا تېرە رەڭگى',
    '💃🏾' => 'ئۇسسۇل ئويناۋاتقان ئايال: ئارا توق تېرە رەڭگى',
    '💃🏿' => 'ئۇسسۇل ئويناۋاتقان ئايال: توق تېرە رەڭ',
    '🕺🏻' => 'ئۇسسۇل ئويناۋاتقان ئەر: ئاچ تېرە رەڭ',
    '🕺🏼' => 'ئۇسسۇل ئويناۋاتقان ئەر: ئارا ئاچ تېرە رەڭگى',
    '🕺🏽' => 'ئۇسسۇل ئويناۋاتقان ئەر: ئارا تېرە رەڭگى',
    '🕺🏾' => 'ئۇسسۇل ئويناۋاتقان ئەر: ئارا توق تېرە رەڭگى',
    '🕺🏿' => 'ئۇسسۇل ئويناۋاتقان ئەر: توق تېرە رەڭ',
    '🕴🏻' => 'كاستۇملۇق ئەر: ئاچ تېرە رەڭ',
    '🕴🏼' => 'كاستۇملۇق ئەر: ئارا ئاچ تېرە رەڭگى',
    '🕴🏽' => 'كاستۇملۇق ئەر: ئارا تېرە رەڭگى',
    '🕴🏾' => 'كاستۇملۇق ئەر: ئارا توق تېرە رەڭگى',
    '🕴🏿' => 'كاستۇملۇق ئەر: توق تېرە رەڭ',
    '👯🏻' => 'سورۇندىكى ئۇزۇن قۇلاق كىشىلەر: ئاچ تېرە رەڭ',
    '👯🏼' => 'سورۇندىكى ئۇزۇن قۇلاق كىشىلەر: ئارا ئاچ تېرە رەڭگى',
    '👯🏽' => 'سورۇندىكى ئۇزۇن قۇلاق كىشىلەر: ئارا تېرە رەڭگى',
    '👯🏾' => 'سورۇندىكى ئۇزۇن قۇلاق كىشىلەر: ئارا توق تېرە رەڭگى',
    '👯🏿' => 'سورۇندىكى ئۇزۇن قۇلاق كىشىلەر: توق تېرە رەڭ',
    '🧖🏻' => 'ھورداقتىكى كىشى: ئاچ تېرە رەڭ',
    '🧖🏼' => 'ھورداقتىكى كىشى: ئارا ئاچ تېرە رەڭگى',
    '🧖🏽' => 'ھورداقتىكى كىشى: ئارا تېرە رەڭگى',
    '🧖🏾' => 'ھورداقتىكى كىشى: ئارا توق تېرە رەڭگى',
    '🧖🏿' => 'ھورداقتىكى كىشى: توق تېرە رەڭ',
    '🧗🏻' => 'ياماشقان كىشى: ئاچ تېرە رەڭ',
    '🧗🏼' => 'ياماشقان كىشى: ئارا ئاچ تېرە رەڭگى',
    '🧗🏽' => 'ياماشقان كىشى: ئارا تېرە رەڭگى',
    '🧗🏾' => 'ياماشقان كىشى: ئارا توق تېرە رەڭگى',
    '🧗🏿' => 'ياماشقان كىشى: توق تېرە رەڭ',
    '🏇🏻' => 'ئات بەيگىسى: ئاچ تېرە رەڭ',
    '🏇🏼' => 'ئات بەيگىسى: ئارا ئاچ تېرە رەڭگى',
    '🏇🏽' => 'ئات بەيگىسى: ئارا تېرە رەڭگى',
    '🏇🏾' => 'ئات بەيگىسى: ئارا توق تېرە رەڭگى',
    '🏇🏿' => 'ئات بەيگىسى: توق تېرە رەڭ',
    '🏂🏻' => 'قار تېيىلىش: ئاچ تېرە رەڭ',
    '🏂🏼' => 'قار تېيىلىش: ئارا ئاچ تېرە رەڭگى',
    '🏂🏽' => 'قار تېيىلىش: ئارا تېرە رەڭگى',
    '🏂🏾' => 'قار تېيىلىش: ئارا توق تېرە رەڭگى',
    '🏂🏿' => 'قار تېيىلىش: توق تېرە رەڭ',
    '🏌🏻' => 'گولفچى: ئاچ تېرە رەڭ',
    '🏌🏼' => 'گولفچى: ئارا ئاچ تېرە رەڭگى',
    '🏌🏽' => 'گولفچى: ئارا تېرە رەڭگى',
    '🏌🏾' => 'گولفچى: ئارا توق تېرە رەڭگى',
    '🏌🏿' => 'گولفچى: توق تېرە رەڭ',
    '🏄🏻' => 'دولقۇن كەزگۈچى: ئاچ تېرە رەڭ',
    '🏄🏼' => 'دولقۇن كەزگۈچى: ئارا ئاچ تېرە رەڭگى',
    '🏄🏽' => 'دولقۇن كەزگۈچى: ئارا تېرە رەڭگى',
    '🏄🏾' => 'دولقۇن كەزگۈچى: ئارا توق تېرە رەڭگى',
    '🏄🏿' => 'دولقۇن كەزگۈچى: توق تېرە رەڭ',
    '🚣🏻' => 'قېيىقچى: ئاچ تېرە رەڭ',
    '🚣🏼' => 'قېيىقچى: ئارا ئاچ تېرە رەڭگى',
    '🚣🏽' => 'قېيىقچى: ئارا تېرە رەڭگى',
    '🚣🏾' => 'قېيىقچى: ئارا توق تېرە رەڭگى',
    '🚣🏿' => 'قېيىقچى: توق تېرە رەڭ',
    '🏊🏻' => 'ئۈزۈۋاتقان كىشى: ئاچ تېرە رەڭ',
    '🏊🏼' => 'ئۈزۈۋاتقان كىشى: ئارا ئاچ تېرە رەڭگى',
    '🏊🏽' => 'ئۈزۈۋاتقان كىشى: ئارا تېرە رەڭگى',
    '🏊🏾' => 'ئۈزۈۋاتقان كىشى: ئارا توق تېرە رەڭگى',
    '🏊🏿' => 'ئۈزۈۋاتقان كىشى: توق تېرە رەڭ',
    '⛹🏻' => 'توپ ئويناۋاتقان كىشى: ئاچ تېرە رەڭ',
    '⛹🏼' => 'توپ ئويناۋاتقان كىشى: ئارا ئاچ تېرە رەڭگى',
    '⛹🏽' => 'توپ ئويناۋاتقان كىشى: ئارا تېرە رەڭگى',
    '⛹🏾' => 'توپ ئويناۋاتقان كىشى: ئارا توق تېرە رەڭگى',
    '⛹🏿' => 'توپ ئويناۋاتقان كىشى: توق تېرە رەڭ',
    '🏋🏻' => 'ئېغىرلىق كۆتۈرگۈچى: ئاچ تېرە رەڭ',
    '🏋🏼' => 'ئېغىرلىق كۆتۈرگۈچى: ئارا ئاچ تېرە رەڭگى',
    '🏋🏽' => 'ئېغىرلىق كۆتۈرگۈچى: ئارا تېرە رەڭگى',
    '🏋🏾' => 'ئېغىرلىق كۆتۈرگۈچى: ئارا توق تېرە رەڭگى',
    '🏋🏿' => 'ئېغىرلىق كۆتۈرگۈچى: توق تېرە رەڭ',
    '🚴🏻' => 'ۋېلىسىپىتلىك كىشى: ئاچ تېرە رەڭ',
    '🚴🏼' => 'ۋېلىسىپىتلىك كىشى: ئارا ئاچ تېرە رەڭگى',
    '🚴🏽' => 'ۋېلىسىپىتلىك كىشى: ئارا تېرە رەڭگى',
    '🚴🏾' => 'ۋېلىسىپىتلىك كىشى: ئارا توق تېرە رەڭگى',
    '🚴🏿' => 'ۋېلىسىپىتلىك كىشى: توق تېرە رەڭ',
    '🚵🏻' => 'تاغ ۋېلىسىپىتى مىنگەن كىشى: ئاچ تېرە رەڭ',
    '🚵🏼' => 'تاغ ۋېلىسىپىتى مىنگەن كىشى: ئارا ئاچ تېرە رەڭگى',
    '🚵🏽' => 'تاغ ۋېلىسىپىتى مىنگەن كىشى: ئارا تېرە رەڭگى',
    '🚵🏾' => 'تاغ ۋېلىسىپىتى مىنگەن كىشى: ئارا توق تېرە رەڭگى',
    '🚵🏿' => 'تاغ ۋېلىسىپىتى مىنگەن كىشى: توق تېرە رەڭ',
    '🤸🏻' => 'پەي سوزۇۋاتقان كىشى: ئاچ تېرە رەڭ',
    '🤸🏼' => 'پەي سوزۇۋاتقان كىشى: ئارا ئاچ تېرە رەڭگى',
    '🤸🏽' => 'پەي سوزۇۋاتقان كىشى: ئارا تېرە رەڭگى',
    '🤸🏾' => 'پەي سوزۇۋاتقان كىشى: ئارا توق تېرە رەڭگى',
    '🤸🏿' => 'پەي سوزۇۋاتقان كىشى: توق تېرە رەڭ',
    '🤼🏻' => 'چېلىشچى: ئاچ تېرە رەڭ',
    '🤼🏼' => 'چېلىشچى: ئارا ئاچ تېرە رەڭگى',
    '🤼🏽' => 'چېلىشچى: ئارا تېرە رەڭگى',
    '🤼🏾' => 'چېلىشچى: ئارا توق تېرە رەڭگى',
    '🤼🏿' => 'چېلىشچى: توق تېرە رەڭ',
    '🤽🏻' => 'سۇ توپى ئويناۋاتقانلار: ئاچ تېرە رەڭ',
    '🤽🏼' => 'سۇ توپى ئويناۋاتقانلار: ئارا ئاچ تېرە رەڭگى',
    '🤽🏽' => 'سۇ توپى ئويناۋاتقانلار: ئارا تېرە رەڭگى',
    '🤽🏾' => 'سۇ توپى ئويناۋاتقانلار: ئارا توق تېرە رەڭگى',
    '🤽🏿' => 'سۇ توپى ئويناۋاتقانلار: توق تېرە رەڭ',
    '🤾🏻' => 'قولتوپ ئويناۋاتقان كىشى: ئاچ تېرە رەڭ',
    '🤾🏼' => 'قولتوپ ئويناۋاتقان كىشى: ئارا ئاچ تېرە رەڭگى',
    '🤾🏽' => 'قولتوپ ئويناۋاتقان كىشى: ئارا تېرە رەڭگى',
    '🤾🏾' => 'قولتوپ ئويناۋاتقان كىشى: ئارا توق تېرە رەڭگى',
    '🤾🏿' => 'قولتوپ ئويناۋاتقان كىشى: توق تېرە رەڭ',
    '🤹🏻' => 'شار ئوينىغۇچى: ئاچ تېرە رەڭ',
    '🤹🏼' => 'شار ئوينىغۇچى: ئارا ئاچ تېرە رەڭگى',
    '🤹🏽' => 'شار ئوينىغۇچى: ئارا تېرە رەڭگى',
    '🤹🏾' => 'شار ئوينىغۇچى: ئارا توق تېرە رەڭگى',
    '🤹🏿' => 'شار ئوينىغۇچى: توق تېرە رەڭ',
    '🧘🏻' => 'گىياھ ھەرىكەتلىك كىشى: ئاچ تېرە رەڭ',
    '🧘🏼' => 'گىياھ ھەرىكەتلىك كىشى: ئارا ئاچ تېرە رەڭگى',
    '🧘🏽' => 'گىياھ ھەرىكەتلىك كىشى: ئارا تېرە رەڭگى',
    '🧘🏾' => 'گىياھ ھەرىكەتلىك كىشى: ئارا توق تېرە رەڭگى',
    '🧘🏿' => 'گىياھ ھەرىكەتلىك كىشى: توق تېرە رەڭ',
    '🛀🏻' => 'يۇيۇنۇۋاتقان كىشى: ئاچ تېرە رەڭ',
    '🛀🏼' => 'يۇيۇنۇۋاتقان كىشى: ئارا ئاچ تېرە رەڭگى',
    '🛀🏽' => 'يۇيۇنۇۋاتقان كىشى: ئارا تېرە رەڭگى',
    '🛀🏾' => 'يۇيۇنۇۋاتقان كىشى: ئارا توق تېرە رەڭگى',
    '🛀🏿' => 'يۇيۇنۇۋاتقان كىشى: توق تېرە رەڭ',
    '🛌🏻' => 'كارىۋاتتىكى كىشى: ئاچ تېرە رەڭ',
    '🛌🏼' => 'كارىۋاتتىكى كىشى: ئارا ئاچ تېرە رەڭگى',
    '🛌🏽' => 'كارىۋاتتىكى كىشى: ئارا تېرە رەڭگى',
    '🛌🏾' => 'كارىۋاتتىكى كىشى: ئارا توق تېرە رەڭگى',
    '🛌🏿' => 'كارىۋاتتىكى كىشى: توق تېرە رەڭ',
    '👭🏻' => 'قول تۇتۇشقان ئاياللار: ئاچ تېرە رەڭ',
    '👭🏼' => 'قول تۇتۇشقان ئاياللار: ئارا ئاچ تېرە رەڭگى',
    '👭🏽' => 'قول تۇتۇشقان ئاياللار: ئارا تېرە رەڭگى',
    '👭🏾' => 'قول تۇتۇشقان ئاياللار: ئارا توق تېرە رەڭگى',
    '👭🏿' => 'قول تۇتۇشقان ئاياللار: توق تېرە رەڭ',
    '👫🏻' => 'قول تۇتۇشقان ئەر-ئايال: ئاچ تېرە رەڭ',
    '👫🏼' => 'قول تۇتۇشقان ئەر-ئايال: ئارا ئاچ تېرە رەڭگى',
    '👫🏽' => 'قول تۇتۇشقان ئەر-ئايال: ئارا تېرە رەڭگى',
    '👫🏾' => 'قول تۇتۇشقان ئەر-ئايال: ئارا توق تېرە رەڭگى',
    '👫🏿' => 'قول تۇتۇشقان ئەر-ئايال: توق تېرە رەڭ',
    '👬🏻' => 'قول تۇتۇشقان ئەرلەر: ئاچ تېرە رەڭ',
    '👬🏼' => 'قول تۇتۇشقان ئەرلەر: ئارا ئاچ تېرە رەڭگى',
    '👬🏽' => 'قول تۇتۇشقان ئەرلەر: ئارا تېرە رەڭگى',
    '👬🏾' => 'قول تۇتۇشقان ئەرلەر: ئارا توق تېرە رەڭگى',
    '👬🏿' => 'قول تۇتۇشقان ئەرلەر: توق تېرە رەڭ',
    '💏🏻' => 'سۆيۈش: ئاچ تېرە رەڭ',
    '💏🏼' => 'سۆيۈش: ئارا ئاچ تېرە رەڭگى',
    '💏🏽' => 'سۆيۈش: ئارا تېرە رەڭگى',
    '💏🏾' => 'سۆيۈش: ئارا توق تېرە رەڭگى',
    '💏🏿' => 'سۆيۈش: توق تېرە رەڭ',
    '💑🏻' => 'يۈرەكلىك جۈپلەر: ئاچ تېرە رەڭ',
    '💑🏼' => 'يۈرەكلىك جۈپلەر: ئارا ئاچ تېرە رەڭگى',
    '💑🏽' => 'يۈرەكلىك جۈپلەر: ئارا تېرە رەڭگى',
    '💑🏾' => 'يۈرەكلىك جۈپلەر: ئارا توق تېرە رەڭگى',
    '💑🏿' => 'يۈرەكلىك جۈپلەر: توق تېرە رەڭ',
    '🏻' => 'ئاچ تېرە رەڭ',
    '🏼' => 'ئارا ئاچ تېرە رەڭگى',
    '🏽' => 'ئارا تېرە رەڭگى',
    '🏾' => 'ئارا توق تېرە رەڭگى',
    '🏿' => 'توق تېرە رەڭ',
    '😀' => 'چىشلىق كۈلگەن چىراي',
    '😃' => 'ئاغزىنى ئېچىپ كۈلۈمسىرەش',
    '😄' => 'ئاغزىنى ئېچىپ كۈلۈمسىرىگەن چىراي',
    '😁' => 'چىشىنى چىقىرىپ كۈلۈمسىرەش',
    '😆' => 'كۆزىنى يۇمۇپ ئاغزىنى ئېچىپ كۈلۈمسىرەش',
    '😅' => 'ئاغزىنى ئېچىپ سوغۇق تەرلەپ كۈلۈمسىرەش',
    '🤣' => 'كۈلۈپ يېتىۋېلىش',
    '😂' => 'خۇش ياش ئاققان چىراي',
    '🙂' => 'ئىللىق خۇش چىراي',
    '🙃' => 'دۈم چىراي',
    '😉' => 'كۆز قىسىش',
    '😊' => 'تەبەسسۇملۇق كۆز ۋە خۇش چىراي',
    '😇' => 'خۇش سالاملىق چىراي',
    '😍' => 'يۈرەك كۆزلۈك خۇش چىراي',
    '🤩' => 'يۇلتۇز كۆرۈش',
    '😘' => 'سۆيگۈ ئەۋەتكەن چىراي',
    '😗' => 'سۆيگەن چىراي',
    '☺' => 'كۈلۈمسىرىگەن چىراي',
    '😚' => 'كۆزىنى يۇمۇپ سۆيگەن چىراي',
    '😙' => 'خۇش كۆزلۈك سۆيگەن چىراي',
    '😋' => 'شۆلگەيلىك چىراي',
    '😛' => 'تىلى چىقىپ قالغان چىراي',
    '😜' => 'تىلىنى چىقىرىپ كۆز قىسقان چىراي ئىپادىسى',
    '🤪' => 'ساراڭ چىراي',
    '😝' => 'كۆزىنى يۇمۇپ تىلىنى چىقارغان چىراي',
    '🤑' => 'پۇل چىراي',
    '🤗' => 'قۇچاقلىغان چىراي',
    '🤭' => 'ئاغزىنى تۇتقان چىراي',
    '🤫' => 'جىم چىراي',
    '🤔' => 'ئويچان چىراي',
    '🤐' => 'سىيرىتما چىراي',
    '🤨' => 'قېشى ئۆرلىگەن چىراي',
    '😐' => 'نورمال چىراي',
    '😑' => 'ئىپادىسىز چىراي',
    '😶' => 'ئېغىزسىز چىراي',
    '😏' => 'ھېجايغان چىراي',
    '😒' => 'مۇز چىراي',
    '🙄' => 'كۆزى پىرقىرىغان چىراي',
    '😬' => 'چىشى قېيىشقان چىراي',
    '🤥' => 'يالغانچى چىراي',
    '😌' => 'خاتىرجەم چىراي',
    '😔' => 'ئويغا چۆمگەن چىراي',
    '😪' => 'ئۇيقۇ چىراي',
    '🤤' => 'شۆلگەي ئاققان چىراي',
    '😴' => 'ئۇخلاق چىراي',
    '😷' => 'ماسكىلىق چىراي',
    '🤒' => 'تېرمومېتىرلىق چىراي',
    '🤕' => 'تېڭىق چىراي',
    '🤢' => 'كۆڭلى ئېلىشقان چىراي',
    '🤮' => 'قۇسقان چىراي',
    '🤧' => 'چۈشكۈرگەن چىراي',
    '😵' => 'باش قايغان چىراي',
    '🤯' => 'بېشى پارتلاش',
    '🤠' => 'پادىچى قالپاقلىق چىراي',
    '😎' => 'كۆزەينەك تاقىغان خۇش چىراي',
    '🤓' => 'دۆت چىراي',
    '🧐' => 'يەكچەشمە چىراي',
    '😕' => 'ھاڭۋاققان چىراي',
    '😟' => 'ئەنسىز چىراي',
    '🙁' => 'سەل قوشۇمىلىق چىراي',
    '☹' => 'قوشۇما تۈرگەن چىراي',
    '😮' => 'ئاغزى ئوچۇق چىراي',
    '😯' => 'جىمجىت چىراي',
    '😲' => 'ھەيران چىراي',
    '😳' => 'قىزارغان چىراي',
    '😦' => 'ئاغزىنى ئېچىپ قوشۇمىسىنى تۈرگەن چىراي',
    '😧' => 'ئازابلىق چىراي',
    '😨' => 'قورقۇنچلۇق چىراي',
    '😰' => 'ئاغزى ئوچۇق سوغۇق تەرلىگەن چىراي',
    '😥' => 'ئۈمىدسىز ئەمما خاتىرجەم چىراي',
    '😢' => 'يىغلىغان چىراي',
    '😭' => 'ئۆكسۈپ يىغلىغان چىراي',
    '😱' => 'قورقۇنچلۇق چىرقىرىغان چىراي',
    '😖' => 'بىزار چىراي',
    '😣' => 'كەسكىن چىراي',
    '😞' => 'ئۈمىدسىز چىراي',
    '😓' => 'سوغۇق تەرلىك چىراي',
    '😩' => 'ھارغان چىراي',
    '😫' => 'ھارغىن چىراي',
    '😤' => 'بۇرنىدىن ھور چىققان چىراي',
    '😡' => 'ھومايغان چىراي',
    '😠' => 'خاپا چىراي',
    '🤬' => 'ئاغزىدا بەلگە چىراي',
    '😈' => 'مۈڭگۈزلۈك خۇش چىراي',
    '👿' => 'مۈڭگۈزلۈك خاپا چىراي',
    '💀' => 'باش سۆڭەك',
    '☠' => 'باش سۆڭەك ۋە ئۇستىخان',
    '💩' => 'پوق',
    '🤡' => 'سېرىكچى چىراي',
    '👹' => 'دىۋە',
    '👺' => 'جىن',
    '👻' => 'ئالۋاستى',
    '👽' => 'تاشقى پىلانېتلىقلار',
    '👾' => 'تاشقى پىلانېتلىق يالماۋۇز',
    '🤖' => 'روبوت چىراي',
    '😺' => 'ئاغزى ئوچۇق خۇش مۈشۈك چىراي',
    '😸' => 'چىشىنى چىقارغان خۇش كۆزلۈك مۈشۈك چىراي',
    '😹' => 'خۇش ياشلىق مۈشۈك چىراي',
    '😻' => 'يۈرەك كۆزلۈك خۇش مۈشۈك چىراي',
    '😼' => 'ئاچچىق كۈلكىلىك مۈشۈك چىراي',
    '😽' => 'كۆزىنى يۇمۇپ سۆيگەن مۈشۈك چىراي',
    '🙀' => 'ھارغان مۈشۈك چىراي',
    '😿' => 'يىغلىغان مۈشۈك چىراي',
    '😾' => 'ھومايغان مۈشۈك چىراي',
    '🙈' => 'ياماننى كۆرمەس مايمۇن',
    '🙉' => 'ياماننى ئاڭلىماس مايمۇن',
    '🙊' => 'يامان سۆزلىمەس مايمۇن',
    '💌' => 'سۆيگۈ خېتى',
    '💘' => 'ئوقلۇق يۈرەك',
    '💝' => 'باغلاق يۈرەك',
    '💖' => 'چاقنىغان يۈرەك',
    '💗' => 'ئۆسۈۋاتقان يۈرەك',
    '💓' => 'سوقۇۋاتقان يۈرەك',
    '💞' => 'ئايلانغان يۈرەك',
    '💕' => 'قوش يۈرەك',
    '💟' => 'يۈرەك بېزەك',
    '❣' => 'يۈرەكلىك ئۈندەش',
    '💔' => 'سۇلغان يۈرەك',
    '❤' => 'قىزىل يۈرەك',
    '🧡' => 'قىزغۇچ يۈرەك',
    '💛' => 'سېرىق يۈرەك',
    '💚' => 'يېشىل يۈرەك',
    '💙' => 'كۆك يۈرەك',
    '💜' => 'سۆسۈن يۈرەك',
    '🖤' => 'قارا يۈرەك',
    '💋' => 'سۆيگەن ئىز',
    '💯' => 'يۈز نومۇر',
    '💢' => 'ئاچچىق بەلگىسى',
    '💥' => 'سوقۇلۇش',
    '💫' => 'قېيىش',
    '💦' => 'تەر تامچىسى',
    '💨' => 'قۇيۇندەك كېتىش',
    '🕳' => 'تۆشۈك',
    '💬' => 'سۆز رامكىسى',
    '🗨' => 'سول سۆز رامكىسى',
    '🗯' => 'ئوڭ خاپىلىق كۆپۈكچىسى',
    '💭' => 'ئوي شارچىسى',
    '💤' => 'ئۇخخخ',
    '👋' => 'قول پۇلاڭلىتىش',
    '🤚' => 'كۆتۈرگەن قولنىڭ ئارقىسى',
    '🖐' => 'بارماقلىرىنى يېيىپ كۆتۈرگەن قول',
    '✋' => 'كۆتۈرگەن قول',
    '🖖' => 'ۋولقان سالام',
    '👌' => 'ماقۇل بەلگىسى',
    '✌' => 'غەلبە ئىشارىسى',
    '🤞' => 'كېسىشكەن بارماقلار',
    '🤟' => 'سۆيىمەن دېگەن ئىشارە',
    '🤘' => 'مۈڭگۈز بەلگىسى',
    '🤙' => 'تېلېفون قىلىڭ',
    '👈' => 'ئارقىچە سولنى كۆرسەتكەن كۆرسەتكۈچ بارماق',
    '👉' => 'ئارقىچە ئوڭنى كۆرسەتكەن كۆرسەتكۈچ بارماق',
    '👆' => 'ئارقىچە ئۈستىنى كۆرسەتكەن كۆرسەتكۈچ بارماق',
    '🖕' => 'ئوتتۇرا بارماق',
    '👇' => 'ئارقىچە ئاستىنى كۆرسەتكەن كۆرسەتكۈچ بارماق',
    '☝' => 'ئۈستىنى كۆرسەتكەن كۆرسەتكۈچ بارماق',
    '👍' => 'قوللاش',
    '👎' => 'پۇتلاش',
    '✊' => 'كۆتۈرگەن مۇشت',
    '👊' => 'كەلگەن مۇشت',
    '🤛' => 'سول مۇشت',
    '🤜' => 'ئوڭ مۇشت',
    '👏' => 'چاۋاك',
    '🙌' => 'قول كۆتۈرۈش',
    '👐' => 'ئوچۇق قول',
    '🤲' => 'ئوچۇم',
    '🤝' => 'قول قىسىش',
    '🙏' => 'قوۋۇشقان قول',
    '✍' => 'يېزىۋاتقان قول',
    '💅' => 'تىرناق بوياش',
    '🤳' => 'ئۆزتارتىم',
    '💪' => 'ئېگىلگەن بىلەك',
    '👂' => 'قۇلاق',
    '👃' => 'بۇرۇن',
    '🧠' => 'مېڭە',
    '👀' => 'كۆزلەر',
    '👁' => 'كۆز',
    '👅' => 'تىل',
    '👄' => 'ئېغىز',
    '👶' => 'بوۋاق',
    '🧒' => 'بالا',
    '👦' => 'ئوغۇل',
    '👧' => 'قىز',
    '🧑' => 'چوڭلار',
    '👱' => 'ئالتۇن چاچ كىشى',
    '👨' => 'ئەر',
    '🧔' => 'ساقاللىق كىشى',
    '👩' => 'ئايال',
    '🧓' => 'قېرىلار',
    '👴' => 'بوۋاي',
    '👵' => 'موماي',
    '🙍' => 'قوشۇمىسىنى تۈرگەن كىشى',
    '🙎' => 'ھومايغان كىشى',
    '🙅' => 'ياق دەپ ئىشارە قىلغان كىشى',
    '🙆' => 'ماقۇل دەپ ئىشارە قىلغان كىشى',
    '💁' => 'تاپان ھەققى بەرگەن كىشى',
    '🙋' => 'قول كۆتۈرگەن كىشى',
    '🙇' => 'ئېگىلگەن كىشى',
    '🤦' => 'يۈزىنى تۇتقان كىشى',
    '🤷' => 'قىسىلغان كىشى',
    '👮' => 'ساقچى',
    '🕵' => 'رازۋېدچىك',
    '💂' => 'قاراۋۇل',
    '👷' => 'قۇرۇلۇشچى',
    '🤴' => 'شاھزادە',
    '👸' => 'مەلىكە',
    '👳' => 'سەللىلىك كىشى',
    '👲' => 'جۇڭگوچە تۇماق كىيگەن ئەر',
    '🧕' => 'ياغلىقلىق ئايال',
    '🤵' => 'تاكسىدولۇق ئەر',
    '👰' => 'چۈمبەللىك كېلىن',
    '🤰' => 'ھامىلدار ئايال',
    '🤱' => 'ئېمىش',
    '👼' => 'بوۋاق پەرىشتە',
    '🎅' => 'مىلاد بوۋاي',
    '🤶' => 'مىلاد موماي',
    '🧙' => 'سېھرىگەر',
    '🧚' => 'ئەرۋاھ',
    '🧛' => 'قانخور مۇردا',
    '🧜' => 'بېلىق ئادەم',
    '🧝' => 'پىر',
    '🧞' => 'شاياتۇن',
    '🧟' => 'زومبى',
    '💆' => 'ئۇۋىلانغان كىشى',
    '💇' => 'چاچ ياساتقان كىشى',
    '🚶' => 'ماڭغان كىشى',
    '🏃' => 'يۈگۈرگەن كىشى',
    '💃' => 'ئۇسسۇل ئويناۋاتقان ئايال',
    '🕺' => 'ئۇسسۇل ئويناۋاتقان ئەر',
    '🕴' => 'كاستۇملۇق ئەر',
    '👯' => 'سورۇندىكى ئۇزۇن قۇلاق كىشىلەر',
    '🧖' => 'ھورداقتىكى كىشى',
    '🧗' => 'ياماشقان كىشى',
    '🤺' => 'قىلىچلىق كىشى',
    '🏇' => 'ئات بەيگىسى',
    '⛷' => 'چاڭغىچى',
    '🏂' => 'قار تېيىلىش',
    '🏌' => 'گولفچى',
    '🏄' => 'دولقۇن كەزگۈچى',
    '🚣' => 'قېيىقچى',
    '🏊' => 'ئۈزۈۋاتقان كىشى',
    '⛹' => 'توپ ئويناۋاتقان كىشى',
    '🏋' => 'ئېغىرلىق كۆتۈرگۈچى',
    '🚴' => 'ۋېلىسىپىتلىك كىشى',
    '🚵' => 'تاغ ۋېلىسىپىتى مىنگەن كىشى',
    '🤸' => 'پەي سوزۇۋاتقان كىشى',
    '🤼' => 'چېلىشچى',
    '🤽' => 'سۇ توپى ئويناۋاتقانلار',
    '🤾' => 'قولتوپ ئويناۋاتقان كىشى',
    '🤹' => 'شار ئوينىغۇچى',
    '🧘' => 'گىياھ ھەرىكەتلىك كىشى',
    '🛀' => 'يۇيۇنۇۋاتقان كىشى',
    '🛌' => 'كارىۋاتتىكى كىشى',
    '👭' => 'قول تۇتۇشقان ئاياللار',
    '👫' => 'قول تۇتۇشقان ئەر-ئايال',
    '👬' => 'قول تۇتۇشقان ئەرلەر',
    '💏' => 'سۆيۈش',
    '💑' => 'يۈرەكلىك جۈپلەر',
    '🗣' => 'سۆزلەۋاتقان باش',
    '👤' => 'كىشى سايىسى',
    '👥' => 'كىشىلەرنىڭ سايىسى',
    '👪' => 'ئائىلە',
    '👣' => 'ئاياغ ئىزى',
    '🐵' => 'مايمۇن چىراي',
    '🐒' => 'مايمۇن',
    '🦍' => 'گورىللا',
    '🐶' => 'ئىت چىراي',
    '🐕' => 'ئىت',
    '🐩' => 'شىر ئىت',
    '🐺' => 'بۆرە يۈز',
    '🦊' => 'تۈلكە چىراي',
    '🐱' => 'مۈشۈك چىراي',
    '🐈' => 'مۈشۈك',
    '🦁' => 'شىر چىراي',
    '🐯' => 'يولۋاس چىراي',
    '🐅' => 'يولۋاس',
    '🐆' => 'قاپلان',
    '🐴' => 'ئات چىراي',
    '🐎' => 'ئات',
    '🦄' => 'قوناق چىراي',
    '🦓' => 'تاغىلئات',
    '🦌' => 'بۇغا',
    '🐮' => 'ئىنەك چىراي',
    '🐂' => 'ئۆكۈز',
    '🐃' => 'سۇ كالىسى',
    '🐄' => 'ئىنەك',
    '🐷' => 'چوشقا چىراي',
    '🐖' => 'چوشقا',
    '🐗' => 'توڭگۇز',
    '🐽' => 'چوشقا بۇرۇن',
    '🐏' => 'قوشقار',
    '🐑' => 'ساغلىق',
    '🐐' => 'ئۆچكە',
    '🐪' => 'تۆگە',
    '🐫' => 'قوش لوككىلىق تۆگە',
    '🦒' => 'زىراپە',
    '🐘' => 'پىل',
    '🦏' => 'كەركىدان',
    '🐭' => 'چاشقان چىراي',
    '🐁' => 'چاشقان',
    '🐀' => 'تورقا',
    '🐹' => 'تورقا چىراي',
    '🐰' => 'توشقان چىراي',
    '🐇' => 'توشقان',
    '🐿' => 'چىپار تىيىن',
    '🦔' => 'كىرپە',
    '🦇' => 'شەپەرەڭ',
    '🐻' => 'ئېيىق چىراي',
    '🐨' => 'خالتائېيىق',
    '🐼' => 'مۈشۈكئېيىق چىراي',
    '🐾' => 'پەنجە ئىزى',
    '🦃' => 'ياۋا توخۇ',
    '🐔' => 'توخۇ',
    '🐓' => 'خوراز',
    '🐣' => 'تۇخۇمدىن چىققان چۆجە',
    '🐤' => 'چۆجە',
    '🐥' => 'ئالدىچە چۆجە',
    '🐦' => 'قۇش',
    '🐧' => 'پىنگۋىن',
    '🕊' => 'كەپتەر',
    '🦅' => 'بۈركۈت',
    '🦆' => 'ئۆردەك',
    '🦉' => 'مۈشۈكياپىلاق',
    '🐸' => 'پاقا چىراي',
    '🐊' => 'تىمساھ',
    '🐢' => 'تاشپاقا',
    '🦎' => 'كەسلەنچۈك',
    '🐍' => 'يىلان',
    '🐲' => 'ئەجدىھا چىراي',
    '🐉' => 'ئەجدىھا',
    '🦕' => 'كەسلەنچۈك پۇتلۇقلار',
    '🦖' => 'ت-رېكس',
    '🐳' => 'پۇشقۇرۇۋاتقان كىت',
    '🐋' => 'كىت',
    '🐬' => 'دېلفىن',
    '🐟' => 'بېلىق',
    '🐠' => 'ئىسسىق بەلباغ بېلىقى',
    '🐡' => 'توقماق بېلىق',
    '🦈' => 'لەھەڭ',
    '🐙' => 'سەككىز ئاياغ',
    '🐚' => 'قۇلۇلە قېپى',
    '🦀' => 'قىسقۇچپاقا',
    '🦐' => 'راك',
    '🦑' => 'قاراقچىبېلىق',
    '🐌' => 'قۇلۇلە',
    '🦋' => 'كېپىنەك',
    '🐛' => 'قۇرت',
    '🐜' => 'چۈمۈلە',
    '🐝' => 'ھەسەل ھەرىسى',
    '🐞' => 'خانقىز',
    '🦗' => 'پالاقتوپ',
    '🕷' => 'ئۆمۈچۈك',
    '🕸' => 'ئۆمۈچۈك تورى',
    '🦂' => 'چايان',
    '💐' => 'گۈلدەستە',
    '🌸' => 'گىلاس چېچىكى',
    '💮' => 'ئاق گۈل',
    '🏵' => 'ئەتىر',
    '🌹' => 'ئەتىرگۈل',
    '🥀' => 'سۇلغان گۈل',
    '🌺' => 'چېچەكياغاچ',
    '🌻' => 'ئاپتاپپەرەس',
    '🌼' => 'چېچەك',
    '🌷' => 'كۈركۈم',
    '🌱' => 'مايسا',
    '🌲' => 'ئارچا',
    '🌳' => 'يوپۇرماق تاشلار',
    '🌴' => 'پالما',
    '🌵' => 'كاكتۇس',
    '🌾' => 'شال',
    '🌿' => 'ئوت-چۆپ',
    '☘' => 'ئۈچقۇلاق',
    '🍀' => 'تۆتياپراق',
    '🍁' => 'ئېرەن يوپۇرمىقى',
    '🍂' => 'چۈشكەن يوپۇرماق',
    '🍃' => 'لەيلىگەن يوپۇرماق',
    '🍄' => 'ئېشەكمەدىكى',
    '🍇' => 'ئۈزۈم',
    '🍈' => 'قوغۇن',
    '🍉' => 'تاۋۇز',
    '🍊' => 'ئاپېلسىن',
    '🍋' => 'لېمون',
    '🍌' => 'بانان',
    '🍍' => 'ئاناناس',
    '🍎' => 'قىزىل ئالما',
    '🍏' => 'يېشىل ئالما',
    '🍐' => 'نەشپۈت',
    '🍑' => 'شاپتۇل',
    '🍒' => 'گىلاس',
    '🍓' => 'بۆلجۈرگەن',
    '🥝' => 'مايمۇن شاپتۇلى',
    '🍅' => 'پەمىدۇر',
    '🥥' => 'كوكۇس',
    '🥑' => 'ئاۋوكادو',
    '🍆' => 'پىدىگەن',
    '🥔' => 'بەرەڭگە',
    '🥕' => 'سەۋزە',
    '🌽' => 'قوناق قۇلىقى',
    '🌶' => 'ئاچچىق مۇچ',
    '🥒' => 'تەرخەمەك',
    '🥦' => 'يېشىل-چېچەك',
    '🥜' => 'يەر ياڭىقى',
    '🌰' => 'كاشتان',
    '🍞' => 'نان',
    '🥐' => 'مۈڭگۈز بولكا',
    '🥖' => 'فىرانسۇزچە بولكا',
    '🥨' => 'يۈرەكبولكا',
    '🥞' => 'قازان كاكچىسى',
    '🧀' => 'پىشلاق پارچىسى',
    '🍖' => 'سۆڭەكلىك گۆش',
    '🍗' => 'پۇت گۆش',
    '🥩' => 'گۆش پارچىسى',
    '🥓' => 'چوشقا كاۋىپى',
    '🍔' => 'ھامبۇرگ بولكىسى',
    '🍟' => 'فىرانسۇزچە قىزارتما',
    '🍕' => 'پىتسا',
    '🌭' => 'خوت دوگ',
    '🥪' => 'ساندۋىچ',
    '🌮' => 'تاكو',
    '🌯' => 'قىيما',
    '🥙' => 'تۈگۈك بولكا',
    '🥚' => 'تۇخۇم',
    '🍳' => 'پىشۇرۇش',
    '🥘' => 'لېگەنلىك يېمەكلىك',
    '🍲' => 'قازاندىكى ئاش',
    '🥣' => 'قوشۇقلۇق قاچا',
    '🥗' => 'يېشىل سالات',
    '🍿' => 'ئېتىلدۇرما',
    '🥫' => 'قۇتىلىق يېمەكلىك',
    '🍱' => 'ئەپلىك ئاش',
    '🍘' => 'گۈرۈچ ئېتىلدۇرمىسى',
    '🍙' => 'گۈرۈچ توپ',
    '🍚' => 'پىشىق گۈرۈچ',
    '🍛' => 'قورۇغان گۈرۈچ',
    '🍜' => 'ھورلۇق قاچا',
    '🍝' => 'ئىتالىيە چۆپى',
    '🍠' => 'تاتلىق بەرەڭگە قىزارتمىسى',
    '🍢' => 'ئودېن',
    '🍣' => 'سۇشى',
    '🍤' => 'قورۇلغان راك',
    '🍥' => 'يۆگىمەچ بېلىق پىشۇرۇقى',
    '🍡' => 'دانگو',
    '🥟' => 'تۈگرە',
    '🥠' => 'تەلەي پىشۇرقى',
    '🥡' => 'قەغەز قاپ',
    '🍦' => 'يۇمشاق مۇزقايماق',
    '🍧' => 'قىرغان مۇز',
    '🍨' => 'مۇزقايماق',
    '🍩' => 'ھالقا پىشۇرۇق',
    '🍪' => 'پىشۇرۇق',
    '🎂' => 'تۇغۇلغان كۈن تورتى',
    '🍰' => 'كىچىك تورت',
    '🥧' => 'پۆرە',
    '🍫' => 'قەلەمچە شاكىلات',
    '🍬' => 'كەمپۈت',
    '🍭' => 'ساپاقلىق كەمپۈت',
    '🍮' => 'قايماق ئۇيۇتمىسى',
    '🍯' => 'ھەسەل قاچىسى',
    '🍼' => 'ئېمىزگۈ قۇتا',
    '🥛' => 'بىر قاچا سۈت',
    '☕' => 'ئىسسىق ئىچىملىك',
    '🍵' => 'پىيالە',
    '🍶' => 'ساكەي',
    '🍾' => 'ياغاچ تۇۋاقلىق بوتۇلكا',
    '🍷' => 'ھاراق رومكىسى',
    '🍸' => 'كوكتېل رومكىسى',
    '🍹' => 'ئىسسىق بەلباغ ئىچىملىكى',
    '🍺' => 'پىۋا رومكىسى',
    '🍻' => 'پىۋا سوقۇشتۇرۇش',
    '🥂' => 'رومكا سوقۇشتۇرۇش',
    '🥃' => 'ئەينەك رومكا',
    '🥤' => 'سۈمۈرگۈچلۈك قاچا',
    '🥢' => 'چوكا',
    '🍽' => 'ئارا-پىچاق ۋە تەخسە',
    '🍴' => 'ئارا ۋە پىچاق',
    '🥄' => 'قوشۇق',
    '🔪' => 'ئاشخانا پىچىقى',
    '🏺' => 'لوڭقا',
    '🌍' => 'ياۋروپا-ئافرىقىنى كۆرسەتكەن گىلوبۇس',
    '🌎' => 'ئىككى ئامېرىكىنى كۆرسەتكەن گىلوبۇس',
    '🌏' => 'ئاسىيا-ئاۋسترالىيەنى كۆرسەتكەن گىلوبۇس',
    '🌐' => 'مېردىيانلىق گىلوبۇس',
    '🗺' => 'دۇنيا خەرىتىسى',
    '🗾' => 'ياپونىيە خەرىتىسى',
    '🏔' => 'قارلىق تاغ',
    '⛰' => 'تاغ',
    '🌋' => 'يانارتاغ',
    '🗻' => 'فۇجى تېغى',
    '🏕' => 'دالىدا قونۇش',
    '🏖' => 'قىرغاق ۋە كۈنلۈك',
    '🏜' => 'قۇملۇق',
    '🏝' => 'قۇملۇق ئارال',
    '🏞' => 'دۆلەتلىك باغچا',
    '🏟' => 'تەنتەربىيە مەيدانى',
    '🏛' => 'قەدىمىي قۇرۇلۇش',
    '🏗' => 'بىنا قۇرۇلۇشى',
    '🏘' => 'ئۆي تۇرالغۇ',
    '🏚' => 'تاشلاندۇق ئۆي',
    '🏠' => 'قورۇ',
    '🏡' => 'گۈللۈك ئۆي',
    '🏢' => 'ئىشخانا بىناسى',
    '🏣' => 'ياپونچە پوچتىخانا',
    '🏤' => 'پوچتىخانا',
    '🏥' => 'دوختۇرخانا',
    '🏦' => 'بانكا',
    '🏨' => 'مېھمانساراي',
    '🏩' => 'ئاشىق-مەشۇقلار مېھمانسارىيى',
    '🏪' => 'قولاي دۇكان',
    '🏫' => 'مەكتەپ',
    '🏬' => 'تۈرلۈك ماللار ماگزىنى',
    '🏭' => 'زاۋۇت',
    '🏯' => 'ياپونچە قەلئە',
    '🏰' => 'قەلئە',
    '💒' => 'توي',
    '🗼' => 'توكيو مۇنارى',
    '🗽' => 'ئەركىنلىك ھەيكىلى',
    '⛪' => 'چېركاۋ',
    '🕌' => 'مەسچىت',
    '🕍' => 'سىناگوگ',
    '⛩' => 'شىنتو ئىبادەتخانىسى',
    '🕋' => 'كەبە',
    '⛲' => 'ئوقبۇلاق',
    '⛺' => 'چېدىر',
    '🌁' => 'تۇمانلىق',
    '🌃' => 'يۇلتۇزلۇق كېچە',
    '🏙' => 'شەھەر مەنزىرىسى',
    '🌄' => 'تاغدىن كۈن چىقىش',
    '🌅' => 'كۈن چىقىش',
    '🌆' => 'گۇگۇمدىكى شەھەر',
    '🌇' => 'كۈن پېتىش',
    '🌉' => 'كېچىدىكى كۆۋرۈك',
    '♨' => 'ئىسسىق بۇلاق',
    '🎠' => 'ئايلانما ئۆي',
    '🎡' => 'ئويۇن چاقپەلىكى',
    '🎢' => 'ھاھۇ پەلەك',
    '💈' => 'ساتراچ تۈۋرۈكى',
    '🎪' => 'سېرىك چېدىرى',
    '🚂' => 'پاراۋۇز',
    '🚃' => 'ۋاگون',
    '🚄' => 'تېز پويىز',
    '🚅' => 'تېز سۈرئەتلىك ئوقپويىز',
    '🚆' => 'پويىز',
    '🚇' => 'مېترو',
    '🚈' => 'يېنىك تۆمۈريول',
    '🚉' => 'ۋوگزال',
    '🚊' => 'تىرامۋاي',
    '🚝' => 'بىررېلىس',
    '🚞' => 'تاغ تۆمۈريولى',
    '🚋' => 'تىرامۋاي ماشىنا',
    '🚌' => 'ئاپتوبۇس',
    '🚍' => 'كېلىۋاتقان ئاپتوبۇس',
    '🚎' => 'تىراللىبۇس',
    '🚐' => 'مىنىبۇس',
    '🚑' => 'قۇتقۇزۇش ماشىنىسى',
    '🚒' => 'ئوت ئۆچۈرۈش ماشىنىسى',
    '🚓' => 'ساقچى ماشىنىسى',
    '🚔' => 'كېلىۋاتقان ساقچى ماشىنىسى',
    '🚕' => 'تاكسى',
    '🚖' => 'كېلىۋاتقان تاكسى',
    '🚗' => 'ئاپتوموبىل',
    '🚘' => 'كېلىۋاتقان ئاپتوموبىل',
    '🚙' => 'دالا ماشىنىسى',
    '🚚' => 'مال ماشىنىسى',
    '🚛' => 'چاتما مال ماشىنىسى',
    '🚜' => 'تىراكتور',
    '🏎' => 'مۇسابىقە ماشىنىسى',
    '🏍' => 'موتوسىكلىت',
    '🛵' => 'كىچىك موتوسىكلىت',
    '🚲' => 'ۋېلىسىپىت',
    '🛴' => 'چاقلىق تېيىلغۇ',
    '🚏' => 'ئاپتوبۇس بېكىتى',
    '🛣' => 'موتورلۇق قاتناش يولى',
    '🛤' => 'تۆمۈر يول',
    '🛢' => 'ماي كۈپى',
    '⛽' => 'ماي ناسوسى',
    '🚨' => 'ساقچى ماشىنىسىنىڭ چىرىقى',
    '🚥' => 'تۈز قاتناش چىرىقى',
    '🚦' => 'تىك قاتناش چىرىقى',
    '🛑' => 'توختاش بەلگىسى',
    '🚧' => 'قۇرۇلۇش',
    '⚓' => 'لەڭگەر',
    '⛵' => 'قېيىق',
    '🛶' => 'قولۋاق',
    '🚤' => 'تېز قېيىق',
    '🛳' => 'يولۇچىلار كېمىسى',
    '⛴' => 'ساياھەت كېمىسى',
    '🛥' => 'موتورلۇق قېيىق',
    '🚢' => 'كېمە',
    '✈' => 'ئايروپىلان',
    '🛩' => 'كىچىك ئايروپىلان',
    '🛫' => 'ئايروپىلان ئۇچۇش',
    '🛬' => 'ئايروپىلان قونۇش',
    '💺' => 'ئورۇن',
    '🚁' => 'تىكئۇچار',
    '🚟' => 'ئاسما پويىز',
    '🚠' => 'تاغ ئاسما يولى',
    '🚡' => 'ئاسما تىرامۋاي',
    '🛰' => 'سۈنئىي ھەمراھ',
    '🚀' => 'راكېتا',
    '🛸' => 'ئۇچار تەخسە',
    '🛎' => 'يۈكتاقچى قوڭغۇرىقى',
    '⌛' => 'قۇمسائەت',
    '⏳' => 'قۇم ئېقىۋاتقان قۇمسائەت',
    '⌚' => 'سائەت',
    '⏰' => 'قوڭغۇراق سائەت',
    '⏱' => 'ۋاقىت سانىغۇچ',
    '⏲' => 'ۋاقىتچى سائەت',
    '🕰' => 'تام سائەت',
    '🕛' => 'سائەت ئون ئىككى',
    '🕧' => 'ئون ئىككى يېرىم',
    '🕐' => 'سائەت بىر',
    '🕜' => 'بىر يېرىم',
    '🕑' => 'سائەت ئىككى',
    '🕝' => 'ئىككى يېرىم',
    '🕒' => 'سائەت ئۈچ',
    '🕞' => 'ئۈچ يېرىم',
    '🕓' => 'سائەت تۆت',
    '🕟' => 'تۆت يېرىم',
    '🕔' => 'سائەت بەش',
    '🕠' => 'بەش يېرىم',
    '🕕' => 'سائەت ئالتە',
    '🕡' => 'ئالتە يېرىم',
    '🕖' => 'سائەت يەتتە',
    '🕢' => 'يەتتە يېرىم',
    '🕗' => 'سائەت سەككىز',
    '🕣' => 'سەككىز يېرىم',
    '🕘' => 'سائەت توققۇز',
    '🕤' => 'توققۇز يېرىم',
    '🕙' => 'سائەت ئون',
    '🕥' => 'ئون يېرىم',
    '🕚' => 'سائەت ئون بىر',
    '🕦' => 'ئون بىر يېرىم',
    '🌑' => 'يېڭى ئاي',
    '🌒' => 'پۈتەر ئورغاق ئاي',
    '🌓' => 'باش چارەك ئاي',
    '🌔' => 'تولار چوڭ ئاي',
    '🌕' => 'تولۇن ئاي',
    '🌖' => 'يۈتەر چوڭ ئاي',
    '🌗' => 'ئاخىرقى چارەك ئاي',
    '🌘' => 'يۈتەر ئورغاق ئاي',
    '🌙' => 'ئورغاق ئاي',
    '🌚' => 'يۈزلۈك يېڭى ئاي',
    '🌛' => 'يۈزلۈك باش چارەك ئاي',
    '🌜' => 'يۈزلۈك ئاخىرقى چارەك ئاي',
    '🌡' => 'تېرمومېتىر',
    '☀' => 'كۈن',
    '🌝' => 'يۈزلۈك تولۇن ئاي',
    '🌞' => 'يۈزلۈك قۇياش',
    '⭐' => 'ئاق ئارا يۇلتۇز',
    '🌟' => 'چاقنار يۇلتۇز',
    '🌠' => 'ئاقار يۇلتۇز',
    '🌌' => 'سامان يولى',
    '☁' => 'بۇلۇت',
    '⛅' => 'بۇلۇتلۇق قۇياش',
    '⛈' => 'گۈلدۈرمامىلىق يامغۇر',
    '🌤' => 'پارچە بۇلۇت ئارقىدا قۇياش',
    '🌥' => 'چوڭ بۇلۇت ئارقىدا قۇياش',
    '🌦' => 'يامغۇرلۇق بۇلۇت ئارقىدا قۇياش',
    '🌧' => 'يامغۇرلۇق بۇلۇت',
    '🌨' => 'قارلىق بۇلۇت',
    '🌩' => 'چاقماقلىق بۇلۇت',
    '🌪' => 'قۇيۇن',
    '🌫' => 'تۇمان',
    '🌬' => 'شامال چىراي',
    '🌀' => 'قاتتىق قۇيۇن',
    '🌈' => 'ھەسەن-ھۈسەن',
    '🌂' => 'يېپىق كۈنلۈك',
    '☂' => 'كۈنلۈك',
    '☔' => 'يامغۇر تامچىلاۋاتقان كۈنلۈك',
    '⛱' => 'يەردىكى كۈنلۈك',
    '⚡' => 'يۇقىرى توك بېسىمى',
    '❄' => 'قار ئۇچقۇنى',
    '☃' => 'قار بوۋاي',
    '⛄' => 'قارسىز قار ئادەم',
    '☄' => 'قۇيرۇقلۇق يۇلتۇز',
    '🔥' => 'ئوت',
    '💧' => 'تامچە',
    '🌊' => 'سۇ دولقۇنى',
    '🎃' => 'كاۋا چىراق',
    '🎄' => 'مىلاد دەرىخى',
    '🎆' => 'ساليۇت',
    '🎇' => 'پارسىلداق',
    '✨' => 'ۋالدۇر-ۋۇلدۇر',
    '🎈' => 'شار',
    '🎉' => 'سورۇن پارسىلدىقى',
    '🎊' => 'قەغەز ئۇۋاق',
    '🎋' => 'تاناباتا دەرىخى',
    '🎍' => 'قارىغاي بېزەك',
    '🎎' => 'ياپونچە قونچاق',
    '🎏' => 'بېلىق لەپ-لەپ',
    '🎐' => 'شامال كاناي',
    '🎑' => 'ئاي كۆرۈش مۇراسىمى',
    '🎀' => 'لېنتا',
    '🎁' => 'ئوراق سوۋغات',
    '🎗' => 'ئەسلەش لېنتىسى',
    '🎟' => 'قوبۇللاش بېلىتى',
    '🎫' => 'بېلەت',
    '🎖' => 'ھەربىي مېدال',
    '🏆' => 'مۇكاپات لوڭقىسى',
    '🏅' => 'تەنتەربىيە مېدالى',
    '🥇' => 'بىرىنچىلىك مېدالى',
    '🥈' => 'ئىككىنچىلىك مېدالى',
    '🥉' => 'ئۈچىنچىلىك مېدالى',
    '⚽' => 'پۇتبول',
    '⚾' => 'قورغانتوپ',
    '🏀' => 'ۋاسكېتبول',
    '🏐' => 'ۋالىبول',
    '🏈' => 'ئامېرىكا پۇتبولى',
    '🏉' => 'زەيتۇن توپ',
    '🎾' => 'چويلا توپ',
    '🎳' => 'دومىلىما توپ',
    '🏏' => 'كالتەكتوپ ئويۇنى',
    '🏑' => 'كالتەكتوپ',
    '🏒' => 'مۇزتوپ',
    '🏓' => 'تىكتاكتوپ',
    '🏸' => 'پەيتوپ',
    '🥊' => 'بوكس پەلىيى',
    '🥋' => 'جانبازلىق كىيىمى',
    '🥅' => 'ۋارتا تورى',
    '⛳' => 'ئورەكتىكى بايراق',
    '⛸' => 'مۇز تېيىلىش',
    '🎣' => 'قارماق سېپى',
    '🎽' => 'يۈگۈرۈش كۆڭلىكى',
    '🎿' => 'چاڭغا',
    '🛷' => 'تېيىلغا',
    '🥌' => 'ئەگمە تاش',
    '🎯' => 'دەل تېگىش',
    '🔫' => 'تاپانچا',
    '🎱' => '8 لىك بىليارت',
    '🔮' => 'كىرىستال توپ',
    '🎮' => 'ئېلېكتىرونلۇق ئويۇن',
    '🕹' => 'ئويۇن تىزگىنىكى',
    '🎰' => 'مال ساتقۇچ',
    '🎲' => 'شىشىخال ئويۇنى',
    '♠' => 'قاغا',
    '♥' => 'تاپان',
    '♦' => 'غىچ',
    '♣' => 'چىتتىر',
    '🃏' => 'جوكېر',
    '🀄' => 'ماجاڭ قىزىل ئەجدىھا',
    '🎴' => 'گۈللۈك قارتا',
    '🎭' => 'ئويۇن كۆرسىتىش',
    '🖼' => 'رامكىلىق رەسىم',
    '🎨' => 'بوياق تاختىسى',
    '👓' => 'ئەينەك',
    '🕶' => 'كۈن ئەينىكى',
    '👔' => 'گالىستۇك',
    '👕' => 'كۆڭلەك',
    '👖' => 'پادىچىلار ئىشتىنى',
    '🧣' => 'شارپا',
    '🧤' => 'پەلەي',
    '🧥' => 'پەلتو',
    '🧦' => 'پايپاق',
    '👗' => 'كىيىم',
    '👘' => 'كىمونو',
    '👙' => 'باغىرداق',
    '👚' => 'ئايالچە كىيىم',
    '👛' => 'ھەميان',
    '👜' => 'قولسومكا',
    '👝' => 'قولبوغچا',
    '🛍' => 'مال سېتىۋېلىش خالتىسى',
    '🎒' => 'كىتاب بوغچىسى',
    '👞' => 'ئەرەنچە ئاياغ',
    '👟' => 'يۈگۈرۈش ئايىغى',
    '👠' => 'ئېگىز پاشنىلىق ئاياغ',
    '👡' => 'ئايالچە سالقىن ئاياغ',
    '👢' => 'ئايالچە ئۆتۈك',
    '👑' => 'تاج',
    '👒' => 'ئايالچە قالپاق',
    '🎩' => 'ئۇزۇن قالپاق',
    '🎓' => 'ئوقۇش پۈتتۈرۈش قالپىقى',
    '🧢' => 'ئۇزۇن تۇمشۇق شەپكە',
    '⛑' => 'قۇتقۇزغۇچى قالپىقى',
    '📿' => 'تەسۋى',
    '💄' => 'لەۋسۇرۇخ',
    '💍' => 'ئۈزۈك',
    '💎' => 'گۆھەر تاش',
    '🔇' => 'ئۈنسىز ياڭراتقۇ',
    '🔈' => 'تۆۋەن ئۈنلۈك ياڭراتقۇ',
    '🔉' => 'ئارا ئۈنلۈك ياڭراتقۇ',
    '🔊' => 'يۇقىرى ئۈنلۈك ياڭراتقۇ',
    '📢' => 'ياڭراتقۇ',
    '📣' => 'ئۈنلەتكۈچ',
    '📯' => 'پوچتا گۈدۈكى',
    '🔔' => 'قوڭغۇراق',
    '🔕' => 'چەكلەنگەن قوڭغۇراق',
    '🎼' => 'مۇزىكا يازمىسى',
    '🎵' => 'نوتا',
    '🎶' => 'نوتىلار',
    '🎙' => 'ئىستۇدىيە مىكروفونى',
    '🎚' => 'دەرىجە سىيرىگۈچ',
    '🎛' => 'تىزگىن تۇتقا',
    '🎤' => 'مىكروفون',
    '🎧' => 'تاقىما تىڭشىغۇچ',
    '📻' => 'رادىيو',
    '🎷' => 'ساكسوفون',
    '🎺' => 'سۇناي',
    '🎸' => 'گىتار',
    '🎹' => 'مۇزىكا تىل تاختىسى',
    '🎻' => 'ئىسكىرىپكا',
    '🥁' => 'دۇمباق',
    '📱' => 'يانفون',
    '📲' => 'كۆرسەتكۈچلۈك يانفون',
    '☎' => 'تېلېفون',
    '📞' => 'تېلېفون ئالغۇچ',
    '📟' => 'چاقىرغۇ',
    '📠' => 'فاكسچى',
    '🔋' => 'باتارېيە',
    '🔌' => 'چاتقۇچ',
    '💻' => 'خاتىرە كومپيۇتېر',
    '🖥' => 'ئۈستەل كومپيۇتېرى',
    '🖨' => 'باسقۇچ',
    '⌨' => 'كۇنۇپكا تاختىسى',
    '🖱' => 'مائۇس',
    '🖲' => 'مائۇس شارچىسى',
    '💽' => 'كومپيۇتېر دىسكىسى',
    '💾' => 'يۇمشاق دىسكا',
    '💿' => 'نۇر دىسكا',
    '📀' => 'dvd',
    '🎥' => 'كىنو كامېراسى',
    '🎞' => 'كىنو رامكىسى',
    '📽' => 'فىلىم قويغۇچ',
    '🎬' => 'چىك-چاك',
    '📺' => 'تېلېۋىزور',
    '📷' => 'كامېرا',
    '📸' => 'چىراقلىق كامېرا',
    '📹' => 'سىن كامېرا',
    '📼' => 'سىنئالغۇ لېنتىسى',
    '🔍' => 'سولغا قارىغان چوڭايتقۇچ',
    '🔎' => 'ئوڭغا قارىغان چوڭايتقۇچ',
    '🕯' => 'شام',
    '💡' => 'لامپۇچكا',
    '🔦' => 'قولچىراق',
    '🏮' => 'قىزىل پانۇس',
    '📔' => 'رەڭلىك خاتىرە',
    '📕' => 'يېپىق كىتاب',
    '📖' => 'ئوچۇق كىتاب',
    '📗' => 'يېشىل كىتاب',
    '📘' => 'كۆك كىتاب',
    '📙' => 'قىزغۇچ كىتاب',
    '📚' => 'كىتابلار',
    '📓' => 'خاتىرە دەپتەر',
    '📒' => 'دەپتەر',
    '📃' => 'ئەگمە بەت',
    '📜' => 'سىيرىش',
    '📄' => 'ئۈستىگە قارىغان بەت',
    '📰' => 'گېزىت',
    '🗞' => 'ئوراق گېزىت',
    '📑' => 'يىغقۇچ بەتكۈچى',
    '🔖' => 'يىغقۇچ',
    '🏷' => 'خەتكۈچ',
    '💰' => 'پۇل خالتىسى',
    '💴' => 'يېن',
    '💵' => 'دوللار',
    '💶' => 'ياۋرو',
    '💷' => 'پوندستېرلىڭ',
    '💸' => 'قاناتلىق پۇل',
    '💳' => 'ئىناۋەتلىك كارتا',
    '💹' => 'يېن ئاشما گىرافىكى',
    '✉' => 'كونۋېرت',
    '📧' => 'تورخەت',
    '📨' => 'كەلگەن خەت',
    '📩' => 'كۆرسەتكۈچلۈك خەت',
    '📤' => 'خەت يوللاش بەلگىسى',
    '📥' => 'خەت كېلىش بەلگىسى',
    '📦' => 'خالتا',
    '📫' => 'تۇغلانغان يېپىق خەت ساندۇقى',
    '📪' => 'تۇغ چۈشۈرۈلگەن يېپىق خەت ساندۇقى',
    '📬' => 'تۇغلانغان ئوچۇق خەت ساندۇقى',
    '📭' => 'تۇغ چۈشۈرۈلگەن ئوچۇق خەت ساندۇقى',
    '📮' => 'پوچتا ساندۇقى',
    '🗳' => 'بېلەت چۈشكەن بېلەت ساندۇقى',
    '✏' => 'قېرىنداش',
    '✒' => 'قارا ئۇچ',
    '🖋' => 'سىياھ قەلەم',
    '🖊' => 'قەلەم',
    '🖌' => 'چوتكا',
    '🖍' => 'بوياق قەلەم',
    '📝' => 'ئەسلەتمە',
    '💼' => 'سومكا',
    '📁' => 'ھۆججەت قىسقۇچ',
    '📂' => 'ئوچۇق قىسقۇچ',
    '🗂' => 'ئايرىق ساندۇق',
    '📅' => 'كالېندار',
    '📆' => 'يىرتىق كالېندار',
    '🗒' => 'ھالقىسىمان خاتىرە',
    '🗓' => 'ھالقىسىمان كالېندار',
    '📇' => 'كارتا كۆرسەتكۈچ',
    '📈' => 'ئاشما گىرافىك',
    '📉' => 'چۈشمە گىرافىك',
    '📊' => 'تۈۋرۈكلۈك گىرافىك',
    '📋' => 'كېسىش تاختىسى',
    '📌' => 'كۇنۇپكا',
    '📍' => 'يۇمىلاق مىخ',
    '📎' => 'قەغەز قىسقۇچ',
    '🖇' => 'ئۇلىنىش',
    '📏' => 'تۈز سىزغۇچ',
    '📐' => 'ئۈچ بۇلۇڭلۇق سىزغۇچ',
    '✂' => 'قايچا',
    '🗃' => 'قەغەز ھۆججەت ساندۇقى',
    '🗄' => 'ھۆججەت ئىشكاپى',
    '🗑' => 'ئەخلەت سېۋىتى',
    '🔒' => 'قۇلۇپلاق',
    '🔓' => 'قۇلۇپسىز',
    '🔏' => 'قەلەملىك قۇلۇپ',
    '🔐' => 'ئاچقۇچلۇق قۇلۇپ',
    '🔑' => 'ئاچقۇچ',
    '🗝' => 'كونا ئاچقۇچ',
    '🔨' => 'بولقا',
    '⛏' => 'چوت',
    '⚒' => 'بولقا ۋە چوت',
    '🛠' => 'بولقا ۋە كۇلۇچ',
    '🗡' => 'خەنجەر',
    '⚔' => 'قايچىلانما شەمشەرلەر',
    '💣' => 'پارتلاتقۇچ',
    '🏹' => 'يا ۋە ئوق',
    '🛡' => 'قالقان',
    '🔧' => 'كۇلۇچ',
    '🔩' => 'گايكا ۋە ۋىنتا',
    '⚙' => 'چىشلىق چاق',
    '🗜' => 'قىسقۇچ',
    '⚖' => 'تەڭپۇڭلۇق ئۆلچىگۈچ',
    '🔗' => 'ئۇلانما',
    '⛓' => 'زەنجىرلەر',
    '⚗' => 'ھورلاندۇرغۇچ',
    '🔬' => 'مىكروسكوپ',
    '🔭' => 'تېلېسكوپ',
    '📡' => 'سۈنئىي ھەمرا ئانتېنناسى',
    '💉' => 'ئىشپىرىس',
    '💊' => 'تابلېتكا',
    '🚪' => 'ئىشىك',
    '🛏' => 'كارىۋات',
    '🛋' => 'دىۋان ۋە چىراق',
    '🚽' => 'ھاجەتخانا',
    '🚿' => 'يۇيۇنۇش',
    '🛁' => 'يۇيۇنداق',
    '🛒' => 'مال ھارۋىسى',
    '🚬' => 'تاماكا',
    '⚰' => 'تاۋۇت',
    '⚱' => 'مېيىت قاچىسى',
    '🗿' => 'تاش ھەيكەل',
    '🏧' => 'پۇلئالغۇ بەلگىسى',
    '🚮' => 'سېۋەتكە ئەخلەت تاشلاش بەلگىسى',
    '🚰' => 'ئىچىملىك سۇ',
    '♿' => 'مېيىپلار ھارۋىسىنىڭ بەلگىسى',
    '🚹' => 'ئەرلەر ھاجەتخانىسى',
    '🚺' => 'ئاياللار ھاجەتخانىسى',
    '🚻' => 'تازىلىق ئۆيى',
    '🚼' => 'بوۋاق بەلگىسى',
    '🚾' => 'سۇخانا',
    '🛂' => 'پارول تىزگىنى',
    '🛃' => 'تاموژنا',
    '🛄' => 'يۈك-تاق ئورنى',
    '🛅' => 'قالدۇق يۈك-تاق',
    '⚠' => 'ئاگاھلاندۇرۇش',
    '🚸' => 'بالىلار ئۆتۈۋاتىدۇ',
    '⛔' => 'كىرمەڭ',
    '🚫' => 'چەكلەنگەن',
    '🚳' => 'ۋېلىسىپىت مىنمەڭ',
    '🚭' => 'تاماكا چەكمەڭ',
    '🚯' => 'ئەخلەت تاشلىماڭ',
    '🚱' => 'ئىچىلمەس سۇ',
    '🚷' => 'پىيادە ماڭماڭ',
    '📵' => 'يانفون ئىشلەتمەڭ',
    '🔞' => 'ئون سەككىزدىن تۆۋەنلەر چەكلنىدۇ',
    '☢' => 'رادىيوئاكتىپ',
    '☣' => 'بىيولوگىيەلىك خەتەر',
    '⬆' => 'ئۈستى كۆرسەتكۈچ',
    '↗' => 'ئۈستى-ئوڭ كۆرسەتكۈچ',
    '➡' => 'ئوڭ كۆرسەتكۈچ',
    '↘' => 'ئاستى ئوڭ كۆرسەتكۈچ',
    '⬇' => 'ئاستى كۆرسەتكۈچ',
    '↙' => 'ئاستى سول كۆرسەتكۈچ',
    '⬅' => 'سول كۆرسەتكۈچ',
    '↖' => 'ئۈستى سول كۆرسەتكۈچ',
    '↕' => 'ئاستى-ئۈستى كۆرسەتكۈچ',
    '↔' => 'ئوڭ-سول كۆرسەتكۈچ',
    '↩' => 'سولغا ئېگىلگەن ئوڭ كۆرسەتكۈچ',
    '↪' => 'ئوڭغا ئېگىلگەن سول كۆرسەتكۈچ',
    '⤴' => 'ئۈستىگە ئېگىلگەن ئوڭ كۆرسەتكۈچ',
    '⤵' => 'ئاستىغا ئېگىلگەن ئوڭ كۆرسەتكۈچ',
    '🔃' => 'سائەت يۆنىلىشىدىكى تىك كۆرسەتكۈچ',
    '🔄' => 'سائەتكە قارشى يۆنىلىشتىكى كۆرسەتكۈچ',
    '🔙' => 'ئارقا كۆرسەتكۈچ',
    '🔚' => 'ئاياغ كۆرسەتكۈچ',
    '🔛' => 'ئوچۇق! كۆرسەتكۈچ',
    '🔜' => 'يېقىندا دېگەن كۆرسەتكۈچ',
    '🔝' => 'چوققا كۆرسەتكۈچ',
    '🛐' => 'ئىبادەتخانا',
    '⚛' => 'ئاتوم بەلگىسى',
    '🕉' => 'ئوم',
    '✡' => 'داۋۇت يۇلتۇزى',
    '☸' => 'دارما چاقى',
    '☯' => 'يىن ياڭ',
    '✝' => 'لاتىن كىرېست',
    '☦' => 'ئورتودوكس',
    '☪' => 'يۇلتۇز ۋە ھىلال ئاي',
    '☮' => 'تىنچلىق بەلگىسى',
    '🕎' => 'قەندىل',
    '🔯' => 'ئالتە بۇرجەكلىك يۇلتۇز',
    '♈' => 'ھەمەل',
    '♉' => 'ئۇي',
    '♊' => 'قوشكېزەك',
    '♋' => 'سەرەتان',
    '♌' => 'شىر',
    '♍' => 'بۇغدايباش',
    '♎' => 'چەل',
    '♏' => 'ئەقرەب',
    '♐' => 'ياچاق',
    '♑' => 'ئوغلاق',
    '♒' => 'سوغلا',
    '♓' => 'بېلىقچى',
    '⛎' => 'يىلانچى',
    '🔀' => 'تاسقاش كۇنۇپكىسى',
    '🔁' => 'قايتىلاش كۇنۇپكىسى',
    '🔂' => 'يەككە قايتىلاش كۇنۇپكىسى',
    '▶' => 'قويۇش كۇنۇپكىسى',
    '⏩' => 'تېز سۈرۈش كۇنۇپكىسى',
    '⏭' => 'كېيىنكى كۇنۇپكىسى',
    '⏯' => 'قويۇش ياكى تورمۇزلاش كۇنۇپكىسى',
    '◀' => 'تېز قايتۇرۇش كۇنۇپكىسى',
    '⏪' => 'قايتۇرۇش كۇنۇپكىسى',
    '⏮' => 'ئالدىنقى كۇنۇپكىسى',
    '🔼' => 'ئۆرلەش كۇنۇپكىسى',
    '⏫' => 'تېز ئۆرلەش كۇنۇپكىسى',
    '🔽' => 'تۆۋەنلەش كۇنۇپكىسى',
    '⏬' => 'تېز تۆۋەنلەش كۇنۇپكىسى',
    '⏸' => 'تورمۇزلاش كۇنۇپكىسى',
    '⏹' => 'توختاش كۇنۇپكىسى',
    '⏺' => 'ئېلىش كۇنۇپكىسى',
    '⏏' => 'چىقىرىش كۇنۇپكىسى',
    '🎦' => 'كىنوخانا',
    '🔅' => 'غۇۋالىق كۇنۇپكىسى',
    '🔆' => 'يورۇقلۇق كۇنۇپكىسى',
    '📶' => 'ئانتېننا بالدىقى',
    '📳' => 'تىترەش ھالىتى',
    '📴' => 'يانفون ئېتىك',
    '♀' => 'ئايال بەلگىسى',
    '♂' => 'ئەر بەلگىسى',
    '✖' => 'ئېغىر كۆپەيتىش بەلگىسى',
    '➕' => 'ئېغىر قوشۇش بەلگىسى',
    '➖' => 'ئېغىر ئېلىش بەلگىسى',
    '➗' => 'ئېغىر بۆلۈش بەلگىسى',
    '‼' => 'قوش ئۈندەش بەلگىسى',
    '⁉' => 'ئۈندەشلىك سوئال بەلگىسى',
    '❓' => 'سوئال بەلگىسى',
    '❔' => 'ئاق سوئال بەلگىسى',
    '❕' => 'ئاق ئۈندەش بەلگىسى',
    '❗' => 'ئۈندەش بەلگىسى',
    '〰' => 'دولقۇنلۇق كۆپ چېكىت',
    '💱' => 'پۇل ئالماشتۇرۇش',
    '💲' => 'ئېغىر دوللار بەلگىسى',
    '⚕' => 'دورا بەلگىسى',
    '♻' => 'يىغىپ ئىشلەش بەلگىسى',
    '⚜' => 'نەقىش',
    '🔱' => 'ئارا بەلگە',
    '📛' => 'ئىزنەك',
    '🔰' => 'ياپونچە باشلانغۇچ بەلگىسى',
    '⭕' => 'چوڭ ئېغىر ھالقا',
    '✅' => 'ئاق ئېغىر توغرا بەلگىسى',
    '☑' => 'تاللانغان بېلەت ساندۇقى',
    '✔' => 'ئېغىر توغرا بەلگىسى',
    '❌' => 'خاتا بەلگىسى',
    '❎' => 'خاتا بەلگە كۇنۇپكىسى',
    '➰' => 'ئەگمە ھالقا',
    '➿' => 'قوش ئەگمە ھالقا',
    '〽' => 'قىسمەن ئۆزگەرتىش بەلگىسى',
    '✳' => 'سەككىز بۇرجەكلىك يۇلتۇز بەلگىسى',
    '✴' => 'سەككىز بۇرجەكلىك يۇلتۇز',
    '❇' => 'چاقناش',
    '™' => 'سودا ماركىسى',
    '🔠' => 'لاتىنچە چوڭ ھەرپ',
    '🔡' => 'لاتىنچە كىچىك ھەرپ',
    '🔢' => 'سان كىرگۈزۈش',
    '🔣' => 'بەلگە كىرگۈزۈش',
    '🔤' => 'لاتىنچە ھەرپ كىرگۈزۈش',
    '🅰' => 'A كۇنۇپكىسى (قان تىپى)',
    '🆎' => 'AB كۇنۇپكىسى (قان تىپى)',
    '🅱' => 'B كۇنۇپكىسى (قان تىپى)',
    '🆑' => 'CL كۇنۇپكىسى',
    '🆒' => '«بولىدىكەن» كۇنۇپكىسى',
    '🆓' => '«بىكار» كۇنۇپكىسى',
    'ℹ' => 'ئۇچۇر',
    '🆔' => 'ID كۇنۇپكىسى',
    'Ⓜ' => 'ھالقىلىق M',
    '🆕' => '«يېڭى» كۇنۇپكىسى',
    '🆖' => 'NG كۇنۇپكىسى',
    '🅾' => 'O كۇنۇپكىسى (قان تىپى)',
    '🆗' => '«OK» كۇنۇپكىسى',
    '🅿' => 'P كۇنۇپكىسى',
    '🆘' => 'SOS كۇنۇپكىسى',
    '🆙' => 'UP! كۇنۇپكىسى',
    '🆚' => 'VS كۇنۇپكىسى',
    '🈁' => 'ياپونچە «بۇ يەر» دېگەن كۇنۇپكا',
    '🈂' => 'ياپونچە «مۇلازىمەت ھەققى» دېگەن كۇنۇپكا',
    '🈷' => 'ياپونچە «ئايلىق» دېگەن كۇنۇپكا',
    '🈶' => 'ياپونچە «ھەقسىز ئەمەس» دېگەن كۇنۇپكا',
    '🈯' => 'ياپونچە «ساقلاق» دېگەن كۇنۇپكا',
    '🉐' => 'ياپونچە «سودىلىشىش» دېگەن كۇنۇپكا',
    '🈹' => 'ياپونچە «ئېتىبار» دېگەن كۇنۇپكا',
    '🈚' => 'ياپونچە «ھەقسىز» دېگەن كۇنۇپكا',
    '🈲' => 'ياپونچە «چەكلەنگەن» دېگەن كۇنۇپكا',
    '🉑' => 'ياپونچە «لاياقەتلىك» دېگەن كونۇپكا',
    '🈸' => 'ياپونچە «ئىلتىماس» كۇنۇپكىسى',
    '🈴' => 'ياپونچە «نومۇر چېكى» كۇنۇپكىسى',
    '🈳' => 'ياپونچە «بوش» دېگەن كۇنۇپكا',
    '㊗' => 'ياپونچە «مۇبارەك» دېگەن كۇنۇپكا',
    '㊙' => 'ياپونچە «مەخپىيەتلىك» دېگەن كۇنۇپكا',
    '🈺' => 'ياپونچە «ئوچۇق» دېگەن كۇنۇپكا',
    '🈵' => 'ياپونچە «بوش ئەمەس» دېگەن كۇنۇپكا',
    '🔴' => 'قىزىل چەمبەر',
    '🔵' => 'كۆك چەمبەر',
    '⚫' => 'قارا چەمبەر',
    '⚪' => 'ئاق چەمبەر',
    '⬛' => 'قارا چوڭ كىۋادرات',
    '⬜' => 'ئاق چوڭ كىۋادرات',
    '◼' => 'قارا ئارا كىۋادرات',
    '◻' => 'ئاق ئارا كىۋادرات',
    '◾' => 'قارا كىچىكرەك كىۋادرات',
    '◽' => 'ئاق كىچىكرەك كىۋادرات',
    '▪' => 'قارا كىچىك كىۋادرات',
    '▫' => 'ئاق كىچىك كىۋادرات',
    '🔶' => 'چوڭ قىزغۇچ رومبا',
    '🔷' => 'چوڭ كۆك رومبا',
    '🔸' => 'كىچىك قىزغۇچ رومبا',
    '🔹' => 'كىچىك كۆك رومبا',
    '🔺' => 'قىزىل ئۈستى ئۈچبۇلۇڭ',
    '🔻' => 'قىزىل ئاستى ئۈچبۇلۇڭ',
    '💠' => 'چېكىتلىك رومبا',
    '🔘' => 'يۇمىلاق كۇنۇپكا',
    '🔳' => 'ئاق كىۋادرات كۇنۇپكىسى',
    '🔲' => 'قارا چاسا كۇنۇپكا',
    '🏁' => 'كاتەكچە بايراق',
    '🚩' => 'ئۈچ بۇرجەك بايراق',
    '🎌' => 'قايچىلانما بايراقلار',
    '🏴' => 'قارا بايراق',
    '🏳' => 'ئاق بايراق',
];
