<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'пацалунак: дарослы дарослы светлы тон скуры сярэднясветлы тон скуры',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'пацалунак: дарослы дарослы светлы тон скуры сярэдні тон скуры',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'пацалунак: дарослы дарослы светлы тон скуры сярэдняцёмны тон скуры',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'пацалунак: дарослы дарослы светлы тон скуры цёмны тон скуры',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'пацалунак: дарослы дарослы сярэднясветлы тон скуры светлы тон скуры',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'пацалунак: дарослы дарослы сярэднясветлы тон скуры сярэдні тон скуры',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'пацалунак: дарослы дарослы сярэднясветлы тон скуры сярэдняцёмны тон скуры',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'пацалунак: дарослы дарослы сярэднясветлы тон скуры цёмны тон скуры',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'пацалунак: дарослы дарослы сярэдні тон скуры светлы тон скуры',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'пацалунак: дарослы дарослы сярэдні тон скуры сярэднясветлы тон скуры',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'пацалунак: дарослы дарослы сярэдні тон скуры сярэдняцёмны тон скуры',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'пацалунак: дарослы дарослы сярэдні тон скуры цёмны тон скуры',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'пацалунак: дарослы дарослы сярэдняцёмны тон скуры светлы тон скуры',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'пацалунак: дарослы дарослы сярэдняцёмны тон скуры сярэднясветлы тон скуры',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'пацалунак: дарослы дарослы сярэдняцёмны тон скуры сярэдні тон скуры',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'пацалунак: дарослы дарослы сярэдняцёмны тон скуры цёмны тон скуры',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'пацалунак: дарослы дарослы цёмны тон скуры светлы тон скуры',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'пацалунак: дарослы дарослы цёмны тон скуры сярэднясветлы тон скуры',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'пацалунак: дарослы дарослы цёмны тон скуры сярэдні тон скуры',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'пацалунак: дарослы дарослы цёмны тон скуры сярэдняцёмны тон скуры',
    '👨🏻‍❤‍💋‍👨🏻' => 'пацалунак: мужчына мужчына светлы тон скуры',
    '👨🏻‍❤‍💋‍👨🏼' => 'пацалунак: мужчына мужчына светлы тон скуры сярэднясветлы тон скуры',
    '👨🏻‍❤‍💋‍👨🏽' => 'пацалунак: мужчына мужчына светлы тон скуры сярэдні тон скуры',
    '👨🏻‍❤‍💋‍👨🏾' => 'пацалунак: мужчына мужчына светлы тон скуры сярэдняцёмны тон скуры',
    '👨🏻‍❤‍💋‍👨🏿' => 'пацалунак: мужчына мужчына светлы тон скуры цёмны тон скуры',
    '👨🏼‍❤‍💋‍👨🏻' => 'пацалунак: мужчына мужчына сярэднясветлы тон скуры светлы тон скуры',
    '👨🏼‍❤‍💋‍👨🏼' => 'пацалунак: мужчына мужчына сярэднясветлы тон скуры',
    '👨🏼‍❤‍💋‍👨🏽' => 'пацалунак: мужчына мужчына сярэднясветлы тон скуры сярэдні тон скуры',
    '👨🏼‍❤‍💋‍👨🏾' => 'пацалунак: мужчына мужчына сярэднясветлы тон скуры сярэдняцёмны тон скуры',
    '👨🏼‍❤‍💋‍👨🏿' => 'пацалунак: мужчына мужчына сярэднясветлы тон скуры цёмны тон скуры',
    '👨🏽‍❤‍💋‍👨🏻' => 'пацалунак: мужчына мужчына сярэдні тон скуры светлы тон скуры',
    '👨🏽‍❤‍💋‍👨🏼' => 'пацалунак: мужчына мужчына сярэдні тон скуры сярэднясветлы тон скуры',
    '👨🏽‍❤‍💋‍👨🏽' => 'пацалунак: мужчына мужчына сярэдні тон скуры',
    '👨🏽‍❤‍💋‍👨🏾' => 'пацалунак: мужчына мужчына сярэдні тон скуры сярэдняцёмны тон скуры',
    '👨🏽‍❤‍💋‍👨🏿' => 'пацалунак: мужчына мужчына сярэдні тон скуры цёмны тон скуры',
    '👨🏾‍❤‍💋‍👨🏻' => 'пацалунак: мужчына мужчына сярэдняцёмны тон скуры светлы тон скуры',
    '👨🏾‍❤‍💋‍👨🏼' => 'пацалунак: мужчына мужчына сярэдняцёмны тон скуры сярэднясветлы тон скуры',
    '👨🏾‍❤‍💋‍👨🏽' => 'пацалунак: мужчына мужчына сярэдняцёмны тон скуры сярэдні тон скуры',
    '👨🏾‍❤‍💋‍👨🏾' => 'пацалунак: мужчына мужчына сярэдняцёмны тон скуры',
    '👨🏾‍❤‍💋‍👨🏿' => 'пацалунак: мужчына мужчына сярэдняцёмны тон скуры цёмны тон скуры',
    '👨🏿‍❤‍💋‍👨🏻' => 'пацалунак: мужчына мужчына цёмны тон скуры светлы тон скуры',
    '👨🏿‍❤‍💋‍👨🏼' => 'пацалунак: мужчына мужчына цёмны тон скуры сярэднясветлы тон скуры',
    '👨🏿‍❤‍💋‍👨🏽' => 'пацалунак: мужчына мужчына цёмны тон скуры сярэдні тон скуры',
    '👨🏿‍❤‍💋‍👨🏾' => 'пацалунак: мужчына мужчына цёмны тон скуры сярэдняцёмны тон скуры',
    '👨🏿‍❤‍💋‍👨🏿' => 'пацалунак: мужчына мужчына цёмны тон скуры',
    '👩🏻‍❤‍💋‍👨🏻' => 'пацалунак: жанчына мужчына светлы тон скуры',
    '👩🏻‍❤‍💋‍👨🏼' => 'пацалунак: жанчына мужчына светлы тон скуры сярэднясветлы тон скуры',
    '👩🏻‍❤‍💋‍👨🏽' => 'пацалунак: жанчына мужчына светлы тон скуры сярэдні тон скуры',
    '👩🏻‍❤‍💋‍👨🏾' => 'пацалунак: жанчына мужчына светлы тон скуры сярэдняцёмны тон скуры',
    '👩🏻‍❤‍💋‍👨🏿' => 'пацалунак: жанчына мужчына светлы тон скуры цёмны тон скуры',
    '👩🏼‍❤‍💋‍👨🏻' => 'пацалунак: жанчына мужчына сярэднясветлы тон скуры светлы тон скуры',
    '👩🏼‍❤‍💋‍👨🏼' => 'пацалунак: жанчына мужчына сярэднясветлы тон скуры',
    '👩🏼‍❤‍💋‍👨🏽' => 'пацалунак: жанчына мужчына сярэднясветлы тон скуры сярэдні тон скуры',
    '👩🏼‍❤‍💋‍👨🏾' => 'пацалунак: жанчына мужчына сярэднясветлы тон скуры сярэдняцёмны тон скуры',
    '👩🏼‍❤‍💋‍👨🏿' => 'пацалунак: жанчына мужчына сярэднясветлы тон скуры цёмны тон скуры',
    '👩🏽‍❤‍💋‍👨🏻' => 'пацалунак: жанчына мужчына сярэдні тон скуры светлы тон скуры',
    '👩🏽‍❤‍💋‍👨🏼' => 'пацалунак: жанчына мужчына сярэдні тон скуры сярэднясветлы тон скуры',
    '👩🏽‍❤‍💋‍👨🏽' => 'пацалунак: жанчына мужчына сярэдні тон скуры',
    '👩🏽‍❤‍💋‍👨🏾' => 'пацалунак: жанчына мужчына сярэдні тон скуры сярэдняцёмны тон скуры',
    '👩🏽‍❤‍💋‍👨🏿' => 'пацалунак: жанчына мужчына сярэдні тон скуры цёмны тон скуры',
    '👩🏾‍❤‍💋‍👨🏻' => 'пацалунак: жанчына мужчына сярэдняцёмны тон скуры светлы тон скуры',
    '👩🏾‍❤‍💋‍👨🏼' => 'пацалунак: жанчына мужчына сярэдняцёмны тон скуры сярэднясветлы тон скуры',
    '👩🏾‍❤‍💋‍👨🏽' => 'пацалунак: жанчына мужчына сярэдняцёмны тон скуры сярэдні тон скуры',
    '👩🏾‍❤‍💋‍👨🏾' => 'пацалунак: жанчына мужчына сярэдняцёмны тон скуры',
    '👩🏾‍❤‍💋‍👨🏿' => 'пацалунак: жанчына мужчына сярэдняцёмны тон скуры цёмны тон скуры',
    '👩🏿‍❤‍💋‍👨🏻' => 'пацалунак: жанчына мужчына цёмны тон скуры светлы тон скуры',
    '👩🏿‍❤‍💋‍👨🏼' => 'пацалунак: жанчына мужчына цёмны тон скуры сярэднясветлы тон скуры',
    '👩🏿‍❤‍💋‍👨🏽' => 'пацалунак: жанчына мужчына цёмны тон скуры сярэдні тон скуры',
    '👩🏿‍❤‍💋‍👨🏾' => 'пацалунак: жанчына мужчына цёмны тон скуры сярэдняцёмны тон скуры',
    '👩🏿‍❤‍💋‍👨🏿' => 'пацалунак: жанчына мужчына цёмны тон скуры',
    '👩🏻‍❤‍💋‍👩🏻' => 'пацалунак: жанчына жанчына светлы тон скуры',
    '👩🏻‍❤‍💋‍👩🏼' => 'пацалунак: жанчына жанчына светлы тон скуры сярэднясветлы тон скуры',
    '👩🏻‍❤‍💋‍👩🏽' => 'пацалунак: жанчына жанчына светлы тон скуры сярэдні тон скуры',
    '👩🏻‍❤‍💋‍👩🏾' => 'пацалунак: жанчына жанчына светлы тон скуры сярэдняцёмны тон скуры',
    '👩🏻‍❤‍💋‍👩🏿' => 'пацалунак: жанчына жанчына светлы тон скуры цёмны тон скуры',
    '👩🏼‍❤‍💋‍👩🏻' => 'пацалунак: жанчына жанчына сярэднясветлы тон скуры светлы тон скуры',
    '👩🏼‍❤‍💋‍👩🏼' => 'пацалунак: жанчына жанчына сярэднясветлы тон скуры',
    '👩🏼‍❤‍💋‍👩🏽' => 'пацалунак: жанчына жанчына сярэднясветлы тон скуры сярэдні тон скуры',
    '👩🏼‍❤‍💋‍👩🏾' => 'пацалунак: жанчына жанчына сярэднясветлы тон скуры сярэдняцёмны тон скуры',
    '👩🏼‍❤‍💋‍👩🏿' => 'пацалунак: жанчына жанчына сярэднясветлы тон скуры цёмны тон скуры',
    '👩🏽‍❤‍💋‍👩🏻' => 'пацалунак: жанчына жанчына сярэдні тон скуры светлы тон скуры',
    '👩🏽‍❤‍💋‍👩🏼' => 'пацалунак: жанчына жанчына сярэдні тон скуры сярэднясветлы тон скуры',
    '👩🏽‍❤‍💋‍👩🏽' => 'пацалунак: жанчына жанчына сярэдні тон скуры',
    '👩🏽‍❤‍💋‍👩🏾' => 'пацалунак: жанчына жанчына сярэдні тон скуры сярэдняцёмны тон скуры',
    '👩🏽‍❤‍💋‍👩🏿' => 'пацалунак: жанчына жанчына сярэдні тон скуры цёмны тон скуры',
    '👩🏾‍❤‍💋‍👩🏻' => 'пацалунак: жанчына жанчына сярэдняцёмны тон скуры светлы тон скуры',
    '👩🏾‍❤‍💋‍👩🏼' => 'пацалунак: жанчына жанчына сярэдняцёмны тон скуры сярэднясветлы тон скуры',
    '👩🏾‍❤‍💋‍👩🏽' => 'пацалунак: жанчына жанчына сярэдняцёмны тон скуры сярэдні тон скуры',
    '👩🏾‍❤‍💋‍👩🏾' => 'пацалунак: жанчына жанчына сярэдняцёмны тон скуры',
    '👩🏾‍❤‍💋‍👩🏿' => 'пацалунак: жанчына жанчына сярэдняцёмны тон скуры цёмны тон скуры',
    '👩🏿‍❤‍💋‍👩🏻' => 'пацалунак: жанчына жанчына цёмны тон скуры светлы тон скуры',
    '👩🏿‍❤‍💋‍👩🏼' => 'пацалунак: жанчына жанчына цёмны тон скуры сярэднясветлы тон скуры',
    '👩🏿‍❤‍💋‍👩🏽' => 'пацалунак: жанчына жанчына цёмны тон скуры сярэдні тон скуры',
    '👩🏿‍❤‍💋‍👩🏾' => 'пацалунак: жанчына жанчына цёмны тон скуры сярэдняцёмны тон скуры',
    '👩🏿‍❤‍💋‍👩🏿' => 'пацалунак: жанчына жанчына цёмны тон скуры',
    '🧑🏻‍🫯‍🧑🏼' => 'барцы: светлы тон скуры сярэднясветлы тон скуры',
    '🧑🏻‍🫯‍🧑🏽' => 'барцы: светлы тон скуры сярэдні тон скуры',
    '🧑🏻‍🫯‍🧑🏾' => 'барцы: светлы тон скуры сярэдняцёмны тон скуры',
    '🧑🏻‍🫯‍🧑🏿' => 'барцы: светлы тон скуры цёмны тон скуры',
    '🧑🏼‍🫯‍🧑🏻' => 'барцы: сярэднясветлы тон скуры светлы тон скуры',
    '🧑🏼‍🫯‍🧑🏽' => 'барцы: сярэднясветлы тон скуры сярэдні тон скуры',
    '🧑🏼‍🫯‍🧑🏾' => 'барцы: сярэднясветлы тон скуры сярэдняцёмны тон скуры',
    '🧑🏼‍🫯‍🧑🏿' => 'барцы: сярэднясветлы тон скуры цёмны тон скуры',
    '🧑🏽‍🫯‍🧑🏻' => 'барцы: сярэдні тон скуры светлы тон скуры',
    '🧑🏽‍🫯‍🧑🏼' => 'барцы: сярэдні тон скуры сярэднясветлы тон скуры',
    '🧑🏽‍🫯‍🧑🏾' => 'барцы: сярэдні тон скуры сярэдняцёмны тон скуры',
    '🧑🏽‍🫯‍🧑🏿' => 'барцы: сярэдні тон скуры цёмны тон скуры',
    '🧑🏾‍🫯‍🧑🏻' => 'барцы: сярэдняцёмны тон скуры светлы тон скуры',
    '🧑🏾‍🫯‍🧑🏼' => 'барцы: сярэдняцёмны тон скуры сярэднясветлы тон скуры',
    '🧑🏾‍🫯‍🧑🏽' => 'барцы: сярэдняцёмны тон скуры сярэдні тон скуры',
    '🧑🏾‍🫯‍🧑🏿' => 'барцы: сярэдняцёмны тон скуры цёмны тон скуры',
    '🧑🏿‍🫯‍🧑🏻' => 'барцы: цёмны тон скуры светлы тон скуры',
    '🧑🏿‍🫯‍🧑🏼' => 'барцы: цёмны тон скуры сярэднясветлы тон скуры',
    '🧑🏿‍🫯‍🧑🏽' => 'барцы: цёмны тон скуры сярэдні тон скуры',
    '🧑🏿‍🫯‍🧑🏾' => 'барцы: цёмны тон скуры сярэдняцёмны тон скуры',
    '🧑🏻‍❤‍🧑🏼' => 'закаханая пара: дарослы дарослы светлы тон скуры сярэднясветлы тон скуры',
    '🧑🏻‍❤‍🧑🏽' => 'закаханая пара: дарослы дарослы светлы тон скуры сярэдні тон скуры',
    '🧑🏻‍❤‍🧑🏾' => 'закаханая пара: дарослы дарослы светлы тон скуры сярэдняцёмны тон скуры',
    '🧑🏻‍❤‍🧑🏿' => 'закаханая пара: дарослы дарослы светлы тон скуры цёмны тон скуры',
    '🧑🏼‍❤‍🧑🏻' => 'закаханая пара: дарослы дарослы сярэднясветлы тон скуры светлы тон скуры',
    '🧑🏼‍❤‍🧑🏽' => 'закаханая пара: дарослы дарослы сярэднясветлы тон скуры сярэдні тон скуры',
    '🧑🏼‍❤‍🧑🏾' => 'закаханая пара: дарослы дарослы сярэднясветлы тон скуры сярэдняцёмны тон скуры',
    '🧑🏼‍❤‍🧑🏿' => 'закаханая пара: дарослы дарослы сярэднясветлы тон скуры цёмны тон скуры',
    '🧑🏽‍❤‍🧑🏻' => 'закаханая пара: дарослы дарослы сярэдні тон скуры светлы тон скуры',
    '🧑🏽‍❤‍🧑🏼' => 'закаханая пара: дарослы дарослы сярэдні тон скуры сярэднясветлы тон скуры',
    '🧑🏽‍❤‍🧑🏾' => 'закаханая пара: дарослы дарослы сярэдні тон скуры сярэдняцёмны тон скуры',
    '🧑🏽‍❤‍🧑🏿' => 'закаханая пара: дарослы дарослы сярэдні тон скуры цёмны тон скуры',
    '🧑🏾‍❤‍🧑🏻' => 'закаханая пара: дарослы дарослы сярэдняцёмны тон скуры светлы тон скуры',
    '🧑🏾‍❤‍🧑🏼' => 'закаханая пара: дарослы дарослы сярэдняцёмны тон скуры сярэднясветлы тон скуры',
    '🧑🏾‍❤‍🧑🏽' => 'закаханая пара: дарослы дарослы сярэдняцёмны тон скуры сярэдні тон скуры',
    '🧑🏾‍❤‍🧑🏿' => 'закаханая пара: дарослы дарослы сярэдняцёмны тон скуры цёмны тон скуры',
    '🧑🏿‍❤‍🧑🏻' => 'закаханая пара: дарослы дарослы цёмны тон скуры светлы тон скуры',
    '🧑🏿‍❤‍🧑🏼' => 'закаханая пара: дарослы дарослы цёмны тон скуры сярэднясветлы тон скуры',
    '🧑🏿‍❤‍🧑🏽' => 'закаханая пара: дарослы дарослы цёмны тон скуры сярэдні тон скуры',
    '🧑🏿‍❤‍🧑🏾' => 'закаханая пара: дарослы дарослы цёмны тон скуры сярэдняцёмны тон скуры',
    '🧑🏻‍🐰‍🧑🏼' => 'людзі весяляцца: светлы тон скуры сярэднясветлы тон скуры',
    '🧑🏻‍🐰‍🧑🏽' => 'людзі весяляцца: светлы тон скуры сярэдні тон скуры',
    '🧑🏻‍🐰‍🧑🏾' => 'людзі весяляцца: светлы тон скуры сярэдняцёмны тон скуры',
    '🧑🏻‍🐰‍🧑🏿' => 'людзі весяляцца: светлы тон скуры цёмны тон скуры',
    '🧑🏼‍🐰‍🧑🏻' => 'людзі весяляцца: сярэднясветлы тон скуры светлы тон скуры',
    '🧑🏼‍🐰‍🧑🏽' => 'людзі весяляцца: сярэднясветлы тон скуры сярэдні тон скуры',
    '🧑🏼‍🐰‍🧑🏾' => 'людзі весяляцца: сярэднясветлы тон скуры сярэдняцёмны тон скуры',
    '🧑🏼‍🐰‍🧑🏿' => 'людзі весяляцца: сярэднясветлы тон скуры цёмны тон скуры',
    '🧑🏽‍🐰‍🧑🏻' => 'людзі весяляцца: сярэдні тон скуры светлы тон скуры',
    '🧑🏽‍🐰‍🧑🏼' => 'людзі весяляцца: сярэдні тон скуры сярэднясветлы тон скуры',
    '🧑🏽‍🐰‍🧑🏾' => 'людзі весяляцца: сярэдні тон скуры сярэдняцёмны тон скуры',
    '🧑🏽‍🐰‍🧑🏿' => 'людзі весяляцца: сярэдні тон скуры цёмны тон скуры',
    '🧑🏾‍🐰‍🧑🏻' => 'людзі весяляцца: сярэдняцёмны тон скуры светлы тон скуры',
    '🧑🏾‍🐰‍🧑🏼' => 'людзі весяляцца: сярэдняцёмны тон скуры сярэднясветлы тон скуры',
    '🧑🏾‍🐰‍🧑🏽' => 'людзі весяляцца: сярэдняцёмны тон скуры сярэдні тон скуры',
    '🧑🏾‍🐰‍🧑🏿' => 'людзі весяляцца: сярэдняцёмны тон скуры цёмны тон скуры',
    '🧑🏿‍🐰‍🧑🏻' => 'людзі весяляцца: цёмны тон скуры светлы тон скуры',
    '🧑🏿‍🐰‍🧑🏼' => 'людзі весяляцца: цёмны тон скуры сярэднясветлы тон скуры',
    '🧑🏿‍🐰‍🧑🏽' => 'людзі весяляцца: цёмны тон скуры сярэдні тон скуры',
    '🧑🏿‍🐰‍🧑🏾' => 'людзі весяляцца: цёмны тон скуры сярэдняцёмны тон скуры',
    '👨🏻‍🫯‍👨🏼' => 'барацьба мужчын: светлы тон скуры сярэднясветлы тон скуры',
    '👨🏻‍🫯‍👨🏽' => 'барацьба мужчын: светлы тон скуры сярэдні тон скуры',
    '👨🏻‍🫯‍👨🏾' => 'барацьба мужчын: светлы тон скуры сярэдняцёмны тон скуры',
    '👨🏻‍🫯‍👨🏿' => 'барацьба мужчын: светлы тон скуры цёмны тон скуры',
    '👨🏼‍🫯‍👨🏻' => 'барацьба мужчын: сярэднясветлы тон скуры светлы тон скуры',
    '👨🏼‍🫯‍👨🏽' => 'барацьба мужчын: сярэднясветлы тон скуры сярэдні тон скуры',
    '👨🏼‍🫯‍👨🏾' => 'барацьба мужчын: сярэднясветлы тон скуры сярэдняцёмны тон скуры',
    '👨🏼‍🫯‍👨🏿' => 'барацьба мужчын: сярэднясветлы тон скуры цёмны тон скуры',
    '👨🏽‍🫯‍👨🏻' => 'барацьба мужчын: сярэдні тон скуры светлы тон скуры',
    '👨🏽‍🫯‍👨🏼' => 'барацьба мужчын: сярэдні тон скуры сярэднясветлы тон скуры',
    '👨🏽‍🫯‍👨🏾' => 'барацьба мужчын: сярэдні тон скуры сярэдняцёмны тон скуры',
    '👨🏽‍🫯‍👨🏿' => 'барацьба мужчын: сярэдні тон скуры цёмны тон скуры',
    '👨🏾‍🫯‍👨🏻' => 'барацьба мужчын: сярэдняцёмны тон скуры светлы тон скуры',
    '👨🏾‍🫯‍👨🏼' => 'барацьба мужчын: сярэдняцёмны тон скуры сярэднясветлы тон скуры',
    '👨🏾‍🫯‍👨🏽' => 'барацьба мужчын: сярэдняцёмны тон скуры сярэдні тон скуры',
    '👨🏾‍🫯‍👨🏿' => 'барацьба мужчын: сярэдняцёмны тон скуры цёмны тон скуры',
    '👨🏿‍🫯‍👨🏻' => 'барацьба мужчын: цёмны тон скуры светлы тон скуры',
    '👨🏿‍🫯‍👨🏼' => 'барацьба мужчын: цёмны тон скуры сярэднясветлы тон скуры',
    '👨🏿‍🫯‍👨🏽' => 'барацьба мужчын: цёмны тон скуры сярэдні тон скуры',
    '👨🏿‍🫯‍👨🏾' => 'барацьба мужчын: цёмны тон скуры сярэдняцёмны тон скуры',
    '👨🏻‍❤‍👨🏻' => 'закаханая пара: мужчына мужчына светлы тон скуры',
    '👨🏻‍❤‍👨🏼' => 'закаханая пара: мужчына мужчына светлы тон скуры сярэднясветлы тон скуры',
    '👨🏻‍❤‍👨🏽' => 'закаханая пара: мужчына мужчына светлы тон скуры сярэдні тон скуры',
    '👨🏻‍❤‍👨🏾' => 'закаханая пара: мужчына мужчына светлы тон скуры сярэдняцёмны тон скуры',
    '👨🏻‍❤‍👨🏿' => 'закаханая пара: мужчына мужчына светлы тон скуры цёмны тон скуры',
    '👨🏼‍❤‍👨🏻' => 'закаханая пара: мужчына мужчына сярэднясветлы тон скуры светлы тон скуры',
    '👨🏼‍❤‍👨🏼' => 'закаханая пара: мужчына мужчына сярэднясветлы тон скуры',
    '👨🏼‍❤‍👨🏽' => 'закаханая пара: мужчына мужчына сярэднясветлы тон скуры сярэдні тон скуры',
    '👨🏼‍❤‍👨🏾' => 'закаханая пара: мужчына мужчына сярэднясветлы тон скуры сярэдняцёмны тон скуры',
    '👨🏼‍❤‍👨🏿' => 'закаханая пара: мужчына мужчына сярэднясветлы тон скуры цёмны тон скуры',
    '👨🏽‍❤‍👨🏻' => 'закаханая пара: мужчына мужчына сярэдні тон скуры светлы тон скуры',
    '👨🏽‍❤‍👨🏼' => 'закаханая пара: мужчына мужчына сярэдні тон скуры сярэднясветлы тон скуры',
    '👨🏽‍❤‍👨🏽' => 'закаханая пара: мужчына мужчына сярэдні тон скуры',
    '👨🏽‍❤‍👨🏾' => 'закаханая пара: мужчына мужчына сярэдні тон скуры сярэдняцёмны тон скуры',
    '👨🏽‍❤‍👨🏿' => 'закаханая пара: мужчына мужчына сярэдні тон скуры цёмны тон скуры',
    '👨🏾‍❤‍👨🏻' => 'закаханая пара: мужчына мужчына сярэдняцёмны тон скуры светлы тон скуры',
    '👨🏾‍❤‍👨🏼' => 'закаханая пара: мужчына мужчына сярэдняцёмны тон скуры сярэднясветлы тон скуры',
    '👨🏾‍❤‍👨🏽' => 'закаханая пара: мужчына мужчына сярэдняцёмны тон скуры сярэдні тон скуры',
    '👨🏾‍❤‍👨🏾' => 'закаханая пара: мужчына мужчына сярэдняцёмны тон скуры',
    '👨🏾‍❤‍👨🏿' => 'закаханая пара: мужчына мужчына сярэдняцёмны тон скуры цёмны тон скуры',
    '👨🏿‍❤‍👨🏻' => 'закаханая пара: мужчына мужчына цёмны тон скуры светлы тон скуры',
    '👨🏿‍❤‍👨🏼' => 'закаханая пара: мужчына мужчына цёмны тон скуры сярэднясветлы тон скуры',
    '👨🏿‍❤‍👨🏽' => 'закаханая пара: мужчына мужчына цёмны тон скуры сярэдні тон скуры',
    '👨🏿‍❤‍👨🏾' => 'закаханая пара: мужчына мужчына цёмны тон скуры сярэдняцёмны тон скуры',
    '👨🏿‍❤‍👨🏿' => 'закаханая пара: мужчына мужчына цёмны тон скуры',
    '👨🏻‍🐰‍👨🏼' => 'мужчыны весяляцца: светлы тон скуры сярэднясветлы тон скуры',
    '👨🏻‍🐰‍👨🏽' => 'мужчыны весяляцца: светлы тон скуры сярэдні тон скуры',
    '👨🏻‍🐰‍👨🏾' => 'мужчыны весяляцца: светлы тон скуры сярэдняцёмны тон скуры',
    '👨🏻‍🐰‍👨🏿' => 'мужчыны весяляцца: светлы тон скуры цёмны тон скуры',
    '👨🏼‍🐰‍👨🏻' => 'мужчыны весяляцца: сярэднясветлы тон скуры светлы тон скуры',
    '👨🏼‍🐰‍👨🏽' => 'мужчыны весяляцца: сярэднясветлы тон скуры сярэдні тон скуры',
    '👨🏼‍🐰‍👨🏾' => 'мужчыны весяляцца: сярэднясветлы тон скуры сярэдняцёмны тон скуры',
    '👨🏼‍🐰‍👨🏿' => 'мужчыны весяляцца: сярэднясветлы тон скуры цёмны тон скуры',
    '👨🏽‍🐰‍👨🏻' => 'мужчыны весяляцца: сярэдні тон скуры светлы тон скуры',
    '👨🏽‍🐰‍👨🏼' => 'мужчыны весяляцца: сярэдні тон скуры сярэднясветлы тон скуры',
    '👨🏽‍🐰‍👨🏾' => 'мужчыны весяляцца: сярэдні тон скуры сярэдняцёмны тон скуры',
    '👨🏽‍🐰‍👨🏿' => 'мужчыны весяляцца: сярэдні тон скуры цёмны тон скуры',
    '👨🏾‍🐰‍👨🏻' => 'мужчыны весяляцца: сярэдняцёмны тон скуры светлы тон скуры',
    '👨🏾‍🐰‍👨🏼' => 'мужчыны весяляцца: сярэдняцёмны тон скуры сярэднясветлы тон скуры',
    '👨🏾‍🐰‍👨🏽' => 'мужчыны весяляцца: сярэдняцёмны тон скуры сярэдні тон скуры',
    '👨🏾‍🐰‍👨🏿' => 'мужчыны весяляцца: сярэдняцёмны тон скуры цёмны тон скуры',
    '👨🏿‍🐰‍👨🏻' => 'мужчыны весяляцца: цёмны тон скуры светлы тон скуры',
    '👨🏿‍🐰‍👨🏼' => 'мужчыны весяляцца: цёмны тон скуры сярэднясветлы тон скуры',
    '👨🏿‍🐰‍👨🏽' => 'мужчыны весяляцца: цёмны тон скуры сярэдні тон скуры',
    '👨🏿‍🐰‍👨🏾' => 'мужчыны весяляцца: цёмны тон скуры сярэдняцёмны тон скуры',
    '👩🏻‍🫯‍👩🏼' => 'жанчыны-барцы: светлы тон скуры сярэднясветлы тон скуры',
    '👩🏻‍🫯‍👩🏽' => 'жанчыны-барцы: светлы тон скуры сярэдні тон скуры',
    '👩🏻‍🫯‍👩🏾' => 'жанчыны-барцы: светлы тон скуры сярэдняцёмны тон скуры',
    '👩🏻‍🫯‍👩🏿' => 'жанчыны-барцы: светлы тон скуры цёмны тон скуры',
    '👩🏼‍🫯‍👩🏻' => 'жанчыны-барцы: сярэднясветлы тон скуры светлы тон скуры',
    '👩🏼‍🫯‍👩🏽' => 'жанчыны-барцы: сярэднясветлы тон скуры сярэдні тон скуры',
    '👩🏼‍🫯‍👩🏾' => 'жанчыны-барцы: сярэднясветлы тон скуры сярэдняцёмны тон скуры',
    '👩🏼‍🫯‍👩🏿' => 'жанчыны-барцы: сярэднясветлы тон скуры цёмны тон скуры',
    '👩🏽‍🫯‍👩🏻' => 'жанчыны-барцы: сярэдні тон скуры светлы тон скуры',
    '👩🏽‍🫯‍👩🏼' => 'жанчыны-барцы: сярэдні тон скуры сярэднясветлы тон скуры',
    '👩🏽‍🫯‍👩🏾' => 'жанчыны-барцы: сярэдні тон скуры сярэдняцёмны тон скуры',
    '👩🏽‍🫯‍👩🏿' => 'жанчыны-барцы: сярэдні тон скуры цёмны тон скуры',
    '👩🏾‍🫯‍👩🏻' => 'жанчыны-барцы: сярэдняцёмны тон скуры светлы тон скуры',
    '👩🏾‍🫯‍👩🏼' => 'жанчыны-барцы: сярэдняцёмны тон скуры сярэднясветлы тон скуры',
    '👩🏾‍🫯‍👩🏽' => 'жанчыны-барцы: сярэдняцёмны тон скуры сярэдні тон скуры',
    '👩🏾‍🫯‍👩🏿' => 'жанчыны-барцы: сярэдняцёмны тон скуры цёмны тон скуры',
    '👩🏿‍🫯‍👩🏻' => 'жанчыны-барцы: цёмны тон скуры светлы тон скуры',
    '👩🏿‍🫯‍👩🏼' => 'жанчыны-барцы: цёмны тон скуры сярэднясветлы тон скуры',
    '👩🏿‍🫯‍👩🏽' => 'жанчыны-барцы: цёмны тон скуры сярэдні тон скуры',
    '👩🏿‍🫯‍👩🏾' => 'жанчыны-барцы: цёмны тон скуры сярэдняцёмны тон скуры',
    '👩🏻‍❤‍👨🏻' => 'закаханая пара: жанчына мужчына светлы тон скуры',
    '👩🏻‍❤‍👨🏼' => 'закаханая пара: жанчына мужчына светлы тон скуры сярэднясветлы тон скуры',
    '👩🏻‍❤‍👨🏽' => 'закаханая пара: жанчына мужчына светлы тон скуры сярэдні тон скуры',
    '👩🏻‍❤‍👨🏾' => 'закаханая пара: жанчына мужчына светлы тон скуры сярэдняцёмны тон скуры',
    '👩🏻‍❤‍👨🏿' => 'закаханая пара: жанчына мужчына светлы тон скуры цёмны тон скуры',
    '👩🏼‍❤‍👨🏻' => 'закаханая пара: жанчына мужчына сярэднясветлы тон скуры светлы тон скуры',
    '👩🏼‍❤‍👨🏼' => 'закаханая пара: жанчына мужчына сярэднясветлы тон скуры',
    '👩🏼‍❤‍👨🏽' => 'закаханая пара: жанчына мужчына сярэднясветлы тон скуры сярэдні тон скуры',
    '👩🏼‍❤‍👨🏾' => 'закаханая пара: жанчына мужчына сярэднясветлы тон скуры сярэдняцёмны тон скуры',
    '👩🏼‍❤‍👨🏿' => 'закаханая пара: жанчына мужчына сярэднясветлы тон скуры цёмны тон скуры',
    '👩🏽‍❤‍👨🏻' => 'закаханая пара: жанчына мужчына сярэдні тон скуры светлы тон скуры',
    '👩🏽‍❤‍👨🏼' => 'закаханая пара: жанчына мужчына сярэдні тон скуры сярэднясветлы тон скуры',
    '👩🏽‍❤‍👨🏽' => 'закаханая пара: жанчына мужчына сярэдні тон скуры',
    '👩🏽‍❤‍👨🏾' => 'закаханая пара: жанчына мужчына сярэдні тон скуры сярэдняцёмны тон скуры',
    '👩🏽‍❤‍👨🏿' => 'закаханая пара: жанчына мужчына сярэдні тон скуры цёмны тон скуры',
    '👩🏾‍❤‍👨🏻' => 'закаханая пара: жанчына мужчына сярэдняцёмны тон скуры светлы тон скуры',
    '👩🏾‍❤‍👨🏼' => 'закаханая пара: жанчына мужчына сярэдняцёмны тон скуры сярэднясветлы тон скуры',
    '👩🏾‍❤‍👨🏽' => 'закаханая пара: жанчына мужчына сярэдняцёмны тон скуры сярэдні тон скуры',
    '👩🏾‍❤‍👨🏾' => 'закаханая пара: жанчына мужчына сярэдняцёмны тон скуры',
    '👩🏾‍❤‍👨🏿' => 'закаханая пара: жанчына мужчына сярэдняцёмны тон скуры цёмны тон скуры',
    '👩🏿‍❤‍👨🏻' => 'закаханая пара: жанчына мужчына цёмны тон скуры светлы тон скуры',
    '👩🏿‍❤‍👨🏼' => 'закаханая пара: жанчына мужчына цёмны тон скуры сярэднясветлы тон скуры',
    '👩🏿‍❤‍👨🏽' => 'закаханая пара: жанчына мужчына цёмны тон скуры сярэдні тон скуры',
    '👩🏿‍❤‍👨🏾' => 'закаханая пара: жанчына мужчына цёмны тон скуры сярэдняцёмны тон скуры',
    '👩🏿‍❤‍👨🏿' => 'закаханая пара: жанчына мужчына цёмны тон скуры',
    '👩🏻‍❤‍👩🏻' => 'закаханая пара: жанчына жанчына светлы тон скуры',
    '👩🏻‍❤‍👩🏼' => 'закаханая пара: жанчына жанчына светлы тон скуры сярэднясветлы тон скуры',
    '👩🏻‍❤‍👩🏽' => 'закаханая пара: жанчына жанчына светлы тон скуры сярэдні тон скуры',
    '👩🏻‍❤‍👩🏾' => 'закаханая пара: жанчына жанчына светлы тон скуры сярэдняцёмны тон скуры',
    '👩🏻‍❤‍👩🏿' => 'закаханая пара: жанчына жанчына светлы тон скуры цёмны тон скуры',
    '👩🏼‍❤‍👩🏻' => 'закаханая пара: жанчына жанчына сярэднясветлы тон скуры светлы тон скуры',
    '👩🏼‍❤‍👩🏼' => 'закаханая пара: жанчына жанчына сярэднясветлы тон скуры',
    '👩🏼‍❤‍👩🏽' => 'закаханая пара: жанчына жанчына сярэднясветлы тон скуры сярэдні тон скуры',
    '👩🏼‍❤‍👩🏾' => 'закаханая пара: жанчына жанчына сярэднясветлы тон скуры сярэдняцёмны тон скуры',
    '👩🏼‍❤‍👩🏿' => 'закаханая пара: жанчына жанчына сярэднясветлы тон скуры цёмны тон скуры',
    '👩🏽‍❤‍👩🏻' => 'закаханая пара: жанчына жанчына сярэдні тон скуры светлы тон скуры',
    '👩🏽‍❤‍👩🏼' => 'закаханая пара: жанчына жанчына сярэдні тон скуры сярэднясветлы тон скуры',
    '👩🏽‍❤‍👩🏽' => 'закаханая пара: жанчына жанчына сярэдні тон скуры',
    '👩🏽‍❤‍👩🏾' => 'закаханая пара: жанчына жанчына сярэдні тон скуры сярэдняцёмны тон скуры',
    '👩🏽‍❤‍👩🏿' => 'закаханая пара: жанчына жанчына сярэдні тон скуры цёмны тон скуры',
    '👩🏾‍❤‍👩🏻' => 'закаханая пара: жанчына жанчына сярэдняцёмны тон скуры светлы тон скуры',
    '👩🏾‍❤‍👩🏼' => 'закаханая пара: жанчына жанчына сярэдняцёмны тон скуры сярэднясветлы тон скуры',
    '👩🏾‍❤‍👩🏽' => 'закаханая пара: жанчына жанчына сярэдняцёмны тон скуры сярэдні тон скуры',
    '👩🏾‍❤‍👩🏾' => 'закаханая пара: жанчына жанчына сярэдняцёмны тон скуры',
    '👩🏾‍❤‍👩🏿' => 'закаханая пара: жанчына жанчына сярэдняцёмны тон скуры цёмны тон скуры',
    '👩🏿‍❤‍👩🏻' => 'закаханая пара: жанчына жанчына цёмны тон скуры светлы тон скуры',
    '👩🏿‍❤‍👩🏼' => 'закаханая пара: жанчына жанчына цёмны тон скуры сярэднясветлы тон скуры',
    '👩🏿‍❤‍👩🏽' => 'закаханая пара: жанчына жанчына цёмны тон скуры сярэдні тон скуры',
    '👩🏿‍❤‍👩🏾' => 'закаханая пара: жанчына жанчына цёмны тон скуры сярэдняцёмны тон скуры',
    '👩🏿‍❤‍👩🏿' => 'закаханая пара: жанчына жанчына цёмны тон скуры',
    '👩🏻‍🐰‍👩🏼' => 'жанчыны весяляцца: светлы тон скуры сярэднясветлы тон скуры',
    '👩🏻‍🐰‍👩🏽' => 'жанчыны весяляцца: светлы тон скуры сярэдні тон скуры',
    '👩🏻‍🐰‍👩🏾' => 'жанчыны весяляцца: светлы тон скуры сярэдняцёмны тон скуры',
    '👩🏻‍🐰‍👩🏿' => 'жанчыны весяляцца: светлы тон скуры цёмны тон скуры',
    '👩🏼‍🐰‍👩🏻' => 'жанчыны весяляцца: сярэднясветлы тон скуры светлы тон скуры',
    '👩🏼‍🐰‍👩🏽' => 'жанчыны весяляцца: сярэднясветлы тон скуры сярэдні тон скуры',
    '👩🏼‍🐰‍👩🏾' => 'жанчыны весяляцца: сярэднясветлы тон скуры сярэдняцёмны тон скуры',
    '👩🏼‍🐰‍👩🏿' => 'жанчыны весяляцца: сярэднясветлы тон скуры цёмны тон скуры',
    '👩🏽‍🐰‍👩🏻' => 'жанчыны весяляцца: сярэдні тон скуры светлы тон скуры',
    '👩🏽‍🐰‍👩🏼' => 'жанчыны весяляцца: сярэдні тон скуры сярэднясветлы тон скуры',
    '👩🏽‍🐰‍👩🏾' => 'жанчыны весяляцца: сярэдні тон скуры сярэдняцёмны тон скуры',
    '👩🏽‍🐰‍👩🏿' => 'жанчыны весяляцца: сярэдні тон скуры цёмны тон скуры',
    '👩🏾‍🐰‍👩🏻' => 'жанчыны весяляцца: сярэдняцёмны тон скуры светлы тон скуры',
    '👩🏾‍🐰‍👩🏼' => 'жанчыны весяляцца: сярэдняцёмны тон скуры сярэднясветлы тон скуры',
    '👩🏾‍🐰‍👩🏽' => 'жанчыны весяляцца: сярэдняцёмны тон скуры сярэдні тон скуры',
    '👩🏾‍🐰‍👩🏿' => 'жанчыны весяляцца: сярэдняцёмны тон скуры цёмны тон скуры',
    '👩🏿‍🐰‍👩🏻' => 'жанчыны весяляцца: цёмны тон скуры светлы тон скуры',
    '👩🏿‍🐰‍👩🏼' => 'жанчыны весяляцца: цёмны тон скуры сярэднясветлы тон скуры',
    '👩🏿‍🐰‍👩🏽' => 'жанчыны весяляцца: цёмны тон скуры сярэдні тон скуры',
    '👩🏿‍🐰‍👩🏾' => 'жанчыны весяляцца: цёмны тон скуры сярэдняцёмны тон скуры',
    '🧑🏻‍🤝‍🧑🏻' => 'людзі трымаюцца за рукі: светлы тон скуры',
    '🧑🏻‍🤝‍🧑🏼' => 'людзі трымаюцца за рукі: светлы тон скуры сярэднясветлы тон скуры',
    '🧑🏻‍🤝‍🧑🏽' => 'людзі трымаюцца за рукі: светлы тон скуры сярэдні тон скуры',
    '🧑🏻‍🤝‍🧑🏾' => 'людзі трымаюцца за рукі: светлы тон скуры сярэдняцёмны тон скуры',
    '🧑🏻‍🤝‍🧑🏿' => 'людзі трымаюцца за рукі: светлы тон скуры цёмны тон скуры',
    '🧑🏼‍🤝‍🧑🏻' => 'людзі трымаюцца за рукі: сярэднясветлы тон скуры светлы тон скуры',
    '🧑🏼‍🤝‍🧑🏼' => 'людзі трымаюцца за рукі: сярэднясветлы тон скуры',
    '🧑🏼‍🤝‍🧑🏽' => 'людзі трымаюцца за рукі: сярэднясветлы тон скуры сярэдні тон скуры',
    '🧑🏼‍🤝‍🧑🏾' => 'людзі трымаюцца за рукі: сярэднясветлы тон скуры сярэдняцёмны тон скуры',
    '🧑🏼‍🤝‍🧑🏿' => 'людзі трымаюцца за рукі: сярэднясветлы тон скуры цёмны тон скуры',
    '🧑🏽‍🤝‍🧑🏻' => 'людзі трымаюцца за рукі: сярэдні тон скуры светлы тон скуры',
    '🧑🏽‍🤝‍🧑🏼' => 'людзі трымаюцца за рукі: сярэдні тон скуры сярэднясветлы тон скуры',
    '🧑🏽‍🤝‍🧑🏽' => 'людзі трымаюцца за рукі: сярэдні тон скуры',
    '🧑🏽‍🤝‍🧑🏾' => 'людзі трымаюцца за рукі: сярэдні тон скуры сярэдняцёмны тон скуры',
    '🧑🏽‍🤝‍🧑🏿' => 'людзі трымаюцца за рукі: сярэдні тон скуры цёмны тон скуры',
    '🧑🏾‍🤝‍🧑🏻' => 'людзі трымаюцца за рукі: сярэдняцёмны тон скуры светлы тон скуры',
    '🧑🏾‍🤝‍🧑🏼' => 'людзі трымаюцца за рукі: сярэдняцёмны тон скуры сярэднясветлы тон скуры',
    '🧑🏾‍🤝‍🧑🏽' => 'людзі трымаюцца за рукі: сярэдняцёмны тон скуры сярэдні тон скуры',
    '🧑🏾‍🤝‍🧑🏾' => 'людзі трымаюцца за рукі: сярэдняцёмны тон скуры',
    '🧑🏾‍🤝‍🧑🏿' => 'людзі трымаюцца за рукі: сярэдняцёмны тон скуры цёмны тон скуры',
    '🧑🏿‍🤝‍🧑🏻' => 'людзі трымаюцца за рукі: цёмны тон скуры светлы тон скуры',
    '🧑🏿‍🤝‍🧑🏼' => 'людзі трымаюцца за рукі: цёмны тон скуры сярэднясветлы тон скуры',
    '🧑🏿‍🤝‍🧑🏽' => 'людзі трымаюцца за рукі: цёмны тон скуры сярэдні тон скуры',
    '🧑🏿‍🤝‍🧑🏾' => 'людзі трымаюцца за рукі: цёмны тон скуры сярэдняцёмны тон скуры',
    '🧑🏿‍🤝‍🧑🏿' => 'людзі трымаюцца за рукі: цёмны тон скуры',
    '👩🏻‍🤝‍👩🏼' => 'жанчыны трымаюцца за рукі: светлы тон скуры сярэднясветлы тон скуры',
    '👩🏻‍🤝‍👩🏽' => 'жанчыны трымаюцца за рукі: светлы тон скуры сярэдні тон скуры',
    '👩🏻‍🤝‍👩🏾' => 'жанчыны трымаюцца за рукі: светлы тон скуры сярэдняцёмны тон скуры',
    '👩🏻‍🤝‍👩🏿' => 'жанчыны трымаюцца за рукі: светлы тон скуры цёмны тон скуры',
    '👩🏼‍🤝‍👩🏻' => 'жанчыны трымаюцца за рукі: сярэднясветлы тон скуры светлы тон скуры',
    '👩🏼‍🤝‍👩🏽' => 'жанчыны трымаюцца за рукі: сярэднясветлы тон скуры сярэдні тон скуры',
    '👩🏼‍🤝‍👩🏾' => 'жанчыны трымаюцца за рукі: сярэднясветлы тон скуры сярэдняцёмны тон скуры',
    '👩🏼‍🤝‍👩🏿' => 'жанчыны трымаюцца за рукі: сярэднясветлы тон скуры цёмны тон скуры',
    '👩🏽‍🤝‍👩🏻' => 'жанчыны трымаюцца за рукі: сярэдні тон скуры светлы тон скуры',
    '👩🏽‍🤝‍👩🏼' => 'жанчыны трымаюцца за рукі: сярэдні тон скуры сярэднясветлы тон скуры',
    '👩🏽‍🤝‍👩🏾' => 'жанчыны трымаюцца за рукі: сярэдні тон скуры сярэдняцёмны тон скуры',
    '👩🏽‍🤝‍👩🏿' => 'жанчыны трымаюцца за рукі: сярэдні тон скуры цёмны тон скуры',
    '👩🏾‍🤝‍👩🏻' => 'жанчыны трымаюцца за рукі: сярэдняцёмны тон скуры светлы тон скуры',
    '👩🏾‍🤝‍👩🏼' => 'жанчыны трымаюцца за рукі: сярэдняцёмны тон скуры сярэднясветлы тон скуры',
    '👩🏾‍🤝‍👩🏽' => 'жанчыны трымаюцца за рукі: сярэдняцёмны тон скуры сярэдні тон скуры',
    '👩🏾‍🤝‍👩🏿' => 'жанчыны трымаюцца за рукі: сярэдняцёмны тон скуры цёмны тон скуры',
    '👩🏿‍🤝‍👩🏻' => 'жанчыны трымаюцца за рукі: цёмны тон скуры светлы тон скуры',
    '👩🏿‍🤝‍👩🏼' => 'жанчыны трымаюцца за рукі: цёмны тон скуры сярэднясветлы тон скуры',
    '👩🏿‍🤝‍👩🏽' => 'жанчыны трымаюцца за рукі: цёмны тон скуры сярэдні тон скуры',
    '👩🏿‍🤝‍👩🏾' => 'жанчыны трымаюцца за рукі: цёмны тон скуры сярэдняцёмны тон скуры',
    '👩🏻‍🤝‍👨🏼' => 'мужчына і жанчына трымаюцца за рукі: светлы тон скуры сярэднясветлы тон скуры',
    '👩🏻‍🤝‍👨🏽' => 'мужчына і жанчына трымаюцца за рукі: светлы тон скуры сярэдні тон скуры',
    '👩🏻‍🤝‍👨🏾' => 'мужчына і жанчына трымаюцца за рукі: светлы тон скуры сярэдняцёмны тон скуры',
    '👩🏻‍🤝‍👨🏿' => 'мужчына і жанчына трымаюцца за рукі: светлы тон скуры цёмны тон скуры',
    '👩🏼‍🤝‍👨🏻' => 'мужчына і жанчына трымаюцца за рукі: сярэднясветлы тон скуры светлы тон скуры',
    '👩🏼‍🤝‍👨🏽' => 'мужчына і жанчына трымаюцца за рукі: сярэднясветлы тон скуры сярэдні тон скуры',
    '👩🏼‍🤝‍👨🏾' => 'мужчына і жанчына трымаюцца за рукі: сярэднясветлы тон скуры сярэдняцёмны тон скуры',
    '👩🏼‍🤝‍👨🏿' => 'мужчына і жанчына трымаюцца за рукі: сярэднясветлы тон скуры цёмны тон скуры',
    '👩🏽‍🤝‍👨🏻' => 'мужчына і жанчына трымаюцца за рукі: сярэдні тон скуры светлы тон скуры',
    '👩🏽‍🤝‍👨🏼' => 'мужчына і жанчына трымаюцца за рукі: сярэдні тон скуры сярэднясветлы тон скуры',
    '👩🏽‍🤝‍👨🏾' => 'мужчына і жанчына трымаюцца за рукі: сярэдні тон скуры сярэдняцёмны тон скуры',
    '👩🏽‍🤝‍👨🏿' => 'мужчына і жанчына трымаюцца за рукі: сярэдні тон скуры цёмны тон скуры',
    '👩🏾‍🤝‍👨🏻' => 'мужчына і жанчына трымаюцца за рукі: сярэдняцёмны тон скуры светлы тон скуры',
    '👩🏾‍🤝‍👨🏼' => 'мужчына і жанчына трымаюцца за рукі: сярэдняцёмны тон скуры сярэднясветлы тон скуры',
    '👩🏾‍🤝‍👨🏽' => 'мужчына і жанчына трымаюцца за рукі: сярэдняцёмны тон скуры сярэдні тон скуры',
    '👩🏾‍🤝‍👨🏿' => 'мужчына і жанчына трымаюцца за рукі: сярэдняцёмны тон скуры цёмны тон скуры',
    '👩🏿‍🤝‍👨🏻' => 'мужчына і жанчына трымаюцца за рукі: цёмны тон скуры светлы тон скуры',
    '👩🏿‍🤝‍👨🏼' => 'мужчына і жанчына трымаюцца за рукі: цёмны тон скуры сярэднясветлы тон скуры',
    '👩🏿‍🤝‍👨🏽' => 'мужчына і жанчына трымаюцца за рукі: цёмны тон скуры сярэдні тон скуры',
    '👩🏿‍🤝‍👨🏾' => 'мужчына і жанчына трымаюцца за рукі: цёмны тон скуры сярэдняцёмны тон скуры',
    '👨🏻‍🤝‍👨🏼' => 'мужчыны трымаюцца за рукі: светлы тон скуры сярэднясветлы тон скуры',
    '👨🏻‍🤝‍👨🏽' => 'мужчыны трымаюцца за рукі: светлы тон скуры сярэдні тон скуры',
    '👨🏻‍🤝‍👨🏾' => 'мужчыны трымаюцца за рукі: светлы тон скуры сярэдняцёмны тон скуры',
    '👨🏻‍🤝‍👨🏿' => 'мужчыны трымаюцца за рукі: светлы тон скуры цёмны тон скуры',
    '👨🏼‍🤝‍👨🏻' => 'мужчыны трымаюцца за рукі: сярэднясветлы тон скуры светлы тон скуры',
    '👨🏼‍🤝‍👨🏽' => 'мужчыны трымаюцца за рукі: сярэднясветлы тон скуры сярэдні тон скуры',
    '👨🏼‍🤝‍👨🏾' => 'мужчыны трымаюцца за рукі: сярэднясветлы тон скуры сярэдняцёмны тон скуры',
    '👨🏼‍🤝‍👨🏿' => 'мужчыны трымаюцца за рукі: сярэднясветлы тон скуры цёмны тон скуры',
    '👨🏽‍🤝‍👨🏻' => 'мужчыны трымаюцца за рукі: сярэдні тон скуры светлы тон скуры',
    '👨🏽‍🤝‍👨🏼' => 'мужчыны трымаюцца за рукі: сярэдні тон скуры сярэднясветлы тон скуры',
    '👨🏽‍🤝‍👨🏾' => 'мужчыны трымаюцца за рукі: сярэдні тон скуры сярэдняцёмны тон скуры',
    '👨🏽‍🤝‍👨🏿' => 'мужчыны трымаюцца за рукі: сярэдні тон скуры цёмны тон скуры',
    '👨🏾‍🤝‍👨🏻' => 'мужчыны трымаюцца за рукі: сярэдняцёмны тон скуры светлы тон скуры',
    '👨🏾‍🤝‍👨🏼' => 'мужчыны трымаюцца за рукі: сярэдняцёмны тон скуры сярэднясветлы тон скуры',
    '👨🏾‍🤝‍👨🏽' => 'мужчыны трымаюцца за рукі: сярэдняцёмны тон скуры сярэдні тон скуры',
    '👨🏾‍🤝‍👨🏿' => 'мужчыны трымаюцца за рукі: сярэдняцёмны тон скуры цёмны тон скуры',
    '👨🏿‍🤝‍👨🏻' => 'мужчыны трымаюцца за рукі: цёмны тон скуры светлы тон скуры',
    '👨🏿‍🤝‍👨🏼' => 'мужчыны трымаюцца за рукі: цёмны тон скуры сярэднясветлы тон скуры',
    '👨🏿‍🤝‍👨🏽' => 'мужчыны трымаюцца за рукі: цёмны тон скуры сярэдні тон скуры',
    '👨🏿‍🤝‍👨🏾' => 'мужчыны трымаюцца за рукі: цёмны тон скуры сярэдняцёмны тон скуры',
    '👩‍❤‍💋‍👨' => 'пацалунак: жанчына мужчына',
    '👨‍❤‍💋‍👨' => 'пацалунак: мужчына мужчына',
    '👩‍❤‍💋‍👩' => 'пацалунак: жанчына жанчына',
    '👨‍👩‍👧‍👦' => 'сям’я: мужчына жанчына дзяўчынка хлопчык',
    '👨‍👩‍👦‍👦' => 'сям’я: мужчына жанчына хлопчык хлопчык',
    '👨‍👩‍👧‍👧' => 'сям’я: мужчына жанчына дзяўчынка дзяўчынка',
    '👨‍👨‍👧‍👦' => 'сям’я: мужчына мужчына дзяўчынка хлопчык',
    '👨‍👨‍👦‍👦' => 'сям’я: мужчына мужчына хлопчык хлопчык',
    '👨‍👨‍👧‍👧' => 'сям’я: мужчына мужчына дзяўчынка дзяўчынка',
    '👩‍👩‍👧‍👦' => 'сям’я: жанчына жанчына дзяўчынка хлопчык',
    '👩‍👩‍👦‍👦' => 'сям’я: жанчына жанчына хлопчык хлопчык',
    '👩‍👩‍👧‍👧' => 'сям’я: жанчына жанчына дзяўчынка дзяўчынка',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'Сцяг: Англія',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'Сцяг: Шатландыя',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'Сцяг: Уэльс',
    '🧑‍🧑‍🧒‍🧒' => 'сям’я: двое дарослых і двое дзяцей',
    '🚶🏻‍♀‍➡' => 'жанчына ідзе: светлы тон скуры , накіраваныя ўправа',
    '🚶🏼‍♀‍➡' => 'жанчына ідзе: сярэднясветлы тон скуры , накіраваныя ўправа',
    '🚶🏽‍♀‍➡' => 'жанчына ідзе: сярэдні тон скуры , накіраваныя ўправа',
    '🚶🏾‍♀‍➡' => 'жанчына ідзе: сярэдняцёмны тон скуры , накіраваныя ўправа',
    '🚶🏿‍♀‍➡' => 'жанчына ідзе: цёмны тон скуры , накіраваныя ўправа',
    '🚶🏻‍♂‍➡' => 'мужчына ідзе: светлы тон скуры , накіраваныя ўправа',
    '🚶🏼‍♂‍➡' => 'мужчына ідзе: сярэднясветлы тон скуры , накіраваныя ўправа',
    '🚶🏽‍♂‍➡' => 'мужчына ідзе: сярэдні тон скуры , накіраваныя ўправа',
    '🚶🏾‍♂‍➡' => 'мужчына ідзе: сярэдняцёмны тон скуры , накіраваныя ўправа',
    '🚶🏿‍♂‍➡' => 'мужчына ідзе: цёмны тон скуры , накіраваныя ўправа',
    '🧎🏻‍♀‍➡' => 'жанчына стаіць на каленях: светлы тон скуры , накіраваныя ўправа',
    '🧎🏼‍♀‍➡' => 'жанчына стаіць на каленях: сярэднясветлы тон скуры , накіраваныя ўправа',
    '🧎🏽‍♀‍➡' => 'жанчына стаіць на каленях: сярэдні тон скуры , накіраваныя ўправа',
    '🧎🏾‍♀‍➡' => 'жанчына стаіць на каленях: сярэдняцёмны тон скуры , накіраваныя ўправа',
    '🧎🏿‍♀‍➡' => 'жанчына стаіць на каленях: цёмны тон скуры , накіраваныя ўправа',
    '🧎🏻‍♂‍➡' => 'мужчына стаіць на каленях: светлы тон скуры , накіраваныя ўправа',
    '🧎🏼‍♂‍➡' => 'мужчына стаіць на каленях: сярэднясветлы тон скуры , накіраваныя ўправа',
    '🧎🏽‍♂‍➡' => 'мужчына стаіць на каленях: сярэдні тон скуры , накіраваныя ўправа',
    '🧎🏾‍♂‍➡' => 'мужчына стаіць на каленях: сярэдняцёмны тон скуры , накіраваныя ўправа',
    '🧎🏿‍♂‍➡' => 'мужчына стаіць на каленях: цёмны тон скуры , накіраваныя ўправа',
    '🧑🏻‍🦯‍➡' => 'чалавек з палкай: светлы тон скуры , накіраваныя ўправа',
    '🧑🏼‍🦯‍➡' => 'чалавек з палкай: сярэднясветлы тон скуры , накіраваныя ўправа',
    '🧑🏽‍🦯‍➡' => 'чалавек з палкай: сярэдні тон скуры , накіраваныя ўправа',
    '🧑🏾‍🦯‍➡' => 'чалавек з палкай: сярэдняцёмны тон скуры , накіраваныя ўправа',
    '🧑🏿‍🦯‍➡' => 'чалавек з палкай: цёмны тон скуры , накіраваныя ўправа',
    '👨🏻‍🦯‍➡' => 'мужчына з палкай: светлы тон скуры , накіраваныя ўправа',
    '👨🏼‍🦯‍➡' => 'мужчына з палкай: сярэднясветлы тон скуры , накіраваныя ўправа',
    '👨🏽‍🦯‍➡' => 'мужчына з палкай: сярэдні тон скуры , накіраваныя ўправа',
    '👨🏾‍🦯‍➡' => 'мужчына з палкай: сярэдняцёмны тон скуры , накіраваныя ўправа',
    '👨🏿‍🦯‍➡' => 'мужчына з палкай: цёмны тон скуры , накіраваныя ўправа',
    '👩🏻‍🦯‍➡' => 'жанчына з палкай: светлы тон скуры , накіраваныя ўправа',
    '👩🏼‍🦯‍➡' => 'жанчына з палкай: сярэднясветлы тон скуры , накіраваныя ўправа',
    '👩🏽‍🦯‍➡' => 'жанчына з палкай: сярэдні тон скуры , накіраваныя ўправа',
    '👩🏾‍🦯‍➡' => 'жанчына з палкай: сярэдняцёмны тон скуры , накіраваныя ўправа',
    '👩🏿‍🦯‍➡' => 'жанчына з палкай: цёмны тон скуры , накіраваныя ўправа',
    '🧑🏻‍🦼‍➡' => 'чалавек у інваліднай калясцы з маторам: светлы тон скуры , накіраваныя ўправа',
    '🧑🏼‍🦼‍➡' => 'чалавек у інваліднай калясцы з маторам: сярэднясветлы тон скуры , накіраваныя ўправа',
    '🧑🏽‍🦼‍➡' => 'чалавек у інваліднай калясцы з маторам: сярэдні тон скуры , накіраваныя ўправа',
    '🧑🏾‍🦼‍➡' => 'чалавек у інваліднай калясцы з маторам: сярэдняцёмны тон скуры , накіраваныя ўправа',
    '🧑🏿‍🦼‍➡' => 'чалавек у інваліднай калясцы з маторам: цёмны тон скуры , накіраваныя ўправа',
    '👨🏻‍🦼‍➡' => 'мужчына ў інваліднай калясцы з маторам: светлы тон скуры , накіраваныя ўправа',
    '👨🏼‍🦼‍➡' => 'мужчына ў інваліднай калясцы з маторам: сярэднясветлы тон скуры , накіраваныя ўправа',
    '👨🏽‍🦼‍➡' => 'мужчына ў інваліднай калясцы з маторам: сярэдні тон скуры , накіраваныя ўправа',
    '👨🏾‍🦼‍➡' => 'мужчына ў інваліднай калясцы з маторам: сярэдняцёмны тон скуры , накіраваныя ўправа',
    '👨🏿‍🦼‍➡' => 'мужчына ў інваліднай калясцы з маторам: цёмны тон скуры , накіраваныя ўправа',
    '👩🏻‍🦼‍➡' => 'жанчына ў інваліднай калясцы з маторам: светлы тон скуры , накіраваныя ўправа',
    '👩🏼‍🦼‍➡' => 'жанчына ў інваліднай калясцы з маторам: сярэднясветлы тон скуры , накіраваныя ўправа',
    '👩🏽‍🦼‍➡' => 'жанчына ў інваліднай калясцы з маторам: сярэдні тон скуры , накіраваныя ўправа',
    '👩🏾‍🦼‍➡' => 'жанчына ў інваліднай калясцы з маторам: сярэдняцёмны тон скуры , накіраваныя ўправа',
    '👩🏿‍🦼‍➡' => 'жанчына ў інваліднай калясцы з маторам: цёмны тон скуры , накіраваныя ўправа',
    '🧑🏻‍🦽‍➡' => 'чалавек у калясцы з ручным прывадам: светлы тон скуры , накіраваныя ўправа',
    '🧑🏼‍🦽‍➡' => 'чалавек у калясцы з ручным прывадам: сярэднясветлы тон скуры , накіраваныя ўправа',
    '🧑🏽‍🦽‍➡' => 'чалавек у калясцы з ручным прывадам: сярэдні тон скуры , накіраваныя ўправа',
    '🧑🏾‍🦽‍➡' => 'чалавек у калясцы з ручным прывадам: сярэдняцёмны тон скуры , накіраваныя ўправа',
    '🧑🏿‍🦽‍➡' => 'чалавек у калясцы з ручным прывадам: цёмны тон скуры , накіраваныя ўправа',
    '👨🏻‍🦽‍➡' => 'мужчына ў калясцы з ручным прывадам: светлы тон скуры , накіраваныя ўправа',
    '👨🏼‍🦽‍➡' => 'мужчына ў калясцы з ручным прывадам: сярэднясветлы тон скуры , накіраваныя ўправа',
    '👨🏽‍🦽‍➡' => 'мужчына ў калясцы з ручным прывадам: сярэдні тон скуры , накіраваныя ўправа',
    '👨🏾‍🦽‍➡' => 'мужчына ў калясцы з ручным прывадам: сярэдняцёмны тон скуры , накіраваныя ўправа',
    '👨🏿‍🦽‍➡' => 'мужчына ў калясцы з ручным прывадам: цёмны тон скуры , накіраваныя ўправа',
    '👩🏻‍🦽‍➡' => 'жанчына ў калясцы з ручным прывадам: светлы тон скуры , накіраваныя ўправа',
    '👩🏼‍🦽‍➡' => 'жанчына ў калясцы з ручным прывадам: сярэднясветлы тон скуры , накіраваныя ўправа',
    '👩🏽‍🦽‍➡' => 'жанчына ў калясцы з ручным прывадам: сярэдні тон скуры , накіраваныя ўправа',
    '👩🏾‍🦽‍➡' => 'жанчына ў калясцы з ручным прывадам: сярэдняцёмны тон скуры , накіраваныя ўправа',
    '👩🏿‍🦽‍➡' => 'жанчына ў калясцы з ручным прывадам: цёмны тон скуры , накіраваныя ўправа',
    '🏃🏻‍♀‍➡' => 'жанчына бяжыць: светлы тон скуры , накіраваныя ўправа',
    '🏃🏼‍♀‍➡' => 'жанчына бяжыць: сярэднясветлы тон скуры , накіраваныя ўправа',
    '🏃🏽‍♀‍➡' => 'жанчына бяжыць: сярэдні тон скуры , накіраваныя ўправа',
    '🏃🏾‍♀‍➡' => 'жанчына бяжыць: сярэдняцёмны тон скуры , накіраваныя ўправа',
    '🏃🏿‍♀‍➡' => 'жанчына бяжыць: цёмны тон скуры , накіраваныя ўправа',
    '🏃🏻‍♂‍➡' => 'мужчына бяжыць: светлы тон скуры , накіраваныя ўправа',
    '🏃🏼‍♂‍➡' => 'мужчына бяжыць: сярэднясветлы тон скуры , накіраваныя ўправа',
    '🏃🏽‍♂‍➡' => 'мужчына бяжыць: сярэдні тон скуры , накіраваныя ўправа',
    '🏃🏾‍♂‍➡' => 'мужчына бяжыць: сярэдняцёмны тон скуры , накіраваныя ўправа',
    '🏃🏿‍♂‍➡' => 'мужчына бяжыць: цёмны тон скуры , накіраваныя ўправа',
    '🫱🏻‍🫲🏼' => 'поціск рук: светлы тон скуры сярэднясветлы тон скуры',
    '🫱🏻‍🫲🏽' => 'поціск рук: светлы тон скуры сярэдні тон скуры',
    '🫱🏻‍🫲🏾' => 'поціск рук: светлы тон скуры сярэдняцёмны тон скуры',
    '🫱🏻‍🫲🏿' => 'поціск рук: светлы тон скуры цёмны тон скуры',
    '🫱🏼‍🫲🏻' => 'поціск рук: сярэднясветлы тон скуры светлы тон скуры',
    '🫱🏼‍🫲🏽' => 'поціск рук: сярэднясветлы тон скуры сярэдні тон скуры',
    '🫱🏼‍🫲🏾' => 'поціск рук: сярэднясветлы тон скуры сярэдняцёмны тон скуры',
    '🫱🏼‍🫲🏿' => 'поціск рук: сярэднясветлы тон скуры цёмны тон скуры',
    '🫱🏽‍🫲🏻' => 'поціск рук: сярэдні тон скуры светлы тон скуры',
    '🫱🏽‍🫲🏼' => 'поціск рук: сярэдні тон скуры сярэднясветлы тон скуры',
    '🫱🏽‍🫲🏾' => 'поціск рук: сярэдні тон скуры сярэдняцёмны тон скуры',
    '🫱🏽‍🫲🏿' => 'поціск рук: сярэдні тон скуры цёмны тон скуры',
    '🫱🏾‍🫲🏻' => 'поціск рук: сярэдняцёмны тон скуры светлы тон скуры',
    '🫱🏾‍🫲🏼' => 'поціск рук: сярэдняцёмны тон скуры сярэднясветлы тон скуры',
    '🫱🏾‍🫲🏽' => 'поціск рук: сярэдняцёмны тон скуры сярэдні тон скуры',
    '🫱🏾‍🫲🏿' => 'поціск рук: сярэдняцёмны тон скуры цёмны тон скуры',
    '🫱🏿‍🫲🏻' => 'поціск рук: цёмны тон скуры светлы тон скуры',
    '🫱🏿‍🫲🏼' => 'поціск рук: цёмны тон скуры сярэднясветлы тон скуры',
    '🫱🏿‍🫲🏽' => 'поціск рук: цёмны тон скуры сярэдні тон скуры',
    '🫱🏿‍🫲🏾' => 'поціск рук: цёмны тон скуры сярэдняцёмны тон скуры',
    '🚶‍♀‍➡' => 'жанчына ідзе: , накіраваныя ўправа',
    '🚶‍♂‍➡' => 'мужчына ідзе: , накіраваныя ўправа',
    '🧎‍♀‍➡' => 'жанчына стаіць на каленях: , накіраваныя ўправа',
    '🧎‍♂‍➡' => 'мужчына стаіць на каленях: , накіраваныя ўправа',
    '🧑‍🦯‍➡' => 'чалавек з палкай: , накіраваныя ўправа',
    '👨‍🦯‍➡' => 'мужчына з палкай: , накіраваныя ўправа',
    '👩‍🦯‍➡' => 'жанчына з палкай: , накіраваныя ўправа',
    '🧑‍🦼‍➡' => 'чалавек у інваліднай калясцы з маторам: , накіраваныя ўправа',
    '👨‍🦼‍➡' => 'мужчына ў інваліднай калясцы з маторам: , накіраваныя ўправа',
    '👩‍🦼‍➡' => 'жанчына ў інваліднай калясцы з маторам: , накіраваныя ўправа',
    '🧑‍🦽‍➡' => 'чалавек у калясцы з ручным прывадам: , накіраваныя ўправа',
    '👨‍🦽‍➡' => 'мужчына ў калясцы з ручным прывадам: , накіраваныя ўправа',
    '👩‍🦽‍➡' => 'жанчына ў калясцы з ручным прывадам: , накіраваныя ўправа',
    '🏃‍♀‍➡' => 'жанчына бяжыць: , накіраваныя ўправа',
    '🏃‍♂‍➡' => 'мужчына бяжыць: , накіраваныя ўправа',
    '👩‍❤‍👨' => 'закаханая пара: жанчына мужчына',
    '👨‍❤‍👨' => 'закаханая пара: мужчына мужчына',
    '👩‍❤‍👩' => 'закаханая пара: жанчына жанчына',
    '👨‍👩‍👦' => 'сям’я: мужчына жанчына хлопчык',
    '👨‍👩‍👧' => 'сям’я: мужчына жанчына дзяўчынка',
    '👨‍👨‍👦' => 'сям’я: мужчына мужчына хлопчык',
    '👨‍👨‍👧' => 'сям’я: мужчына мужчына дзяўчынка',
    '👩‍👩‍👦' => 'сям’я: жанчына жанчына хлопчык',
    '👩‍👩‍👧' => 'сям’я: жанчына жанчына дзяўчынка',
    '👨‍👦‍👦' => 'сям’я: мужчына хлопчык хлопчык',
    '👨‍👧‍👦' => 'сям’я: мужчына дзяўчынка хлопчык',
    '👨‍👧‍👧' => 'сям’я: мужчына дзяўчынка дзяўчынка',
    '👩‍👦‍👦' => 'сям’я: жанчына хлопчык хлопчык',
    '👩‍👧‍👦' => 'сям’я: жанчына дзяўчынка хлопчык',
    '👩‍👧‍👧' => 'сям’я: жанчына дзяўчынка дзяўчынка',
    '🧑‍🤝‍🧑' => 'людзі трымаюцца за рукі',
    '🧑‍🧑‍🧒' => 'сям’я: двое дарослых і дзіця',
    '🧑‍🧒‍🧒' => 'сям’я: дарослы і двое дзяцей',
    '🧑🏻‍🦰' => 'дарослы: светлы тон скуры рыжыя валасы',
    '🧑🏼‍🦰' => 'дарослы: сярэднясветлы тон скуры рыжыя валасы',
    '🧑🏽‍🦰' => 'дарослы: сярэдні тон скуры рыжыя валасы',
    '🧑🏾‍🦰' => 'дарослы: сярэдняцёмны тон скуры рыжыя валасы',
    '🧑🏿‍🦰' => 'дарослы: цёмны тон скуры рыжыя валасы',
    '🧑🏻‍🦱' => 'дарослы: светлы тон скуры курчавыя валасы',
    '🧑🏼‍🦱' => 'дарослы: сярэднясветлы тон скуры курчавыя валасы',
    '🧑🏽‍🦱' => 'дарослы: сярэдні тон скуры курчавыя валасы',
    '🧑🏾‍🦱' => 'дарослы: сярэдняцёмны тон скуры курчавыя валасы',
    '🧑🏿‍🦱' => 'дарослы: цёмны тон скуры курчавыя валасы',
    '🧑🏻‍🦳' => 'дарослы: светлы тон скуры сівыя валасы',
    '🧑🏼‍🦳' => 'дарослы: сярэднясветлы тон скуры сівыя валасы',
    '🧑🏽‍🦳' => 'дарослы: сярэдні тон скуры сівыя валасы',
    '🧑🏾‍🦳' => 'дарослы: сярэдняцёмны тон скуры сівыя валасы',
    '🧑🏿‍🦳' => 'дарослы: цёмны тон скуры сівыя валасы',
    '🧑🏻‍🦲' => 'дарослы: светлы тон скуры лысы',
    '🧑🏼‍🦲' => 'дарослы: сярэднясветлы тон скуры лысы',
    '🧑🏽‍🦲' => 'дарослы: сярэдні тон скуры лысы',
    '🧑🏾‍🦲' => 'дарослы: сярэдняцёмны тон скуры лысы',
    '🧑🏿‍🦲' => 'дарослы: цёмны тон скуры лысы',
    '🧑🏻‍🩰' => 'балерына: светлы тон скуры',
    '🧑🏼‍🩰' => 'балерына: сярэднясветлы тон скуры',
    '🧑🏽‍🩰' => 'балерына: сярэдні тон скуры',
    '🧑🏾‍🩰' => 'балерына: сярэдняцёмны тон скуры',
    '🧑🏿‍🩰' => 'балерына: цёмны тон скуры',
    '🧔🏻‍♂' => 'мужчына: светлы тон скуры барада',
    '🧔🏼‍♂' => 'мужчына: сярэднясветлы тон скуры барада',
    '🧔🏽‍♂' => 'мужчына: сярэдні тон скуры барада',
    '🧔🏾‍♂' => 'мужчына: сярэдняцёмны тон скуры барада',
    '🧔🏿‍♂' => 'мужчына: цёмны тон скуры барада',
    '👱🏻‍♂' => 'бялявы мужчына: светлы тон скуры',
    '👱🏼‍♂' => 'бялявы мужчына: сярэднясветлы тон скуры',
    '👱🏽‍♂' => 'бялявы мужчына: сярэдні тон скуры',
    '👱🏾‍♂' => 'бялявы мужчына: сярэдняцёмны тон скуры',
    '👱🏿‍♂' => 'бялявы мужчына: цёмны тон скуры',
    '👨🏻‍🦰' => 'мужчына: светлы тон скуры рыжыя валасы',
    '👨🏼‍🦰' => 'мужчына: сярэднясветлы тон скуры рыжыя валасы',
    '👨🏽‍🦰' => 'мужчына: сярэдні тон скуры рыжыя валасы',
    '👨🏾‍🦰' => 'мужчына: сярэдняцёмны тон скуры рыжыя валасы',
    '👨🏿‍🦰' => 'мужчына: цёмны тон скуры рыжыя валасы',
    '👨🏻‍🦱' => 'мужчына: светлы тон скуры курчавыя валасы',
    '👨🏼‍🦱' => 'мужчына: сярэднясветлы тон скуры курчавыя валасы',
    '👨🏽‍🦱' => 'мужчына: сярэдні тон скуры курчавыя валасы',
    '👨🏾‍🦱' => 'мужчына: сярэдняцёмны тон скуры курчавыя валасы',
    '👨🏿‍🦱' => 'мужчына: цёмны тон скуры курчавыя валасы',
    '👨🏻‍🦳' => 'мужчына: светлы тон скуры сівыя валасы',
    '👨🏼‍🦳' => 'мужчына: сярэднясветлы тон скуры сівыя валасы',
    '👨🏽‍🦳' => 'мужчына: сярэдні тон скуры сівыя валасы',
    '👨🏾‍🦳' => 'мужчына: сярэдняцёмны тон скуры сівыя валасы',
    '👨🏿‍🦳' => 'мужчына: цёмны тон скуры сівыя валасы',
    '👨🏻‍🦲' => 'мужчына: светлы тон скуры лысы',
    '👨🏼‍🦲' => 'мужчына: сярэднясветлы тон скуры лысы',
    '👨🏽‍🦲' => 'мужчына: сярэдні тон скуры лысы',
    '👨🏾‍🦲' => 'мужчына: сярэдняцёмны тон скуры лысы',
    '👨🏿‍🦲' => 'мужчына: цёмны тон скуры лысы',
    '🧔🏻‍♀' => 'жанчына: светлы тон скуры барада',
    '🧔🏼‍♀' => 'жанчына: сярэднясветлы тон скуры барада',
    '🧔🏽‍♀' => 'жанчына: сярэдні тон скуры барада',
    '🧔🏾‍♀' => 'жанчына: сярэдняцёмны тон скуры барада',
    '🧔🏿‍♀' => 'жанчына: цёмны тон скуры барада',
    '👱🏻‍♀' => 'бялявая жанчына: светлы тон скуры',
    '👱🏼‍♀' => 'бялявая жанчына: сярэднясветлы тон скуры',
    '👱🏽‍♀' => 'бялявая жанчына: сярэдні тон скуры',
    '👱🏾‍♀' => 'бялявая жанчына: сярэдняцёмны тон скуры',
    '👱🏿‍♀' => 'бялявая жанчына: цёмны тон скуры',
    '👩🏻‍🦰' => 'жанчына: светлы тон скуры рыжыя валасы',
    '👩🏼‍🦰' => 'жанчына: сярэднясветлы тон скуры рыжыя валасы',
    '👩🏽‍🦰' => 'жанчына: сярэдні тон скуры рыжыя валасы',
    '👩🏾‍🦰' => 'жанчына: сярэдняцёмны тон скуры рыжыя валасы',
    '👩🏿‍🦰' => 'жанчына: цёмны тон скуры рыжыя валасы',
    '👩🏻‍🦱' => 'жанчына: светлы тон скуры курчавыя валасы',
    '👩🏼‍🦱' => 'жанчына: сярэднясветлы тон скуры курчавыя валасы',
    '👩🏽‍🦱' => 'жанчына: сярэдні тон скуры курчавыя валасы',
    '👩🏾‍🦱' => 'жанчына: сярэдняцёмны тон скуры курчавыя валасы',
    '👩🏿‍🦱' => 'жанчына: цёмны тон скуры курчавыя валасы',
    '👩🏻‍🦳' => 'жанчына: светлы тон скуры сівыя валасы',
    '👩🏼‍🦳' => 'жанчына: сярэднясветлы тон скуры сівыя валасы',
    '👩🏽‍🦳' => 'жанчына: сярэдні тон скуры сівыя валасы',
    '👩🏾‍🦳' => 'жанчына: сярэдняцёмны тон скуры сівыя валасы',
    '👩🏿‍🦳' => 'жанчына: цёмны тон скуры сівыя валасы',
    '👩🏻‍🦲' => 'жанчына: светлы тон скуры лысы',
    '👩🏼‍🦲' => 'жанчына: сярэднясветлы тон скуры лысы',
    '👩🏽‍🦲' => 'жанчына: сярэдні тон скуры лысы',
    '👩🏾‍🦲' => 'жанчына: сярэдняцёмны тон скуры лысы',
    '👩🏿‍🦲' => 'жанчына: цёмны тон скуры лысы',
    '🙍🏻‍♂' => 'засмучаны мужчына: светлы тон скуры',
    '🙍🏼‍♂' => 'засмучаны мужчына: сярэднясветлы тон скуры',
    '🙍🏽‍♂' => 'засмучаны мужчына: сярэдні тон скуры',
    '🙍🏾‍♂' => 'засмучаны мужчына: сярэдняцёмны тон скуры',
    '🙍🏿‍♂' => 'засмучаны мужчына: цёмны тон скуры',
    '🙍🏻‍♀' => 'засмучаная жанчына: светлы тон скуры',
    '🙍🏼‍♀' => 'засмучаная жанчына: сярэднясветлы тон скуры',
    '🙍🏽‍♀' => 'засмучаная жанчына: сярэдні тон скуры',
    '🙍🏾‍♀' => 'засмучаная жанчына: сярэдняцёмны тон скуры',
    '🙍🏿‍♀' => 'засмучаная жанчына: цёмны тон скуры',
    '🙎🏻‍♂' => 'надзьмуты мужчына: светлы тон скуры',
    '🙎🏼‍♂' => 'надзьмуты мужчына: сярэднясветлы тон скуры',
    '🙎🏽‍♂' => 'надзьмуты мужчына: сярэдні тон скуры',
    '🙎🏾‍♂' => 'надзьмуты мужчына: сярэдняцёмны тон скуры',
    '🙎🏿‍♂' => 'надзьмуты мужчына: цёмны тон скуры',
    '🙎🏻‍♀' => 'надзьмутая жанчына: светлы тон скуры',
    '🙎🏼‍♀' => 'надзьмутая жанчына: сярэднясветлы тон скуры',
    '🙎🏽‍♀' => 'надзьмутая жанчына: сярэдні тон скуры',
    '🙎🏾‍♀' => 'надзьмутая жанчына: сярэдняцёмны тон скуры',
    '🙎🏿‍♀' => 'надзьмутая жанчына: цёмны тон скуры',
    '🙅🏻‍♂' => 'мужчына супраць: светлы тон скуры',
    '🙅🏼‍♂' => 'мужчына супраць: сярэднясветлы тон скуры',
    '🙅🏽‍♂' => 'мужчына супраць: сярэдні тон скуры',
    '🙅🏾‍♂' => 'мужчына супраць: сярэдняцёмны тон скуры',
    '🙅🏿‍♂' => 'мужчына супраць: цёмны тон скуры',
    '🙅🏻‍♀' => 'жанчына супраць: светлы тон скуры',
    '🙅🏼‍♀' => 'жанчына супраць: сярэднясветлы тон скуры',
    '🙅🏽‍♀' => 'жанчына супраць: сярэдні тон скуры',
    '🙅🏾‍♀' => 'жанчына супраць: сярэдняцёмны тон скуры',
    '🙅🏿‍♀' => 'жанчына супраць: цёмны тон скуры',
    '🙆🏻‍♂' => 'мужчына паказвае згоду: светлы тон скуры',
    '🙆🏼‍♂' => 'мужчына паказвае згоду: сярэднясветлы тон скуры',
    '🙆🏽‍♂' => 'мужчына паказвае згоду: сярэдні тон скуры',
    '🙆🏾‍♂' => 'мужчына паказвае згоду: сярэдняцёмны тон скуры',
    '🙆🏿‍♂' => 'мужчына паказвае згоду: цёмны тон скуры',
    '🙆🏻‍♀' => 'жанчына паказвае згоду: светлы тон скуры',
    '🙆🏼‍♀' => 'жанчына паказвае згоду: сярэднясветлы тон скуры',
    '🙆🏽‍♀' => 'жанчына паказвае згоду: сярэдні тон скуры',
    '🙆🏾‍♀' => 'жанчына паказвае згоду: сярэдняцёмны тон скуры',
    '🙆🏿‍♀' => 'жанчына паказвае згоду: цёмны тон скуры',
    '💁🏻‍♂' => 'мужчына трасе рукой: светлы тон скуры',
    '💁🏼‍♂' => 'мужчына трасе рукой: сярэднясветлы тон скуры',
    '💁🏽‍♂' => 'мужчына трасе рукой: сярэдні тон скуры',
    '💁🏾‍♂' => 'мужчына трасе рукой: сярэдняцёмны тон скуры',
    '💁🏿‍♂' => 'мужчына трасе рукой: цёмны тон скуры',
    '💁🏻‍♀' => 'жанчына трасе рукой: светлы тон скуры',
    '💁🏼‍♀' => 'жанчына трасе рукой: сярэднясветлы тон скуры',
    '💁🏽‍♀' => 'жанчына трасе рукой: сярэдні тон скуры',
    '💁🏾‍♀' => 'жанчына трасе рукой: сярэдняцёмны тон скуры',
    '💁🏿‍♀' => 'жанчына трасе рукой: цёмны тон скуры',
    '🙋🏻‍♂' => 'мужчына цягне руку: светлы тон скуры',
    '🙋🏼‍♂' => 'мужчына цягне руку: сярэднясветлы тон скуры',
    '🙋🏽‍♂' => 'мужчына цягне руку: сярэдні тон скуры',
    '🙋🏾‍♂' => 'мужчына цягне руку: сярэдняцёмны тон скуры',
    '🙋🏿‍♂' => 'мужчына цягне руку: цёмны тон скуры',
    '🙋🏻‍♀' => 'жанчына цягне руку: светлы тон скуры',
    '🙋🏼‍♀' => 'жанчына цягне руку: сярэднясветлы тон скуры',
    '🙋🏽‍♀' => 'жанчына цягне руку: сярэдні тон скуры',
    '🙋🏾‍♀' => 'жанчына цягне руку: сярэдняцёмны тон скуры',
    '🙋🏿‍♀' => 'жанчына цягне руку: цёмны тон скуры',
    '🧏🏻‍♂' => 'глухі мужчына: светлы тон скуры',
    '🧏🏼‍♂' => 'глухі мужчына: сярэднясветлы тон скуры',
    '🧏🏽‍♂' => 'глухі мужчына: сярэдні тон скуры',
    '🧏🏾‍♂' => 'глухі мужчына: сярэдняцёмны тон скуры',
    '🧏🏿‍♂' => 'глухі мужчына: цёмны тон скуры',
    '🧏🏻‍♀' => 'глухая жанчына: светлы тон скуры',
    '🧏🏼‍♀' => 'глухая жанчына: сярэднясветлы тон скуры',
    '🧏🏽‍♀' => 'глухая жанчына: сярэдні тон скуры',
    '🧏🏾‍♀' => 'глухая жанчына: сярэдняцёмны тон скуры',
    '🧏🏿‍♀' => 'глухая жанчына: цёмны тон скуры',
    '🙇🏻‍♂' => 'мужчына нізка кланяецца: светлы тон скуры',
    '🙇🏼‍♂' => 'мужчына нізка кланяецца: сярэднясветлы тон скуры',
    '🙇🏽‍♂' => 'мужчына нізка кланяецца: сярэдні тон скуры',
    '🙇🏾‍♂' => 'мужчына нізка кланяецца: сярэдняцёмны тон скуры',
    '🙇🏿‍♂' => 'мужчына нізка кланяецца: цёмны тон скуры',
    '🙇🏻‍♀' => 'жанчына нізка кланяецца: светлы тон скуры',
    '🙇🏼‍♀' => 'жанчына нізка кланяецца: сярэднясветлы тон скуры',
    '🙇🏽‍♀' => 'жанчына нізка кланяецца: сярэдні тон скуры',
    '🙇🏾‍♀' => 'жанчына нізка кланяецца: сярэдняцёмны тон скуры',
    '🙇🏿‍♀' => 'жанчына нізка кланяецца: цёмны тон скуры',
    '🤦🏻‍♂' => 'мужчына з далонню на твары: светлы тон скуры',
    '🤦🏼‍♂' => 'мужчына з далонню на твары: сярэднясветлы тон скуры',
    '🤦🏽‍♂' => 'мужчына з далонню на твары: сярэдні тон скуры',
    '🤦🏾‍♂' => 'мужчына з далонню на твары: сярэдняцёмны тон скуры',
    '🤦🏿‍♂' => 'мужчына з далонню на твары: цёмны тон скуры',
    '🤦🏻‍♀' => 'жанчына з далонню на твары: светлы тон скуры',
    '🤦🏼‍♀' => 'жанчына з далонню на твары: сярэднясветлы тон скуры',
    '🤦🏽‍♀' => 'жанчына з далонню на твары: сярэдні тон скуры',
    '🤦🏾‍♀' => 'жанчына з далонню на твары: сярэдняцёмны тон скуры',
    '🤦🏿‍♀' => 'жанчына з далонню на твары: цёмны тон скуры',
    '🤷🏻‍♂' => 'мужчына паціскае плячыма: светлы тон скуры',
    '🤷🏼‍♂' => 'мужчына паціскае плячыма: сярэднясветлы тон скуры',
    '🤷🏽‍♂' => 'мужчына паціскае плячыма: сярэдні тон скуры',
    '🤷🏾‍♂' => 'мужчына паціскае плячыма: сярэдняцёмны тон скуры',
    '🤷🏿‍♂' => 'мужчына паціскае плячыма: цёмны тон скуры',
    '🤷🏻‍♀' => 'жанчына паціскае плячыма: светлы тон скуры',
    '🤷🏼‍♀' => 'жанчына паціскае плячыма: сярэднясветлы тон скуры',
    '🤷🏽‍♀' => 'жанчына паціскае плячыма: сярэдні тон скуры',
    '🤷🏾‍♀' => 'жанчына паціскае плячыма: сярэдняцёмны тон скуры',
    '🤷🏿‍♀' => 'жанчына паціскае плячыма: цёмны тон скуры',
    '🧑🏻‍⚕' => 'медыцынскі работнік: светлы тон скуры',
    '🧑🏼‍⚕' => 'медыцынскі работнік: сярэднясветлы тон скуры',
    '🧑🏽‍⚕' => 'медыцынскі работнік: сярэдні тон скуры',
    '🧑🏾‍⚕' => 'медыцынскі работнік: сярэдняцёмны тон скуры',
    '🧑🏿‍⚕' => 'медыцынскі работнік: цёмны тон скуры',
    '👨🏻‍⚕' => 'доктар: светлы тон скуры',
    '👨🏼‍⚕' => 'доктар: сярэднясветлы тон скуры',
    '👨🏽‍⚕' => 'доктар: сярэдні тон скуры',
    '👨🏾‍⚕' => 'доктар: сярэдняцёмны тон скуры',
    '👨🏿‍⚕' => 'доктар: цёмны тон скуры',
    '👩🏻‍⚕' => 'доктарка: светлы тон скуры',
    '👩🏼‍⚕' => 'доктарка: сярэднясветлы тон скуры',
    '👩🏽‍⚕' => 'доктарка: сярэдні тон скуры',
    '👩🏾‍⚕' => 'доктарка: сярэдняцёмны тон скуры',
    '👩🏿‍⚕' => 'доктарка: цёмны тон скуры',
    '🧑🏻‍🎓' => 'навучэнец: светлы тон скуры',
    '🧑🏼‍🎓' => 'навучэнец: сярэднясветлы тон скуры',
    '🧑🏽‍🎓' => 'навучэнец: сярэдні тон скуры',
    '🧑🏾‍🎓' => 'навучэнец: сярэдняцёмны тон скуры',
    '🧑🏿‍🎓' => 'навучэнец: цёмны тон скуры',
    '👨🏻‍🎓' => 'студэнт: светлы тон скуры',
    '👨🏼‍🎓' => 'студэнт: сярэднясветлы тон скуры',
    '👨🏽‍🎓' => 'студэнт: сярэдні тон скуры',
    '👨🏾‍🎓' => 'студэнт: сярэдняцёмны тон скуры',
    '👨🏿‍🎓' => 'студэнт: цёмны тон скуры',
    '👩🏻‍🎓' => 'студэнтка: светлы тон скуры',
    '👩🏼‍🎓' => 'студэнтка: сярэднясветлы тон скуры',
    '👩🏽‍🎓' => 'студэнтка: сярэдні тон скуры',
    '👩🏾‍🎓' => 'студэнтка: сярэдняцёмны тон скуры',
    '👩🏿‍🎓' => 'студэнтка: цёмны тон скуры',
    '🧑🏻‍🏫' => 'выкладчык: светлы тон скуры',
    '🧑🏼‍🏫' => 'выкладчык: сярэднясветлы тон скуры',
    '🧑🏽‍🏫' => 'выкладчык: сярэдні тон скуры',
    '🧑🏾‍🏫' => 'выкладчык: сярэдняцёмны тон скуры',
    '🧑🏿‍🏫' => 'выкладчык: цёмны тон скуры',
    '👨🏻‍🏫' => 'настаўнік: светлы тон скуры',
    '👨🏼‍🏫' => 'настаўнік: сярэднясветлы тон скуры',
    '👨🏽‍🏫' => 'настаўнік: сярэдні тон скуры',
    '👨🏾‍🏫' => 'настаўнік: сярэдняцёмны тон скуры',
    '👨🏿‍🏫' => 'настаўнік: цёмны тон скуры',
    '👩🏻‍🏫' => 'настаўніца: светлы тон скуры',
    '👩🏼‍🏫' => 'настаўніца: сярэднясветлы тон скуры',
    '👩🏽‍🏫' => 'настаўніца: сярэдні тон скуры',
    '👩🏾‍🏫' => 'настаўніца: сярэдняцёмны тон скуры',
    '👩🏿‍🏫' => 'настаўніца: цёмны тон скуры',
    '🧑🏻‍⚖' => 'суддзя: светлы тон скуры',
    '🧑🏼‍⚖' => 'суддзя: сярэднясветлы тон скуры',
    '🧑🏽‍⚖' => 'суддзя: сярэдні тон скуры',
    '🧑🏾‍⚖' => 'суддзя: сярэдняцёмны тон скуры',
    '🧑🏿‍⚖' => 'суддзя: цёмны тон скуры',
    '👨🏻‍⚖' => 'суддзя-мужчына: светлы тон скуры',
    '👨🏼‍⚖' => 'суддзя-мужчына: сярэднясветлы тон скуры',
    '👨🏽‍⚖' => 'суддзя-мужчына: сярэдні тон скуры',
    '👨🏾‍⚖' => 'суддзя-мужчына: сярэдняцёмны тон скуры',
    '👨🏿‍⚖' => 'суддзя-мужчына: цёмны тон скуры',
    '👩🏻‍⚖' => 'суддзя-жанчына: светлы тон скуры',
    '👩🏼‍⚖' => 'суддзя-жанчына: сярэднясветлы тон скуры',
    '👩🏽‍⚖' => 'суддзя-жанчына: сярэдні тон скуры',
    '👩🏾‍⚖' => 'суддзя-жанчына: сярэдняцёмны тон скуры',
    '👩🏿‍⚖' => 'суддзя-жанчына: цёмны тон скуры',
    '🧑🏻‍🌾' => 'аграрый: светлы тон скуры',
    '🧑🏼‍🌾' => 'аграрый: сярэднясветлы тон скуры',
    '🧑🏽‍🌾' => 'аграрый: сярэдні тон скуры',
    '🧑🏾‍🌾' => 'аграрый: сярэдняцёмны тон скуры',
    '🧑🏿‍🌾' => 'аграрый: цёмны тон скуры',
    '👨🏻‍🌾' => 'фермер: светлы тон скуры',
    '👨🏼‍🌾' => 'фермер: сярэднясветлы тон скуры',
    '👨🏽‍🌾' => 'фермер: сярэдні тон скуры',
    '👨🏾‍🌾' => 'фермер: сярэдняцёмны тон скуры',
    '👨🏿‍🌾' => 'фермер: цёмны тон скуры',
    '👩🏻‍🌾' => 'фермерка: светлы тон скуры',
    '👩🏼‍🌾' => 'фермерка: сярэднясветлы тон скуры',
    '👩🏽‍🌾' => 'фермерка: сярэдні тон скуры',
    '👩🏾‍🌾' => 'фермерка: сярэдняцёмны тон скуры',
    '👩🏿‍🌾' => 'фермерка: цёмны тон скуры',
    '🧑🏻‍🍳' => 'повар: светлы тон скуры',
    '🧑🏼‍🍳' => 'повар: сярэднясветлы тон скуры',
    '🧑🏽‍🍳' => 'повар: сярэдні тон скуры',
    '🧑🏾‍🍳' => 'повар: сярэдняцёмны тон скуры',
    '🧑🏿‍🍳' => 'повар: цёмны тон скуры',
    '👨🏻‍🍳' => 'кухар: светлы тон скуры',
    '👨🏼‍🍳' => 'кухар: сярэднясветлы тон скуры',
    '👨🏽‍🍳' => 'кухар: сярэдні тон скуры',
    '👨🏾‍🍳' => 'кухар: сярэдняцёмны тон скуры',
    '👨🏿‍🍳' => 'кухар: цёмны тон скуры',
    '👩🏻‍🍳' => 'кухарка: светлы тон скуры',
    '👩🏼‍🍳' => 'кухарка: сярэднясветлы тон скуры',
    '👩🏽‍🍳' => 'кухарка: сярэдні тон скуры',
    '👩🏾‍🍳' => 'кухарка: сярэдняцёмны тон скуры',
    '👩🏿‍🍳' => 'кухарка: цёмны тон скуры',
    '🧑🏻‍🔧' => 'механік: светлы тон скуры',
    '🧑🏼‍🔧' => 'механік: сярэднясветлы тон скуры',
    '🧑🏽‍🔧' => 'механік: сярэдні тон скуры',
    '🧑🏾‍🔧' => 'механік: сярэдняцёмны тон скуры',
    '🧑🏿‍🔧' => 'механік: цёмны тон скуры',
    '👨🏻‍🔧' => 'мужчына-механік: светлы тон скуры',
    '👨🏼‍🔧' => 'мужчына-механік: сярэднясветлы тон скуры',
    '👨🏽‍🔧' => 'мужчына-механік: сярэдні тон скуры',
    '👨🏾‍🔧' => 'мужчына-механік: сярэдняцёмны тон скуры',
    '👨🏿‍🔧' => 'мужчына-механік: цёмны тон скуры',
    '👩🏻‍🔧' => 'жанчына-механік: светлы тон скуры',
    '👩🏼‍🔧' => 'жанчына-механік: сярэднясветлы тон скуры',
    '👩🏽‍🔧' => 'жанчына-механік: сярэдні тон скуры',
    '👩🏾‍🔧' => 'жанчына-механік: сярэдняцёмны тон скуры',
    '👩🏿‍🔧' => 'жанчына-механік: цёмны тон скуры',
    '🧑🏻‍🏭' => 'завадчанін: светлы тон скуры',
    '🧑🏼‍🏭' => 'завадчанін: сярэднясветлы тон скуры',
    '🧑🏽‍🏭' => 'завадчанін: сярэдні тон скуры',
    '🧑🏾‍🏭' => 'завадчанін: сярэдняцёмны тон скуры',
    '🧑🏿‍🏭' => 'завадчанін: цёмны тон скуры',
    '👨🏻‍🏭' => 'працаўнік завода: светлы тон скуры',
    '👨🏼‍🏭' => 'працаўнік завода: сярэднясветлы тон скуры',
    '👨🏽‍🏭' => 'працаўнік завода: сярэдні тон скуры',
    '👨🏾‍🏭' => 'працаўнік завода: сярэдняцёмны тон скуры',
    '👨🏿‍🏭' => 'працаўнік завода: цёмны тон скуры',
    '👩🏻‍🏭' => 'працаўніца завода: светлы тон скуры',
    '👩🏼‍🏭' => 'працаўніца завода: сярэднясветлы тон скуры',
    '👩🏽‍🏭' => 'працаўніца завода: сярэдні тон скуры',
    '👩🏾‍🏭' => 'працаўніца завода: сярэдняцёмны тон скуры',
    '👩🏿‍🏭' => 'працаўніца завода: цёмны тон скуры',
    '🧑🏻‍💼' => 'службовец: светлы тон скуры',
    '🧑🏼‍💼' => 'службовец: сярэднясветлы тон скуры',
    '🧑🏽‍💼' => 'службовец: сярэдні тон скуры',
    '🧑🏾‍💼' => 'службовец: сярэдняцёмны тон скуры',
    '🧑🏿‍💼' => 'службовец: цёмны тон скуры',
    '👨🏻‍💼' => 'служачы: светлы тон скуры',
    '👨🏼‍💼' => 'служачы: сярэднясветлы тон скуры',
    '👨🏽‍💼' => 'служачы: сярэдні тон скуры',
    '👨🏾‍💼' => 'служачы: сярэдняцёмны тон скуры',
    '👨🏿‍💼' => 'служачы: цёмны тон скуры',
    '👩🏻‍💼' => 'служачая: светлы тон скуры',
    '👩🏼‍💼' => 'служачая: сярэднясветлы тон скуры',
    '👩🏽‍💼' => 'служачая: сярэдні тон скуры',
    '👩🏾‍💼' => 'служачая: сярэдняцёмны тон скуры',
    '👩🏿‍💼' => 'служачая: цёмны тон скуры',
    '🧑🏻‍🔬' => 'навуковец: светлы тон скуры',
    '🧑🏼‍🔬' => 'навуковец: сярэднясветлы тон скуры',
    '🧑🏽‍🔬' => 'навуковец: сярэдні тон скуры',
    '🧑🏾‍🔬' => 'навуковец: сярэдняцёмны тон скуры',
    '🧑🏿‍🔬' => 'навуковец: цёмны тон скуры',
    '👨🏻‍🔬' => 'вучоны: светлы тон скуры',
    '👨🏼‍🔬' => 'вучоны: сярэднясветлы тон скуры',
    '👨🏽‍🔬' => 'вучоны: сярэдні тон скуры',
    '👨🏾‍🔬' => 'вучоны: сярэдняцёмны тон скуры',
    '👨🏿‍🔬' => 'вучоны: цёмны тон скуры',
    '👩🏻‍🔬' => 'вучоная: светлы тон скуры',
    '👩🏼‍🔬' => 'вучоная: сярэднясветлы тон скуры',
    '👩🏽‍🔬' => 'вучоная: сярэдні тон скуры',
    '👩🏾‍🔬' => 'вучоная: сярэдняцёмны тон скуры',
    '👩🏿‍🔬' => 'вучоная: цёмны тон скуры',
    '🧑🏻‍💻' => 'тэхнік: светлы тон скуры',
    '🧑🏼‍💻' => 'тэхнік: сярэднясветлы тон скуры',
    '🧑🏽‍💻' => 'тэхнік: сярэдні тон скуры',
    '🧑🏾‍💻' => 'тэхнік: сярэдняцёмны тон скуры',
    '🧑🏿‍💻' => 'тэхнік: цёмны тон скуры',
    '👨🏻‍💻' => 'камп’ютаршчык: светлы тон скуры',
    '👨🏼‍💻' => 'камп’ютаршчык: сярэднясветлы тон скуры',
    '👨🏽‍💻' => 'камп’ютаршчык: сярэдні тон скуры',
    '👨🏾‍💻' => 'камп’ютаршчык: сярэдняцёмны тон скуры',
    '👨🏿‍💻' => 'камп’ютаршчык: цёмны тон скуры',
    '👩🏻‍💻' => 'камп’ютаршчыца: светлы тон скуры',
    '👩🏼‍💻' => 'камп’ютаршчыца: сярэднясветлы тон скуры',
    '👩🏽‍💻' => 'камп’ютаршчыца: сярэдні тон скуры',
    '👩🏾‍💻' => 'камп’ютаршчыца: сярэдняцёмны тон скуры',
    '👩🏿‍💻' => 'камп’ютаршчыца: цёмны тон скуры',
    '🧑🏻‍🎤' => 'пяюн: светлы тон скуры',
    '🧑🏼‍🎤' => 'пяюн: сярэднясветлы тон скуры',
    '🧑🏽‍🎤' => 'пяюн: сярэдні тон скуры',
    '🧑🏾‍🎤' => 'пяюн: сярэдняцёмны тон скуры',
    '🧑🏿‍🎤' => 'пяюн: цёмны тон скуры',
    '👨🏻‍🎤' => 'спявак: светлы тон скуры',
    '👨🏼‍🎤' => 'спявак: сярэднясветлы тон скуры',
    '👨🏽‍🎤' => 'спявак: сярэдні тон скуры',
    '👨🏾‍🎤' => 'спявак: сярэдняцёмны тон скуры',
    '👨🏿‍🎤' => 'спявак: цёмны тон скуры',
    '👩🏻‍🎤' => 'спявачка: светлы тон скуры',
    '👩🏼‍🎤' => 'спявачка: сярэднясветлы тон скуры',
    '👩🏽‍🎤' => 'спявачка: сярэдні тон скуры',
    '👩🏾‍🎤' => 'спявачка: сярэдняцёмны тон скуры',
    '👩🏿‍🎤' => 'спявачка: цёмны тон скуры',
    '🧑🏻‍🎨' => 'жывапісец: светлы тон скуры',
    '🧑🏼‍🎨' => 'жывапісец: сярэднясветлы тон скуры',
    '🧑🏽‍🎨' => 'жывапісец: сярэдні тон скуры',
    '🧑🏾‍🎨' => 'жывапісец: сярэдняцёмны тон скуры',
    '🧑🏿‍🎨' => 'жывапісец: цёмны тон скуры',
    '👨🏻‍🎨' => 'мастак: светлы тон скуры',
    '👨🏼‍🎨' => 'мастак: сярэднясветлы тон скуры',
    '👨🏽‍🎨' => 'мастак: сярэдні тон скуры',
    '👨🏾‍🎨' => 'мастак: сярэдняцёмны тон скуры',
    '👨🏿‍🎨' => 'мастак: цёмны тон скуры',
    '👩🏻‍🎨' => 'мастачка: светлы тон скуры',
    '👩🏼‍🎨' => 'мастачка: сярэднясветлы тон скуры',
    '👩🏽‍🎨' => 'мастачка: сярэдні тон скуры',
    '👩🏾‍🎨' => 'мастачка: сярэдняцёмны тон скуры',
    '👩🏿‍🎨' => 'мастачка: цёмны тон скуры',
    '🧑🏻‍✈' => 'пілот: светлы тон скуры',
    '🧑🏼‍✈' => 'пілот: сярэднясветлы тон скуры',
    '🧑🏽‍✈' => 'пілот: сярэдні тон скуры',
    '🧑🏾‍✈' => 'пілот: сярэдняцёмны тон скуры',
    '🧑🏿‍✈' => 'пілот: цёмны тон скуры',
    '👨🏻‍✈' => 'мужчына-пілот: светлы тон скуры',
    '👨🏼‍✈' => 'мужчына-пілот: сярэднясветлы тон скуры',
    '👨🏽‍✈' => 'мужчына-пілот: сярэдні тон скуры',
    '👨🏾‍✈' => 'мужчына-пілот: сярэдняцёмны тон скуры',
    '👨🏿‍✈' => 'мужчына-пілот: цёмны тон скуры',
    '👩🏻‍✈' => 'жанчына-пілот: светлы тон скуры',
    '👩🏼‍✈' => 'жанчына-пілот: сярэднясветлы тон скуры',
    '👩🏽‍✈' => 'жанчына-пілот: сярэдні тон скуры',
    '👩🏾‍✈' => 'жанчына-пілот: сярэдняцёмны тон скуры',
    '👩🏿‍✈' => 'жанчына-пілот: цёмны тон скуры',
    '🧑🏻‍🚀' => 'астранаўт: светлы тон скуры',
    '🧑🏼‍🚀' => 'астранаўт: сярэднясветлы тон скуры',
    '🧑🏽‍🚀' => 'астранаўт: сярэдні тон скуры',
    '🧑🏾‍🚀' => 'астранаўт: сярэдняцёмны тон скуры',
    '🧑🏿‍🚀' => 'астранаўт: цёмны тон скуры',
    '👨🏻‍🚀' => 'касманаўт: светлы тон скуры',
    '👨🏼‍🚀' => 'касманаўт: сярэднясветлы тон скуры',
    '👨🏽‍🚀' => 'касманаўт: сярэдні тон скуры',
    '👨🏾‍🚀' => 'касманаўт: сярэдняцёмны тон скуры',
    '👨🏿‍🚀' => 'касманаўт: цёмны тон скуры',
    '👩🏻‍🚀' => 'касманаўтка: светлы тон скуры',
    '👩🏼‍🚀' => 'касманаўтка: сярэднясветлы тон скуры',
    '👩🏽‍🚀' => 'касманаўтка: сярэдні тон скуры',
    '👩🏾‍🚀' => 'касманаўтка: сярэдняцёмны тон скуры',
    '👩🏿‍🚀' => 'касманаўтка: цёмны тон скуры',
    '🧑🏻‍🚒' => 'пажарны: светлы тон скуры',
    '🧑🏼‍🚒' => 'пажарны: сярэднясветлы тон скуры',
    '🧑🏽‍🚒' => 'пажарны: сярэдні тон скуры',
    '🧑🏾‍🚒' => 'пажарны: сярэдняцёмны тон скуры',
    '🧑🏿‍🚒' => 'пажарны: цёмны тон скуры',
    '👨🏻‍🚒' => 'пажарнік: светлы тон скуры',
    '👨🏼‍🚒' => 'пажарнік: сярэднясветлы тон скуры',
    '👨🏽‍🚒' => 'пажарнік: сярэдні тон скуры',
    '👨🏾‍🚒' => 'пажарнік: сярэдняцёмны тон скуры',
    '👨🏿‍🚒' => 'пажарнік: цёмны тон скуры',
    '👩🏻‍🚒' => 'пажарніца: светлы тон скуры',
    '👩🏼‍🚒' => 'пажарніца: сярэднясветлы тон скуры',
    '👩🏽‍🚒' => 'пажарніца: сярэдні тон скуры',
    '👩🏾‍🚒' => 'пажарніца: сярэдняцёмны тон скуры',
    '👩🏿‍🚒' => 'пажарніца: цёмны тон скуры',
    '👮🏻‍♂' => 'паліцэйскі: светлы тон скуры',
    '👮🏼‍♂' => 'паліцэйскі: сярэднясветлы тон скуры',
    '👮🏽‍♂' => 'паліцэйскі: сярэдні тон скуры',
    '👮🏾‍♂' => 'паліцэйскі: сярэдняцёмны тон скуры',
    '👮🏿‍♂' => 'паліцэйскі: цёмны тон скуры',
    '👮🏻‍♀' => 'паліцэйская: светлы тон скуры',
    '👮🏼‍♀' => 'паліцэйская: сярэднясветлы тон скуры',
    '👮🏽‍♀' => 'паліцэйская: сярэдні тон скуры',
    '👮🏾‍♀' => 'паліцэйская: сярэдняцёмны тон скуры',
    '👮🏿‍♀' => 'паліцэйская: цёмны тон скуры',
    '🕵🏻‍♂' => 'сышчык: светлы тон скуры',
    '🕵🏼‍♂' => 'сышчык: сярэднясветлы тон скуры',
    '🕵🏽‍♂' => 'сышчык: сярэдні тон скуры',
    '🕵🏾‍♂' => 'сышчык: сярэдняцёмны тон скуры',
    '🕵🏿‍♂' => 'сышчык: цёмны тон скуры',
    '🕵🏻‍♀' => 'сышчыца: светлы тон скуры',
    '🕵🏼‍♀' => 'сышчыца: сярэднясветлы тон скуры',
    '🕵🏽‍♀' => 'сышчыца: сярэдні тон скуры',
    '🕵🏾‍♀' => 'сышчыца: сярэдняцёмны тон скуры',
    '🕵🏿‍♀' => 'сышчыца: цёмны тон скуры',
    '💂🏻‍♂' => 'каравульны: светлы тон скуры',
    '💂🏼‍♂' => 'каравульны: сярэднясветлы тон скуры',
    '💂🏽‍♂' => 'каравульны: сярэдні тон скуры',
    '💂🏾‍♂' => 'каравульны: сярэдняцёмны тон скуры',
    '💂🏿‍♂' => 'каравульны: цёмны тон скуры',
    '💂🏻‍♀' => 'ахоўніца: светлы тон скуры',
    '💂🏼‍♀' => 'ахоўніца: сярэднясветлы тон скуры',
    '💂🏽‍♀' => 'ахоўніца: сярэдні тон скуры',
    '💂🏾‍♀' => 'ахоўніца: сярэдняцёмны тон скуры',
    '💂🏿‍♀' => 'ахоўніца: цёмны тон скуры',
    '👷🏻‍♂' => 'мужчына-будаўнік: светлы тон скуры',
    '👷🏼‍♂' => 'мужчына-будаўнік: сярэднясветлы тон скуры',
    '👷🏽‍♂' => 'мужчына-будаўнік: сярэдні тон скуры',
    '👷🏾‍♂' => 'мужчына-будаўнік: сярэдняцёмны тон скуры',
    '👷🏿‍♂' => 'мужчына-будаўнік: цёмны тон скуры',
    '👷🏻‍♀' => 'будаўніца: светлы тон скуры',
    '👷🏼‍♀' => 'будаўніца: сярэднясветлы тон скуры',
    '👷🏽‍♀' => 'будаўніца: сярэдні тон скуры',
    '👷🏾‍♀' => 'будаўніца: сярэдняцёмны тон скуры',
    '👷🏿‍♀' => 'будаўніца: цёмны тон скуры',
    '👳🏻‍♂' => 'мужчына ў турбане: светлы тон скуры',
    '👳🏼‍♂' => 'мужчына ў турбане: сярэднясветлы тон скуры',
    '👳🏽‍♂' => 'мужчына ў турбане: сярэдні тон скуры',
    '👳🏾‍♂' => 'мужчына ў турбане: сярэдняцёмны тон скуры',
    '👳🏿‍♂' => 'мужчына ў турбане: цёмны тон скуры',
    '👳🏻‍♀' => 'жанчына ў турбане: светлы тон скуры',
    '👳🏼‍♀' => 'жанчына ў турбане: сярэднясветлы тон скуры',
    '👳🏽‍♀' => 'жанчына ў турбане: сярэдні тон скуры',
    '👳🏾‍♀' => 'жанчына ў турбане: сярэдняцёмны тон скуры',
    '👳🏿‍♀' => 'жанчына ў турбане: цёмны тон скуры',
    '🤵🏻‍♂' => 'мужчына ў смокінгу: светлы тон скуры',
    '🤵🏼‍♂' => 'мужчына ў смокінгу: сярэднясветлы тон скуры',
    '🤵🏽‍♂' => 'мужчына ў смокінгу: сярэдні тон скуры',
    '🤵🏾‍♂' => 'мужчына ў смокінгу: сярэдняцёмны тон скуры',
    '🤵🏿‍♂' => 'мужчына ў смокінгу: цёмны тон скуры',
    '🤵🏻‍♀' => 'жанчына ў смокінгу: светлы тон скуры',
    '🤵🏼‍♀' => 'жанчына ў смокінгу: сярэднясветлы тон скуры',
    '🤵🏽‍♀' => 'жанчына ў смокінгу: сярэдні тон скуры',
    '🤵🏾‍♀' => 'жанчына ў смокінгу: сярэдняцёмны тон скуры',
    '🤵🏿‍♀' => 'жанчына ў смокінгу: цёмны тон скуры',
    '👰🏻‍♂' => 'мужчына ў вэлюме: светлы тон скуры',
    '👰🏼‍♂' => 'мужчына ў вэлюме: сярэднясветлы тон скуры',
    '👰🏽‍♂' => 'мужчына ў вэлюме: сярэдні тон скуры',
    '👰🏾‍♂' => 'мужчына ў вэлюме: сярэдняцёмны тон скуры',
    '👰🏿‍♂' => 'мужчына ў вэлюме: цёмны тон скуры',
    '👰🏻‍♀' => 'жанчына ў вэлюме: светлы тон скуры',
    '👰🏼‍♀' => 'жанчына ў вэлюме: сярэднясветлы тон скуры',
    '👰🏽‍♀' => 'жанчына ў вэлюме: сярэдні тон скуры',
    '👰🏾‍♀' => 'жанчына ў вэлюме: сярэдняцёмны тон скуры',
    '👰🏿‍♀' => 'жанчына ў вэлюме: цёмны тон скуры',
    '👩🏻‍🍼' => 'жанчына корміць дзіця: светлы тон скуры',
    '👩🏼‍🍼' => 'жанчына корміць дзіця: сярэднясветлы тон скуры',
    '👩🏽‍🍼' => 'жанчына корміць дзіця: сярэдні тон скуры',
    '👩🏾‍🍼' => 'жанчына корміць дзіця: сярэдняцёмны тон скуры',
    '👩🏿‍🍼' => 'жанчына корміць дзіця: цёмны тон скуры',
    '👨🏻‍🍼' => 'мужчына корміць дзіця: светлы тон скуры',
    '👨🏼‍🍼' => 'мужчына корміць дзіця: сярэднясветлы тон скуры',
    '👨🏽‍🍼' => 'мужчына корміць дзіця: сярэдні тон скуры',
    '👨🏾‍🍼' => 'мужчына корміць дзіця: сярэдняцёмны тон скуры',
    '👨🏿‍🍼' => 'мужчына корміць дзіця: цёмны тон скуры',
    '🧑🏻‍🍼' => 'чалавек корміць дзіця: светлы тон скуры',
    '🧑🏼‍🍼' => 'чалавек корміць дзіця: сярэднясветлы тон скуры',
    '🧑🏽‍🍼' => 'чалавек корміць дзіця: сярэдні тон скуры',
    '🧑🏾‍🍼' => 'чалавек корміць дзіця: сярэдняцёмны тон скуры',
    '🧑🏿‍🍼' => 'чалавек корміць дзіця: цёмны тон скуры',
    '🧑🏻‍🎄' => 'спадарыня Клаус: светлы тон скуры',
    '🧑🏼‍🎄' => 'спадарыня Клаус: сярэднясветлы тон скуры',
    '🧑🏽‍🎄' => 'спадарыня Клаус: сярэдні тон скуры',
    '🧑🏾‍🎄' => 'спадарыня Клаус: сярэдняцёмны тон скуры',
    '🧑🏿‍🎄' => 'спадарыня Клаус: цёмны тон скуры',
    '🦸🏻‍♂' => 'мужчына-супергерой: светлы тон скуры',
    '🦸🏼‍♂' => 'мужчына-супергерой: сярэднясветлы тон скуры',
    '🦸🏽‍♂' => 'мужчына-супергерой: сярэдні тон скуры',
    '🦸🏾‍♂' => 'мужчына-супергерой: сярэдняцёмны тон скуры',
    '🦸🏿‍♂' => 'мужчына-супергерой: цёмны тон скуры',
    '🦸🏻‍♀' => 'жанчына-супергерой: светлы тон скуры',
    '🦸🏼‍♀' => 'жанчына-супергерой: сярэднясветлы тон скуры',
    '🦸🏽‍♀' => 'жанчына-супергерой: сярэдні тон скуры',
    '🦸🏾‍♀' => 'жанчына-супергерой: сярэдняцёмны тон скуры',
    '🦸🏿‍♀' => 'жанчына-супергерой: цёмны тон скуры',
    '🦹🏻‍♂' => 'суперзлачынец: светлы тон скуры',
    '🦹🏼‍♂' => 'суперзлачынец: сярэднясветлы тон скуры',
    '🦹🏽‍♂' => 'суперзлачынец: сярэдні тон скуры',
    '🦹🏾‍♂' => 'суперзлачынец: сярэдняцёмны тон скуры',
    '🦹🏿‍♂' => 'суперзлачынец: цёмны тон скуры',
    '🦹🏻‍♀' => 'суперзлачынка: светлы тон скуры',
    '🦹🏼‍♀' => 'суперзлачынка: сярэднясветлы тон скуры',
    '🦹🏽‍♀' => 'суперзлачынка: сярэдні тон скуры',
    '🦹🏾‍♀' => 'суперзлачынка: сярэдняцёмны тон скуры',
    '🦹🏿‍♀' => 'суперзлачынка: цёмны тон скуры',
    '🧙🏻‍♂' => 'чарадзей: светлы тон скуры',
    '🧙🏼‍♂' => 'чарадзей: сярэднясветлы тон скуры',
    '🧙🏽‍♂' => 'чарадзей: сярэдні тон скуры',
    '🧙🏾‍♂' => 'чарадзей: сярэдняцёмны тон скуры',
    '🧙🏿‍♂' => 'чарадзей: цёмны тон скуры',
    '🧙🏻‍♀' => 'чараўніца: светлы тон скуры',
    '🧙🏼‍♀' => 'чараўніца: сярэднясветлы тон скуры',
    '🧙🏽‍♀' => 'чараўніца: сярэдні тон скуры',
    '🧙🏾‍♀' => 'чараўніца: сярэдняцёмны тон скуры',
    '🧙🏿‍♀' => 'чараўніца: цёмны тон скуры',
    '🧚🏻‍♂' => 'мужчына-фея: светлы тон скуры',
    '🧚🏼‍♂' => 'мужчына-фея: сярэднясветлы тон скуры',
    '🧚🏽‍♂' => 'мужчына-фея: сярэдні тон скуры',
    '🧚🏾‍♂' => 'мужчына-фея: сярэдняцёмны тон скуры',
    '🧚🏿‍♂' => 'мужчына-фея: цёмны тон скуры',
    '🧚🏻‍♀' => 'жанчына-фея: светлы тон скуры',
    '🧚🏼‍♀' => 'жанчына-фея: сярэднясветлы тон скуры',
    '🧚🏽‍♀' => 'жанчына-фея: сярэдні тон скуры',
    '🧚🏾‍♀' => 'жанчына-фея: сярэдняцёмны тон скуры',
    '🧚🏿‍♀' => 'жанчына-фея: цёмны тон скуры',
    '🧛🏻‍♂' => 'мужчына-вампір: светлы тон скуры',
    '🧛🏼‍♂' => 'мужчына-вампір: сярэднясветлы тон скуры',
    '🧛🏽‍♂' => 'мужчына-вампір: сярэдні тон скуры',
    '🧛🏾‍♂' => 'мужчына-вампір: сярэдняцёмны тон скуры',
    '🧛🏿‍♂' => 'мужчына-вампір: цёмны тон скуры',
    '🧛🏻‍♀' => 'вампірка: светлы тон скуры',
    '🧛🏼‍♀' => 'вампірка: сярэднясветлы тон скуры',
    '🧛🏽‍♀' => 'вампірка: сярэдні тон скуры',
    '🧛🏾‍♀' => 'вампірка: сярэдняцёмны тон скуры',
    '🧛🏿‍♀' => 'вампірка: цёмны тон скуры',
    '🧜🏻‍♂' => 'мужчына-русалка: светлы тон скуры',
    '🧜🏼‍♂' => 'мужчына-русалка: сярэднясветлы тон скуры',
    '🧜🏽‍♂' => 'мужчына-русалка: сярэдні тон скуры',
    '🧜🏾‍♂' => 'мужчына-русалка: сярэдняцёмны тон скуры',
    '🧜🏿‍♂' => 'мужчына-русалка: цёмны тон скуры',
    '🧜🏻‍♀' => 'русалка: светлы тон скуры',
    '🧜🏼‍♀' => 'русалка: сярэднясветлы тон скуры',
    '🧜🏽‍♀' => 'русалка: сярэдні тон скуры',
    '🧜🏾‍♀' => 'русалка: сярэдняцёмны тон скуры',
    '🧜🏿‍♀' => 'русалка: цёмны тон скуры',
    '🧝🏻‍♂' => 'мужчына-эльф: светлы тон скуры',
    '🧝🏼‍♂' => 'мужчына-эльф: сярэднясветлы тон скуры',
    '🧝🏽‍♂' => 'мужчына-эльф: сярэдні тон скуры',
    '🧝🏾‍♂' => 'мужчына-эльф: сярэдняцёмны тон скуры',
    '🧝🏿‍♂' => 'мужчына-эльф: цёмны тон скуры',
    '🧝🏻‍♀' => 'эльфійка: светлы тон скуры',
    '🧝🏼‍♀' => 'эльфійка: сярэднясветлы тон скуры',
    '🧝🏽‍♀' => 'эльфійка: сярэдні тон скуры',
    '🧝🏾‍♀' => 'эльфійка: сярэдняцёмны тон скуры',
    '🧝🏿‍♀' => 'эльфійка: цёмны тон скуры',
    '💆🏻‍♂' => 'мужчыну масажуюць: светлы тон скуры',
    '💆🏼‍♂' => 'мужчыну масажуюць: сярэднясветлы тон скуры',
    '💆🏽‍♂' => 'мужчыну масажуюць: сярэдні тон скуры',
    '💆🏾‍♂' => 'мужчыну масажуюць: сярэдняцёмны тон скуры',
    '💆🏿‍♂' => 'мужчыну масажуюць: цёмны тон скуры',
    '💆🏻‍♀' => 'жанчыну масажуюць: светлы тон скуры',
    '💆🏼‍♀' => 'жанчыну масажуюць: сярэднясветлы тон скуры',
    '💆🏽‍♀' => 'жанчыну масажуюць: сярэдні тон скуры',
    '💆🏾‍♀' => 'жанчыну масажуюць: сярэдняцёмны тон скуры',
    '💆🏿‍♀' => 'жанчыну масажуюць: цёмны тон скуры',
    '💇🏻‍♂' => 'мужчыне стрыгуць валоссе: светлы тон скуры',
    '💇🏼‍♂' => 'мужчыне стрыгуць валоссе: сярэднясветлы тон скуры',
    '💇🏽‍♂' => 'мужчыне стрыгуць валоссе: сярэдні тон скуры',
    '💇🏾‍♂' => 'мужчыне стрыгуць валоссе: сярэдняцёмны тон скуры',
    '💇🏿‍♂' => 'мужчыне стрыгуць валоссе: цёмны тон скуры',
    '💇🏻‍♀' => 'жанчыне стрыгуць валоссе: светлы тон скуры',
    '💇🏼‍♀' => 'жанчыне стрыгуць валоссе: сярэднясветлы тон скуры',
    '💇🏽‍♀' => 'жанчыне стрыгуць валоссе: сярэдні тон скуры',
    '💇🏾‍♀' => 'жанчыне стрыгуць валоссе: сярэдняцёмны тон скуры',
    '💇🏿‍♀' => 'жанчыне стрыгуць валоссе: цёмны тон скуры',
    '🚶🏻‍♂' => 'мужчына ідзе: светлы тон скуры',
    '🚶🏼‍♂' => 'мужчына ідзе: сярэднясветлы тон скуры',
    '🚶🏽‍♂' => 'мужчына ідзе: сярэдні тон скуры',
    '🚶🏾‍♂' => 'мужчына ідзе: сярэдняцёмны тон скуры',
    '🚶🏿‍♂' => 'мужчына ідзе: цёмны тон скуры',
    '🚶🏻‍♀' => 'жанчына ідзе: светлы тон скуры',
    '🚶🏼‍♀' => 'жанчына ідзе: сярэднясветлы тон скуры',
    '🚶🏽‍♀' => 'жанчына ідзе: сярэдні тон скуры',
    '🚶🏾‍♀' => 'жанчына ідзе: сярэдняцёмны тон скуры',
    '🚶🏿‍♀' => 'жанчына ідзе: цёмны тон скуры',
    '🚶🏻‍➡' => 'чалавек ідзе: светлы тон скуры , накіраваныя ўправа',
    '🚶🏼‍➡' => 'чалавек ідзе: сярэднясветлы тон скуры , накіраваныя ўправа',
    '🚶🏽‍➡' => 'чалавек ідзе: сярэдні тон скуры , накіраваныя ўправа',
    '🚶🏾‍➡' => 'чалавек ідзе: сярэдняцёмны тон скуры , накіраваныя ўправа',
    '🚶🏿‍➡' => 'чалавек ідзе: цёмны тон скуры , накіраваныя ўправа',
    '🧍🏻‍♂' => 'мужчына стаіць: светлы тон скуры',
    '🧍🏼‍♂' => 'мужчына стаіць: сярэднясветлы тон скуры',
    '🧍🏽‍♂' => 'мужчына стаіць: сярэдні тон скуры',
    '🧍🏾‍♂' => 'мужчына стаіць: сярэдняцёмны тон скуры',
    '🧍🏿‍♂' => 'мужчына стаіць: цёмны тон скуры',
    '🧍🏻‍♀' => 'жанчына стаіць: светлы тон скуры',
    '🧍🏼‍♀' => 'жанчына стаіць: сярэднясветлы тон скуры',
    '🧍🏽‍♀' => 'жанчына стаіць: сярэдні тон скуры',
    '🧍🏾‍♀' => 'жанчына стаіць: сярэдняцёмны тон скуры',
    '🧍🏿‍♀' => 'жанчына стаіць: цёмны тон скуры',
    '🧎🏻‍♂' => 'мужчына стаіць на каленях: светлы тон скуры',
    '🧎🏼‍♂' => 'мужчына стаіць на каленях: сярэднясветлы тон скуры',
    '🧎🏽‍♂' => 'мужчына стаіць на каленях: сярэдні тон скуры',
    '🧎🏾‍♂' => 'мужчына стаіць на каленях: сярэдняцёмны тон скуры',
    '🧎🏿‍♂' => 'мужчына стаіць на каленях: цёмны тон скуры',
    '🧎🏻‍♀' => 'жанчына стаіць на каленях: светлы тон скуры',
    '🧎🏼‍♀' => 'жанчына стаіць на каленях: сярэднясветлы тон скуры',
    '🧎🏽‍♀' => 'жанчына стаіць на каленях: сярэдні тон скуры',
    '🧎🏾‍♀' => 'жанчына стаіць на каленях: сярэдняцёмны тон скуры',
    '🧎🏿‍♀' => 'жанчына стаіць на каленях: цёмны тон скуры',
    '🧎🏻‍➡' => 'чалавек на каленях: светлы тон скуры , накіраваныя ўправа',
    '🧎🏼‍➡' => 'чалавек на каленях: сярэднясветлы тон скуры , накіраваныя ўправа',
    '🧎🏽‍➡' => 'чалавек на каленях: сярэдні тон скуры , накіраваныя ўправа',
    '🧎🏾‍➡' => 'чалавек на каленях: сярэдняцёмны тон скуры , накіраваныя ўправа',
    '🧎🏿‍➡' => 'чалавек на каленях: цёмны тон скуры , накіраваныя ўправа',
    '🧑🏻‍🦯' => 'чалавек з палкай: светлы тон скуры',
    '🧑🏼‍🦯' => 'чалавек з палкай: сярэднясветлы тон скуры',
    '🧑🏽‍🦯' => 'чалавек з палкай: сярэдні тон скуры',
    '🧑🏾‍🦯' => 'чалавек з палкай: сярэдняцёмны тон скуры',
    '🧑🏿‍🦯' => 'чалавек з палкай: цёмны тон скуры',
    '👨🏻‍🦯' => 'мужчына з палкай: светлы тон скуры',
    '👨🏼‍🦯' => 'мужчына з палкай: сярэднясветлы тон скуры',
    '👨🏽‍🦯' => 'мужчына з палкай: сярэдні тон скуры',
    '👨🏾‍🦯' => 'мужчына з палкай: сярэдняцёмны тон скуры',
    '👨🏿‍🦯' => 'мужчына з палкай: цёмны тон скуры',
    '👩🏻‍🦯' => 'жанчына з палкай: светлы тон скуры',
    '👩🏼‍🦯' => 'жанчына з палкай: сярэднясветлы тон скуры',
    '👩🏽‍🦯' => 'жанчына з палкай: сярэдні тон скуры',
    '👩🏾‍🦯' => 'жанчына з палкай: сярэдняцёмны тон скуры',
    '👩🏿‍🦯' => 'жанчына з палкай: цёмны тон скуры',
    '🧑🏻‍🦼' => 'чалавек у інваліднай калясцы з маторам: светлы тон скуры',
    '🧑🏼‍🦼' => 'чалавек у інваліднай калясцы з маторам: сярэднясветлы тон скуры',
    '🧑🏽‍🦼' => 'чалавек у інваліднай калясцы з маторам: сярэдні тон скуры',
    '🧑🏾‍🦼' => 'чалавек у інваліднай калясцы з маторам: сярэдняцёмны тон скуры',
    '🧑🏿‍🦼' => 'чалавек у інваліднай калясцы з маторам: цёмны тон скуры',
    '👨🏻‍🦼' => 'мужчына ў інваліднай калясцы з маторам: светлы тон скуры',
    '👨🏼‍🦼' => 'мужчына ў інваліднай калясцы з маторам: сярэднясветлы тон скуры',
    '👨🏽‍🦼' => 'мужчына ў інваліднай калясцы з маторам: сярэдні тон скуры',
    '👨🏾‍🦼' => 'мужчына ў інваліднай калясцы з маторам: сярэдняцёмны тон скуры',
    '👨🏿‍🦼' => 'мужчына ў інваліднай калясцы з маторам: цёмны тон скуры',
    '👩🏻‍🦼' => 'жанчына ў інваліднай калясцы з маторам: светлы тон скуры',
    '👩🏼‍🦼' => 'жанчына ў інваліднай калясцы з маторам: сярэднясветлы тон скуры',
    '👩🏽‍🦼' => 'жанчына ў інваліднай калясцы з маторам: сярэдні тон скуры',
    '👩🏾‍🦼' => 'жанчына ў інваліднай калясцы з маторам: сярэдняцёмны тон скуры',
    '👩🏿‍🦼' => 'жанчына ў інваліднай калясцы з маторам: цёмны тон скуры',
    '🧑🏻‍🦽' => 'чалавек у калясцы з ручным прывадам: светлы тон скуры',
    '🧑🏼‍🦽' => 'чалавек у калясцы з ручным прывадам: сярэднясветлы тон скуры',
    '🧑🏽‍🦽' => 'чалавек у калясцы з ручным прывадам: сярэдні тон скуры',
    '🧑🏾‍🦽' => 'чалавек у калясцы з ручным прывадам: сярэдняцёмны тон скуры',
    '🧑🏿‍🦽' => 'чалавек у калясцы з ручным прывадам: цёмны тон скуры',
    '👨🏻‍🦽' => 'мужчына ў калясцы з ручным прывадам: светлы тон скуры',
    '👨🏼‍🦽' => 'мужчына ў калясцы з ручным прывадам: сярэднясветлы тон скуры',
    '👨🏽‍🦽' => 'мужчына ў калясцы з ручным прывадам: сярэдні тон скуры',
    '👨🏾‍🦽' => 'мужчына ў калясцы з ручным прывадам: сярэдняцёмны тон скуры',
    '👨🏿‍🦽' => 'мужчына ў калясцы з ручным прывадам: цёмны тон скуры',
    '👩🏻‍🦽' => 'жанчына ў калясцы з ручным прывадам: светлы тон скуры',
    '👩🏼‍🦽' => 'жанчына ў калясцы з ручным прывадам: сярэднясветлы тон скуры',
    '👩🏽‍🦽' => 'жанчына ў калясцы з ручным прывадам: сярэдні тон скуры',
    '👩🏾‍🦽' => 'жанчына ў калясцы з ручным прывадам: сярэдняцёмны тон скуры',
    '👩🏿‍🦽' => 'жанчына ў калясцы з ручным прывадам: цёмны тон скуры',
    '🏃🏻‍♂' => 'мужчына бяжыць: светлы тон скуры',
    '🏃🏼‍♂' => 'мужчына бяжыць: сярэднясветлы тон скуры',
    '🏃🏽‍♂' => 'мужчына бяжыць: сярэдні тон скуры',
    '🏃🏾‍♂' => 'мужчына бяжыць: сярэдняцёмны тон скуры',
    '🏃🏿‍♂' => 'мужчына бяжыць: цёмны тон скуры',
    '🏃🏻‍♀' => 'жанчына бяжыць: светлы тон скуры',
    '🏃🏼‍♀' => 'жанчына бяжыць: сярэднясветлы тон скуры',
    '🏃🏽‍♀' => 'жанчына бяжыць: сярэдні тон скуры',
    '🏃🏾‍♀' => 'жанчына бяжыць: сярэдняцёмны тон скуры',
    '🏃🏿‍♀' => 'жанчына бяжыць: цёмны тон скуры',
    '🏃🏻‍➡' => 'чалавек бяжыць: светлы тон скуры , накіраваныя ўправа',
    '🏃🏼‍➡' => 'чалавек бяжыць: сярэднясветлы тон скуры , накіраваныя ўправа',
    '🏃🏽‍➡' => 'чалавек бяжыць: сярэдні тон скуры , накіраваныя ўправа',
    '🏃🏾‍➡' => 'чалавек бяжыць: сярэдняцёмны тон скуры , накіраваныя ўправа',
    '🏃🏿‍➡' => 'чалавек бяжыць: цёмны тон скуры , накіраваныя ўправа',
    '👯🏻‍♀' => 'жанчыны весяляцца: светлы тон скуры',
    '👯🏼‍♀' => 'жанчыны весяляцца: сярэднясветлы тон скуры',
    '👯🏽‍♀' => 'жанчыны весяляцца: сярэдні тон скуры',
    '👯🏾‍♀' => 'жанчыны весяляцца: сярэдняцёмны тон скуры',
    '👯🏿‍♀' => 'жанчыны весяляцца: цёмны тон скуры',
    '👯🏻‍♂' => 'мужчыны весяляцца: светлы тон скуры',
    '👯🏼‍♂' => 'мужчыны весяляцца: сярэднясветлы тон скуры',
    '👯🏽‍♂' => 'мужчыны весяляцца: сярэдні тон скуры',
    '👯🏾‍♂' => 'мужчыны весяляцца: сярэдняцёмны тон скуры',
    '👯🏿‍♂' => 'мужчыны весяляцца: цёмны тон скуры',
    '🧖🏻‍♂' => 'мужчына ў лазні: светлы тон скуры',
    '🧖🏼‍♂' => 'мужчына ў лазні: сярэднясветлы тон скуры',
    '🧖🏽‍♂' => 'мужчына ў лазні: сярэдні тон скуры',
    '🧖🏾‍♂' => 'мужчына ў лазні: сярэдняцёмны тон скуры',
    '🧖🏿‍♂' => 'мужчына ў лазні: цёмны тон скуры',
    '🧖🏻‍♀' => 'жанчына ў лазні: светлы тон скуры',
    '🧖🏼‍♀' => 'жанчына ў лазні: сярэднясветлы тон скуры',
    '🧖🏽‍♀' => 'жанчына ў лазні: сярэдні тон скуры',
    '🧖🏾‍♀' => 'жанчына ў лазні: сярэдняцёмны тон скуры',
    '🧖🏿‍♀' => 'жанчына ў лазні: цёмны тон скуры',
    '🧗🏻‍♂' => 'мужчына падымаецца на гару: светлы тон скуры',
    '🧗🏼‍♂' => 'мужчына падымаецца на гару: сярэднясветлы тон скуры',
    '🧗🏽‍♂' => 'мужчына падымаецца на гару: сярэдні тон скуры',
    '🧗🏾‍♂' => 'мужчына падымаецца на гару: сярэдняцёмны тон скуры',
    '🧗🏿‍♂' => 'мужчына падымаецца на гару: цёмны тон скуры',
    '🧗🏻‍♀' => 'жанчына падымаецца на гару: светлы тон скуры',
    '🧗🏼‍♀' => 'жанчына падымаецца на гару: сярэднясветлы тон скуры',
    '🧗🏽‍♀' => 'жанчына падымаецца на гару: сярэдні тон скуры',
    '🧗🏾‍♀' => 'жанчына падымаецца на гару: сярэдняцёмны тон скуры',
    '🧗🏿‍♀' => 'жанчына падымаецца на гару: цёмны тон скуры',
    '🏌🏻‍♂' => 'мужчына гуляе ў гольф: светлы тон скуры',
    '🏌🏼‍♂' => 'мужчына гуляе ў гольф: сярэднясветлы тон скуры',
    '🏌🏽‍♂' => 'мужчына гуляе ў гольф: сярэдні тон скуры',
    '🏌🏾‍♂' => 'мужчына гуляе ў гольф: сярэдняцёмны тон скуры',
    '🏌🏿‍♂' => 'мужчына гуляе ў гольф: цёмны тон скуры',
    '🏌🏻‍♀' => 'жанчына гуляе ў гольф: светлы тон скуры',
    '🏌🏼‍♀' => 'жанчына гуляе ў гольф: сярэднясветлы тон скуры',
    '🏌🏽‍♀' => 'жанчына гуляе ў гольф: сярэдні тон скуры',
    '🏌🏾‍♀' => 'жанчына гуляе ў гольф: сярэдняцёмны тон скуры',
    '🏌🏿‍♀' => 'жанчына гуляе ў гольф: цёмны тон скуры',
    '🏄🏻‍♂' => 'серфінгіст: светлы тон скуры',
    '🏄🏼‍♂' => 'серфінгіст: сярэднясветлы тон скуры',
    '🏄🏽‍♂' => 'серфінгіст: сярэдні тон скуры',
    '🏄🏾‍♂' => 'серфінгіст: сярэдняцёмны тон скуры',
    '🏄🏿‍♂' => 'серфінгіст: цёмны тон скуры',
    '🏄🏻‍♀' => 'серфінгістка: светлы тон скуры',
    '🏄🏼‍♀' => 'серфінгістка: сярэднясветлы тон скуры',
    '🏄🏽‍♀' => 'серфінгістка: сярэдні тон скуры',
    '🏄🏾‍♀' => 'серфінгістка: сярэдняцёмны тон скуры',
    '🏄🏿‍♀' => 'серфінгістка: цёмны тон скуры',
    '🚣🏻‍♂' => 'вясляр: светлы тон скуры',
    '🚣🏼‍♂' => 'вясляр: сярэднясветлы тон скуры',
    '🚣🏽‍♂' => 'вясляр: сярэдні тон скуры',
    '🚣🏾‍♂' => 'вясляр: сярэдняцёмны тон скуры',
    '🚣🏿‍♂' => 'вясляр: цёмны тон скуры',
    '🚣🏻‍♀' => 'вяслярка: светлы тон скуры',
    '🚣🏼‍♀' => 'вяслярка: сярэднясветлы тон скуры',
    '🚣🏽‍♀' => 'вяслярка: сярэдні тон скуры',
    '🚣🏾‍♀' => 'вяслярка: сярэдняцёмны тон скуры',
    '🚣🏿‍♀' => 'вяслярка: цёмны тон скуры',
    '🏊🏻‍♂' => 'плывец: светлы тон скуры',
    '🏊🏼‍♂' => 'плывец: сярэднясветлы тон скуры',
    '🏊🏽‍♂' => 'плывец: сярэдні тон скуры',
    '🏊🏾‍♂' => 'плывец: сярэдняцёмны тон скуры',
    '🏊🏿‍♂' => 'плывец: цёмны тон скуры',
    '🏊🏻‍♀' => 'плыўчыха: светлы тон скуры',
    '🏊🏼‍♀' => 'плыўчыха: сярэднясветлы тон скуры',
    '🏊🏽‍♀' => 'плыўчыха: сярэдні тон скуры',
    '🏊🏾‍♀' => 'плыўчыха: сярэдняцёмны тон скуры',
    '🏊🏿‍♀' => 'плыўчыха: цёмны тон скуры',
    '⛹🏻‍♂' => 'мужчына з мячом: светлы тон скуры',
    '⛹🏼‍♂' => 'мужчына з мячом: сярэднясветлы тон скуры',
    '⛹🏽‍♂' => 'мужчына з мячом: сярэдні тон скуры',
    '⛹🏾‍♂' => 'мужчына з мячом: сярэдняцёмны тон скуры',
    '⛹🏿‍♂' => 'мужчына з мячом: цёмны тон скуры',
    '⛹🏻‍♀' => 'жанчына з мячом: светлы тон скуры',
    '⛹🏼‍♀' => 'жанчына з мячом: сярэднясветлы тон скуры',
    '⛹🏽‍♀' => 'жанчына з мячом: сярэдні тон скуры',
    '⛹🏾‍♀' => 'жанчына з мячом: сярэдняцёмны тон скуры',
    '⛹🏿‍♀' => 'жанчына з мячом: цёмны тон скуры',
    '🏋🏻‍♂' => 'цяжкаатлет: светлы тон скуры',
    '🏋🏼‍♂' => 'цяжкаатлет: сярэднясветлы тон скуры',
    '🏋🏽‍♂' => 'цяжкаатлет: сярэдні тон скуры',
    '🏋🏾‍♂' => 'цяжкаатлет: сярэдняцёмны тон скуры',
    '🏋🏿‍♂' => 'цяжкаатлет: цёмны тон скуры',
    '🏋🏻‍♀' => 'цяжкаатлетка: светлы тон скуры',
    '🏋🏼‍♀' => 'цяжкаатлетка: сярэднясветлы тон скуры',
    '🏋🏽‍♀' => 'цяжкаатлетка: сярэдні тон скуры',
    '🏋🏾‍♀' => 'цяжкаатлетка: сярэдняцёмны тон скуры',
    '🏋🏿‍♀' => 'цяжкаатлетка: цёмны тон скуры',
    '🚴🏻‍♂' => 'веласіпедыст: светлы тон скуры',
    '🚴🏼‍♂' => 'веласіпедыст: сярэднясветлы тон скуры',
    '🚴🏽‍♂' => 'веласіпедыст: сярэдні тон скуры',
    '🚴🏾‍♂' => 'веласіпедыст: сярэдняцёмны тон скуры',
    '🚴🏿‍♂' => 'веласіпедыст: цёмны тон скуры',
    '🚴🏻‍♀' => 'веласіпедыстка: светлы тон скуры',
    '🚴🏼‍♀' => 'веласіпедыстка: сярэднясветлы тон скуры',
    '🚴🏽‍♀' => 'веласіпедыстка: сярэдні тон скуры',
    '🚴🏾‍♀' => 'веласіпедыстка: сярэдняцёмны тон скуры',
    '🚴🏿‍♀' => 'веласіпедыстка: цёмны тон скуры',
    '🚵🏻‍♂' => 'мужчына на горным веласіпедзе: светлы тон скуры',
    '🚵🏼‍♂' => 'мужчына на горным веласіпедзе: сярэднясветлы тон скуры',
    '🚵🏽‍♂' => 'мужчына на горным веласіпедзе: сярэдні тон скуры',
    '🚵🏾‍♂' => 'мужчына на горным веласіпедзе: сярэдняцёмны тон скуры',
    '🚵🏿‍♂' => 'мужчына на горным веласіпедзе: цёмны тон скуры',
    '🚵🏻‍♀' => 'жанчына на горным веласіпедзе: светлы тон скуры',
    '🚵🏼‍♀' => 'жанчына на горным веласіпедзе: сярэднясветлы тон скуры',
    '🚵🏽‍♀' => 'жанчына на горным веласіпедзе: сярэдні тон скуры',
    '🚵🏾‍♀' => 'жанчына на горным веласіпедзе: сярэдняцёмны тон скуры',
    '🚵🏿‍♀' => 'жанчына на горным веласіпедзе: цёмны тон скуры',
    '🤸🏻‍♂' => 'мужчына ходзіць колам: светлы тон скуры',
    '🤸🏼‍♂' => 'мужчына ходзіць колам: сярэднясветлы тон скуры',
    '🤸🏽‍♂' => 'мужчына ходзіць колам: сярэдні тон скуры',
    '🤸🏾‍♂' => 'мужчына ходзіць колам: сярэдняцёмны тон скуры',
    '🤸🏿‍♂' => 'мужчына ходзіць колам: цёмны тон скуры',
    '🤸🏻‍♀' => 'жанчына ходзіць колам: светлы тон скуры',
    '🤸🏼‍♀' => 'жанчына ходзіць колам: сярэднясветлы тон скуры',
    '🤸🏽‍♀' => 'жанчына ходзіць колам: сярэдні тон скуры',
    '🤸🏾‍♀' => 'жанчына ходзіць колам: сярэдняцёмны тон скуры',
    '🤸🏿‍♀' => 'жанчына ходзіць колам: цёмны тон скуры',
    '🤼🏻‍♀' => 'жанчыны-барцы: светлы тон скуры',
    '🤼🏼‍♀' => 'жанчыны-барцы: сярэднясветлы тон скуры',
    '🤼🏽‍♀' => 'жанчыны-барцы: сярэдні тон скуры',
    '🤼🏾‍♀' => 'жанчыны-барцы: сярэдняцёмны тон скуры',
    '🤼🏿‍♀' => 'жанчыны-барцы: цёмны тон скуры',
    '🤼🏻‍♂' => 'барацьба мужчын: светлы тон скуры',
    '🤼🏼‍♂' => 'барацьба мужчын: сярэднясветлы тон скуры',
    '🤼🏽‍♂' => 'барацьба мужчын: сярэдні тон скуры',
    '🤼🏾‍♂' => 'барацьба мужчын: сярэдняцёмны тон скуры',
    '🤼🏿‍♂' => 'барацьба мужчын: цёмны тон скуры',
    '🤽🏻‍♂' => 'мужчына гуляе ў воднае пола: светлы тон скуры',
    '🤽🏼‍♂' => 'мужчына гуляе ў воднае пола: сярэднясветлы тон скуры',
    '🤽🏽‍♂' => 'мужчына гуляе ў воднае пола: сярэдні тон скуры',
    '🤽🏾‍♂' => 'мужчына гуляе ў воднае пола: сярэдняцёмны тон скуры',
    '🤽🏿‍♂' => 'мужчына гуляе ў воднае пола: цёмны тон скуры',
    '🤽🏻‍♀' => 'жанчына гуляе ў воднае пола: светлы тон скуры',
    '🤽🏼‍♀' => 'жанчына гуляе ў воднае пола: сярэднясветлы тон скуры',
    '🤽🏽‍♀' => 'жанчына гуляе ў воднае пола: сярэдні тон скуры',
    '🤽🏾‍♀' => 'жанчына гуляе ў воднае пола: сярэдняцёмны тон скуры',
    '🤽🏿‍♀' => 'жанчына гуляе ў воднае пола: цёмны тон скуры',
    '🤾🏻‍♂' => 'гандбаліст: светлы тон скуры',
    '🤾🏼‍♂' => 'гандбаліст: сярэднясветлы тон скуры',
    '🤾🏽‍♂' => 'гандбаліст: сярэдні тон скуры',
    '🤾🏾‍♂' => 'гандбаліст: сярэдняцёмны тон скуры',
    '🤾🏿‍♂' => 'гандбаліст: цёмны тон скуры',
    '🤾🏻‍♀' => 'гандбалістка: светлы тон скуры',
    '🤾🏼‍♀' => 'гандбалістка: сярэднясветлы тон скуры',
    '🤾🏽‍♀' => 'гандбалістка: сярэдні тон скуры',
    '🤾🏾‍♀' => 'гандбалістка: сярэдняцёмны тон скуры',
    '🤾🏿‍♀' => 'гандбалістка: цёмны тон скуры',
    '🤹🏻‍♂' => 'мужчына жангліруе: светлы тон скуры',
    '🤹🏼‍♂' => 'мужчына жангліруе: сярэднясветлы тон скуры',
    '🤹🏽‍♂' => 'мужчына жангліруе: сярэдні тон скуры',
    '🤹🏾‍♂' => 'мужчына жангліруе: сярэдняцёмны тон скуры',
    '🤹🏿‍♂' => 'мужчына жангліруе: цёмны тон скуры',
    '🤹🏻‍♀' => 'жанглёрка: светлы тон скуры',
    '🤹🏼‍♀' => 'жанглёрка: сярэднясветлы тон скуры',
    '🤹🏽‍♀' => 'жанглёрка: сярэдні тон скуры',
    '🤹🏾‍♀' => 'жанглёрка: сярэдняцёмны тон скуры',
    '🤹🏿‍♀' => 'жанглёрка: цёмны тон скуры',
    '🧘🏻‍♂' => 'мужчына ў позе лотаса: светлы тон скуры',
    '🧘🏼‍♂' => 'мужчына ў позе лотаса: сярэднясветлы тон скуры',
    '🧘🏽‍♂' => 'мужчына ў позе лотаса: сярэдні тон скуры',
    '🧘🏾‍♂' => 'мужчына ў позе лотаса: сярэдняцёмны тон скуры',
    '🧘🏿‍♂' => 'мужчына ў позе лотаса: цёмны тон скуры',
    '🧘🏻‍♀' => 'жанчына ў позе лотаса: светлы тон скуры',
    '🧘🏼‍♀' => 'жанчына ў позе лотаса: сярэднясветлы тон скуры',
    '🧘🏽‍♀' => 'жанчына ў позе лотаса: сярэдні тон скуры',
    '🧘🏾‍♀' => 'жанчына ў позе лотаса: сярэдняцёмны тон скуры',
    '🧘🏿‍♀' => 'жанчына ў позе лотаса: цёмны тон скуры',
    '🧑‍🦰' => 'дарослы: рыжыя валасы',
    '🧑‍🦱' => 'дарослы: курчавыя валасы',
    '🧑‍🦳' => 'дарослы: сівыя валасы',
    '🧑‍🦲' => 'дарослы: лысы',
    '👨‍🦰' => 'мужчына: рыжыя валасы',
    '👨‍🦱' => 'мужчына: курчавыя валасы',
    '👨‍🦳' => 'мужчына: сівыя валасы',
    '👨‍🦲' => 'мужчына: лысы',
    '👩‍🦰' => 'жанчына: рыжыя валасы',
    '👩‍🦱' => 'жанчына: курчавыя валасы',
    '👩‍🦳' => 'жанчына: сівыя валасы',
    '👩‍🦲' => 'жанчына: лысы',
    '🚶‍➡' => 'чалавек ідзе: , накіраваныя ўправа',
    '🧎‍➡' => 'чалавек на каленях: , накіраваныя ўправа',
    '🏃‍➡' => 'чалавек бяжыць: , накіраваныя ўправа',
    '👨‍👦' => 'сям’я: мужчына хлопчык',
    '👨‍👧' => 'сям’я: мужчына дзяўчынка',
    '👩‍👦' => 'сям’я: жанчына хлопчык',
    '👩‍👧' => 'сям’я: жанчына дзяўчынка',
    '😶‍🌫' => 'твар у аблоках',
    '😮‍💨' => 'твар выдыхае',
    '🙂‍↕' => 'вертыкальна ківае галавой',
    '😵‍💫' => 'твар з вачыма-спіралямі',
    '❤‍🔥' => 'сэрца ў агні',
    '❤‍🩹' => 'сэрца загойваецца',
    '👁‍🗨' => 'вока ў бурбалцы',
    '🧔‍♂' => 'мужчына: барада',
    '👱‍♂' => 'бялявы мужчына',
    '🧔‍♀' => 'жанчына: барада',
    '👱‍♀' => 'бялявая жанчына',
    '🙍‍♂' => 'засмучаны мужчына',
    '🙍‍♀' => 'засмучаная жанчына',
    '🙎‍♂' => 'надзьмуты мужчына',
    '🙎‍♀' => 'надзьмутая жанчына',
    '🙅‍♂' => 'мужчына супраць',
    '🙅‍♀' => 'жанчына супраць',
    '🙆‍♂' => 'мужчына паказвае згоду',
    '🙆‍♀' => 'жанчына паказвае згоду',
    '💁‍♂' => 'мужчына трасе рукой',
    '💁‍♀' => 'жанчына трасе рукой',
    '🙋‍♂' => 'мужчына цягне руку',
    '🙋‍♀' => 'жанчына цягне руку',
    '🧏‍♂' => 'глухі мужчына',
    '🧏‍♀' => 'глухая жанчына',
    '🙇‍♂' => 'мужчына нізка кланяецца',
    '🙇‍♀' => 'жанчына нізка кланяецца',
    '🤦‍♂' => 'мужчына з далонню на твары',
    '🤦‍♀' => 'жанчына з далонню на твары',
    '🤷‍♂' => 'мужчына паціскае плячыма',
    '🤷‍♀' => 'жанчына паціскае плячыма',
    '🧑‍⚕' => 'медыцынскі работнік',
    '👨‍⚕' => 'доктар',
    '👩‍⚕' => 'доктарка',
    '🧑‍🎓' => 'навучэнец',
    '👨‍🎓' => 'студэнт',
    '👩‍🎓' => 'студэнтка',
    '🧑‍🏫' => 'выкладчык',
    '👨‍🏫' => 'настаўнік',
    '👩‍🏫' => 'настаўніца',
    '🧑‍⚖' => 'суддзя',
    '👨‍⚖' => 'суддзя-мужчына',
    '👩‍⚖' => 'суддзя-жанчына',
    '🧑‍🌾' => 'аграрый',
    '👨‍🌾' => 'фермер',
    '👩‍🌾' => 'фермерка',
    '🧑‍🍳' => 'повар',
    '👨‍🍳' => 'кухар',
    '👩‍🍳' => 'кухарка',
    '🧑‍🔧' => 'механік',
    '👨‍🔧' => 'мужчына-механік',
    '👩‍🔧' => 'жанчына-механік',
    '🧑‍🏭' => 'завадчанін',
    '👨‍🏭' => 'працаўнік завода',
    '👩‍🏭' => 'працаўніца завода',
    '🧑‍💼' => 'службовец',
    '👨‍💼' => 'служачы',
    '👩‍💼' => 'служачая',
    '🧑‍🔬' => 'навуковец',
    '👨‍🔬' => 'вучоны',
    '👩‍🔬' => 'вучоная',
    '🧑‍💻' => 'тэхнік',
    '👨‍💻' => 'камп’ютаршчык',
    '👩‍💻' => 'камп’ютаршчыца',
    '🧑‍🎤' => 'пяюн',
    '👨‍🎤' => 'спявак',
    '👩‍🎤' => 'спявачка',
    '🧑‍🎨' => 'жывапісец',
    '👨‍🎨' => 'мастак',
    '👩‍🎨' => 'мастачка',
    '🧑‍✈' => 'пілот',
    '👨‍✈' => 'мужчына-пілот',
    '👩‍✈' => 'жанчына-пілот',
    '🧑‍🚀' => 'астранаўт',
    '👨‍🚀' => 'касманаўт',
    '👩‍🚀' => 'касманаўтка',
    '🧑‍🚒' => 'пажарны',
    '👨‍🚒' => 'пажарнік',
    '👩‍🚒' => 'пажарніца',
    '👮‍♂' => 'паліцэйскі',
    '👮‍♀' => 'паліцэйская',
    '🕵‍♂' => 'сышчык',
    '🕵‍♀' => 'сышчыца',
    '💂‍♂' => 'каравульны',
    '💂‍♀' => 'ахоўніца',
    '👷‍♂' => 'мужчына-будаўнік',
    '👷‍♀' => 'будаўніца',
    '👳‍♂' => 'мужчына ў турбане',
    '👳‍♀' => 'жанчына ў турбане',
    '🤵‍♂' => 'мужчына ў смокінгу',
    '🤵‍♀' => 'жанчына ў смокінгу',
    '👰‍♂' => 'мужчына ў вэлюме',
    '👰‍♀' => 'жанчына ў вэлюме',
    '👩‍🍼' => 'жанчына корміць дзіця',
    '👨‍🍼' => 'мужчына корміць дзіця',
    '🧑‍🍼' => 'чалавек корміць дзіця',
    '🧑‍🎄' => 'спадарыня Клаус',
    '🦸‍♂' => 'мужчына-супергерой',
    '🦸‍♀' => 'жанчына-супергерой',
    '🦹‍♂' => 'суперзлачынец',
    '🦹‍♀' => 'суперзлачынка',
    '🧙‍♂' => 'чарадзей',
    '🧙‍♀' => 'чараўніца',
    '🧚‍♂' => 'мужчына-фея',
    '🧚‍♀' => 'жанчына-фея',
    '🧛‍♂' => 'мужчына-вампір',
    '🧛‍♀' => 'вампірка',
    '🧜‍♂' => 'мужчына-русалка',
    '🧜‍♀' => 'русалка',
    '🧝‍♂' => 'мужчына-эльф',
    '🧝‍♀' => 'эльфійка',
    '🧞‍♂' => 'мужчына-джын',
    '🧞‍♀' => 'жанчына-джын',
    '🧟‍♂' => 'мужчына-зомбі',
    '🧟‍♀' => 'жанчына-зомбі',
    '💆‍♂' => 'мужчыну масажуюць',
    '💆‍♀' => 'жанчыну масажуюць',
    '💇‍♂' => 'мужчыне стрыгуць валоссе',
    '💇‍♀' => 'жанчыне стрыгуць валоссе',
    '🚶‍♂' => 'мужчына ідзе',
    '🚶‍♀' => 'жанчына ідзе',
    '🧍‍♂' => 'мужчына стаіць',
    '🧍‍♀' => 'жанчына стаіць',
    '🧎‍♂' => 'мужчына стаіць на каленях',
    '🧎‍♀' => 'жанчына стаіць на каленях',
    '🧑‍🦯' => 'чалавек з палкай',
    '👨‍🦯' => 'мужчына з палкай',
    '👩‍🦯' => 'жанчына з палкай',
    '🧑‍🦼' => 'чалавек у інваліднай калясцы з маторам',
    '👨‍🦼' => 'мужчына ў інваліднай калясцы з маторам',
    '👩‍🦼' => 'жанчына ў інваліднай калясцы з маторам',
    '🧑‍🦽' => 'чалавек у калясцы з ручным прывадам',
    '👨‍🦽' => 'мужчына ў калясцы з ручным прывадам',
    '👩‍🦽' => 'жанчына ў калясцы з ручным прывадам',
    '🏃‍♂' => 'мужчына бяжыць',
    '🏃‍♀' => 'жанчына бяжыць',
    '🧑‍🩰' => 'балерына',
    '👯‍♂' => 'мужчыны весяляцца',
    '👯‍♀' => 'жанчыны весяляцца',
    '🧖‍♂' => 'мужчына ў лазні',
    '🧖‍♀' => 'жанчына ў лазні',
    '🧗‍♂' => 'мужчына падымаецца на гару',
    '🧗‍♀' => 'жанчына падымаецца на гару',
    '🏌‍♂' => 'мужчына гуляе ў гольф',
    '🏌‍♀' => 'жанчына гуляе ў гольф',
    '🏄‍♂' => 'серфінгіст',
    '🏄‍♀' => 'серфінгістка',
    '🚣‍♂' => 'вясляр',
    '🚣‍♀' => 'вяслярка',
    '🏊‍♂' => 'плывец',
    '🏊‍♀' => 'плыўчыха',
    '⛹‍♂' => 'мужчына з мячом',
    '⛹‍♀' => 'жанчына з мячом',
    '🏋‍♂' => 'цяжкаатлет',
    '🏋‍♀' => 'цяжкаатлетка',
    '🚴‍♂' => 'веласіпедыст',
    '🚴‍♀' => 'веласіпедыстка',
    '🚵‍♂' => 'мужчына на горным веласіпедзе',
    '🚵‍♀' => 'жанчына на горным веласіпедзе',
    '🤸‍♂' => 'мужчына ходзіць колам',
    '🤸‍♀' => 'жанчына ходзіць колам',
    '🤼‍♂' => 'барацьба мужчын',
    '🤼‍♀' => 'жанчыны-барцы',
    '🤽‍♂' => 'мужчына гуляе ў воднае пола',
    '🤽‍♀' => 'жанчына гуляе ў воднае пола',
    '🤾‍♂' => 'гандбаліст',
    '🤾‍♀' => 'гандбалістка',
    '🤹‍♂' => 'мужчына жангліруе',
    '🤹‍♀' => 'жанглёрка',
    '🧘‍♂' => 'мужчына ў позе лотаса',
    '🧘‍♀' => 'жанчына ў позе лотаса',
    '🧑‍🧒' => 'сям’я: дарослы і дзіця',
    '🐕‍🦺' => 'службовы сабака',
    '🐈‍⬛' => 'чорны кот',
    '🐻‍❄' => 'белы мядзведзь',
    '🐦‍⬛' => 'дрозд',
    '🐦‍🔥' => 'фенікс',
    '🍋‍🟩' => 'лайм',
    '🍄‍🟫' => 'карычневы грыб',
    '⛓‍💥' => 'зламаны ланцуг',
    '🏳‍🌈' => 'вясёлкавы сцяг',
    '🏳‍⚧' => 'трансгендарны сцяг',
    '🏴‍☠' => 'пірацкі сцяг',
    '👋🏻' => 'махае рукой: светлы тон скуры',
    '👋🏼' => 'махае рукой: сярэднясветлы тон скуры',
    '👋🏽' => 'махае рукой: сярэдні тон скуры',
    '👋🏾' => 'махае рукой: сярэдняцёмны тон скуры',
    '👋🏿' => 'махае рукой: цёмны тон скуры',
    '🤚🏻' => 'паднятая далонь: светлы тон скуры',
    '🤚🏼' => 'паднятая далонь: сярэднясветлы тон скуры',
    '🤚🏽' => 'паднятая далонь: сярэдні тон скуры',
    '🤚🏾' => 'паднятая далонь: сярэдняцёмны тон скуры',
    '🤚🏿' => 'паднятая далонь: цёмны тон скуры',
    '🖐🏻' => 'паднятая рука з растапыранымі пальцамі: светлы тон скуры',
    '🖐🏼' => 'паднятая рука з растапыранымі пальцамі: сярэднясветлы тон скуры',
    '🖐🏽' => 'паднятая рука з растапыранымі пальцамі: сярэдні тон скуры',
    '🖐🏾' => 'паднятая рука з растапыранымі пальцамі: сярэдняцёмны тон скуры',
    '🖐🏿' => 'паднятая рука з растапыранымі пальцамі: цёмны тон скуры',
    '✋🏻' => 'паднятая рука: светлы тон скуры',
    '✋🏼' => 'паднятая рука: сярэднясветлы тон скуры',
    '✋🏽' => 'паднятая рука: сярэдні тон скуры',
    '✋🏾' => 'паднятая рука: сярэдняцёмны тон скуры',
    '✋🏿' => 'паднятая рука: цёмны тон скуры',
    '🖖🏻' => 'вулканскі салют: светлы тон скуры',
    '🖖🏼' => 'вулканскі салют: сярэднясветлы тон скуры',
    '🖖🏽' => 'вулканскі салют: сярэдні тон скуры',
    '🖖🏾' => 'вулканскі салют: сярэдняцёмны тон скуры',
    '🖖🏿' => 'вулканскі салют: цёмны тон скуры',
    '🫱🏻' => 'рука направа: светлы тон скуры',
    '🫱🏼' => 'рука направа: сярэднясветлы тон скуры',
    '🫱🏽' => 'рука направа: сярэдні тон скуры',
    '🫱🏾' => 'рука направа: сярэдняцёмны тон скуры',
    '🫱🏿' => 'рука направа: цёмны тон скуры',
    '🫲🏻' => 'рука налева: светлы тон скуры',
    '🫲🏼' => 'рука налева: сярэднясветлы тон скуры',
    '🫲🏽' => 'рука налева: сярэдні тон скуры',
    '🫲🏾' => 'рука налева: сярэдняцёмны тон скуры',
    '🫲🏿' => 'рука налева: цёмны тон скуры',
    '🫳🏻' => 'рука далонню ўніз: светлы тон скуры',
    '🫳🏼' => 'рука далонню ўніз: сярэднясветлы тон скуры',
    '🫳🏽' => 'рука далонню ўніз: сярэдні тон скуры',
    '🫳🏾' => 'рука далонню ўніз: сярэдняцёмны тон скуры',
    '🫳🏿' => 'рука далонню ўніз: цёмны тон скуры',
    '🫴🏻' => 'рука далонню ўверх: светлы тон скуры',
    '🫴🏼' => 'рука далонню ўверх: сярэднясветлы тон скуры',
    '🫴🏽' => 'рука далонню ўверх: сярэдні тон скуры',
    '🫴🏾' => 'рука далонню ўверх: сярэдняцёмны тон скуры',
    '🫴🏿' => 'рука далонню ўверх: цёмны тон скуры',
    '🫷🏻' => 'рука штурхае ўлева: светлы тон скуры',
    '🫷🏼' => 'рука штурхае ўлева: сярэднясветлы тон скуры',
    '🫷🏽' => 'рука штурхае ўлева: сярэдні тон скуры',
    '🫷🏾' => 'рука штурхае ўлева: сярэдняцёмны тон скуры',
    '🫷🏿' => 'рука штурхае ўлева: цёмны тон скуры',
    '🫸🏻' => 'рука штурхае ўправа: светлы тон скуры',
    '🫸🏼' => 'рука штурхае ўправа: сярэднясветлы тон скуры',
    '🫸🏽' => 'рука штурхае ўправа: сярэдні тон скуры',
    '🫸🏾' => 'рука штурхае ўправа: сярэдняцёмны тон скуры',
    '🫸🏿' => 'рука штурхае ўправа: цёмны тон скуры',
    '👌🏻' => 'жэст «ОК»: светлы тон скуры',
    '👌🏼' => 'жэст «ОК»: сярэднясветлы тон скуры',
    '👌🏽' => 'жэст «ОК»: сярэдні тон скуры',
    '👌🏾' => 'жэст «ОК»: сярэдняцёмны тон скуры',
    '👌🏿' => 'жэст «ОК»: цёмны тон скуры',
    '🤌🏻' => 'зведзеныя пальцы: светлы тон скуры',
    '🤌🏼' => 'зведзеныя пальцы: сярэднясветлы тон скуры',
    '🤌🏽' => 'зведзеныя пальцы: сярэдні тон скуры',
    '🤌🏾' => 'зведзеныя пальцы: сярэдняцёмны тон скуры',
    '🤌🏿' => 'зведзеныя пальцы: цёмны тон скуры',
    '🤏🏻' => 'тры пальцы: светлы тон скуры',
    '🤏🏼' => 'тры пальцы: сярэднясветлы тон скуры',
    '🤏🏽' => 'тры пальцы: сярэдні тон скуры',
    '🤏🏾' => 'тры пальцы: сярэдняцёмны тон скуры',
    '🤏🏿' => 'тры пальцы: цёмны тон скуры',
    '✌🏻' => 'жэст перамогі: светлы тон скуры',
    '✌🏼' => 'жэст перамогі: сярэднясветлы тон скуры',
    '✌🏽' => 'жэст перамогі: сярэдні тон скуры',
    '✌🏾' => 'жэст перамогі: сярэдняцёмны тон скуры',
    '✌🏿' => 'жэст перамогі: цёмны тон скуры',
    '🤞🏻' => 'скрыжаваныя пальцы: светлы тон скуры',
    '🤞🏼' => 'скрыжаваныя пальцы: сярэднясветлы тон скуры',
    '🤞🏽' => 'скрыжаваныя пальцы: сярэдні тон скуры',
    '🤞🏾' => 'скрыжаваныя пальцы: сярэдняцёмны тон скуры',
    '🤞🏿' => 'скрыжаваныя пальцы: цёмны тон скуры',
    '🫰🏻' => 'рука са скрыжаванымі вялікім і ўказальным пальцамі: светлы тон скуры',
    '🫰🏼' => 'рука са скрыжаванымі вялікім і ўказальным пальцамі: сярэднясветлы тон скуры',
    '🫰🏽' => 'рука са скрыжаванымі вялікім і ўказальным пальцамі: сярэдні тон скуры',
    '🫰🏾' => 'рука са скрыжаванымі вялікім і ўказальным пальцамі: сярэдняцёмны тон скуры',
    '🫰🏿' => 'рука са скрыжаванымі вялікім і ўказальным пальцамі: цёмны тон скуры',
    '🤟🏻' => 'жэст «люблю цябе»: светлы тон скуры',
    '🤟🏼' => 'жэст «люблю цябе»: сярэднясветлы тон скуры',
    '🤟🏽' => 'жэст «люблю цябе»: сярэдні тон скуры',
    '🤟🏾' => 'жэст «люблю цябе»: сярэдняцёмны тон скуры',
    '🤟🏿' => 'жэст «люблю цябе»: цёмны тон скуры',
    '🤘🏻' => 'жэст «каза»: светлы тон скуры',
    '🤘🏼' => 'жэст «каза»: сярэднясветлы тон скуры',
    '🤘🏽' => 'жэст «каза»: сярэдні тон скуры',
    '🤘🏾' => 'жэст «каза»: сярэдняцёмны тон скуры',
    '🤘🏿' => 'жэст «каза»: цёмны тон скуры',
    '🤙🏻' => 'пазвані мне: светлы тон скуры',
    '🤙🏼' => 'пазвані мне: сярэднясветлы тон скуры',
    '🤙🏽' => 'пазвані мне: сярэдні тон скуры',
    '🤙🏾' => 'пазвані мне: сярэдняцёмны тон скуры',
    '🤙🏿' => 'пазвані мне: цёмны тон скуры',
    '👈🏻' => 'рука з указальным пальцам улева: светлы тон скуры',
    '👈🏼' => 'рука з указальным пальцам улева: сярэднясветлы тон скуры',
    '👈🏽' => 'рука з указальным пальцам улева: сярэдні тон скуры',
    '👈🏾' => 'рука з указальным пальцам улева: сярэдняцёмны тон скуры',
    '👈🏿' => 'рука з указальным пальцам улева: цёмны тон скуры',
    '👉🏻' => 'рука з указальным пальцам управа: светлы тон скуры',
    '👉🏼' => 'рука з указальным пальцам управа: сярэднясветлы тон скуры',
    '👉🏽' => 'рука з указальным пальцам управа: сярэдні тон скуры',
    '👉🏾' => 'рука з указальным пальцам управа: сярэдняцёмны тон скуры',
    '👉🏿' => 'рука з указальным пальцам управа: цёмны тон скуры',
    '👆🏻' => 'рука з указальным пальцам уверх: светлы тон скуры',
    '👆🏼' => 'рука з указальным пальцам уверх: сярэднясветлы тон скуры',
    '👆🏽' => 'рука з указальным пальцам уверх: сярэдні тон скуры',
    '👆🏾' => 'рука з указальным пальцам уверх: сярэдняцёмны тон скуры',
    '👆🏿' => 'рука з указальным пальцам уверх: цёмны тон скуры',
    '🖕🏻' => 'сярэдні палец: светлы тон скуры',
    '🖕🏼' => 'сярэдні палец: сярэднясветлы тон скуры',
    '🖕🏽' => 'сярэдні палец: сярэдні тон скуры',
    '🖕🏾' => 'сярэдні палец: сярэдняцёмны тон скуры',
    '🖕🏿' => 'сярэдні палец: цёмны тон скуры',
    '👇🏻' => 'рука з указальным пальцам уніз: светлы тон скуры',
    '👇🏼' => 'рука з указальным пальцам уніз: сярэднясветлы тон скуры',
    '👇🏽' => 'рука з указальным пальцам уніз: сярэдні тон скуры',
    '👇🏾' => 'рука з указальным пальцам уніз: сярэдняцёмны тон скуры',
    '👇🏿' => 'рука з указальным пальцам уніз: цёмны тон скуры',
    '☝🏻' => 'указальны палец уверх: светлы тон скуры',
    '☝🏼' => 'указальны палец уверх: сярэднясветлы тон скуры',
    '☝🏽' => 'указальны палец уверх: сярэдні тон скуры',
    '☝🏾' => 'указальны палец уверх: сярэдняцёмны тон скуры',
    '☝🏿' => 'указальны палец уверх: цёмны тон скуры',
    '🫵🏻' => 'указальны палец накіраваны на гледача: светлы тон скуры',
    '🫵🏼' => 'указальны палец накіраваны на гледача: сярэднясветлы тон скуры',
    '🫵🏽' => 'указальны палец накіраваны на гледача: сярэдні тон скуры',
    '🫵🏾' => 'указальны палец накіраваны на гледача: сярэдняцёмны тон скуры',
    '🫵🏿' => 'указальны палец накіраваны на гледача: цёмны тон скуры',
    '👍🏻' => 'вялікі палец уверх: светлы тон скуры',
    '👍🏼' => 'вялікі палец уверх: сярэднясветлы тон скуры',
    '👍🏽' => 'вялікі палец уверх: сярэдні тон скуры',
    '👍🏾' => 'вялікі палец уверх: сярэдняцёмны тон скуры',
    '👍🏿' => 'вялікі палец уверх: цёмны тон скуры',
    '👎🏻' => 'вялікі палец уніз: светлы тон скуры',
    '👎🏼' => 'вялікі палец уніз: сярэднясветлы тон скуры',
    '👎🏽' => 'вялікі палец уніз: сярэдні тон скуры',
    '👎🏾' => 'вялікі палец уніз: сярэдняцёмны тон скуры',
    '👎🏿' => 'вялікі палец уніз: цёмны тон скуры',
    '✊🏻' => 'падняты кулак: светлы тон скуры',
    '✊🏼' => 'падняты кулак: сярэднясветлы тон скуры',
    '✊🏽' => 'падняты кулак: сярэдні тон скуры',
    '✊🏾' => 'падняты кулак: сярэдняцёмны тон скуры',
    '✊🏿' => 'падняты кулак: цёмны тон скуры',
    '👊🏻' => 'ляціць кулак: светлы тон скуры',
    '👊🏼' => 'ляціць кулак: сярэднясветлы тон скуры',
    '👊🏽' => 'ляціць кулак: сярэдні тон скуры',
    '👊🏾' => 'ляціць кулак: сярэдняцёмны тон скуры',
    '👊🏿' => 'ляціць кулак: цёмны тон скуры',
    '🤛🏻' => 'кулак улева: светлы тон скуры',
    '🤛🏼' => 'кулак улева: сярэднясветлы тон скуры',
    '🤛🏽' => 'кулак улева: сярэдні тон скуры',
    '🤛🏾' => 'кулак улева: сярэдняцёмны тон скуры',
    '🤛🏿' => 'кулак улева: цёмны тон скуры',
    '🤜🏻' => 'кулак управа: светлы тон скуры',
    '🤜🏼' => 'кулак управа: сярэднясветлы тон скуры',
    '🤜🏽' => 'кулак управа: сярэдні тон скуры',
    '🤜🏾' => 'кулак управа: сярэдняцёмны тон скуры',
    '🤜🏿' => 'кулак управа: цёмны тон скуры',
    '👏🏻' => 'пляскае ў ладкі: светлы тон скуры',
    '👏🏼' => 'пляскае ў ладкі: сярэднясветлы тон скуры',
    '👏🏽' => 'пляскае ў ладкі: сярэдні тон скуры',
    '👏🏾' => 'пляскае ў ладкі: сярэдняцёмны тон скуры',
    '👏🏿' => 'пляскае ў ладкі: цёмны тон скуры',
    '🙌🏻' => 'чалавек паднімае рукі: светлы тон скуры',
    '🙌🏼' => 'чалавек паднімае рукі: сярэднясветлы тон скуры',
    '🙌🏽' => 'чалавек паднімае рукі: сярэдні тон скуры',
    '🙌🏾' => 'чалавек паднімае рукі: сярэдняцёмны тон скуры',
    '🙌🏿' => 'чалавек паднімае рукі: цёмны тон скуры',
    '🫶🏻' => 'рукі ў форме сэрца: светлы тон скуры',
    '🫶🏼' => 'рукі ў форме сэрца: сярэднясветлы тон скуры',
    '🫶🏽' => 'рукі ў форме сэрца: сярэдні тон скуры',
    '🫶🏾' => 'рукі ў форме сэрца: сярэдняцёмны тон скуры',
    '🫶🏿' => 'рукі ў форме сэрца: цёмны тон скуры',
    '👐🏻' => 'адкрытыя рукі: светлы тон скуры',
    '👐🏼' => 'адкрытыя рукі: сярэднясветлы тон скуры',
    '👐🏽' => 'адкрытыя рукі: сярэдні тон скуры',
    '👐🏾' => 'адкрытыя рукі: сярэдняцёмны тон скуры',
    '👐🏿' => 'адкрытыя рукі: цёмны тон скуры',
    '🤲🏻' => 'складзеныя разам далоні: светлы тон скуры',
    '🤲🏼' => 'складзеныя разам далоні: сярэднясветлы тон скуры',
    '🤲🏽' => 'складзеныя разам далоні: сярэдні тон скуры',
    '🤲🏾' => 'складзеныя разам далоні: сярэдняцёмны тон скуры',
    '🤲🏿' => 'складзеныя разам далоні: цёмны тон скуры',
    '🤝🏻' => 'поціск рук: светлы тон скуры',
    '🤝🏼' => 'поціск рук: сярэднясветлы тон скуры',
    '🤝🏽' => 'поціск рук: сярэдні тон скуры',
    '🤝🏾' => 'поціск рук: сярэдняцёмны тон скуры',
    '🤝🏿' => 'поціск рук: цёмны тон скуры',
    '🙏🏻' => 'складзеныя рукі: светлы тон скуры',
    '🙏🏼' => 'складзеныя рукі: сярэднясветлы тон скуры',
    '🙏🏽' => 'складзеныя рукі: сярэдні тон скуры',
    '🙏🏾' => 'складзеныя рукі: сярэдняцёмны тон скуры',
    '🙏🏿' => 'складзеныя рукі: цёмны тон скуры',
    '✍🏻' => 'пішучая рука: светлы тон скуры',
    '✍🏼' => 'пішучая рука: сярэднясветлы тон скуры',
    '✍🏽' => 'пішучая рука: сярэдні тон скуры',
    '✍🏾' => 'пішучая рука: сярэдняцёмны тон скуры',
    '✍🏿' => 'пішучая рука: цёмны тон скуры',
    '💅🏻' => 'лак для ногцяў: светлы тон скуры',
    '💅🏼' => 'лак для ногцяў: сярэднясветлы тон скуры',
    '💅🏽' => 'лак для ногцяў: сярэдні тон скуры',
    '💅🏾' => 'лак для ногцяў: сярэдняцёмны тон скуры',
    '💅🏿' => 'лак для ногцяў: цёмны тон скуры',
    '🤳🏻' => 'сэлфі: светлы тон скуры',
    '🤳🏼' => 'сэлфі: сярэднясветлы тон скуры',
    '🤳🏽' => 'сэлфі: сярэдні тон скуры',
    '🤳🏾' => 'сэлфі: сярэдняцёмны тон скуры',
    '🤳🏿' => 'сэлфі: цёмны тон скуры',
    '💪🏻' => 'дэманстрацыя біцэпса: светлы тон скуры',
    '💪🏼' => 'дэманстрацыя біцэпса: сярэднясветлы тон скуры',
    '💪🏽' => 'дэманстрацыя біцэпса: сярэдні тон скуры',
    '💪🏾' => 'дэманстрацыя біцэпса: сярэдняцёмны тон скуры',
    '💪🏿' => 'дэманстрацыя біцэпса: цёмны тон скуры',
    '🦵🏻' => 'нага: светлы тон скуры',
    '🦵🏼' => 'нага: сярэднясветлы тон скуры',
    '🦵🏽' => 'нага: сярэдні тон скуры',
    '🦵🏾' => 'нага: сярэдняцёмны тон скуры',
    '🦵🏿' => 'нага: цёмны тон скуры',
    '🦶🏻' => 'ступня: светлы тон скуры',
    '🦶🏼' => 'ступня: сярэднясветлы тон скуры',
    '🦶🏽' => 'ступня: сярэдні тон скуры',
    '🦶🏾' => 'ступня: сярэдняцёмны тон скуры',
    '🦶🏿' => 'ступня: цёмны тон скуры',
    '👂🏻' => 'вуха: светлы тон скуры',
    '👂🏼' => 'вуха: сярэднясветлы тон скуры',
    '👂🏽' => 'вуха: сярэдні тон скуры',
    '👂🏾' => 'вуха: сярэдняцёмны тон скуры',
    '👂🏿' => 'вуха: цёмны тон скуры',
    '🦻🏻' => 'вуха са слыхавым апаратам: светлы тон скуры',
    '🦻🏼' => 'вуха са слыхавым апаратам: сярэднясветлы тон скуры',
    '🦻🏽' => 'вуха са слыхавым апаратам: сярэдні тон скуры',
    '🦻🏾' => 'вуха са слыхавым апаратам: сярэдняцёмны тон скуры',
    '🦻🏿' => 'вуха са слыхавым апаратам: цёмны тон скуры',
    '👃🏻' => 'нос: светлы тон скуры',
    '👃🏼' => 'нос: сярэднясветлы тон скуры',
    '👃🏽' => 'нос: сярэдні тон скуры',
    '👃🏾' => 'нос: сярэдняцёмны тон скуры',
    '👃🏿' => 'нос: цёмны тон скуры',
    '👶🏻' => 'немаўля: светлы тон скуры',
    '👶🏼' => 'немаўля: сярэднясветлы тон скуры',
    '👶🏽' => 'немаўля: сярэдні тон скуры',
    '👶🏾' => 'немаўля: сярэдняцёмны тон скуры',
    '👶🏿' => 'немаўля: цёмны тон скуры',
    '🧒🏻' => 'дзіця: светлы тон скуры',
    '🧒🏼' => 'дзіця: сярэднясветлы тон скуры',
    '🧒🏽' => 'дзіця: сярэдні тон скуры',
    '🧒🏾' => 'дзіця: сярэдняцёмны тон скуры',
    '🧒🏿' => 'дзіця: цёмны тон скуры',
    '👦🏻' => 'хлопчык: светлы тон скуры',
    '👦🏼' => 'хлопчык: сярэднясветлы тон скуры',
    '👦🏽' => 'хлопчык: сярэдні тон скуры',
    '👦🏾' => 'хлопчык: сярэдняцёмны тон скуры',
    '👦🏿' => 'хлопчык: цёмны тон скуры',
    '👧🏻' => 'дзяўчынка: светлы тон скуры',
    '👧🏼' => 'дзяўчынка: сярэднясветлы тон скуры',
    '👧🏽' => 'дзяўчынка: сярэдні тон скуры',
    '👧🏾' => 'дзяўчынка: сярэдняцёмны тон скуры',
    '👧🏿' => 'дзяўчынка: цёмны тон скуры',
    '🧑🏻' => 'дарослы: светлы тон скуры',
    '🧑🏼' => 'дарослы: сярэднясветлы тон скуры',
    '🧑🏽' => 'дарослы: сярэдні тон скуры',
    '🧑🏾' => 'дарослы: сярэдняцёмны тон скуры',
    '🧑🏿' => 'дарослы: цёмны тон скуры',
    '👱🏻' => 'бялявы чалавек: светлы тон скуры',
    '👱🏼' => 'бялявы чалавек: сярэднясветлы тон скуры',
    '👱🏽' => 'бялявы чалавек: сярэдні тон скуры',
    '👱🏾' => 'бялявы чалавек: сярэдняцёмны тон скуры',
    '👱🏿' => 'бялявы чалавек: цёмны тон скуры',
    '👨🏻' => 'мужчына: светлы тон скуры',
    '👨🏼' => 'мужчына: сярэднясветлы тон скуры',
    '👨🏽' => 'мужчына: сярэдні тон скуры',
    '👨🏾' => 'мужчына: сярэдняцёмны тон скуры',
    '👨🏿' => 'мужчына: цёмны тон скуры',
    '🧔🏻' => 'чалавек з барадой: светлы тон скуры',
    '🧔🏼' => 'чалавек з барадой: сярэднясветлы тон скуры',
    '🧔🏽' => 'чалавек з барадой: сярэдні тон скуры',
    '🧔🏾' => 'чалавек з барадой: сярэдняцёмны тон скуры',
    '🧔🏿' => 'чалавек з барадой: цёмны тон скуры',
    '👩🏻' => 'жанчына: светлы тон скуры',
    '👩🏼' => 'жанчына: сярэднясветлы тон скуры',
    '👩🏽' => 'жанчына: сярэдні тон скуры',
    '👩🏾' => 'жанчына: сярэдняцёмны тон скуры',
    '👩🏿' => 'жанчына: цёмны тон скуры',
    '🧓🏻' => 'у гадах: светлы тон скуры',
    '🧓🏼' => 'у гадах: сярэднясветлы тон скуры',
    '🧓🏽' => 'у гадах: сярэдні тон скуры',
    '🧓🏾' => 'у гадах: сярэдняцёмны тон скуры',
    '🧓🏿' => 'у гадах: цёмны тон скуры',
    '👴🏻' => 'дзядуля: светлы тон скуры',
    '👴🏼' => 'дзядуля: сярэднясветлы тон скуры',
    '👴🏽' => 'дзядуля: сярэдні тон скуры',
    '👴🏾' => 'дзядуля: сярэдняцёмны тон скуры',
    '👴🏿' => 'дзядуля: цёмны тон скуры',
    '👵🏻' => 'бабуля: светлы тон скуры',
    '👵🏼' => 'бабуля: сярэднясветлы тон скуры',
    '👵🏽' => 'бабуля: сярэдні тон скуры',
    '👵🏾' => 'бабуля: сярэдняцёмны тон скуры',
    '👵🏿' => 'бабуля: цёмны тон скуры',
    '🙍🏻' => 'засмучаны чалавек: светлы тон скуры',
    '🙍🏼' => 'засмучаны чалавек: сярэднясветлы тон скуры',
    '🙍🏽' => 'засмучаны чалавек: сярэдні тон скуры',
    '🙍🏾' => 'засмучаны чалавек: сярэдняцёмны тон скуры',
    '🙍🏿' => 'засмучаны чалавек: цёмны тон скуры',
    '🙎🏻' => 'надзьмуты чалавек: светлы тон скуры',
    '🙎🏼' => 'надзьмуты чалавек: сярэднясветлы тон скуры',
    '🙎🏽' => 'надзьмуты чалавек: сярэдні тон скуры',
    '🙎🏾' => 'надзьмуты чалавек: сярэдняцёмны тон скуры',
    '🙎🏿' => 'надзьмуты чалавек: цёмны тон скуры',
    '🙅🏻' => 'чалавек супраць: светлы тон скуры',
    '🙅🏼' => 'чалавек супраць: сярэднясветлы тон скуры',
    '🙅🏽' => 'чалавек супраць: сярэдні тон скуры',
    '🙅🏾' => 'чалавек супраць: сярэдняцёмны тон скуры',
    '🙅🏿' => 'чалавек супраць: цёмны тон скуры',
    '🙆🏻' => 'чалавек паказвае згоду: светлы тон скуры',
    '🙆🏼' => 'чалавек паказвае згоду: сярэднясветлы тон скуры',
    '🙆🏽' => 'чалавек паказвае згоду: сярэдні тон скуры',
    '🙆🏾' => 'чалавек паказвае згоду: сярэдняцёмны тон скуры',
    '🙆🏿' => 'чалавек паказвае згоду: цёмны тон скуры',
    '💁🏻' => 'чалавек трасе рукой: светлы тон скуры',
    '💁🏼' => 'чалавек трасе рукой: сярэднясветлы тон скуры',
    '💁🏽' => 'чалавек трасе рукой: сярэдні тон скуры',
    '💁🏾' => 'чалавек трасе рукой: сярэдняцёмны тон скуры',
    '💁🏿' => 'чалавек трасе рукой: цёмны тон скуры',
    '🙋🏻' => 'чалавек цягне руку: светлы тон скуры',
    '🙋🏼' => 'чалавек цягне руку: сярэднясветлы тон скуры',
    '🙋🏽' => 'чалавек цягне руку: сярэдні тон скуры',
    '🙋🏾' => 'чалавек цягне руку: сярэдняцёмны тон скуры',
    '🙋🏿' => 'чалавек цягне руку: цёмны тон скуры',
    '🧏🏻' => 'глухі чалавек: светлы тон скуры',
    '🧏🏼' => 'глухі чалавек: сярэднясветлы тон скуры',
    '🧏🏽' => 'глухі чалавек: сярэдні тон скуры',
    '🧏🏾' => 'глухі чалавек: сярэдняцёмны тон скуры',
    '🧏🏿' => 'глухі чалавек: цёмны тон скуры',
    '🙇🏻' => 'чалавек кланяецца: светлы тон скуры',
    '🙇🏼' => 'чалавек кланяецца: сярэднясветлы тон скуры',
    '🙇🏽' => 'чалавек кланяецца: сярэдні тон скуры',
    '🙇🏾' => 'чалавек кланяецца: сярэдняцёмны тон скуры',
    '🙇🏿' => 'чалавек кланяецца: цёмны тон скуры',
    '🤦🏻' => 'далонь на твары: светлы тон скуры',
    '🤦🏼' => 'далонь на твары: сярэднясветлы тон скуры',
    '🤦🏽' => 'далонь на твары: сярэдні тон скуры',
    '🤦🏾' => 'далонь на твары: сярэдняцёмны тон скуры',
    '🤦🏿' => 'далонь на твары: цёмны тон скуры',
    '🤷🏻' => 'паціскае плячыма: светлы тон скуры',
    '🤷🏼' => 'паціскае плячыма: сярэднясветлы тон скуры',
    '🤷🏽' => 'паціскае плячыма: сярэдні тон скуры',
    '🤷🏾' => 'паціскае плячыма: сярэдняцёмны тон скуры',
    '🤷🏿' => 'паціскае плячыма: цёмны тон скуры',
    '👮🏻' => 'паліцыянт: светлы тон скуры',
    '👮🏼' => 'паліцыянт: сярэднясветлы тон скуры',
    '👮🏽' => 'паліцыянт: сярэдні тон скуры',
    '👮🏾' => 'паліцыянт: сярэдняцёмны тон скуры',
    '👮🏿' => 'паліцыянт: цёмны тон скуры',
    '🕵🏻' => 'дэтэктыў: светлы тон скуры',
    '🕵🏼' => 'дэтэктыў: сярэднясветлы тон скуры',
    '🕵🏽' => 'дэтэктыў: сярэдні тон скуры',
    '🕵🏾' => 'дэтэктыў: сярэдняцёмны тон скуры',
    '🕵🏿' => 'дэтэктыў: цёмны тон скуры',
    '💂🏻' => 'варта: светлы тон скуры',
    '💂🏼' => 'варта: сярэднясветлы тон скуры',
    '💂🏽' => 'варта: сярэдні тон скуры',
    '💂🏾' => 'варта: сярэдняцёмны тон скуры',
    '💂🏿' => 'варта: цёмны тон скуры',
    '🥷🏻' => 'ніндзя: светлы тон скуры',
    '🥷🏼' => 'ніндзя: сярэднясветлы тон скуры',
    '🥷🏽' => 'ніндзя: сярэдні тон скуры',
    '🥷🏾' => 'ніндзя: сярэдняцёмны тон скуры',
    '🥷🏿' => 'ніндзя: цёмны тон скуры',
    '👷🏻' => 'будаўнік: светлы тон скуры',
    '👷🏼' => 'будаўнік: сярэднясветлы тон скуры',
    '👷🏽' => 'будаўнік: сярэдні тон скуры',
    '👷🏾' => 'будаўнік: сярэдняцёмны тон скуры',
    '👷🏿' => 'будаўнік: цёмны тон скуры',
    '🫅🏻' => 'чалавек з каронай: светлы тон скуры',
    '🫅🏼' => 'чалавек з каронай: сярэднясветлы тон скуры',
    '🫅🏽' => 'чалавек з каронай: сярэдні тон скуры',
    '🫅🏾' => 'чалавек з каронай: сярэдняцёмны тон скуры',
    '🫅🏿' => 'чалавек з каронай: цёмны тон скуры',
    '🤴🏻' => 'прынц: светлы тон скуры',
    '🤴🏼' => 'прынц: сярэднясветлы тон скуры',
    '🤴🏽' => 'прынц: сярэдні тон скуры',
    '🤴🏾' => 'прынц: сярэдняцёмны тон скуры',
    '🤴🏿' => 'прынц: цёмны тон скуры',
    '👸🏻' => 'прынцэса: светлы тон скуры',
    '👸🏼' => 'прынцэса: сярэднясветлы тон скуры',
    '👸🏽' => 'прынцэса: сярэдні тон скуры',
    '👸🏾' => 'прынцэса: сярэдняцёмны тон скуры',
    '👸🏿' => 'прынцэса: цёмны тон скуры',
    '👳🏻' => 'чалавек у турбане: светлы тон скуры',
    '👳🏼' => 'чалавек у турбане: сярэднясветлы тон скуры',
    '👳🏽' => 'чалавек у турбане: сярэдні тон скуры',
    '👳🏾' => 'чалавек у турбане: сярэдняцёмны тон скуры',
    '👳🏿' => 'чалавек у турбане: цёмны тон скуры',
    '👲🏻' => 'мужчына ў кітайскай шапачцы: светлы тон скуры',
    '👲🏼' => 'мужчына ў кітайскай шапачцы: сярэднясветлы тон скуры',
    '👲🏽' => 'мужчына ў кітайскай шапачцы: сярэдні тон скуры',
    '👲🏾' => 'мужчына ў кітайскай шапачцы: сярэдняцёмны тон скуры',
    '👲🏿' => 'мужчына ў кітайскай шапачцы: цёмны тон скуры',
    '🧕🏻' => 'жанчына ў хустцы: светлы тон скуры',
    '🧕🏼' => 'жанчына ў хустцы: сярэднясветлы тон скуры',
    '🧕🏽' => 'жанчына ў хустцы: сярэдні тон скуры',
    '🧕🏾' => 'жанчына ў хустцы: сярэдняцёмны тон скуры',
    '🧕🏿' => 'жанчына ў хустцы: цёмны тон скуры',
    '🤵🏻' => 'чалавек у смокінгу: светлы тон скуры',
    '🤵🏼' => 'чалавек у смокінгу: сярэднясветлы тон скуры',
    '🤵🏽' => 'чалавек у смокінгу: сярэдні тон скуры',
    '🤵🏾' => 'чалавек у смокінгу: сярэдняцёмны тон скуры',
    '🤵🏿' => 'чалавек у смокінгу: цёмны тон скуры',
    '👰🏻' => 'нявеста ў вэлюме: светлы тон скуры',
    '👰🏼' => 'нявеста ў вэлюме: сярэднясветлы тон скуры',
    '👰🏽' => 'нявеста ў вэлюме: сярэдні тон скуры',
    '👰🏾' => 'нявеста ў вэлюме: сярэдняцёмны тон скуры',
    '👰🏿' => 'нявеста ў вэлюме: цёмны тон скуры',
    '🤰🏻' => 'цяжарная: светлы тон скуры',
    '🤰🏼' => 'цяжарная: сярэднясветлы тон скуры',
    '🤰🏽' => 'цяжарная: сярэдні тон скуры',
    '🤰🏾' => 'цяжарная: сярэдняцёмны тон скуры',
    '🤰🏿' => 'цяжарная: цёмны тон скуры',
    '🫃🏻' => 'цяжарны мужчына: светлы тон скуры',
    '🫃🏼' => 'цяжарны мужчына: сярэднясветлы тон скуры',
    '🫃🏽' => 'цяжарны мужчына: сярэдні тон скуры',
    '🫃🏾' => 'цяжарны мужчына: сярэдняцёмны тон скуры',
    '🫃🏿' => 'цяжарны мужчына: цёмны тон скуры',
    '🫄🏻' => 'цяжарны чалавек: светлы тон скуры',
    '🫄🏼' => 'цяжарны чалавек: сярэднясветлы тон скуры',
    '🫄🏽' => 'цяжарны чалавек: сярэдні тон скуры',
    '🫄🏾' => 'цяжарны чалавек: сярэдняцёмны тон скуры',
    '🫄🏿' => 'цяжарны чалавек: цёмны тон скуры',
    '🤱🏻' => 'кормячая маці: светлы тон скуры',
    '🤱🏼' => 'кормячая маці: сярэднясветлы тон скуры',
    '🤱🏽' => 'кормячая маці: сярэдні тон скуры',
    '🤱🏾' => 'кормячая маці: сярэдняцёмны тон скуры',
    '🤱🏿' => 'кормячая маці: цёмны тон скуры',
    '👼🏻' => 'анёлак: светлы тон скуры',
    '👼🏼' => 'анёлак: сярэднясветлы тон скуры',
    '👼🏽' => 'анёлак: сярэдні тон скуры',
    '👼🏾' => 'анёлак: сярэдняцёмны тон скуры',
    '👼🏿' => 'анёлак: цёмны тон скуры',
    '🎅🏻' => 'Санта Клаус: светлы тон скуры',
    '🎅🏼' => 'Санта Клаус: сярэднясветлы тон скуры',
    '🎅🏽' => 'Санта Клаус: сярэдні тон скуры',
    '🎅🏾' => 'Санта Клаус: сярэдняцёмны тон скуры',
    '🎅🏿' => 'Санта Клаус: цёмны тон скуры',
    '🤶🏻' => 'місіс Клаус: светлы тон скуры',
    '🤶🏼' => 'місіс Клаус: сярэднясветлы тон скуры',
    '🤶🏽' => 'місіс Клаус: сярэдні тон скуры',
    '🤶🏾' => 'місіс Клаус: сярэдняцёмны тон скуры',
    '🤶🏿' => 'місіс Клаус: цёмны тон скуры',
    '🦸🏻' => 'супергерой: светлы тон скуры',
    '🦸🏼' => 'супергерой: сярэднясветлы тон скуры',
    '🦸🏽' => 'супергерой: сярэдні тон скуры',
    '🦸🏾' => 'супергерой: сярэдняцёмны тон скуры',
    '🦸🏿' => 'супергерой: цёмны тон скуры',
    '🦹🏻' => 'суперзлачынца: светлы тон скуры',
    '🦹🏼' => 'суперзлачынца: сярэднясветлы тон скуры',
    '🦹🏽' => 'суперзлачынца: сярэдні тон скуры',
    '🦹🏾' => 'суперзлачынца: сярэдняцёмны тон скуры',
    '🦹🏿' => 'суперзлачынца: цёмны тон скуры',
    '🧙🏻' => 'чараўнік: светлы тон скуры',
    '🧙🏼' => 'чараўнік: сярэднясветлы тон скуры',
    '🧙🏽' => 'чараўнік: сярэдні тон скуры',
    '🧙🏾' => 'чараўнік: сярэдняцёмны тон скуры',
    '🧙🏿' => 'чараўнік: цёмны тон скуры',
    '🧚🏻' => 'фея: светлы тон скуры',
    '🧚🏼' => 'фея: сярэднясветлы тон скуры',
    '🧚🏽' => 'фея: сярэдні тон скуры',
    '🧚🏾' => 'фея: сярэдняцёмны тон скуры',
    '🧚🏿' => 'фея: цёмны тон скуры',
    '🧛🏻' => 'вампір: светлы тон скуры',
    '🧛🏼' => 'вампір: сярэднясветлы тон скуры',
    '🧛🏽' => 'вампір: сярэдні тон скуры',
    '🧛🏾' => 'вампір: сярэдняцёмны тон скуры',
    '🧛🏿' => 'вампір: цёмны тон скуры',
    '🧜🏻' => 'русалкі: светлы тон скуры',
    '🧜🏼' => 'русалкі: сярэднясветлы тон скуры',
    '🧜🏽' => 'русалкі: сярэдні тон скуры',
    '🧜🏾' => 'русалкі: сярэдняцёмны тон скуры',
    '🧜🏿' => 'русалкі: цёмны тон скуры',
    '🧝🏻' => 'эльф: светлы тон скуры',
    '🧝🏼' => 'эльф: сярэднясветлы тон скуры',
    '🧝🏽' => 'эльф: сярэдні тон скуры',
    '🧝🏾' => 'эльф: сярэдняцёмны тон скуры',
    '🧝🏿' => 'эльф: цёмны тон скуры',
    '💆🏻' => 'чалавека масажуюць: светлы тон скуры',
    '💆🏼' => 'чалавека масажуюць: сярэднясветлы тон скуры',
    '💆🏽' => 'чалавека масажуюць: сярэдні тон скуры',
    '💆🏾' => 'чалавека масажуюць: сярэдняцёмны тон скуры',
    '💆🏿' => 'чалавека масажуюць: цёмны тон скуры',
    '💇🏻' => 'чалавеку стрыгуць валоссе: светлы тон скуры',
    '💇🏼' => 'чалавеку стрыгуць валоссе: сярэднясветлы тон скуры',
    '💇🏽' => 'чалавеку стрыгуць валоссе: сярэдні тон скуры',
    '💇🏾' => 'чалавеку стрыгуць валоссе: сярэдняцёмны тон скуры',
    '💇🏿' => 'чалавеку стрыгуць валоссе: цёмны тон скуры',
    '🚶🏻' => 'чалавек ідзе: светлы тон скуры',
    '🚶🏼' => 'чалавек ідзе: сярэднясветлы тон скуры',
    '🚶🏽' => 'чалавек ідзе: сярэдні тон скуры',
    '🚶🏾' => 'чалавек ідзе: сярэдняцёмны тон скуры',
    '🚶🏿' => 'чалавек ідзе: цёмны тон скуры',
    '🧍🏻' => 'чалавек стаіць: светлы тон скуры',
    '🧍🏼' => 'чалавек стаіць: сярэднясветлы тон скуры',
    '🧍🏽' => 'чалавек стаіць: сярэдні тон скуры',
    '🧍🏾' => 'чалавек стаіць: сярэдняцёмны тон скуры',
    '🧍🏿' => 'чалавек стаіць: цёмны тон скуры',
    '🧎🏻' => 'чалавек на каленях: светлы тон скуры',
    '🧎🏼' => 'чалавек на каленях: сярэднясветлы тон скуры',
    '🧎🏽' => 'чалавек на каленях: сярэдні тон скуры',
    '🧎🏾' => 'чалавек на каленях: сярэдняцёмны тон скуры',
    '🧎🏿' => 'чалавек на каленях: цёмны тон скуры',
    '🏃🏻' => 'чалавек бяжыць: светлы тон скуры',
    '🏃🏼' => 'чалавек бяжыць: сярэднясветлы тон скуры',
    '🏃🏽' => 'чалавек бяжыць: сярэдні тон скуры',
    '🏃🏾' => 'чалавек бяжыць: сярэдняцёмны тон скуры',
    '🏃🏿' => 'чалавек бяжыць: цёмны тон скуры',
    '💃🏻' => 'танцорка: светлы тон скуры',
    '💃🏼' => 'танцорка: сярэднясветлы тон скуры',
    '💃🏽' => 'танцорка: сярэдні тон скуры',
    '💃🏾' => 'танцорка: сярэдняцёмны тон скуры',
    '💃🏿' => 'танцорка: цёмны тон скуры',
    '🕺🏻' => 'танцор: светлы тон скуры',
    '🕺🏼' => 'танцор: сярэднясветлы тон скуры',
    '🕺🏽' => 'танцор: сярэдні тон скуры',
    '🕺🏾' => 'танцор: сярэдняцёмны тон скуры',
    '🕺🏿' => 'танцор: цёмны тон скуры',
    '🕴🏻' => 'мужчына ў дзелавым касцюме левітуе: светлы тон скуры',
    '🕴🏼' => 'мужчына ў дзелавым касцюме левітуе: сярэднясветлы тон скуры',
    '🕴🏽' => 'мужчына ў дзелавым касцюме левітуе: сярэдні тон скуры',
    '🕴🏾' => 'мужчына ў дзелавым касцюме левітуе: сярэдняцёмны тон скуры',
    '🕴🏿' => 'мужчына ў дзелавым касцюме левітуе: цёмны тон скуры',
    '👯🏻' => 'людзі весяляцца: светлы тон скуры',
    '👯🏼' => 'людзі весяляцца: сярэднясветлы тон скуры',
    '👯🏽' => 'людзі весяляцца: сярэдні тон скуры',
    '👯🏾' => 'людзі весяляцца: сярэдняцёмны тон скуры',
    '👯🏿' => 'людзі весяляцца: цёмны тон скуры',
    '🧖🏻' => 'чалавек у лазні: светлы тон скуры',
    '🧖🏼' => 'чалавек у лазні: сярэднясветлы тон скуры',
    '🧖🏽' => 'чалавек у лазні: сярэдні тон скуры',
    '🧖🏾' => 'чалавек у лазні: сярэдняцёмны тон скуры',
    '🧖🏿' => 'чалавек у лазні: цёмны тон скуры',
    '🧗🏻' => 'чалавек падымаецца на гару: светлы тон скуры',
    '🧗🏼' => 'чалавек падымаецца на гару: сярэднясветлы тон скуры',
    '🧗🏽' => 'чалавек падымаецца на гару: сярэдні тон скуры',
    '🧗🏾' => 'чалавек падымаецца на гару: сярэдняцёмны тон скуры',
    '🧗🏿' => 'чалавек падымаецца на гару: цёмны тон скуры',
    '🏇🏻' => 'скачкі: светлы тон скуры',
    '🏇🏼' => 'скачкі: сярэднясветлы тон скуры',
    '🏇🏽' => 'скачкі: сярэдні тон скуры',
    '🏇🏾' => 'скачкі: сярэдняцёмны тон скуры',
    '🏇🏿' => 'скачкі: цёмны тон скуры',
    '🏂🏻' => 'снаўбардыст: светлы тон скуры',
    '🏂🏼' => 'снаўбардыст: сярэднясветлы тон скуры',
    '🏂🏽' => 'снаўбардыст: сярэдні тон скуры',
    '🏂🏾' => 'снаўбардыст: сярэдняцёмны тон скуры',
    '🏂🏿' => 'снаўбардыст: цёмны тон скуры',
    '🏌🏻' => 'чалавек гуляе ў гольф: светлы тон скуры',
    '🏌🏼' => 'чалавек гуляе ў гольф: сярэднясветлы тон скуры',
    '🏌🏽' => 'чалавек гуляе ў гольф: сярэдні тон скуры',
    '🏌🏾' => 'чалавек гуляе ў гольф: сярэдняцёмны тон скуры',
    '🏌🏿' => 'чалавек гуляе ў гольф: цёмны тон скуры',
    '🏄🏻' => 'сёрфінг: светлы тон скуры',
    '🏄🏼' => 'сёрфінг: сярэднясветлы тон скуры',
    '🏄🏽' => 'сёрфінг: сярэдні тон скуры',
    '🏄🏾' => 'сёрфінг: сярэдняцёмны тон скуры',
    '🏄🏿' => 'сёрфінг: цёмны тон скуры',
    '🚣🏻' => 'веславанне: светлы тон скуры',
    '🚣🏼' => 'веславанне: сярэднясветлы тон скуры',
    '🚣🏽' => 'веславанне: сярэдні тон скуры',
    '🚣🏾' => 'веславанне: сярэдняцёмны тон скуры',
    '🚣🏿' => 'веславанне: цёмны тон скуры',
    '🏊🏻' => 'чалавек плыве: светлы тон скуры',
    '🏊🏼' => 'чалавек плыве: сярэднясветлы тон скуры',
    '🏊🏽' => 'чалавек плыве: сярэдні тон скуры',
    '🏊🏾' => 'чалавек плыве: сярэдняцёмны тон скуры',
    '🏊🏿' => 'чалавек плыве: цёмны тон скуры',
    '⛹🏻' => 'чалавек з мячом: светлы тон скуры',
    '⛹🏼' => 'чалавек з мячом: сярэднясветлы тон скуры',
    '⛹🏽' => 'чалавек з мячом: сярэдні тон скуры',
    '⛹🏾' => 'чалавек з мячом: сярэдняцёмны тон скуры',
    '⛹🏿' => 'чалавек з мячом: цёмны тон скуры',
    '🏋🏻' => 'чалавек са штангай: светлы тон скуры',
    '🏋🏼' => 'чалавек са штангай: сярэднясветлы тон скуры',
    '🏋🏽' => 'чалавек са штангай: сярэдні тон скуры',
    '🏋🏾' => 'чалавек са штангай: сярэдняцёмны тон скуры',
    '🏋🏿' => 'чалавек са штангай: цёмны тон скуры',
    '🚴🏻' => 'чалавек на веласіпедзе: светлы тон скуры',
    '🚴🏼' => 'чалавек на веласіпедзе: сярэднясветлы тон скуры',
    '🚴🏽' => 'чалавек на веласіпедзе: сярэдні тон скуры',
    '🚴🏾' => 'чалавек на веласіпедзе: сярэдняцёмны тон скуры',
    '🚴🏿' => 'чалавек на веласіпедзе: цёмны тон скуры',
    '🚵🏻' => 'чалавек на горным веласіпедзе: светлы тон скуры',
    '🚵🏼' => 'чалавек на горным веласіпедзе: сярэднясветлы тон скуры',
    '🚵🏽' => 'чалавек на горным веласіпедзе: сярэдні тон скуры',
    '🚵🏾' => 'чалавек на горным веласіпедзе: сярэдняцёмны тон скуры',
    '🚵🏿' => 'чалавек на горным веласіпедзе: цёмны тон скуры',
    '🤸🏻' => 'ходзіць колам: светлы тон скуры',
    '🤸🏼' => 'ходзіць колам: сярэднясветлы тон скуры',
    '🤸🏽' => 'ходзіць колам: сярэдні тон скуры',
    '🤸🏾' => 'ходзіць колам: сярэдняцёмны тон скуры',
    '🤸🏿' => 'ходзіць колам: цёмны тон скуры',
    '🤼🏻' => 'барцы: светлы тон скуры',
    '🤼🏼' => 'барцы: сярэднясветлы тон скуры',
    '🤼🏽' => 'барцы: сярэдні тон скуры',
    '🤼🏾' => 'барцы: сярэдняцёмны тон скуры',
    '🤼🏿' => 'барцы: цёмны тон скуры',
    '🤽🏻' => 'воднае пола: светлы тон скуры',
    '🤽🏼' => 'воднае пола: сярэднясветлы тон скуры',
    '🤽🏽' => 'воднае пола: сярэдні тон скуры',
    '🤽🏾' => 'воднае пола: сярэдняцёмны тон скуры',
    '🤽🏿' => 'воднае пола: цёмны тон скуры',
    '🤾🏻' => 'гандбол: светлы тон скуры',
    '🤾🏼' => 'гандбол: сярэднясветлы тон скуры',
    '🤾🏽' => 'гандбол: сярэдні тон скуры',
    '🤾🏾' => 'гандбол: сярэдняцёмны тон скуры',
    '🤾🏿' => 'гандбол: цёмны тон скуры',
    '🤹🏻' => 'жанглёр: светлы тон скуры',
    '🤹🏼' => 'жанглёр: сярэднясветлы тон скуры',
    '🤹🏽' => 'жанглёр: сярэдні тон скуры',
    '🤹🏾' => 'жанглёр: сярэдняцёмны тон скуры',
    '🤹🏿' => 'жанглёр: цёмны тон скуры',
    '🧘🏻' => 'чалавек у позе лотаса: светлы тон скуры',
    '🧘🏼' => 'чалавек у позе лотаса: сярэднясветлы тон скуры',
    '🧘🏽' => 'чалавек у позе лотаса: сярэдні тон скуры',
    '🧘🏾' => 'чалавек у позе лотаса: сярэдняцёмны тон скуры',
    '🧘🏿' => 'чалавек у позе лотаса: цёмны тон скуры',
    '🛀🏻' => 'чалавек прымае ванну: светлы тон скуры',
    '🛀🏼' => 'чалавек прымае ванну: сярэднясветлы тон скуры',
    '🛀🏽' => 'чалавек прымае ванну: сярэдні тон скуры',
    '🛀🏾' => 'чалавек прымае ванну: сярэдняцёмны тон скуры',
    '🛀🏿' => 'чалавек прымае ванну: цёмны тон скуры',
    '🛌🏻' => 'чалавек у ложку: светлы тон скуры',
    '🛌🏼' => 'чалавек у ложку: сярэднясветлы тон скуры',
    '🛌🏽' => 'чалавек у ложку: сярэдні тон скуры',
    '🛌🏾' => 'чалавек у ложку: сярэдняцёмны тон скуры',
    '🛌🏿' => 'чалавек у ложку: цёмны тон скуры',
    '👭🏻' => 'жанчыны трымаюцца за рукі: светлы тон скуры',
    '👭🏼' => 'жанчыны трымаюцца за рукі: сярэднясветлы тон скуры',
    '👭🏽' => 'жанчыны трымаюцца за рукі: сярэдні тон скуры',
    '👭🏾' => 'жанчыны трымаюцца за рукі: сярэдняцёмны тон скуры',
    '👭🏿' => 'жанчыны трымаюцца за рукі: цёмны тон скуры',
    '👫🏻' => 'мужчына і жанчына трымаюцца за рукі: светлы тон скуры',
    '👫🏼' => 'мужчына і жанчына трымаюцца за рукі: сярэднясветлы тон скуры',
    '👫🏽' => 'мужчына і жанчына трымаюцца за рукі: сярэдні тон скуры',
    '👫🏾' => 'мужчына і жанчына трымаюцца за рукі: сярэдняцёмны тон скуры',
    '👫🏿' => 'мужчына і жанчына трымаюцца за рукі: цёмны тон скуры',
    '👬🏻' => 'мужчыны трымаюцца за рукі: светлы тон скуры',
    '👬🏼' => 'мужчыны трымаюцца за рукі: сярэднясветлы тон скуры',
    '👬🏽' => 'мужчыны трымаюцца за рукі: сярэдні тон скуры',
    '👬🏾' => 'мужчыны трымаюцца за рукі: сярэдняцёмны тон скуры',
    '👬🏿' => 'мужчыны трымаюцца за рукі: цёмны тон скуры',
    '💏🏻' => 'пацалунак: светлы тон скуры',
    '💏🏼' => 'пацалунак: сярэднясветлы тон скуры',
    '💏🏽' => 'пацалунак: сярэдні тон скуры',
    '💏🏾' => 'пацалунак: сярэдняцёмны тон скуры',
    '💏🏿' => 'пацалунак: цёмны тон скуры',
    '💑🏻' => 'закаханая пара: светлы тон скуры',
    '💑🏼' => 'закаханая пара: сярэднясветлы тон скуры',
    '💑🏽' => 'закаханая пара: сярэдні тон скуры',
    '💑🏾' => 'закаханая пара: сярэдняцёмны тон скуры',
    '💑🏿' => 'закаханая пара: цёмны тон скуры',
    '🇦🇨' => 'Сцяг: Востраў Узнясення',
    '🇦🇩' => 'Сцяг: Андора',
    '🇦🇪' => 'Сцяг: Аб’яднаныя Арабскія Эміраты',
    '🇦🇫' => 'Сцяг: Афганістан',
    '🇦🇬' => 'Сцяг: Антыгуа і Барбуда',
    '🇦🇮' => 'Сцяг: Ангілья',
    '🇦🇱' => 'Сцяг: Албанія',
    '🇦🇲' => 'Сцяг: Арменія',
    '🇦🇴' => 'Сцяг: Ангола',
    '🇦🇶' => 'Сцяг: Антарктыка',
    '🇦🇷' => 'Сцяг: Аргенціна',
    '🇦🇸' => 'Сцяг: Амерыканскае Самоа',
    '🇦🇹' => 'Сцяг: Аўстрыя',
    '🇦🇺' => 'Сцяг: Аўстралія',
    '🇦🇼' => 'Сцяг: Аруба',
    '🇦🇽' => 'Сцяг: Аландскія астравы',
    '🇦🇿' => 'Сцяг: Азербайджан',
    '🇧🇦' => 'Сцяг: Боснія і Герцагавіна',
    '🇧🇧' => 'Сцяг: Барбадас',
    '🇧🇩' => 'Сцяг: Бангладэш',
    '🇧🇪' => 'Сцяг: Бельгія',
    '🇧🇫' => 'Сцяг: Буркіна-Фасо',
    '🇧🇬' => 'Сцяг: Балгарыя',
    '🇧🇭' => 'Сцяг: Бахрэйн',
    '🇧🇮' => 'Сцяг: Бурундзі',
    '🇧🇯' => 'Сцяг: Бенін',
    '🇧🇱' => 'Сцяг: Сен-Бартэльмі',
    '🇧🇲' => 'Сцяг: Бермудскія астравы',
    '🇧🇳' => 'Сцяг: Бруней',
    '🇧🇴' => 'Сцяг: Балівія',
    '🇧🇶' => 'Сцяг: Карыбскія Нідэрланды',
    '🇧🇷' => 'Сцяг: Бразілія',
    '🇧🇸' => 'Сцяг: Багамскія астравы',
    '🇧🇹' => 'Сцяг: Бутан',
    '🇧🇻' => 'Сцяг: Востраў Бувэ',
    '🇧🇼' => 'Сцяг: Батсвана',
    '🇧🇾' => 'Сцяг: Беларусь',
    '🇧🇿' => 'Сцяг: Беліз',
    '🇨🇦' => 'Сцяг: Канада',
    '🇨🇨' => 'Сцяг: Какосавыя (Кілінг) астравы',
    '🇨🇩' => 'Сцяг: Конга (Кіншаса)',
    '🇨🇫' => 'Сцяг: Цэнтральна-Афрыканская Рэспубліка',
    '🇨🇬' => 'Сцяг: Конга - Бразавіль',
    '🇨🇭' => 'Сцяг: Швейцарыя',
    '🇨🇮' => 'Сцяг: Кот-д’Івуар',
    '🇨🇰' => 'Сцяг: Астравы Кука',
    '🇨🇱' => 'Сцяг: Чылі',
    '🇨🇲' => 'Сцяг: Камерун',
    '🇨🇳' => 'Сцяг: Кітай',
    '🇨🇴' => 'Сцяг: Калумбія',
    '🇨🇵' => 'Сцяг: Востраў Кліпертан',
    '🇨🇶' => 'Сцяг: Сарк',
    '🇨🇷' => 'Сцяг: Коста-Рыка',
    '🇨🇺' => 'Сцяг: Куба',
    '🇨🇻' => 'Сцяг: Каба-Вердэ',
    '🇨🇼' => 'Сцяг: Кюрасаа',
    '🇨🇽' => 'Сцяг: Востраў Каляд',
    '🇨🇾' => 'Сцяг: Кіпр',
    '🇨🇿' => 'Сцяг: Чэхія',
    '🇩🇪' => 'Сцяг: Германія',
    '🇩🇬' => 'Сцяг: Востраў Дыега-Гарсія',
    '🇩🇯' => 'Сцяг: Джыбуці',
    '🇩🇰' => 'Сцяг: Данія',
    '🇩🇲' => 'Сцяг: Дамініка',
    '🇩🇴' => 'Сцяг: Дамініканская Рэспубліка',
    '🇩🇿' => 'Сцяг: Алжыр',
    '🇪🇦' => 'Сцяг: Сеута і Мелілья',
    '🇪🇨' => 'Сцяг: Эквадор',
    '🇪🇪' => 'Сцяг: Эстонія',
    '🇪🇬' => 'Сцяг: Егіпет',
    '🇪🇭' => 'Сцяг: Заходняя Сахара',
    '🇪🇷' => 'Сцяг: Эрытрэя',
    '🇪🇸' => 'Сцяг: Іспанія',
    '🇪🇹' => 'Сцяг: Эфіопія',
    '🇪🇺' => 'Сцяг: Еўрапейскі саюз',
    '🇫🇮' => 'Сцяг: Фінляндыя',
    '🇫🇯' => 'Сцяг: Фіджы',
    '🇫🇰' => 'Сцяг: Фалклендскія астравы',
    '🇫🇲' => 'Сцяг: Мікранезія',
    '🇫🇴' => 'Сцяг: Фарэрскія астравы',
    '🇫🇷' => 'Сцяг: Францыя',
    '🇬🇦' => 'Сцяг: Габон',
    '🇬🇧' => 'Сцяг: Вялікабрытанія',
    '🇬🇩' => 'Сцяг: Грэнада',
    '🇬🇪' => 'Сцяг: Грузія',
    '🇬🇫' => 'Сцяг: Французская Гвіяна',
    '🇬🇬' => 'Сцяг: Гернсі',
    '🇬🇭' => 'Сцяг: Гана',
    '🇬🇮' => 'Сцяг: Гібралтар',
    '🇬🇱' => 'Сцяг: Грэнландыя',
    '🇬🇲' => 'Сцяг: Гамбія',
    '🇬🇳' => 'Сцяг: Гвінея',
    '🇬🇵' => 'Сцяг: Гвадэлупа',
    '🇬🇶' => 'Сцяг: Экватарыяльная Гвінея',
    '🇬🇷' => 'Сцяг: Грэцыя',
    '🇬🇸' => 'Сцяг: Паўднёвая Георгія і Паўднёвыя Сандвічавы астравы',
    '🇬🇹' => 'Сцяг: Гватэмала',
    '🇬🇺' => 'Сцяг: Гуам',
    '🇬🇼' => 'Сцяг: Гвінея-Бісау',
    '🇬🇾' => 'Сцяг: Гаяна',
    '🇭🇰' => 'Сцяг: Ганконг, САР (Кітай)',
    '🇭🇲' => 'Сцяг: Астравы Херд і Макдональд',
    '🇭🇳' => 'Сцяг: Гандурас',
    '🇭🇷' => 'Сцяг: Харватыя',
    '🇭🇹' => 'Сцяг: Гаіці',
    '🇭🇺' => 'Сцяг: Венгрыя',
    '🇮🇨' => 'Сцяг: Канарскія астравы',
    '🇮🇩' => 'Сцяг: Інданезія',
    '🇮🇪' => 'Сцяг: Ірландыя',
    '🇮🇱' => 'Сцяг: Ізраіль',
    '🇮🇲' => 'Сцяг: Востраў Мэн',
    '🇮🇳' => 'Сцяг: Індыя',
    '🇮🇴' => 'Сцяг: Брытанская тэрыторыя ў Індыйскім акіяне',
    '🇮🇶' => 'Сцяг: Ірак',
    '🇮🇷' => 'Сцяг: Іран',
    '🇮🇸' => 'Сцяг: Ісландыя',
    '🇮🇹' => 'Сцяг: Італія',
    '🇯🇪' => 'Сцяг: Джэрсі',
    '🇯🇲' => 'Сцяг: Ямайка',
    '🇯🇴' => 'Сцяг: Іарданія',
    '🇯🇵' => 'Сцяг: Японія',
    '🇰🇪' => 'Сцяг: Кенія',
    '🇰🇬' => 'Сцяг: Кыргызстан',
    '🇰🇭' => 'Сцяг: Камбоджа',
    '🇰🇮' => 'Сцяг: Кірыбаці',
    '🇰🇲' => 'Сцяг: Каморскія астравы',
    '🇰🇳' => 'Сцяг: Сент-Кітс і Невіс',
    '🇰🇵' => 'Сцяг: Паўночная Карэя',
    '🇰🇷' => 'Сцяг: Паўднёвая Карэя',
    '🇰🇼' => 'Сцяг: Кувейт',
    '🇰🇾' => 'Сцяг: Кайманавы астравы',
    '🇰🇿' => 'Сцяг: Казахстан',
    '🇱🇦' => 'Сцяг: Лаос',
    '🇱🇧' => 'Сцяг: Ліван',
    '🇱🇨' => 'Сцяг: Сент-Люсія',
    '🇱🇮' => 'Сцяг: Ліхтэнштэйн',
    '🇱🇰' => 'Сцяг: Шры-Ланка',
    '🇱🇷' => 'Сцяг: Ліберыя',
    '🇱🇸' => 'Сцяг: Лесота',
    '🇱🇹' => 'Сцяг: Літва',
    '🇱🇺' => 'Сцяг: Люксембург',
    '🇱🇻' => 'Сцяг: Латвія',
    '🇱🇾' => 'Сцяг: Лівія',
    '🇲🇦' => 'Сцяг: Марока',
    '🇲🇨' => 'Сцяг: Манака',
    '🇲🇩' => 'Сцяг: Малдова',
    '🇲🇪' => 'Сцяг: Чарнагорыя',
    '🇲🇫' => 'Сцяг: Сен-Мартэн',
    '🇲🇬' => 'Сцяг: Мадагаскар',
    '🇲🇭' => 'Сцяг: Маршалавы астравы',
    '🇲🇰' => 'Сцяг: Паўночная Македонія',
    '🇲🇱' => 'Сцяг: Малі',
    '🇲🇲' => 'Сцяг: М’янма (Бірма)',
    '🇲🇳' => 'Сцяг: Манголія',
    '🇲🇴' => 'Сцяг: Макаа, САР (Кітай)',
    '🇲🇵' => 'Сцяг: Паўночныя Марыянскія астравы',
    '🇲🇶' => 'Сцяг: Марцініка',
    '🇲🇷' => 'Сцяг: Маўрытанія',
    '🇲🇸' => 'Сцяг: Мантсерат',
    '🇲🇹' => 'Сцяг: Мальта',
    '🇲🇺' => 'Сцяг: Маўрыкій',
    '🇲🇻' => 'Сцяг: Мальдывы',
    '🇲🇼' => 'Сцяг: Малаві',
    '🇲🇽' => 'Сцяг: Мексіка',
    '🇲🇾' => 'Сцяг: Малайзія',
    '🇲🇿' => 'Сцяг: Мазамбік',
    '🇳🇦' => 'Сцяг: Намібія',
    '🇳🇨' => 'Сцяг: Новая Каледонія',
    '🇳🇪' => 'Сцяг: Нігер',
    '🇳🇫' => 'Сцяг: Востраў Норфалк',
    '🇳🇬' => 'Сцяг: Нігерыя',
    '🇳🇮' => 'Сцяг: Нікарагуа',
    '🇳🇱' => 'Сцяг: Нідэрланды',
    '🇳🇴' => 'Сцяг: Нарвегія',
    '🇳🇵' => 'Сцяг: Непал',
    '🇳🇷' => 'Сцяг: Науру',
    '🇳🇺' => 'Сцяг: Ніуэ',
    '🇳🇿' => 'Сцяг: Новая Зеландыя',
    '🇴🇲' => 'Сцяг: Аман',
    '🇵🇦' => 'Сцяг: Панама',
    '🇵🇪' => 'Сцяг: Перу',
    '🇵🇫' => 'Сцяг: Французская Палінезія',
    '🇵🇬' => 'Сцяг: Папуа-Новая Гвінея',
    '🇵🇭' => 'Сцяг: Філіпіны',
    '🇵🇰' => 'Сцяг: Пакістан',
    '🇵🇱' => 'Сцяг: Польшча',
    '🇵🇲' => 'Сцяг: Сен-П’ер і Мікелон',
    '🇵🇳' => 'Сцяг: Астравы Піткэрн',
    '🇵🇷' => 'Сцяг: Пуэрта-Рыка',
    '🇵🇸' => 'Сцяг: Палесцінскія Тэрыторыі',
    '🇵🇹' => 'Сцяг: Партугалія',
    '🇵🇼' => 'Сцяг: Палау',
    '🇵🇾' => 'Сцяг: Парагвай',
    '🇶🇦' => 'Сцяг: Катар',
    '🇷🇪' => 'Сцяг: Рэюньён',
    '🇷🇴' => 'Сцяг: Румынія',
    '🇷🇸' => 'Сцяг: Сербія',
    '🇷🇺' => 'Сцяг: Расія',
    '🇷🇼' => 'Сцяг: Руанда',
    '🇸🇦' => 'Сцяг: Саудаўская Аравія',
    '🇸🇧' => 'Сцяг: Саламонавы астравы',
    '🇸🇨' => 'Сцяг: Сейшэльскія астравы',
    '🇸🇩' => 'Сцяг: Судан',
    '🇸🇪' => 'Сцяг: Швецыя',
    '🇸🇬' => 'Сцяг: Сінгапур',
    '🇸🇭' => 'Сцяг: Востраў Святой Алены',
    '🇸🇮' => 'Сцяг: Славенія',
    '🇸🇯' => 'Сцяг: Шпіцберген і Ян-Маен',
    '🇸🇰' => 'Сцяг: Славакія',
    '🇸🇱' => 'Сцяг: Сьера-Леонэ',
    '🇸🇲' => 'Сцяг: Сан-Марына',
    '🇸🇳' => 'Сцяг: Сенегал',
    '🇸🇴' => 'Сцяг: Самалі',
    '🇸🇷' => 'Сцяг: Сурынам',
    '🇸🇸' => 'Сцяг: Паўднёвы Судан',
    '🇸🇹' => 'Сцяг: Сан-Тамэ і Прынсіпі',
    '🇸🇻' => 'Сцяг: Сальвадор',
    '🇸🇽' => 'Сцяг: Сінт-Мартэн',
    '🇸🇾' => 'Сцяг: Сірыя',
    '🇸🇿' => 'Сцяг: Эсватыні',
    '🇹🇦' => 'Сцяг: Трыстан-да-Кунья',
    '🇹🇨' => 'Сцяг: Астравы Цёркс і Кайкас',
    '🇹🇩' => 'Сцяг: Чад',
    '🇹🇫' => 'Сцяг: Французскія паўднёвыя тэрыторыі',
    '🇹🇬' => 'Сцяг: Тога',
    '🇹🇭' => 'Сцяг: Тайланд',
    '🇹🇯' => 'Сцяг: Таджыкістан',
    '🇹🇰' => 'Сцяг: Такелау',
    '🇹🇱' => 'Сцяг: Тымор-Лешці',
    '🇹🇲' => 'Сцяг: Туркменістан',
    '🇹🇳' => 'Сцяг: Туніс',
    '🇹🇴' => 'Сцяг: Тонга',
    '🇹🇷' => 'Сцяг: Турцыя',
    '🇹🇹' => 'Сцяг: Трынідад і Табага',
    '🇹🇻' => 'Сцяг: Тувалу',
    '🇹🇼' => 'Сцяг: Тайвань',
    '🇹🇿' => 'Сцяг: Танзанія',
    '🇺🇦' => 'Сцяг: Украіна',
    '🇺🇬' => 'Сцяг: Уганда',
    '🇺🇲' => 'Сцяг: Малыя Аддаленыя астравы ЗША',
    '🇺🇳' => 'Сцяг: Арганізацыя Аб’яднаных Нацый',
    '🇺🇸' => 'Сцяг: Злучаныя Штаты Амерыкі',
    '🇺🇾' => 'Сцяг: Уругвай',
    '🇺🇿' => 'Сцяг: Узбекістан',
    '🇻🇦' => 'Сцяг: Ватыкан',
    '🇻🇨' => 'Сцяг: Сент-Вінсент і Грэнадзіны',
    '🇻🇪' => 'Сцяг: Венесуэла',
    '🇻🇬' => 'Сцяг: Брытанскія Віргінскія астравы',
    '🇻🇮' => 'Сцяг: Амерыканскія Віргінскія астравы',
    '🇻🇳' => 'Сцяг: В’етнам',
    '🇻🇺' => 'Сцяг: Вануату',
    '🇼🇫' => 'Сцяг: Уоліс і Футуна',
    '🇼🇸' => 'Сцяг: Самоа',
    '🇽🇰' => 'Сцяг: Косава',
    '🇾🇪' => 'Сцяг: Емен',
    '🇾🇹' => 'Сцяг: Маёта',
    '🇿🇦' => 'Сцяг: Паўднёва-Афрыканская Рэспубліка',
    '🇿🇲' => 'Сцяг: Замбія',
    '🇿🇼' => 'Сцяг: Зімбабвэ',
    '🔟' => 'Клавіша: 10',
    '🏻' => 'светлы тон скуры',
    '🏼' => 'сярэднясветлы тон скуры',
    '🏽' => 'сярэдні тон скуры',
    '🏾' => 'сярэдняцёмны тон скуры',
    '🏿' => 'цёмны тон скуры',
    '😀' => 'шырока ўсміхаецца',
    '😃' => 'усміхаецца з адкрытым ротам',
    '😄' => 'твар, які ўсміхаецца, адкрыўшы рот і прыплюшчыўшы вочы',
    '😁' => 'твар, які шырока ўсміхаецца, прыплюшчыўшы вочы',
    '😆' => 'твар, які смяецца, адкрыўшы рот і заплюшчыўшы вочы',
    '😅' => 'усміхаецца адкрытым ротам з халодным потам на лбе',
    '🤣' => 'качаюся са смеху',
    '😂' => 'слёзы шчасця',
    '🙂' => 'злёгку ўсміхаецца',
    '🙃' => 'дагары нагамі',
    '🫠' => 'твар растае',
    '😉' => 'падморгвае',
    '😊' => 'усміхаецца, прыплюшчыўшы вочы',
    '😇' => 'твар з німбам',
    '🥰' => 'твар з трыма сэрцамі ўсміхаецца',
    '😍' => 'закаханы твар',
    '🤩' => 'твар з зоркамі',
    '😘' => 'паветраны пацалунак',
    '😗' => 'цалуе',
    '☺' => 'усміхаецца',
    '😚' => 'цалуе, заплюшчыўшы вочы',
    '😙' => 'цалуе, прыплюшчыўшы вочы',
    '🥲' => 'усмешлівы твар са слязой',
    '😋' => 'смачна',
    '😛' => 'паказвае язык',
    '😜' => 'паказвае язык і падморгвае',
    '🤪' => 'вар’яцкі твар',
    '😝' => 'паказвае язык, заплюшчыўшы вочы',
    '🤑' => 'чую грошы',
    '🤗' => 'абдымкі',
    '🤭' => 'закрывае рукой рот',
    '🫢' => 'твар з расплюшчанымі вачыма і закрытым рукой ротам',
    '🫣' => 'закрыты твар падглядае адным вокам',
    '🤫' => 'шыкае',
    '🤔' => 'у роздуме',
    '🫡' => 'твар салютуе',
    '🤐' => 'рот на замок',
    '🤨' => 'твар з узнятым брывом',
    '😐' => 'нейтральны твар',
    '😑' => 'без эмоцый',
    '😶' => 'твар без рота',
    '🫥' => 'твар, намаляваны пункцірам',
    '😏' => 'ухмыляецца',
    '😒' => 'незадаволены твар',
    '🙄' => 'закочвае вочы',
    '😬' => 'скрыўлены твар',
    '🤥' => 'твар хлуса',
    '🫨' => 'раздвоены твар',
    '😌' => 'адчувае палёгку',
    '😔' => 'задуменны твар',
    '😪' => 'сонны твар',
    '🤤' => 'пускае сліну',
    '😴' => 'спіць',
    '🫩' => 'твар з мяшкамі пад вачамі',
    '😷' => 'твар у медыцынскай масцы',
    '🤒' => 'твар з тэрмометрам',
    '🤕' => 'твар з павязкай на галаве',
    '🤢' => 'моташна',
    '🤮' => 'ванітуе',
    '🤧' => 'чхае',
    '🥵' => 'гарачы твар',
    '🥶' => 'змерзлы твар',
    '🥴' => 'ап’янелы твар',
    '😵' => 'галава круціцца',
    '🤯' => 'галава выбухае',
    '🤠' => 'каўбой у капелюшы',
    '🥳' => 'святкуе',
    '🥸' => 'твар пад маскіроўкай',
    '😎' => 'усміхаецца ў сонечных акулярах',
    '🤓' => 'гік',
    '🧐' => 'твар з маноклем',
    '😕' => 'разгублены твар',
    '🫤' => 'твар са скошаным ротам',
    '😟' => 'занепакоены твар',
    '🙁' => 'злёгку засмучаны твар',
    '☹' => 'засмучаны твар',
    '😮' => 'твар з адкрытым ротам',
    '😯' => 'ашаломлены твар',
    '😲' => 'здзіўлены твар',
    '😳' => 'здранцвелы твар',
    '🫪' => 'перакошаны твар',
    '🥺' => 'упрошвае',
    '🥹' => 'стрымлівае слёзы',
    '😦' => 'засмучаны твар з адкрытым ротам',
    '😧' => 'пакутлівы твар',
    '😨' => 'напалоханы твар',
    '😰' => 'твар з адкрытым ротам і халодным потам на лбе',
    '😥' => 'расчараванне з палёгкай',
    '😢' => 'плача',
    '😭' => 'плача ўголас',
    '😱' => 'спалохана крычыць',
    '😖' => 'безвыходнасць',
    '😣' => 'упарты твар',
    '😞' => 'расчараваны твар',
    '😓' => 'халодны пот на твары',
    '😩' => 'змораны твар',
    '😫' => 'стомлены твар',
    '🥱' => 'пазяханне',
    '😤' => 'пара з носа',
    '😡' => 'надзьмуты твар',
    '😠' => 'злуецца',
    '🤬' => 'твар са знакамі на роце',
    '😈' => 'рагацік з усмешкай',
    '👿' => 'злы рагаты чорт',
    '💀' => 'чэрап',
    '☠' => 'чэрап і косці',
    '💩' => 'какашка',
    '🤡' => 'твар клоуна',
    '👹' => 'людажэр',
    '👺' => 'гоблін',
    '👻' => 'прывід',
    '👽' => 'іншапланецянін',
    '👾' => 'монстр-іншапланецянін',
    '🤖' => 'робат',
    '😺' => 'кот усміхаецца, адкрыўшы рот',
    '😸' => 'кот шырока ўсміхаецца, зажмурыўшы вочы',
    '😹' => 'кот плача ад шчасця',
    '😻' => 'закаханы кот',
    '😼' => 'кот са скрыўленай усмешкай',
    '😽' => 'кот цалуе, закрыўшы вочы',
    '🙀' => 'змораны кот',
    '😿' => 'кот плача',
    '😾' => 'надзьмуты кот',
    '🙈' => 'нічога не бачу',
    '🙉' => 'нічога не чую',
    '🙊' => 'нічога не скажу',
    '💌' => 'любоўны ліст',
    '💘' => 'страла ў сэрцы',
    '💝' => 'сэрца са стужачкай',
    '💖' => 'бліскучае сэрца',
    '💗' => 'сэрца, якое павялічваецца',
    '💓' => 'пульсуючае сэрца',
    '💞' => 'сэрцы, якія круцяцца',
    '💕' => 'два сэрцы',
    '💟' => 'стылізаванае сэрца',
    '❣' => 'клічнік у форме сэрца',
    '💔' => 'разбітае сэрца',
    '❤' => 'чырвонае сэрца',
    '🩷' => 'ружовае сэрца',
    '🧡' => 'аранжавае сэрца',
    '💛' => 'жоўтае сэрца',
    '💚' => 'зялёнае сэрца',
    '💙' => 'сіняе сэрца',
    '🩵' => 'блакітнае сэрца',
    '💜' => 'фіялетавае сэрца',
    '🤎' => 'карычневае сэрца',
    '🖤' => 'чорнае сэрца',
    '🩶' => 'шэрае сэрца',
    '🤍' => 'белае сэрца',
    '💋' => 'след ад пацалунку',
    '💯' => 'сто ачкоў',
    '💢' => 'сімвал злосці',
    '🫯' => 'бойка',
    '💥' => 'выбух',
    '💫' => 'галавакружэнне',
    '💦' => 'пырскі поту',
    '💨' => 'знікненне',
    '🕳' => 'дзірка',
    '💬' => 'воблачка з тэкстам',
    '🗨' => 'бурбалка з тэкстам злева',
    '🗯' => 'бурбалка з абурэннем справа',
    '💭' => 'воблачка з думкамі',
    '💤' => 'сон',
    '👋' => 'махае рукой',
    '🤚' => 'паднятая далонь',
    '🖐' => 'паднятая рука з растапыранымі пальцамі',
    '✋' => 'паднятая рука',
    '🖖' => 'вулканскі салют',
    '🫱' => 'рука направа',
    '🫲' => 'рука налева',
    '🫳' => 'рука далонню ўніз',
    '🫴' => 'рука далонню ўверх',
    '🫷' => 'рука штурхае ўлева',
    '🫸' => 'рука штурхае ўправа',
    '👌' => 'жэст «ОК»',
    '🤌' => 'зведзеныя пальцы',
    '🤏' => 'тры пальцы',
    '✌' => 'жэст перамогі',
    '🤞' => 'скрыжаваныя пальцы',
    '🫰' => 'рука са скрыжаванымі вялікім і ўказальным пальцамі',
    '🤟' => 'жэст «люблю цябе»',
    '🤘' => 'жэст «каза»',
    '🤙' => 'пазвані мне',
    '👈' => 'рука з указальным пальцам улева',
    '👉' => 'рука з указальным пальцам управа',
    '👆' => 'рука з указальным пальцам уверх',
    '🖕' => 'сярэдні палец',
    '👇' => 'рука з указальным пальцам уніз',
    '☝' => 'указальны палец уверх',
    '🫵' => 'указальны палец накіраваны на гледача',
    '👍' => 'вялікі палец уверх',
    '👎' => 'вялікі палец уніз',
    '✊' => 'падняты кулак',
    '👊' => 'ляціць кулак',
    '🤛' => 'кулак улева',
    '🤜' => 'кулак управа',
    '👏' => 'пляскае ў ладкі',
    '🙌' => 'чалавек паднімае рукі',
    '🫶' => 'рукі ў форме сэрца',
    '👐' => 'адкрытыя рукі',
    '🤲' => 'складзеныя разам далоні',
    '🤝' => 'поціск рук',
    '🙏' => 'складзеныя рукі',
    '✍' => 'пішучая рука',
    '💅' => 'лак для ногцяў',
    '🤳' => 'сэлфі',
    '💪' => 'дэманстрацыя біцэпса',
    '🦾' => 'механічная рука',
    '🦿' => 'механічная нага',
    '🦵' => 'нага',
    '🦶' => 'ступня',
    '👂' => 'вуха',
    '🦻' => 'вуха са слыхавым апаратам',
    '👃' => 'нос',
    '🧠' => 'мозг',
    '🫀' => 'сэрца',
    '🫁' => 'лёгкія',
    '🦷' => 'зуб',
    '🦴' => 'косць',
    '👀' => 'вочы',
    '👁' => 'вока',
    '👅' => 'язык',
    '👄' => 'рот',
    '🫦' => 'закусванне губы',
    '👶' => 'немаўля',
    '🧒' => 'дзіця',
    '👦' => 'хлопчык',
    '👧' => 'дзяўчынка',
    '🧑' => 'дарослы',
    '👱' => 'бялявы чалавек',
    '👨' => 'мужчына',
    '🧔' => 'чалавек з барадой',
    '👩' => 'жанчына',
    '🧓' => 'у гадах',
    '👴' => 'дзядуля',
    '👵' => 'бабуля',
    '🙍' => 'засмучаны чалавек',
    '🙎' => 'надзьмуты чалавек',
    '🙅' => 'чалавек супраць',
    '🙆' => 'чалавек паказвае згоду',
    '💁' => 'чалавек трасе рукой',
    '🙋' => 'чалавек цягне руку',
    '🧏' => 'глухі чалавек',
    '🙇' => 'чалавек кланяецца',
    '🤦' => 'далонь на твары',
    '🤷' => 'паціскае плячыма',
    '👮' => 'паліцыянт',
    '🕵' => 'дэтэктыў',
    '💂' => 'варта',
    '🥷' => 'ніндзя',
    '👷' => 'будаўнік',
    '🫅' => 'чалавек з каронай',
    '🤴' => 'прынц',
    '👸' => 'прынцэса',
    '👳' => 'чалавек у турбане',
    '👲' => 'мужчына ў кітайскай шапачцы',
    '🧕' => 'жанчына ў хустцы',
    '🤵' => 'чалавек у смокінгу',
    '👰' => 'нявеста ў вэлюме',
    '🤰' => 'цяжарная',
    '🫃' => 'цяжарны мужчына',
    '🫄' => 'цяжарны чалавек',
    '🤱' => 'кормячая маці',
    '👼' => 'анёлак',
    '🎅' => 'Санта Клаус',
    '🤶' => 'місіс Клаус',
    '🦸' => 'супергерой',
    '🦹' => 'суперзлачынца',
    '🧙' => 'чараўнік',
    '🧚' => 'фея',
    '🧛' => 'вампір',
    '🧜' => 'русалкі',
    '🧝' => 'эльф',
    '🧞' => 'джын',
    '🧟' => 'зомбі',
    '🧌' => 'троль',
    '🫈' => 'снежны чалавек',
    '💆' => 'чалавека масажуюць',
    '💇' => 'чалавеку стрыгуць валоссе',
    '🚶' => 'чалавек ідзе',
    '🧍' => 'чалавек стаіць',
    '🧎' => 'чалавек на каленях',
    '🏃' => 'чалавек бяжыць',
    '💃' => 'танцорка',
    '🕺' => 'танцор',
    '🕴' => 'мужчына ў дзелавым касцюме левітуе',
    '👯' => 'людзі весяляцца',
    '🧖' => 'чалавек у лазні',
    '🧗' => 'чалавек падымаецца на гару',
    '🤺' => 'фехтавальшчык',
    '🏇' => 'скачкі',
    '⛷' => 'лыжнік',
    '🏂' => 'снаўбардыст',
    '🏌' => 'чалавек гуляе ў гольф',
    '🏄' => 'сёрфінг',
    '🚣' => 'веславанне',
    '🏊' => 'чалавек плыве',
    '⛹' => 'чалавек з мячом',
    '🏋' => 'чалавек са штангай',
    '🚴' => 'чалавек на веласіпедзе',
    '🚵' => 'чалавек на горным веласіпедзе',
    '🤸' => 'ходзіць колам',
    '🤼' => 'барцы',
    '🤽' => 'воднае пола',
    '🤾' => 'гандбол',
    '🤹' => 'жанглёр',
    '🧘' => 'чалавек у позе лотаса',
    '🛀' => 'чалавек прымае ванну',
    '🛌' => 'чалавек у ложку',
    '👭' => 'жанчыны трымаюцца за рукі',
    '👫' => 'мужчына і жанчына трымаюцца за рукі',
    '👬' => 'мужчыны трымаюцца за рукі',
    '💏' => 'пацалунак',
    '💑' => 'закаханая пара',
    '🗣' => 'гаворачая галава',
    '👤' => 'сілуэт бюста',
    '👥' => 'сілуэты бюстаў',
    '🫂' => 'людзі абдымаюцца',
    '👪' => 'сям’я',
    '👣' => 'сляды ног',
    '🫆' => 'адбітак пальца',
    '🦰' => 'рыжыя валасы',
    '🦱' => 'курчавыя валасы',
    '🦳' => 'сівыя валасы',
    '🦲' => 'лысы',
    '🐵' => 'пыска малпы',
    '🐒' => 'малпа',
    '🦍' => 'гарыла',
    '🦧' => 'арангутан',
    '🐶' => 'сабачая пыска',
    '🐕' => 'сабака',
    '🦮' => 'сабака-павадыр',
    '🐩' => 'пудзель',
    '🐺' => 'воўк',
    '🦊' => 'ліс',
    '🦝' => 'янот',
    '🐱' => 'каціная пыска',
    '🐈' => 'кот',
    '🦁' => 'леў',
    '🐯' => 'пыска тыгра',
    '🐅' => 'тыгр',
    '🐆' => 'леапард',
    '🐴' => 'пыска каня',
    '🫎' => 'лось',
    '🫏' => 'асёл',
    '🐎' => 'конь',
    '🦄' => 'пыска аднарога',
    '🦓' => 'зебра',
    '🦌' => 'алень',
    '🦬' => 'зубр',
    '🐮' => 'пыска каровы',
    '🐂' => 'бык',
    '🐃' => 'вадзяны буйвал',
    '🐄' => 'карова',
    '🐷' => 'пыска свінні',
    '🐖' => 'свіння',
    '🐗' => 'дзік',
    '🐽' => 'свіны пятачок',
    '🐏' => 'баран',
    '🐑' => 'авечка',
    '🐐' => 'казёл',
    '🐪' => 'вярблюд',
    '🐫' => 'двухгорбы вярблюд',
    '🦙' => 'лама',
    '🦒' => 'жыраф',
    '🐘' => 'слон',
    '🦣' => 'мамант',
    '🦏' => 'насарог',
    '🦛' => 'гіпапатам',
    '🐭' => 'мышыная пыска',
    '🐁' => 'мыш',
    '🐀' => 'пацук',
    '🐹' => 'пыска хамяка',
    '🐰' => 'заечая пыска',
    '🐇' => 'трус',
    '🐿' => 'бурундук',
    '🦫' => 'бабёр',
    '🦔' => 'вожык',
    '🦇' => 'кажан',
    '🐻' => 'мядзведжая пыска',
    '🐨' => 'каала',
    '🐼' => 'панда',
    '🦥' => 'лянівец',
    '🦦' => 'выдра',
    '🦨' => 'скунс',
    '🦘' => 'кенгуру',
    '🦡' => 'барсук',
    '🐾' => 'сляды лап',
    '🦃' => 'індычка',
    '🐔' => 'курыца',
    '🐓' => 'певень',
    '🐣' => 'кураня вылупліваецца',
    '🐤' => 'кураня',
    '🐥' => 'кураня спераду',
    '🐦' => 'птушка',
    '🐧' => 'пінгвін',
    '🕊' => 'голуб',
    '🦅' => 'арол',
    '🦆' => 'качка',
    '🦢' => 'лебедзь',
    '🦉' => 'сава',
    '🦤' => 'дадо',
    '🪶' => 'пяро',
    '🦩' => 'фламінга',
    '🦚' => 'паўлін',
    '🦜' => 'папугай',
    '🪽' => 'крыло',
    '🪿' => 'гусь',
    '🐸' => 'жаба',
    '🐊' => 'кракадзіл',
    '🐢' => 'чарапаха',
    '🦎' => 'яшчарка',
    '🐍' => 'змяя',
    '🐲' => 'галава цмока',
    '🐉' => 'цмок',
    '🦕' => 'заўрапод',
    '🦖' => 'тыраназаўр',
    '🐳' => 'фантануючы кіт',
    '🐋' => 'кіт',
    '🐬' => 'дэльфін',
    '🫍' => 'касатка',
    '🦭' => 'цюлень',
    '🐟' => 'рыба',
    '🐠' => 'трапічная рыба',
    '🐡' => 'іголкабрухавая рыба',
    '🦈' => 'акула',
    '🐙' => 'васьміног',
    '🐚' => 'спіральная ракушка',
    '🪸' => 'карал',
    '🪼' => 'медуза',
    '🦀' => 'краб',
    '🦞' => 'амар',
    '🦐' => 'крэветка',
    '🦑' => 'кальмар',
    '🦪' => 'вустрыца',
    '🐌' => 'смоўж',
    '🦋' => 'матылёк',
    '🐛' => 'кузурка',
    '🐜' => 'мураш',
    '🐝' => 'пчала',
    '🪲' => 'жук',
    '🐞' => 'божая кароўка',
    '🦗' => 'цвыркун',
    '🪳' => 'таракан',
    '🕷' => 'павук',
    '🕸' => 'павуцінне',
    '🦂' => 'скарпіён',
    '🦟' => 'камар',
    '🪰' => 'муха',
    '🪱' => 'чарвяк',
    '🦠' => 'мікроб',
    '💐' => 'букет',
    '🌸' => 'вішнёвая квецень',
    '💮' => 'белая кветка',
    '🪷' => 'лотас',
    '🏵' => 'разетка',
    '🌹' => 'ружа',
    '🥀' => 'завялая кветка',
    '🌺' => 'гібіскус',
    '🌻' => 'сланечнік',
    '🌼' => 'квецень',
    '🌷' => 'цюльпан',
    '🪻' => 'гіяцынт',
    '🌱' => 'расада',
    '🪴' => 'вазон',
    '🌲' => 'вечназялёнае дрэва',
    '🌳' => 'ліставое дрэва',
    '🌴' => 'пальма',
    '🌵' => 'кактус',
    '🌾' => 'колас рыса',
    '🌿' => 'лекавая трава',
    '☘' => 'трыліснік',
    '🍀' => 'чатырохлістая канюшына',
    '🍁' => 'кляновы ліст',
    '🍂' => 'апалы ліст',
    '🍃' => 'ліст кружыцца ў паветры',
    '🪹' => 'пустое гняздо',
    '🪺' => 'гняздо з яйкамі',
    '🍄' => 'грыб',
    '🪾' => 'бязлістае дрэва',
    '🍇' => 'вінаград',
    '🍈' => 'дыня',
    '🍉' => 'кавун',
    '🍊' => 'мандарын',
    '🍋' => 'лімон',
    '🍌' => 'банан',
    '🍍' => 'ананас',
    '🥭' => 'манга',
    '🍎' => 'чырвоны яблык',
    '🍏' => 'зялёны яблык',
    '🍐' => 'груша',
    '🍑' => 'персік',
    '🍒' => 'вішні',
    '🍓' => 'клубніцы',
    '🫐' => 'буякі',
    '🥝' => 'ківі',
    '🍅' => 'памідор',
    '🫒' => 'аліва',
    '🥥' => 'какос',
    '🥑' => 'авакада',
    '🍆' => 'баклажан',
    '🥔' => 'бульба',
    '🥕' => 'морква',
    '🌽' => 'катах кукурузы',
    '🌶' => 'востры перац',
    '🫑' => 'балгарскі перац',
    '🥒' => 'агурок',
    '🥬' => 'зеляніна',
    '🥦' => 'брокалі',
    '🧄' => 'часнок',
    '🧅' => 'цыбуля',
    '🥜' => 'арахіс',
    '🫘' => 'боб',
    '🌰' => 'каштан',
    '🫚' => 'корань імбіру',
    '🫛' => 'гарохавы стручок',
    '🫜' => 'караняплод',
    '🍞' => 'хлеб',
    '🥐' => 'круасан',
    '🥖' => 'багет',
    '🫓' => 'праснак',
    '🥨' => 'крэндзель',
    '🥯' => 'пышка',
    '🥞' => 'бліны',
    '🧇' => 'вафля',
    '🧀' => 'кавалак сыру',
    '🍖' => 'мяса на косці',
    '🍗' => 'курыная ножка',
    '🥩' => 'кавалак мяса',
    '🥓' => 'бекон',
    '🍔' => 'гамбургер',
    '🍟' => 'бульба фры',
    '🍕' => 'піца',
    '🌭' => 'хот-дог',
    '🥪' => 'сандвіч',
    '🌮' => 'така',
    '🌯' => 'бурыта',
    '🫔' => 'тамале',
    '🥙' => 'піта',
    '🧆' => 'фалафель',
    '🥚' => 'яйка',
    '🍳' => 'гатаванне',
    '🥘' => 'рагу ў патэльні',
    '🍲' => 'гаршчок з ежай',
    '🫕' => 'фандзю',
    '🥣' => 'міска з лыжкай',
    '🥗' => 'салата з зеляніны',
    '🍿' => 'папкорн',
    '🧈' => 'масла',
    '🧂' => 'соль',
    '🥫' => 'кансерваваная ежа',
    '🍱' => 'бэнто',
    '🍘' => 'рысавае пячэнне',
    '🍙' => 'рысавы шарык',
    '🍚' => 'згатаваны рыс',
    '🍛' => 'рыс і кары',
    '🍜' => 'міска з гарачай ежай',
    '🍝' => 'спагеці',
    '🍠' => 'запечаная салодкая бульба',
    '🍢' => 'одэн',
    '🍣' => 'сушы',
    '🍤' => 'смажаная крэветка',
    '🍥' => 'рыбны пірог з завітком',
    '🥮' => 'месяцовы пернік',
    '🍡' => 'данга',
    '🥟' => 'пельмені',
    '🥠' => 'пячэнне з прадказаннем',
    '🥡' => 'ежа на вынас',
    '🍦' => 'мяккае марожанае',
    '🍧' => 'фруктовы лёд',
    '🍨' => 'марожанае',
    '🍩' => 'пончык',
    '🍪' => 'пячэнне',
    '🎂' => 'імянінны торт',
    '🍰' => 'слоены пірог',
    '🧁' => 'кекс',
    '🥧' => 'торт',
    '🍫' => 'плітка шакаладу',
    '🍬' => 'цукерка',
    '🍭' => 'ледзянец',
    '🍮' => 'карамельны пудынг',
    '🍯' => 'гаршчок мёду',
    '🍼' => 'дзіцячая бутэлечка',
    '🥛' => 'шклянка малака',
    '☕' => 'гарачы напой',
    '🫖' => 'чайнік',
    '🍵' => 'кубачак чаю без ручкі',
    '🍶' => 'саке',
    '🍾' => 'шампанскае адкаркавана',
    '🍷' => 'келіх віна',
    '🍸' => 'келіх кактэйлю',
    '🍹' => 'трапічны напой',
    '🍺' => 'куфель піва',
    '🍻' => 'чоканне куфляў',
    '🥂' => 'чоканне келіхаў',
    '🥃' => 'шклянка для віна',
    '🫗' => 'ліць вадкасць',
    '🥤' => 'шклянка з саломінкай',
    '🧋' => 'чай з шарыкамі',
    '🧃' => 'пачак з напоем',
    '🧉' => 'матэ',
    '🧊' => 'кубік лёду',
    '🥢' => 'палачкі',
    '🍽' => 'талерка, відэлец і нож',
    '🍴' => 'відэлец і нож',
    '🥄' => 'лыжка',
    '🔪' => 'кухонны нож',
    '🫙' => 'слоік',
    '🏺' => 'амфара',
    '🌍' => 'зямны шар (еўропа і афрыка)',
    '🌎' => 'зямны шар (паўночная і паўднёвая амерыкі)',
    '🌏' => 'зямны шар (аўстралія і азія)',
    '🌐' => 'зямны шар з мерыдыянамі',
    '🗺' => 'карта свету',
    '🗾' => 'карта японіі',
    '🧭' => 'компас',
    '🏔' => 'заснежаная гара',
    '⛰' => 'гара',
    '🛘' => 'апоўзень',
    '🌋' => 'вулкан',
    '🗻' => 'гара фудзі',
    '🏕' => 'кемпінг',
    '🏖' => 'пляж і парасон',
    '🏜' => 'пустыня',
    '🏝' => 'ненаселены востраў',
    '🏞' => 'нацыянальны парк',
    '🏟' => 'стадыён',
    '🏛' => 'будынак у класічным стылі',
    '🏗' => 'будаўніцтва',
    '🧱' => 'цагліна',
    '🪨' => 'камень',
    '🪵' => 'драўніна',
    '🛖' => 'хата',
    '🏘' => 'дамы',
    '🏚' => 'закінуты дом',
    '🏠' => 'дом',
    '🏡' => 'дом з садам',
    '🏢' => 'офісны будынак',
    '🏣' => 'японскі паштамт',
    '🏤' => 'паштамт',
    '🏥' => 'бальніца',
    '🏦' => 'банк',
    '🏨' => 'гатэль',
    '🏩' => 'любоўны гатэль',
    '🏪' => 'кругласутачная крама',
    '🏫' => 'школа',
    '🏬' => 'універмаг',
    '🏭' => 'завод',
    '🏯' => 'японскі замак',
    '🏰' => 'замак',
    '💒' => 'вяселле',
    '🗼' => 'такійская тэлевежа',
    '🗽' => 'статуя свабоды',
    '⛪' => 'царква',
    '🕌' => 'мячэць',
    '🛕' => 'індуісцкі храм',
    '🕍' => 'сінагога',
    '⛩' => 'сінтаісцкі храм',
    '🕋' => 'кааба',
    '⛲' => 'фантан',
    '⛺' => 'палатка',
    '🌁' => 'туманнае надвор’е',
    '🌃' => 'зорная ноч',
    '🏙' => 'гарадскі краявід',
    '🌄' => 'узыход сонца над гарамі',
    '🌅' => 'узыход сонца',
    '🌆' => 'гарадскі краявід у змярканні',
    '🌇' => 'захад сонца',
    '🌉' => 'мост уначы',
    '♨' => 'гарачыя крыніцы',
    '🎠' => 'конік з каруселі',
    '🛝' => 'дзіцячая горка',
    '🎡' => 'кола агляду',
    '🎢' => 'амерыканскія горкі',
    '💈' => 'каляровы слуп',
    '🎪' => 'цыркавая палатка',
    '🚂' => 'лакаматыў',
    '🚃' => 'чыгуначны вагон',
    '🚄' => 'высакаскорасны цягнік',
    '🚅' => 'цягнік-пуля',
    '🚆' => 'цягнік',
    '🚇' => 'метро',
    '🚈' => 'электрычка',
    '🚉' => 'станцыя',
    '🚊' => 'трамвай',
    '🚝' => 'манарэйка',
    '🚞' => 'чыгунка ў гарах',
    '🚋' => 'трамвайны вагон',
    '🚌' => 'аўтобус',
    '🚍' => 'набліжаецца аўтобус',
    '🚎' => 'тралейбус',
    '🚐' => 'мікрааўтобус',
    '🚑' => 'хуткая дапамога',
    '🚒' => 'пажарная машына',
    '🚓' => 'паліцэйская машына',
    '🚔' => 'набліжаецца паліцэйская машына',
    '🚕' => 'таксі',
    '🚖' => 'набліжаецца таксі',
    '🚗' => 'аўтамабіль',
    '🚘' => 'набліжаецца аўтамабіль',
    '🚙' => 'джып',
    '🛻' => 'пікап',
    '🚚' => 'грузавік',
    '🚛' => 'аўтапоезд',
    '🚜' => 'трактар',
    '🏎' => 'гоначны аўтамабіль',
    '🏍' => 'матацыкл',
    '🛵' => 'скутар',
    '🦽' => 'інвалідная каляска з ручным прывадам',
    '🦼' => 'інвалідная каляска з маторам',
    '🛺' => 'аўтарыкша',
    '🚲' => 'веласіпед',
    '🛴' => 'самакат',
    '🛹' => 'скейтборд',
    '🛼' => 'ролікавы канёк',
    '🚏' => 'аўтобусны прыпынак',
    '🛣' => 'аўтамагістраль',
    '🛤' => 'чыгунка',
    '🛢' => 'бочка з нафтай',
    '⛽' => 'бензакалонка',
    '🛞' => 'кола',
    '🚨' => 'паліцэйская мігалка',
    '🚥' => 'гарызантальны святлафор',
    '🚦' => 'вертыкальны святлафор',
    '🛑' => 'знак “стоп”',
    '🚧' => 'будаўнічыя работы',
    '⚓' => 'якар',
    '🛟' => 'ратавальны круг',
    '⛵' => 'паруснік',
    '🛶' => 'каноэ',
    '🚤' => 'быстраходны катар',
    '🛳' => 'пасажырскі лайнер',
    '⛴' => 'паром',
    '🛥' => 'маторная лодка',
    '🚢' => 'карабель',
    '✈' => 'самалёт',
    '🛩' => 'невялікі самалёт',
    '🛫' => 'узлёт',
    '🛬' => 'пасадка',
    '🪂' => 'парашут',
    '💺' => 'месца',
    '🚁' => 'верталёт',
    '🚟' => 'падвесная чыгунка',
    '🚠' => 'горны фунікулёр',
    '🚡' => 'канатная дарога',
    '🛰' => 'спадарожнік',
    '🚀' => 'ракета',
    '🛸' => 'лятаючая талерка',
    '🛎' => 'званок у гатэлі',
    '🧳' => 'багаж',
    '⌛' => 'пясочны гадзіннік адлічыў час',
    '⏳' => 'пясочны гадзіннік лічыць час',
    '⌚' => 'наручны гадзіннік',
    '⏰' => 'будзільнік',
    '⏱' => 'секундамер',
    '⏲' => 'таймер',
    '🕰' => 'камінны гадзіннік',
    '🕛' => 'дванаццаць гадзін',
    '🕧' => 'палова на першую',
    '🕐' => 'адна гадзіна',
    '🕜' => 'палова на другую',
    '🕑' => 'дзве гадзіны',
    '🕝' => 'палова на трэцюю',
    '🕒' => 'тры гадзіны',
    '🕞' => 'палова на чацвёртую',
    '🕓' => 'чатыры гадзіны',
    '🕟' => 'палова на пятую',
    '🕔' => 'пяць гадзін',
    '🕠' => 'палова на шостую',
    '🕕' => 'шэсць гадзін',
    '🕡' => 'палова на сёмую',
    '🕖' => 'сем гадзін',
    '🕢' => 'палова на восьмую',
    '🕗' => 'восем гадзін',
    '🕣' => 'палова на дзявятую',
    '🕘' => 'дзевяць гадзін',
    '🕤' => 'палова на дзясятую',
    '🕙' => 'дзесяць гадзін',
    '🕥' => 'палова на адзінаццатую',
    '🕚' => 'адзінаццаць гадзін',
    '🕦' => 'палова на дванаццатую',
    '🌑' => 'маладзік',
    '🌒' => 'рост сярпа',
    '🌓' => 'першая чвэрць',
    '🌔' => 'рост гарба',
    '🌕' => 'поўня',
    '🌖' => 'змяншэнне гарба',
    '🌗' => 'апошняя чвэрць',
    '🌘' => 'змяншэнне сярпа',
    '🌙' => 'паўмесяц',
    '🌚' => 'маладзік з тварам',
    '🌛' => 'месяц у першай чвэрці з тварам',
    '🌜' => 'месяц у апошняй чвэрці з тварам',
    '🌡' => 'тэрмометр',
    '☀' => 'сонца',
    '🌝' => 'поўня з тварам',
    '🌞' => 'сонца з тварам',
    '🪐' => 'планета з кальцом',
    '⭐' => 'звычайная зорка',
    '🌟' => 'бліскучая зорка',
    '🌠' => 'знічка',
    '🌌' => 'млечны шлях',
    '☁' => 'воблака',
    '⛅' => 'сонца за воблакам',
    '⛈' => 'хмара з маланкай і дажджом',
    '🌤' => 'сонца за маленькім воблакам',
    '🌥' => 'сонца за вялікім воблакам',
    '🌦' => 'сонца за дажджавой хмарай',
    '🌧' => 'хмара і дождж',
    '🌨' => 'хмара і снег',
    '🌩' => 'хмара з маланкай',
    '🌪' => 'тарнада',
    '🌫' => 'туман',
    '🌬' => 'твар ветру',
    '🌀' => 'цыклон',
    '🌈' => 'вясёлка',
    '🌂' => 'закрыты парасон',
    '☂' => 'парасон',
    '☔' => 'парасон з кроплямі дажджу',
    '⛱' => 'пляжны парасон',
    '⚡' => 'высокае напружанне',
    '❄' => 'сняжынка',
    '☃' => 'снегавік',
    '⛄' => 'снегавік без снегападу',
    '☄' => 'камета',
    '🔥' => 'агонь',
    '💧' => 'кропелька',
    '🌊' => 'хваля',
    '🎃' => 'гарбузны ліхтар',
    '🎄' => 'навагодняя ёлка',
    '🎆' => 'феерверк',
    '🎇' => 'бенгальскі агонь',
    '🧨' => 'петарда',
    '✨' => 'іскры',
    '🎈' => 'паветраны шарык',
    '🎉' => 'хлапушка',
    '🎊' => 'шарык з канфеці',
    '🎋' => 'дрэва танабата',
    '🎍' => 'кадамацу',
    '🎎' => 'японскія лялькі',
    '🎏' => 'каінаборы',
    '🎐' => 'музычная падвеска',
    '🎑' => 'цукімі',
    '🧧' => 'чырвоны канверт',
    '🎀' => 'стужка',
    '🎁' => 'запакаваны падарунак',
    '🎗' => 'памятная стужка',
    '🎟' => 'уваходныя білеты',
    '🎫' => 'білет',
    '🎖' => 'ваенны медаль',
    '🏆' => 'кубак',
    '🏅' => 'спартыўны медаль',
    '🥇' => 'залаты медаль',
    '🥈' => 'сярэбраны медаль',
    '🥉' => 'бронзавы медаль',
    '⚽' => 'футбольны мяч',
    '⚾' => 'бейсбольны мяч',
    '🥎' => 'софтбол',
    '🏀' => 'баскетбол',
    '🏐' => 'валейбол',
    '🏈' => 'амерыканскі футбол',
    '🏉' => 'рэгбі',
    '🎾' => 'тэніс',
    '🥏' => 'фрысбі',
    '🎳' => 'боўлінг',
    '🏏' => 'крыкет',
    '🏑' => 'хакей на траве',
    '🏒' => 'хакей з шайбай',
    '🥍' => 'лакрос',
    '🏓' => 'пінг-понг',
    '🏸' => 'бадмінтон',
    '🥊' => 'баксёрская пальчатка',
    '🥋' => 'уніформа для адзінаборстваў',
    '🥅' => 'футбольныя вароты',
    '⛳' => 'флажок у лунцы',
    '⛸' => 'канёк',
    '🎣' => 'вуда для рыбалкі',
    '🤿' => 'маска для падводнага плавання',
    '🎽' => 'саколка для бегу',
    '🎿' => 'лыжы',
    '🛷' => 'санкі',
    '🥌' => 'шайба для кёрлінгу',
    '🎯' => 'прамое пападанне',
    '🪀' => 'ё-ё',
    '🪁' => 'паветраны змей',
    '🔫' => 'вадзяны пісталет',
    '🎱' => 'більярд',
    '🔮' => 'крыштальны шар',
    '🪄' => 'чароўная палачка',
    '🎮' => 'відэагульня',
    '🕹' => 'джойсцік',
    '🎰' => 'гульнявы аўтамат',
    '🎲' => 'ігральная косць',
    '🧩' => 'частка пазла',
    '🧸' => 'плюшавы мядзведзь',
    '🪅' => 'піньята',
    '🪩' => 'люстраны шар',
    '🪆' => 'матрошка',
    '♠' => 'віны',
    '♥' => 'чырвы',
    '♦' => 'звонкі',
    '♣' => 'трэфы',
    '♟' => 'пешка',
    '🃏' => 'джокер',
    '🀄' => 'чырвоны дракон у маджонгу',
    '🎴' => 'ігральныя карты ханафуда',
    '🎭' => 'выканальніцкія віды мастацтва',
    '🖼' => 'карціна ў рамцы',
    '🎨' => 'палітра мастака',
    '🧵' => 'нітка',
    '🪡' => 'швейная іголка',
    '🧶' => 'пража',
    '🪢' => 'вузел',
    '👓' => 'акуляры',
    '🕶' => 'сонечныя акуляры',
    '🥽' => 'ахоўныя акуляры',
    '🥼' => 'лабараторны халат',
    '🦺' => 'сігнальная камізэлька',
    '👔' => 'гальштук',
    '👕' => 'футболка',
    '👖' => 'джынсы',
    '🧣' => 'шалік',
    '🧤' => 'пальчаткі',
    '🧥' => 'паліто',
    '🧦' => 'шкарпэткі',
    '👗' => 'сукенка',
    '👘' => 'кімано',
    '🥻' => 'сары',
    '🩱' => 'закрыты купальнік',
    '🩲' => 'плаўкі',
    '🩳' => 'шорты',
    '👙' => 'бікіні',
    '👚' => 'жаночае адзенне',
    '🪭' => 'веер',
    '👛' => 'кашалёк',
    '👜' => 'дамская сумачка',
    '👝' => 'сумачка',
    '🛍' => 'пакеты для шопінгу',
    '🎒' => 'школьны ранец',
    '🩴' => 'в’етнамка',
    '👞' => 'мужчынскі туфель',
    '👟' => 'красовак',
    '🥾' => 'паходны бот',
    '🥿' => 'балетка',
    '👠' => 'туфель на абцасе',
    '👡' => 'жаночая сандаля',
    '🩰' => 'пуанты',
    '👢' => 'жаночы бот',
    '🪮' => 'грэбень',
    '👑' => 'карона',
    '👒' => 'жаночы капялюш',
    '🎩' => 'цыліндр',
    '🎓' => 'акадэмічная шапачка',
    '🧢' => 'кепка',
    '🪖' => 'ваенная каска',
    '⛑' => 'каска з белым крыжам',
    '📿' => 'ружанец',
    '💄' => 'памада',
    '💍' => 'кальцо',
    '💎' => 'каштоўны самацвет',
    '🔇' => 'без гуку',
    '🔈' => 'дынамік',
    '🔉' => 'ціха',
    '🔊' => 'гучна',
    '📢' => 'гучнагаварыцель',
    '📣' => 'мегафон',
    '📯' => 'паштовая труба',
    '🔔' => 'званочак',
    '🔕' => 'перакрэслены званочак',
    '🎼' => 'партытура',
    '🎵' => 'музычная нота',
    '🎶' => 'музычныя ноты',
    '🎙' => 'студыйны мікрафон',
    '🎚' => 'паўзунок',
    '🎛' => 'рэгулятары',
    '🎤' => 'мікрафон',
    '🎧' => 'навушнікі',
    '📻' => 'радыё',
    '🎷' => 'саксафон',
    '🎺' => 'труба',
    '🪊' => 'трамбон',
    '🪗' => 'акардэон',
    '🎸' => 'гітара',
    '🎹' => 'музычная клавіятура',
    '🎻' => 'скрыпка',
    '🪕' => 'банджа',
    '🥁' => 'барабан',
    '🪘' => 'выцягнуты барабан',
    '🪇' => 'маракасы',
    '🪈' => 'флейта',
    '🪉' => 'арфа',
    '📱' => 'мабільны тэлефон',
    '📲' => 'мабільны тэлефон са стрэлкай',
    '☎' => 'хатні тэлефон',
    '📞' => 'тэлефонная трубка',
    '📟' => 'пэйджар',
    '📠' => 'факсімільны апарат',
    '🔋' => 'батарэйка',
    '🪫' => 'нізкі зарад',
    '🔌' => 'вілка',
    '💻' => 'ноўтбук',
    '🖥' => 'стацыянарны камп’ютар',
    '🖨' => 'прынтар',
    '⌨' => 'клавіятура',
    '🖱' => 'камп’ютарная мыш',
    '🖲' => 'трэкбол',
    '💽' => 'міні-дыск',
    '💾' => 'дыскета',
    '💿' => 'аптычны дыск',
    '📀' => 'DVD',
    '🧮' => 'лічыльнікі',
    '🎥' => 'кінакамера',
    '🎞' => 'кінаплёнка',
    '📽' => 'кінапраектар',
    '🎬' => 'нумаратар з хлапушкай',
    '📺' => 'тэлевізар',
    '📷' => 'камера',
    '📸' => 'камера з успышкай',
    '📹' => 'відэакамера',
    '📼' => 'відэакасета',
    '🔍' => 'лупа павернута ўлева',
    '🔎' => 'лупа павернута ўправа',
    '🕯' => 'свечка',
    '💡' => 'лямпачка',
    '🔦' => 'ліхтарык',
    '🏮' => 'чырвоны папяровы ліхтар',
    '🪔' => 'лямпа дыя',
    '📔' => 'нататнік з дэкаратыўнай вокладкай',
    '📕' => 'закрытая кніга',
    '📖' => 'адкрытая кніга',
    '📗' => 'зялёная кніга',
    '📘' => 'сіняя кніга',
    '📙' => 'аранжавая кніга',
    '📚' => 'кнігі',
    '📓' => 'нататнік',
    '📒' => 'бухгалтарская кніга',
    '📃' => 'старонка з загібам',
    '📜' => 'скрутак',
    '📄' => 'старонка',
    '📰' => 'газета',
    '🗞' => 'скручаная газета',
    '📑' => 'закладкі',
    '🔖' => 'закладка',
    '🏷' => 'бірка',
    '🪙' => 'манета',
    '💰' => 'мяшок з грашыма',
    '🪎' => 'скрыня са скарбамі',
    '💴' => 'банкнот іены',
    '💵' => 'банкнот долара',
    '💶' => 'банкнот еўра',
    '💷' => 'банкнот фунта',
    '💸' => 'грошы з крыламі',
    '💳' => 'крэдытная карта',
    '🧾' => 'чэк',
    '💹' => 'дыяграма росту са знакам іены',
    '✉' => 'канверт',
    '📧' => 'электронны ліст',
    '📨' => 'уваходны ліст',
    '📩' => 'выходны ліст',
    '📤' => 'латок для выходнай пошты',
    '📥' => 'латок для ўваходнай пошты',
    '📦' => 'пасылка',
    '📫' => 'закрытая паштовая скрынка з паднятым флажком',
    '📪' => 'закрытая паштовая скрынка з апушчаным флажком',
    '📬' => 'адкрытая паштовая скрынка з паднятым флажком',
    '📭' => 'адкрытая паштовая скрынка з апушчаным флажком',
    '📮' => 'паштовая скрынка',
    '🗳' => 'урна для галасавання',
    '✏' => 'аловак',
    '✒' => 'чорнае пяро',
    '🖋' => 'пёравая ручка',
    '🖊' => 'аўтаручка',
    '🖌' => 'пэндзаль',
    '🖍' => 'пастэль',
    '📝' => 'памятка',
    '💼' => 'партфель',
    '📁' => 'папка для файлаў',
    '📂' => 'адкрытая папка для файлаў',
    '🗂' => 'раздзяляльнікі для картатэкі',
    '📅' => 'каляндар',
    '📆' => 'адрыўны каляндар',
    '🗒' => 'перакідны нататнік',
    '🗓' => 'перакідны каляндар',
    '📇' => 'картатэка',
    '📈' => 'дыяграма росту',
    '📉' => 'дыяграма зніжэння',
    '📊' => 'лінейчастая дыяграма',
    '📋' => 'планшэт з заціскам',
    '📌' => 'канцылярская кнопка',
    '📍' => 'круглая канцылярская кнопка',
    '📎' => 'сашчэпка',
    '🖇' => 'злучаныя сашчэпкі',
    '📏' => 'лінейка',
    '📐' => 'трохвугольная лінейка',
    '✂' => 'нажніцы',
    '🗃' => 'каробка для картатэкі',
    '🗄' => 'архіўная шафа',
    '🗑' => 'кошык для смецця',
    '🔒' => 'замкнёны замок',
    '🔓' => 'адамкнёны замок',
    '🔏' => 'замкнёны замок з пяром',
    '🔐' => 'замкнёны замок з ключом',
    '🔑' => 'ключ',
    '🗝' => 'стары ключ',
    '🔨' => 'малаток',
    '🪓' => 'сякера',
    '⛏' => 'кірка',
    '⚒' => 'малаток і кірка',
    '🛠' => 'малаток і гаечны ключ',
    '🗡' => 'кінжал',
    '⚔' => 'скрыжаваныя мячы',
    '💣' => 'бомба',
    '🪃' => 'бумеранг',
    '🏹' => 'лук са стралой',
    '🛡' => 'шчыт',
    '🪚' => 'піла',
    '🔧' => 'гаечны ключ',
    '🪛' => 'адвёртка',
    '🔩' => 'ніт і гайка',
    '⚙' => 'шасцярня',
    '🗜' => 'ціскі',
    '⚖' => 'шалі',
    '🦯' => 'палка',
    '🔗' => 'злучаныя звёны',
    '⛓' => 'ланцугі',
    '🪝' => 'кручок',
    '🧰' => 'скрыня з інструментамі',
    '🧲' => 'магніт',
    '🪜' => 'драбіны',
    '🪏' => 'шуфель',
    '⚗' => 'перагонны куб',
    '🧪' => 'прабірка',
    '🧫' => 'чашка Петры',
    '🧬' => 'ДНК',
    '🔬' => 'мікраскоп',
    '🔭' => 'тэлескоп',
    '📡' => 'спадарожнікавая антэна',
    '💉' => 'шпрыц',
    '🩸' => 'кропля крыві',
    '💊' => 'таблетка',
    '🩹' => 'пластыр',
    '🩼' => 'мыліца',
    '🩺' => 'стэтаскоп',
    '🩻' => 'рэнтген',
    '🚪' => 'дзверы',
    '🛗' => 'ліфт',
    '🪞' => 'люстэрка',
    '🪟' => 'акно',
    '🛏' => 'ложак',
    '🛋' => 'канапа з лямпай',
    '🪑' => 'крэсла',
    '🚽' => 'унітаз',
    '🪠' => 'вантуз',
    '🚿' => 'душ',
    '🛁' => 'ванна',
    '🪤' => 'пастка',
    '🪒' => 'брытва',
    '🧴' => 'бутэлька з ласьёнам',
    '🧷' => 'шпілька',
    '🧹' => 'мятла',
    '🧺' => 'кошык',
    '🧻' => 'рулон паперы',
    '🪣' => 'вядро',
    '🧼' => 'мыла',
    '🫧' => 'бурбалкі',
    '🪥' => 'зубная шчотка',
    '🧽' => 'мачалка',
    '🧯' => 'вогнетушыцель',
    '🛒' => 'каляска для тавараў',
    '🚬' => 'курэнне',
    '⚰' => 'труна',
    '🪦' => 'надмагільны помнік',
    '⚱' => 'урна з прахам',
    '🧿' => 'Назар',
    '🪬' => 'хамса',
    '🗿' => 'мааі',
    '🪧' => 'плакат',
    '🪪' => 'пасведчанне асобы',
    '🏧' => 'знак банкамата',
    '🚮' => 'знак «кідайце смецце ў урну»',
    '🚰' => 'пітная вада',
    '♿' => 'знак «для інвалідаў»',
    '🚹' => 'мужчынскі туалет',
    '🚺' => 'жаночы туалет',
    '🚻' => 'прыбіральня',
    '🚼' => 'знак «немаўля»',
    '🚾' => 'туалет',
    '🛂' => 'пашпартны кантроль',
    '🛃' => 'мытня',
    '🛄' => 'атрыманне багажу',
    '🛅' => 'камера для хавання',
    '⚠' => 'папярэджанне',
    '🚸' => 'дзеці на дарозе',
    '⛔' => 'уезд забаронены',
    '🚫' => 'забаронена',
    '🚳' => 'рух на веласіпедзе забаронены',
    '🚭' => 'курэнне забаронена',
    '🚯' => 'смеціць забаронена',
    '🚱' => 'непрыдатная для піцця вада',
    '🚷' => 'рух пешаходаў забаронены',
    '📵' => 'карыстацца мабільнымі тэлефонамі забаронена',
    '🔞' => 'толькі для паўналетніх',
    '☢' => 'радыяцыя',
    '☣' => 'біялагічная небяспека',
    '⬆' => 'стрэлка ўверх',
    '↗' => 'стрэлка ўверх-управа',
    '➡' => 'стрэлка ўправа',
    '↘' => 'стрэлка ўніз-управа',
    '⬇' => 'стрэлка ўніз',
    '↙' => 'стрэлка ўніз-улева',
    '⬅' => 'стрэлка ўлева',
    '↖' => 'стрэлка ўверх-улева',
    '↕' => 'стрэлка ўверх-уніз',
    '↔' => 'стрэлка ўлева-ўправа',
    '↩' => 'стрэлка ўправа з паваротам улева',
    '↪' => 'стрэлка ўлева з паваротам управа',
    '⤴' => 'стрэлка ўправа з паваротам уверх',
    '⤵' => 'стрэлка ўправа з паваротам уніз',
    '🔃' => 'вертыкальныя стрэлкі па гадзіннікавай стрэлцы',
    '🔄' => 'кнопка са стрэлкамі супраць гадзіннікавай стрэлкі',
    '🔙' => 'стрэлка «назад»',
    '🔚' => 'стрэлка «канец»',
    '🔛' => 'стрэлка «уключана!»',
    '🔜' => 'стрэлка «неўзабаве»',
    '🔝' => 'стрэлка «верх»',
    '🛐' => 'культавае памяшканне',
    '⚛' => 'сімвал атама',
    '🕉' => 'ом',
    '✡' => 'зорка Давіда',
    '☸' => 'кола дхармы',
    '☯' => 'інь і ян',
    '✝' => 'каталіцкі крыж',
    '☦' => 'праваслаўны крыж',
    '☪' => 'зорка і паўмесяц',
    '☮' => 'пацыфік',
    '🕎' => 'сямісвечнік',
    '🔯' => 'шасціканцовая зорка з кропкай',
    '🪯' => 'кханда',
    '♈' => 'знак задыяка Авен',
    '♉' => 'знак задыяка Цялец',
    '♊' => 'знак задыяка Блізняты',
    '♋' => 'знак задыяка Рак',
    '♌' => 'знак задыяка Леў',
    '♍' => 'знак задыяка Дзева',
    '♎' => 'знак задыяка Шалі',
    '♏' => 'знак задыяка Скарпіён',
    '♐' => 'знак задыяка Стралец',
    '♑' => 'знак задыяка Казярог',
    '♒' => 'знак задыяка Вадалей',
    '♓' => 'знак задыяка Рыбы',
    '⛎' => 'знак задыяка Змеяносец',
    '🔀' => 'кнопка «перамяшаць трэкі»',
    '🔁' => 'кнопка «паўтарыць»',
    '🔂' => 'кнопка «паўтараць адзін трэк»',
    '▶' => 'кнопка «прайграць»',
    '⏩' => 'кнопка перамоткі наперад',
    '⏭' => 'кнопка «наступны трэк»',
    '⏯' => 'кнопка «прайграць» і «прыпыніць»',
    '◀' => 'кнопка «прайграць назад»',
    '⏪' => 'кнопка перамоткі назад',
    '⏮' => 'кнопка «папярэдні трэк»',
    '🔼' => 'кнопка «уверх»',
    '⏫' => 'кнопка «хутка ўверх»',
    '🔽' => 'кнопка «ўніз»',
    '⏬' => 'кнопка «хутка ўніз»',
    '⏸' => 'кнопка «прыпыніць»',
    '⏹' => 'кнопка «спыніць»',
    '⏺' => 'кнопка «запіс»',
    '⏏' => 'кнопка «выняць»',
    '🎦' => 'кіно',
    '🔅' => 'кнопка змяншэння яркасці',
    '🔆' => 'кнопка павелічэння яркасці',
    '📶' => 'узровень сігналу сеткі',
    '🛜' => 'бесправадны',
    '📳' => 'рэжым вібрацыі',
    '📴' => 'мабільны тэлефон выключаны',
    '♀' => 'жаночы сімвал',
    '♂' => 'мужчынскі сімвал',
    '⚧' => 'сімвал трансгендара',
    '✖' => 'знак множання',
    '➕' => 'знак складання',
    '➖' => 'знак аднімання',
    '➗' => 'знак дзялення',
    '🟰' => 'тоўсты знак роўнасці',
    '♾' => 'бясконцасць',
    '‼' => 'два клічнікі',
    '⁉' => 'клічнік з пытальнікам',
    '❓' => 'пытальнік',
    '❔' => 'белы пытальнік',
    '❕' => 'белы клічнік',
    '❗' => 'чырвоны клічнік',
    '〰' => 'хвалісты працяжнік',
    '💱' => 'абмен валют',
    '💲' => 'знак долара',
    '⚕' => 'медыцынскі сімвал',
    '♻' => 'сімвал перапрацоўкі',
    '⚜' => 'геральдычная лілея',
    '🔱' => 'трызубец',
    '📛' => 'бэйдж з імем',
    '🔰' => 'японскі сімвал «пачатковец»',
    '⭕' => 'чырвонае кольца',
    '✅' => 'вялікая белая птушка',
    '☑' => 'квадрат з птушкай',
    '✔' => 'знак птушкі',
    '❌' => 'крыжык',
    '❎' => 'кнопка з крыжыкам',
    '➰' => 'звілістая пятля',
    '➿' => 'падвойная звілістая пятля',
    '〽' => 'знак змены партыі',
    '✳' => 'васьміканцовая зорачка',
    '✴' => 'васьміканцовая зорка',
    '❇' => 'іскра',
    '™' => 'таварны знак',
    '🫟' => 'пырскі',
    '🔠' => 'увод лацінскіх літар верхнім рэгістрам',
    '🔡' => 'увод лацінскіх літар ніжнім рэгістрам',
    '🔢' => 'увод лічбаў',
    '🔣' => 'увод сімвалаў',
    '🔤' => 'увод лацінскіх літар',
    '🅰' => 'значок «група крыві A»',
    '🆎' => 'AB (група крыві)',
    '🅱' => 'значок «група крыві B»',
    '🆑' => 'кнопка «ачысціць»',
    '🆒' => 'слова «файна» ў квадраце',
    '🆓' => 'слова «бясплатна» ў квадраце',
    'ℹ' => 'крыніца інфармацыі',
    '🆔' => 'слова «пасведчанне» ў квадраце',
    'Ⓜ' => 'літара «M» у коле',
    '🆕' => 'слова «новы» ў квадраце',
    '🆖' => 'скарачэнне «нічога добрага» ў квадраце',
    '🅾' => 'значок «група крыві 0»',
    '🆗' => 'ОК у квадраце',
    '🅿' => 'знак «паркоўка»',
    '🆘' => 'знак «SOS»',
    '🆙' => 'знак «новы ўзровень!»',
    '🆚' => 'знак «супраць»',
    '🈁' => 'ідэаграма «тут» у квадраце',
    '🈂' => 'ідэаграма «сэрвіс» у квадраце',
    '🈷' => 'ідэаграма «месяц» у квадраце',
    '🈶' => 'ідэаграма «ў наяўнасці» ў квадраце',
    '🈯' => 'ідэаграма «паказванне пальцам» у квадраце',
    '🉐' => 'ідэаграма «выгадная здзелка» ў крузе',
    '🈹' => 'ідэаграма «скідка» ў квадраце',
    '🈚' => 'ідэаграма «адсутнасць» у квадраце',
    '🈲' => 'ідэаграма «забаронена» ў квадраце',
    '🉑' => 'ідэаграма «прыняць» ў крузе',
    '🈸' => 'ідэаграма «заяўка» у квадраце',
    '🈴' => 'ідэаграма «пагадненне» ў квадраце',
    '🈳' => 'ідэаграма «свабодна» ў квадраце',
    '㊗' => 'ідэаграма «віншаванні» ў квадраце',
    '㊙' => 'ідэаграма «сакрэтна» ў крузе',
    '🈺' => 'ідэаграма «працуе» ў квадраце',
    '🈵' => 'ідэаграма «поўны» ў квадраце',
    '🔴' => 'чырвоны круг',
    '🟠' => 'аранжавы круг',
    '🟡' => 'жоўты круг',
    '🟢' => 'зялёны круг',
    '🔵' => 'сіні круг',
    '🟣' => 'фіялетавы круг',
    '🟤' => 'карычневы круг',
    '⚫' => 'чорны круг',
    '⚪' => 'белы круг',
    '🟥' => 'чырвоны квадрат',
    '🟧' => 'аранжавы квадрат',
    '🟨' => 'жоўты квадрат',
    '🟩' => 'зялёны квадрат',
    '🟦' => 'сіні квадрат',
    '🟪' => 'фіялетавы квадрат',
    '🟫' => 'карычневы квадрат',
    '⬛' => 'вялікі чорны квадрат',
    '⬜' => 'вялікі белы квадрат',
    '◼' => 'чорны сярэдні квадрат',
    '◻' => 'белы сярэдні квадрат',
    '◾' => 'невялікі чорны квадрат',
    '◽' => 'невялікі белы квадрат',
    '▪' => 'малы чорны квадрат',
    '▫' => 'малы белы квадрат',
    '🔶' => 'вялікі аранжавы ромб',
    '🔷' => 'вялікі сіні ромб',
    '🔸' => 'малы аранжавы ромб',
    '🔹' => 'малы сіні ромб',
    '🔺' => 'чырвоны трохвугольнік вяршыняй уверх',
    '🔻' => 'чырвоны трохвугольнік вяршыняй уніз',
    '💠' => 'ромб з кропкай',
    '🔘' => 'пераключальнік',
    '🔳' => 'белая квадратная кнопка',
    '🔲' => 'чорная квадратная кнопка',
    '🏁' => 'клятчасты сцяг',
    '🚩' => 'трохвугольны сцяг',
    '🎌' => 'скрыжаваныя сцягі',
    '🏴' => 'чорны сцяг развяваецца',
    '🏳' => 'белы сцяг развяваецца',
];
