<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'posa: şahs, şahs, açyk deri reňki, orta açyk deri reňki',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'posa: şahs, şahs, açyk deri reňki, orta deri reňki',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'posa: şahs, şahs, açyk deri reňki, orta goýy deri reňki',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'posa: şahs, şahs, açyk deri reňki, goýy deri reňki',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'posa: şahs, şahs, orta açyk deri reňki, açyk deri reňki',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'posa: şahs, şahs, orta açyk deri reňki, orta deri reňki',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'posa: şahs, şahs, orta açyk deri reňki, orta goýy deri reňki',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'posa: şahs, şahs, orta açyk deri reňki, goýy deri reňki',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'posa: şahs, şahs, orta deri reňki, açyk deri reňki',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'posa: şahs, şahs, orta deri reňki, orta açyk deri reňki',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'posa: şahs, şahs, orta deri reňki, orta goýy deri reňki',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'posa: şahs, şahs, orta deri reňki, goýy deri reňki',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'posa: şahs, şahs, orta goýy deri reňki, açyk deri reňki',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'posa: şahs, şahs, orta goýy deri reňki, orta açyk deri reňki',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'posa: şahs, şahs, orta goýy deri reňki, orta deri reňki',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'posa: şahs, şahs, orta goýy deri reňki, goýy deri reňki',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'posa: şahs, şahs, goýy deri reňki, açyk deri reňki',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'posa: şahs, şahs, goýy deri reňki, orta açyk deri reňki',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'posa: şahs, şahs, goýy deri reňki, orta deri reňki',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'posa: şahs, şahs, goýy deri reňki, orta goýy deri reňki',
    '👨🏻‍❤‍💋‍👨🏻' => 'posa: erkek, erkek, açyk deri reňki',
    '👨🏻‍❤‍💋‍👨🏼' => 'posa: erkek, erkek, açyk deri reňki, orta açyk deri reňki',
    '👨🏻‍❤‍💋‍👨🏽' => 'posa: erkek, erkek, açyk deri reňki, orta deri reňki',
    '👨🏻‍❤‍💋‍👨🏾' => 'posa: erkek, erkek, açyk deri reňki, orta goýy deri reňki',
    '👨🏻‍❤‍💋‍👨🏿' => 'posa: erkek, erkek, açyk deri reňki, goýy deri reňki',
    '👨🏼‍❤‍💋‍👨🏻' => 'posa: erkek, erkek, orta açyk deri reňki, açyk deri reňki',
    '👨🏼‍❤‍💋‍👨🏼' => 'posa: erkek, erkek, orta açyk deri reňki',
    '👨🏼‍❤‍💋‍👨🏽' => 'posa: erkek, erkek, orta açyk deri reňki, orta deri reňki',
    '👨🏼‍❤‍💋‍👨🏾' => 'posa: erkek, erkek, orta açyk deri reňki, orta goýy deri reňki',
    '👨🏼‍❤‍💋‍👨🏿' => 'posa: erkek, erkek, orta açyk deri reňki, goýy deri reňki',
    '👨🏽‍❤‍💋‍👨🏻' => 'posa: erkek, erkek, orta deri reňki, açyk deri reňki',
    '👨🏽‍❤‍💋‍👨🏼' => 'posa: erkek, erkek, orta deri reňki, orta açyk deri reňki',
    '👨🏽‍❤‍💋‍👨🏽' => 'posa: erkek, erkek, orta deri reňki',
    '👨🏽‍❤‍💋‍👨🏾' => 'posa: erkek, erkek, orta deri reňki, orta goýy deri reňki',
    '👨🏽‍❤‍💋‍👨🏿' => 'posa: erkek, erkek, orta deri reňki, goýy deri reňki',
    '👨🏾‍❤‍💋‍👨🏻' => 'posa: erkek, erkek, orta goýy deri reňki, açyk deri reňki',
    '👨🏾‍❤‍💋‍👨🏼' => 'posa: erkek, erkek, orta goýy deri reňki, orta açyk deri reňki',
    '👨🏾‍❤‍💋‍👨🏽' => 'posa: erkek, erkek, orta goýy deri reňki, orta deri reňki',
    '👨🏾‍❤‍💋‍👨🏾' => 'posa: erkek, erkek, orta goýy deri reňki',
    '👨🏾‍❤‍💋‍👨🏿' => 'posa: erkek, erkek, orta goýy deri reňki, goýy deri reňki',
    '👨🏿‍❤‍💋‍👨🏻' => 'posa: erkek, erkek, goýy deri reňki, açyk deri reňki',
    '👨🏿‍❤‍💋‍👨🏼' => 'posa: erkek, erkek, goýy deri reňki, orta açyk deri reňki',
    '👨🏿‍❤‍💋‍👨🏽' => 'posa: erkek, erkek, goýy deri reňki, orta deri reňki',
    '👨🏿‍❤‍💋‍👨🏾' => 'posa: erkek, erkek, goýy deri reňki, orta goýy deri reňki',
    '👨🏿‍❤‍💋‍👨🏿' => 'posa: erkek, erkek, goýy deri reňki',
    '👩🏻‍❤‍💋‍👨🏻' => 'posa: zenan, erkek, açyk deri reňki',
    '👩🏻‍❤‍💋‍👨🏼' => 'posa: zenan, erkek, açyk deri reňki, orta açyk deri reňki',
    '👩🏻‍❤‍💋‍👨🏽' => 'posa: zenan, erkek, açyk deri reňki, orta deri reňki',
    '👩🏻‍❤‍💋‍👨🏾' => 'posa: zenan, erkek, açyk deri reňki, orta goýy deri reňki',
    '👩🏻‍❤‍💋‍👨🏿' => 'posa: zenan, erkek, açyk deri reňki, goýy deri reňki',
    '👩🏼‍❤‍💋‍👨🏻' => 'posa: zenan, erkek, orta açyk deri reňki, açyk deri reňki',
    '👩🏼‍❤‍💋‍👨🏼' => 'posa: zenan, erkek, orta açyk deri reňki',
    '👩🏼‍❤‍💋‍👨🏽' => 'posa: zenan, erkek, orta açyk deri reňki, orta deri reňki',
    '👩🏼‍❤‍💋‍👨🏾' => 'posa: zenan, erkek, orta açyk deri reňki, orta goýy deri reňki',
    '👩🏼‍❤‍💋‍👨🏿' => 'posa: zenan, erkek, orta açyk deri reňki, goýy deri reňki',
    '👩🏽‍❤‍💋‍👨🏻' => 'posa: zenan, erkek, orta deri reňki, açyk deri reňki',
    '👩🏽‍❤‍💋‍👨🏼' => 'posa: zenan, erkek, orta deri reňki, orta açyk deri reňki',
    '👩🏽‍❤‍💋‍👨🏽' => 'posa: zenan, erkek, orta deri reňki',
    '👩🏽‍❤‍💋‍👨🏾' => 'posa: zenan, erkek, orta deri reňki, orta goýy deri reňki',
    '👩🏽‍❤‍💋‍👨🏿' => 'posa: zenan, erkek, orta deri reňki, goýy deri reňki',
    '👩🏾‍❤‍💋‍👨🏻' => 'posa: zenan, erkek, orta goýy deri reňki, açyk deri reňki',
    '👩🏾‍❤‍💋‍👨🏼' => 'posa: zenan, erkek, orta goýy deri reňki, orta açyk deri reňki',
    '👩🏾‍❤‍💋‍👨🏽' => 'posa: zenan, erkek, orta goýy deri reňki, orta deri reňki',
    '👩🏾‍❤‍💋‍👨🏾' => 'posa: zenan, erkek, orta goýy deri reňki',
    '👩🏾‍❤‍💋‍👨🏿' => 'posa: zenan, erkek, orta goýy deri reňki, goýy deri reňki',
    '👩🏿‍❤‍💋‍👨🏻' => 'posa: zenan, erkek, goýy deri reňki, açyk deri reňki',
    '👩🏿‍❤‍💋‍👨🏼' => 'posa: zenan, erkek, goýy deri reňki, orta açyk deri reňki',
    '👩🏿‍❤‍💋‍👨🏽' => 'posa: zenan, erkek, goýy deri reňki, orta deri reňki',
    '👩🏿‍❤‍💋‍👨🏾' => 'posa: zenan, erkek, goýy deri reňki, orta goýy deri reňki',
    '👩🏿‍❤‍💋‍👨🏿' => 'posa: zenan, erkek, goýy deri reňki',
    '👩🏻‍❤‍💋‍👩🏻' => 'posa: zenan, zenan, açyk deri reňki',
    '👩🏻‍❤‍💋‍👩🏼' => 'posa: zenan, zenan, açyk deri reňki, orta açyk deri reňki',
    '👩🏻‍❤‍💋‍👩🏽' => 'posa: zenan, zenan, açyk deri reňki, orta deri reňki',
    '👩🏻‍❤‍💋‍👩🏾' => 'posa: zenan, zenan, açyk deri reňki, orta goýy deri reňki',
    '👩🏻‍❤‍💋‍👩🏿' => 'posa: zenan, zenan, açyk deri reňki, goýy deri reňki',
    '👩🏼‍❤‍💋‍👩🏻' => 'posa: zenan, zenan, orta açyk deri reňki, açyk deri reňki',
    '👩🏼‍❤‍💋‍👩🏼' => 'posa: zenan, zenan, orta açyk deri reňki',
    '👩🏼‍❤‍💋‍👩🏽' => 'posa: zenan, zenan, orta açyk deri reňki, orta deri reňki',
    '👩🏼‍❤‍💋‍👩🏾' => 'posa: zenan, zenan, orta açyk deri reňki, orta goýy deri reňki',
    '👩🏼‍❤‍💋‍👩🏿' => 'posa: zenan, zenan, orta açyk deri reňki, goýy deri reňki',
    '👩🏽‍❤‍💋‍👩🏻' => 'posa: zenan, zenan, orta deri reňki, açyk deri reňki',
    '👩🏽‍❤‍💋‍👩🏼' => 'posa: zenan, zenan, orta deri reňki, orta açyk deri reňki',
    '👩🏽‍❤‍💋‍👩🏽' => 'posa: zenan, zenan, orta deri reňki',
    '👩🏽‍❤‍💋‍👩🏾' => 'posa: zenan, zenan, orta deri reňki, orta goýy deri reňki',
    '👩🏽‍❤‍💋‍👩🏿' => 'posa: zenan, zenan, orta deri reňki, goýy deri reňki',
    '👩🏾‍❤‍💋‍👩🏻' => 'posa: zenan, zenan, orta goýy deri reňki, açyk deri reňki',
    '👩🏾‍❤‍💋‍👩🏼' => 'posa: zenan, zenan, orta goýy deri reňki, orta açyk deri reňki',
    '👩🏾‍❤‍💋‍👩🏽' => 'posa: zenan, zenan, orta goýy deri reňki, orta deri reňki',
    '👩🏾‍❤‍💋‍👩🏾' => 'posa: zenan, zenan, orta goýy deri reňki',
    '👩🏾‍❤‍💋‍👩🏿' => 'posa: zenan, zenan, orta goýy deri reňki, goýy deri reňki',
    '👩🏿‍❤‍💋‍👩🏻' => 'posa: zenan, zenan, goýy deri reňki, açyk deri reňki',
    '👩🏿‍❤‍💋‍👩🏼' => 'posa: zenan, zenan, goýy deri reňki, orta açyk deri reňki',
    '👩🏿‍❤‍💋‍👩🏽' => 'posa: zenan, zenan, goýy deri reňki, orta deri reňki',
    '👩🏿‍❤‍💋‍👩🏾' => 'posa: zenan, zenan, goýy deri reňki, orta goýy deri reňki',
    '👩🏿‍❤‍💋‍👩🏿' => 'posa: zenan, zenan, goýy deri reňki',
    '🧑🏻‍🫯‍🧑🏼' => 'göreş tutýan adamlar: açyk deri reňki, orta açyk deri reňki',
    '🧑🏻‍🫯‍🧑🏽' => 'göreş tutýan adamlar: açyk deri reňki, orta deri reňki',
    '🧑🏻‍🫯‍🧑🏾' => 'göreş tutýan adamlar: açyk deri reňki, orta goýy deri reňki',
    '🧑🏻‍🫯‍🧑🏿' => 'göreş tutýan adamlar: açyk deri reňki, goýy deri reňki',
    '🧑🏼‍🫯‍🧑🏻' => 'göreş tutýan adamlar: orta açyk deri reňki, açyk deri reňki',
    '🧑🏼‍🫯‍🧑🏽' => 'göreş tutýan adamlar: orta açyk deri reňki, orta deri reňki',
    '🧑🏼‍🫯‍🧑🏾' => 'göreş tutýan adamlar: orta açyk deri reňki, orta goýy deri reňki',
    '🧑🏼‍🫯‍🧑🏿' => 'göreş tutýan adamlar: orta açyk deri reňki, goýy deri reňki',
    '🧑🏽‍🫯‍🧑🏻' => 'göreş tutýan adamlar: orta deri reňki, açyk deri reňki',
    '🧑🏽‍🫯‍🧑🏼' => 'göreş tutýan adamlar: orta deri reňki, orta açyk deri reňki',
    '🧑🏽‍🫯‍🧑🏾' => 'göreş tutýan adamlar: orta deri reňki, orta goýy deri reňki',
    '🧑🏽‍🫯‍🧑🏿' => 'göreş tutýan adamlar: orta deri reňki, goýy deri reňki',
    '🧑🏾‍🫯‍🧑🏻' => 'göreş tutýan adamlar: orta goýy deri reňki, açyk deri reňki',
    '🧑🏾‍🫯‍🧑🏼' => 'göreş tutýan adamlar: orta goýy deri reňki, orta açyk deri reňki',
    '🧑🏾‍🫯‍🧑🏽' => 'göreş tutýan adamlar: orta goýy deri reňki, orta deri reňki',
    '🧑🏾‍🫯‍🧑🏿' => 'göreş tutýan adamlar: orta goýy deri reňki, goýy deri reňki',
    '🧑🏿‍🫯‍🧑🏻' => 'göreş tutýan adamlar: goýy deri reňki, açyk deri reňki',
    '🧑🏿‍🫯‍🧑🏼' => 'göreş tutýan adamlar: goýy deri reňki, orta açyk deri reňki',
    '🧑🏿‍🫯‍🧑🏽' => 'göreş tutýan adamlar: goýy deri reňki, orta deri reňki',
    '🧑🏿‍🫯‍🧑🏾' => 'göreş tutýan adamlar: goýy deri reňki, orta goýy deri reňki',
    '🧑🏻‍❤‍🧑🏼' => 'ýürekli jübüt: şahs, şahs, açyk deri reňki, orta açyk deri reňki',
    '🧑🏻‍❤‍🧑🏽' => 'ýürekli jübüt: şahs, şahs, açyk deri reňki, orta deri reňki',
    '🧑🏻‍❤‍🧑🏾' => 'ýürekli jübüt: şahs, şahs, açyk deri reňki, orta goýy deri reňki',
    '🧑🏻‍❤‍🧑🏿' => 'ýürekli jübüt: şahs, şahs, açyk deri reňki, goýy deri reňki',
    '🧑🏼‍❤‍🧑🏻' => 'ýürekli jübüt: şahs, şahs, orta açyk deri reňki, açyk deri reňki',
    '🧑🏼‍❤‍🧑🏽' => 'ýürekli jübüt: şahs, şahs, orta açyk deri reňki, orta deri reňki',
    '🧑🏼‍❤‍🧑🏾' => 'ýürekli jübüt: şahs, şahs, orta açyk deri reňki, orta goýy deri reňki',
    '🧑🏼‍❤‍🧑🏿' => 'ýürekli jübüt: şahs, şahs, orta açyk deri reňki, goýy deri reňki',
    '🧑🏽‍❤‍🧑🏻' => 'ýürekli jübüt: şahs, şahs, orta deri reňki, açyk deri reňki',
    '🧑🏽‍❤‍🧑🏼' => 'ýürekli jübüt: şahs, şahs, orta deri reňki, orta açyk deri reňki',
    '🧑🏽‍❤‍🧑🏾' => 'ýürekli jübüt: şahs, şahs, orta deri reňki, orta goýy deri reňki',
    '🧑🏽‍❤‍🧑🏿' => 'ýürekli jübüt: şahs, şahs, orta deri reňki, goýy deri reňki',
    '🧑🏾‍❤‍🧑🏻' => 'ýürekli jübüt: şahs, şahs, orta goýy deri reňki, açyk deri reňki',
    '🧑🏾‍❤‍🧑🏼' => 'ýürekli jübüt: şahs, şahs, orta goýy deri reňki, orta açyk deri reňki',
    '🧑🏾‍❤‍🧑🏽' => 'ýürekli jübüt: şahs, şahs, orta goýy deri reňki, orta deri reňki',
    '🧑🏾‍❤‍🧑🏿' => 'ýürekli jübüt: şahs, şahs, orta goýy deri reňki, goýy deri reňki',
    '🧑🏿‍❤‍🧑🏻' => 'ýürekli jübüt: şahs, şahs, goýy deri reňki, açyk deri reňki',
    '🧑🏿‍❤‍🧑🏼' => 'ýürekli jübüt: şahs, şahs, goýy deri reňki, orta açyk deri reňki',
    '🧑🏿‍❤‍🧑🏽' => 'ýürekli jübüt: şahs, şahs, goýy deri reňki, orta deri reňki',
    '🧑🏿‍❤‍🧑🏾' => 'ýürekli jübüt: şahs, şahs, goýy deri reňki, orta goýy deri reňki',
    '🧑🏻‍🐰‍🧑🏼' => 'towşan gulakly adamlar: açyk deri reňki, orta açyk deri reňki',
    '🧑🏻‍🐰‍🧑🏽' => 'towşan gulakly adamlar: açyk deri reňki, orta deri reňki',
    '🧑🏻‍🐰‍🧑🏾' => 'towşan gulakly adamlar: açyk deri reňki, orta goýy deri reňki',
    '🧑🏻‍🐰‍🧑🏿' => 'towşan gulakly adamlar: açyk deri reňki, goýy deri reňki',
    '🧑🏼‍🐰‍🧑🏻' => 'towşan gulakly adamlar: orta açyk deri reňki, açyk deri reňki',
    '🧑🏼‍🐰‍🧑🏽' => 'towşan gulakly adamlar: orta açyk deri reňki, orta deri reňki',
    '🧑🏼‍🐰‍🧑🏾' => 'towşan gulakly adamlar: orta açyk deri reňki, orta goýy deri reňki',
    '🧑🏼‍🐰‍🧑🏿' => 'towşan gulakly adamlar: orta açyk deri reňki, goýy deri reňki',
    '🧑🏽‍🐰‍🧑🏻' => 'towşan gulakly adamlar: orta deri reňki, açyk deri reňki',
    '🧑🏽‍🐰‍🧑🏼' => 'towşan gulakly adamlar: orta deri reňki, orta açyk deri reňki',
    '🧑🏽‍🐰‍🧑🏾' => 'towşan gulakly adamlar: orta deri reňki, orta goýy deri reňki',
    '🧑🏽‍🐰‍🧑🏿' => 'towşan gulakly adamlar: orta deri reňki, goýy deri reňki',
    '🧑🏾‍🐰‍🧑🏻' => 'towşan gulakly adamlar: orta goýy deri reňki, açyk deri reňki',
    '🧑🏾‍🐰‍🧑🏼' => 'towşan gulakly adamlar: orta goýy deri reňki, orta açyk deri reňki',
    '🧑🏾‍🐰‍🧑🏽' => 'towşan gulakly adamlar: orta goýy deri reňki, orta deri reňki',
    '🧑🏾‍🐰‍🧑🏿' => 'towşan gulakly adamlar: orta goýy deri reňki, goýy deri reňki',
    '🧑🏿‍🐰‍🧑🏻' => 'towşan gulakly adamlar: goýy deri reňki, açyk deri reňki',
    '🧑🏿‍🐰‍🧑🏼' => 'towşan gulakly adamlar: goýy deri reňki, orta açyk deri reňki',
    '🧑🏿‍🐰‍🧑🏽' => 'towşan gulakly adamlar: goýy deri reňki, orta deri reňki',
    '🧑🏿‍🐰‍🧑🏾' => 'towşan gulakly adamlar: goýy deri reňki, orta goýy deri reňki',
    '👨🏻‍🫯‍👨🏼' => 'göreş tutýan erkekler: açyk deri reňki, orta açyk deri reňki',
    '👨🏻‍🫯‍👨🏽' => 'göreş tutýan erkekler: açyk deri reňki, orta deri reňki',
    '👨🏻‍🫯‍👨🏾' => 'göreş tutýan erkekler: açyk deri reňki, orta goýy deri reňki',
    '👨🏻‍🫯‍👨🏿' => 'göreş tutýan erkekler: açyk deri reňki, goýy deri reňki',
    '👨🏼‍🫯‍👨🏻' => 'göreş tutýan erkekler: orta açyk deri reňki, açyk deri reňki',
    '👨🏼‍🫯‍👨🏽' => 'göreş tutýan erkekler: orta açyk deri reňki, orta deri reňki',
    '👨🏼‍🫯‍👨🏾' => 'göreş tutýan erkekler: orta açyk deri reňki, orta goýy deri reňki',
    '👨🏼‍🫯‍👨🏿' => 'göreş tutýan erkekler: orta açyk deri reňki, goýy deri reňki',
    '👨🏽‍🫯‍👨🏻' => 'göreş tutýan erkekler: orta deri reňki, açyk deri reňki',
    '👨🏽‍🫯‍👨🏼' => 'göreş tutýan erkekler: orta deri reňki, orta açyk deri reňki',
    '👨🏽‍🫯‍👨🏾' => 'göreş tutýan erkekler: orta deri reňki, orta goýy deri reňki',
    '👨🏽‍🫯‍👨🏿' => 'göreş tutýan erkekler: orta deri reňki, goýy deri reňki',
    '👨🏾‍🫯‍👨🏻' => 'göreş tutýan erkekler: orta goýy deri reňki, açyk deri reňki',
    '👨🏾‍🫯‍👨🏼' => 'göreş tutýan erkekler: orta goýy deri reňki, orta açyk deri reňki',
    '👨🏾‍🫯‍👨🏽' => 'göreş tutýan erkekler: orta goýy deri reňki, orta deri reňki',
    '👨🏾‍🫯‍👨🏿' => 'göreş tutýan erkekler: orta goýy deri reňki, goýy deri reňki',
    '👨🏿‍🫯‍👨🏻' => 'göreş tutýan erkekler: goýy deri reňki, açyk deri reňki',
    '👨🏿‍🫯‍👨🏼' => 'göreş tutýan erkekler: goýy deri reňki, orta açyk deri reňki',
    '👨🏿‍🫯‍👨🏽' => 'göreş tutýan erkekler: goýy deri reňki, orta deri reňki',
    '👨🏿‍🫯‍👨🏾' => 'göreş tutýan erkekler: goýy deri reňki, orta goýy deri reňki',
    '👨🏻‍❤‍👨🏻' => 'ýürekli jübüt: erkek, erkek, açyk deri reňki',
    '👨🏻‍❤‍👨🏼' => 'ýürekli jübüt: erkek, erkek, açyk deri reňki, orta açyk deri reňki',
    '👨🏻‍❤‍👨🏽' => 'ýürekli jübüt: erkek, erkek, açyk deri reňki, orta deri reňki',
    '👨🏻‍❤‍👨🏾' => 'ýürekli jübüt: erkek, erkek, açyk deri reňki, orta goýy deri reňki',
    '👨🏻‍❤‍👨🏿' => 'ýürekli jübüt: erkek, erkek, açyk deri reňki, goýy deri reňki',
    '👨🏼‍❤‍👨🏻' => 'ýürekli jübüt: erkek, erkek, orta açyk deri reňki, açyk deri reňki',
    '👨🏼‍❤‍👨🏼' => 'ýürekli jübüt: erkek, erkek, orta açyk deri reňki',
    '👨🏼‍❤‍👨🏽' => 'ýürekli jübüt: erkek, erkek, orta açyk deri reňki, orta deri reňki',
    '👨🏼‍❤‍👨🏾' => 'ýürekli jübüt: erkek, erkek, orta açyk deri reňki, orta goýy deri reňki',
    '👨🏼‍❤‍👨🏿' => 'ýürekli jübüt: erkek, erkek, orta açyk deri reňki, goýy deri reňki',
    '👨🏽‍❤‍👨🏻' => 'ýürekli jübüt: erkek, erkek, orta deri reňki, açyk deri reňki',
    '👨🏽‍❤‍👨🏼' => 'ýürekli jübüt: erkek, erkek, orta deri reňki, orta açyk deri reňki',
    '👨🏽‍❤‍👨🏽' => 'ýürekli jübüt: erkek, erkek, orta deri reňki',
    '👨🏽‍❤‍👨🏾' => 'ýürekli jübüt: erkek, erkek, orta deri reňki, orta goýy deri reňki',
    '👨🏽‍❤‍👨🏿' => 'ýürekli jübüt: erkek, erkek, orta deri reňki, goýy deri reňki',
    '👨🏾‍❤‍👨🏻' => 'ýürekli jübüt: erkek, erkek, orta goýy deri reňki, açyk deri reňki',
    '👨🏾‍❤‍👨🏼' => 'ýürekli jübüt: erkek, erkek, orta goýy deri reňki, orta açyk deri reňki',
    '👨🏾‍❤‍👨🏽' => 'ýürekli jübüt: erkek, erkek, orta goýy deri reňki, orta deri reňki',
    '👨🏾‍❤‍👨🏾' => 'ýürekli jübüt: erkek, erkek, orta goýy deri reňki',
    '👨🏾‍❤‍👨🏿' => 'ýürekli jübüt: erkek, erkek, orta goýy deri reňki, goýy deri reňki',
    '👨🏿‍❤‍👨🏻' => 'ýürekli jübüt: erkek, erkek, goýy deri reňki, açyk deri reňki',
    '👨🏿‍❤‍👨🏼' => 'ýürekli jübüt: erkek, erkek, goýy deri reňki, orta açyk deri reňki',
    '👨🏿‍❤‍👨🏽' => 'ýürekli jübüt: erkek, erkek, goýy deri reňki, orta deri reňki',
    '👨🏿‍❤‍👨🏾' => 'ýürekli jübüt: erkek, erkek, goýy deri reňki, orta goýy deri reňki',
    '👨🏿‍❤‍👨🏿' => 'ýürekli jübüt: erkek, erkek, goýy deri reňki',
    '👨🏻‍🐰‍👨🏼' => 'towşan gulakly erkekler: açyk deri reňki, orta açyk deri reňki',
    '👨🏻‍🐰‍👨🏽' => 'towşan gulakly erkekler: açyk deri reňki, orta deri reňki',
    '👨🏻‍🐰‍👨🏾' => 'towşan gulakly erkekler: açyk deri reňki, orta goýy deri reňki',
    '👨🏻‍🐰‍👨🏿' => 'towşan gulakly erkekler: açyk deri reňki, goýy deri reňki',
    '👨🏼‍🐰‍👨🏻' => 'towşan gulakly erkekler: orta açyk deri reňki, açyk deri reňki',
    '👨🏼‍🐰‍👨🏽' => 'towşan gulakly erkekler: orta açyk deri reňki, orta deri reňki',
    '👨🏼‍🐰‍👨🏾' => 'towşan gulakly erkekler: orta açyk deri reňki, orta goýy deri reňki',
    '👨🏼‍🐰‍👨🏿' => 'towşan gulakly erkekler: orta açyk deri reňki, goýy deri reňki',
    '👨🏽‍🐰‍👨🏻' => 'towşan gulakly erkekler: orta deri reňki, açyk deri reňki',
    '👨🏽‍🐰‍👨🏼' => 'towşan gulakly erkekler: orta deri reňki, orta açyk deri reňki',
    '👨🏽‍🐰‍👨🏾' => 'towşan gulakly erkekler: orta deri reňki, orta goýy deri reňki',
    '👨🏽‍🐰‍👨🏿' => 'towşan gulakly erkekler: orta deri reňki, goýy deri reňki',
    '👨🏾‍🐰‍👨🏻' => 'towşan gulakly erkekler: orta goýy deri reňki, açyk deri reňki',
    '👨🏾‍🐰‍👨🏼' => 'towşan gulakly erkekler: orta goýy deri reňki, orta açyk deri reňki',
    '👨🏾‍🐰‍👨🏽' => 'towşan gulakly erkekler: orta goýy deri reňki, orta deri reňki',
    '👨🏾‍🐰‍👨🏿' => 'towşan gulakly erkekler: orta goýy deri reňki, goýy deri reňki',
    '👨🏿‍🐰‍👨🏻' => 'towşan gulakly erkekler: goýy deri reňki, açyk deri reňki',
    '👨🏿‍🐰‍👨🏼' => 'towşan gulakly erkekler: goýy deri reňki, orta açyk deri reňki',
    '👨🏿‍🐰‍👨🏽' => 'towşan gulakly erkekler: goýy deri reňki, orta deri reňki',
    '👨🏿‍🐰‍👨🏾' => 'towşan gulakly erkekler: goýy deri reňki, orta goýy deri reňki',
    '👩🏻‍🫯‍👩🏼' => 'göreş tutýan zenanlar: açyk deri reňki, orta açyk deri reňki',
    '👩🏻‍🫯‍👩🏽' => 'göreş tutýan zenanlar: açyk deri reňki, orta deri reňki',
    '👩🏻‍🫯‍👩🏾' => 'göreş tutýan zenanlar: açyk deri reňki, orta goýy deri reňki',
    '👩🏻‍🫯‍👩🏿' => 'göreş tutýan zenanlar: açyk deri reňki, goýy deri reňki',
    '👩🏼‍🫯‍👩🏻' => 'göreş tutýan zenanlar: orta açyk deri reňki, açyk deri reňki',
    '👩🏼‍🫯‍👩🏽' => 'göreş tutýan zenanlar: orta açyk deri reňki, orta deri reňki',
    '👩🏼‍🫯‍👩🏾' => 'göreş tutýan zenanlar: orta açyk deri reňki, orta goýy deri reňki',
    '👩🏼‍🫯‍👩🏿' => 'göreş tutýan zenanlar: orta açyk deri reňki, goýy deri reňki',
    '👩🏽‍🫯‍👩🏻' => 'göreş tutýan zenanlar: orta deri reňki, açyk deri reňki',
    '👩🏽‍🫯‍👩🏼' => 'göreş tutýan zenanlar: orta deri reňki, orta açyk deri reňki',
    '👩🏽‍🫯‍👩🏾' => 'göreş tutýan zenanlar: orta deri reňki, orta goýy deri reňki',
    '👩🏽‍🫯‍👩🏿' => 'göreş tutýan zenanlar: orta deri reňki, goýy deri reňki',
    '👩🏾‍🫯‍👩🏻' => 'göreş tutýan zenanlar: orta goýy deri reňki, açyk deri reňki',
    '👩🏾‍🫯‍👩🏼' => 'göreş tutýan zenanlar: orta goýy deri reňki, orta açyk deri reňki',
    '👩🏾‍🫯‍👩🏽' => 'göreş tutýan zenanlar: orta goýy deri reňki, orta deri reňki',
    '👩🏾‍🫯‍👩🏿' => 'göreş tutýan zenanlar: orta goýy deri reňki, goýy deri reňki',
    '👩🏿‍🫯‍👩🏻' => 'göreş tutýan zenanlar: goýy deri reňki, açyk deri reňki',
    '👩🏿‍🫯‍👩🏼' => 'göreş tutýan zenanlar: goýy deri reňki, orta açyk deri reňki',
    '👩🏿‍🫯‍👩🏽' => 'göreş tutýan zenanlar: goýy deri reňki, orta deri reňki',
    '👩🏿‍🫯‍👩🏾' => 'göreş tutýan zenanlar: goýy deri reňki, orta goýy deri reňki',
    '👩🏻‍❤‍👨🏻' => 'ýürekli jübüt: zenan, erkek, açyk deri reňki',
    '👩🏻‍❤‍👨🏼' => 'ýürekli jübüt: zenan, erkek, açyk deri reňki, orta açyk deri reňki',
    '👩🏻‍❤‍👨🏽' => 'ýürekli jübüt: zenan, erkek, açyk deri reňki, orta deri reňki',
    '👩🏻‍❤‍👨🏾' => 'ýürekli jübüt: zenan, erkek, açyk deri reňki, orta goýy deri reňki',
    '👩🏻‍❤‍👨🏿' => 'ýürekli jübüt: zenan, erkek, açyk deri reňki, goýy deri reňki',
    '👩🏼‍❤‍👨🏻' => 'ýürekli jübüt: zenan, erkek, orta açyk deri reňki, açyk deri reňki',
    '👩🏼‍❤‍👨🏼' => 'ýürekli jübüt: zenan, erkek, orta açyk deri reňki',
    '👩🏼‍❤‍👨🏽' => 'ýürekli jübüt: zenan, erkek, orta açyk deri reňki, orta deri reňki',
    '👩🏼‍❤‍👨🏾' => 'ýürekli jübüt: zenan, erkek, orta açyk deri reňki, orta goýy deri reňki',
    '👩🏼‍❤‍👨🏿' => 'ýürekli jübüt: zenan, erkek, orta açyk deri reňki, goýy deri reňki',
    '👩🏽‍❤‍👨🏻' => 'ýürekli jübüt: zenan, erkek, orta deri reňki, açyk deri reňki',
    '👩🏽‍❤‍👨🏼' => 'ýürekli jübüt: zenan, erkek, orta deri reňki, orta açyk deri reňki',
    '👩🏽‍❤‍👨🏽' => 'ýürekli jübüt: zenan, erkek, orta deri reňki',
    '👩🏽‍❤‍👨🏾' => 'ýürekli jübüt: zenan, erkek, orta deri reňki, orta goýy deri reňki',
    '👩🏽‍❤‍👨🏿' => 'ýürekli jübüt: zenan, erkek, orta deri reňki, goýy deri reňki',
    '👩🏾‍❤‍👨🏻' => 'ýürekli jübüt: zenan, erkek, orta goýy deri reňki, açyk deri reňki',
    '👩🏾‍❤‍👨🏼' => 'ýürekli jübüt: zenan, erkek, orta goýy deri reňki, orta açyk deri reňki',
    '👩🏾‍❤‍👨🏽' => 'ýürekli jübüt: zenan, erkek, orta goýy deri reňki, orta deri reňki',
    '👩🏾‍❤‍👨🏾' => 'ýürekli jübüt: zenan, erkek, orta goýy deri reňki',
    '👩🏾‍❤‍👨🏿' => 'ýürekli jübüt: zenan, erkek, orta goýy deri reňki, goýy deri reňki',
    '👩🏿‍❤‍👨🏻' => 'ýürekli jübüt: zenan, erkek, goýy deri reňki, açyk deri reňki',
    '👩🏿‍❤‍👨🏼' => 'ýürekli jübüt: zenan, erkek, goýy deri reňki, orta açyk deri reňki',
    '👩🏿‍❤‍👨🏽' => 'ýürekli jübüt: zenan, erkek, goýy deri reňki, orta deri reňki',
    '👩🏿‍❤‍👨🏾' => 'ýürekli jübüt: zenan, erkek, goýy deri reňki, orta goýy deri reňki',
    '👩🏿‍❤‍👨🏿' => 'ýürekli jübüt: zenan, erkek, goýy deri reňki',
    '👩🏻‍❤‍👩🏻' => 'ýürekli jübüt: zenan, zenan, açyk deri reňki',
    '👩🏻‍❤‍👩🏼' => 'ýürekli jübüt: zenan, zenan, açyk deri reňki, orta açyk deri reňki',
    '👩🏻‍❤‍👩🏽' => 'ýürekli jübüt: zenan, zenan, açyk deri reňki, orta deri reňki',
    '👩🏻‍❤‍👩🏾' => 'ýürekli jübüt: zenan, zenan, açyk deri reňki, orta goýy deri reňki',
    '👩🏻‍❤‍👩🏿' => 'ýürekli jübüt: zenan, zenan, açyk deri reňki, goýy deri reňki',
    '👩🏼‍❤‍👩🏻' => 'ýürekli jübüt: zenan, zenan, orta açyk deri reňki, açyk deri reňki',
    '👩🏼‍❤‍👩🏼' => 'ýürekli jübüt: zenan, zenan, orta açyk deri reňki',
    '👩🏼‍❤‍👩🏽' => 'ýürekli jübüt: zenan, zenan, orta açyk deri reňki, orta deri reňki',
    '👩🏼‍❤‍👩🏾' => 'ýürekli jübüt: zenan, zenan, orta açyk deri reňki, orta goýy deri reňki',
    '👩🏼‍❤‍👩🏿' => 'ýürekli jübüt: zenan, zenan, orta açyk deri reňki, goýy deri reňki',
    '👩🏽‍❤‍👩🏻' => 'ýürekli jübüt: zenan, zenan, orta deri reňki, açyk deri reňki',
    '👩🏽‍❤‍👩🏼' => 'ýürekli jübüt: zenan, zenan, orta deri reňki, orta açyk deri reňki',
    '👩🏽‍❤‍👩🏽' => 'ýürekli jübüt: zenan, zenan, orta deri reňki',
    '👩🏽‍❤‍👩🏾' => 'ýürekli jübüt: zenan, zenan, orta deri reňki, orta goýy deri reňki',
    '👩🏽‍❤‍👩🏿' => 'ýürekli jübüt: zenan, zenan, orta deri reňki, goýy deri reňki',
    '👩🏾‍❤‍👩🏻' => 'ýürekli jübüt: zenan, zenan, orta goýy deri reňki, açyk deri reňki',
    '👩🏾‍❤‍👩🏼' => 'ýürekli jübüt: zenan, zenan, orta goýy deri reňki, orta açyk deri reňki',
    '👩🏾‍❤‍👩🏽' => 'ýürekli jübüt: zenan, zenan, orta goýy deri reňki, orta deri reňki',
    '👩🏾‍❤‍👩🏾' => 'ýürekli jübüt: zenan, zenan, orta goýy deri reňki',
    '👩🏾‍❤‍👩🏿' => 'ýürekli jübüt: zenan, zenan, orta goýy deri reňki, goýy deri reňki',
    '👩🏿‍❤‍👩🏻' => 'ýürekli jübüt: zenan, zenan, goýy deri reňki, açyk deri reňki',
    '👩🏿‍❤‍👩🏼' => 'ýürekli jübüt: zenan, zenan, goýy deri reňki, orta açyk deri reňki',
    '👩🏿‍❤‍👩🏽' => 'ýürekli jübüt: zenan, zenan, goýy deri reňki, orta deri reňki',
    '👩🏿‍❤‍👩🏾' => 'ýürekli jübüt: zenan, zenan, goýy deri reňki, orta goýy deri reňki',
    '👩🏿‍❤‍👩🏿' => 'ýürekli jübüt: zenan, zenan, goýy deri reňki',
    '👩🏻‍🐰‍👩🏼' => 'towşan gulakly zenanlar: açyk deri reňki, orta açyk deri reňki',
    '👩🏻‍🐰‍👩🏽' => 'towşan gulakly zenanlar: açyk deri reňki, orta deri reňki',
    '👩🏻‍🐰‍👩🏾' => 'towşan gulakly zenanlar: açyk deri reňki, orta goýy deri reňki',
    '👩🏻‍🐰‍👩🏿' => 'towşan gulakly zenanlar: açyk deri reňki, goýy deri reňki',
    '👩🏼‍🐰‍👩🏻' => 'towşan gulakly zenanlar: orta açyk deri reňki, açyk deri reňki',
    '👩🏼‍🐰‍👩🏽' => 'towşan gulakly zenanlar: orta açyk deri reňki, orta deri reňki',
    '👩🏼‍🐰‍👩🏾' => 'towşan gulakly zenanlar: orta açyk deri reňki, orta goýy deri reňki',
    '👩🏼‍🐰‍👩🏿' => 'towşan gulakly zenanlar: orta açyk deri reňki, goýy deri reňki',
    '👩🏽‍🐰‍👩🏻' => 'towşan gulakly zenanlar: orta deri reňki, açyk deri reňki',
    '👩🏽‍🐰‍👩🏼' => 'towşan gulakly zenanlar: orta deri reňki, orta açyk deri reňki',
    '👩🏽‍🐰‍👩🏾' => 'towşan gulakly zenanlar: orta deri reňki, orta goýy deri reňki',
    '👩🏽‍🐰‍👩🏿' => 'towşan gulakly zenanlar: orta deri reňki, goýy deri reňki',
    '👩🏾‍🐰‍👩🏻' => 'towşan gulakly zenanlar: orta goýy deri reňki, açyk deri reňki',
    '👩🏾‍🐰‍👩🏼' => 'towşan gulakly zenanlar: orta goýy deri reňki, orta açyk deri reňki',
    '👩🏾‍🐰‍👩🏽' => 'towşan gulakly zenanlar: orta goýy deri reňki, orta deri reňki',
    '👩🏾‍🐰‍👩🏿' => 'towşan gulakly zenanlar: orta goýy deri reňki, goýy deri reňki',
    '👩🏿‍🐰‍👩🏻' => 'towşan gulakly zenanlar: goýy deri reňki, açyk deri reňki',
    '👩🏿‍🐰‍👩🏼' => 'towşan gulakly zenanlar: goýy deri reňki, orta açyk deri reňki',
    '👩🏿‍🐰‍👩🏽' => 'towşan gulakly zenanlar: goýy deri reňki, orta deri reňki',
    '👩🏿‍🐰‍👩🏾' => 'towşan gulakly zenanlar: goýy deri reňki, orta goýy deri reňki',
    '🧑🏻‍🤝‍🧑🏻' => 'el tutuşýan adamlar: açyk deri reňki',
    '🧑🏻‍🤝‍🧑🏼' => 'el tutuşýan adamlar: açyk deri reňki, orta açyk deri reňki',
    '🧑🏻‍🤝‍🧑🏽' => 'el tutuşýan adamlar: açyk deri reňki, orta deri reňki',
    '🧑🏻‍🤝‍🧑🏾' => 'el tutuşýan adamlar: açyk deri reňki, orta goýy deri reňki',
    '🧑🏻‍🤝‍🧑🏿' => 'el tutuşýan adamlar: açyk deri reňki, goýy deri reňki',
    '🧑🏼‍🤝‍🧑🏻' => 'el tutuşýan adamlar: orta açyk deri reňki, açyk deri reňki',
    '🧑🏼‍🤝‍🧑🏼' => 'el tutuşýan adamlar: orta açyk deri reňki',
    '🧑🏼‍🤝‍🧑🏽' => 'el tutuşýan adamlar: orta açyk deri reňki, orta deri reňki',
    '🧑🏼‍🤝‍🧑🏾' => 'el tutuşýan adamlar: orta açyk deri reňki, orta goýy deri reňki',
    '🧑🏼‍🤝‍🧑🏿' => 'el tutuşýan adamlar: orta açyk deri reňki, goýy deri reňki',
    '🧑🏽‍🤝‍🧑🏻' => 'el tutuşýan adamlar: orta deri reňki, açyk deri reňki',
    '🧑🏽‍🤝‍🧑🏼' => 'el tutuşýan adamlar: orta deri reňki, orta açyk deri reňki',
    '🧑🏽‍🤝‍🧑🏽' => 'el tutuşýan adamlar: orta deri reňki',
    '🧑🏽‍🤝‍🧑🏾' => 'el tutuşýan adamlar: orta deri reňki, orta goýy deri reňki',
    '🧑🏽‍🤝‍🧑🏿' => 'el tutuşýan adamlar: orta deri reňki, goýy deri reňki',
    '🧑🏾‍🤝‍🧑🏻' => 'el tutuşýan adamlar: orta goýy deri reňki, açyk deri reňki',
    '🧑🏾‍🤝‍🧑🏼' => 'el tutuşýan adamlar: orta goýy deri reňki, orta açyk deri reňki',
    '🧑🏾‍🤝‍🧑🏽' => 'el tutuşýan adamlar: orta goýy deri reňki, orta deri reňki',
    '🧑🏾‍🤝‍🧑🏾' => 'el tutuşýan adamlar: orta goýy deri reňki',
    '🧑🏾‍🤝‍🧑🏿' => 'el tutuşýan adamlar: orta goýy deri reňki, goýy deri reňki',
    '🧑🏿‍🤝‍🧑🏻' => 'el tutuşýan adamlar: goýy deri reňki, açyk deri reňki',
    '🧑🏿‍🤝‍🧑🏼' => 'el tutuşýan adamlar: goýy deri reňki, orta açyk deri reňki',
    '🧑🏿‍🤝‍🧑🏽' => 'el tutuşýan adamlar: goýy deri reňki, orta deri reňki',
    '🧑🏿‍🤝‍🧑🏾' => 'el tutuşýan adamlar: goýy deri reňki, orta goýy deri reňki',
    '🧑🏿‍🤝‍🧑🏿' => 'el tutuşýan adamlar: goýy deri reňki',
    '👩🏻‍🤝‍👩🏼' => 'el tutuşan aýallar: açyk deri reňki, orta açyk deri reňki',
    '👩🏻‍🤝‍👩🏽' => 'el tutuşan aýallar: açyk deri reňki, orta deri reňki',
    '👩🏻‍🤝‍👩🏾' => 'el tutuşan aýallar: açyk deri reňki, orta goýy deri reňki',
    '👩🏻‍🤝‍👩🏿' => 'el tutuşan aýallar: açyk deri reňki, goýy deri reňki',
    '👩🏼‍🤝‍👩🏻' => 'el tutuşan aýallar: orta açyk deri reňki, açyk deri reňki',
    '👩🏼‍🤝‍👩🏽' => 'el tutuşan aýallar: orta açyk deri reňki, orta deri reňki',
    '👩🏼‍🤝‍👩🏾' => 'el tutuşan aýallar: orta açyk deri reňki, orta goýy deri reňki',
    '👩🏼‍🤝‍👩🏿' => 'el tutuşan aýallar: orta açyk deri reňki, goýy deri reňki',
    '👩🏽‍🤝‍👩🏻' => 'el tutuşan aýallar: orta deri reňki, açyk deri reňki',
    '👩🏽‍🤝‍👩🏼' => 'el tutuşan aýallar: orta deri reňki, orta açyk deri reňki',
    '👩🏽‍🤝‍👩🏾' => 'el tutuşan aýallar: orta deri reňki, orta goýy deri reňki',
    '👩🏽‍🤝‍👩🏿' => 'el tutuşan aýallar: orta deri reňki, goýy deri reňki',
    '👩🏾‍🤝‍👩🏻' => 'el tutuşan aýallar: orta goýy deri reňki, açyk deri reňki',
    '👩🏾‍🤝‍👩🏼' => 'el tutuşan aýallar: orta goýy deri reňki, orta açyk deri reňki',
    '👩🏾‍🤝‍👩🏽' => 'el tutuşan aýallar: orta goýy deri reňki, orta deri reňki',
    '👩🏾‍🤝‍👩🏿' => 'el tutuşan aýallar: orta goýy deri reňki, goýy deri reňki',
    '👩🏿‍🤝‍👩🏻' => 'el tutuşan aýallar: goýy deri reňki, açyk deri reňki',
    '👩🏿‍🤝‍👩🏼' => 'el tutuşan aýallar: goýy deri reňki, orta açyk deri reňki',
    '👩🏿‍🤝‍👩🏽' => 'el tutuşan aýallar: goýy deri reňki, orta deri reňki',
    '👩🏿‍🤝‍👩🏾' => 'el tutuşan aýallar: goýy deri reňki, orta goýy deri reňki',
    '👩🏻‍🤝‍👨🏼' => 'el tutuşan aýal bilen erkek: açyk deri reňki, orta açyk deri reňki',
    '👩🏻‍🤝‍👨🏽' => 'el tutuşan aýal bilen erkek: açyk deri reňki, orta deri reňki',
    '👩🏻‍🤝‍👨🏾' => 'el tutuşan aýal bilen erkek: açyk deri reňki, orta goýy deri reňki',
    '👩🏻‍🤝‍👨🏿' => 'el tutuşan aýal bilen erkek: açyk deri reňki, goýy deri reňki',
    '👩🏼‍🤝‍👨🏻' => 'el tutuşan aýal bilen erkek: orta açyk deri reňki, açyk deri reňki',
    '👩🏼‍🤝‍👨🏽' => 'el tutuşan aýal bilen erkek: orta açyk deri reňki, orta deri reňki',
    '👩🏼‍🤝‍👨🏾' => 'el tutuşan aýal bilen erkek: orta açyk deri reňki, orta goýy deri reňki',
    '👩🏼‍🤝‍👨🏿' => 'el tutuşan aýal bilen erkek: orta açyk deri reňki, goýy deri reňki',
    '👩🏽‍🤝‍👨🏻' => 'el tutuşan aýal bilen erkek: orta deri reňki, açyk deri reňki',
    '👩🏽‍🤝‍👨🏼' => 'el tutuşan aýal bilen erkek: orta deri reňki, orta açyk deri reňki',
    '👩🏽‍🤝‍👨🏾' => 'el tutuşan aýal bilen erkek: orta deri reňki, orta goýy deri reňki',
    '👩🏽‍🤝‍👨🏿' => 'el tutuşan aýal bilen erkek: orta deri reňki, goýy deri reňki',
    '👩🏾‍🤝‍👨🏻' => 'el tutuşan aýal bilen erkek: orta goýy deri reňki, açyk deri reňki',
    '👩🏾‍🤝‍👨🏼' => 'el tutuşan aýal bilen erkek: orta goýy deri reňki, orta açyk deri reňki',
    '👩🏾‍🤝‍👨🏽' => 'el tutuşan aýal bilen erkek: orta goýy deri reňki, orta deri reňki',
    '👩🏾‍🤝‍👨🏿' => 'el tutuşan aýal bilen erkek: orta goýy deri reňki, goýy deri reňki',
    '👩🏿‍🤝‍👨🏻' => 'el tutuşan aýal bilen erkek: goýy deri reňki, açyk deri reňki',
    '👩🏿‍🤝‍👨🏼' => 'el tutuşan aýal bilen erkek: goýy deri reňki, orta açyk deri reňki',
    '👩🏿‍🤝‍👨🏽' => 'el tutuşan aýal bilen erkek: goýy deri reňki, orta deri reňki',
    '👩🏿‍🤝‍👨🏾' => 'el tutuşan aýal bilen erkek: goýy deri reňki, orta goýy deri reňki',
    '👨🏻‍🤝‍👨🏼' => 'el tutuşan erkekler: açyk deri reňki, orta açyk deri reňki',
    '👨🏻‍🤝‍👨🏽' => 'el tutuşan erkekler: açyk deri reňki, orta deri reňki',
    '👨🏻‍🤝‍👨🏾' => 'el tutuşan erkekler: açyk deri reňki, orta goýy deri reňki',
    '👨🏻‍🤝‍👨🏿' => 'el tutuşan erkekler: açyk deri reňki, goýy deri reňki',
    '👨🏼‍🤝‍👨🏻' => 'el tutuşan erkekler: orta açyk deri reňki, açyk deri reňki',
    '👨🏼‍🤝‍👨🏽' => 'el tutuşan erkekler: orta açyk deri reňki, orta deri reňki',
    '👨🏼‍🤝‍👨🏾' => 'el tutuşan erkekler: orta açyk deri reňki, orta goýy deri reňki',
    '👨🏼‍🤝‍👨🏿' => 'el tutuşan erkekler: orta açyk deri reňki, goýy deri reňki',
    '👨🏽‍🤝‍👨🏻' => 'el tutuşan erkekler: orta deri reňki, açyk deri reňki',
    '👨🏽‍🤝‍👨🏼' => 'el tutuşan erkekler: orta deri reňki, orta açyk deri reňki',
    '👨🏽‍🤝‍👨🏾' => 'el tutuşan erkekler: orta deri reňki, orta goýy deri reňki',
    '👨🏽‍🤝‍👨🏿' => 'el tutuşan erkekler: orta deri reňki, goýy deri reňki',
    '👨🏾‍🤝‍👨🏻' => 'el tutuşan erkekler: orta goýy deri reňki, açyk deri reňki',
    '👨🏾‍🤝‍👨🏼' => 'el tutuşan erkekler: orta goýy deri reňki, orta açyk deri reňki',
    '👨🏾‍🤝‍👨🏽' => 'el tutuşan erkekler: orta goýy deri reňki, orta deri reňki',
    '👨🏾‍🤝‍👨🏿' => 'el tutuşan erkekler: orta goýy deri reňki, goýy deri reňki',
    '👨🏿‍🤝‍👨🏻' => 'el tutuşan erkekler: goýy deri reňki, açyk deri reňki',
    '👨🏿‍🤝‍👨🏼' => 'el tutuşan erkekler: goýy deri reňki, orta açyk deri reňki',
    '👨🏿‍🤝‍👨🏽' => 'el tutuşan erkekler: goýy deri reňki, orta deri reňki',
    '👨🏿‍🤝‍👨🏾' => 'el tutuşan erkekler: goýy deri reňki, orta goýy deri reňki',
    '👩‍❤‍💋‍👨' => 'posa: zenan, erkek',
    '👨‍❤‍💋‍👨' => 'posa: erkek, erkek',
    '👩‍❤‍💋‍👩' => 'posa: zenan, zenan',
    '👨‍👩‍👧‍👦' => 'maşgala: erkek, zenan, gyz, oglan',
    '👨‍👩‍👦‍👦' => 'maşgala: erkek, zenan, oglan, oglan',
    '👨‍👩‍👧‍👧' => 'maşgala: erkek, zenan, gyz, gyz',
    '👨‍👨‍👧‍👦' => 'maşgala: erkek, erkek, gyz, oglan',
    '👨‍👨‍👦‍👦' => 'maşgala: erkek, erkek, oglan, oglan',
    '👨‍👨‍👧‍👧' => 'maşgala: erkek, erkek, gyz, gyz',
    '👩‍👩‍👧‍👦' => 'maşgala: zenan, zenan, gyz, oglan',
    '👩‍👩‍👦‍👦' => 'maşgala: zenan, zenan, oglan, oglan',
    '👩‍👩‍👧‍👧' => 'maşgala: zenan, zenan, gyz, gyz',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'baýdak: Angliýa',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'baýdak: Şotlandiýa',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'baýdak: Uels',
    '🧑‍🧑‍🧒‍🧒' => 'maşgala: uly, uly, çaga, çaga',
    '🚶🏻‍♀‍➡' => 'ýörap barýan zenan: açyk deri reňki, ýüzi saga',
    '🚶🏼‍♀‍➡' => 'ýörap barýan zenan: orta açyk deri reňki, ýüzi saga',
    '🚶🏽‍♀‍➡' => 'ýörap barýan zenan: orta deri reňki, ýüzi saga',
    '🚶🏾‍♀‍➡' => 'ýörap barýan zenan: orta goýy deri reňki, ýüzi saga',
    '🚶🏿‍♀‍➡' => 'ýörap barýan zenan: goýy deri reňki, ýüzi saga',
    '🚶🏻‍♂‍➡' => 'ýöräp barýan erkek: açyk deri reňki, ýüzi saga',
    '🚶🏼‍♂‍➡' => 'ýöräp barýan erkek: orta açyk deri reňki, ýüzi saga',
    '🚶🏽‍♂‍➡' => 'ýöräp barýan erkek: orta deri reňki, ýüzi saga',
    '🚶🏾‍♂‍➡' => 'ýöräp barýan erkek: orta goýy deri reňki, ýüzi saga',
    '🚶🏿‍♂‍➡' => 'ýöräp barýan erkek: goýy deri reňki, ýüzi saga',
    '🧎🏻‍♀‍➡' => 'dyza çöken zenan: açyk deri reňki, ýüzi saga',
    '🧎🏼‍♀‍➡' => 'dyza çöken zenan: orta açyk deri reňki, ýüzi saga',
    '🧎🏽‍♀‍➡' => 'dyza çöken zenan: orta deri reňki, ýüzi saga',
    '🧎🏾‍♀‍➡' => 'dyza çöken zenan: orta goýy deri reňki, ýüzi saga',
    '🧎🏿‍♀‍➡' => 'dyza çöken zenan: goýy deri reňki, ýüzi saga',
    '🧎🏻‍♂‍➡' => 'dyza çöken erkek: açyk deri reňki, ýüzi saga',
    '🧎🏼‍♂‍➡' => 'dyza çöken erkek: orta açyk deri reňki, ýüzi saga',
    '🧎🏽‍♂‍➡' => 'dyza çöken erkek: orta deri reňki, ýüzi saga',
    '🧎🏾‍♂‍➡' => 'dyza çöken erkek: orta goýy deri reňki, ýüzi saga',
    '🧎🏿‍♂‍➡' => 'dyza çöken erkek: goýy deri reňki, ýüzi saga',
    '🧑🏻‍🦯‍➡' => 'kör hasaly adam: açyk deri reňki, ýüzi saga',
    '🧑🏼‍🦯‍➡' => 'kör hasaly adam: orta açyk deri reňki, ýüzi saga',
    '🧑🏽‍🦯‍➡' => 'kör hasaly adam: orta deri reňki, ýüzi saga',
    '🧑🏾‍🦯‍➡' => 'kör hasaly adam: orta goýy deri reňki, ýüzi saga',
    '🧑🏿‍🦯‍➡' => 'kör hasaly adam: goýy deri reňki, ýüzi saga',
    '👨🏻‍🦯‍➡' => 'kör hasaly erkek: açyk deri reňki, ýüzi saga',
    '👨🏼‍🦯‍➡' => 'kör hasaly erkek: orta açyk deri reňki, ýüzi saga',
    '👨🏽‍🦯‍➡' => 'kör hasaly erkek: orta deri reňki, ýüzi saga',
    '👨🏾‍🦯‍➡' => 'kör hasaly erkek: orta goýy deri reňki, ýüzi saga',
    '👨🏿‍🦯‍➡' => 'kör hasaly erkek: goýy deri reňki, ýüzi saga',
    '👩🏻‍🦯‍➡' => 'kör hasaly zenan: açyk deri reňki, ýüzi saga',
    '👩🏼‍🦯‍➡' => 'kör hasaly zenan: orta açyk deri reňki, ýüzi saga',
    '👩🏽‍🦯‍➡' => 'kör hasaly zenan: orta deri reňki, ýüzi saga',
    '👩🏾‍🦯‍➡' => 'kör hasaly zenan: orta goýy deri reňki, ýüzi saga',
    '👩🏿‍🦯‍➡' => 'kör hasaly zenan: goýy deri reňki, ýüzi saga',
    '🧑🏻‍🦼‍➡' => 'motorly arabajykdaky adam: açyk deri reňki, ýüzi saga',
    '🧑🏼‍🦼‍➡' => 'motorly arabajykdaky adam: orta açyk deri reňki, ýüzi saga',
    '🧑🏽‍🦼‍➡' => 'motorly arabajykdaky adam: orta deri reňki, ýüzi saga',
    '🧑🏾‍🦼‍➡' => 'motorly arabajykdaky adam: orta goýy deri reňki, ýüzi saga',
    '🧑🏿‍🦼‍➡' => 'motorly arabajykdaky adam: goýy deri reňki, ýüzi saga',
    '👨🏻‍🦼‍➡' => 'motorly maýyp arabasynda erkek: açyk deri reňki, ýüzi saga',
    '👨🏼‍🦼‍➡' => 'motorly maýyp arabasynda erkek: orta açyk deri reňki, ýüzi saga',
    '👨🏽‍🦼‍➡' => 'motorly maýyp arabasynda erkek: orta deri reňki, ýüzi saga',
    '👨🏾‍🦼‍➡' => 'motorly maýyp arabasynda erkek: orta goýy deri reňki, ýüzi saga',
    '👨🏿‍🦼‍➡' => 'motorly maýyp arabasynda erkek: goýy deri reňki, ýüzi saga',
    '👩🏻‍🦼‍➡' => 'motorly maýyp arabasynda zenan: açyk deri reňki, ýüzi saga',
    '👩🏼‍🦼‍➡' => 'motorly maýyp arabasynda zenan: orta açyk deri reňki, ýüzi saga',
    '👩🏽‍🦼‍➡' => 'motorly maýyp arabasynda zenan: orta deri reňki, ýüzi saga',
    '👩🏾‍🦼‍➡' => 'motorly maýyp arabasynda zenan: orta goýy deri reňki, ýüzi saga',
    '👩🏿‍🦼‍➡' => 'motorly maýyp arabasynda zenan: goýy deri reňki, ýüzi saga',
    '🧑🏻‍🦽‍➡' => 'el bilen işleýän tigirçekli oturgyçdaky adam: açyk deri reňki, ýüzi saga',
    '🧑🏼‍🦽‍➡' => 'el bilen işleýän tigirçekli oturgyçdaky adam: orta açyk deri reňki, ýüzi saga',
    '🧑🏽‍🦽‍➡' => 'el bilen işleýän tigirçekli oturgyçdaky adam: orta deri reňki, ýüzi saga',
    '🧑🏾‍🦽‍➡' => 'el bilen işleýän tigirçekli oturgyçdaky adam: orta goýy deri reňki, ýüzi saga',
    '🧑🏿‍🦽‍➡' => 'el bilen işleýän tigirçekli oturgyçdaky adam: goýy deri reňki, ýüzi saga',
    '👨🏻‍🦽‍➡' => 'el maýyp arabasynda erkek: açyk deri reňki, ýüzi saga',
    '👨🏼‍🦽‍➡' => 'el maýyp arabasynda erkek: orta açyk deri reňki, ýüzi saga',
    '👨🏽‍🦽‍➡' => 'el maýyp arabasynda erkek: orta deri reňki, ýüzi saga',
    '👨🏾‍🦽‍➡' => 'el maýyp arabasynda erkek: orta goýy deri reňki, ýüzi saga',
    '👨🏿‍🦽‍➡' => 'el maýyp arabasynda erkek: goýy deri reňki, ýüzi saga',
    '👩🏻‍🦽‍➡' => 'el maýyp arabasynda zenan: açyk deri reňki, ýüzi saga',
    '👩🏼‍🦽‍➡' => 'el maýyp arabasynda zenan: orta açyk deri reňki, ýüzi saga',
    '👩🏽‍🦽‍➡' => 'el maýyp arabasynda zenan: orta deri reňki, ýüzi saga',
    '👩🏾‍🦽‍➡' => 'el maýyp arabasynda zenan: orta goýy deri reňki, ýüzi saga',
    '👩🏿‍🦽‍➡' => 'el maýyp arabasynda zenan: goýy deri reňki, ýüzi saga',
    '🏃🏻‍♀‍➡' => 'ylgap barýan zenan: açyk deri reňki, ýüzi saga',
    '🏃🏼‍♀‍➡' => 'ylgap barýan zenan: orta açyk deri reňki, ýüzi saga',
    '🏃🏽‍♀‍➡' => 'ylgap barýan zenan: orta deri reňki, ýüzi saga',
    '🏃🏾‍♀‍➡' => 'ylgap barýan zenan: orta goýy deri reňki, ýüzi saga',
    '🏃🏿‍♀‍➡' => 'ylgap barýan zenan: goýy deri reňki, ýüzi saga',
    '🏃🏻‍♂‍➡' => 'ylgap barýan erkek: açyk deri reňki, ýüzi saga',
    '🏃🏼‍♂‍➡' => 'ylgap barýan erkek: orta açyk deri reňki, ýüzi saga',
    '🏃🏽‍♂‍➡' => 'ylgap barýan erkek: orta deri reňki, ýüzi saga',
    '🏃🏾‍♂‍➡' => 'ylgap barýan erkek: orta goýy deri reňki, ýüzi saga',
    '🏃🏿‍♂‍➡' => 'ylgap barýan erkek: goýy deri reňki, ýüzi saga',
    '🫱🏻‍🫲🏼' => 'el gysyşmak: açyk deri reňki, orta açyk deri reňki',
    '🫱🏻‍🫲🏽' => 'el gysyşmak: açyk deri reňki, orta deri reňki',
    '🫱🏻‍🫲🏾' => 'el gysyşmak: açyk deri reňki, orta goýy deri reňki',
    '🫱🏻‍🫲🏿' => 'el gysyşmak: açyk deri reňki, goýy deri reňki',
    '🫱🏼‍🫲🏻' => 'el gysyşmak: orta açyk deri reňki, açyk deri reňki',
    '🫱🏼‍🫲🏽' => 'el gysyşmak: orta açyk deri reňki, orta deri reňki',
    '🫱🏼‍🫲🏾' => 'el gysyşmak: orta açyk deri reňki, orta goýy deri reňki',
    '🫱🏼‍🫲🏿' => 'el gysyşmak: orta açyk deri reňki, goýy deri reňki',
    '🫱🏽‍🫲🏻' => 'el gysyşmak: orta deri reňki, açyk deri reňki',
    '🫱🏽‍🫲🏼' => 'el gysyşmak: orta deri reňki, orta açyk deri reňki',
    '🫱🏽‍🫲🏾' => 'el gysyşmak: orta deri reňki, orta goýy deri reňki',
    '🫱🏽‍🫲🏿' => 'el gysyşmak: orta deri reňki, goýy deri reňki',
    '🫱🏾‍🫲🏻' => 'el gysyşmak: orta goýy deri reňki, açyk deri reňki',
    '🫱🏾‍🫲🏼' => 'el gysyşmak: orta goýy deri reňki, orta açyk deri reňki',
    '🫱🏾‍🫲🏽' => 'el gysyşmak: orta goýy deri reňki, orta deri reňki',
    '🫱🏾‍🫲🏿' => 'el gysyşmak: orta goýy deri reňki, goýy deri reňki',
    '🫱🏿‍🫲🏻' => 'el gysyşmak: goýy deri reňki, açyk deri reňki',
    '🫱🏿‍🫲🏼' => 'el gysyşmak: goýy deri reňki, orta açyk deri reňki',
    '🫱🏿‍🫲🏽' => 'el gysyşmak: goýy deri reňki, orta deri reňki',
    '🫱🏿‍🫲🏾' => 'el gysyşmak: goýy deri reňki, orta goýy deri reňki',
    '🚶‍♀‍➡' => 'ýörap barýan zenan: ýüzi saga',
    '🚶‍♂‍➡' => 'ýöräp barýan erkek: ýüzi saga',
    '🧎‍♀‍➡' => 'dyza çöken zenan: ýüzi saga',
    '🧎‍♂‍➡' => 'dyza çöken erkek: ýüzi saga',
    '🧑‍🦯‍➡' => 'kör hasaly adam: ýüzi saga',
    '👨‍🦯‍➡' => 'kör hasaly erkek: ýüzi saga',
    '👩‍🦯‍➡' => 'kör hasaly zenan: ýüzi saga',
    '🧑‍🦼‍➡' => 'motorly arabajykdaky adam: ýüzi saga',
    '👨‍🦼‍➡' => 'motorly maýyp arabasynda erkek: ýüzi saga',
    '👩‍🦼‍➡' => 'motorly maýyp arabasynda zenan: ýüzi saga',
    '🧑‍🦽‍➡' => 'el bilen işleýän tigirçekli oturgyçdaky adam: ýüzi saga',
    '👨‍🦽‍➡' => 'el maýyp arabasynda erkek: ýüzi saga',
    '👩‍🦽‍➡' => 'el maýyp arabasynda zenan: ýüzi saga',
    '🏃‍♀‍➡' => 'ylgap barýan zenan: ýüzi saga',
    '🏃‍♂‍➡' => 'ylgap barýan erkek: ýüzi saga',
    '👩‍❤‍👨' => 'ýürekli jübüt: zenan, erkek',
    '👨‍❤‍👨' => 'ýürekli jübüt: erkek, erkek',
    '👩‍❤‍👩' => 'ýürekli jübüt: zenan, zenan',
    '👨‍👩‍👦' => 'maşgala: erkek, zenan, oglan',
    '👨‍👩‍👧' => 'maşgala: erkek, zenan, gyz',
    '👨‍👨‍👦' => 'maşgala: erkek, erkek, oglan',
    '👨‍👨‍👧' => 'maşgala: erkek, erkek, gyz',
    '👩‍👩‍👦' => 'maşgala: zenan, zenan, oglan',
    '👩‍👩‍👧' => 'maşgala: zenan, zenan, gyz',
    '👨‍👦‍👦' => 'maşgala: erkek, oglan, oglan',
    '👨‍👧‍👦' => 'maşgala: erkek, gyz, oglan',
    '👨‍👧‍👧' => 'maşgala: erkek, gyz, gyz',
    '👩‍👦‍👦' => 'maşgala: zenan, oglan, oglan',
    '👩‍👧‍👦' => 'maşgala: zenan, gyz, oglan',
    '👩‍👧‍👧' => 'maşgala: zenan, gyz, gyz',
    '🧑‍🤝‍🧑' => 'el tutuşýan adamlar',
    '🧑‍🧑‍🧒' => 'maşgala: uly, uly, çaga',
    '🧑‍🧒‍🧒' => 'maşgala: uly, çaga, çaga',
    '🧑🏻‍🦰' => 'şahs: açyk deri reňki, gyzyl saç',
    '🧑🏼‍🦰' => 'şahs: orta açyk deri reňki, gyzyl saç',
    '🧑🏽‍🦰' => 'şahs: orta deri reňki, gyzyl saç',
    '🧑🏾‍🦰' => 'şahs: orta goýy deri reňki, gyzyl saç',
    '🧑🏿‍🦰' => 'şahs: goýy deri reňki, gyzyl saç',
    '🧑🏻‍🦱' => 'şahs: açyk deri reňki, buýra saç',
    '🧑🏼‍🦱' => 'şahs: orta açyk deri reňki, buýra saç',
    '🧑🏽‍🦱' => 'şahs: orta deri reňki, buýra saç',
    '🧑🏾‍🦱' => 'şahs: orta goýy deri reňki, buýra saç',
    '🧑🏿‍🦱' => 'şahs: goýy deri reňki, buýra saç',
    '🧑🏻‍🦳' => 'şahs: açyk deri reňki, ak saç',
    '🧑🏼‍🦳' => 'şahs: orta açyk deri reňki, ak saç',
    '🧑🏽‍🦳' => 'şahs: orta deri reňki, ak saç',
    '🧑🏾‍🦳' => 'şahs: orta goýy deri reňki, ak saç',
    '🧑🏿‍🦳' => 'şahs: goýy deri reňki, ak saç',
    '🧑🏻‍🦲' => 'şahs: açyk deri reňki, kel',
    '🧑🏼‍🦲' => 'şahs: orta açyk deri reňki, kel',
    '🧑🏽‍🦲' => 'şahs: orta deri reňki, kel',
    '🧑🏾‍🦲' => 'şahs: orta goýy deri reňki, kel',
    '🧑🏿‍🦲' => 'şahs: goýy deri reňki, kel',
    '🧑🏻‍🩰' => 'balerina: açyk deri reňki',
    '🧑🏼‍🩰' => 'balerina: orta açyk deri reňki',
    '🧑🏽‍🩰' => 'balerina: orta deri reňki',
    '🧑🏾‍🩰' => 'balerina: orta goýy deri reňki',
    '🧑🏿‍🩰' => 'balerina: goýy deri reňki',
    '🧔🏻‍♂' => 'adam: açyk deri reňki, sakal',
    '🧔🏼‍♂' => 'adam: orta açyk deri reňki, sakal',
    '🧔🏽‍♂' => 'adam: orta deri reňki, sakal',
    '🧔🏾‍♂' => 'adam: orta goýy deri reňki, sakal',
    '🧔🏿‍♂' => 'adam: goýy deri reňki, sakal',
    '👱🏻‍♂' => 'erkek adam: açyk deri reňki, sary saç',
    '👱🏼‍♂' => 'erkek adam: orta açyk deri reňki, sary saç',
    '👱🏽‍♂' => 'erkek adam: orta deri reňki, sary saç',
    '👱🏾‍♂' => 'erkek adam: orta goýy deri reňki, sary saç',
    '👱🏿‍♂' => 'erkek adam: goýy deri reňki, sary saç',
    '👨🏻‍🦰' => 'erkek: açyk deri reňki, gyzyl saç',
    '👨🏼‍🦰' => 'erkek: orta açyk deri reňki, gyzyl saç',
    '👨🏽‍🦰' => 'erkek: orta deri reňki, gyzyl saç',
    '👨🏾‍🦰' => 'erkek: orta goýy deri reňki, gyzyl saç',
    '👨🏿‍🦰' => 'erkek: goýy deri reňki, gyzyl saç',
    '👨🏻‍🦱' => 'erkek: açyk deri reňki, buýra saç',
    '👨🏼‍🦱' => 'erkek: orta açyk deri reňki, buýra saç',
    '👨🏽‍🦱' => 'erkek: orta deri reňki, buýra saç',
    '👨🏾‍🦱' => 'erkek: orta goýy deri reňki, buýra saç',
    '👨🏿‍🦱' => 'erkek: goýy deri reňki, buýra saç',
    '👨🏻‍🦳' => 'erkek: açyk deri reňki, ak saç',
    '👨🏼‍🦳' => 'erkek: orta açyk deri reňki, ak saç',
    '👨🏽‍🦳' => 'erkek: orta deri reňki, ak saç',
    '👨🏾‍🦳' => 'erkek: orta goýy deri reňki, ak saç',
    '👨🏿‍🦳' => 'erkek: goýy deri reňki, ak saç',
    '👨🏻‍🦲' => 'erkek: açyk deri reňki, kel',
    '👨🏼‍🦲' => 'erkek: orta açyk deri reňki, kel',
    '👨🏽‍🦲' => 'erkek: orta deri reňki, kel',
    '👨🏾‍🦲' => 'erkek: orta goýy deri reňki, kel',
    '👨🏿‍🦲' => 'erkek: goýy deri reňki, kel',
    '🧔🏻‍♀' => 'aýal: açyk deri reňki, sakal',
    '🧔🏼‍♀' => 'aýal: orta açyk deri reňki, sakal',
    '🧔🏽‍♀' => 'aýal: orta deri reňki, sakal',
    '🧔🏾‍♀' => 'aýal: orta goýy deri reňki, sakal',
    '🧔🏿‍♀' => 'aýal: goýy deri reňki, sakal',
    '👱🏻‍♀' => 'zenan: açyk deri reňki, sary saçly',
    '👱🏼‍♀' => 'zenan: orta açyk deri reňki, sary saçly',
    '👱🏽‍♀' => 'zenan: orta deri reňki, sary saçly',
    '👱🏾‍♀' => 'zenan: orta goýy deri reňki, sary saçly',
    '👱🏿‍♀' => 'zenan: goýy deri reňki, sary saçly',
    '👩🏻‍🦰' => 'zenan: açyk deri reňki, gyzyl saç',
    '👩🏼‍🦰' => 'zenan: orta açyk deri reňki, gyzyl saç',
    '👩🏽‍🦰' => 'zenan: orta deri reňki, gyzyl saç',
    '👩🏾‍🦰' => 'zenan: orta goýy deri reňki, gyzyl saç',
    '👩🏿‍🦰' => 'zenan: goýy deri reňki, gyzyl saç',
    '👩🏻‍🦱' => 'zenan: açyk deri reňki, buýra saç',
    '👩🏼‍🦱' => 'zenan: orta açyk deri reňki, buýra saç',
    '👩🏽‍🦱' => 'zenan: orta deri reňki, buýra saç',
    '👩🏾‍🦱' => 'zenan: orta goýy deri reňki, buýra saç',
    '👩🏿‍🦱' => 'zenan: goýy deri reňki, buýra saç',
    '👩🏻‍🦳' => 'zenan: açyk deri reňki, ak saç',
    '👩🏼‍🦳' => 'zenan: orta açyk deri reňki, ak saç',
    '👩🏽‍🦳' => 'zenan: orta deri reňki, ak saç',
    '👩🏾‍🦳' => 'zenan: orta goýy deri reňki, ak saç',
    '👩🏿‍🦳' => 'zenan: goýy deri reňki, ak saç',
    '👩🏻‍🦲' => 'zenan: açyk deri reňki, kel',
    '👩🏼‍🦲' => 'zenan: orta açyk deri reňki, kel',
    '👩🏽‍🦲' => 'zenan: orta deri reňki, kel',
    '👩🏾‍🦲' => 'zenan: orta goýy deri reňki, kel',
    '👩🏿‍🦲' => 'zenan: goýy deri reňki, kel',
    '🙍🏻‍♂' => 'çytylýan erkek: açyk deri reňki',
    '🙍🏼‍♂' => 'çytylýan erkek: orta açyk deri reňki',
    '🙍🏽‍♂' => 'çytylýan erkek: orta deri reňki',
    '🙍🏾‍♂' => 'çytylýan erkek: orta goýy deri reňki',
    '🙍🏿‍♂' => 'çytylýan erkek: goýy deri reňki',
    '🙍🏻‍♀' => 'çytylýan zenan: açyk deri reňki',
    '🙍🏼‍♀' => 'çytylýan zenan: orta açyk deri reňki',
    '🙍🏽‍♀' => 'çytylýan zenan: orta deri reňki',
    '🙍🏾‍♀' => 'çytylýan zenan: orta goýy deri reňki',
    '🙍🏿‍♀' => 'çytylýan zenan: goýy deri reňki',
    '🙎🏻‍♂' => 'gamaşyk erkek: açyk deri reňki',
    '🙎🏼‍♂' => 'gamaşyk erkek: orta açyk deri reňki',
    '🙎🏽‍♂' => 'gamaşyk erkek: orta deri reňki',
    '🙎🏾‍♂' => 'gamaşyk erkek: orta goýy deri reňki',
    '🙎🏿‍♂' => 'gamaşyk erkek: goýy deri reňki',
    '🙎🏻‍♀' => 'gamaşyk zenan: açyk deri reňki',
    '🙎🏼‍♀' => 'gamaşyk zenan: orta açyk deri reňki',
    '🙎🏽‍♀' => 'gamaşyk zenan: orta deri reňki',
    '🙎🏾‍♀' => 'gamaşyk zenan: orta goýy deri reňki',
    '🙎🏿‍♀' => 'gamaşyk zenan: goýy deri reňki',
    '🙅🏻‍♂' => 'ÝOK ümleýän erkek: açyk deri reňki',
    '🙅🏼‍♂' => 'ÝOK ümleýän erkek: orta açyk deri reňki',
    '🙅🏽‍♂' => 'ÝOK ümleýän erkek: orta deri reňki',
    '🙅🏾‍♂' => 'ÝOK ümleýän erkek: orta goýy deri reňki',
    '🙅🏿‍♂' => 'ÝOK ümleýän erkek: goýy deri reňki',
    '🙅🏻‍♀' => 'ÝOK ümleýän zenan: açyk deri reňki',
    '🙅🏼‍♀' => 'ÝOK ümleýän zenan: orta açyk deri reňki',
    '🙅🏽‍♀' => 'ÝOK ümleýän zenan: orta deri reňki',
    '🙅🏾‍♀' => 'ÝOK ümleýän zenan: orta goýy deri reňki',
    '🙅🏿‍♀' => 'ÝOK ümleýän zenan: goýy deri reňki',
    '🙆🏻‍♂' => 'Bolýar ümleýän erkek: açyk deri reňki',
    '🙆🏼‍♂' => 'Bolýar ümleýän erkek: orta açyk deri reňki',
    '🙆🏽‍♂' => 'Bolýar ümleýän erkek: orta deri reňki',
    '🙆🏾‍♂' => 'Bolýar ümleýän erkek: orta goýy deri reňki',
    '🙆🏿‍♂' => 'Bolýar ümleýän erkek: goýy deri reňki',
    '🙆🏻‍♀' => 'Bolýar ümleýän zenan: açyk deri reňki',
    '🙆🏼‍♀' => 'Bolýar ümleýän zenan: orta açyk deri reňki',
    '🙆🏽‍♀' => 'Bolýar ümleýän zenan: orta deri reňki',
    '🙆🏾‍♀' => 'Bolýar ümleýän zenan: orta goýy deri reňki',
    '🙆🏿‍♀' => 'Bolýar ümleýän zenan: goýy deri reňki',
    '💁🏻‍♂' => 'elini açan erkek: açyk deri reňki',
    '💁🏼‍♂' => 'elini açan erkek: orta açyk deri reňki',
    '💁🏽‍♂' => 'elini açan erkek: orta deri reňki',
    '💁🏾‍♂' => 'elini açan erkek: orta goýy deri reňki',
    '💁🏿‍♂' => 'elini açan erkek: goýy deri reňki',
    '💁🏻‍♀' => 'elini açan zenan: açyk deri reňki',
    '💁🏼‍♀' => 'elini açan zenan: orta açyk deri reňki',
    '💁🏽‍♀' => 'elini açan zenan: orta deri reňki',
    '💁🏾‍♀' => 'elini açan zenan: orta goýy deri reňki',
    '💁🏿‍♀' => 'elini açan zenan: goýy deri reňki',
    '🙋🏻‍♂' => 'elini galdyrýan erkek: açyk deri reňki',
    '🙋🏼‍♂' => 'elini galdyrýan erkek: orta açyk deri reňki',
    '🙋🏽‍♂' => 'elini galdyrýan erkek: orta deri reňki',
    '🙋🏾‍♂' => 'elini galdyrýan erkek: orta goýy deri reňki',
    '🙋🏿‍♂' => 'elini galdyrýan erkek: goýy deri reňki',
    '🙋🏻‍♀' => 'elini galdyrýan zenan: açyk deri reňki',
    '🙋🏼‍♀' => 'elini galdyrýan zenan: orta açyk deri reňki',
    '🙋🏽‍♀' => 'elini galdyrýan zenan: orta deri reňki',
    '🙋🏾‍♀' => 'elini galdyrýan zenan: orta goýy deri reňki',
    '🙋🏿‍♀' => 'elini galdyrýan zenan: goýy deri reňki',
    '🧏🏻‍♂' => 'ker erkek: açyk deri reňki',
    '🧏🏼‍♂' => 'ker erkek: orta açyk deri reňki',
    '🧏🏽‍♂' => 'ker erkek: orta deri reňki',
    '🧏🏾‍♂' => 'ker erkek: orta goýy deri reňki',
    '🧏🏿‍♂' => 'ker erkek: goýy deri reňki',
    '🧏🏻‍♀' => 'ker zenan: açyk deri reňki',
    '🧏🏼‍♀' => 'ker zenan: orta açyk deri reňki',
    '🧏🏽‍♀' => 'ker zenan: orta deri reňki',
    '🧏🏾‍♀' => 'ker zenan: orta goýy deri reňki',
    '🧏🏿‍♀' => 'ker zenan: goýy deri reňki',
    '🙇🏻‍♂' => 'tagzym edýän erkek: açyk deri reňki',
    '🙇🏼‍♂' => 'tagzym edýän erkek: orta açyk deri reňki',
    '🙇🏽‍♂' => 'tagzym edýän erkek: orta deri reňki',
    '🙇🏾‍♂' => 'tagzym edýän erkek: orta goýy deri reňki',
    '🙇🏿‍♂' => 'tagzym edýän erkek: goýy deri reňki',
    '🙇🏻‍♀' => 'tagzym edýän zenan: açyk deri reňki',
    '🙇🏼‍♀' => 'tagzym edýän zenan: orta açyk deri reňki',
    '🙇🏽‍♀' => 'tagzym edýän zenan: orta deri reňki',
    '🙇🏾‍♀' => 'tagzym edýän zenan: orta goýy deri reňki',
    '🙇🏿‍♀' => 'tagzym edýän zenan: goýy deri reňki',
    '🤦🏻‍♂' => 'elini maňlaýyna urýan erkek: açyk deri reňki',
    '🤦🏼‍♂' => 'elini maňlaýyna urýan erkek: orta açyk deri reňki',
    '🤦🏽‍♂' => 'elini maňlaýyna urýan erkek: orta deri reňki',
    '🤦🏾‍♂' => 'elini maňlaýyna urýan erkek: orta goýy deri reňki',
    '🤦🏿‍♂' => 'elini maňlaýyna urýan erkek: goýy deri reňki',
    '🤦🏻‍♀' => 'elini maňlaýyna urýan zenan: açyk deri reňki',
    '🤦🏼‍♀' => 'elini maňlaýyna urýan zenan: orta açyk deri reňki',
    '🤦🏽‍♀' => 'elini maňlaýyna urýan zenan: orta deri reňki',
    '🤦🏾‍♀' => 'elini maňlaýyna urýan zenan: orta goýy deri reňki',
    '🤦🏿‍♀' => 'elini maňlaýyna urýan zenan: goýy deri reňki',
    '🤷🏻‍♂' => 'egnini gysýan erkek: açyk deri reňki',
    '🤷🏼‍♂' => 'egnini gysýan erkek: orta açyk deri reňki',
    '🤷🏽‍♂' => 'egnini gysýan erkek: orta deri reňki',
    '🤷🏾‍♂' => 'egnini gysýan erkek: orta goýy deri reňki',
    '🤷🏿‍♂' => 'egnini gysýan erkek: goýy deri reňki',
    '🤷🏻‍♀' => 'egnini gysýan zenan: açyk deri reňki',
    '🤷🏼‍♀' => 'egnini gysýan zenan: orta açyk deri reňki',
    '🤷🏽‍♀' => 'egnini gysýan zenan: orta deri reňki',
    '🤷🏾‍♀' => 'egnini gysýan zenan: orta goýy deri reňki',
    '🤷🏿‍♀' => 'egnini gysýan zenan: goýy deri reňki',
    '🧑🏻‍⚕' => 'saglyk işgäri: açyk deri reňki',
    '🧑🏼‍⚕' => 'saglyk işgäri: orta açyk deri reňki',
    '🧑🏽‍⚕' => 'saglyk işgäri: orta deri reňki',
    '🧑🏾‍⚕' => 'saglyk işgäri: orta goýy deri reňki',
    '🧑🏿‍⚕' => 'saglyk işgäri: goýy deri reňki',
    '👨🏻‍⚕' => 'erkek saglygy goraýyş işgäri: açyk deri reňki',
    '👨🏼‍⚕' => 'erkek saglygy goraýyş işgäri: orta açyk deri reňki',
    '👨🏽‍⚕' => 'erkek saglygy goraýyş işgäri: orta deri reňki',
    '👨🏾‍⚕' => 'erkek saglygy goraýyş işgäri: orta goýy deri reňki',
    '👨🏿‍⚕' => 'erkek saglygy goraýyş işgäri: goýy deri reňki',
    '👩🏻‍⚕' => 'zenan saglygy goraýyş işgäri: açyk deri reňki',
    '👩🏼‍⚕' => 'zenan saglygy goraýyş işgäri: orta açyk deri reňki',
    '👩🏽‍⚕' => 'zenan saglygy goraýyş işgäri: orta deri reňki',
    '👩🏾‍⚕' => 'zenan saglygy goraýyş işgäri: orta goýy deri reňki',
    '👩🏿‍⚕' => 'zenan saglygy goraýyş işgäri: goýy deri reňki',
    '🧑🏻‍🎓' => 'talyp: açyk deri reňki',
    '🧑🏼‍🎓' => 'talyp: orta açyk deri reňki',
    '🧑🏽‍🎓' => 'talyp: orta deri reňki',
    '🧑🏾‍🎓' => 'talyp: orta goýy deri reňki',
    '🧑🏿‍🎓' => 'talyp: goýy deri reňki',
    '👨🏻‍🎓' => 'erkek talyp: açyk deri reňki',
    '👨🏼‍🎓' => 'erkek talyp: orta açyk deri reňki',
    '👨🏽‍🎓' => 'erkek talyp: orta deri reňki',
    '👨🏾‍🎓' => 'erkek talyp: orta goýy deri reňki',
    '👨🏿‍🎓' => 'erkek talyp: goýy deri reňki',
    '👩🏻‍🎓' => 'zenan talyp: açyk deri reňki',
    '👩🏼‍🎓' => 'zenan talyp: orta açyk deri reňki',
    '👩🏽‍🎓' => 'zenan talyp: orta deri reňki',
    '👩🏾‍🎓' => 'zenan talyp: orta goýy deri reňki',
    '👩🏿‍🎓' => 'zenan talyp: goýy deri reňki',
    '🧑🏻‍🏫' => 'mugallym: açyk deri reňki',
    '🧑🏼‍🏫' => 'mugallym: orta açyk deri reňki',
    '🧑🏽‍🏫' => 'mugallym: orta deri reňki',
    '🧑🏾‍🏫' => 'mugallym: orta goýy deri reňki',
    '🧑🏿‍🏫' => 'mugallym: goýy deri reňki',
    '👨🏻‍🏫' => 'erkek mugallym: açyk deri reňki',
    '👨🏼‍🏫' => 'erkek mugallym: orta açyk deri reňki',
    '👨🏽‍🏫' => 'erkek mugallym: orta deri reňki',
    '👨🏾‍🏫' => 'erkek mugallym: orta goýy deri reňki',
    '👨🏿‍🏫' => 'erkek mugallym: goýy deri reňki',
    '👩🏻‍🏫' => 'zenan mugallym: açyk deri reňki',
    '👩🏼‍🏫' => 'zenan mugallym: orta açyk deri reňki',
    '👩🏽‍🏫' => 'zenan mugallym: orta deri reňki',
    '👩🏾‍🏫' => 'zenan mugallym: orta goýy deri reňki',
    '👩🏿‍🏫' => 'zenan mugallym: goýy deri reňki',
    '🧑🏻‍⚖' => 'kazy: açyk deri reňki',
    '🧑🏼‍⚖' => 'kazy: orta açyk deri reňki',
    '🧑🏽‍⚖' => 'kazy: orta deri reňki',
    '🧑🏾‍⚖' => 'kazy: orta goýy deri reňki',
    '🧑🏿‍⚖' => 'kazy: goýy deri reňki',
    '👨🏻‍⚖' => 'erkek kazy: açyk deri reňki',
    '👨🏼‍⚖' => 'erkek kazy: orta açyk deri reňki',
    '👨🏽‍⚖' => 'erkek kazy: orta deri reňki',
    '👨🏾‍⚖' => 'erkek kazy: orta goýy deri reňki',
    '👨🏿‍⚖' => 'erkek kazy: goýy deri reňki',
    '👩🏻‍⚖' => 'zenan kazy: açyk deri reňki',
    '👩🏼‍⚖' => 'zenan kazy: orta açyk deri reňki',
    '👩🏽‍⚖' => 'zenan kazy: orta deri reňki',
    '👩🏾‍⚖' => 'zenan kazy: orta goýy deri reňki',
    '👩🏿‍⚖' => 'zenan kazy: goýy deri reňki',
    '🧑🏻‍🌾' => 'fermer: açyk deri reňki',
    '🧑🏼‍🌾' => 'fermer: orta açyk deri reňki',
    '🧑🏽‍🌾' => 'fermer: orta deri reňki',
    '🧑🏾‍🌾' => 'fermer: orta goýy deri reňki',
    '🧑🏿‍🌾' => 'fermer: goýy deri reňki',
    '👨🏻‍🌾' => 'erkek daýhan: açyk deri reňki',
    '👨🏼‍🌾' => 'erkek daýhan: orta açyk deri reňki',
    '👨🏽‍🌾' => 'erkek daýhan: orta deri reňki',
    '👨🏾‍🌾' => 'erkek daýhan: orta goýy deri reňki',
    '👨🏿‍🌾' => 'erkek daýhan: goýy deri reňki',
    '👩🏻‍🌾' => 'zenan daýhan: açyk deri reňki',
    '👩🏼‍🌾' => 'zenan daýhan: orta açyk deri reňki',
    '👩🏽‍🌾' => 'zenan daýhan: orta deri reňki',
    '👩🏾‍🌾' => 'zenan daýhan: orta goýy deri reňki',
    '👩🏿‍🌾' => 'zenan daýhan: goýy deri reňki',
    '🧑🏻‍🍳' => 'aşpez: açyk deri reňki',
    '🧑🏼‍🍳' => 'aşpez: orta açyk deri reňki',
    '🧑🏽‍🍳' => 'aşpez: orta deri reňki',
    '🧑🏾‍🍳' => 'aşpez: orta goýy deri reňki',
    '🧑🏿‍🍳' => 'aşpez: goýy deri reňki',
    '👨🏻‍🍳' => 'erkek aşpez: açyk deri reňki',
    '👨🏼‍🍳' => 'erkek aşpez: orta açyk deri reňki',
    '👨🏽‍🍳' => 'erkek aşpez: orta deri reňki',
    '👨🏾‍🍳' => 'erkek aşpez: orta goýy deri reňki',
    '👨🏿‍🍳' => 'erkek aşpez: goýy deri reňki',
    '👩🏻‍🍳' => 'zenan aşpez: açyk deri reňki',
    '👩🏼‍🍳' => 'zenan aşpez: orta açyk deri reňki',
    '👩🏽‍🍳' => 'zenan aşpez: orta deri reňki',
    '👩🏾‍🍳' => 'zenan aşpez: orta goýy deri reňki',
    '👩🏿‍🍳' => 'zenan aşpez: goýy deri reňki',
    '🧑🏻‍🔧' => 'mehanik: açyk deri reňki',
    '🧑🏼‍🔧' => 'mehanik: orta açyk deri reňki',
    '🧑🏽‍🔧' => 'mehanik: orta deri reňki',
    '🧑🏾‍🔧' => 'mehanik: orta goýy deri reňki',
    '🧑🏿‍🔧' => 'mehanik: goýy deri reňki',
    '👨🏻‍🔧' => 'erkek mehanik: açyk deri reňki',
    '👨🏼‍🔧' => 'erkek mehanik: orta açyk deri reňki',
    '👨🏽‍🔧' => 'erkek mehanik: orta deri reňki',
    '👨🏾‍🔧' => 'erkek mehanik: orta goýy deri reňki',
    '👨🏿‍🔧' => 'erkek mehanik: goýy deri reňki',
    '👩🏻‍🔧' => 'zenan mehanik: açyk deri reňki',
    '👩🏼‍🔧' => 'zenan mehanik: orta açyk deri reňki',
    '👩🏽‍🔧' => 'zenan mehanik: orta deri reňki',
    '👩🏾‍🔧' => 'zenan mehanik: orta goýy deri reňki',
    '👩🏿‍🔧' => 'zenan mehanik: goýy deri reňki',
    '🧑🏻‍🏭' => 'fabrik işçisi: açyk deri reňki',
    '🧑🏼‍🏭' => 'fabrik işçisi: orta açyk deri reňki',
    '🧑🏽‍🏭' => 'fabrik işçisi: orta deri reňki',
    '🧑🏾‍🏭' => 'fabrik işçisi: orta goýy deri reňki',
    '🧑🏿‍🏭' => 'fabrik işçisi: goýy deri reňki',
    '👨🏻‍🏭' => 'erkek zawod işçisi: açyk deri reňki',
    '👨🏼‍🏭' => 'erkek zawod işçisi: orta açyk deri reňki',
    '👨🏽‍🏭' => 'erkek zawod işçisi: orta deri reňki',
    '👨🏾‍🏭' => 'erkek zawod işçisi: orta goýy deri reňki',
    '👨🏿‍🏭' => 'erkek zawod işçisi: goýy deri reňki',
    '👩🏻‍🏭' => 'zenan zawod işçisi: açyk deri reňki',
    '👩🏼‍🏭' => 'zenan zawod işçisi: orta açyk deri reňki',
    '👩🏽‍🏭' => 'zenan zawod işçisi: orta deri reňki',
    '👩🏾‍🏭' => 'zenan zawod işçisi: orta goýy deri reňki',
    '👩🏿‍🏭' => 'zenan zawod işçisi: goýy deri reňki',
    '🧑🏻‍💼' => 'edara işçisi: açyk deri reňki',
    '🧑🏼‍💼' => 'edara işçisi: orta açyk deri reňki',
    '🧑🏽‍💼' => 'edara işçisi: orta deri reňki',
    '🧑🏾‍💼' => 'edara işçisi: orta goýy deri reňki',
    '🧑🏿‍💼' => 'edara işçisi: goýy deri reňki',
    '👨🏻‍💼' => 'erkek ofis işgäri: açyk deri reňki',
    '👨🏼‍💼' => 'erkek ofis işgäri: orta açyk deri reňki',
    '👨🏽‍💼' => 'erkek ofis işgäri: orta deri reňki',
    '👨🏾‍💼' => 'erkek ofis işgäri: orta goýy deri reňki',
    '👨🏿‍💼' => 'erkek ofis işgäri: goýy deri reňki',
    '👩🏻‍💼' => 'zenan ofis işgäri: açyk deri reňki',
    '👩🏼‍💼' => 'zenan ofis işgäri: orta açyk deri reňki',
    '👩🏽‍💼' => 'zenan ofis işgäri: orta deri reňki',
    '👩🏾‍💼' => 'zenan ofis işgäri: orta goýy deri reňki',
    '👩🏿‍💼' => 'zenan ofis işgäri: goýy deri reňki',
    '🧑🏻‍🔬' => 'alym: açyk deri reňki',
    '🧑🏼‍🔬' => 'alym: orta açyk deri reňki',
    '🧑🏽‍🔬' => 'alym: orta deri reňki',
    '🧑🏾‍🔬' => 'alym: orta goýy deri reňki',
    '🧑🏿‍🔬' => 'alym: goýy deri reňki',
    '👨🏻‍🔬' => 'erkek alym: açyk deri reňki',
    '👨🏼‍🔬' => 'erkek alym: orta açyk deri reňki',
    '👨🏽‍🔬' => 'erkek alym: orta deri reňki',
    '👨🏾‍🔬' => 'erkek alym: orta goýy deri reňki',
    '👨🏿‍🔬' => 'erkek alym: goýy deri reňki',
    '👩🏻‍🔬' => 'zenan alym: açyk deri reňki',
    '👩🏼‍🔬' => 'zenan alym: orta açyk deri reňki',
    '👩🏽‍🔬' => 'zenan alym: orta deri reňki',
    '👩🏾‍🔬' => 'zenan alym: orta goýy deri reňki',
    '👩🏿‍🔬' => 'zenan alym: goýy deri reňki',
    '🧑🏻‍💻' => 'tehnolog: açyk deri reňki',
    '🧑🏼‍💻' => 'tehnolog: orta açyk deri reňki',
    '🧑🏽‍💻' => 'tehnolog: orta deri reňki',
    '🧑🏾‍💻' => 'tehnolog: orta goýy deri reňki',
    '🧑🏿‍💻' => 'tehnolog: goýy deri reňki',
    '👨🏻‍💻' => 'erkek tehnolog: açyk deri reňki',
    '👨🏼‍💻' => 'erkek tehnolog: orta açyk deri reňki',
    '👨🏽‍💻' => 'erkek tehnolog: orta deri reňki',
    '👨🏾‍💻' => 'erkek tehnolog: orta goýy deri reňki',
    '👨🏿‍💻' => 'erkek tehnolog: goýy deri reňki',
    '👩🏻‍💻' => 'zenan tehnolog: açyk deri reňki',
    '👩🏼‍💻' => 'zenan tehnolog: orta açyk deri reňki',
    '👩🏽‍💻' => 'zenan tehnolog: orta deri reňki',
    '👩🏾‍💻' => 'zenan tehnolog: orta goýy deri reňki',
    '👩🏿‍💻' => 'zenan tehnolog: goýy deri reňki',
    '🧑🏻‍🎤' => 'aýdymçy: açyk deri reňki',
    '🧑🏼‍🎤' => 'aýdymçy: orta açyk deri reňki',
    '🧑🏽‍🎤' => 'aýdymçy: orta deri reňki',
    '🧑🏾‍🎤' => 'aýdymçy: orta goýy deri reňki',
    '🧑🏿‍🎤' => 'aýdymçy: goýy deri reňki',
    '👨🏻‍🎤' => 'erkek aýdymçy: açyk deri reňki',
    '👨🏼‍🎤' => 'erkek aýdymçy: orta açyk deri reňki',
    '👨🏽‍🎤' => 'erkek aýdymçy: orta deri reňki',
    '👨🏾‍🎤' => 'erkek aýdymçy: orta goýy deri reňki',
    '👨🏿‍🎤' => 'erkek aýdymçy: goýy deri reňki',
    '👩🏻‍🎤' => 'zenan aýdymçy: açyk deri reňki',
    '👩🏼‍🎤' => 'zenan aýdymçy: orta açyk deri reňki',
    '👩🏽‍🎤' => 'zenan aýdymçy: orta deri reňki',
    '👩🏾‍🎤' => 'zenan aýdymçy: orta goýy deri reňki',
    '👩🏿‍🎤' => 'zenan aýdymçy: goýy deri reňki',
    '🧑🏻‍🎨' => 'suratkeş: açyk deri reňki',
    '🧑🏼‍🎨' => 'suratkeş: orta açyk deri reňki',
    '🧑🏽‍🎨' => 'suratkeş: orta deri reňki',
    '🧑🏾‍🎨' => 'suratkeş: orta goýy deri reňki',
    '🧑🏿‍🎨' => 'suratkeş: goýy deri reňki',
    '👨🏻‍🎨' => 'erkek suratkeş: açyk deri reňki',
    '👨🏼‍🎨' => 'erkek suratkeş: orta açyk deri reňki',
    '👨🏽‍🎨' => 'erkek suratkeş: orta deri reňki',
    '👨🏾‍🎨' => 'erkek suratkeş: orta goýy deri reňki',
    '👨🏿‍🎨' => 'erkek suratkeş: goýy deri reňki',
    '👩🏻‍🎨' => 'zenan surarteş: açyk deri reňki',
    '👩🏼‍🎨' => 'zenan surarteş: orta açyk deri reňki',
    '👩🏽‍🎨' => 'zenan surarteş: orta deri reňki',
    '👩🏾‍🎨' => 'zenan surarteş: orta goýy deri reňki',
    '👩🏿‍🎨' => 'zenan surarteş: goýy deri reňki',
    '🧑🏻‍✈' => 'uçarman: açyk deri reňki',
    '🧑🏼‍✈' => 'uçarman: orta açyk deri reňki',
    '🧑🏽‍✈' => 'uçarman: orta deri reňki',
    '🧑🏾‍✈' => 'uçarman: orta goýy deri reňki',
    '🧑🏿‍✈' => 'uçarman: goýy deri reňki',
    '👨🏻‍✈' => 'erkek uçarman: açyk deri reňki',
    '👨🏼‍✈' => 'erkek uçarman: orta açyk deri reňki',
    '👨🏽‍✈' => 'erkek uçarman: orta deri reňki',
    '👨🏾‍✈' => 'erkek uçarman: orta goýy deri reňki',
    '👨🏿‍✈' => 'erkek uçarman: goýy deri reňki',
    '👩🏻‍✈' => 'zenan uçarman: açyk deri reňki',
    '👩🏼‍✈' => 'zenan uçarman: orta açyk deri reňki',
    '👩🏽‍✈' => 'zenan uçarman: orta deri reňki',
    '👩🏾‍✈' => 'zenan uçarman: orta goýy deri reňki',
    '👩🏿‍✈' => 'zenan uçarman: goýy deri reňki',
    '🧑🏻‍🚀' => 'kosmonawt: açyk deri reňki',
    '🧑🏼‍🚀' => 'kosmonawt: orta açyk deri reňki',
    '🧑🏽‍🚀' => 'kosmonawt: orta deri reňki',
    '🧑🏾‍🚀' => 'kosmonawt: orta goýy deri reňki',
    '🧑🏿‍🚀' => 'kosmonawt: goýy deri reňki',
    '👨🏻‍🚀' => 'erkek kosmonawt: açyk deri reňki',
    '👨🏼‍🚀' => 'erkek kosmonawt: orta açyk deri reňki',
    '👨🏽‍🚀' => 'erkek kosmonawt: orta deri reňki',
    '👨🏾‍🚀' => 'erkek kosmonawt: orta goýy deri reňki',
    '👨🏿‍🚀' => 'erkek kosmonawt: goýy deri reňki',
    '👩🏻‍🚀' => 'zenan kosmonawt: açyk deri reňki',
    '👩🏼‍🚀' => 'zenan kosmonawt: orta açyk deri reňki',
    '👩🏽‍🚀' => 'zenan kosmonawt: orta deri reňki',
    '👩🏾‍🚀' => 'zenan kosmonawt: orta goýy deri reňki',
    '👩🏿‍🚀' => 'zenan kosmonawt: goýy deri reňki',
    '🧑🏻‍🚒' => 'ýangyn söndüriji işgär: açyk deri reňki',
    '🧑🏼‍🚒' => 'ýangyn söndüriji işgär: orta açyk deri reňki',
    '🧑🏽‍🚒' => 'ýangyn söndüriji işgär: orta deri reňki',
    '🧑🏾‍🚒' => 'ýangyn söndüriji işgär: orta goýy deri reňki',
    '🧑🏿‍🚒' => 'ýangyn söndüriji işgär: goýy deri reňki',
    '👨🏻‍🚒' => 'erkek ýangyn söndüriji: açyk deri reňki',
    '👨🏼‍🚒' => 'erkek ýangyn söndüriji: orta açyk deri reňki',
    '👨🏽‍🚒' => 'erkek ýangyn söndüriji: orta deri reňki',
    '👨🏾‍🚒' => 'erkek ýangyn söndüriji: orta goýy deri reňki',
    '👨🏿‍🚒' => 'erkek ýangyn söndüriji: goýy deri reňki',
    '👩🏻‍🚒' => 'zenan ýangyn söndüriji: açyk deri reňki',
    '👩🏼‍🚒' => 'zenan ýangyn söndüriji: orta açyk deri reňki',
    '👩🏽‍🚒' => 'zenan ýangyn söndüriji: orta deri reňki',
    '👩🏾‍🚒' => 'zenan ýangyn söndüriji: orta goýy deri reňki',
    '👩🏿‍🚒' => 'zenan ýangyn söndüriji: goýy deri reňki',
    '👮🏻‍♂' => 'erkek polisiýa işgäri: açyk deri reňki',
    '👮🏼‍♂' => 'erkek polisiýa işgäri: orta açyk deri reňki',
    '👮🏽‍♂' => 'erkek polisiýa işgäri: orta deri reňki',
    '👮🏾‍♂' => 'erkek polisiýa işgäri: orta goýy deri reňki',
    '👮🏿‍♂' => 'erkek polisiýa işgäri: goýy deri reňki',
    '👮🏻‍♀' => 'zenan polisiýa işgäri: açyk deri reňki',
    '👮🏼‍♀' => 'zenan polisiýa işgäri: orta açyk deri reňki',
    '👮🏽‍♀' => 'zenan polisiýa işgäri: orta deri reňki',
    '👮🏾‍♀' => 'zenan polisiýa işgäri: orta goýy deri reňki',
    '👮🏿‍♀' => 'zenan polisiýa işgäri: goýy deri reňki',
    '🕵🏻‍♂' => 'erkek aňtawçy: açyk deri reňki',
    '🕵🏼‍♂' => 'erkek aňtawçy: orta açyk deri reňki',
    '🕵🏽‍♂' => 'erkek aňtawçy: orta deri reňki',
    '🕵🏾‍♂' => 'erkek aňtawçy: orta goýy deri reňki',
    '🕵🏿‍♂' => 'erkek aňtawçy: goýy deri reňki',
    '🕵🏻‍♀' => 'zenan aňtawçy: açyk deri reňki',
    '🕵🏼‍♀' => 'zenan aňtawçy: orta açyk deri reňki',
    '🕵🏽‍♀' => 'zenan aňtawçy: orta deri reňki',
    '🕵🏾‍♀' => 'zenan aňtawçy: orta goýy deri reňki',
    '🕵🏿‍♀' => 'zenan aňtawçy: goýy deri reňki',
    '💂🏻‍♂' => 'erkek sakçy: açyk deri reňki',
    '💂🏼‍♂' => 'erkek sakçy: orta açyk deri reňki',
    '💂🏽‍♂' => 'erkek sakçy: orta deri reňki',
    '💂🏾‍♂' => 'erkek sakçy: orta goýy deri reňki',
    '💂🏿‍♂' => 'erkek sakçy: goýy deri reňki',
    '💂🏻‍♀' => 'zenan sakçy: açyk deri reňki',
    '💂🏼‍♀' => 'zenan sakçy: orta açyk deri reňki',
    '💂🏽‍♀' => 'zenan sakçy: orta deri reňki',
    '💂🏾‍♀' => 'zenan sakçy: orta goýy deri reňki',
    '💂🏿‍♀' => 'zenan sakçy: goýy deri reňki',
    '👷🏻‍♂' => 'erkek gurluşyk işçisi: açyk deri reňki',
    '👷🏼‍♂' => 'erkek gurluşyk işçisi: orta açyk deri reňki',
    '👷🏽‍♂' => 'erkek gurluşyk işçisi: orta deri reňki',
    '👷🏾‍♂' => 'erkek gurluşyk işçisi: orta goýy deri reňki',
    '👷🏿‍♂' => 'erkek gurluşyk işçisi: goýy deri reňki',
    '👷🏻‍♀' => 'zenan gurluşyk işçisi: açyk deri reňki',
    '👷🏼‍♀' => 'zenan gurluşyk işçisi: orta açyk deri reňki',
    '👷🏽‍♀' => 'zenan gurluşyk işçisi: orta deri reňki',
    '👷🏾‍♀' => 'zenan gurluşyk işçisi: orta goýy deri reňki',
    '👷🏿‍♀' => 'zenan gurluşyk işçisi: goýy deri reňki',
    '👳🏻‍♂' => 'selleli erkek: açyk deri reňki',
    '👳🏼‍♂' => 'selleli erkek: orta açyk deri reňki',
    '👳🏽‍♂' => 'selleli erkek: orta deri reňki',
    '👳🏾‍♂' => 'selleli erkek: orta goýy deri reňki',
    '👳🏿‍♂' => 'selleli erkek: goýy deri reňki',
    '👳🏻‍♀' => 'selleli zenan: açyk deri reňki',
    '👳🏼‍♀' => 'selleli zenan: orta açyk deri reňki',
    '👳🏽‍♀' => 'selleli zenan: orta deri reňki',
    '👳🏾‍♀' => 'selleli zenan: orta goýy deri reňki',
    '👳🏿‍♀' => 'selleli zenan: goýy deri reňki',
    '🤵🏻‍♂' => 'smokingde erkek: açyk deri reňki',
    '🤵🏼‍♂' => 'smokingde erkek: orta açyk deri reňki',
    '🤵🏽‍♂' => 'smokingde erkek: orta deri reňki',
    '🤵🏾‍♂' => 'smokingde erkek: orta goýy deri reňki',
    '🤵🏿‍♂' => 'smokingde erkek: goýy deri reňki',
    '🤵🏻‍♀' => 'aýal smokingde: açyk deri reňki',
    '🤵🏼‍♀' => 'aýal smokingde: orta açyk deri reňki',
    '🤵🏽‍♀' => 'aýal smokingde: orta deri reňki',
    '🤵🏾‍♀' => 'aýal smokingde: orta goýy deri reňki',
    '🤵🏿‍♀' => 'aýal smokingde: goýy deri reňki',
    '👰🏻‍♂' => 'fataly erkek: açyk deri reňki',
    '👰🏼‍♂' => 'fataly erkek: orta açyk deri reňki',
    '👰🏽‍♂' => 'fataly erkek: orta deri reňki',
    '👰🏾‍♂' => 'fataly erkek: orta goýy deri reňki',
    '👰🏿‍♂' => 'fataly erkek: goýy deri reňki',
    '👰🏻‍♀' => 'fataly aýal: açyk deri reňki',
    '👰🏼‍♀' => 'fataly aýal: orta açyk deri reňki',
    '👰🏽‍♀' => 'fataly aýal: orta deri reňki',
    '👰🏾‍♀' => 'fataly aýal: orta goýy deri reňki',
    '👰🏿‍♀' => 'fataly aýal: goýy deri reňki',
    '👩🏻‍🍼' => 'bäbegi emdirýän aýal: açyk deri reňki',
    '👩🏼‍🍼' => 'bäbegi emdirýän aýal: orta açyk deri reňki',
    '👩🏽‍🍼' => 'bäbegi emdirýän aýal: orta deri reňki',
    '👩🏾‍🍼' => 'bäbegi emdirýän aýal: orta goýy deri reňki',
    '👩🏿‍🍼' => 'bäbegi emdirýän aýal: goýy deri reňki',
    '👨🏻‍🍼' => 'bäbegi emdirýän erkek: açyk deri reňki',
    '👨🏼‍🍼' => 'bäbegi emdirýän erkek: orta açyk deri reňki',
    '👨🏽‍🍼' => 'bäbegi emdirýän erkek: orta deri reňki',
    '👨🏾‍🍼' => 'bäbegi emdirýän erkek: orta goýy deri reňki',
    '👨🏿‍🍼' => 'bäbegi emdirýän erkek: goýy deri reňki',
    '🧑🏻‍🍼' => 'bäbegi emdirýän adam: açyk deri reňki',
    '🧑🏼‍🍼' => 'bäbegi emdirýän adam: orta açyk deri reňki',
    '🧑🏽‍🍼' => 'bäbegi emdirýän adam: orta deri reňki',
    '🧑🏾‍🍼' => 'bäbegi emdirýän adam: orta goýy deri reňki',
    '🧑🏿‍🍼' => 'bäbegi emdirýän adam: goýy deri reňki',
    '🧑🏻‍🎄' => 'maks klaus: açyk deri reňki',
    '🧑🏼‍🎄' => 'maks klaus: orta açyk deri reňki',
    '🧑🏽‍🎄' => 'maks klaus: orta deri reňki',
    '🧑🏾‍🎄' => 'maks klaus: orta goýy deri reňki',
    '🧑🏿‍🎄' => 'maks klaus: goýy deri reňki',
    '🦸🏻‍♂' => 'erkek supergahryman: açyk deri reňki',
    '🦸🏼‍♂' => 'erkek supergahryman: orta açyk deri reňki',
    '🦸🏽‍♂' => 'erkek supergahryman: orta deri reňki',
    '🦸🏾‍♂' => 'erkek supergahryman: orta goýy deri reňki',
    '🦸🏿‍♂' => 'erkek supergahryman: goýy deri reňki',
    '🦸🏻‍♀' => 'zenan supergahryman: açyk deri reňki',
    '🦸🏼‍♀' => 'zenan supergahryman: orta açyk deri reňki',
    '🦸🏽‍♀' => 'zenan supergahryman: orta deri reňki',
    '🦸🏾‍♀' => 'zenan supergahryman: orta goýy deri reňki',
    '🦸🏿‍♀' => 'zenan supergahryman: goýy deri reňki',
    '🦹🏻‍♂' => 'erkek superbetpäl: açyk deri reňki',
    '🦹🏼‍♂' => 'erkek superbetpäl: orta açyk deri reňki',
    '🦹🏽‍♂' => 'erkek superbetpäl: orta deri reňki',
    '🦹🏾‍♂' => 'erkek superbetpäl: orta goýy deri reňki',
    '🦹🏿‍♂' => 'erkek superbetpäl: goýy deri reňki',
    '🦹🏻‍♀' => 'zenan superbetpäl: açyk deri reňki',
    '🦹🏼‍♀' => 'zenan superbetpäl: orta açyk deri reňki',
    '🦹🏽‍♀' => 'zenan superbetpäl: orta deri reňki',
    '🦹🏾‍♀' => 'zenan superbetpäl: orta goýy deri reňki',
    '🦹🏿‍♀' => 'zenan superbetpäl: goýy deri reňki',
    '🧙🏻‍♂' => 'jadygöý erkek: açyk deri reňki',
    '🧙🏼‍♂' => 'jadygöý erkek: orta açyk deri reňki',
    '🧙🏽‍♂' => 'jadygöý erkek: orta deri reňki',
    '🧙🏾‍♂' => 'jadygöý erkek: orta goýy deri reňki',
    '🧙🏿‍♂' => 'jadygöý erkek: goýy deri reňki',
    '🧙🏻‍♀' => 'jadygöý aýal: açyk deri reňki',
    '🧙🏼‍♀' => 'jadygöý aýal: orta açyk deri reňki',
    '🧙🏽‍♀' => 'jadygöý aýal: orta deri reňki',
    '🧙🏾‍♀' => 'jadygöý aýal: orta goýy deri reňki',
    '🧙🏿‍♀' => 'jadygöý aýal: goýy deri reňki',
    '🧚🏻‍♂' => 'peri erkek: açyk deri reňki',
    '🧚🏼‍♂' => 'peri erkek: orta açyk deri reňki',
    '🧚🏽‍♂' => 'peri erkek: orta deri reňki',
    '🧚🏾‍♂' => 'peri erkek: orta goýy deri reňki',
    '🧚🏿‍♂' => 'peri erkek: goýy deri reňki',
    '🧚🏻‍♀' => 'perizat: açyk deri reňki',
    '🧚🏼‍♀' => 'perizat: orta açyk deri reňki',
    '🧚🏽‍♀' => 'perizat: orta deri reňki',
    '🧚🏾‍♀' => 'perizat: orta goýy deri reňki',
    '🧚🏿‍♀' => 'perizat: goýy deri reňki',
    '🧛🏻‍♂' => 'wampir erkek: açyk deri reňki',
    '🧛🏼‍♂' => 'wampir erkek: orta açyk deri reňki',
    '🧛🏽‍♂' => 'wampir erkek: orta deri reňki',
    '🧛🏾‍♂' => 'wampir erkek: orta goýy deri reňki',
    '🧛🏿‍♂' => 'wampir erkek: goýy deri reňki',
    '🧛🏻‍♀' => 'wampir aýal: açyk deri reňki',
    '🧛🏼‍♀' => 'wampir aýal: orta açyk deri reňki',
    '🧛🏽‍♀' => 'wampir aýal: orta deri reňki',
    '🧛🏾‍♀' => 'wampir aýal: orta goýy deri reňki',
    '🧛🏿‍♀' => 'wampir aýal: goýy deri reňki',
    '🧜🏻‍♂' => 'suw erkegi: açyk deri reňki',
    '🧜🏼‍♂' => 'suw erkegi: orta açyk deri reňki',
    '🧜🏽‍♂' => 'suw erkegi: orta deri reňki',
    '🧜🏾‍♂' => 'suw erkegi: orta goýy deri reňki',
    '🧜🏿‍♂' => 'suw erkegi: goýy deri reňki',
    '🧜🏻‍♀' => 'suw gyzy: açyk deri reňki',
    '🧜🏼‍♀' => 'suw gyzy: orta açyk deri reňki',
    '🧜🏽‍♀' => 'suw gyzy: orta deri reňki',
    '🧜🏾‍♀' => 'suw gyzy: orta goýy deri reňki',
    '🧜🏿‍♀' => 'suw gyzy: goýy deri reňki',
    '🧝🏻‍♂' => 'erkek elf: açyk deri reňki',
    '🧝🏼‍♂' => 'erkek elf: orta açyk deri reňki',
    '🧝🏽‍♂' => 'erkek elf: orta deri reňki',
    '🧝🏾‍♂' => 'erkek elf: orta goýy deri reňki',
    '🧝🏿‍♂' => 'erkek elf: goýy deri reňki',
    '🧝🏻‍♀' => 'aýal elf: açyk deri reňki',
    '🧝🏼‍♀' => 'aýal elf: orta açyk deri reňki',
    '🧝🏽‍♀' => 'aýal elf: orta deri reňki',
    '🧝🏾‍♀' => 'aýal elf: orta goýy deri reňki',
    '🧝🏿‍♀' => 'aýal elf: goýy deri reňki',
    '💆🏻‍♂' => 'massaž edilýän erkek: açyk deri reňki',
    '💆🏼‍♂' => 'massaž edilýän erkek: orta açyk deri reňki',
    '💆🏽‍♂' => 'massaž edilýän erkek: orta deri reňki',
    '💆🏾‍♂' => 'massaž edilýän erkek: orta goýy deri reňki',
    '💆🏿‍♂' => 'massaž edilýän erkek: goýy deri reňki',
    '💆🏻‍♀' => 'massaž edilýän zenan: açyk deri reňki',
    '💆🏼‍♀' => 'massaž edilýän zenan: orta açyk deri reňki',
    '💆🏽‍♀' => 'massaž edilýän zenan: orta deri reňki',
    '💆🏾‍♀' => 'massaž edilýän zenan: orta goýy deri reňki',
    '💆🏿‍♀' => 'massaž edilýän zenan: goýy deri reňki',
    '💇🏻‍♂' => 'saçy kiçeldilýän erkek: açyk deri reňki',
    '💇🏼‍♂' => 'saçy kiçeldilýän erkek: orta açyk deri reňki',
    '💇🏽‍♂' => 'saçy kiçeldilýän erkek: orta deri reňki',
    '💇🏾‍♂' => 'saçy kiçeldilýän erkek: orta goýy deri reňki',
    '💇🏿‍♂' => 'saçy kiçeldilýän erkek: goýy deri reňki',
    '💇🏻‍♀' => 'saçy kiçeldilýän zenan: açyk deri reňki',
    '💇🏼‍♀' => 'saçy kiçeldilýän zenan: orta açyk deri reňki',
    '💇🏽‍♀' => 'saçy kiçeldilýän zenan: orta deri reňki',
    '💇🏾‍♀' => 'saçy kiçeldilýän zenan: orta goýy deri reňki',
    '💇🏿‍♀' => 'saçy kiçeldilýän zenan: goýy deri reňki',
    '🚶🏻‍♂' => 'ýöräp barýan erkek: açyk deri reňki',
    '🚶🏼‍♂' => 'ýöräp barýan erkek: orta açyk deri reňki',
    '🚶🏽‍♂' => 'ýöräp barýan erkek: orta deri reňki',
    '🚶🏾‍♂' => 'ýöräp barýan erkek: orta goýy deri reňki',
    '🚶🏿‍♂' => 'ýöräp barýan erkek: goýy deri reňki',
    '🚶🏻‍♀' => 'ýörap barýan zenan: açyk deri reňki',
    '🚶🏼‍♀' => 'ýörap barýan zenan: orta açyk deri reňki',
    '🚶🏽‍♀' => 'ýörap barýan zenan: orta deri reňki',
    '🚶🏾‍♀' => 'ýörap barýan zenan: orta goýy deri reňki',
    '🚶🏿‍♀' => 'ýörap barýan zenan: goýy deri reňki',
    '🚶🏻‍➡' => 'ýöräp barýan adam: açyk deri reňki, ýüzi saga',
    '🚶🏼‍➡' => 'ýöräp barýan adam: orta açyk deri reňki, ýüzi saga',
    '🚶🏽‍➡' => 'ýöräp barýan adam: orta deri reňki, ýüzi saga',
    '🚶🏾‍➡' => 'ýöräp barýan adam: orta goýy deri reňki, ýüzi saga',
    '🚶🏿‍➡' => 'ýöräp barýan adam: goýy deri reňki, ýüzi saga',
    '🧍🏻‍♂' => 'dik duran erkek: açyk deri reňki',
    '🧍🏼‍♂' => 'dik duran erkek: orta açyk deri reňki',
    '🧍🏽‍♂' => 'dik duran erkek: orta deri reňki',
    '🧍🏾‍♂' => 'dik duran erkek: orta goýy deri reňki',
    '🧍🏿‍♂' => 'dik duran erkek: goýy deri reňki',
    '🧍🏻‍♀' => 'dik duran zenan: açyk deri reňki',
    '🧍🏼‍♀' => 'dik duran zenan: orta açyk deri reňki',
    '🧍🏽‍♀' => 'dik duran zenan: orta deri reňki',
    '🧍🏾‍♀' => 'dik duran zenan: orta goýy deri reňki',
    '🧍🏿‍♀' => 'dik duran zenan: goýy deri reňki',
    '🧎🏻‍♂' => 'dyza çöken erkek: açyk deri reňki',
    '🧎🏼‍♂' => 'dyza çöken erkek: orta açyk deri reňki',
    '🧎🏽‍♂' => 'dyza çöken erkek: orta deri reňki',
    '🧎🏾‍♂' => 'dyza çöken erkek: orta goýy deri reňki',
    '🧎🏿‍♂' => 'dyza çöken erkek: goýy deri reňki',
    '🧎🏻‍♀' => 'dyza çöken zenan: açyk deri reňki',
    '🧎🏼‍♀' => 'dyza çöken zenan: orta açyk deri reňki',
    '🧎🏽‍♀' => 'dyza çöken zenan: orta deri reňki',
    '🧎🏾‍♀' => 'dyza çöken zenan: orta goýy deri reňki',
    '🧎🏿‍♀' => 'dyza çöken zenan: goýy deri reňki',
    '🧎🏻‍➡' => 'dyza çöken adam: açyk deri reňki, ýüzi saga',
    '🧎🏼‍➡' => 'dyza çöken adam: orta açyk deri reňki, ýüzi saga',
    '🧎🏽‍➡' => 'dyza çöken adam: orta deri reňki, ýüzi saga',
    '🧎🏾‍➡' => 'dyza çöken adam: orta goýy deri reňki, ýüzi saga',
    '🧎🏿‍➡' => 'dyza çöken adam: goýy deri reňki, ýüzi saga',
    '🧑🏻‍🦯' => 'kör hasaly adam: açyk deri reňki',
    '🧑🏼‍🦯' => 'kör hasaly adam: orta açyk deri reňki',
    '🧑🏽‍🦯' => 'kör hasaly adam: orta deri reňki',
    '🧑🏾‍🦯' => 'kör hasaly adam: orta goýy deri reňki',
    '🧑🏿‍🦯' => 'kör hasaly adam: goýy deri reňki',
    '👨🏻‍🦯' => 'kör hasaly erkek: açyk deri reňki',
    '👨🏼‍🦯' => 'kör hasaly erkek: orta açyk deri reňki',
    '👨🏽‍🦯' => 'kör hasaly erkek: orta deri reňki',
    '👨🏾‍🦯' => 'kör hasaly erkek: orta goýy deri reňki',
    '👨🏿‍🦯' => 'kör hasaly erkek: goýy deri reňki',
    '👩🏻‍🦯' => 'kör hasaly zenan: açyk deri reňki',
    '👩🏼‍🦯' => 'kör hasaly zenan: orta açyk deri reňki',
    '👩🏽‍🦯' => 'kör hasaly zenan: orta deri reňki',
    '👩🏾‍🦯' => 'kör hasaly zenan: orta goýy deri reňki',
    '👩🏿‍🦯' => 'kör hasaly zenan: goýy deri reňki',
    '🧑🏻‍🦼' => 'motorly arabajykdaky adam: açyk deri reňki',
    '🧑🏼‍🦼' => 'motorly arabajykdaky adam: orta açyk deri reňki',
    '🧑🏽‍🦼' => 'motorly arabajykdaky adam: orta deri reňki',
    '🧑🏾‍🦼' => 'motorly arabajykdaky adam: orta goýy deri reňki',
    '🧑🏿‍🦼' => 'motorly arabajykdaky adam: goýy deri reňki',
    '👨🏻‍🦼' => 'motorly maýyp arabasynda erkek: açyk deri reňki',
    '👨🏼‍🦼' => 'motorly maýyp arabasynda erkek: orta açyk deri reňki',
    '👨🏽‍🦼' => 'motorly maýyp arabasynda erkek: orta deri reňki',
    '👨🏾‍🦼' => 'motorly maýyp arabasynda erkek: orta goýy deri reňki',
    '👨🏿‍🦼' => 'motorly maýyp arabasynda erkek: goýy deri reňki',
    '👩🏻‍🦼' => 'motorly maýyp arabasynda zenan: açyk deri reňki',
    '👩🏼‍🦼' => 'motorly maýyp arabasynda zenan: orta açyk deri reňki',
    '👩🏽‍🦼' => 'motorly maýyp arabasynda zenan: orta deri reňki',
    '👩🏾‍🦼' => 'motorly maýyp arabasynda zenan: orta goýy deri reňki',
    '👩🏿‍🦼' => 'motorly maýyp arabasynda zenan: goýy deri reňki',
    '🧑🏻‍🦽' => 'el bilen işleýän tigirçekli oturgyçdaky adam: açyk deri reňki',
    '🧑🏼‍🦽' => 'el bilen işleýän tigirçekli oturgyçdaky adam: orta açyk deri reňki',
    '🧑🏽‍🦽' => 'el bilen işleýän tigirçekli oturgyçdaky adam: orta deri reňki',
    '🧑🏾‍🦽' => 'el bilen işleýän tigirçekli oturgyçdaky adam: orta goýy deri reňki',
    '🧑🏿‍🦽' => 'el bilen işleýän tigirçekli oturgyçdaky adam: goýy deri reňki',
    '👨🏻‍🦽' => 'el maýyp arabasynda erkek: açyk deri reňki',
    '👨🏼‍🦽' => 'el maýyp arabasynda erkek: orta açyk deri reňki',
    '👨🏽‍🦽' => 'el maýyp arabasynda erkek: orta deri reňki',
    '👨🏾‍🦽' => 'el maýyp arabasynda erkek: orta goýy deri reňki',
    '👨🏿‍🦽' => 'el maýyp arabasynda erkek: goýy deri reňki',
    '👩🏻‍🦽' => 'el maýyp arabasynda zenan: açyk deri reňki',
    '👩🏼‍🦽' => 'el maýyp arabasynda zenan: orta açyk deri reňki',
    '👩🏽‍🦽' => 'el maýyp arabasynda zenan: orta deri reňki',
    '👩🏾‍🦽' => 'el maýyp arabasynda zenan: orta goýy deri reňki',
    '👩🏿‍🦽' => 'el maýyp arabasynda zenan: goýy deri reňki',
    '🏃🏻‍♂' => 'ylgap barýan erkek: açyk deri reňki',
    '🏃🏼‍♂' => 'ylgap barýan erkek: orta açyk deri reňki',
    '🏃🏽‍♂' => 'ylgap barýan erkek: orta deri reňki',
    '🏃🏾‍♂' => 'ylgap barýan erkek: orta goýy deri reňki',
    '🏃🏿‍♂' => 'ylgap barýan erkek: goýy deri reňki',
    '🏃🏻‍♀' => 'ylgap barýan zenan: açyk deri reňki',
    '🏃🏼‍♀' => 'ylgap barýan zenan: orta açyk deri reňki',
    '🏃🏽‍♀' => 'ylgap barýan zenan: orta deri reňki',
    '🏃🏾‍♀' => 'ylgap barýan zenan: orta goýy deri reňki',
    '🏃🏿‍♀' => 'ylgap barýan zenan: goýy deri reňki',
    '🏃🏻‍➡' => 'ylgap barýan adam: açyk deri reňki, ýüzi saga',
    '🏃🏼‍➡' => 'ylgap barýan adam: orta açyk deri reňki, ýüzi saga',
    '🏃🏽‍➡' => 'ylgap barýan adam: orta deri reňki, ýüzi saga',
    '🏃🏾‍➡' => 'ylgap barýan adam: orta goýy deri reňki, ýüzi saga',
    '🏃🏿‍➡' => 'ylgap barýan adam: goýy deri reňki, ýüzi saga',
    '👯🏻‍♀' => 'towşan gulakly zenanlar: açyk deri reňki',
    '👯🏼‍♀' => 'towşan gulakly zenanlar: orta açyk deri reňki',
    '👯🏽‍♀' => 'towşan gulakly zenanlar: orta deri reňki',
    '👯🏾‍♀' => 'towşan gulakly zenanlar: orta goýy deri reňki',
    '👯🏿‍♀' => 'towşan gulakly zenanlar: goýy deri reňki',
    '👯🏻‍♂' => 'towşan gulakly erkekler: açyk deri reňki',
    '👯🏼‍♂' => 'towşan gulakly erkekler: orta açyk deri reňki',
    '👯🏽‍♂' => 'towşan gulakly erkekler: orta deri reňki',
    '👯🏾‍♂' => 'towşan gulakly erkekler: orta goýy deri reňki',
    '👯🏿‍♂' => 'towşan gulakly erkekler: goýy deri reňki',
    '🧖🏻‍♂' => 'bug otagyndaky erkek: açyk deri reňki',
    '🧖🏼‍♂' => 'bug otagyndaky erkek: orta açyk deri reňki',
    '🧖🏽‍♂' => 'bug otagyndaky erkek: orta deri reňki',
    '🧖🏾‍♂' => 'bug otagyndaky erkek: orta goýy deri reňki',
    '🧖🏿‍♂' => 'bug otagyndaky erkek: goýy deri reňki',
    '🧖🏻‍♀' => 'bug otagyndaky aýal: açyk deri reňki',
    '🧖🏼‍♀' => 'bug otagyndaky aýal: orta açyk deri reňki',
    '🧖🏽‍♀' => 'bug otagyndaky aýal: orta deri reňki',
    '🧖🏾‍♀' => 'bug otagyndaky aýal: orta goýy deri reňki',
    '🧖🏿‍♀' => 'bug otagyndaky aýal: goýy deri reňki',
    '🧗🏻‍♂' => 'dyrmaşýan erkek: açyk deri reňki',
    '🧗🏼‍♂' => 'dyrmaşýan erkek: orta açyk deri reňki',
    '🧗🏽‍♂' => 'dyrmaşýan erkek: orta deri reňki',
    '🧗🏾‍♂' => 'dyrmaşýan erkek: orta goýy deri reňki',
    '🧗🏿‍♂' => 'dyrmaşýan erkek: goýy deri reňki',
    '🧗🏻‍♀' => 'dyrmaşýan zenan: açyk deri reňki',
    '🧗🏼‍♀' => 'dyrmaşýan zenan: orta açyk deri reňki',
    '🧗🏽‍♀' => 'dyrmaşýan zenan: orta deri reňki',
    '🧗🏾‍♀' => 'dyrmaşýan zenan: orta goýy deri reňki',
    '🧗🏿‍♀' => 'dyrmaşýan zenan: goýy deri reňki',
    '🏌🏻‍♂' => 'golf oýnaýan erkek: açyk deri reňki',
    '🏌🏼‍♂' => 'golf oýnaýan erkek: orta açyk deri reňki',
    '🏌🏽‍♂' => 'golf oýnaýan erkek: orta deri reňki',
    '🏌🏾‍♂' => 'golf oýnaýan erkek: orta goýy deri reňki',
    '🏌🏿‍♂' => 'golf oýnaýan erkek: goýy deri reňki',
    '🏌🏻‍♀' => 'golf oýnaýan zenan: açyk deri reňki',
    '🏌🏼‍♀' => 'golf oýnaýan zenan: orta açyk deri reňki',
    '🏌🏽‍♀' => 'golf oýnaýan zenan: orta deri reňki',
    '🏌🏾‍♀' => 'golf oýnaýan zenan: orta goýy deri reňki',
    '🏌🏿‍♀' => 'golf oýnaýan zenan: goýy deri reňki',
    '🏄🏻‍♂' => 'sörf edýän erkek: açyk deri reňki',
    '🏄🏼‍♂' => 'sörf edýän erkek: orta açyk deri reňki',
    '🏄🏽‍♂' => 'sörf edýän erkek: orta deri reňki',
    '🏄🏾‍♂' => 'sörf edýän erkek: orta goýy deri reňki',
    '🏄🏿‍♂' => 'sörf edýän erkek: goýy deri reňki',
    '🏄🏻‍♀' => 'sörf edýän zenan: açyk deri reňki',
    '🏄🏼‍♀' => 'sörf edýän zenan: orta açyk deri reňki',
    '🏄🏽‍♀' => 'sörf edýän zenan: orta deri reňki',
    '🏄🏾‍♀' => 'sörf edýän zenan: orta goýy deri reňki',
    '🏄🏿‍♀' => 'sörf edýän zenan: goýy deri reňki',
    '🚣🏻‍♂' => 'gaýyk kürekleýän erkek: açyk deri reňki',
    '🚣🏼‍♂' => 'gaýyk kürekleýän erkek: orta açyk deri reňki',
    '🚣🏽‍♂' => 'gaýyk kürekleýän erkek: orta deri reňki',
    '🚣🏾‍♂' => 'gaýyk kürekleýän erkek: orta goýy deri reňki',
    '🚣🏿‍♂' => 'gaýyk kürekleýän erkek: goýy deri reňki',
    '🚣🏻‍♀' => 'gaýyk kürekleýän zenan: açyk deri reňki',
    '🚣🏼‍♀' => 'gaýyk kürekleýän zenan: orta açyk deri reňki',
    '🚣🏽‍♀' => 'gaýyk kürekleýän zenan: orta deri reňki',
    '🚣🏾‍♀' => 'gaýyk kürekleýän zenan: orta goýy deri reňki',
    '🚣🏿‍♀' => 'gaýyk kürekleýän zenan: goýy deri reňki',
    '🏊🏻‍♂' => 'ýüzüp ýören erkek: açyk deri reňki',
    '🏊🏼‍♂' => 'ýüzüp ýören erkek: orta açyk deri reňki',
    '🏊🏽‍♂' => 'ýüzüp ýören erkek: orta deri reňki',
    '🏊🏾‍♂' => 'ýüzüp ýören erkek: orta goýy deri reňki',
    '🏊🏿‍♂' => 'ýüzüp ýören erkek: goýy deri reňki',
    '🏊🏻‍♀' => 'ýüzüp ýören zenan: açyk deri reňki',
    '🏊🏼‍♀' => 'ýüzüp ýören zenan: orta açyk deri reňki',
    '🏊🏽‍♀' => 'ýüzüp ýören zenan: orta deri reňki',
    '🏊🏾‍♀' => 'ýüzüp ýören zenan: orta goýy deri reňki',
    '🏊🏿‍♀' => 'ýüzüp ýören zenan: goýy deri reňki',
    '⛹🏻‍♂' => 'topy bökdürýän erkek: açyk deri reňki',
    '⛹🏼‍♂' => 'topy bökdürýän erkek: orta açyk deri reňki',
    '⛹🏽‍♂' => 'topy bökdürýän erkek: orta deri reňki',
    '⛹🏾‍♂' => 'topy bökdürýän erkek: orta goýy deri reňki',
    '⛹🏿‍♂' => 'topy bökdürýän erkek: goýy deri reňki',
    '⛹🏻‍♀' => 'topy bökdürýän zenan: açyk deri reňki',
    '⛹🏼‍♀' => 'topy bökdürýän zenan: orta açyk deri reňki',
    '⛹🏽‍♀' => 'topy bökdürýän zenan: orta deri reňki',
    '⛹🏾‍♀' => 'topy bökdürýän zenan: orta goýy deri reňki',
    '⛹🏿‍♀' => 'topy bökdürýän zenan: goýy deri reňki',
    '🏋🏻‍♂' => 'agyrlyk göterýän erkek: açyk deri reňki',
    '🏋🏼‍♂' => 'agyrlyk göterýän erkek: orta açyk deri reňki',
    '🏋🏽‍♂' => 'agyrlyk göterýän erkek: orta deri reňki',
    '🏋🏾‍♂' => 'agyrlyk göterýän erkek: orta goýy deri reňki',
    '🏋🏿‍♂' => 'agyrlyk göterýän erkek: goýy deri reňki',
    '🏋🏻‍♀' => 'agyrlyk göterýän zenan: açyk deri reňki',
    '🏋🏼‍♀' => 'agyrlyk göterýän zenan: orta açyk deri reňki',
    '🏋🏽‍♀' => 'agyrlyk göterýän zenan: orta deri reňki',
    '🏋🏾‍♀' => 'agyrlyk göterýän zenan: orta goýy deri reňki',
    '🏋🏿‍♀' => 'agyrlyk göterýän zenan: goýy deri reňki',
    '🚴🏻‍♂' => 'tigir sürýän erkek: açyk deri reňki',
    '🚴🏼‍♂' => 'tigir sürýän erkek: orta açyk deri reňki',
    '🚴🏽‍♂' => 'tigir sürýän erkek: orta deri reňki',
    '🚴🏾‍♂' => 'tigir sürýän erkek: orta goýy deri reňki',
    '🚴🏿‍♂' => 'tigir sürýän erkek: goýy deri reňki',
    '🚴🏻‍♀' => 'tigir sürýän zenan: açyk deri reňki',
    '🚴🏼‍♀' => 'tigir sürýän zenan: orta açyk deri reňki',
    '🚴🏽‍♀' => 'tigir sürýän zenan: orta deri reňki',
    '🚴🏾‍♀' => 'tigir sürýän zenan: orta goýy deri reňki',
    '🚴🏿‍♀' => 'tigir sürýän zenan: goýy deri reňki',
    '🚵🏻‍♂' => 'dagda tigir sürýän erkek: açyk deri reňki',
    '🚵🏼‍♂' => 'dagda tigir sürýän erkek: orta açyk deri reňki',
    '🚵🏽‍♂' => 'dagda tigir sürýän erkek: orta deri reňki',
    '🚵🏾‍♂' => 'dagda tigir sürýän erkek: orta goýy deri reňki',
    '🚵🏿‍♂' => 'dagda tigir sürýän erkek: goýy deri reňki',
    '🚵🏻‍♀' => 'dagda tigir sürýän zenan: açyk deri reňki',
    '🚵🏼‍♀' => 'dagda tigir sürýän zenan: orta açyk deri reňki',
    '🚵🏽‍♀' => 'dagda tigir sürýän zenan: orta deri reňki',
    '🚵🏾‍♀' => 'dagda tigir sürýän zenan: orta goýy deri reňki',
    '🚵🏿‍♀' => 'dagda tigir sürýän zenan: goýy deri reňki',
    '🤸🏻‍♂' => 'ýanyn aşyr atýan erkek: açyk deri reňki',
    '🤸🏼‍♂' => 'ýanyn aşyr atýan erkek: orta açyk deri reňki',
    '🤸🏽‍♂' => 'ýanyn aşyr atýan erkek: orta deri reňki',
    '🤸🏾‍♂' => 'ýanyn aşyr atýan erkek: orta goýy deri reňki',
    '🤸🏿‍♂' => 'ýanyn aşyr atýan erkek: goýy deri reňki',
    '🤸🏻‍♀' => 'ýanyn aşyr atýan zenan: açyk deri reňki',
    '🤸🏼‍♀' => 'ýanyn aşyr atýan zenan: orta açyk deri reňki',
    '🤸🏽‍♀' => 'ýanyn aşyr atýan zenan: orta deri reňki',
    '🤸🏾‍♀' => 'ýanyn aşyr atýan zenan: orta goýy deri reňki',
    '🤸🏿‍♀' => 'ýanyn aşyr atýan zenan: goýy deri reňki',
    '🤼🏻‍♀' => 'göreş tutýan zenanlar: açyk deri reňki',
    '🤼🏼‍♀' => 'göreş tutýan zenanlar: orta açyk deri reňki',
    '🤼🏽‍♀' => 'göreş tutýan zenanlar: orta deri reňki',
    '🤼🏾‍♀' => 'göreş tutýan zenanlar: orta goýy deri reňki',
    '🤼🏿‍♀' => 'göreş tutýan zenanlar: goýy deri reňki',
    '🤼🏻‍♂' => 'göreş tutýan erkekler: açyk deri reňki',
    '🤼🏼‍♂' => 'göreş tutýan erkekler: orta açyk deri reňki',
    '🤼🏽‍♂' => 'göreş tutýan erkekler: orta deri reňki',
    '🤼🏾‍♂' => 'göreş tutýan erkekler: orta goýy deri reňki',
    '🤼🏿‍♂' => 'göreş tutýan erkekler: goýy deri reňki',
    '🤽🏻‍♂' => 'suw polo oýnaýan erkek: açyk deri reňki',
    '🤽🏼‍♂' => 'suw polo oýnaýan erkek: orta açyk deri reňki',
    '🤽🏽‍♂' => 'suw polo oýnaýan erkek: orta deri reňki',
    '🤽🏾‍♂' => 'suw polo oýnaýan erkek: orta goýy deri reňki',
    '🤽🏿‍♂' => 'suw polo oýnaýan erkek: goýy deri reňki',
    '🤽🏻‍♀' => 'suw polo oýnaýan zenan: açyk deri reňki',
    '🤽🏼‍♀' => 'suw polo oýnaýan zenan: orta açyk deri reňki',
    '🤽🏽‍♀' => 'suw polo oýnaýan zenan: orta deri reňki',
    '🤽🏾‍♀' => 'suw polo oýnaýan zenan: orta goýy deri reňki',
    '🤽🏿‍♀' => 'suw polo oýnaýan zenan: goýy deri reňki',
    '🤾🏻‍♂' => 'gandbol oýnaýan erkek: açyk deri reňki',
    '🤾🏼‍♂' => 'gandbol oýnaýan erkek: orta açyk deri reňki',
    '🤾🏽‍♂' => 'gandbol oýnaýan erkek: orta deri reňki',
    '🤾🏾‍♂' => 'gandbol oýnaýan erkek: orta goýy deri reňki',
    '🤾🏿‍♂' => 'gandbol oýnaýan erkek: goýy deri reňki',
    '🤾🏻‍♀' => 'gandbol oýnaýan aýal: açyk deri reňki',
    '🤾🏼‍♀' => 'gandbol oýnaýan aýal: orta açyk deri reňki',
    '🤾🏽‍♀' => 'gandbol oýnaýan aýal: orta deri reňki',
    '🤾🏾‍♀' => 'gandbol oýnaýan aýal: orta goýy deri reňki',
    '🤾🏿‍♀' => 'gandbol oýnaýan aýal: goýy deri reňki',
    '🤹🏻‍♂' => 'hokgabazlyk edýän erkek: açyk deri reňki',
    '🤹🏼‍♂' => 'hokgabazlyk edýän erkek: orta açyk deri reňki',
    '🤹🏽‍♂' => 'hokgabazlyk edýän erkek: orta deri reňki',
    '🤹🏾‍♂' => 'hokgabazlyk edýän erkek: orta goýy deri reňki',
    '🤹🏿‍♂' => 'hokgabazlyk edýän erkek: goýy deri reňki',
    '🤹🏻‍♀' => 'hokgabazlyk edýän zenan: açyk deri reňki',
    '🤹🏼‍♀' => 'hokgabazlyk edýän zenan: orta açyk deri reňki',
    '🤹🏽‍♀' => 'hokgabazlyk edýän zenan: orta deri reňki',
    '🤹🏾‍♀' => 'hokgabazlyk edýän zenan: orta goýy deri reňki',
    '🤹🏿‍♀' => 'hokgabazlyk edýän zenan: goýy deri reňki',
    '🧘🏻‍♂' => 'lotus oturyşyndaky erkek: açyk deri reňki',
    '🧘🏼‍♂' => 'lotus oturyşyndaky erkek: orta açyk deri reňki',
    '🧘🏽‍♂' => 'lotus oturyşyndaky erkek: orta deri reňki',
    '🧘🏾‍♂' => 'lotus oturyşyndaky erkek: orta goýy deri reňki',
    '🧘🏿‍♂' => 'lotus oturyşyndaky erkek: goýy deri reňki',
    '🧘🏻‍♀' => 'lotus oturyşyndaky zenan: açyk deri reňki',
    '🧘🏼‍♀' => 'lotus oturyşyndaky zenan: orta açyk deri reňki',
    '🧘🏽‍♀' => 'lotus oturyşyndaky zenan: orta deri reňki',
    '🧘🏾‍♀' => 'lotus oturyşyndaky zenan: orta goýy deri reňki',
    '🧘🏿‍♀' => 'lotus oturyşyndaky zenan: goýy deri reňki',
    '🧑‍🦰' => 'şahs: gyzyl saç',
    '🧑‍🦱' => 'şahs: buýra saç',
    '🧑‍🦳' => 'şahs: ak saç',
    '🧑‍🦲' => 'şahs: kel',
    '👨‍🦰' => 'erkek: gyzyl saç',
    '👨‍🦱' => 'erkek: buýra saç',
    '👨‍🦳' => 'erkek: ak saç',
    '👨‍🦲' => 'erkek: kel',
    '👩‍🦰' => 'zenan: gyzyl saç',
    '👩‍🦱' => 'zenan: buýra saç',
    '👩‍🦳' => 'zenan: ak saç',
    '👩‍🦲' => 'zenan: kel',
    '🚶‍➡' => 'ýöräp barýan adam: ýüzi saga',
    '🧎‍➡' => 'dyza çöken adam: ýüzi saga',
    '🏃‍➡' => 'ylgap barýan adam: ýüzi saga',
    '👨‍👦' => 'maşgala: erkek, oglan',
    '👨‍👧' => 'maşgala: erkek, gyz',
    '👩‍👦' => 'maşgala: zenan, oglan',
    '👩‍👧' => 'maşgala: zenan, gyz',
    '😶‍🌫' => 'bulutlaryň içinde ýüz',
    '😮‍💨' => 'bugarýan ýüz',
    '🙂‍↕' => 'aşak-ýokaryk sallanýan kelle',
    '😵‍💫' => 'spiral gözli ýüz',
    '❤‍🔥' => 'ýanyp duran ýürek',
    '❤‍🩹' => 'gowulaşýan ýürek',
    '👁‍🗨' => 'gepleşik şarynyň içinde göz',
    '🧔‍♂' => 'adam: sakal',
    '👱‍♂' => 'erkek adam: sary saç',
    '🧔‍♀' => 'aýal: sakal',
    '👱‍♀' => 'zenan: sary saçly',
    '🙍‍♂' => 'çytylýan erkek',
    '🙍‍♀' => 'çytylýan zenan',
    '🙎‍♂' => 'gamaşyk erkek',
    '🙎‍♀' => 'gamaşyk zenan',
    '🙅‍♂' => 'ÝOK ümleýän erkek',
    '🙅‍♀' => 'ÝOK ümleýän zenan',
    '🙆‍♂' => 'Bolýar ümleýän erkek',
    '🙆‍♀' => 'Bolýar ümleýän zenan',
    '💁‍♂' => 'elini açan erkek',
    '💁‍♀' => 'elini açan zenan',
    '🙋‍♂' => 'elini galdyrýan erkek',
    '🙋‍♀' => 'elini galdyrýan zenan',
    '🧏‍♂' => 'ker erkek',
    '🧏‍♀' => 'ker zenan',
    '🙇‍♂' => 'tagzym edýän erkek',
    '🙇‍♀' => 'tagzym edýän zenan',
    '🤦‍♂' => 'elini maňlaýyna urýan erkek',
    '🤦‍♀' => 'elini maňlaýyna urýan zenan',
    '🤷‍♂' => 'egnini gysýan erkek',
    '🤷‍♀' => 'egnini gysýan zenan',
    '🧑‍⚕' => 'saglyk işgäri',
    '👨‍⚕' => 'erkek saglygy goraýyş işgäri',
    '👩‍⚕' => 'zenan saglygy goraýyş işgäri',
    '🧑‍🎓' => 'talyp',
    '👨‍🎓' => 'erkek talyp',
    '👩‍🎓' => 'zenan talyp',
    '🧑‍🏫' => 'mugallym',
    '👨‍🏫' => 'erkek mugallym',
    '👩‍🏫' => 'zenan mugallym',
    '🧑‍⚖' => 'kazy',
    '👨‍⚖' => 'erkek kazy',
    '👩‍⚖' => 'zenan kazy',
    '🧑‍🌾' => 'fermer',
    '👨‍🌾' => 'erkek daýhan',
    '👩‍🌾' => 'zenan daýhan',
    '🧑‍🍳' => 'aşpez',
    '👨‍🍳' => 'erkek aşpez',
    '👩‍🍳' => 'zenan aşpez',
    '🧑‍🔧' => 'mehanik',
    '👨‍🔧' => 'erkek mehanik',
    '👩‍🔧' => 'zenan mehanik',
    '🧑‍🏭' => 'fabrik işçisi',
    '👨‍🏭' => 'erkek zawod işçisi',
    '👩‍🏭' => 'zenan zawod işçisi',
    '🧑‍💼' => 'edara işçisi',
    '👨‍💼' => 'erkek ofis işgäri',
    '👩‍💼' => 'zenan ofis işgäri',
    '🧑‍🔬' => 'alym',
    '👨‍🔬' => 'erkek alym',
    '👩‍🔬' => 'zenan alym',
    '🧑‍💻' => 'tehnolog',
    '👨‍💻' => 'erkek tehnolog',
    '👩‍💻' => 'zenan tehnolog',
    '🧑‍🎤' => 'aýdymçy',
    '👨‍🎤' => 'erkek aýdymçy',
    '👩‍🎤' => 'zenan aýdymçy',
    '🧑‍🎨' => 'suratkeş',
    '👨‍🎨' => 'erkek suratkeş',
    '👩‍🎨' => 'zenan surarteş',
    '🧑‍✈' => 'uçarman',
    '👨‍✈' => 'erkek uçarman',
    '👩‍✈' => 'zenan uçarman',
    '🧑‍🚀' => 'kosmonawt',
    '👨‍🚀' => 'erkek kosmonawt',
    '👩‍🚀' => 'zenan kosmonawt',
    '🧑‍🚒' => 'ýangyn söndüriji işgär',
    '👨‍🚒' => 'erkek ýangyn söndüriji',
    '👩‍🚒' => 'zenan ýangyn söndüriji',
    '👮‍♂' => 'erkek polisiýa işgäri',
    '👮‍♀' => 'zenan polisiýa işgäri',
    '🕵‍♂' => 'erkek aňtawçy',
    '🕵‍♀' => 'zenan aňtawçy',
    '💂‍♂' => 'erkek sakçy',
    '💂‍♀' => 'zenan sakçy',
    '👷‍♂' => 'erkek gurluşyk işçisi',
    '👷‍♀' => 'zenan gurluşyk işçisi',
    '👳‍♂' => 'selleli erkek',
    '👳‍♀' => 'selleli zenan',
    '🤵‍♂' => 'smokingde erkek',
    '🤵‍♀' => 'aýal smokingde',
    '👰‍♂' => 'fataly erkek',
    '👰‍♀' => 'fataly aýal',
    '👩‍🍼' => 'bäbegi emdirýän aýal',
    '👨‍🍼' => 'bäbegi emdirýän erkek',
    '🧑‍🍼' => 'bäbegi emdirýän adam',
    '🧑‍🎄' => 'maks klaus',
    '🦸‍♂' => 'erkek supergahryman',
    '🦸‍♀' => 'zenan supergahryman',
    '🦹‍♂' => 'erkek superbetpäl',
    '🦹‍♀' => 'zenan superbetpäl',
    '🧙‍♂' => 'jadygöý erkek',
    '🧙‍♀' => 'jadygöý aýal',
    '🧚‍♂' => 'peri erkek',
    '🧚‍♀' => 'perizat',
    '🧛‍♂' => 'wampir erkek',
    '🧛‍♀' => 'wampir aýal',
    '🧜‍♂' => 'suw erkegi',
    '🧜‍♀' => 'suw gyzy',
    '🧝‍♂' => 'erkek elf',
    '🧝‍♀' => 'aýal elf',
    '🧞‍♂' => 'erkek jyn',
    '🧞‍♀' => 'aýal jyn',
    '🧟‍♂' => 'erkek zombi',
    '🧟‍♀' => 'aýal zombi',
    '💆‍♂' => 'massaž edilýän erkek',
    '💆‍♀' => 'massaž edilýän zenan',
    '💇‍♂' => 'saçy kiçeldilýän erkek',
    '💇‍♀' => 'saçy kiçeldilýän zenan',
    '🚶‍♂' => 'ýöräp barýan erkek',
    '🚶‍♀' => 'ýörap barýan zenan',
    '🧍‍♂' => 'dik duran erkek',
    '🧍‍♀' => 'dik duran zenan',
    '🧎‍♂' => 'dyza çöken erkek',
    '🧎‍♀' => 'dyza çöken zenan',
    '🧑‍🦯' => 'kör hasaly adam',
    '👨‍🦯' => 'kör hasaly erkek',
    '👩‍🦯' => 'kör hasaly zenan',
    '🧑‍🦼' => 'motorly arabajykdaky adam',
    '👨‍🦼' => 'motorly maýyp arabasynda erkek',
    '👩‍🦼' => 'motorly maýyp arabasynda zenan',
    '🧑‍🦽' => 'el bilen işleýän tigirçekli oturgyçdaky adam',
    '👨‍🦽' => 'el maýyp arabasynda erkek',
    '👩‍🦽' => 'el maýyp arabasynda zenan',
    '🏃‍♂' => 'ylgap barýan erkek',
    '🏃‍♀' => 'ylgap barýan zenan',
    '🧑‍🩰' => 'balerina',
    '👯‍♂' => 'towşan gulakly erkekler',
    '👯‍♀' => 'towşan gulakly zenanlar',
    '🧖‍♂' => 'bug otagyndaky erkek',
    '🧖‍♀' => 'bug otagyndaky aýal',
    '🧗‍♂' => 'dyrmaşýan erkek',
    '🧗‍♀' => 'dyrmaşýan zenan',
    '🏌‍♂' => 'golf oýnaýan erkek',
    '🏌‍♀' => 'golf oýnaýan zenan',
    '🏄‍♂' => 'sörf edýän erkek',
    '🏄‍♀' => 'sörf edýän zenan',
    '🚣‍♂' => 'gaýyk kürekleýän erkek',
    '🚣‍♀' => 'gaýyk kürekleýän zenan',
    '🏊‍♂' => 'ýüzüp ýören erkek',
    '🏊‍♀' => 'ýüzüp ýören zenan',
    '⛹‍♂' => 'topy bökdürýän erkek',
    '⛹‍♀' => 'topy bökdürýän zenan',
    '🏋‍♂' => 'agyrlyk göterýän erkek',
    '🏋‍♀' => 'agyrlyk göterýän zenan',
    '🚴‍♂' => 'tigir sürýän erkek',
    '🚴‍♀' => 'tigir sürýän zenan',
    '🚵‍♂' => 'dagda tigir sürýän erkek',
    '🚵‍♀' => 'dagda tigir sürýän zenan',
    '🤸‍♂' => 'ýanyn aşyr atýan erkek',
    '🤸‍♀' => 'ýanyn aşyr atýan zenan',
    '🤼‍♂' => 'göreş tutýan erkekler',
    '🤼‍♀' => 'göreş tutýan zenanlar',
    '🤽‍♂' => 'suw polo oýnaýan erkek',
    '🤽‍♀' => 'suw polo oýnaýan zenan',
    '🤾‍♂' => 'gandbol oýnaýan erkek',
    '🤾‍♀' => 'gandbol oýnaýan aýal',
    '🤹‍♂' => 'hokgabazlyk edýän erkek',
    '🤹‍♀' => 'hokgabazlyk edýän zenan',
    '🧘‍♂' => 'lotus oturyşyndaky erkek',
    '🧘‍♀' => 'lotus oturyşyndaky zenan',
    '🧑‍🧒' => 'maşgala: uly, çaga',
    '🐕‍🦺' => 'gulluk iti',
    '🐈‍⬛' => 'Gara pişik',
    '🐻‍❄' => 'polýar aýy',
    '🐦‍⬛' => 'gara guş',
    '🐦‍🔥' => 'kaknus',
    '🍋‍🟩' => 'laým',
    '🍄‍🟫' => 'mele kömelek',
    '⛓‍💥' => 'döwük zynjyr',
    '🏳‍🌈' => 'älemgoşar baýdak',
    '🏳‍⚧' => 'transseksual baýdagy',
    '🏴‍☠' => 'garakçy baýdagy',
    '👋🏻' => 'galgaýan el: açyk deri reňki',
    '👋🏼' => 'galgaýan el: orta açyk deri reňki',
    '👋🏽' => 'galgaýan el: orta deri reňki',
    '👋🏾' => 'galgaýan el: orta goýy deri reňki',
    '👋🏿' => 'galgaýan el: goýy deri reňki',
    '🤚🏻' => 'galdyrylan el arkasy: açyk deri reňki',
    '🤚🏼' => 'galdyrylan el arkasy: orta açyk deri reňki',
    '🤚🏽' => 'galdyrylan el arkasy: orta deri reňki',
    '🤚🏾' => 'galdyrylan el arkasy: orta goýy deri reňki',
    '🤚🏿' => 'galdyrylan el arkasy: goýy deri reňki',
    '🖐🏻' => 'barmaklaryň arasy açylan el: açyk deri reňki',
    '🖐🏼' => 'barmaklaryň arasy açylan el: orta açyk deri reňki',
    '🖐🏽' => 'barmaklaryň arasy açylan el: orta deri reňki',
    '🖐🏾' => 'barmaklaryň arasy açylan el: orta goýy deri reňki',
    '🖐🏿' => 'barmaklaryň arasy açylan el: goýy deri reňki',
    '✋🏻' => 'galdyrylan el: açyk deri reňki',
    '✋🏼' => 'galdyrylan el: orta açyk deri reňki',
    '✋🏽' => 'galdyrylan el: orta deri reňki',
    '✋🏾' => 'galdyrylan el: orta goýy deri reňki',
    '✋🏿' => 'galdyrylan el: goýy deri reňki',
    '🖖🏻' => 'wulkan salam: açyk deri reňki',
    '🖖🏼' => 'wulkan salam: orta açyk deri reňki',
    '🖖🏽' => 'wulkan salam: orta deri reňki',
    '🖖🏾' => 'wulkan salam: orta goýy deri reňki',
    '🖖🏿' => 'wulkan salam: goýy deri reňki',
    '🫱🏻' => 'saga el: açyk deri reňki',
    '🫱🏼' => 'saga el: orta açyk deri reňki',
    '🫱🏽' => 'saga el: orta deri reňki',
    '🫱🏾' => 'saga el: orta goýy deri reňki',
    '🫱🏿' => 'saga el: goýy deri reňki',
    '🫲🏻' => 'çepe el: açyk deri reňki',
    '🫲🏼' => 'çepe el: orta açyk deri reňki',
    '🫲🏽' => 'çepe el: orta deri reňki',
    '🫲🏾' => 'çepe el: orta goýy deri reňki',
    '🫲🏿' => 'çepe el: goýy deri reňki',
    '🫳🏻' => 'aýasy aşak seredýän el: açyk deri reňki',
    '🫳🏼' => 'aýasy aşak seredýän el: orta açyk deri reňki',
    '🫳🏽' => 'aýasy aşak seredýän el: orta deri reňki',
    '🫳🏾' => 'aýasy aşak seredýän el: orta goýy deri reňki',
    '🫳🏿' => 'aýasy aşak seredýän el: goýy deri reňki',
    '🫴🏻' => 'aýasy ýokaryk seredýän el: açyk deri reňki',
    '🫴🏼' => 'aýasy ýokaryk seredýän el: orta açyk deri reňki',
    '🫴🏽' => 'aýasy ýokaryk seredýän el: orta deri reňki',
    '🫴🏾' => 'aýasy ýokaryk seredýän el: orta goýy deri reňki',
    '🫴🏿' => 'aýasy ýokaryk seredýän el: goýy deri reňki',
    '🫷🏻' => 'çepe itýän el: açyk deri reňki',
    '🫷🏼' => 'çepe itýän el: orta açyk deri reňki',
    '🫷🏽' => 'çepe itýän el: orta deri reňki',
    '🫷🏾' => 'çepe itýän el: orta goýy deri reňki',
    '🫷🏿' => 'çepe itýän el: goýy deri reňki',
    '🫸🏻' => 'saga itýän el: açyk deri reňki',
    '🫸🏼' => 'saga itýän el: orta açyk deri reňki',
    '🫸🏽' => 'saga itýän el: orta deri reňki',
    '🫸🏾' => 'saga itýän el: orta goýy deri reňki',
    '🫸🏿' => 'saga itýän el: goýy deri reňki',
    '👌🏻' => 'OK eli: açyk deri reňki',
    '👌🏼' => 'OK eli: orta açyk deri reňki',
    '👌🏽' => 'OK eli: orta deri reňki',
    '👌🏾' => 'OK eli: orta goýy deri reňki',
    '👌🏿' => 'OK eli: goýy deri reňki',
    '🤌🏻' => 'gysylan barmaklar: açyk deri reňki',
    '🤌🏼' => 'gysylan barmaklar: orta açyk deri reňki',
    '🤌🏽' => 'gysylan barmaklar: orta deri reňki',
    '🤌🏾' => 'gysylan barmaklar: orta goýy deri reňki',
    '🤌🏿' => 'gysylan barmaklar: goýy deri reňki',
    '🤏🏻' => 'çümmükleýän el: açyk deri reňki',
    '🤏🏼' => 'çümmükleýän el: orta açyk deri reňki',
    '🤏🏽' => 'çümmükleýän el: orta deri reňki',
    '🤏🏾' => 'çümmükleýän el: orta goýy deri reňki',
    '🤏🏿' => 'çümmükleýän el: goýy deri reňki',
    '✌🏻' => 'ýeňiş alamatyny görkezýän el: açyk deri reňki',
    '✌🏼' => 'ýeňiş alamatyny görkezýän el: orta açyk deri reňki',
    '✌🏽' => 'ýeňiş alamatyny görkezýän el: orta deri reňki',
    '✌🏾' => 'ýeňiş alamatyny görkezýän el: orta goýy deri reňki',
    '✌🏿' => 'ýeňiş alamatyny görkezýän el: goýy deri reňki',
    '🤞🏻' => 'atanak edilen barmak: açyk deri reňki',
    '🤞🏼' => 'atanak edilen barmak: orta açyk deri reňki',
    '🤞🏽' => 'atanak edilen barmak: orta deri reňki',
    '🤞🏾' => 'atanak edilen barmak: orta goýy deri reňki',
    '🤞🏿' => 'atanak edilen barmak: goýy deri reňki',
    '🫰🏻' => 'süýem we başam barmagy çapraz el: açyk deri reňki',
    '🫰🏼' => 'süýem we başam barmagy çapraz el: orta açyk deri reňki',
    '🫰🏽' => 'süýem we başam barmagy çapraz el: orta deri reňki',
    '🫰🏾' => 'süýem we başam barmagy çapraz el: orta goýy deri reňki',
    '🫰🏿' => 'süýem we başam barmagy çapraz el: goýy deri reňki',
    '🤟🏻' => 'seni söýýän ümi: açyk deri reňki',
    '🤟🏼' => 'seni söýýän ümi: orta açyk deri reňki',
    '🤟🏽' => 'seni söýýän ümi: orta deri reňki',
    '🤟🏾' => 'seni söýýän ümi: orta goýy deri reňki',
    '🤟🏿' => 'seni söýýän ümi: goýy deri reňki',
    '🤘🏻' => 'şah belgisi: açyk deri reňki',
    '🤘🏼' => 'şah belgisi: orta açyk deri reňki',
    '🤘🏽' => 'şah belgisi: orta deri reňki',
    '🤘🏾' => 'şah belgisi: orta goýy deri reňki',
    '🤘🏿' => 'şah belgisi: goýy deri reňki',
    '🤙🏻' => 'jaňlaş eli: açyk deri reňki',
    '🤙🏼' => 'jaňlaş eli: orta açyk deri reňki',
    '🤙🏽' => 'jaňlaş eli: orta deri reňki',
    '🤙🏾' => 'jaňlaş eli: orta goýy deri reňki',
    '🤙🏿' => 'jaňlaş eli: goýy deri reňki',
    '👈🏻' => 'çepi görkezýän el-arkasy süýem barmak: açyk deri reňki',
    '👈🏼' => 'çepi görkezýän el-arkasy süýem barmak: orta açyk deri reňki',
    '👈🏽' => 'çepi görkezýän el-arkasy süýem barmak: orta deri reňki',
    '👈🏾' => 'çepi görkezýän el-arkasy süýem barmak: orta goýy deri reňki',
    '👈🏿' => 'çepi görkezýän el-arkasy süýem barmak: goýy deri reňki',
    '👉🏻' => 'sagy görkezýän el-arkasy süýem barmak: açyk deri reňki',
    '👉🏼' => 'sagy görkezýän el-arkasy süýem barmak: orta açyk deri reňki',
    '👉🏽' => 'sagy görkezýän el-arkasy süýem barmak: orta deri reňki',
    '👉🏾' => 'sagy görkezýän el-arkasy süýem barmak: orta goýy deri reňki',
    '👉🏿' => 'sagy görkezýän el-arkasy süýem barmak: goýy deri reňki',
    '👆🏻' => 'el-arkasy süýem barmak ýokaryk: açyk deri reňki',
    '👆🏼' => 'el-arkasy süýem barmak ýokaryk: orta açyk deri reňki',
    '👆🏽' => 'el-arkasy süýem barmak ýokaryk: orta deri reňki',
    '👆🏾' => 'el-arkasy süýem barmak ýokaryk: orta goýy deri reňki',
    '👆🏿' => 'el-arkasy süýem barmak ýokaryk: goýy deri reňki',
    '🖕🏻' => 'orta barmak: açyk deri reňki',
    '🖕🏼' => 'orta barmak: orta açyk deri reňki',
    '🖕🏽' => 'orta barmak: orta deri reňki',
    '🖕🏾' => 'orta barmak: orta goýy deri reňki',
    '🖕🏿' => 'orta barmak: goýy deri reňki',
    '👇🏻' => 'aşagy görkezýän el-arkasy süýem barmak: açyk deri reňki',
    '👇🏼' => 'aşagy görkezýän el-arkasy süýem barmak: orta açyk deri reňki',
    '👇🏽' => 'aşagy görkezýän el-arkasy süýem barmak: orta deri reňki',
    '👇🏾' => 'aşagy görkezýän el-arkasy süýem barmak: orta goýy deri reňki',
    '👇🏿' => 'aşagy görkezýän el-arkasy süýem barmak: goýy deri reňki',
    '☝🏻' => 'ýokaryny görkezýän süýem barmak: açyk deri reňki',
    '☝🏼' => 'ýokaryny görkezýän süýem barmak: orta açyk deri reňki',
    '☝🏽' => 'ýokaryny görkezýän süýem barmak: orta deri reňki',
    '☝🏾' => 'ýokaryny görkezýän süýem barmak: orta goýy deri reňki',
    '☝🏿' => 'ýokaryny görkezýän süýem barmak: goýy deri reňki',
    '🫵🏻' => 'tomaşaça gönükdirilen süýem barmak: açyk deri reňki',
    '🫵🏼' => 'tomaşaça gönükdirilen süýem barmak: orta açyk deri reňki',
    '🫵🏽' => 'tomaşaça gönükdirilen süýem barmak: orta deri reňki',
    '🫵🏾' => 'tomaşaça gönükdirilen süýem barmak: orta goýy deri reňki',
    '🫵🏿' => 'tomaşaça gönükdirilen süýem barmak: goýy deri reňki',
    '👍🏻' => 'başam barmak ýokary: açyk deri reňki',
    '👍🏼' => 'başam barmak ýokary: orta açyk deri reňki',
    '👍🏽' => 'başam barmak ýokary: orta deri reňki',
    '👍🏾' => 'başam barmak ýokary: orta goýy deri reňki',
    '👍🏿' => 'başam barmak ýokary: goýy deri reňki',
    '👎🏻' => 'başam barmak aşak: açyk deri reňki',
    '👎🏼' => 'başam barmak aşak: orta açyk deri reňki',
    '👎🏽' => 'başam barmak aşak: orta deri reňki',
    '👎🏾' => 'başam barmak aşak: orta goýy deri reňki',
    '👎🏿' => 'başam barmak aşak: goýy deri reňki',
    '✊🏻' => 'galdyrylan ýumruk: açyk deri reňki',
    '✊🏼' => 'galdyrylan ýumruk: orta açyk deri reňki',
    '✊🏽' => 'galdyrylan ýumruk: orta deri reňki',
    '✊🏾' => 'galdyrylan ýumruk: orta goýy deri reňki',
    '✊🏿' => 'galdyrylan ýumruk: goýy deri reňki',
    '👊🏻' => 'gelýän ýumruk: açyk deri reňki',
    '👊🏼' => 'gelýän ýumruk: orta açyk deri reňki',
    '👊🏽' => 'gelýän ýumruk: orta deri reňki',
    '👊🏾' => 'gelýän ýumruk: orta goýy deri reňki',
    '👊🏿' => 'gelýän ýumruk: goýy deri reňki',
    '🤛🏻' => 'çepe ýumruk: açyk deri reňki',
    '🤛🏼' => 'çepe ýumruk: orta açyk deri reňki',
    '🤛🏽' => 'çepe ýumruk: orta deri reňki',
    '🤛🏾' => 'çepe ýumruk: orta goýy deri reňki',
    '🤛🏿' => 'çepe ýumruk: goýy deri reňki',
    '🤜🏻' => 'saga ýumruk: açyk deri reňki',
    '🤜🏼' => 'saga ýumruk: orta açyk deri reňki',
    '🤜🏽' => 'saga ýumruk: orta deri reňki',
    '🤜🏾' => 'saga ýumruk: orta goýy deri reňki',
    '🤜🏿' => 'saga ýumruk: goýy deri reňki',
    '👏🏻' => 'çapak çalýan eller: açyk deri reňki',
    '👏🏼' => 'çapak çalýan eller: orta açyk deri reňki',
    '👏🏽' => 'çapak çalýan eller: orta deri reňki',
    '👏🏾' => 'çapak çalýan eller: orta goýy deri reňki',
    '👏🏿' => 'çapak çalýan eller: goýy deri reňki',
    '🙌🏻' => 'elleri galdyrmak: açyk deri reňki',
    '🙌🏼' => 'elleri galdyrmak: orta açyk deri reňki',
    '🙌🏽' => 'elleri galdyrmak: orta deri reňki',
    '🙌🏾' => 'elleri galdyrmak: orta goýy deri reňki',
    '🙌🏿' => 'elleri galdyrmak: goýy deri reňki',
    '🫶🏻' => 'ýürek ýasaýan eller: açyk deri reňki',
    '🫶🏼' => 'ýürek ýasaýan eller: orta açyk deri reňki',
    '🫶🏽' => 'ýürek ýasaýan eller: orta deri reňki',
    '🫶🏾' => 'ýürek ýasaýan eller: orta goýy deri reňki',
    '🫶🏿' => 'ýürek ýasaýan eller: goýy deri reňki',
    '👐🏻' => 'açyk eller: açyk deri reňki',
    '👐🏼' => 'açyk eller: orta açyk deri reňki',
    '👐🏽' => 'açyk eller: orta deri reňki',
    '👐🏾' => 'açyk eller: orta goýy deri reňki',
    '👐🏿' => 'açyk eller: goýy deri reňki',
    '🤲🏻' => 'aýalary birleşdirip ýokary galdyrmak: açyk deri reňki',
    '🤲🏼' => 'aýalary birleşdirip ýokary galdyrmak: orta açyk deri reňki',
    '🤲🏽' => 'aýalary birleşdirip ýokary galdyrmak: orta deri reňki',
    '🤲🏾' => 'aýalary birleşdirip ýokary galdyrmak: orta goýy deri reňki',
    '🤲🏿' => 'aýalary birleşdirip ýokary galdyrmak: goýy deri reňki',
    '🤝🏻' => 'el gysyşmak: açyk deri reňki',
    '🤝🏼' => 'el gysyşmak: orta açyk deri reňki',
    '🤝🏽' => 'el gysyşmak: orta deri reňki',
    '🤝🏾' => 'el gysyşmak: orta goýy deri reňki',
    '🤝🏿' => 'el gysyşmak: goýy deri reňki',
    '🙏🏻' => 'birleşen eller: açyk deri reňki',
    '🙏🏼' => 'birleşen eller: orta açyk deri reňki',
    '🙏🏽' => 'birleşen eller: orta deri reňki',
    '🙏🏾' => 'birleşen eller: orta goýy deri reňki',
    '🙏🏿' => 'birleşen eller: goýy deri reňki',
    '✍🏻' => 'ýazýan el: açyk deri reňki',
    '✍🏼' => 'ýazýan el: orta açyk deri reňki',
    '✍🏽' => 'ýazýan el: orta deri reňki',
    '✍🏾' => 'ýazýan el: orta goýy deri reňki',
    '✍🏿' => 'ýazýan el: goýy deri reňki',
    '💅🏻' => 'dyrnak lagy: açyk deri reňki',
    '💅🏼' => 'dyrnak lagy: orta açyk deri reňki',
    '💅🏽' => 'dyrnak lagy: orta deri reňki',
    '💅🏾' => 'dyrnak lagy: orta goýy deri reňki',
    '💅🏿' => 'dyrnak lagy: goýy deri reňki',
    '🤳🏻' => 'selfi: açyk deri reňki',
    '🤳🏼' => 'selfi: orta açyk deri reňki',
    '🤳🏽' => 'selfi: orta deri reňki',
    '🤳🏾' => 'selfi: orta goýy deri reňki',
    '🤳🏿' => 'selfi: goýy deri reňki',
    '💪🏻' => 'bükülen tirsek: açyk deri reňki',
    '💪🏼' => 'bükülen tirsek: orta açyk deri reňki',
    '💪🏽' => 'bükülen tirsek: orta deri reňki',
    '💪🏾' => 'bükülen tirsek: orta goýy deri reňki',
    '💪🏿' => 'bükülen tirsek: goýy deri reňki',
    '🦵🏻' => 'aýak: açyk deri reňki',
    '🦵🏼' => 'aýak: orta açyk deri reňki',
    '🦵🏽' => 'aýak: orta deri reňki',
    '🦵🏾' => 'aýak: orta goýy deri reňki',
    '🦵🏿' => 'aýak: goýy deri reňki',
    '🦶🏻' => 'daban: açyk deri reňki',
    '🦶🏼' => 'daban: orta açyk deri reňki',
    '🦶🏽' => 'daban: orta deri reňki',
    '🦶🏾' => 'daban: orta goýy deri reňki',
    '🦶🏿' => 'daban: goýy deri reňki',
    '👂🏻' => 'gulak: açyk deri reňki',
    '👂🏼' => 'gulak: orta açyk deri reňki',
    '👂🏽' => 'gulak: orta deri reňki',
    '👂🏾' => 'gulak: orta goýy deri reňki',
    '👂🏿' => 'gulak: goýy deri reňki',
    '🦻🏻' => 'eşidiş enjamly gulak: açyk deri reňki',
    '🦻🏼' => 'eşidiş enjamly gulak: orta açyk deri reňki',
    '🦻🏽' => 'eşidiş enjamly gulak: orta deri reňki',
    '🦻🏾' => 'eşidiş enjamly gulak: orta goýy deri reňki',
    '🦻🏿' => 'eşidiş enjamly gulak: goýy deri reňki',
    '👃🏻' => 'burun: açyk deri reňki',
    '👃🏼' => 'burun: orta açyk deri reňki',
    '👃🏽' => 'burun: orta deri reňki',
    '👃🏾' => 'burun: orta goýy deri reňki',
    '👃🏿' => 'burun: goýy deri reňki',
    '👶🏻' => 'bäbek: açyk deri reňki',
    '👶🏼' => 'bäbek: orta açyk deri reňki',
    '👶🏽' => 'bäbek: orta deri reňki',
    '👶🏾' => 'bäbek: orta goýy deri reňki',
    '👶🏿' => 'bäbek: goýy deri reňki',
    '🧒🏻' => 'çaga: açyk deri reňki',
    '🧒🏼' => 'çaga: orta açyk deri reňki',
    '🧒🏽' => 'çaga: orta deri reňki',
    '🧒🏾' => 'çaga: orta goýy deri reňki',
    '🧒🏿' => 'çaga: goýy deri reňki',
    '👦🏻' => 'oglan: açyk deri reňki',
    '👦🏼' => 'oglan: orta açyk deri reňki',
    '👦🏽' => 'oglan: orta deri reňki',
    '👦🏾' => 'oglan: orta goýy deri reňki',
    '👦🏿' => 'oglan: goýy deri reňki',
    '👧🏻' => 'gyz: açyk deri reňki',
    '👧🏼' => 'gyz: orta açyk deri reňki',
    '👧🏽' => 'gyz: orta deri reňki',
    '👧🏾' => 'gyz: orta goýy deri reňki',
    '👧🏿' => 'gyz: goýy deri reňki',
    '🧑🏻' => 'şahs: açyk deri reňki',
    '🧑🏼' => 'şahs: orta açyk deri reňki',
    '🧑🏽' => 'şahs: orta deri reňki',
    '🧑🏾' => 'şahs: orta goýy deri reňki',
    '🧑🏿' => 'şahs: goýy deri reňki',
    '👱🏻' => 'adam: açyk deri reňki, sary saçly',
    '👱🏼' => 'adam: orta açyk deri reňki, sary saçly',
    '👱🏽' => 'adam: orta deri reňki, sary saçly',
    '👱🏾' => 'adam: orta goýy deri reňki, sary saçly',
    '👱🏿' => 'adam: goýy deri reňki, sary saçly',
    '👨🏻' => 'erkek: açyk deri reňki',
    '👨🏼' => 'erkek: orta açyk deri reňki',
    '👨🏽' => 'erkek: orta deri reňki',
    '👨🏾' => 'erkek: orta goýy deri reňki',
    '👨🏿' => 'erkek: goýy deri reňki',
    '🧔🏻' => 'kişi: açyk deri reňki, sakal',
    '🧔🏼' => 'kişi: orta açyk deri reňki, sakal',
    '🧔🏽' => 'kişi: orta deri reňki, sakal',
    '🧔🏾' => 'kişi: orta goýy deri reňki, sakal',
    '🧔🏿' => 'kişi: goýy deri reňki, sakal',
    '👩🏻' => 'zenan: açyk deri reňki',
    '👩🏼' => 'zenan: orta açyk deri reňki',
    '👩🏽' => 'zenan: orta deri reňki',
    '👩🏾' => 'zenan: orta goýy deri reňki',
    '👩🏿' => 'zenan: goýy deri reňki',
    '🧓🏻' => 'gartaşan kişi: açyk deri reňki',
    '🧓🏼' => 'gartaşan kişi: orta açyk deri reňki',
    '🧓🏽' => 'gartaşan kişi: orta deri reňki',
    '🧓🏾' => 'gartaşan kişi: orta goýy deri reňki',
    '🧓🏿' => 'gartaşan kişi: goýy deri reňki',
    '👴🏻' => 'goja: açyk deri reňki',
    '👴🏼' => 'goja: orta açyk deri reňki',
    '👴🏽' => 'goja: orta deri reňki',
    '👴🏾' => 'goja: orta goýy deri reňki',
    '👴🏿' => 'goja: goýy deri reňki',
    '👵🏻' => 'garry aýal: açyk deri reňki',
    '👵🏼' => 'garry aýal: orta açyk deri reňki',
    '👵🏽' => 'garry aýal: orta deri reňki',
    '👵🏾' => 'garry aýal: orta goýy deri reňki',
    '👵🏿' => 'garry aýal: goýy deri reňki',
    '🙍🏻' => 'çytyk adam: açyk deri reňki',
    '🙍🏼' => 'çytyk adam: orta açyk deri reňki',
    '🙍🏽' => 'çytyk adam: orta deri reňki',
    '🙍🏾' => 'çytyk adam: orta goýy deri reňki',
    '🙍🏿' => 'çytyk adam: goýy deri reňki',
    '🙎🏻' => 'gamaşyk adam: açyk deri reňki',
    '🙎🏼' => 'gamaşyk adam: orta açyk deri reňki',
    '🙎🏽' => 'gamaşyk adam: orta deri reňki',
    '🙎🏾' => 'gamaşyk adam: orta goýy deri reňki',
    '🙎🏿' => 'gamaşyk adam: goýy deri reňki',
    '🙅🏻' => 'ÝOK ümleýän adam: açyk deri reňki',
    '🙅🏼' => 'ÝOK ümleýän adam: orta açyk deri reňki',
    '🙅🏽' => 'ÝOK ümleýän adam: orta deri reňki',
    '🙅🏾' => 'ÝOK ümleýän adam: orta goýy deri reňki',
    '🙅🏿' => 'ÝOK ümleýän adam: goýy deri reňki',
    '🙆🏻' => 'Bolýar ümleýän adam: açyk deri reňki',
    '🙆🏼' => 'Bolýar ümleýän adam: orta açyk deri reňki',
    '🙆🏽' => 'Bolýar ümleýän adam: orta deri reňki',
    '🙆🏾' => 'Bolýar ümleýän adam: orta goýy deri reňki',
    '🙆🏿' => 'Bolýar ümleýän adam: goýy deri reňki',
    '💁🏻' => 'elini açan adam: açyk deri reňki',
    '💁🏼' => 'elini açan adam: orta açyk deri reňki',
    '💁🏽' => 'elini açan adam: orta deri reňki',
    '💁🏾' => 'elini açan adam: orta goýy deri reňki',
    '💁🏿' => 'elini açan adam: goýy deri reňki',
    '🙋🏻' => 'elini galdyrýan adam: açyk deri reňki',
    '🙋🏼' => 'elini galdyrýan adam: orta açyk deri reňki',
    '🙋🏽' => 'elini galdyrýan adam: orta deri reňki',
    '🙋🏾' => 'elini galdyrýan adam: orta goýy deri reňki',
    '🙋🏿' => 'elini galdyrýan adam: goýy deri reňki',
    '🧏🏻' => 'ker adam: açyk deri reňki',
    '🧏🏼' => 'ker adam: orta açyk deri reňki',
    '🧏🏽' => 'ker adam: orta deri reňki',
    '🧏🏾' => 'ker adam: orta goýy deri reňki',
    '🧏🏿' => 'ker adam: goýy deri reňki',
    '🙇🏻' => 'tagzym edýän adam: açyk deri reňki',
    '🙇🏼' => 'tagzym edýän adam: orta açyk deri reňki',
    '🙇🏽' => 'tagzym edýän adam: orta deri reňki',
    '🙇🏾' => 'tagzym edýän adam: orta goýy deri reňki',
    '🙇🏿' => 'tagzym edýän adam: goýy deri reňki',
    '🤦🏻' => 'elini maňlaýyna urýan adam: açyk deri reňki',
    '🤦🏼' => 'elini maňlaýyna urýan adam: orta açyk deri reňki',
    '🤦🏽' => 'elini maňlaýyna urýan adam: orta deri reňki',
    '🤦🏾' => 'elini maňlaýyna urýan adam: orta goýy deri reňki',
    '🤦🏿' => 'elini maňlaýyna urýan adam: goýy deri reňki',
    '🤷🏻' => 'egnini gysýan adam: açyk deri reňki',
    '🤷🏼' => 'egnini gysýan adam: orta açyk deri reňki',
    '🤷🏽' => 'egnini gysýan adam: orta deri reňki',
    '🤷🏾' => 'egnini gysýan adam: orta goýy deri reňki',
    '🤷🏿' => 'egnini gysýan adam: goýy deri reňki',
    '👮🏻' => 'polisiýa işgäri: açyk deri reňki',
    '👮🏼' => 'polisiýa işgäri: orta açyk deri reňki',
    '👮🏽' => 'polisiýa işgäri: orta deri reňki',
    '👮🏾' => 'polisiýa işgäri: orta goýy deri reňki',
    '👮🏿' => 'polisiýa işgäri: goýy deri reňki',
    '🕵🏻' => 'aňtawçy: açyk deri reňki',
    '🕵🏼' => 'aňtawçy: orta açyk deri reňki',
    '🕵🏽' => 'aňtawçy: orta deri reňki',
    '🕵🏾' => 'aňtawçy: orta goýy deri reňki',
    '🕵🏿' => 'aňtawçy: goýy deri reňki',
    '💂🏻' => 'sakçy: açyk deri reňki',
    '💂🏼' => 'sakçy: orta açyk deri reňki',
    '💂🏽' => 'sakçy: orta deri reňki',
    '💂🏾' => 'sakçy: orta goýy deri reňki',
    '💂🏿' => 'sakçy: goýy deri reňki',
    '🥷🏻' => 'nindzýa: açyk deri reňki',
    '🥷🏼' => 'nindzýa: orta açyk deri reňki',
    '🥷🏽' => 'nindzýa: orta deri reňki',
    '🥷🏾' => 'nindzýa: orta goýy deri reňki',
    '🥷🏿' => 'nindzýa: goýy deri reňki',
    '👷🏻' => 'gurluşyk işçisi: açyk deri reňki',
    '👷🏼' => 'gurluşyk işçisi: orta açyk deri reňki',
    '👷🏽' => 'gurluşyk işçisi: orta deri reňki',
    '👷🏾' => 'gurluşyk işçisi: orta goýy deri reňki',
    '👷🏿' => 'gurluşyk işçisi: goýy deri reňki',
    '🫅🏻' => 'täçli şahs: açyk deri reňki',
    '🫅🏼' => 'täçli şahs: orta açyk deri reňki',
    '🫅🏽' => 'täçli şahs: orta deri reňki',
    '🫅🏾' => 'täçli şahs: orta goýy deri reňki',
    '🫅🏿' => 'täçli şahs: goýy deri reňki',
    '🤴🏻' => 'şazada: açyk deri reňki',
    '🤴🏼' => 'şazada: orta açyk deri reňki',
    '🤴🏽' => 'şazada: orta deri reňki',
    '🤴🏾' => 'şazada: orta goýy deri reňki',
    '🤴🏿' => 'şazada: goýy deri reňki',
    '👸🏻' => 'şa gyzy: açyk deri reňki',
    '👸🏼' => 'şa gyzy: orta açyk deri reňki',
    '👸🏽' => 'şa gyzy: orta deri reňki',
    '👸🏾' => 'şa gyzy: orta goýy deri reňki',
    '👸🏿' => 'şa gyzy: goýy deri reňki',
    '👳🏻' => 'selleli adam: açyk deri reňki',
    '👳🏼' => 'selleli adam: orta açyk deri reňki',
    '👳🏽' => 'selleli adam: orta deri reňki',
    '👳🏾' => 'selleli adam: orta goýy deri reňki',
    '👳🏿' => 'selleli adam: goýy deri reňki',
    '👲🏻' => 'Hytaý şyrdakly kişi: açyk deri reňki',
    '👲🏼' => 'Hytaý şyrdakly kişi: orta açyk deri reňki',
    '👲🏽' => 'Hytaý şyrdakly kişi: orta deri reňki',
    '👲🏾' => 'Hytaý şyrdakly kişi: orta goýy deri reňki',
    '👲🏿' => 'Hytaý şyrdakly kişi: goýy deri reňki',
    '🧕🏻' => 'ýaglykly aýal: açyk deri reňki',
    '🧕🏼' => 'ýaglykly aýal: orta açyk deri reňki',
    '🧕🏽' => 'ýaglykly aýal: orta deri reňki',
    '🧕🏾' => 'ýaglykly aýal: orta goýy deri reňki',
    '🧕🏿' => 'ýaglykly aýal: goýy deri reňki',
    '🤵🏻' => 'smokingli kişi: açyk deri reňki',
    '🤵🏼' => 'smokingli kişi: orta açyk deri reňki',
    '🤵🏽' => 'smokingli kişi: orta deri reňki',
    '🤵🏾' => 'smokingli kişi: orta goýy deri reňki',
    '🤵🏿' => 'smokingli kişi: goýy deri reňki',
    '👰🏻' => 'nykaply kişi: açyk deri reňki',
    '👰🏼' => 'nykaply kişi: orta açyk deri reňki',
    '👰🏽' => 'nykaply kişi: orta deri reňki',
    '👰🏾' => 'nykaply kişi: orta goýy deri reňki',
    '👰🏿' => 'nykaply kişi: goýy deri reňki',
    '🤰🏻' => 'göwreli aýal: açyk deri reňki',
    '🤰🏼' => 'göwreli aýal: orta açyk deri reňki',
    '🤰🏽' => 'göwreli aýal: orta deri reňki',
    '🤰🏾' => 'göwreli aýal: orta goýy deri reňki',
    '🤰🏿' => 'göwreli aýal: goýy deri reňki',
    '🫃🏻' => 'göwreli adam: açyk deri reňki',
    '🫃🏼' => 'göwreli adam: orta açyk deri reňki',
    '🫃🏽' => 'göwreli adam: orta deri reňki',
    '🫃🏾' => 'göwreli adam: orta goýy deri reňki',
    '🫃🏿' => 'göwreli adam: goýy deri reňki',
    '🫄🏻' => 'göwreli şahs: açyk deri reňki',
    '🫄🏼' => 'göwreli şahs: orta açyk deri reňki',
    '🫄🏽' => 'göwreli şahs: orta deri reňki',
    '🫄🏾' => 'göwreli şahs: orta goýy deri reňki',
    '🫄🏿' => 'göwreli şahs: goýy deri reňki',
    '🤱🏻' => 'emdirmek: açyk deri reňki',
    '🤱🏼' => 'emdirmek: orta açyk deri reňki',
    '🤱🏽' => 'emdirmek: orta deri reňki',
    '🤱🏾' => 'emdirmek: orta goýy deri reňki',
    '🤱🏿' => 'emdirmek: goýy deri reňki',
    '👼🏻' => 'bäbek perişde: açyk deri reňki',
    '👼🏼' => 'bäbek perişde: orta açyk deri reňki',
    '👼🏽' => 'bäbek perişde: orta deri reňki',
    '👼🏾' => 'bäbek perişde: orta goýy deri reňki',
    '👼🏿' => 'bäbek perişde: goýy deri reňki',
    '🎅🏻' => 'Aýaz baba: açyk deri reňki',
    '🎅🏼' => 'Aýaz baba: orta açyk deri reňki',
    '🎅🏽' => 'Aýaz baba: orta deri reňki',
    '🎅🏾' => 'Aýaz baba: orta goýy deri reňki',
    '🎅🏿' => 'Aýaz baba: goýy deri reňki',
    '🤶🏻' => 'Aýaz mama: açyk deri reňki',
    '🤶🏼' => 'Aýaz mama: orta açyk deri reňki',
    '🤶🏽' => 'Aýaz mama: orta deri reňki',
    '🤶🏾' => 'Aýaz mama: orta goýy deri reňki',
    '🤶🏿' => 'Aýaz mama: goýy deri reňki',
    '🦸🏻' => 'supergahryman: açyk deri reňki',
    '🦸🏼' => 'supergahryman: orta açyk deri reňki',
    '🦸🏽' => 'supergahryman: orta deri reňki',
    '🦸🏾' => 'supergahryman: orta goýy deri reňki',
    '🦸🏿' => 'supergahryman: goýy deri reňki',
    '🦹🏻' => 'superbetpäl: açyk deri reňki',
    '🦹🏼' => 'superbetpäl: orta açyk deri reňki',
    '🦹🏽' => 'superbetpäl: orta deri reňki',
    '🦹🏾' => 'superbetpäl: orta goýy deri reňki',
    '🦹🏿' => 'superbetpäl: goýy deri reňki',
    '🧙🏻' => 'jadygöý: açyk deri reňki',
    '🧙🏼' => 'jadygöý: orta açyk deri reňki',
    '🧙🏽' => 'jadygöý: orta deri reňki',
    '🧙🏾' => 'jadygöý: orta goýy deri reňki',
    '🧙🏿' => 'jadygöý: goýy deri reňki',
    '🧚🏻' => 'peri: açyk deri reňki',
    '🧚🏼' => 'peri: orta açyk deri reňki',
    '🧚🏽' => 'peri: orta deri reňki',
    '🧚🏾' => 'peri: orta goýy deri reňki',
    '🧚🏿' => 'peri: goýy deri reňki',
    '🧛🏻' => 'wampir: açyk deri reňki',
    '🧛🏼' => 'wampir: orta açyk deri reňki',
    '🧛🏽' => 'wampir: orta deri reňki',
    '🧛🏾' => 'wampir: orta goýy deri reňki',
    '🧛🏿' => 'wampir: goýy deri reňki',
    '🧜🏻' => 'suw adam: açyk deri reňki',
    '🧜🏼' => 'suw adam: orta açyk deri reňki',
    '🧜🏽' => 'suw adam: orta deri reňki',
    '🧜🏾' => 'suw adam: orta goýy deri reňki',
    '🧜🏿' => 'suw adam: goýy deri reňki',
    '🧝🏻' => 'elf: açyk deri reňki',
    '🧝🏼' => 'elf: orta açyk deri reňki',
    '🧝🏽' => 'elf: orta deri reňki',
    '🧝🏾' => 'elf: orta goýy deri reňki',
    '🧝🏿' => 'elf: goýy deri reňki',
    '💆🏻' => 'massaž edilýän adam: açyk deri reňki',
    '💆🏼' => 'massaž edilýän adam: orta açyk deri reňki',
    '💆🏽' => 'massaž edilýän adam: orta deri reňki',
    '💆🏾' => 'massaž edilýän adam: orta goýy deri reňki',
    '💆🏿' => 'massaž edilýän adam: goýy deri reňki',
    '💇🏻' => 'saçy kiçeldilýän adam: açyk deri reňki',
    '💇🏼' => 'saçy kiçeldilýän adam: orta açyk deri reňki',
    '💇🏽' => 'saçy kiçeldilýän adam: orta deri reňki',
    '💇🏾' => 'saçy kiçeldilýän adam: orta goýy deri reňki',
    '💇🏿' => 'saçy kiçeldilýän adam: goýy deri reňki',
    '🚶🏻' => 'ýöräp barýan adam: açyk deri reňki',
    '🚶🏼' => 'ýöräp barýan adam: orta açyk deri reňki',
    '🚶🏽' => 'ýöräp barýan adam: orta deri reňki',
    '🚶🏾' => 'ýöräp barýan adam: orta goýy deri reňki',
    '🚶🏿' => 'ýöräp barýan adam: goýy deri reňki',
    '🧍🏻' => 'dik duran adam: açyk deri reňki',
    '🧍🏼' => 'dik duran adam: orta açyk deri reňki',
    '🧍🏽' => 'dik duran adam: orta deri reňki',
    '🧍🏾' => 'dik duran adam: orta goýy deri reňki',
    '🧍🏿' => 'dik duran adam: goýy deri reňki',
    '🧎🏻' => 'dyza çöken adam: açyk deri reňki',
    '🧎🏼' => 'dyza çöken adam: orta açyk deri reňki',
    '🧎🏽' => 'dyza çöken adam: orta deri reňki',
    '🧎🏾' => 'dyza çöken adam: orta goýy deri reňki',
    '🧎🏿' => 'dyza çöken adam: goýy deri reňki',
    '🏃🏻' => 'ylgap barýan adam: açyk deri reňki',
    '🏃🏼' => 'ylgap barýan adam: orta açyk deri reňki',
    '🏃🏽' => 'ylgap barýan adam: orta deri reňki',
    '🏃🏾' => 'ylgap barýan adam: orta goýy deri reňki',
    '🏃🏿' => 'ylgap barýan adam: goýy deri reňki',
    '💃🏻' => 'tans edýän zenan: açyk deri reňki',
    '💃🏼' => 'tans edýän zenan: orta açyk deri reňki',
    '💃🏽' => 'tans edýän zenan: orta deri reňki',
    '💃🏾' => 'tans edýän zenan: orta goýy deri reňki',
    '💃🏿' => 'tans edýän zenan: goýy deri reňki',
    '🕺🏻' => 'tans edýän erkek: açyk deri reňki',
    '🕺🏼' => 'tans edýän erkek: orta açyk deri reňki',
    '🕺🏽' => 'tans edýän erkek: orta deri reňki',
    '🕺🏾' => 'tans edýän erkek: orta goýy deri reňki',
    '🕺🏿' => 'tans edýän erkek: goýy deri reňki',
    '🕴🏻' => 'kostýum-balakly ýokary galyp barýan kişi: açyk deri reňki',
    '🕴🏼' => 'kostýum-balakly ýokary galyp barýan kişi: orta açyk deri reňki',
    '🕴🏽' => 'kostýum-balakly ýokary galyp barýan kişi: orta deri reňki',
    '🕴🏾' => 'kostýum-balakly ýokary galyp barýan kişi: orta goýy deri reňki',
    '🕴🏿' => 'kostýum-balakly ýokary galyp barýan kişi: goýy deri reňki',
    '👯🏻' => 'towşan gulakly adamlar: açyk deri reňki',
    '👯🏼' => 'towşan gulakly adamlar: orta açyk deri reňki',
    '👯🏽' => 'towşan gulakly adamlar: orta deri reňki',
    '👯🏾' => 'towşan gulakly adamlar: orta goýy deri reňki',
    '👯🏿' => 'towşan gulakly adamlar: goýy deri reňki',
    '🧖🏻' => 'bug otagyndaky adam: açyk deri reňki',
    '🧖🏼' => 'bug otagyndaky adam: orta açyk deri reňki',
    '🧖🏽' => 'bug otagyndaky adam: orta deri reňki',
    '🧖🏾' => 'bug otagyndaky adam: orta goýy deri reňki',
    '🧖🏿' => 'bug otagyndaky adam: goýy deri reňki',
    '🧗🏻' => 'dyrmaşýan adam: açyk deri reňki',
    '🧗🏼' => 'dyrmaşýan adam: orta açyk deri reňki',
    '🧗🏽' => 'dyrmaşýan adam: orta deri reňki',
    '🧗🏾' => 'dyrmaşýan adam: orta goýy deri reňki',
    '🧗🏿' => 'dyrmaşýan adam: goýy deri reňki',
    '🏇🏻' => 'çapyşýan at: açyk deri reňki',
    '🏇🏼' => 'çapyşýan at: orta açyk deri reňki',
    '🏇🏽' => 'çapyşýan at: orta deri reňki',
    '🏇🏾' => 'çapyşýan at: orta goýy deri reňki',
    '🏇🏿' => 'çapyşýan at: goýy deri reňki',
    '🏂🏻' => 'snoubordçy: açyk deri reňki',
    '🏂🏼' => 'snoubordçy: orta açyk deri reňki',
    '🏂🏽' => 'snoubordçy: orta deri reňki',
    '🏂🏾' => 'snoubordçy: orta goýy deri reňki',
    '🏂🏿' => 'snoubordçy: goýy deri reňki',
    '🏌🏻' => 'golf oýnaýan adam: açyk deri reňki',
    '🏌🏼' => 'golf oýnaýan adam: orta açyk deri reňki',
    '🏌🏽' => 'golf oýnaýan adam: orta deri reňki',
    '🏌🏾' => 'golf oýnaýan adam: orta goýy deri reňki',
    '🏌🏿' => 'golf oýnaýan adam: goýy deri reňki',
    '🏄🏻' => 'sörf edýän adam: açyk deri reňki',
    '🏄🏼' => 'sörf edýän adam: orta açyk deri reňki',
    '🏄🏽' => 'sörf edýän adam: orta deri reňki',
    '🏄🏾' => 'sörf edýän adam: orta goýy deri reňki',
    '🏄🏿' => 'sörf edýän adam: goýy deri reňki',
    '🚣🏻' => 'gaýyk kürekleýän adam: açyk deri reňki',
    '🚣🏼' => 'gaýyk kürekleýän adam: orta açyk deri reňki',
    '🚣🏽' => 'gaýyk kürekleýän adam: orta deri reňki',
    '🚣🏾' => 'gaýyk kürekleýän adam: orta goýy deri reňki',
    '🚣🏿' => 'gaýyk kürekleýän adam: goýy deri reňki',
    '🏊🏻' => 'ýüzüp ýören adam: açyk deri reňki',
    '🏊🏼' => 'ýüzüp ýören adam: orta açyk deri reňki',
    '🏊🏽' => 'ýüzüp ýören adam: orta deri reňki',
    '🏊🏾' => 'ýüzüp ýören adam: orta goýy deri reňki',
    '🏊🏿' => 'ýüzüp ýören adam: goýy deri reňki',
    '⛹🏻' => 'topy bökdürýän adam: açyk deri reňki',
    '⛹🏼' => 'topy bökdürýän adam: orta açyk deri reňki',
    '⛹🏽' => 'topy bökdürýän adam: orta deri reňki',
    '⛹🏾' => 'topy bökdürýän adam: orta goýy deri reňki',
    '⛹🏿' => 'topy bökdürýän adam: goýy deri reňki',
    '🏋🏻' => 'agyrlyk göterýän adam: açyk deri reňki',
    '🏋🏼' => 'agyrlyk göterýän adam: orta açyk deri reňki',
    '🏋🏽' => 'agyrlyk göterýän adam: orta deri reňki',
    '🏋🏾' => 'agyrlyk göterýän adam: orta goýy deri reňki',
    '🏋🏿' => 'agyrlyk göterýän adam: goýy deri reňki',
    '🚴🏻' => 'tigir sürýän adam: açyk deri reňki',
    '🚴🏼' => 'tigir sürýän adam: orta açyk deri reňki',
    '🚴🏽' => 'tigir sürýän adam: orta deri reňki',
    '🚴🏾' => 'tigir sürýän adam: orta goýy deri reňki',
    '🚴🏿' => 'tigir sürýän adam: goýy deri reňki',
    '🚵🏻' => 'dagda tigir sürýän adam: açyk deri reňki',
    '🚵🏼' => 'dagda tigir sürýän adam: orta açyk deri reňki',
    '🚵🏽' => 'dagda tigir sürýän adam: orta deri reňki',
    '🚵🏾' => 'dagda tigir sürýän adam: orta goýy deri reňki',
    '🚵🏿' => 'dagda tigir sürýän adam: goýy deri reňki',
    '🤸🏻' => 'ýanyn aşyr atýan adam: açyk deri reňki',
    '🤸🏼' => 'ýanyn aşyr atýan adam: orta açyk deri reňki',
    '🤸🏽' => 'ýanyn aşyr atýan adam: orta deri reňki',
    '🤸🏾' => 'ýanyn aşyr atýan adam: orta goýy deri reňki',
    '🤸🏿' => 'ýanyn aşyr atýan adam: goýy deri reňki',
    '🤼🏻' => 'göreş tutýan adamlar: açyk deri reňki',
    '🤼🏼' => 'göreş tutýan adamlar: orta açyk deri reňki',
    '🤼🏽' => 'göreş tutýan adamlar: orta deri reňki',
    '🤼🏾' => 'göreş tutýan adamlar: orta goýy deri reňki',
    '🤼🏿' => 'göreş tutýan adamlar: goýy deri reňki',
    '🤽🏻' => 'suw polo oýnaýan adam: açyk deri reňki',
    '🤽🏼' => 'suw polo oýnaýan adam: orta açyk deri reňki',
    '🤽🏽' => 'suw polo oýnaýan adam: orta deri reňki',
    '🤽🏾' => 'suw polo oýnaýan adam: orta goýy deri reňki',
    '🤽🏿' => 'suw polo oýnaýan adam: goýy deri reňki',
    '🤾🏻' => 'gandbol oýnaýan adam: açyk deri reňki',
    '🤾🏼' => 'gandbol oýnaýan adam: orta açyk deri reňki',
    '🤾🏽' => 'gandbol oýnaýan adam: orta deri reňki',
    '🤾🏾' => 'gandbol oýnaýan adam: orta goýy deri reňki',
    '🤾🏿' => 'gandbol oýnaýan adam: goýy deri reňki',
    '🤹🏻' => 'hokgabazlyk edýän adam: açyk deri reňki',
    '🤹🏼' => 'hokgabazlyk edýän adam: orta açyk deri reňki',
    '🤹🏽' => 'hokgabazlyk edýän adam: orta deri reňki',
    '🤹🏾' => 'hokgabazlyk edýän adam: orta goýy deri reňki',
    '🤹🏿' => 'hokgabazlyk edýän adam: goýy deri reňki',
    '🧘🏻' => 'lotus oturyşyndaky adam: açyk deri reňki',
    '🧘🏼' => 'lotus oturyşyndaky adam: orta açyk deri reňki',
    '🧘🏽' => 'lotus oturyşyndaky adam: orta deri reňki',
    '🧘🏾' => 'lotus oturyşyndaky adam: orta goýy deri reňki',
    '🧘🏿' => 'lotus oturyşyndaky adam: goýy deri reňki',
    '🛀🏻' => 'wannada suwa düşýän adam: açyk deri reňki',
    '🛀🏼' => 'wannada suwa düşýän adam: orta açyk deri reňki',
    '🛀🏽' => 'wannada suwa düşýän adam: orta deri reňki',
    '🛀🏾' => 'wannada suwa düşýän adam: orta goýy deri reňki',
    '🛀🏿' => 'wannada suwa düşýän adam: goýy deri reňki',
    '🛌🏻' => 'ýatalgada ýatan adam: açyk deri reňki',
    '🛌🏼' => 'ýatalgada ýatan adam: orta açyk deri reňki',
    '🛌🏽' => 'ýatalgada ýatan adam: orta deri reňki',
    '🛌🏾' => 'ýatalgada ýatan adam: orta goýy deri reňki',
    '🛌🏿' => 'ýatalgada ýatan adam: goýy deri reňki',
    '👭🏻' => 'el tutuşan aýallar: açyk deri reňki',
    '👭🏼' => 'el tutuşan aýallar: orta açyk deri reňki',
    '👭🏽' => 'el tutuşan aýallar: orta deri reňki',
    '👭🏾' => 'el tutuşan aýallar: orta goýy deri reňki',
    '👭🏿' => 'el tutuşan aýallar: goýy deri reňki',
    '👫🏻' => 'el tutuşan aýal bilen erkek: açyk deri reňki',
    '👫🏼' => 'el tutuşan aýal bilen erkek: orta açyk deri reňki',
    '👫🏽' => 'el tutuşan aýal bilen erkek: orta deri reňki',
    '👫🏾' => 'el tutuşan aýal bilen erkek: orta goýy deri reňki',
    '👫🏿' => 'el tutuşan aýal bilen erkek: goýy deri reňki',
    '👬🏻' => 'el tutuşan erkekler: açyk deri reňki',
    '👬🏼' => 'el tutuşan erkekler: orta açyk deri reňki',
    '👬🏽' => 'el tutuşan erkekler: orta deri reňki',
    '👬🏾' => 'el tutuşan erkekler: orta goýy deri reňki',
    '👬🏿' => 'el tutuşan erkekler: goýy deri reňki',
    '💏🏻' => 'posa: açyk deri reňki',
    '💏🏼' => 'posa: orta açyk deri reňki',
    '💏🏽' => 'posa: orta deri reňki',
    '💏🏾' => 'posa: orta goýy deri reňki',
    '💏🏿' => 'posa: goýy deri reňki',
    '💑🏻' => 'ýürekli jübüt: açyk deri reňki',
    '💑🏼' => 'ýürekli jübüt: orta açyk deri reňki',
    '💑🏽' => 'ýürekli jübüt: orta deri reňki',
    '💑🏾' => 'ýürekli jübüt: orta goýy deri reňki',
    '💑🏿' => 'ýürekli jübüt: goýy deri reňki',
    '🇦🇨' => 'baýdak: Beýgeliş adasy',
    '🇦🇩' => 'baýdak: Andorra',
    '🇦🇪' => 'baýdak: Birleşen Arap Emirlikleri',
    '🇦🇫' => 'baýdak: Owganystan',
    '🇦🇬' => 'baýdak: Antigua we Barbuda',
    '🇦🇮' => 'baýdak: Angilýa',
    '🇦🇱' => 'baýdak: Albaniýa',
    '🇦🇲' => 'baýdak: Ermenistan',
    '🇦🇴' => 'baýdak: Angola',
    '🇦🇶' => 'baýdak: Antarktika',
    '🇦🇷' => 'baýdak: Argentina',
    '🇦🇸' => 'baýdak: Amerikan Samoasy',
    '🇦🇹' => 'baýdak: Awstriýa',
    '🇦🇺' => 'baýdak: Awstraliýa',
    '🇦🇼' => 'baýdak: Aruba',
    '🇦🇽' => 'baýdak: Aland adalary',
    '🇦🇿' => 'baýdak: Azerbaýjan',
    '🇧🇦' => 'baýdak: Bosniýa we Gersegowina',
    '🇧🇧' => 'baýdak: Barbados',
    '🇧🇩' => 'baýdak: Bangladeş',
    '🇧🇪' => 'baýdak: Belgiýa',
    '🇧🇫' => 'baýdak: Burkina-Faso',
    '🇧🇬' => 'baýdak: Bolgariýa',
    '🇧🇭' => 'baýdak: Bahreýn',
    '🇧🇮' => 'baýdak: Burundi',
    '🇧🇯' => 'baýdak: Benin',
    '🇧🇱' => 'baýdak: Sen-Bartelemi',
    '🇧🇲' => 'baýdak: Bermuda',
    '🇧🇳' => 'baýdak: Bruneý',
    '🇧🇴' => 'baýdak: Boliwiýa',
    '🇧🇶' => 'baýdak: Karib Niderlandlary',
    '🇧🇷' => 'baýdak: Braziliýa',
    '🇧🇸' => 'baýdak: Bagama adalary',
    '🇧🇹' => 'baýdak: Butan',
    '🇧🇻' => 'baýdak: Buwe adasy',
    '🇧🇼' => 'baýdak: Botswana',
    '🇧🇾' => 'baýdak: Belarus',
    '🇧🇿' => 'baýdak: Beliz',
    '🇨🇦' => 'baýdak: Kanada',
    '🇨🇨' => 'baýdak: Kokos (Kiling) adalary',
    '🇨🇩' => 'baýdak: Kongo - Kinşasa',
    '🇨🇫' => 'baýdak: Merkezi Afrika Respublikasy',
    '🇨🇬' => 'baýdak: Kongo - Brazzawil',
    '🇨🇭' => 'baýdak: Şweýsariýa',
    '🇨🇮' => 'baýdak: Kot-d’Iwuar',
    '🇨🇰' => 'baýdak: Kuk adalary',
    '🇨🇱' => 'baýdak: Çili',
    '🇨🇲' => 'baýdak: Kamerun',
    '🇨🇳' => 'baýdak: Hytaý',
    '🇨🇴' => 'baýdak: Kolumbiýa',
    '🇨🇵' => 'baýdak: Klipperton adasy',
    '🇨🇶' => 'baýdak: Sark',
    '🇨🇷' => 'baýdak: Kosta-Rika',
    '🇨🇺' => 'baýdak: Kuba',
    '🇨🇻' => 'baýdak: Kabo-Werde',
    '🇨🇼' => 'baýdak: Kýurasao',
    '🇨🇽' => 'baýdak: Roždestwo adasy',
    '🇨🇾' => 'baýdak: Kipr',
    '🇨🇿' => 'baýdak: Çehiýa',
    '🇩🇪' => 'baýdak: Germaniýa',
    '🇩🇬' => 'baýdak: Diýego-Garsiýa',
    '🇩🇯' => 'baýdak: Jibuti',
    '🇩🇰' => 'baýdak: Daniýa',
    '🇩🇲' => 'baýdak: Dominika',
    '🇩🇴' => 'baýdak: Dominikan Respublikasy',
    '🇩🇿' => 'baýdak: Alžir',
    '🇪🇦' => 'baýdak: Seuta we Melilýa',
    '🇪🇨' => 'baýdak: Ekwador',
    '🇪🇪' => 'baýdak: Estoniýa',
    '🇪🇬' => 'baýdak: Müsür',
    '🇪🇭' => 'baýdak: Günbatar Sahara',
    '🇪🇷' => 'baýdak: Eritreýa',
    '🇪🇸' => 'baýdak: Ispaniýa',
    '🇪🇹' => 'baýdak: Efiopiýa',
    '🇪🇺' => 'baýdak: Ýewropa Bileleşigi',
    '🇫🇮' => 'baýdak: Finlýandiýa',
    '🇫🇯' => 'baýdak: Fiji',
    '🇫🇰' => 'baýdak: Folklend adalary',
    '🇫🇲' => 'baýdak: Mikroneziýa',
    '🇫🇴' => 'baýdak: Farer adalary',
    '🇫🇷' => 'baýdak: Fransiýa',
    '🇬🇦' => 'baýdak: Gabon',
    '🇬🇧' => 'baýdak: Birleşen Patyşalyk',
    '🇬🇩' => 'baýdak: Grenada',
    '🇬🇪' => 'baýdak: Gruziýa',
    '🇬🇫' => 'baýdak: Fransuz Gwianasy',
    '🇬🇬' => 'baýdak: Gernsi',
    '🇬🇭' => 'baýdak: Gana',
    '🇬🇮' => 'baýdak: Gibraltar',
    '🇬🇱' => 'baýdak: Grenlandiýa',
    '🇬🇲' => 'baýdak: Gambiýa',
    '🇬🇳' => 'baýdak: Gwineýa',
    '🇬🇵' => 'baýdak: Gwadelupa',
    '🇬🇶' => 'baýdak: Ekwatorial Gwineýa',
    '🇬🇷' => 'baýdak: Gresiýa',
    '🇬🇸' => 'baýdak: Günorta Georgiýa we Günorta Sendwiç adasy',
    '🇬🇹' => 'baýdak: Gwatemala',
    '🇬🇺' => 'baýdak: Guam',
    '🇬🇼' => 'baýdak: Gwineýa-Bisau',
    '🇬🇾' => 'baýdak: Gaýana',
    '🇭🇰' => 'baýdak: Gonkong AAS Hytaý',
    '🇭🇲' => 'baýdak: Herd we Makdonald adalary',
    '🇭🇳' => 'baýdak: Gonduras',
    '🇭🇷' => 'baýdak: Horwatiýa',
    '🇭🇹' => 'baýdak: Gaiti',
    '🇭🇺' => 'baýdak: Wengriýa',
    '🇮🇨' => 'baýdak: Kanar adalary',
    '🇮🇩' => 'baýdak: Indoneziýa',
    '🇮🇪' => 'baýdak: Irlandiýa',
    '🇮🇱' => 'baýdak: Ysraýyl',
    '🇮🇲' => 'baýdak: Men adasy',
    '🇮🇳' => 'baýdak: Hindistan',
    '🇮🇴' => 'baýdak: Britaniýanyň Hindi okeanyndaky territoriýalary',
    '🇮🇶' => 'baýdak: Yrak',
    '🇮🇷' => 'baýdak: Eýran',
    '🇮🇸' => 'baýdak: Islandiýa',
    '🇮🇹' => 'baýdak: Italiýa',
    '🇯🇪' => 'baýdak: Jersi',
    '🇯🇲' => 'baýdak: Ýamaýka',
    '🇯🇴' => 'baýdak: Iordaniýa',
    '🇯🇵' => 'baýdak: Ýaponiýa',
    '🇰🇪' => 'baýdak: Keniýa',
    '🇰🇬' => 'baýdak: Gyrgyzystan',
    '🇰🇭' => 'baýdak: Kamboja',
    '🇰🇮' => 'baýdak: Kiribati',
    '🇰🇲' => 'baýdak: Komor adalary',
    '🇰🇳' => 'baýdak: Sent-Kits we Newis',
    '🇰🇵' => 'baýdak: Demirgazyk Koreýa',
    '🇰🇷' => 'baýdak: Günorta Koreýa',
    '🇰🇼' => 'baýdak: Kuweýt',
    '🇰🇾' => 'baýdak: Kaýman adalary',
    '🇰🇿' => 'baýdak: Gazagystan',
    '🇱🇦' => 'baýdak: Laos',
    '🇱🇧' => 'baýdak: Liwan',
    '🇱🇨' => 'baýdak: Sent-Lýusiýa',
    '🇱🇮' => 'baýdak: Lihtenşteýn',
    '🇱🇰' => 'baýdak: Şri-Lanka',
    '🇱🇷' => 'baýdak: Liberiýa',
    '🇱🇸' => 'baýdak: Lesoto',
    '🇱🇹' => 'baýdak: Litwa',
    '🇱🇺' => 'baýdak: Lýuksemburg',
    '🇱🇻' => 'baýdak: Latwiýa',
    '🇱🇾' => 'baýdak: Liwiýa',
    '🇲🇦' => 'baýdak: Marokko',
    '🇲🇨' => 'baýdak: Monako',
    '🇲🇩' => 'baýdak: Moldowa',
    '🇲🇪' => 'baýdak: Çernogoriýa',
    '🇲🇫' => 'baýdak: Sen-Marten',
    '🇲🇬' => 'baýdak: Madagaskar',
    '🇲🇭' => 'baýdak: Marşall adalary',
    '🇲🇰' => 'baýdak: Demirgazyk Makedoniýa',
    '🇲🇱' => 'baýdak: Mali',
    '🇲🇲' => 'baýdak: Mýanma (Birma)',
    '🇲🇳' => 'baýdak: Mongoliýa',
    '🇲🇴' => 'baýdak: Makao AAS Hytaý',
    '🇲🇵' => 'baýdak: Demirgazyk Mariana adalary',
    '🇲🇶' => 'baýdak: Martinika',
    '🇲🇷' => 'baýdak: Mawritaniýa',
    '🇲🇸' => 'baýdak: Monserrat',
    '🇲🇹' => 'baýdak: Malta',
    '🇲🇺' => 'baýdak: Mawrikiý',
    '🇲🇻' => 'baýdak: Maldiwler',
    '🇲🇼' => 'baýdak: Malawi',
    '🇲🇽' => 'baýdak: Meksika',
    '🇲🇾' => 'baýdak: Malaýziýa',
    '🇲🇿' => 'baýdak: Mozambik',
    '🇳🇦' => 'baýdak: Namibiýa',
    '🇳🇨' => 'baýdak: Täze Kaledoniýa',
    '🇳🇪' => 'baýdak: Niger',
    '🇳🇫' => 'baýdak: Norfolk adasy',
    '🇳🇬' => 'baýdak: Nigeriýa',
    '🇳🇮' => 'baýdak: Nikaragua',
    '🇳🇱' => 'baýdak: Niderlandlar',
    '🇳🇴' => 'baýdak: Norwegiýa',
    '🇳🇵' => 'baýdak: Nepal',
    '🇳🇷' => 'baýdak: Nauru',
    '🇳🇺' => 'baýdak: Niue',
    '🇳🇿' => 'baýdak: Täze Zelandiýa',
    '🇴🇲' => 'baýdak: Oman',
    '🇵🇦' => 'baýdak: Panama',
    '🇵🇪' => 'baýdak: Peru',
    '🇵🇫' => 'baýdak: Fransuz Polineziýasy',
    '🇵🇬' => 'baýdak: Papua - Täze Gwineýa',
    '🇵🇭' => 'baýdak: Filippinler',
    '🇵🇰' => 'baýdak: Pakistan',
    '🇵🇱' => 'baýdak: Polşa',
    '🇵🇲' => 'baýdak: Sen-Pýer we Mikelon',
    '🇵🇳' => 'baýdak: Pitkern adalary',
    '🇵🇷' => 'baýdak: Puerto-Riko',
    '🇵🇸' => 'baýdak: Palestina territoriýasy',
    '🇵🇹' => 'baýdak: Portugaliýa',
    '🇵🇼' => 'baýdak: Palau',
    '🇵🇾' => 'baýdak: Paragwaý',
    '🇶🇦' => 'baýdak: Katar',
    '🇷🇪' => 'baýdak: Reýunýon',
    '🇷🇴' => 'baýdak: Rumyniýa',
    '🇷🇸' => 'baýdak: Serbiýa',
    '🇷🇺' => 'baýdak: Russiýa',
    '🇷🇼' => 'baýdak: Ruanda',
    '🇸🇦' => 'baýdak: Saud Arabystany',
    '🇸🇧' => 'baýdak: Solomon adalary',
    '🇸🇨' => 'baýdak: Seýşel adalary',
    '🇸🇩' => 'baýdak: Sudan',
    '🇸🇪' => 'baýdak: Şwesiýa',
    '🇸🇬' => 'baýdak: Singapur',
    '🇸🇭' => 'baýdak: Keramatly Ýelena adasy',
    '🇸🇮' => 'baýdak: Sloweniýa',
    '🇸🇯' => 'baýdak: Şpisbergen we Ýan-Maýen',
    '🇸🇰' => 'baýdak: Slowakiýa',
    '🇸🇱' => 'baýdak: Sýerra-Leone',
    '🇸🇲' => 'baýdak: San-Marino',
    '🇸🇳' => 'baýdak: Senegal',
    '🇸🇴' => 'baýdak: Somali',
    '🇸🇷' => 'baýdak: Surinam',
    '🇸🇸' => 'baýdak: Günorta Sudan',
    '🇸🇹' => 'baýdak: San-Tome we Prinsipi',
    '🇸🇻' => 'baýdak: Salwador',
    '🇸🇽' => 'baýdak: Sint-Marten',
    '🇸🇾' => 'baýdak: Siriýa',
    '🇸🇿' => 'baýdak: Eswatini',
    '🇹🇦' => 'baýdak: Tristan-da-Kunýa',
    '🇹🇨' => 'baýdak: Terks we Kaýkos adalary',
    '🇹🇩' => 'baýdak: Çad',
    '🇹🇫' => 'baýdak: Fransuz günorta territoriýalary',
    '🇹🇬' => 'baýdak: Togo',
    '🇹🇭' => 'baýdak: Taýland',
    '🇹🇯' => 'baýdak: Täjigistan',
    '🇹🇰' => 'baýdak: Tokelau',
    '🇹🇱' => 'baýdak: Timor-Leste',
    '🇹🇲' => 'baýdak: Türkmenistan',
    '🇹🇳' => 'baýdak: Tunis',
    '🇹🇴' => 'baýdak: Tonga',
    '🇹🇷' => 'baýdak: Türkiýe',
    '🇹🇹' => 'baýdak: Trinidad we Tobago',
    '🇹🇻' => 'baýdak: Tuwalu',
    '🇹🇼' => 'baýdak: Taýwan',
    '🇹🇿' => 'baýdak: Tanzaniýa',
    '🇺🇦' => 'baýdak: Ukraina',
    '🇺🇬' => 'baýdak: Uganda',
    '🇺🇲' => 'baýdak: ABŞ-nyň daşarky adalary',
    '🇺🇳' => 'baýdak: Birleşen Milletler Guramasy',
    '🇺🇸' => 'baýdak: Amerikanyň Birleşen Ştatlary',
    '🇺🇾' => 'baýdak: Urugwaý',
    '🇺🇿' => 'baýdak: Özbegistan',
    '🇻🇦' => 'baýdak: Watikan',
    '🇻🇨' => 'baýdak: Sent-Winsent we Grenadinler',
    '🇻🇪' => 'baýdak: Wenesuela',
    '🇻🇬' => 'baýdak: Britan Wirgin adalary',
    '🇻🇮' => 'baýdak: ABŞ-nyň Wirgin adalary',
    '🇻🇳' => 'baýdak: Wýetnam',
    '🇻🇺' => 'baýdak: Wanuatu',
    '🇼🇫' => 'baýdak: Uollis we Futuna',
    '🇼🇸' => 'baýdak: Samoa',
    '🇽🇰' => 'baýdak: Kosowo',
    '🇾🇪' => 'baýdak: Ýemen',
    '🇾🇹' => 'baýdak: Maýotta',
    '🇿🇦' => 'baýdak: Günorta Afrika',
    '🇿🇲' => 'baýdak: Zambiýa',
    '🇿🇼' => 'baýdak: Zimbabwe',
    '🔟' => 'klawiş gapagy: 10',
    '🏻' => 'açyk deri reňki',
    '🏼' => 'orta açyk deri reňki',
    '🏽' => 'orta deri reňki',
    '🏾' => 'orta goýy deri reňki',
    '🏿' => 'goýy deri reňki',
    '😀' => 'syrtarýan ýüz',
    '😃' => 'ullakan gözli syrtarýan ýüz',
    '😄' => 'gülýän gözli syrtarýan ýüz',
    '😁' => 'gülýän gözli ýyrşarýan ýüz',
    '😆' => 'gytak gözli syrtarýan ýüz',
    '😅' => 'syrtarýan derli ýüz',
    '🤣' => 'içiňi tutup gülmek',
    '😂' => 'begenç gözýaşly ýüz',
    '🙂' => 'çalaja ýylgyrýan ýüz',
    '🙃' => 'dik başaşak ýüz',
    '🫠' => 'ereýän ýüz',
    '😉' => 'göz gypýan ýüz',
    '😊' => 'gülýän gözli ýylgyrýan ýüz',
    '😇' => 'başy halkaly ýylgyrýan ýüz',
    '🥰' => 'üç ýürekli ýylgyrýan ýüz',
    '😍' => 'ýürek gözli ýylgyrýan ýüz',
    '🤩' => 'ýyldyz düşen',
    '😘' => 'posa üfleýän ýüz',
    '😗' => 'öpýän ýüz',
    '☺' => 'ýylgyrýan ýüz',
    '😚' => 'ýumuk gözli öpýän ýüz',
    '😙' => 'gülýän gözli öpýän ýüz',
    '🥲' => 'gözýaşly ýylgyrýan ýüz',
    '😋' => 'nahara agzyny şapyrdadýan ýüz',
    '😛' => 'dilini çykarýan ýüz',
    '😜' => 'dilini çykarýan we göz gypýan ýüz',
    '🤪' => 'däli ýüz',
    '😝' => 'dilini çykarýan we gözüniň gytagy bilen seredýän ýüz',
    '🤑' => 'pul agyzly ýüz',
    '🤗' => 'gujaklaýan ýüz',
    '🤭' => 'eli agzynyň üstünde ýüz',
    '🫢' => 'gözleri açyk we agzyň üstünde el bolan ýüz',
    '🫣' => 'göz gytagyndan garaýan ýüz',
    '🤫' => '"ýuwaşş" diýýän ýüz',
    '🤔' => 'oýlanýan ýüz',
    '🫡' => 'salam berýän ýüz',
    '🤐' => 'syrma agyzly ýüz',
    '🤨' => 'gaşyny galdyran ýüz',
    '😐' => 'syr bildirmeýän ýüz',
    '😑' => 'duýgusyz ýüz',
    '😶' => 'agyzsyz ýüz',
    '🫥' => 'nokatly çyzykdan ýüz',
    '😏' => 'kinaýaly ýüz',
    '😒' => 'göwni bitmedik ýüz',
    '🙄' => 'gözüni agdarýan ýüz',
    '😬' => 'ýyrşarýan ýüz',
    '🤥' => 'ýalançy ýüz',
    '🫨' => 'titreýan ýüz',
    '😌' => 'ynjalan ýüz',
    '😔' => 'gussaly ýüz',
    '😪' => 'ukuly ýüz',
    '🤤' => 'gyllygy akýan ýüz',
    '😴' => 'uklap ýatan ýüz',
    '🫩' => 'gözüniň aşagy halkaly ýüz',
    '😷' => 'saglyk maskaly ýüz',
    '🤒' => 'termometrli ýüz',
    '🤕' => 'kellesi sargyly ýüz',
    '🤢' => 'ýüregi bulanýan ýüz',
    '🤮' => 'gusýan ýüz',
    '🤧' => 'asgyrýan ýüz',
    '🥵' => 'gyzan ýüz',
    '🥶' => 'sowuk ýüz',
    '🥴' => 'garagol ýüz',
    '😵' => 'urlan ýüz',
    '🤯' => 'partlaýan kelle',
    '🤠' => 'kowboý papakly ýüz',
    '🥳' => 'şagalaňly ýüz',
    '🥸' => 'ýüzi gizlenen',
    '😎' => 'gün äýnekli ýylgyrýan ýüz',
    '🤓' => 'botan ýüz',
    '🧐' => 'monoklly ýüz',
    '😕' => 'başy çaşan ýüz',
    '🫤' => 'diagonal agyzly ýüz',
    '😟' => 'aladaly ýüz',
    '🙁' => 'çalaja çytyk ýüz',
    '☹' => 'çytyk ýüz',
    '😮' => 'açyk agyzly ýüz',
    '😯' => 'aňalyp galan ýüz',
    '😲' => 'aňk-taňk bolan ýüz',
    '😳' => 'gyzaran ýüz',
    '🫪' => 'gyşyk ýüz',
    '🥺' => 'ýalbarýan ýüz',
    '🥹' => 'gözýaşyny saklap duran ýüz',
    '😦' => 'açyk agyzly çytyk ýüz',
    '😧' => 'jebir çekýän ýüz',
    '😨' => 'gorkuly ýüz',
    '😰' => 'sowuk derli biynjalyk ýüz',
    '😥' => 'gynançly, ýöne ynjalan ýüz',
    '😢' => 'aglaýan ýüz',
    '😭' => 'möňňürýän ýüz',
    '😱' => 'gorkup çygyrýan ýüz',
    '😖' => 'ugruny ýitiren ýüz',
    '😣' => 'çynyny edýän ýüz',
    '😞' => 'lapykeç ýüz',
    '😓' => 'derli salyk ýüz',
    '😩' => 'argyn ýüz',
    '😫' => 'ýadaw ýüz',
    '🥱' => 'pallaýan ýüz',
    '😤' => 'burnundan bug çykýan ýüz',
    '😡' => 'gamaşyk ýüz',
    '😠' => 'gaharly ýüz',
    '🤬' => 'agzynyň üsti simwolly ýüz',
    '😈' => 'şahly ýylgyrýan ýüz',
    '👿' => 'şahly gaharly ýüz',
    '💀' => 'kelleçanak',
    '☠' => 'kelleçanak we atanak süňk',
    '💩' => 'tezek',
    '🤡' => 'masgarabaz ýüz',
    '👹' => 'döw',
    '👺' => 'goblin',
    '👻' => 'arwah',
    '👽' => 'gelmişek',
    '👾' => 'gelmişek nägehan',
    '🤖' => 'robot',
    '😺' => 'syrtarýan pişik',
    '😸' => 'ýylgyrýan gözli syrtarýan pişik',
    '😹' => 'begenç gözýaşly pişik',
    '😻' => 'ýürek gözli ýylgyrýan pişik',
    '😼' => 'kinaýaly ýylgyrýan pişik',
    '😽' => 'öpýän pişik',
    '🙀' => 'argyn pişik',
    '😿' => 'aglaýan pişik',
    '😾' => 'gamaşyk pişik',
    '🙈' => 'görmedim-bilmedim maýmyn',
    '🙉' => 'eşitmedim-bilmedim maýmyn',
    '🙊' => 'gürlemedim-bilmedim maýmyn',
    '💌' => 'söýgi haty',
    '💘' => 'okly ýürek',
    '💝' => 'lentaly ýürek',
    '💖' => 'lowurdaýan ýürek',
    '💗' => 'ulalýan ýürek',
    '💓' => 'urýan ýürek',
    '💞' => 'aýlanýan ýürekler',
    '💕' => 'goşa ýürek',
    '💟' => 'ýürek bezegi',
    '❣' => 'ýürekli ýüzlenme',
    '💔' => 'synan ýürek',
    '❤' => 'gyzyl ýürek',
    '🩷' => 'gülgüne ýürek',
    '🧡' => 'mämişi ýürek',
    '💛' => 'sary ýürek',
    '💚' => 'ýaşyl ýürek',
    '💙' => 'gök ýürek',
    '🩵' => 'açyk gök ýürek',
    '💜' => 'mawy ýürek',
    '🤎' => 'goňur ýürek',
    '🖤' => 'gara ýürek',
    '🩶' => 'küljümek ýürek',
    '🤍' => 'ak ýürek',
    '💋' => 'posa yzy',
    '💯' => 'ýüz utuk',
    '💢' => 'gaharyň nyşany',
    '🫯' => 'uruş buludy',
    '💥' => 'çakyşma',
    '💫' => 'başy aýlanan',
    '💦' => 'der damjalary',
    '💨' => 'zut jyrmak',
    '🕳' => 'deşik',
    '💬' => 'gepleşik şary',
    '🗨' => 'çepden gepleşik şary',
    '🗯' => 'sagdan gahar şary',
    '💭' => 'pikir şary',
    '💤' => 'uhh',
    '👋' => 'galgaýan el',
    '🤚' => 'galdyrylan el arkasy',
    '🖐' => 'barmaklaryň arasy açylan el',
    '✋' => 'galdyrylan el',
    '🖖' => 'wulkan salam',
    '🫱' => 'saga el',
    '🫲' => 'çepe el',
    '🫳' => 'aýasy aşak seredýän el',
    '🫴' => 'aýasy ýokaryk seredýän el',
    '🫷' => 'çepe itýän el',
    '🫸' => 'saga itýän el',
    '👌' => 'OK eli',
    '🤌' => 'gysylan barmaklar',
    '🤏' => 'çümmükleýän el',
    '✌' => 'ýeňiş alamatyny görkezýän el',
    '🤞' => 'atanak edilen barmak',
    '🫰' => 'süýem we başam barmagy çapraz el',
    '🤟' => 'seni söýýän ümi',
    '🤘' => 'şah belgisi',
    '🤙' => 'jaňlaş eli',
    '👈' => 'çepi görkezýän el-arkasy süýem barmak',
    '👉' => 'sagy görkezýän el-arkasy süýem barmak',
    '👆' => 'el-arkasy süýem barmak ýokaryk',
    '🖕' => 'orta barmak',
    '👇' => 'aşagy görkezýän el-arkasy süýem barmak',
    '☝' => 'ýokaryny görkezýän süýem barmak',
    '🫵' => 'tomaşaça gönükdirilen süýem barmak',
    '👍' => 'başam barmak ýokary',
    '👎' => 'başam barmak aşak',
    '✊' => 'galdyrylan ýumruk',
    '👊' => 'gelýän ýumruk',
    '🤛' => 'çepe ýumruk',
    '🤜' => 'saga ýumruk',
    '👏' => 'çapak çalýan eller',
    '🙌' => 'elleri galdyrmak',
    '🫶' => 'ýürek ýasaýan eller',
    '👐' => 'açyk eller',
    '🤲' => 'aýalary birleşdirip ýokary galdyrmak',
    '🤝' => 'el gysyşmak',
    '🙏' => 'birleşen eller',
    '✍' => 'ýazýan el',
    '💅' => 'dyrnak lagy',
    '🤳' => 'selfi',
    '💪' => 'bükülen tirsek',
    '🦾' => 'mehaniki gol',
    '🦿' => 'mehaniki aýak',
    '🦵' => 'aýak',
    '🦶' => 'daban',
    '👂' => 'gulak',
    '🦻' => 'eşidiş enjamly gulak',
    '👃' => 'burun',
    '🧠' => 'beýin',
    '🫀' => 'ýürek',
    '🫁' => 'öýken',
    '🦷' => 'diş',
    '🦴' => 'süňk',
    '👀' => 'gözler',
    '👁' => 'göz',
    '👅' => 'dil',
    '👄' => 'agyz',
    '🫦' => 'dodagy dişlemek',
    '👶' => 'bäbek',
    '🧒' => 'çaga',
    '👦' => 'oglan',
    '👧' => 'gyz',
    '🧑' => 'şahs',
    '👱' => 'adam: sary saçly',
    '👨' => 'erkek',
    '🧔' => 'kişi: sakal',
    '👩' => 'zenan',
    '🧓' => 'gartaşan kişi',
    '👴' => 'goja',
    '👵' => 'garry aýal',
    '🙍' => 'çytyk adam',
    '🙎' => 'gamaşyk adam',
    '🙅' => 'ÝOK ümleýän adam',
    '🙆' => 'Bolýar ümleýän adam',
    '💁' => 'elini açan adam',
    '🙋' => 'elini galdyrýan adam',
    '🧏' => 'ker adam',
    '🙇' => 'tagzym edýän adam',
    '🤦' => 'elini maňlaýyna urýan adam',
    '🤷' => 'egnini gysýan adam',
    '👮' => 'polisiýa işgäri',
    '🕵' => 'aňtawçy',
    '💂' => 'sakçy',
    '🥷' => 'nindzýa',
    '👷' => 'gurluşyk işçisi',
    '🫅' => 'täçli şahs',
    '🤴' => 'şazada',
    '👸' => 'şa gyzy',
    '👳' => 'selleli adam',
    '👲' => 'Hytaý şyrdakly kişi',
    '🧕' => 'ýaglykly aýal',
    '🤵' => 'smokingli kişi',
    '👰' => 'nykaply kişi',
    '🤰' => 'göwreli aýal',
    '🫃' => 'göwreli adam',
    '🫄' => 'göwreli şahs',
    '🤱' => 'emdirmek',
    '👼' => 'bäbek perişde',
    '🎅' => 'Aýaz baba',
    '🤶' => 'Aýaz mama',
    '🦸' => 'supergahryman',
    '🦹' => 'superbetpäl',
    '🧙' => 'jadygöý',
    '🧚' => 'peri',
    '🧛' => 'wampir',
    '🧜' => 'suw adam',
    '🧝' => 'elf',
    '🧞' => 'jyn-arwah',
    '🧟' => 'zombi',
    '🧌' => 'trol',
    '🫈' => 'tüýlek jandar',
    '💆' => 'massaž edilýän adam',
    '💇' => 'saçy kiçeldilýän adam',
    '🚶' => 'ýöräp barýan adam',
    '🧍' => 'dik duran adam',
    '🧎' => 'dyza çöken adam',
    '🏃' => 'ylgap barýan adam',
    '💃' => 'tans edýän zenan',
    '🕺' => 'tans edýän erkek',
    '🕴' => 'kostýum-balakly ýokary galyp barýan kişi',
    '👯' => 'towşan gulakly adamlar',
    '🧖' => 'bug otagyndaky adam',
    '🧗' => 'dyrmaşýan adam',
    '🤺' => 'gylyçlaşýan adam',
    '🏇' => 'çapyşýan at',
    '⛷' => 'lyžaçy',
    '🏂' => 'snoubordçy',
    '🏌' => 'golf oýnaýan adam',
    '🏄' => 'sörf edýän adam',
    '🚣' => 'gaýyk kürekleýän adam',
    '🏊' => 'ýüzüp ýören adam',
    '⛹' => 'topy bökdürýän adam',
    '🏋' => 'agyrlyk göterýän adam',
    '🚴' => 'tigir sürýän adam',
    '🚵' => 'dagda tigir sürýän adam',
    '🤸' => 'ýanyn aşyr atýan adam',
    '🤼' => 'göreş tutýan adamlar',
    '🤽' => 'suw polo oýnaýan adam',
    '🤾' => 'gandbol oýnaýan adam',
    '🤹' => 'hokgabazlyk edýän adam',
    '🧘' => 'lotus oturyşyndaky adam',
    '🛀' => 'wannada suwa düşýän adam',
    '🛌' => 'ýatalgada ýatan adam',
    '👭' => 'el tutuşan aýallar',
    '👫' => 'el tutuşan aýal bilen erkek',
    '👬' => 'el tutuşan erkekler',
    '💏' => 'posa',
    '💑' => 'ýürekli jübüt',
    '🗣' => 'gürleýän kelle',
    '👤' => 'sudury görünýän heýkel',
    '👥' => 'sudury görünýän heýkeller',
    '🫂' => 'gujaklaşýan adamlar',
    '👪' => 'maşgala',
    '👣' => 'aýak yzlary',
    '🫆' => 'barmak yzy',
    '🦰' => 'gyzyl saç',
    '🦱' => 'buýra saç',
    '🦳' => 'ak saç',
    '🦲' => 'kel',
    '🐵' => 'maýmyn ýüz',
    '🐒' => 'maýmyn',
    '🦍' => 'gorilla',
    '🦧' => 'orangutang',
    '🐶' => 'it ýüz',
    '🐕' => 'it',
    '🦮' => 'ýoldaş it',
    '🐩' => 'pudel',
    '🐺' => 'möjek',
    '🦊' => 'tilki',
    '🦝' => 'ýenot',
    '🐱' => 'pişik ýüz',
    '🐈' => 'pişik',
    '🦁' => 'ýolbars',
    '🐯' => 'gaplaň ýüz',
    '🐅' => 'gaplaň',
    '🐆' => 'bars',
    '🐴' => 'at ýüz',
    '🫎' => 'deresygyr',
    '🫏' => 'eşek',
    '🐎' => 'at',
    '🦄' => 'ýekeşah',
    '🦓' => 'zebra',
    '🦌' => 'sugun',
    '🦬' => 'bizon',
    '🐮' => 'sygyr ýüz',
    '🐂' => 'öküz',
    '🐃' => 'gäwmiş ýüz',
    '🐄' => 'sygyr',
    '🐷' => 'doňuz ýüz',
    '🐖' => 'doňuz',
    '🐗' => 'ýekegapan',
    '🐽' => 'doňuz burun',
    '🐏' => 'goç',
    '🐑' => 'goýun',
    '🐐' => 'geçi',
    '🐪' => 'düýe',
    '🐫' => 'iki örküçli düýe',
    '🦙' => 'lama',
    '🦒' => 'žiraf',
    '🐘' => 'pil',
    '🦣' => 'mamont',
    '🦏' => 'kerk',
    '🦛' => 'begemot',
    '🐭' => 'syçan ýüz',
    '🐁' => 'syçan',
    '🐀' => 'alaka',
    '🐹' => 'homýak',
    '🐰' => 'towşan ýüz',
    '🐇' => 'towşan',
    '🐿' => 'alajagözen',
    '🦫' => 'samyr',
    '🦔' => 'oklukirpi',
    '🦇' => 'ýarganat',
    '🐻' => 'aýy',
    '🐨' => 'koala',
    '🐼' => 'panda',
    '🦥' => 'leniwes',
    '🦦' => 'gunduz',
    '🦨' => 'skuns',
    '🦘' => 'kenguru',
    '🦡' => 'torsuk',
    '🐾' => 'penje yzlary',
    '🦃' => 'hindi towugy',
    '🐔' => 'towuk',
    '🐓' => 'horaz',
    '🐣' => 'ýumurtgadan çykýan jüýje',
    '🐤' => 'jüýjejik',
    '🐥' => 'bäri garaýan jüýjejik',
    '🐦' => 'guş',
    '🐧' => 'pingwin',
    '🕊' => 'kepderi',
    '🦅' => 'bürgüt',
    '🦆' => 'ördek',
    '🦢' => 'guw',
    '🦉' => 'baýguş',
    '🦤' => 'dront',
    '🪶' => 'ýelek',
    '🦩' => 'gyzylinjik',
    '🦚' => 'tawus',
    '🦜' => 'totyguş',
    '🪽' => 'ganat',
    '🪿' => 'gaz',
    '🐸' => 'gurbaga',
    '🐊' => 'krokodil',
    '🐢' => 'pyşdyl',
    '🦎' => 'hažžyk',
    '🐍' => 'ýylan',
    '🐲' => 'aždarha ýüz',
    '🐉' => 'aždarha',
    '🦕' => 'zauropod',
    '🦖' => 'Tiranozawr Reks',
    '🐳' => 'suw pürkýän kit',
    '🐋' => 'kit',
    '🐬' => 'delfin',
    '🫍' => 'kosatka',
    '🦭' => 'düwlen',
    '🐟' => 'balyk',
    '🐠' => 'tropiki balyk',
    '🐡' => 'çişýän balyk',
    '🦈' => 'akula',
    '🐙' => 'osminog',
    '🐚' => 'spiral çaňňalak',
    '🪸' => 'merjen',
    '🪼' => 'meduza',
    '🦀' => 'leňňeç',
    '🦞' => 'omar',
    '🦐' => 'krewetka',
    '🦑' => 'kalmar',
    '🦪' => 'ustrisa',
    '🐌' => 'ulitka',
    '🦋' => 'kebelek',
    '🐛' => 'mör-möjek',
    '🐜' => 'garynja',
    '🐝' => 'balary',
    '🪲' => 'tomzak',
    '🐞' => 'kekene',
    '🦗' => 'çybyn',
    '🪳' => 'saçakçy',
    '🕷' => 'möý',
    '🕸' => 'möýüň kerebi',
    '🦂' => 'içýan',
    '🦟' => 'moskito',
    '🪰' => 'siňek',
    '🪱' => 'gurçuk',
    '🦠' => 'mikrop',
    '💐' => 'desse',
    '🌸' => 'ülje güli',
    '💮' => 'ak gül',
    '🪷' => 'lotus',
    '🏵' => 'bezeg güli',
    '🌹' => 'bägül',
    '🥀' => 'sülleren gül',
    '🌺' => 'hytaý bägüli',
    '🌻' => 'günebakar',
    '🌼' => 'açylan gül',
    '🌷' => 'çigildem',
    '🪻' => 'giasint',
    '🌱' => 'şine',
    '🪴' => 'gorşokdaky ösümlik',
    '🌲' => 'hemişe gök öwüsýän agaç',
    '🌳' => 'ýaprakly agaç',
    '🌴' => 'palma agajy',
    '🌵' => 'kaktus',
    '🌾' => 'şaly',
    '🌿' => 'dermanlyk ot',
    '☘' => 'üç ýaprakly',
    '🍀' => 'dört ýaprakly ýorunja',
    '🍁' => 'kerkaw ýapragy',
    '🍂' => 'ýere gaçan ýaprak',
    '🍃' => 'şemala galgaýan ýaprak',
    '🪹' => 'boş höwürtge',
    '🪺' => 'içi ýumurtgaly höwürtge',
    '🍄' => 'kömelek',
    '🪾' => 'ýapraksyz agaç',
    '🍇' => 'üzüm',
    '🍈' => 'gawun',
    '🍉' => 'garpyz',
    '🍊' => 'mandarin',
    '🍋' => 'limon',
    '🍌' => 'banan',
    '🍍' => 'ananas',
    '🥭' => 'mango',
    '🍎' => 'gyzyl alma',
    '🍏' => 'ýaşyl alma',
    '🍐' => 'armyt',
    '🍑' => 'şetdaly',
    '🍒' => 'ülje',
    '🍓' => 'ýertudana',
    '🫐' => 'çernika',
    '🥝' => 'kiwi',
    '🍅' => 'pomidor',
    '🫒' => 'zeýtun',
    '🥥' => 'kokos',
    '🥑' => 'awokado',
    '🍆' => 'badamjan',
    '🥔' => 'ýeralma',
    '🥕' => 'käşir',
    '🌽' => 'mekgejöwen',
    '🌶' => 'ajy garaburç',
    '🫑' => 'bolgar burç',
    '🥒' => 'hyýar',
    '🥬' => 'ýaprakly ýaşyl',
    '🥦' => 'brokkoli',
    '🧄' => 'sarymsak',
    '🧅' => 'sogan',
    '🥜' => 'arahis',
    '🫘' => 'noýba',
    '🌰' => 'kaştan',
    '🫚' => 'zenjebil köki',
    '🫛' => 'nohudyň kösügi',
    '🫜' => 'köki miweli',
    '🍞' => 'çörek',
    '🥐' => 'kruassan',
    '🥖' => 'baget çörek',
    '🫓' => 'ýasy çörek',
    '🥨' => 'krendel',
    '🥯' => 'rogalik',
    '🥞' => 'byzmyk',
    '🧇' => 'wafli',
    '🧀' => 'peýnir bölegi',
    '🍖' => 'süňkli et',
    '🍗' => 'guş budy',
    '🥩' => 'et dilimi',
    '🥓' => 'bekon',
    '🍔' => 'gamburger',
    '🍟' => 'fransuz frisi',
    '🍕' => 'pizza',
    '🌭' => 'hotdog',
    '🥪' => 'sendwiç',
    '🌮' => 'tako',
    '🌯' => 'burrito',
    '🫔' => 'tamale',
    '🥙' => 'dykylan çörek',
    '🧆' => 'falafel',
    '🥚' => 'ýumurtga',
    '🍳' => 'kulinariýa',
    '🥘' => 'ýalpak taba',
    '🍲' => 'naharly gazan',
    '🫕' => 'fondýu',
    '🥣' => 'çemçe bilen şakäse',
    '🥗' => 'ýaşyl işdäaçar',
    '🍿' => 'patrak',
    '🧈' => 'mesge',
    '🧂' => 'duz',
    '🥫' => 'gaplanan iýmit',
    '🍱' => 'bento gutusy',
    '🍘' => 'tüwi kreker',
    '🍙' => 'tüwi tokgasy',
    '🍚' => 'bişirilen tüwi',
    '🍛' => 'karri tüwi',
    '🍜' => 'bugarýan jam',
    '🍝' => 'spagetti',
    '🍠' => 'gowrulan ýeralma',
    '🍢' => 'oden',
    '🍣' => 'suşi',
    '🍤' => 'gowrulan krewetka',
    '🍥' => 'tüweleýli balyk tort',
    '🥮' => 'aý tort',
    '🍡' => 'dango',
    '🥟' => 'hytaý böregi',
    '🥠' => 'bagt kökesi',
    '🥡' => 'iýmit alyp gidilýän guty',
    '🍦' => 'ýumşak buzgaýmak',
    '🍧' => 'syrylan buz',
    '🍨' => 'buzgaýmak',
    '🍩' => 'ponçik',
    '🍪' => 'kökejik',
    '🎂' => 'doglan gün torty',
    '🍰' => 'tortuň dilimi',
    '🧁' => 'käse tort',
    '🥧' => 'tort',
    '🍫' => 'şokolad plitasy',
    '🍬' => 'kemput',
    '🍭' => 'horaz-süýji',
    '🍮' => 'süýji krem',
    '🍯' => 'bally golça',
    '🍼' => 'bäbek çüýşesi',
    '🥛' => 'bir bulgur süýt',
    '☕' => 'gyzgyn içgi',
    '🫖' => 'çäýnek',
    '🍵' => 'käse',
    '🍶' => 'sake',
    '🍾' => 'dykysy atylýan çüýşe',
    '🍷' => 'çakyr bulgury',
    '🍸' => 'kokteýl bulgury',
    '🍹' => 'tropiki içgi',
    '🍺' => 'piwo bokaly',
    '🍻' => 'çakyşýan piwo bokallary',
    '🥂' => 'çakyşýan bulgurlar',
    '🥃' => 'aýna bokal',
    '🫗' => 'guýulýan suwuklyk',
    '🥤' => 'turbajykly stakan',
    '🧋' => 'köpürjikli çaý',
    '🧃' => 'içgi gutusy',
    '🧉' => 'dost',
    '🧊' => 'buz kuby',
    '🥢' => 'çöp',
    '🍽' => 'tabakly çarşak we pyçak',
    '🍴' => 'çarşajyk we pyçak',
    '🥄' => 'çemçe',
    '🔪' => 'aşhana pyçagy',
    '🫙' => 'banka',
    '🏺' => 'küýze',
    '🌍' => 'Ýewropa-Afrikany görkezýän globus',
    '🌎' => 'Amerikany görkezýän globus',
    '🌏' => 'Aziýa-Awstraliýany görkezýän globus',
    '🌐' => 'meridianly globus',
    '🗺' => 'dünýä kartasy',
    '🗾' => 'Ýaponiýa kartasy',
    '🧭' => 'kompas',
    '🏔' => 'üsti garly dag',
    '⛰' => 'dag',
    '🛘' => 'ýer süýşgüni',
    '🌋' => 'ýanardag',
    '🗻' => 'Fuji dagy',
    '🏕' => 'kemping',
    '🏖' => 'saýawanly kenar',
    '🏜' => 'çöl',
    '🏝' => 'çölli ada',
    '🏞' => 'milli seýilgäh',
    '🏟' => 'stadion',
    '🏛' => 'nusgawy bina',
    '🏗' => 'binanyň gurluşygy',
    '🧱' => 'kerpiç',
    '🪨' => 'daş',
    '🪵' => 'agaç',
    '🛖' => 'çatma',
    '🏘' => 'jaýlar',
    '🏚' => 'taşlanan jaý',
    '🏠' => 'jaý',
    '🏡' => 'howluly jaý',
    '🏢' => 'ofis binasy',
    '🏣' => 'Ýapon poçtasy',
    '🏤' => 'poçta',
    '🏥' => 'hassahana',
    '🏦' => 'bank',
    '🏨' => 'myhmanhana',
    '🏩' => 'söýgi myhmanhanasy',
    '🏪' => 'market',
    '🏫' => 'mekdep',
    '🏬' => 'dükan',
    '🏭' => 'zawod',
    '🏯' => 'Ýapon galasy',
    '🏰' => 'gala',
    '💒' => 'toý',
    '🗼' => 'Tokio diňi',
    '🗽' => 'Azatlyk heýkeli',
    '⛪' => 'buthana',
    '🕌' => 'metjit',
    '🛕' => 'indus ybadathanasy',
    '🕍' => 'sinagog',
    '⛩' => 'şinto ybadathanasy',
    '🕋' => 'Käbe',
    '⛲' => 'çüwdürim',
    '⛺' => 'çadyr',
    '🌁' => 'ümürli',
    '🌃' => 'ýyldyzly gije',
    '🏙' => 'şäher görnüşi',
    '🌄' => 'dagyň aňrysyndan günüň dogşy',
    '🌅' => 'günüň dogşy',
    '🌆' => 'agşamara şäher peýzažy',
    '🌇' => 'günüň ýaşmagy',
    '🌉' => 'gijeki köpri',
    '♨' => 'gyzgyn çeşme',
    '🎠' => 'karusel aty',
    '🛝' => 'oýun meýdançasyndaky typançak',
    '🎡' => 'şeýtan çarhy',
    '🎢' => 'Amerikan gorkisi',
    '💈' => 'ala-mula spiral',
    '🎪' => 'sirk çadyry',
    '🚂' => 'lokomotiw',
    '🚃' => 'wagon',
    '🚄' => 'ýokary tizlikli otly',
    '🚅' => 'ok burunly otly',
    '🚆' => 'otly',
    '🚇' => 'metro',
    '🚈' => 'ýeňil metro',
    '🚉' => 'menzil',
    '🚊' => 'tramwaý',
    '🚝' => 'monorels',
    '🚞' => 'dag demirýoly',
    '🚋' => 'tramwaý wagony',
    '🚌' => 'awtobus',
    '🚍' => 'gelýän awtobus',
    '🚎' => 'trolleýbus',
    '🚐' => 'mikroawtobus',
    '🚑' => 'tiz kömek ulagy',
    '🚒' => 'ýangyn awtoulagy',
    '🚓' => 'polisiýa awtoulagy',
    '🚔' => 'gelýän polisiýa awtoulagy',
    '🚕' => 'taksi',
    '🚖' => 'gelýän taksi',
    '🚗' => 'awtomobil',
    '🚘' => 'gelýän awtomobil',
    '🚙' => 'ýeňil sport awtoulagy',
    '🛻' => 'pikap ulagy',
    '🚚' => 'awtofurgon',
    '🚛' => 'ýük awtoulagy',
    '🚜' => 'traktor',
    '🏎' => 'ýaryş awtoulagy',
    '🏍' => 'motosikl',
    '🛵' => 'moto-skuter',
    '🦽' => 'el maýyp arabasy',
    '🦼' => 'motorly maýyp arabasy',
    '🛺' => 'awtorikşa',
    '🚲' => 'welosiped',
    '🛴' => 'depgili skuter',
    '🛹' => 'skeýtbord',
    '🛼' => 'tigirli konki',
    '🚏' => 'awtobus duralgasy',
    '🛣' => 'ulag ýoly',
    '🛤' => 'demir ýol relsi',
    '🛢' => 'nebit çelegi',
    '⛽' => 'ýangyç nasosy',
    '🛞' => 'tigir',
    '🚨' => 'polisiýa awtoulagy çyrasy',
    '🚥' => 'kese ýolyşyk',
    '🚦' => 'dik ýolyşyk',
    '🛑' => 'dur belgisi',
    '🚧' => 'gurluşyk',
    '⚓' => 'labyr',
    '🛟' => 'halas ediş tegelegi',
    '⛵' => 'ýelkenli gämi',
    '🛶' => 'kanoe',
    '🚤' => 'tiz kater',
    '🛳' => 'ýolagçy gämisi',
    '⛴' => 'parom',
    '🛥' => 'motorly gaýyk',
    '🚢' => 'gämi',
    '✈' => 'uçar',
    '🛩' => 'kiçi uçar',
    '🛫' => 'uçaryň ugramagy',
    '🛬' => 'uçaryň gelmegi',
    '🪂' => 'paraşýut',
    '💺' => 'ýer',
    '🚁' => 'dikuçar',
    '🚟' => 'asma demirýol',
    '🚠' => 'tanap ýol',
    '🚡' => 'howa tramwaýy',
    '🛰' => 'hemra',
    '🚀' => 'raketa',
    '🛸' => 'uçýan tabak',
    '🛎' => 'çagyryş jaňy',
    '🧳' => 'goş',
    '⌛' => 'çägeli sagat boldy',
    '⏳' => 'çägeli sagat bolmady',
    '⌚' => 'goşar sagady',
    '⏰' => 'oýaryjy sagat',
    '⏱' => 'sekundomer',
    '⏲' => 'wagt belleýji sagat',
    '🕰' => 'diregli sagat',
    '🕛' => 'sagat on iki',
    '🕧' => 'biriň ýary',
    '🕐' => 'sagat bir',
    '🕜' => 'ikiniň ýary',
    '🕑' => 'sagat iki',
    '🕝' => 'üçüň ýary',
    '🕒' => 'sagat üç',
    '🕞' => 'dördüň ýary',
    '🕓' => 'sagat dört',
    '🕟' => 'bäşiň ýary',
    '🕔' => 'sagat bäş',
    '🕠' => 'altynyň ýary',
    '🕕' => 'sagat alty',
    '🕡' => 'ýediniň ýary',
    '🕖' => 'sagat ýedi',
    '🕢' => 'sekiziň ýary',
    '🕗' => 'sagat sekiz',
    '🕣' => 'dokuzyň ýary',
    '🕘' => 'sagat dokuz',
    '🕤' => 'onuň ýary',
    '🕙' => 'sagat on',
    '🕥' => 'on biriň ýary',
    '🕚' => 'sagat on bir',
    '🕦' => 'on ikiniň ýary',
    '🌑' => 'täze aý',
    '🌒' => 'ýaş aý',
    '🌓' => 'birinji çärýek aý',
    '🌔' => 'ulalýan aý',
    '🌕' => 'dolan aý',
    '🌖' => 'kiçelýän aý',
    '🌗' => 'soňky çärýek aý',
    '🌘' => 'köne aý',
    '🌙' => 'ýarym aý',
    '🌚' => 'täze aý ýüz',
    '🌛' => 'ýüzli birinji çärýek aý',
    '🌜' => 'ýüzli soňky çärýek aý',
    '🌡' => 'termometr',
    '☀' => 'güneş',
    '🌝' => 'ýüzli dolan aý',
    '🌞' => 'ýüzli güneş',
    '🪐' => 'halkaly planeta',
    '⭐' => 'ýyldyz',
    '🌟' => 'lowurdaýan ýyldyz',
    '🌠' => 'süýnýän ýyldyz',
    '🌌' => 'Akmaýanyň ýoly',
    '☁' => 'bulut',
    '⛅' => 'buludyň aňrysyndaky güneş',
    '⛈' => 'ýyldyrymly we ýagyşly bulut',
    '🌤' => 'kiçi buludyň aňrysyndaky güneş',
    '🌥' => 'uly buludyň aňrysyndaky güneş',
    '🌦' => 'ýagyşly buludyň aňrysyndaky güneş',
    '🌧' => 'ýagyşly bulut',
    '🌨' => 'garly bulut',
    '🌩' => 'ýyldyrymly bulut',
    '🌪' => 'tornado',
    '🌫' => 'ümür',
    '🌬' => 'şemal ýüz',
    '🌀' => 'siklon',
    '🌈' => 'älemgoşar',
    '🌂' => 'ýapyk saýawan',
    '☂' => 'saýawan',
    '☔' => 'ýagyş damjaly saýawan',
    '⛱' => 'ýerde duran saýawan',
    '⚡' => 'ýokary güýjenme',
    '❄' => 'gar tozgasy',
    '☃' => 'gar adam',
    '⛄' => 'garsyz gar adam',
    '☄' => 'kometa',
    '🔥' => 'ýangyn',
    '💧' => 'damjajyk',
    '🌊' => 'suw tolkuny',
    '🎃' => 'otly kädi',
    '🎄' => 'täze ýyl agajy',
    '🎆' => 'feýerwerk',
    '🎇' => 'uçgun çykaryjy',
    '🧨' => 'salýut',
    '✨' => 'uçgunlar',
    '🎈' => 'şar',
    '🎉' => 'şüweleň parkyldawajy',
    '🎊' => 'konfetti topy',
    '🎋' => 'tanabata agajy',
    '🎍' => 'sosna bezegi',
    '🎎' => 'ýapon gurjaklary',
    '🎏' => 'balyk lenta',
    '🎐' => 'hytaý jaňjagazy',
    '🎑' => 'aý synlaýyş dabarasy',
    '🧧' => 'gyzyl bukja',
    '🎀' => 'lenta',
    '🎁' => 'dolanylgy sowgat',
    '🎗' => 'hatyra lenta',
    '🎟' => 'giriş petekleri',
    '🎫' => 'petek',
    '🎖' => 'harby medal',
    '🏆' => 'baýrak',
    '🏅' => 'sport medaly',
    '🥇' => '1-nji ornuň medaly',
    '🥈' => '2-nji ornuň medaly',
    '🥉' => '3-nji ornuň medaly',
    '⚽' => 'futbol pökgüsi',
    '⚾' => 'beýsbol',
    '🥎' => 'softbol',
    '🏀' => 'basketbol',
    '🏐' => 'woleýbol',
    '🏈' => 'amerikan futboly',
    '🏉' => 'regbi',
    '🎾' => 'tennis',
    '🥏' => 'uçýan disk',
    '🎳' => 'bouling',
    '🏏' => 'kriket oýny',
    '🏑' => 'gök otuň üstünde oýnalýan hokkeý',
    '🏒' => 'buz hokkeýi',
    '🥍' => 'lakros',
    '🏓' => 'stol tennisi',
    '🏸' => 'badminton',
    '🥊' => 'boks elligi',
    '🥋' => 'söweş sungaty formasy',
    '🥅' => 'derweze',
    '⛳' => 'deşige dikilen baýdak',
    '⛸' => 'buz konkisi',
    '🎣' => 'çeňňek taýagy',
    '🤿' => 'çümüş maskasy',
    '🎽' => 'ýeňsiz maýka',
    '🎿' => 'lyža',
    '🛷' => 'sani',
    '🥌' => 'kýorling daşy',
    '🎯' => 'dürs urgy',
    '🪀' => 'ýo-ýo',
    '🪁' => 'batbörek',
    '🔫' => 'suw sapançasy',
    '🎱' => '8 bilýard topy',
    '🔮' => 'hrustal şar',
    '🪄' => 'jadyly taýajyk',
    '🎮' => 'wideo oýun',
    '🕹' => 'joýstik',
    '🎰' => 'oýun awtomaty',
    '🎲' => 'oýun kubigi',
    '🧩' => 'tapmaça bölegi',
    '🧸' => 'oýunjak aýy',
    '🪅' => 'pinýata',
    '🪩' => 'aýna şar',
    '🪆' => 'matrýoşkalar',
    '♠' => 'gara kart',
    '♥' => 'alma kart',
    '♦' => 'kerpiç kart',
    '♣' => 'jydak kart',
    '♟' => 'küşt pyýadasy',
    '🃏' => 'joker',
    '🀄' => 'mahjong gyzyl aždarha',
    '🎴' => 'gülli kart',
    '🎭' => 'ýerine ýetiriş sungaty',
    '🖼' => 'çarçuwaly surat',
    '🎨' => 'suratkeş palitrasy',
    '🧵' => 'ýüp',
    '🪡' => 'tikin iňňesi',
    '🧶' => 'ýumak',
    '🪢' => 'düwün',
    '👓' => 'äýnek',
    '🕶' => 'gara äýnek',
    '🥽' => 'goraýjy äýnek',
    '🥼' => 'barlaghana halady',
    '🦺' => 'halas ediş gursakçasy',
    '👔' => 'boýunbagy',
    '👕' => 'futbolka',
    '👖' => 'jinsi',
    '🧣' => 'şarf',
    '🧤' => 'ellik',
    '🧥' => 'palto',
    '🧦' => 'jorap',
    '👗' => 'eşik',
    '👘' => 'kimono',
    '🥻' => 'sari',
    '🩱' => 'bitewi kupalnik',
    '🩲' => 'gysga türsük',
    '🩳' => 'şorty',
    '👙' => 'bikini',
    '👚' => 'aýal eşikleri',
    '🪭' => 'eplenýän el ýelpewajy',
    '👛' => 'gapjyk',
    '👜' => 'el sumka',
    '👝' => 'klaç sumka',
    '🛍' => 'söwda goşhaltalary',
    '🎒' => 'mekdep goşhaltasy',
    '🩴' => 'şypbyk',
    '👞' => 'erkek aýakgaby',
    '👟' => 'ylgaw aýakgaby',
    '🥾' => 'ýöriş botinkasy',
    '🥿' => 'tekiz köwüş',
    '👠' => 'ökjeli köwüş',
    '👡' => 'aýal çepegi',
    '🩰' => 'balet köwşi',
    '👢' => 'aýal ädigi',
    '🪮' => 'saçgysgyç',
    '👑' => 'täç',
    '👒' => 'aýal şlýapasy',
    '🎩' => 'çüri şlýapa',
    '🎓' => 'uçurym papagy',
    '🧢' => 'kölegelikli papak',
    '🪖' => 'harby kaska',
    '⛑' => 'halas edijiniň kaskasy',
    '📿' => 'tesbi',
    '💄' => 'pomada',
    '💍' => 'ýüzük',
    '💎' => 'gymmatbaha daş',
    '🔇' => 'sesi ýapyk dinamik',
    '🔈' => 'pes sesli dinamik',
    '🔉' => 'orta sesli dinamik',
    '🔊' => 'gaty sesli dinamik',
    '📢' => 'dinamik',
    '📣' => 'megafon',
    '📯' => 'poçta kerneýi',
    '🔔' => 'jaň',
    '🔕' => 'üsti çyzyk jaň',
    '🎼' => 'partitura',
    '🎵' => 'nota',
    '🎶' => 'notalar',
    '🎙' => 'studiýa mikrofony',
    '🎚' => 'dereje süýşüriji',
    '🎛' => 'dolandyryş nurbatlary',
    '🎤' => 'mikrofon',
    '🎧' => 'nauşnik',
    '📻' => 'radio',
    '🎷' => 'saksofon',
    '🎺' => 'surnaý',
    '🪊' => 'trombon',
    '🪗' => 'akkordeon',
    '🎸' => 'gitara',
    '🎹' => 'saz klawiaturasy',
    '🎻' => 'skripka',
    '🪕' => 'banjo',
    '🥁' => 'deprek',
    '🪘' => 'uzyn deprek',
    '🪇' => 'marakas',
    '🪈' => 'tüýdük',
    '🪉' => 'arfa',
    '📱' => 'mobil telefon',
    '📲' => 'okly mobil telefon',
    '☎' => 'telefon trubkasy',
    '📞' => 'trubka',
    '📟' => 'peýjer',
    '📠' => 'faks apparaty',
    '🔋' => 'batareý',
    '🪫' => 'batareý pes',
    '🔌' => 'tok wilkasy',
    '💻' => 'noutbuk',
    '🖥' => 'iş stoly kompýuteri',
    '🖨' => 'printer',
    '⌨' => 'klawiatura',
    '🖱' => 'kompýuteriň syçanjygy',
    '🖲' => 'syçanjygyň topy',
    '💽' => 'kompýuter diski',
    '💾' => 'çeýe disk',
    '💿' => 'optiki disk',
    '📀' => 'DVD',
    '🧮' => 'çot',
    '🎥' => 'kinokamera',
    '🎞' => 'filmden kadrlar',
    '📽' => 'film proýektory',
    '🎬' => 'hlopuşka',
    '📺' => 'telewizor',
    '📷' => 'kamera',
    '📸' => 'wspyşkaly kamera',
    '📹' => 'wideokamera',
    '📼' => 'wideokasseta',
    '🔍' => 'çepe egilen lupa',
    '🔎' => 'saga egilen lupa',
    '🕯' => 'şem',
    '💡' => 'lampa',
    '🔦' => 'fonar',
    '🏮' => 'gyzyl hytaý fonarjygy',
    '🪔' => 'diýa çyrasy',
    '📔' => 'bezelen gapakly depderçe',
    '📕' => 'ýapyk kitap',
    '📖' => 'açyk kitap',
    '📗' => 'ýaşyl kitap',
    '📘' => 'gök kitap',
    '📙' => 'mämişi kitap',
    '📚' => 'kitaplar',
    '📓' => 'depderçe',
    '📒' => 'buhgalter kitaby',
    '📃' => 'düýrümli sahypa',
    '📜' => 'düýrlem',
    '📄' => 'açyk sahypa',
    '📰' => 'gazet',
    '🗞' => 'düýrlenen gazet',
    '📑' => 'bellikçe tablary',
    '🔖' => 'bellikçe',
    '🏷' => 'tagma',
    '🪙' => 'şaýlyk',
    '💰' => 'pully halta',
    '🪎' => 'hazyna sandygy',
    '💴' => 'ýen banknot',
    '💵' => 'dollar banknot',
    '💶' => 'ýewro banknot',
    '💷' => 'funt sterling banknot',
    '💸' => 'ganatly pul',
    '💳' => 'kredit karty',
    '🧾' => 'töleg haty',
    '💹' => 'ýenli köpelýän grafik',
    '✉' => 'bukja',
    '📧' => 'e-poçta',
    '📨' => 'gelýän konwert',
    '📩' => 'okly konwert',
    '📤' => 'gidýän mejime',
    '📥' => 'gelýän mejime',
    '📦' => 'paket',
    '📫' => 'galdyrylan baýdakly ýapyk poçta gutusy',
    '📪' => 'ýatyrylan baýdakly ýapyk poçta gutusy',
    '📬' => 'galdyrylan baýdakly açyk poçta gutusy',
    '📭' => 'ýatyrylan baýdakly açyk poçta gutusy',
    '📮' => 'poçta gutusy',
    '🗳' => 'býulletenli ses beriş gutusy',
    '✏' => 'galam',
    '✒' => 'gara uç',
    '🖋' => 'doldurylýan ruçka',
    '🖊' => 'ruçka',
    '🖌' => 'kist',
    '🖍' => 'flomaster',
    '📝' => 'ýatlama',
    '💼' => 'portfel',
    '📁' => 'faýl bukjasy',
    '📂' => 'açyk faýl bukjasy',
    '🗂' => 'kart indeksi bölüjileri',
    '📅' => 'senenama',
    '📆' => 'ýyrtylýan senenama',
    '🗒' => 'spirally depderçe',
    '🗓' => 'spirally senenama',
    '📇' => 'kart indeksi',
    '📈' => 'köpelýän grafik',
    '📉' => 'azalýan grafik',
    '📊' => 'setir diagramma',
    '📋' => 'bildiriş tagtasy',
    '📌' => 'düwme',
    '📍' => 'tokga iňňejik',
    '📎' => 'skrepka',
    '🖇' => 'baglanan skrepkalar',
    '📏' => 'göni çyzgyç',
    '📐' => 'üçburç çyzgyç',
    '✂' => 'gaýçy',
    '🗃' => 'kart faýl gutusy',
    '🗄' => 'faýl çekmesi',
    '🗑' => 'zibil bedresi',
    '🔒' => 'gulply',
    '🔓' => 'gulpy açyk',
    '🔏' => 'ruçkaly gulply',
    '🔐' => 'açarly gulply',
    '🔑' => 'açar',
    '🗝' => 'köne açar',
    '🔨' => 'çekiç',
    '🪓' => 'palta',
    '⛏' => 'çüý goparýan',
    '⚒' => 'çekiç we çüý goparýan',
    '🛠' => 'çekiç we nurbat açar',
    '🗡' => 'hanjar',
    '⚔' => 'atanaklaýyn gylyçlar',
    '💣' => 'bomba',
    '🪃' => 'bumerang',
    '🏹' => 'ok-ýaý',
    '🛡' => 'galkan',
    '🪚' => 'agaç byçgysy',
    '🔧' => 'gaýka açary',
    '🪛' => 'otwýortka',
    '🔩' => 'bolt-nurbat',
    '⚙' => 'dişli',
    '🗜' => 'gysgyç',
    '⚖' => 'deňagramlylyk terezisi',
    '🦯' => 'ak hasa',
    '🔗' => 'bag',
    '⛓' => 'zynjyrlar',
    '🪝' => 'ilgençek',
    '🧰' => 'gural gutusy',
    '🧲' => 'magnit',
    '🪜' => 'merdiwan',
    '🪏' => 'pilçe',
    '⚗' => 'suwuklyk gaby',
    '🧪' => 'probirka',
    '🧫' => 'petri çaşkasy',
    '🧬' => 'dnk',
    '🔬' => 'mikroskop',
    '🔭' => 'teleskop',
    '📡' => 'hemra antennasy',
    '💉' => 'şpris',
    '🩸' => 'gan damjasy',
    '💊' => 'gerdejik',
    '🩹' => 'ýelmeşiji plastyr',
    '🩼' => 'pişek',
    '🩺' => 'stetoskop',
    '🩻' => 'rentgen',
    '🚪' => 'gapy',
    '🛗' => 'lift',
    '🪞' => 'aýna',
    '🪟' => 'penjire',
    '🛏' => 'ýatalga',
    '🛋' => 'diwan we çyra',
    '🪑' => 'oturgyç',
    '🚽' => 'hajathana',
    '🪠' => 'plunžer',
    '🚿' => 'duş',
    '🛁' => 'wanna',
    '🪤' => 'gapan',
    '🪒' => 'päki',
    '🧴' => 'losýon çüýşesi',
    '🧷' => 'iňňebagjyk',
    '🧹' => 'sübse',
    '🧺' => 'sebet',
    '🧻' => 'kagyz rulony',
    '🪣' => 'bedre',
    '🧼' => 'sabyn',
    '🫧' => 'köpükler',
    '🪥' => 'diş çotga',
    '🧽' => 'moçalka',
    '🧯' => 'ýangyn söndüriji',
    '🛒' => 'söwda merkezi arabajygy',
    '🚬' => 'çilim',
    '⚰' => 'tabyt',
    '🪦' => 'mazar daşy',
    '⚱' => 'jynaza gorküýzesi',
    '🧿' => 'göz monjuk',
    '🪬' => 'hamsa',
    '🗿' => 'moai',
    '🪧' => 'plakat',
    '🪪' => 'şahsyýetnama',
    '🏧' => 'bankomat belgisi',
    '🚮' => 'zibili bedrä taşla belgisi',
    '🚰' => 'içilýän suw',
    '♿' => 'maýyp arabajygy simwoly',
    '🚹' => 'erkekler otagy',
    '🚺' => 'aýallar otagy',
    '🚻' => 'tualet',
    '🚼' => 'bäbek nyşany',
    '🚾' => 'unitaz',
    '🛂' => 'pasport barlagy',
    '🛃' => 'gümrük nokady',
    '🛄' => 'goş almak',
    '🛅' => 'galdyrylan goş',
    '⚠' => 'duýduryş',
    '🚸' => 'çagalar geçýär',
    '⛔' => 'girmek gadagan',
    '🚫' => 'gadagan',
    '🚳' => 'welosiped gadagan',
    '🚭' => 'çilim çekmek gadagan',
    '🚯' => 'zibil taşlamak gadagan',
    '🚱' => 'içilmeýän suw',
    '🚷' => 'pyýadalar gadagan',
    '📵' => 'mobil telefonlar gadagan',
    '🔞' => 'on sekiz ýaşamadyklara gadagan',
    '☢' => 'radioaktiw',
    '☣' => 'biologik howp',
    '⬆' => 'ýokary ok',
    '↗' => 'ýokary-saga ok',
    '➡' => 'saga ok',
    '↘' => 'aşak-saga ok',
    '⬇' => 'aşak ok',
    '↙' => 'aşak-çepe ok',
    '⬅' => 'çepe ok',
    '↖' => 'ýokary-çepe ok',
    '↕' => 'ýokary-aşak ok',
    '↔' => 'çepe-saga ok',
    '↩' => 'saga ok, çepe egrelýän',
    '↪' => 'çepe ok, saga egrelýän',
    '⤴' => 'saga ok, ýokary egrelýän',
    '⤵' => 'saga ok, aşak egrelýän',
    '🔃' => 'sagadyň ugruna dik oklar',
    '🔄' => 'sagadyň tersine oklar düwmesi',
    '🔙' => 'BACK oky',
    '🔚' => 'END oky',
    '🔛' => 'ON! oky',
    '🔜' => 'SOON oky',
    '🔝' => 'TOP oky',
    '🛐' => 'ybadat ýeri',
    '⚛' => 'atom nyşany',
    '🕉' => 'om',
    '✡' => 'Dawudyň ýyldyzy',
    '☸' => 'darmanyň çarhy',
    '☯' => 'ýin ýang',
    '✝' => 'katolik haçy',
    '☦' => 'prawoslaw haçy',
    '☪' => 'ýyldyz we ýarymaý',
    '☮' => 'parahatçylygyň nyşany',
    '🕎' => 'menora',
    '🔯' => 'nokatly altyburç ýyldyz',
    '🪯' => 'khanda',
    '♈' => 'Guzy',
    '♉' => 'Sowur',
    '♊' => 'Ekizler',
    '♋' => 'Seretan',
    '♌' => 'Şir',
    '♍' => 'Sünbüle',
    '♎' => 'Mizan',
    '♏' => 'Akrap',
    '♐' => 'Kowus',
    '♑' => 'Owlak',
    '♒' => 'Gowa',
    '♓' => 'Hut',
    '⛎' => 'Ýylançy',
    '🔀' => 'garyşyk düwmesi',
    '🔁' => 'gaýtala düwmesi',
    '🔂' => 'ýeke gaýtala düwmesi',
    '▶' => 'aýtdyr düwmesi',
    '⏩' => 'öňe sara düwmesi',
    '⏭' => 'indiki ýodajyk düwmesi',
    '⏯' => 'aýtdyr ýa-da sägindir düwmesi',
    '◀' => 'tersine düwmesi',
    '⏪' => 'yza sara düwmesi',
    '⏮' => 'soňky ýodajyk düwmesi',
    '🔼' => 'ýokary düwmesi',
    '⏫' => 'ýokary sara düwmesi',
    '🔽' => 'aşak düwmesi',
    '⏬' => 'aşak sara düwmesi',
    '⏸' => 'sägindir düwmesi',
    '⏹' => 'sakla düwmesi',
    '⏺' => 'ýazdyr düwmesi',
    '⏏' => 'çykar düwmesi',
    '🎦' => 'kinoteatr',
    '🔅' => 'öçügsi düwmesi',
    '🔆' => 'ýagty düwmesi',
    '📶' => 'antenna zolaklary',
    '🛜' => 'simsiz',
    '📳' => 'titreme tertibi',
    '📴' => 'mobil telefon ýapyk',
    '♀' => 'aýal-gyz nyşany',
    '♂' => 'erkek nyşany',
    '⚧' => 'transgender nyşany',
    '✖' => 'köpeltmek',
    '➕' => 'goşmak',
    '➖' => 'aýyrmak',
    '➗' => 'bölmek',
    '🟰' => 'ýogyn deňdir belgisi',
    '♾' => 'tükeniksizlik',
    '‼' => 'goşa ýüzlenme belgisi',
    '⁉' => 'ýüzlenme sorag belgisi',
    '❓' => 'gyzyl sorag belgisi',
    '❔' => 'ak sorag belgisi',
    '❕' => 'ak ýüzlenme belgisi',
    '❗' => 'gyzyl ýüzlenme belgisi',
    '〰' => 'tolkunly kese çyzyk',
    '💱' => 'walýuta çalşygy',
    '💲' => 'goýy dollar belgisi',
    '⚕' => 'lukmançylygyň nyşany',
    '♻' => 'gaýtadan işlemek nyşany',
    '⚜' => 'iris',
    '🔱' => 'üçdiş emblemasy',
    '📛' => 'at tarketkasy',
    '🔰' => 'öwrenjeler üçin ýaponça nyşany',
    '⭕' => 'içi boş gyzyl tegelek',
    '✅' => 'barlag belligi düwmesi',
    '☑' => 'barlag bellikli barlag gutusy',
    '✔' => 'barlag belligi',
    '❌' => 'atanak belgisi',
    '❎' => 'atanak belgili düwme',
    '➰' => 'buýra halka',
    '➿' => 'goşa buýra halka',
    '〽' => 'bölek çalşyk belgisi',
    '✳' => 'bellijek',
    '✴' => 'sekiz tikenli ýyldyzjyk',
    '❇' => 'uçgun',
    '™' => 'söwda belgisi',
    '🫟' => 'syçratgy',
    '🔠' => 'latyn baş harp girizme',
    '🔡' => 'latyn setir harp girizme',
    '🔢' => 'san girizme',
    '🔣' => 'simwol girizme',
    '🔤' => 'latyn harp girizme',
    '🅰' => 'A düwmesi (gan topary)',
    '🆎' => 'AB düwmesi (gan topary)',
    '🅱' => 'B düwmesi (gan topary)',
    '🆑' => 'CL düwmesi',
    '🆒' => 'COOL düwmesi',
    '🆓' => 'FREE düwmesi',
    'ℹ' => 'maglumat',
    '🆔' => 'ID düwmesi',
    'Ⓜ' => 'halkaly M',
    '🆕' => 'NEW düwmesi',
    '🆖' => 'NG düwmesi',
    '🅾' => 'O düwmesi (gan topary)',
    '🆗' => 'OK düwmesi',
    '🅿' => 'P düwmesi',
    '🆘' => 'SOS düwmesi',
    '🆙' => 'UP! düwmesi',
    '🆚' => 'VS düwmesi',
    '🈁' => 'ýaponça "şu ýerde" düwmesi',
    '🈂' => 'ýaponça "hyzmat tölegi" düwmesi',
    '🈷' => 'ýaponça "aýlyk möçber" düwmesi',
    '🈶' => 'ýaponça "mugt däl" düwmesi',
    '🈯' => 'ýaponça "bronlanan" düwmesi',
    '🉐' => 'ýaponça "alyş-çalyş" düwmesi',
    '🈹' => 'ýaponça "arzanladyş" düwmesi',
    '🈚' => 'ýaponça "mugt" düwmesi',
    '🈲' => 'ýaponça "gadagan" düwmesi',
    '🉑' => 'ýaponça "kabul ederlik" düwmesi',
    '🈸' => 'ýaponça "ýüz tutmak" düwmesi',
    '🈴' => 'ýaponça "kanagatlanarly baha" düwmesi',
    '🈳' => 'ýaponça "boş iş orny" düwmesi',
    '㊗' => 'ýaponça "gutlaglar" düwmesi',
    '㊙' => 'ýaponça "gizlin" düwmesi',
    '🈺' => 'ýaponça "biznese açyk" düwmesi',
    '🈵' => 'ýaponça "boş iş orny ýok" düwmesi',
    '🔴' => 'gyzyl halka',
    '🟠' => 'narynç tegelek',
    '🟡' => 'sary tegelek',
    '🟢' => 'ýaşyl tegelek',
    '🔵' => 'gök halka',
    '🟣' => 'melewşe tegelek',
    '🟤' => 'goňur tegelek',
    '⚫' => 'gara halka',
    '⚪' => 'ak halka',
    '🟥' => 'gyzyl inedördül',
    '🟧' => 'narynç inedördül',
    '🟨' => 'sary inedördül',
    '🟩' => 'ýaşyl inedördül',
    '🟦' => 'gök inedördül',
    '🟪' => 'melewşe inedördül',
    '🟫' => 'goňur inedördül',
    '⬛' => 'gara uly inedördül',
    '⬜' => 'ak uly inedördül',
    '◼' => 'gara ortaça inedördül',
    '◻' => 'ak ortaça inedördül',
    '◾' => 'gara orta-kiçi inedördül',
    '◽' => 'ak orta-kiçi inedördül',
    '▪' => 'gara kiçi inedördül',
    '▫' => 'ak kiçi inedördül',
    '🔶' => 'uly mämişi pişme',
    '🔷' => 'uly gök pişme',
    '🔸' => 'kiçi mämişi pişme',
    '🔹' => 'kiçi gök pişme',
    '🔺' => 'ýokaryk gyzyl üçburç',
    '🔻' => 'aşak gyzyl üçburç',
    '💠' => 'nokatly pişme',
    '🔘' => 'radio düwmesi',
    '🔳' => 'ak inedördül düwme',
    '🔲' => 'gara inedördül düwme',
    '🏁' => 'ala baýdak',
    '🚩' => 'üçburç baýdak',
    '🎌' => 'atanak baýdaklar',
    '🏴' => 'gara baýdak',
    '🏳' => 'ak baýdak',
];
