<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'пољубац: одрасла особа, одрасла особа, свијетла кожа и средње свијетла кожа',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'пољубац: одрасла особа, одрасла особа, свијетла кожа и ни свијетла ни тамна кожа',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'пољубац: одрасла особа, одрасла особа, свијетла кожа и средње тамна кожа',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'пољубац: одрасла особа, одрасла особа, свијетла кожа и тамна кожа',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'пољубац: одрасла особа, одрасла особа, средње свијетла кожа и свијетла кожа',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'пољубац: одрасла особа, одрасла особа, средње свијетла кожа и ни свијетла ни тамна кожа',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'пољубац: одрасла особа, одрасла особа, средње свијетла кожа и средње тамна кожа',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'пољубац: одрасла особа, одрасла особа, средње свијетла кожа и тамна кожа',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'пољубац: одрасла особа, одрасла особа, ни свијетла ни тамна кожа и свијетла кожа',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'пољубац: одрасла особа, одрасла особа, ни свијетла ни тамна кожа и средње свијетла кожа',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'пољубац: одрасла особа, одрасла особа, ни свијетла ни тамна кожа и средње тамна кожа',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'пољубац: одрасла особа, одрасла особа, ни свијетла ни тамна кожа и тамна кожа',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'пољубац: одрасла особа, одрасла особа, средње тамна кожа и свијетла кожа',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'пољубац: одрасла особа, одрасла особа, средње тамна кожа и средње свијетла кожа',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'пољубац: одрасла особа, одрасла особа, средње тамна кожа и ни свијетла ни тамна кожа',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'пољубац: одрасла особа, одрасла особа, средње тамна кожа и тамна кожа',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'пољубац: одрасла особа, одрасла особа, тамна кожа и свијетла кожа',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'пољубац: одрасла особа, одрасла особа, тамна кожа и средње свијетла кожа',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'пољубац: одрасла особа, одрасла особа, тамна кожа и ни свијетла ни тамна кожа',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'пољубац: одрасла особа, одрасла особа, тамна кожа и средње тамна кожа',
    '👨🏻‍❤‍💋‍👨🏻' => 'пољубац: мушкарац, мушкарац и свијетла кожа',
    '👨🏻‍❤‍💋‍👨🏼' => 'пољубац: мушкарац, мушкарац, свијетла кожа и средње свијетла кожа',
    '👨🏻‍❤‍💋‍👨🏽' => 'пољубац: мушкарац, мушкарац, свијетла кожа и ни свијетла ни тамна кожа',
    '👨🏻‍❤‍💋‍👨🏾' => 'пољубац: мушкарац, мушкарац, свијетла кожа и средње тамна кожа',
    '👨🏻‍❤‍💋‍👨🏿' => 'пољубац: мушкарац, мушкарац, свијетла кожа и тамна кожа',
    '👨🏼‍❤‍💋‍👨🏻' => 'пољубац: мушкарац, мушкарац, средње свијетла кожа и свијетла кожа',
    '👨🏼‍❤‍💋‍👨🏼' => 'пољубац: мушкарац, мушкарац и средње свијетла кожа',
    '👨🏼‍❤‍💋‍👨🏽' => 'пољубац: мушкарац, мушкарац, средње свијетла кожа и ни свијетла ни тамна кожа',
    '👨🏼‍❤‍💋‍👨🏾' => 'пољубац: мушкарац, мушкарац, средње свијетла кожа и средње тамна кожа',
    '👨🏼‍❤‍💋‍👨🏿' => 'пољубац: мушкарац, мушкарац, средње свијетла кожа и тамна кожа',
    '👨🏽‍❤‍💋‍👨🏻' => 'пољубац: мушкарац, мушкарац, ни свијетла ни тамна кожа и свијетла кожа',
    '👨🏽‍❤‍💋‍👨🏼' => 'пољубац: мушкарац, мушкарац, ни свијетла ни тамна кожа и средње свијетла кожа',
    '👨🏽‍❤‍💋‍👨🏽' => 'пољубац: мушкарац, мушкарац и ни свијетла ни тамна кожа',
    '👨🏽‍❤‍💋‍👨🏾' => 'пољубац: мушкарац, мушкарац, ни свијетла ни тамна кожа и средње тамна кожа',
    '👨🏽‍❤‍💋‍👨🏿' => 'пољубац: мушкарац, мушкарац, ни свијетла ни тамна кожа и тамна кожа',
    '👨🏾‍❤‍💋‍👨🏻' => 'пољубац: мушкарац, мушкарац, средње тамна кожа и свијетла кожа',
    '👨🏾‍❤‍💋‍👨🏼' => 'пољубац: мушкарац, мушкарац, средње тамна кожа и средње свијетла кожа',
    '👨🏾‍❤‍💋‍👨🏽' => 'пољубац: мушкарац, мушкарац, средње тамна кожа и ни свијетла ни тамна кожа',
    '👨🏾‍❤‍💋‍👨🏾' => 'пољубац: мушкарац, мушкарац и средње тамна кожа',
    '👨🏾‍❤‍💋‍👨🏿' => 'пољубац: мушкарац, мушкарац, средње тамна кожа и тамна кожа',
    '👨🏿‍❤‍💋‍👨🏻' => 'пољубац: мушкарац, мушкарац, тамна кожа и свијетла кожа',
    '👨🏿‍❤‍💋‍👨🏼' => 'пољубац: мушкарац, мушкарац, тамна кожа и средње свијетла кожа',
    '👨🏿‍❤‍💋‍👨🏽' => 'пољубац: мушкарац, мушкарац, тамна кожа и ни свијетла ни тамна кожа',
    '👨🏿‍❤‍💋‍👨🏾' => 'пољубац: мушкарац, мушкарац, тамна кожа и средње тамна кожа',
    '👨🏿‍❤‍💋‍👨🏿' => 'пољубац: мушкарац, мушкарац и тамна кожа',
    '👩🏻‍❤‍💋‍👨🏻' => 'пољубац: жена, мушкарац и свијетла кожа',
    '👩🏻‍❤‍💋‍👨🏼' => 'пољубац: жена, мушкарац, свијетла кожа и средње свијетла кожа',
    '👩🏻‍❤‍💋‍👨🏽' => 'пољубац: жена, мушкарац, свијетла кожа и ни свијетла ни тамна кожа',
    '👩🏻‍❤‍💋‍👨🏾' => 'пољубац: жена, мушкарац, свијетла кожа и средње тамна кожа',
    '👩🏻‍❤‍💋‍👨🏿' => 'пољубац: жена, мушкарац, свијетла кожа и тамна кожа',
    '👩🏼‍❤‍💋‍👨🏻' => 'пољубац: жена, мушкарац, средње свијетла кожа и свијетла кожа',
    '👩🏼‍❤‍💋‍👨🏼' => 'пољубац: жена, мушкарац и средње свијетла кожа',
    '👩🏼‍❤‍💋‍👨🏽' => 'пољубац: жена, мушкарац, средње свијетла кожа и ни свијетла ни тамна кожа',
    '👩🏼‍❤‍💋‍👨🏾' => 'пољубац: жена, мушкарац, средње свијетла кожа и средње тамна кожа',
    '👩🏼‍❤‍💋‍👨🏿' => 'пољубац: жена, мушкарац, средње свијетла кожа и тамна кожа',
    '👩🏽‍❤‍💋‍👨🏻' => 'пољубац: жена, мушкарац, ни свијетла ни тамна кожа и свијетла кожа',
    '👩🏽‍❤‍💋‍👨🏼' => 'пољубац: жена, мушкарац, ни свијетла ни тамна кожа и средње свијетла кожа',
    '👩🏽‍❤‍💋‍👨🏽' => 'пољубац: жена, мушкарац и ни свијетла ни тамна кожа',
    '👩🏽‍❤‍💋‍👨🏾' => 'пољубац: жена, мушкарац, ни свијетла ни тамна кожа и средње тамна кожа',
    '👩🏽‍❤‍💋‍👨🏿' => 'пољубац: жена, мушкарац, ни свијетла ни тамна кожа и тамна кожа',
    '👩🏾‍❤‍💋‍👨🏻' => 'пољубац: жена, мушкарац, средње тамна кожа и свијетла кожа',
    '👩🏾‍❤‍💋‍👨🏼' => 'пољубац: жена, мушкарац, средње тамна кожа и средње свијетла кожа',
    '👩🏾‍❤‍💋‍👨🏽' => 'пољубац: жена, мушкарац, средње тамна кожа и ни свијетла ни тамна кожа',
    '👩🏾‍❤‍💋‍👨🏾' => 'пољубац: жена, мушкарац и средње тамна кожа',
    '👩🏾‍❤‍💋‍👨🏿' => 'пољубац: жена, мушкарац, средње тамна кожа и тамна кожа',
    '👩🏿‍❤‍💋‍👨🏻' => 'пољубац: жена, мушкарац, тамна кожа и свијетла кожа',
    '👩🏿‍❤‍💋‍👨🏼' => 'пољубац: жена, мушкарац, тамна кожа и средње свијетла кожа',
    '👩🏿‍❤‍💋‍👨🏽' => 'пољубац: жена, мушкарац, тамна кожа и ни свијетла ни тамна кожа',
    '👩🏿‍❤‍💋‍👨🏾' => 'пољубац: жена, мушкарац, тамна кожа и средње тамна кожа',
    '👩🏿‍❤‍💋‍👨🏿' => 'пољубац: жена, мушкарац и тамна кожа',
    '👩🏻‍❤‍💋‍👩🏻' => 'пољубац: жена, жена и свијетла кожа',
    '👩🏻‍❤‍💋‍👩🏼' => 'пољубац: жена, жена, свијетла кожа и средње свијетла кожа',
    '👩🏻‍❤‍💋‍👩🏽' => 'пољубац: жена, жена, свијетла кожа и ни свијетла ни тамна кожа',
    '👩🏻‍❤‍💋‍👩🏾' => 'пољубац: жена, жена, свијетла кожа и средње тамна кожа',
    '👩🏻‍❤‍💋‍👩🏿' => 'пољубац: жена, жена, свијетла кожа и тамна кожа',
    '👩🏼‍❤‍💋‍👩🏻' => 'пољубац: жена, жена, средње свијетла кожа и свијетла кожа',
    '👩🏼‍❤‍💋‍👩🏼' => 'пољубац: жена, жена и средње свијетла кожа',
    '👩🏼‍❤‍💋‍👩🏽' => 'пољубац: жена, жена, средње свијетла кожа и ни свијетла ни тамна кожа',
    '👩🏼‍❤‍💋‍👩🏾' => 'пољубац: жена, жена, средње свијетла кожа и средње тамна кожа',
    '👩🏼‍❤‍💋‍👩🏿' => 'пољубац: жена, жена, средње свијетла кожа и тамна кожа',
    '👩🏽‍❤‍💋‍👩🏻' => 'пољубац: жена, жена, ни свијетла ни тамна кожа и свијетла кожа',
    '👩🏽‍❤‍💋‍👩🏼' => 'пољубац: жена, жена, ни свијетла ни тамна кожа и средње свијетла кожа',
    '👩🏽‍❤‍💋‍👩🏽' => 'пољубац: жена, жена и ни свијетла ни тамна кожа',
    '👩🏽‍❤‍💋‍👩🏾' => 'пољубац: жена, жена, ни свијетла ни тамна кожа и средње тамна кожа',
    '👩🏽‍❤‍💋‍👩🏿' => 'пољубац: жена, жена, ни свијетла ни тамна кожа и тамна кожа',
    '👩🏾‍❤‍💋‍👩🏻' => 'пољубац: жена, жена, средње тамна кожа и свијетла кожа',
    '👩🏾‍❤‍💋‍👩🏼' => 'пољубац: жена, жена, средње тамна кожа и средње свијетла кожа',
    '👩🏾‍❤‍💋‍👩🏽' => 'пољубац: жена, жена, средње тамна кожа и ни свијетла ни тамна кожа',
    '👩🏾‍❤‍💋‍👩🏾' => 'пољубац: жена, жена и средње тамна кожа',
    '👩🏾‍❤‍💋‍👩🏿' => 'пољубац: жена, жена, средње тамна кожа и тамна кожа',
    '👩🏿‍❤‍💋‍👩🏻' => 'пољубац: жена, жена, тамна кожа и свијетла кожа',
    '👩🏿‍❤‍💋‍👩🏼' => 'пољубац: жена, жена, тамна кожа и средње свијетла кожа',
    '👩🏿‍❤‍💋‍👩🏽' => 'пољубац: жена, жена, тамна кожа и ни свијетла ни тамна кожа',
    '👩🏿‍❤‍💋‍👩🏾' => 'пољубац: жена, жена, тамна кожа и средње тамна кожа',
    '👩🏿‍❤‍💋‍👩🏿' => 'пољубац: жена, жена и тамна кожа',
    '🧑🏻‍🫯‍🧑🏼' => 'рвање: свијетла кожа и средње свијетла кожа',
    '🧑🏻‍🫯‍🧑🏽' => 'рвање: свијетла кожа и ни свијетла ни тамна кожа',
    '🧑🏻‍🫯‍🧑🏾' => 'рвање: свијетла кожа и средње тамна кожа',
    '🧑🏻‍🫯‍🧑🏿' => 'рвање: свијетла кожа и тамна кожа',
    '🧑🏼‍🫯‍🧑🏻' => 'рвање: средње свијетла кожа и свијетла кожа',
    '🧑🏼‍🫯‍🧑🏽' => 'рвање: средње свијетла кожа и ни свијетла ни тамна кожа',
    '🧑🏼‍🫯‍🧑🏾' => 'рвање: средње свијетла кожа и средње тамна кожа',
    '🧑🏼‍🫯‍🧑🏿' => 'рвање: средње свијетла кожа и тамна кожа',
    '🧑🏽‍🫯‍🧑🏻' => 'рвање: ни свијетла ни тамна кожа и свијетла кожа',
    '🧑🏽‍🫯‍🧑🏼' => 'рвање: ни свијетла ни тамна кожа и средње свијетла кожа',
    '🧑🏽‍🫯‍🧑🏾' => 'рвање: ни свијетла ни тамна кожа и средње тамна кожа',
    '🧑🏽‍🫯‍🧑🏿' => 'рвање: ни свијетла ни тамна кожа и тамна кожа',
    '🧑🏾‍🫯‍🧑🏻' => 'рвање: средње тамна кожа и свијетла кожа',
    '🧑🏾‍🫯‍🧑🏼' => 'рвање: средње тамна кожа и средње свијетла кожа',
    '🧑🏾‍🫯‍🧑🏽' => 'рвање: средње тамна кожа и ни свијетла ни тамна кожа',
    '🧑🏾‍🫯‍🧑🏿' => 'рвање: средње тамна кожа и тамна кожа',
    '🧑🏿‍🫯‍🧑🏻' => 'рвање: тамна кожа и свијетла кожа',
    '🧑🏿‍🫯‍🧑🏼' => 'рвање: тамна кожа и средње свијетла кожа',
    '🧑🏿‍🫯‍🧑🏽' => 'рвање: тамна кожа и ни свијетла ни тамна кожа',
    '🧑🏿‍🫯‍🧑🏾' => 'рвање: тамна кожа и средње тамна кожа',
    '🧑🏻‍❤‍🧑🏼' => 'пар са срцем: одрасла особа, одрасла особа, свијетла кожа и средње свијетла кожа',
    '🧑🏻‍❤‍🧑🏽' => 'пар са срцем: одрасла особа, одрасла особа, свијетла кожа и ни свијетла ни тамна кожа',
    '🧑🏻‍❤‍🧑🏾' => 'пар са срцем: одрасла особа, одрасла особа, свијетла кожа и средње тамна кожа',
    '🧑🏻‍❤‍🧑🏿' => 'пар са срцем: одрасла особа, одрасла особа, свијетла кожа и тамна кожа',
    '🧑🏼‍❤‍🧑🏻' => 'пар са срцем: одрасла особа, одрасла особа, средње свијетла кожа и свијетла кожа',
    '🧑🏼‍❤‍🧑🏽' => 'пар са срцем: одрасла особа, одрасла особа, средње свијетла кожа и ни свијетла ни тамна кожа',
    '🧑🏼‍❤‍🧑🏾' => 'пар са срцем: одрасла особа, одрасла особа, средње свијетла кожа и средње тамна кожа',
    '🧑🏼‍❤‍🧑🏿' => 'пар са срцем: одрасла особа, одрасла особа, средње свијетла кожа и тамна кожа',
    '🧑🏽‍❤‍🧑🏻' => 'пар са срцем: одрасла особа, одрасла особа, ни свијетла ни тамна кожа и свијетла кожа',
    '🧑🏽‍❤‍🧑🏼' => 'пар са срцем: одрасла особа, одрасла особа, ни свијетла ни тамна кожа и средње свијетла кожа',
    '🧑🏽‍❤‍🧑🏾' => 'пар са срцем: одрасла особа, одрасла особа, ни свијетла ни тамна кожа и средње тамна кожа',
    '🧑🏽‍❤‍🧑🏿' => 'пар са срцем: одрасла особа, одрасла особа, ни свијетла ни тамна кожа и тамна кожа',
    '🧑🏾‍❤‍🧑🏻' => 'пар са срцем: одрасла особа, одрасла особа, средње тамна кожа и свијетла кожа',
    '🧑🏾‍❤‍🧑🏼' => 'пар са срцем: одрасла особа, одрасла особа, средње тамна кожа и средње свијетла кожа',
    '🧑🏾‍❤‍🧑🏽' => 'пар са срцем: одрасла особа, одрасла особа, средње тамна кожа и ни свијетла ни тамна кожа',
    '🧑🏾‍❤‍🧑🏿' => 'пар са срцем: одрасла особа, одрасла особа, средње тамна кожа и тамна кожа',
    '🧑🏿‍❤‍🧑🏻' => 'пар са срцем: одрасла особа, одрасла особа, тамна кожа и свијетла кожа',
    '🧑🏿‍❤‍🧑🏼' => 'пар са срцем: одрасла особа, одрасла особа, тамна кожа и средње свијетла кожа',
    '🧑🏿‍❤‍🧑🏽' => 'пар са срцем: одрасла особа, одрасла особа, тамна кожа и ни свијетла ни тамна кожа',
    '🧑🏿‍❤‍🧑🏾' => 'пар са срцем: одрасла особа, одрасла особа, тамна кожа и средње тамна кожа',
    '🧑🏻‍🐰‍🧑🏼' => 'особе у проводу: свијетла кожа и средње свијетла кожа',
    '🧑🏻‍🐰‍🧑🏽' => 'особе у проводу: свијетла кожа и ни свијетла ни тамна кожа',
    '🧑🏻‍🐰‍🧑🏾' => 'особе у проводу: свијетла кожа и средње тамна кожа',
    '🧑🏻‍🐰‍🧑🏿' => 'особе у проводу: свијетла кожа и тамна кожа',
    '🧑🏼‍🐰‍🧑🏻' => 'особе у проводу: средње свијетла кожа и свијетла кожа',
    '🧑🏼‍🐰‍🧑🏽' => 'особе у проводу: средње свијетла кожа и ни свијетла ни тамна кожа',
    '🧑🏼‍🐰‍🧑🏾' => 'особе у проводу: средње свијетла кожа и средње тамна кожа',
    '🧑🏼‍🐰‍🧑🏿' => 'особе у проводу: средње свијетла кожа и тамна кожа',
    '🧑🏽‍🐰‍🧑🏻' => 'особе у проводу: ни свијетла ни тамна кожа и свијетла кожа',
    '🧑🏽‍🐰‍🧑🏼' => 'особе у проводу: ни свијетла ни тамна кожа и средње свијетла кожа',
    '🧑🏽‍🐰‍🧑🏾' => 'особе у проводу: ни свијетла ни тамна кожа и средње тамна кожа',
    '🧑🏽‍🐰‍🧑🏿' => 'особе у проводу: ни свијетла ни тамна кожа и тамна кожа',
    '🧑🏾‍🐰‍🧑🏻' => 'особе у проводу: средње тамна кожа и свијетла кожа',
    '🧑🏾‍🐰‍🧑🏼' => 'особе у проводу: средње тамна кожа и средње свијетла кожа',
    '🧑🏾‍🐰‍🧑🏽' => 'особе у проводу: средње тамна кожа и ни свијетла ни тамна кожа',
    '🧑🏾‍🐰‍🧑🏿' => 'особе у проводу: средње тамна кожа и тамна кожа',
    '🧑🏿‍🐰‍🧑🏻' => 'особе у проводу: тамна кожа и свијетла кожа',
    '🧑🏿‍🐰‍🧑🏼' => 'особе у проводу: тамна кожа и средње свијетла кожа',
    '🧑🏿‍🐰‍🧑🏽' => 'особе у проводу: тамна кожа и ни свијетла ни тамна кожа',
    '🧑🏿‍🐰‍🧑🏾' => 'особе у проводу: тамна кожа и средње тамна кожа',
    '👨🏻‍🫯‍👨🏼' => 'рвачи: свијетла кожа и средње свијетла кожа',
    '👨🏻‍🫯‍👨🏽' => 'рвачи: свијетла кожа и ни свијетла ни тамна кожа',
    '👨🏻‍🫯‍👨🏾' => 'рвачи: свијетла кожа и средње тамна кожа',
    '👨🏻‍🫯‍👨🏿' => 'рвачи: свијетла кожа и тамна кожа',
    '👨🏼‍🫯‍👨🏻' => 'рвачи: средње свијетла кожа и свијетла кожа',
    '👨🏼‍🫯‍👨🏽' => 'рвачи: средње свијетла кожа и ни свијетла ни тамна кожа',
    '👨🏼‍🫯‍👨🏾' => 'рвачи: средње свијетла кожа и средње тамна кожа',
    '👨🏼‍🫯‍👨🏿' => 'рвачи: средње свијетла кожа и тамна кожа',
    '👨🏽‍🫯‍👨🏻' => 'рвачи: ни свијетла ни тамна кожа и свијетла кожа',
    '👨🏽‍🫯‍👨🏼' => 'рвачи: ни свијетла ни тамна кожа и средње свијетла кожа',
    '👨🏽‍🫯‍👨🏾' => 'рвачи: ни свијетла ни тамна кожа и средње тамна кожа',
    '👨🏽‍🫯‍👨🏿' => 'рвачи: ни свијетла ни тамна кожа и тамна кожа',
    '👨🏾‍🫯‍👨🏻' => 'рвачи: средње тамна кожа и свијетла кожа',
    '👨🏾‍🫯‍👨🏼' => 'рвачи: средње тамна кожа и средње свијетла кожа',
    '👨🏾‍🫯‍👨🏽' => 'рвачи: средње тамна кожа и ни свијетла ни тамна кожа',
    '👨🏾‍🫯‍👨🏿' => 'рвачи: средње тамна кожа и тамна кожа',
    '👨🏿‍🫯‍👨🏻' => 'рвачи: тамна кожа и свијетла кожа',
    '👨🏿‍🫯‍👨🏼' => 'рвачи: тамна кожа и средње свијетла кожа',
    '👨🏿‍🫯‍👨🏽' => 'рвачи: тамна кожа и ни свијетла ни тамна кожа',
    '👨🏿‍🫯‍👨🏾' => 'рвачи: тамна кожа и средње тамна кожа',
    '👨🏻‍❤‍👨🏻' => 'пар са срцем: мушкарац, мушкарац и свијетла кожа',
    '👨🏻‍❤‍👨🏼' => 'пар са срцем: мушкарац, мушкарац, свијетла кожа и средње свијетла кожа',
    '👨🏻‍❤‍👨🏽' => 'пар са срцем: мушкарац, мушкарац, свијетла кожа и ни свијетла ни тамна кожа',
    '👨🏻‍❤‍👨🏾' => 'пар са срцем: мушкарац, мушкарац, свијетла кожа и средње тамна кожа',
    '👨🏻‍❤‍👨🏿' => 'пар са срцем: мушкарац, мушкарац, свијетла кожа и тамна кожа',
    '👨🏼‍❤‍👨🏻' => 'пар са срцем: мушкарац, мушкарац, средње свијетла кожа и свијетла кожа',
    '👨🏼‍❤‍👨🏼' => 'пар са срцем: мушкарац, мушкарац и средње свијетла кожа',
    '👨🏼‍❤‍👨🏽' => 'пар са срцем: мушкарац, мушкарац, средње свијетла кожа и ни свијетла ни тамна кожа',
    '👨🏼‍❤‍👨🏾' => 'пар са срцем: мушкарац, мушкарац, средње свијетла кожа и средње тамна кожа',
    '👨🏼‍❤‍👨🏿' => 'пар са срцем: мушкарац, мушкарац, средње свијетла кожа и тамна кожа',
    '👨🏽‍❤‍👨🏻' => 'пар са срцем: мушкарац, мушкарац, ни свијетла ни тамна кожа и свијетла кожа',
    '👨🏽‍❤‍👨🏼' => 'пар са срцем: мушкарац, мушкарац, ни свијетла ни тамна кожа и средње свијетла кожа',
    '👨🏽‍❤‍👨🏽' => 'пар са срцем: мушкарац, мушкарац и ни свијетла ни тамна кожа',
    '👨🏽‍❤‍👨🏾' => 'пар са срцем: мушкарац, мушкарац, ни свијетла ни тамна кожа и средње тамна кожа',
    '👨🏽‍❤‍👨🏿' => 'пар са срцем: мушкарац, мушкарац, ни свијетла ни тамна кожа и тамна кожа',
    '👨🏾‍❤‍👨🏻' => 'пар са срцем: мушкарац, мушкарац, средње тамна кожа и свијетла кожа',
    '👨🏾‍❤‍👨🏼' => 'пар са срцем: мушкарац, мушкарац, средње тамна кожа и средње свијетла кожа',
    '👨🏾‍❤‍👨🏽' => 'пар са срцем: мушкарац, мушкарац, средње тамна кожа и ни свијетла ни тамна кожа',
    '👨🏾‍❤‍👨🏾' => 'пар са срцем: мушкарац, мушкарац и средње тамна кожа',
    '👨🏾‍❤‍👨🏿' => 'пар са срцем: мушкарац, мушкарац, средње тамна кожа и тамна кожа',
    '👨🏿‍❤‍👨🏻' => 'пар са срцем: мушкарац, мушкарац, тамна кожа и свијетла кожа',
    '👨🏿‍❤‍👨🏼' => 'пар са срцем: мушкарац, мушкарац, тамна кожа и средње свијетла кожа',
    '👨🏿‍❤‍👨🏽' => 'пар са срцем: мушкарац, мушкарац, тамна кожа и ни свијетла ни тамна кожа',
    '👨🏿‍❤‍👨🏾' => 'пар са срцем: мушкарац, мушкарац, тамна кожа и средње тамна кожа',
    '👨🏿‍❤‍👨🏿' => 'пар са срцем: мушкарац, мушкарац и тамна кожа',
    '👨🏻‍🐰‍👨🏼' => 'мушкарци у проводу: свијетла кожа и средње свијетла кожа',
    '👨🏻‍🐰‍👨🏽' => 'мушкарци у проводу: свијетла кожа и ни свијетла ни тамна кожа',
    '👨🏻‍🐰‍👨🏾' => 'мушкарци у проводу: свијетла кожа и средње тамна кожа',
    '👨🏻‍🐰‍👨🏿' => 'мушкарци у проводу: свијетла кожа и тамна кожа',
    '👨🏼‍🐰‍👨🏻' => 'мушкарци у проводу: средње свијетла кожа и свијетла кожа',
    '👨🏼‍🐰‍👨🏽' => 'мушкарци у проводу: средње свијетла кожа и ни свијетла ни тамна кожа',
    '👨🏼‍🐰‍👨🏾' => 'мушкарци у проводу: средње свијетла кожа и средње тамна кожа',
    '👨🏼‍🐰‍👨🏿' => 'мушкарци у проводу: средње свијетла кожа и тамна кожа',
    '👨🏽‍🐰‍👨🏻' => 'мушкарци у проводу: ни свијетла ни тамна кожа и свијетла кожа',
    '👨🏽‍🐰‍👨🏼' => 'мушкарци у проводу: ни свијетла ни тамна кожа и средње свијетла кожа',
    '👨🏽‍🐰‍👨🏾' => 'мушкарци у проводу: ни свијетла ни тамна кожа и средње тамна кожа',
    '👨🏽‍🐰‍👨🏿' => 'мушкарци у проводу: ни свијетла ни тамна кожа и тамна кожа',
    '👨🏾‍🐰‍👨🏻' => 'мушкарци у проводу: средње тамна кожа и свијетла кожа',
    '👨🏾‍🐰‍👨🏼' => 'мушкарци у проводу: средње тамна кожа и средње свијетла кожа',
    '👨🏾‍🐰‍👨🏽' => 'мушкарци у проводу: средње тамна кожа и ни свијетла ни тамна кожа',
    '👨🏾‍🐰‍👨🏿' => 'мушкарци у проводу: средње тамна кожа и тамна кожа',
    '👨🏿‍🐰‍👨🏻' => 'мушкарци у проводу: тамна кожа и свијетла кожа',
    '👨🏿‍🐰‍👨🏼' => 'мушкарци у проводу: тамна кожа и средње свијетла кожа',
    '👨🏿‍🐰‍👨🏽' => 'мушкарци у проводу: тамна кожа и ни свијетла ни тамна кожа',
    '👨🏿‍🐰‍👨🏾' => 'мушкарци у проводу: тамна кожа и средње тамна кожа',
    '👩🏻‍🫯‍👩🏼' => 'рвачице: свијетла кожа и средње свијетла кожа',
    '👩🏻‍🫯‍👩🏽' => 'рвачице: свијетла кожа и ни свијетла ни тамна кожа',
    '👩🏻‍🫯‍👩🏾' => 'рвачице: свијетла кожа и средње тамна кожа',
    '👩🏻‍🫯‍👩🏿' => 'рвачице: свијетла кожа и тамна кожа',
    '👩🏼‍🫯‍👩🏻' => 'рвачице: средње свијетла кожа и свијетла кожа',
    '👩🏼‍🫯‍👩🏽' => 'рвачице: средње свијетла кожа и ни свијетла ни тамна кожа',
    '👩🏼‍🫯‍👩🏾' => 'рвачице: средње свијетла кожа и средње тамна кожа',
    '👩🏼‍🫯‍👩🏿' => 'рвачице: средње свијетла кожа и тамна кожа',
    '👩🏽‍🫯‍👩🏻' => 'рвачице: ни свијетла ни тамна кожа и свијетла кожа',
    '👩🏽‍🫯‍👩🏼' => 'рвачице: ни свијетла ни тамна кожа и средње свијетла кожа',
    '👩🏽‍🫯‍👩🏾' => 'рвачице: ни свијетла ни тамна кожа и средње тамна кожа',
    '👩🏽‍🫯‍👩🏿' => 'рвачице: ни свијетла ни тамна кожа и тамна кожа',
    '👩🏾‍🫯‍👩🏻' => 'рвачице: средње тамна кожа и свијетла кожа',
    '👩🏾‍🫯‍👩🏼' => 'рвачице: средње тамна кожа и средње свијетла кожа',
    '👩🏾‍🫯‍👩🏽' => 'рвачице: средње тамна кожа и ни свијетла ни тамна кожа',
    '👩🏾‍🫯‍👩🏿' => 'рвачице: средње тамна кожа и тамна кожа',
    '👩🏿‍🫯‍👩🏻' => 'рвачице: тамна кожа и свијетла кожа',
    '👩🏿‍🫯‍👩🏼' => 'рвачице: тамна кожа и средње свијетла кожа',
    '👩🏿‍🫯‍👩🏽' => 'рвачице: тамна кожа и ни свијетла ни тамна кожа',
    '👩🏿‍🫯‍👩🏾' => 'рвачице: тамна кожа и средње тамна кожа',
    '👩🏻‍❤‍👨🏻' => 'пар са срцем: жена, мушкарац и свијетла кожа',
    '👩🏻‍❤‍👨🏼' => 'пар са срцем: жена, мушкарац, свијетла кожа и средње свијетла кожа',
    '👩🏻‍❤‍👨🏽' => 'пар са срцем: жена, мушкарац, свијетла кожа и ни свијетла ни тамна кожа',
    '👩🏻‍❤‍👨🏾' => 'пар са срцем: жена, мушкарац, свијетла кожа и средње тамна кожа',
    '👩🏻‍❤‍👨🏿' => 'пар са срцем: жена, мушкарац, свијетла кожа и тамна кожа',
    '👩🏼‍❤‍👨🏻' => 'пар са срцем: жена, мушкарац, средње свијетла кожа и свијетла кожа',
    '👩🏼‍❤‍👨🏼' => 'пар са срцем: жена, мушкарац и средње свијетла кожа',
    '👩🏼‍❤‍👨🏽' => 'пар са срцем: жена, мушкарац, средње свијетла кожа и ни свијетла ни тамна кожа',
    '👩🏼‍❤‍👨🏾' => 'пар са срцем: жена, мушкарац, средње свијетла кожа и средње тамна кожа',
    '👩🏼‍❤‍👨🏿' => 'пар са срцем: жена, мушкарац, средње свијетла кожа и тамна кожа',
    '👩🏽‍❤‍👨🏻' => 'пар са срцем: жена, мушкарац, ни свијетла ни тамна кожа и свијетла кожа',
    '👩🏽‍❤‍👨🏼' => 'пар са срцем: жена, мушкарац, ни свијетла ни тамна кожа и средње свијетла кожа',
    '👩🏽‍❤‍👨🏽' => 'пар са срцем: жена, мушкарац и ни свијетла ни тамна кожа',
    '👩🏽‍❤‍👨🏾' => 'пар са срцем: жена, мушкарац, ни свијетла ни тамна кожа и средње тамна кожа',
    '👩🏽‍❤‍👨🏿' => 'пар са срцем: жена, мушкарац, ни свијетла ни тамна кожа и тамна кожа',
    '👩🏾‍❤‍👨🏻' => 'пар са срцем: жена, мушкарац, средње тамна кожа и свијетла кожа',
    '👩🏾‍❤‍👨🏼' => 'пар са срцем: жена, мушкарац, средње тамна кожа и средње свијетла кожа',
    '👩🏾‍❤‍👨🏽' => 'пар са срцем: жена, мушкарац, средње тамна кожа и ни свијетла ни тамна кожа',
    '👩🏾‍❤‍👨🏾' => 'пар са срцем: жена, мушкарац и средње тамна кожа',
    '👩🏾‍❤‍👨🏿' => 'пар са срцем: жена, мушкарац, средње тамна кожа и тамна кожа',
    '👩🏿‍❤‍👨🏻' => 'пар са срцем: жена, мушкарац, тамна кожа и свијетла кожа',
    '👩🏿‍❤‍👨🏼' => 'пар са срцем: жена, мушкарац, тамна кожа и средње свијетла кожа',
    '👩🏿‍❤‍👨🏽' => 'пар са срцем: жена, мушкарац, тамна кожа и ни свијетла ни тамна кожа',
    '👩🏿‍❤‍👨🏾' => 'пар са срцем: жена, мушкарац, тамна кожа и средње тамна кожа',
    '👩🏿‍❤‍👨🏿' => 'пар са срцем: жена, мушкарац и тамна кожа',
    '👩🏻‍❤‍👩🏻' => 'пар са срцем: жена, жена и свијетла кожа',
    '👩🏻‍❤‍👩🏼' => 'пар са срцем: жена, жена, свијетла кожа и средње свијетла кожа',
    '👩🏻‍❤‍👩🏽' => 'пар са срцем: жена, жена, свијетла кожа и ни свијетла ни тамна кожа',
    '👩🏻‍❤‍👩🏾' => 'пар са срцем: жена, жена, свијетла кожа и средње тамна кожа',
    '👩🏻‍❤‍👩🏿' => 'пар са срцем: жена, жена, свијетла кожа и тамна кожа',
    '👩🏼‍❤‍👩🏻' => 'пар са срцем: жена, жена, средње свијетла кожа и свијетла кожа',
    '👩🏼‍❤‍👩🏼' => 'пар са срцем: жена, жена и средње свијетла кожа',
    '👩🏼‍❤‍👩🏽' => 'пар са срцем: жена, жена, средње свијетла кожа и ни свијетла ни тамна кожа',
    '👩🏼‍❤‍👩🏾' => 'пар са срцем: жена, жена, средње свијетла кожа и средње тамна кожа',
    '👩🏼‍❤‍👩🏿' => 'пар са срцем: жена, жена, средње свијетла кожа и тамна кожа',
    '👩🏽‍❤‍👩🏻' => 'пар са срцем: жена, жена, ни свијетла ни тамна кожа и свијетла кожа',
    '👩🏽‍❤‍👩🏼' => 'пар са срцем: жена, жена, ни свијетла ни тамна кожа и средње свијетла кожа',
    '👩🏽‍❤‍👩🏽' => 'пар са срцем: жена, жена и ни свијетла ни тамна кожа',
    '👩🏽‍❤‍👩🏾' => 'пар са срцем: жена, жена, ни свијетла ни тамна кожа и средње тамна кожа',
    '👩🏽‍❤‍👩🏿' => 'пар са срцем: жена, жена, ни свијетла ни тамна кожа и тамна кожа',
    '👩🏾‍❤‍👩🏻' => 'пар са срцем: жена, жена, средње тамна кожа и свијетла кожа',
    '👩🏾‍❤‍👩🏼' => 'пар са срцем: жена, жена, средње тамна кожа и средње свијетла кожа',
    '👩🏾‍❤‍👩🏽' => 'пар са срцем: жена, жена, средње тамна кожа и ни свијетла ни тамна кожа',
    '👩🏾‍❤‍👩🏾' => 'пар са срцем: жена, жена и средње тамна кожа',
    '👩🏾‍❤‍👩🏿' => 'пар са срцем: жена, жена, средње тамна кожа и тамна кожа',
    '👩🏿‍❤‍👩🏻' => 'пар са срцем: жена, жена, тамна кожа и свијетла кожа',
    '👩🏿‍❤‍👩🏼' => 'пар са срцем: жена, жена, тамна кожа и средње свијетла кожа',
    '👩🏿‍❤‍👩🏽' => 'пар са срцем: жена, жена, тамна кожа и ни свијетла ни тамна кожа',
    '👩🏿‍❤‍👩🏾' => 'пар са срцем: жена, жена, тамна кожа и средње тамна кожа',
    '👩🏿‍❤‍👩🏿' => 'пар са срцем: жена, жена и тамна кожа',
    '👩🏻‍🐰‍👩🏼' => 'жене у проводу: свијетла кожа и средње свијетла кожа',
    '👩🏻‍🐰‍👩🏽' => 'жене у проводу: свијетла кожа и ни свијетла ни тамна кожа',
    '👩🏻‍🐰‍👩🏾' => 'жене у проводу: свијетла кожа и средње тамна кожа',
    '👩🏻‍🐰‍👩🏿' => 'жене у проводу: свијетла кожа и тамна кожа',
    '👩🏼‍🐰‍👩🏻' => 'жене у проводу: средње свијетла кожа и свијетла кожа',
    '👩🏼‍🐰‍👩🏽' => 'жене у проводу: средње свијетла кожа и ни свијетла ни тамна кожа',
    '👩🏼‍🐰‍👩🏾' => 'жене у проводу: средње свијетла кожа и средње тамна кожа',
    '👩🏼‍🐰‍👩🏿' => 'жене у проводу: средње свијетла кожа и тамна кожа',
    '👩🏽‍🐰‍👩🏻' => 'жене у проводу: ни свијетла ни тамна кожа и свијетла кожа',
    '👩🏽‍🐰‍👩🏼' => 'жене у проводу: ни свијетла ни тамна кожа и средње свијетла кожа',
    '👩🏽‍🐰‍👩🏾' => 'жене у проводу: ни свијетла ни тамна кожа и средње тамна кожа',
    '👩🏽‍🐰‍👩🏿' => 'жене у проводу: ни свијетла ни тамна кожа и тамна кожа',
    '👩🏾‍🐰‍👩🏻' => 'жене у проводу: средње тамна кожа и свијетла кожа',
    '👩🏾‍🐰‍👩🏼' => 'жене у проводу: средње тамна кожа и средње свијетла кожа',
    '👩🏾‍🐰‍👩🏽' => 'жене у проводу: средње тамна кожа и ни свијетла ни тамна кожа',
    '👩🏾‍🐰‍👩🏿' => 'жене у проводу: средње тамна кожа и тамна кожа',
    '👩🏿‍🐰‍👩🏻' => 'жене у проводу: тамна кожа и свијетла кожа',
    '👩🏿‍🐰‍👩🏼' => 'жене у проводу: тамна кожа и средње свијетла кожа',
    '👩🏿‍🐰‍👩🏽' => 'жене у проводу: тамна кожа и ни свијетла ни тамна кожа',
    '👩🏿‍🐰‍👩🏾' => 'жене у проводу: тамна кожа и средње тамна кожа',
    '🧑🏻‍🤝‍🧑🏻' => 'особе се држе за руке: свијетла кожа',
    '🧑🏻‍🤝‍🧑🏼' => 'особе се држе за руке: свијетла кожа и средње свијетла кожа',
    '🧑🏻‍🤝‍🧑🏽' => 'особе се држе за руке: свијетла кожа и ни свијетла ни тамна кожа',
    '🧑🏻‍🤝‍🧑🏾' => 'особе се држе за руке: свијетла кожа и средње тамна кожа',
    '🧑🏻‍🤝‍🧑🏿' => 'особе се држе за руке: свијетла кожа и тамна кожа',
    '🧑🏼‍🤝‍🧑🏻' => 'особе се држе за руке: средње свијетла кожа и свијетла кожа',
    '🧑🏼‍🤝‍🧑🏼' => 'особе се држе за руке: средње свијетла кожа',
    '🧑🏼‍🤝‍🧑🏽' => 'особе се држе за руке: средње свијетла кожа и ни свијетла ни тамна кожа',
    '🧑🏼‍🤝‍🧑🏾' => 'особе се држе за руке: средње свијетла кожа и средње тамна кожа',
    '🧑🏼‍🤝‍🧑🏿' => 'особе се држе за руке: средње свијетла кожа и тамна кожа',
    '🧑🏽‍🤝‍🧑🏻' => 'особе се држе за руке: ни свијетла ни тамна кожа и свијетла кожа',
    '🧑🏽‍🤝‍🧑🏼' => 'особе се држе за руке: ни свијетла ни тамна кожа и средње свијетла кожа',
    '🧑🏽‍🤝‍🧑🏽' => 'особе се држе за руке: ни свијетла ни тамна кожа',
    '🧑🏽‍🤝‍🧑🏾' => 'особе се држе за руке: ни свијетла ни тамна кожа и средње тамна кожа',
    '🧑🏽‍🤝‍🧑🏿' => 'особе се држе за руке: ни свијетла ни тамна кожа и тамна кожа',
    '🧑🏾‍🤝‍🧑🏻' => 'особе се држе за руке: средње тамна кожа и свијетла кожа',
    '🧑🏾‍🤝‍🧑🏼' => 'особе се држе за руке: средње тамна кожа и средње свијетла кожа',
    '🧑🏾‍🤝‍🧑🏽' => 'особе се држе за руке: средње тамна кожа и ни свијетла ни тамна кожа',
    '🧑🏾‍🤝‍🧑🏾' => 'особе се држе за руке: средње тамна кожа',
    '🧑🏾‍🤝‍🧑🏿' => 'особе се држе за руке: средње тамна кожа и тамна кожа',
    '🧑🏿‍🤝‍🧑🏻' => 'особе се држе за руке: тамна кожа и свијетла кожа',
    '🧑🏿‍🤝‍🧑🏼' => 'особе се држе за руке: тамна кожа и средње свијетла кожа',
    '🧑🏿‍🤝‍🧑🏽' => 'особе се држе за руке: тамна кожа и ни свијетла ни тамна кожа',
    '🧑🏿‍🤝‍🧑🏾' => 'особе се држе за руке: тамна кожа и средње тамна кожа',
    '🧑🏿‍🤝‍🧑🏿' => 'особе се држе за руке: тамна кожа',
    '👩🏻‍🤝‍👩🏼' => 'жене се држе за руке: свијетла кожа и средње свијетла кожа',
    '👩🏻‍🤝‍👩🏽' => 'жене се држе за руке: свијетла кожа и ни свијетла ни тамна кожа',
    '👩🏻‍🤝‍👩🏾' => 'жене се држе за руке: свијетла кожа и средње тамна кожа',
    '👩🏻‍🤝‍👩🏿' => 'жене се држе за руке: свијетла кожа и тамна кожа',
    '👩🏼‍🤝‍👩🏻' => 'жене се држе за руке: средње свијетла кожа и свијетла кожа',
    '👩🏼‍🤝‍👩🏽' => 'жене се држе за руке: средње свијетла кожа и ни свијетла ни тамна кожа',
    '👩🏼‍🤝‍👩🏾' => 'жене се држе за руке: средње свијетла кожа и средње тамна кожа',
    '👩🏼‍🤝‍👩🏿' => 'жене се држе за руке: средње свијетла кожа и тамна кожа',
    '👩🏽‍🤝‍👩🏻' => 'жене се држе за руке: ни свијетла ни тамна кожа и свијетла кожа',
    '👩🏽‍🤝‍👩🏼' => 'жене се држе за руке: ни свијетла ни тамна кожа и средње свијетла кожа',
    '👩🏽‍🤝‍👩🏾' => 'жене се држе за руке: ни свијетла ни тамна кожа и средње тамна кожа',
    '👩🏽‍🤝‍👩🏿' => 'жене се држе за руке: ни свијетла ни тамна кожа и тамна кожа',
    '👩🏾‍🤝‍👩🏻' => 'жене се држе за руке: средње тамна кожа и свијетла кожа',
    '👩🏾‍🤝‍👩🏼' => 'жене се држе за руке: средње тамна кожа и средње свијетла кожа',
    '👩🏾‍🤝‍👩🏽' => 'жене се држе за руке: средње тамна кожа и ни свијетла ни тамна кожа',
    '👩🏾‍🤝‍👩🏿' => 'жене се држе за руке: средње тамна кожа и тамна кожа',
    '👩🏿‍🤝‍👩🏻' => 'жене се држе за руке: тамна кожа и свијетла кожа',
    '👩🏿‍🤝‍👩🏼' => 'жене се држе за руке: тамна кожа и средње свијетла кожа',
    '👩🏿‍🤝‍👩🏽' => 'жене се држе за руке: тамна кожа и ни свијетла ни тамна кожа',
    '👩🏿‍🤝‍👩🏾' => 'жене се држе за руке: тамна кожа и средње тамна кожа',
    '👩🏻‍🤝‍👨🏼' => 'жена и мушкарац се држе за руке: свијетла кожа и средње свијетла кожа',
    '👩🏻‍🤝‍👨🏽' => 'жена и мушкарац се држе за руке: свијетла кожа и ни свијетла ни тамна кожа',
    '👩🏻‍🤝‍👨🏾' => 'жена и мушкарац се држе за руке: свијетла кожа и средње тамна кожа',
    '👩🏻‍🤝‍👨🏿' => 'жена и мушкарац се држе за руке: свијетла кожа и тамна кожа',
    '👩🏼‍🤝‍👨🏻' => 'жена и мушкарац се држе за руке: средње свијетла кожа и свијетла кожа',
    '👩🏼‍🤝‍👨🏽' => 'жена и мушкарац се држе за руке: средње свијетла кожа и ни свијетла ни тамна кожа',
    '👩🏼‍🤝‍👨🏾' => 'жена и мушкарац се држе за руке: средње свијетла кожа и средње тамна кожа',
    '👩🏼‍🤝‍👨🏿' => 'жена и мушкарац се држе за руке: средње свијетла кожа и тамна кожа',
    '👩🏽‍🤝‍👨🏻' => 'жена и мушкарац се држе за руке: ни свијетла ни тамна кожа и свијетла кожа',
    '👩🏽‍🤝‍👨🏼' => 'жена и мушкарац се држе за руке: ни свијетла ни тамна кожа и средње свијетла кожа',
    '👩🏽‍🤝‍👨🏾' => 'жена и мушкарац се држе за руке: ни свијетла ни тамна кожа и средње тамна кожа',
    '👩🏽‍🤝‍👨🏿' => 'жена и мушкарац се држе за руке: ни свијетла ни тамна кожа и тамна кожа',
    '👩🏾‍🤝‍👨🏻' => 'жена и мушкарац се држе за руке: средње тамна кожа и свијетла кожа',
    '👩🏾‍🤝‍👨🏼' => 'жена и мушкарац се држе за руке: средње тамна кожа и средње свијетла кожа',
    '👩🏾‍🤝‍👨🏽' => 'жена и мушкарац се држе за руке: средње тамна кожа и ни свијетла ни тамна кожа',
    '👩🏾‍🤝‍👨🏿' => 'жена и мушкарац се држе за руке: средње тамна кожа и тамна кожа',
    '👩🏿‍🤝‍👨🏻' => 'жена и мушкарац се држе за руке: тамна кожа и свијетла кожа',
    '👩🏿‍🤝‍👨🏼' => 'жена и мушкарац се држе за руке: тамна кожа и средње свијетла кожа',
    '👩🏿‍🤝‍👨🏽' => 'жена и мушкарац се држе за руке: тамна кожа и ни свијетла ни тамна кожа',
    '👩🏿‍🤝‍👨🏾' => 'жена и мушкарац се држе за руке: тамна кожа и средње тамна кожа',
    '👨🏻‍🤝‍👨🏼' => 'мушкарци се држе за руке: свијетла кожа и средње свијетла кожа',
    '👨🏻‍🤝‍👨🏽' => 'мушкарци се држе за руке: свијетла кожа и ни свијетла ни тамна кожа',
    '👨🏻‍🤝‍👨🏾' => 'мушкарци се држе за руке: свијетла кожа и средње тамна кожа',
    '👨🏻‍🤝‍👨🏿' => 'мушкарци се држе за руке: свијетла кожа и тамна кожа',
    '👨🏼‍🤝‍👨🏻' => 'мушкарци се држе за руке: средње свијетла кожа и свијетла кожа',
    '👨🏼‍🤝‍👨🏽' => 'мушкарци се држе за руке: средње свијетла кожа и ни свијетла ни тамна кожа',
    '👨🏼‍🤝‍👨🏾' => 'мушкарци се држе за руке: средње свијетла кожа и средње тамна кожа',
    '👨🏼‍🤝‍👨🏿' => 'мушкарци се држе за руке: средње свијетла кожа и тамна кожа',
    '👨🏽‍🤝‍👨🏻' => 'мушкарци се држе за руке: ни свијетла ни тамна кожа и свијетла кожа',
    '👨🏽‍🤝‍👨🏼' => 'мушкарци се држе за руке: ни свијетла ни тамна кожа и средње свијетла кожа',
    '👨🏽‍🤝‍👨🏾' => 'мушкарци се држе за руке: ни свијетла ни тамна кожа и средње тамна кожа',
    '👨🏽‍🤝‍👨🏿' => 'мушкарци се држе за руке: ни свијетла ни тамна кожа и тамна кожа',
    '👨🏾‍🤝‍👨🏻' => 'мушкарци се држе за руке: средње тамна кожа и свијетла кожа',
    '👨🏾‍🤝‍👨🏼' => 'мушкарци се држе за руке: средње тамна кожа и средње свијетла кожа',
    '👨🏾‍🤝‍👨🏽' => 'мушкарци се држе за руке: средње тамна кожа и ни свијетла ни тамна кожа',
    '👨🏾‍🤝‍👨🏿' => 'мушкарци се држе за руке: средње тамна кожа и тамна кожа',
    '👨🏿‍🤝‍👨🏻' => 'мушкарци се држе за руке: тамна кожа и свијетла кожа',
    '👨🏿‍🤝‍👨🏼' => 'мушкарци се држе за руке: тамна кожа и средње свијетла кожа',
    '👨🏿‍🤝‍👨🏽' => 'мушкарци се држе за руке: тамна кожа и ни свијетла ни тамна кожа',
    '👨🏿‍🤝‍👨🏾' => 'мушкарци се држе за руке: тамна кожа и средње тамна кожа',
    '👩‍❤‍💋‍👨' => 'пољубац: жена и мушкарац',
    '👨‍❤‍💋‍👨' => 'пољубац: мушкарац и мушкарац',
    '👩‍❤‍💋‍👩' => 'пољубац: жена и жена',
    '👨‍👩‍👧‍👦' => 'породица: мушкарац, жена, дјевојчица и дјечак',
    '👨‍👩‍👦‍👦' => 'породица: мушкарац, жена, дјечак и дјечак',
    '👨‍👩‍👧‍👧' => 'породица: мушкарац, жена, дјевојчица и дјевојчица',
    '👨‍👨‍👧‍👦' => 'породица: мушкарац, мушкарац, дјевојчица и дјечак',
    '👨‍👨‍👦‍👦' => 'породица: мушкарац, мушкарац, дјечак и дјечак',
    '👨‍👨‍👧‍👧' => 'породица: мушкарац, мушкарац, дјевојчица и дјевојчица',
    '👩‍👩‍👧‍👦' => 'породица: жена, жена, дјевојчица и дјечак',
    '👩‍👩‍👦‍👦' => 'породица: жена, жена, дјечак и дјечак',
    '👩‍👩‍👧‍👧' => 'породица: жена, жена, дјевојчица и дјевојчица',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'застава: Енглеска',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'застава: Шкотска',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'застава: Велс',
    '🧑‍🧑‍🧒‍🧒' => 'породица: одрасла особа, одрасла особа, дијете, дијете',
    '🚶🏻‍♀‍➡' => 'жена хода: свијетла кожа и гледа удесно',
    '🚶🏼‍♀‍➡' => 'жена хода: средње свијетла кожа и гледа удесно',
    '🚶🏽‍♀‍➡' => 'жена хода: ни свијетла ни тамна кожа и гледа удесно',
    '🚶🏾‍♀‍➡' => 'жена хода: средње тамна кожа и гледа удесно',
    '🚶🏿‍♀‍➡' => 'жена хода: тамна кожа и гледа удесно',
    '🚶🏻‍♂‍➡' => 'мушкарац хода: свијетла кожа и гледа удесно',
    '🚶🏼‍♂‍➡' => 'мушкарац хода: средње свијетла кожа и гледа удесно',
    '🚶🏽‍♂‍➡' => 'мушкарац хода: ни свијетла ни тамна кожа и гледа удесно',
    '🚶🏾‍♂‍➡' => 'мушкарац хода: средње тамна кожа и гледа удесно',
    '🚶🏿‍♂‍➡' => 'мушкарац хода: тамна кожа и гледа удесно',
    '🧎🏻‍♀‍➡' => 'жена клечи: свијетла кожа и гледа удесно',
    '🧎🏼‍♀‍➡' => 'жена клечи: средње свијетла кожа и гледа удесно',
    '🧎🏽‍♀‍➡' => 'жена клечи: ни свијетла ни тамна кожа и гледа удесно',
    '🧎🏾‍♀‍➡' => 'жена клечи: средње тамна кожа и гледа удесно',
    '🧎🏿‍♀‍➡' => 'жена клечи: тамна кожа и гледа удесно',
    '🧎🏻‍♂‍➡' => 'човек клечи: свијетла кожа и гледа удесно',
    '🧎🏼‍♂‍➡' => 'човек клечи: средње свијетла кожа и гледа удесно',
    '🧎🏽‍♂‍➡' => 'човек клечи: ни свијетла ни тамна кожа и гледа удесно',
    '🧎🏾‍♂‍➡' => 'човек клечи: средње тамна кожа и гледа удесно',
    '🧎🏿‍♂‍➡' => 'човек клечи: тамна кожа и гледа удесно',
    '🧑🏻‍🦯‍➡' => 'особа са помоћним штапом: свијетла кожа и гледа удесно',
    '🧑🏼‍🦯‍➡' => 'особа са помоћним штапом: средње свијетла кожа и гледа удесно',
    '🧑🏽‍🦯‍➡' => 'особа са помоћним штапом: ни свијетла ни тамна кожа и гледа удесно',
    '🧑🏾‍🦯‍➡' => 'особа са помоћним штапом: средње тамна кожа и гледа удесно',
    '🧑🏿‍🦯‍➡' => 'особа са помоћним штапом: тамна кожа и гледа удесно',
    '👨🏻‍🦯‍➡' => 'човјек са помоћним штапом: свијетла кожа и гледа удесно',
    '👨🏼‍🦯‍➡' => 'човјек са помоћним штапом: средње свијетла кожа и гледа удесно',
    '👨🏽‍🦯‍➡' => 'човјек са помоћним штапом: ни свијетла ни тамна кожа и гледа удесно',
    '👨🏾‍🦯‍➡' => 'човјек са помоћним штапом: средње тамна кожа и гледа удесно',
    '👨🏿‍🦯‍➡' => 'човјек са помоћним штапом: тамна кожа и гледа удесно',
    '👩🏻‍🦯‍➡' => 'жена са помоћним штапом: свијетла кожа и гледа удесно',
    '👩🏼‍🦯‍➡' => 'жена са помоћним штапом: средње свијетла кожа и гледа удесно',
    '👩🏽‍🦯‍➡' => 'жена са помоћним штапом: ни свијетла ни тамна кожа и гледа удесно',
    '👩🏾‍🦯‍➡' => 'жена са помоћним штапом: средње тамна кожа и гледа удесно',
    '👩🏿‍🦯‍➡' => 'жена са помоћним штапом: тамна кожа и гледа удесно',
    '🧑🏻‍🦼‍➡' => 'особа у моторним колицима: свијетла кожа и гледа удесно',
    '🧑🏼‍🦼‍➡' => 'особа у моторним колицима: средње свијетла кожа и гледа удесно',
    '🧑🏽‍🦼‍➡' => 'особа у моторним колицима: ни свијетла ни тамна кожа и гледа удесно',
    '🧑🏾‍🦼‍➡' => 'особа у моторним колицима: средње тамна кожа и гледа удесно',
    '🧑🏿‍🦼‍➡' => 'особа у моторним колицима: тамна кожа и гледа удесно',
    '👨🏻‍🦼‍➡' => 'човјек у моторним колицима: свијетла кожа и гледа удесно',
    '👨🏼‍🦼‍➡' => 'човјек у моторним колицима: средње свијетла кожа и гледа удесно',
    '👨🏽‍🦼‍➡' => 'човјек у моторним колицима: ни свијетла ни тамна кожа и гледа удесно',
    '👨🏾‍🦼‍➡' => 'човјек у моторним колицима: средње тамна кожа и гледа удесно',
    '👨🏿‍🦼‍➡' => 'човјек у моторним колицима: тамна кожа и гледа удесно',
    '👩🏻‍🦼‍➡' => 'жена у моторним колицима: свијетла кожа и гледа удесно',
    '👩🏼‍🦼‍➡' => 'жена у моторним колицима: средње свијетла кожа и гледа удесно',
    '👩🏽‍🦼‍➡' => 'жена у моторним колицима: ни свијетла ни тамна кожа и гледа удесно',
    '👩🏾‍🦼‍➡' => 'жена у моторним колицима: средње тамна кожа и гледа удесно',
    '👩🏿‍🦼‍➡' => 'жена у моторним колицима: тамна кожа и гледа удесно',
    '🧑🏻‍🦽‍➡' => 'особа у механичким колицима: свијетла кожа и гледа удесно',
    '🧑🏼‍🦽‍➡' => 'особа у механичким колицима: средње свијетла кожа и гледа удесно',
    '🧑🏽‍🦽‍➡' => 'особа у механичким колицима: ни свијетла ни тамна кожа и гледа удесно',
    '🧑🏾‍🦽‍➡' => 'особа у механичким колицима: средње тамна кожа и гледа удесно',
    '🧑🏿‍🦽‍➡' => 'особа у механичким колицима: тамна кожа и гледа удесно',
    '👨🏻‍🦽‍➡' => 'човјек у механичким колицима: свијетла кожа и гледа удесно',
    '👨🏼‍🦽‍➡' => 'човјек у механичким колицима: средње свијетла кожа и гледа удесно',
    '👨🏽‍🦽‍➡' => 'човјек у механичким колицима: ни свијетла ни тамна кожа и гледа удесно',
    '👨🏾‍🦽‍➡' => 'човјек у механичким колицима: средње тамна кожа и гледа удесно',
    '👨🏿‍🦽‍➡' => 'човјек у механичким колицима: тамна кожа и гледа удесно',
    '👩🏻‍🦽‍➡' => 'жена у механичким колицима: свијетла кожа и гледа удесно',
    '👩🏼‍🦽‍➡' => 'жена у механичким колицима: средње свијетла кожа и гледа удесно',
    '👩🏽‍🦽‍➡' => 'жена у механичким колицима: ни свијетла ни тамна кожа и гледа удесно',
    '👩🏾‍🦽‍➡' => 'жена у механичким колицима: средње тамна кожа и гледа удесно',
    '👩🏿‍🦽‍➡' => 'жена у механичким колицима: тамна кожа и гледа удесно',
    '🏃🏻‍♀‍➡' => 'жена трчи: свијетла кожа и гледа удесно',
    '🏃🏼‍♀‍➡' => 'жена трчи: средње свијетла кожа и гледа удесно',
    '🏃🏽‍♀‍➡' => 'жена трчи: ни свијетла ни тамна кожа и гледа удесно',
    '🏃🏾‍♀‍➡' => 'жена трчи: средње тамна кожа и гледа удесно',
    '🏃🏿‍♀‍➡' => 'жена трчи: тамна кожа и гледа удесно',
    '🏃🏻‍♂‍➡' => 'мушкарац трчи: свијетла кожа и гледа удесно',
    '🏃🏼‍♂‍➡' => 'мушкарац трчи: средње свијетла кожа и гледа удесно',
    '🏃🏽‍♂‍➡' => 'мушкарац трчи: ни свијетла ни тамна кожа и гледа удесно',
    '🏃🏾‍♂‍➡' => 'мушкарац трчи: средње тамна кожа и гледа удесно',
    '🏃🏿‍♂‍➡' => 'мушкарац трчи: тамна кожа и гледа удесно',
    '🫱🏻‍🫲🏼' => 'руковање: свијетла кожа и средње свијетла кожа',
    '🫱🏻‍🫲🏽' => 'руковање: свијетла кожа и ни свијетла ни тамна кожа',
    '🫱🏻‍🫲🏾' => 'руковање: свијетла кожа и средње тамна кожа',
    '🫱🏻‍🫲🏿' => 'руковање: свијетла кожа и тамна кожа',
    '🫱🏼‍🫲🏻' => 'руковање: средње свијетла кожа и свијетла кожа',
    '🫱🏼‍🫲🏽' => 'руковање: средње свијетла кожа и ни свијетла ни тамна кожа',
    '🫱🏼‍🫲🏾' => 'руковање: средње свијетла кожа и средње тамна кожа',
    '🫱🏼‍🫲🏿' => 'руковање: средње свијетла кожа и тамна кожа',
    '🫱🏽‍🫲🏻' => 'руковање: ни свијетла ни тамна кожа и свијетла кожа',
    '🫱🏽‍🫲🏼' => 'руковање: ни свијетла ни тамна кожа и средње свијетла кожа',
    '🫱🏽‍🫲🏾' => 'руковање: ни свијетла ни тамна кожа и средње тамна кожа',
    '🫱🏽‍🫲🏿' => 'руковање: ни свијетла ни тамна кожа и тамна кожа',
    '🫱🏾‍🫲🏻' => 'руковање: средње тамна кожа и свијетла кожа',
    '🫱🏾‍🫲🏼' => 'руковање: средње тамна кожа и средње свијетла кожа',
    '🫱🏾‍🫲🏽' => 'руковање: средње тамна кожа и ни свијетла ни тамна кожа',
    '🫱🏾‍🫲🏿' => 'руковање: средње тамна кожа и тамна кожа',
    '🫱🏿‍🫲🏻' => 'руковање: тамна кожа и свијетла кожа',
    '🫱🏿‍🫲🏼' => 'руковање: тамна кожа и средње свијетла кожа',
    '🫱🏿‍🫲🏽' => 'руковање: тамна кожа и ни свијетла ни тамна кожа',
    '🫱🏿‍🫲🏾' => 'руковање: тамна кожа и средње тамна кожа',
    '🚶‍♀‍➡' => 'жена хода: гледа удесно',
    '🚶‍♂‍➡' => 'мушкарац хода: гледа удесно',
    '🧎‍♀‍➡' => 'жена клечи: гледа удесно',
    '🧎‍♂‍➡' => 'човек клечи: гледа удесно',
    '🧑‍🦯‍➡' => 'особа са помоћним штапом: гледа удесно',
    '👨‍🦯‍➡' => 'човјек са помоћним штапом: гледа удесно',
    '👩‍🦯‍➡' => 'жена са помоћним штапом: гледа удесно',
    '🧑‍🦼‍➡' => 'особа у моторним колицима: гледа удесно',
    '👨‍🦼‍➡' => 'човјек у моторним колицима: гледа удесно',
    '👩‍🦼‍➡' => 'жена у моторним колицима: гледа удесно',
    '🧑‍🦽‍➡' => 'особа у механичким колицима: гледа удесно',
    '👨‍🦽‍➡' => 'човјек у механичким колицима: гледа удесно',
    '👩‍🦽‍➡' => 'жена у механичким колицима: гледа удесно',
    '🏃‍♀‍➡' => 'жена трчи: гледа удесно',
    '🏃‍♂‍➡' => 'мушкарац трчи: гледа удесно',
    '👩‍❤‍👨' => 'пар са срцем: жена и мушкарац',
    '👨‍❤‍👨' => 'пар са срцем: мушкарац и мушкарац',
    '👩‍❤‍👩' => 'пар са срцем: жена и жена',
    '👨‍👩‍👦' => 'породица: мушкарац, жена и дјечак',
    '👨‍👩‍👧' => 'породица: мушкарац, жена и дјевојчица',
    '👨‍👨‍👦' => 'породица: мушкарац, мушкарац и дјечак',
    '👨‍👨‍👧' => 'породица: мушкарац, мушкарац и дјевојчица',
    '👩‍👩‍👦' => 'породица: жена, жена и дјечак',
    '👩‍👩‍👧' => 'породица: жена, жена и дјевојчица',
    '👨‍👦‍👦' => 'породица: мушкарац, дјечак и дјечак',
    '👨‍👧‍👦' => 'породица: мушкарац, дјевојчица и дјечак',
    '👨‍👧‍👧' => 'породица: мушкарац, дјевојчица и дјевојчица',
    '👩‍👦‍👦' => 'породица: жена, дјечак и дјечак',
    '👩‍👧‍👦' => 'породица: жена, дјевојчица и дјечак',
    '👩‍👧‍👧' => 'породица: жена, дјевојчица и дјевојчица',
    '🧑‍🤝‍🧑' => 'особе се држе за руке',
    '🧑‍🧑‍🧒' => 'породица: одрасла особа, одрасла особа, дијете',
    '🧑‍🧒‍🧒' => 'породица: одрасла особа, дијете, дијете',
    '🧑🏻‍🦰' => 'одрасла особа: свијетла кожа и црвена коса',
    '🧑🏼‍🦰' => 'одрасла особа: средње свијетла кожа и црвена коса',
    '🧑🏽‍🦰' => 'одрасла особа: ни свијетла ни тамна кожа и црвена коса',
    '🧑🏾‍🦰' => 'одрасла особа: средње тамна кожа и црвена коса',
    '🧑🏿‍🦰' => 'одрасла особа: тамна кожа и црвена коса',
    '🧑🏻‍🦱' => 'одрасла особа: свијетла кожа и коврџава коса',
    '🧑🏼‍🦱' => 'одрасла особа: средње свијетла кожа и коврџава коса',
    '🧑🏽‍🦱' => 'одрасла особа: ни свијетла ни тамна кожа и коврџава коса',
    '🧑🏾‍🦱' => 'одрасла особа: средње тамна кожа и коврџава коса',
    '🧑🏿‍🦱' => 'одрасла особа: тамна кожа и коврџава коса',
    '🧑🏻‍🦳' => 'одрасла особа: свијетла кожа и сиједа коса',
    '🧑🏼‍🦳' => 'одрасла особа: средње свијетла кожа и сиједа коса',
    '🧑🏽‍🦳' => 'одрасла особа: ни свијетла ни тамна кожа и сиједа коса',
    '🧑🏾‍🦳' => 'одрасла особа: средње тамна кожа и сиједа коса',
    '🧑🏿‍🦳' => 'одрасла особа: тамна кожа и сиједа коса',
    '🧑🏻‍🦲' => 'одрасла особа: свијетла кожа и ћелав',
    '🧑🏼‍🦲' => 'одрасла особа: средње свијетла кожа и ћелав',
    '🧑🏽‍🦲' => 'одрасла особа: ни свијетла ни тамна кожа и ћелав',
    '🧑🏾‍🦲' => 'одрасла особа: средње тамна кожа и ћелав',
    '🧑🏿‍🦲' => 'одрасла особа: тамна кожа и ћелав',
    '🧑🏻‍🩰' => 'балетан: свијетла кожа',
    '🧑🏼‍🩰' => 'балетан: средње свијетла кожа',
    '🧑🏽‍🩰' => 'балетан: ни свијетла ни тамна кожа',
    '🧑🏾‍🩰' => 'балетан: средње тамна кожа',
    '🧑🏿‍🩰' => 'балетан: тамна кожа',
    '🧔🏻‍♂' => 'мушкарац: свијетла кожа и брада',
    '🧔🏼‍♂' => 'мушкарац: средње свијетла кожа и брада',
    '🧔🏽‍♂' => 'мушкарац: ни свијетла ни тамна кожа и брада',
    '🧔🏾‍♂' => 'мушкарац: средње тамна кожа и брада',
    '🧔🏿‍♂' => 'мушкарац: тамна кожа и брада',
    '👱🏻‍♂' => 'плав мушкарац: свијетла кожа',
    '👱🏼‍♂' => 'плав мушкарац: средње свијетла кожа',
    '👱🏽‍♂' => 'плав мушкарац: ни свијетла ни тамна кожа',
    '👱🏾‍♂' => 'плав мушкарац: средње тамна кожа',
    '👱🏿‍♂' => 'плав мушкарац: тамна кожа',
    '👨🏻‍🦰' => 'мушкарац: свијетла кожа и црвена коса',
    '👨🏼‍🦰' => 'мушкарац: средње свијетла кожа и црвена коса',
    '👨🏽‍🦰' => 'мушкарац: ни свијетла ни тамна кожа и црвена коса',
    '👨🏾‍🦰' => 'мушкарац: средње тамна кожа и црвена коса',
    '👨🏿‍🦰' => 'мушкарац: тамна кожа и црвена коса',
    '👨🏻‍🦱' => 'мушкарац: свијетла кожа и коврџава коса',
    '👨🏼‍🦱' => 'мушкарац: средње свијетла кожа и коврџава коса',
    '👨🏽‍🦱' => 'мушкарац: ни свијетла ни тамна кожа и коврџава коса',
    '👨🏾‍🦱' => 'мушкарац: средње тамна кожа и коврџава коса',
    '👨🏿‍🦱' => 'мушкарац: тамна кожа и коврџава коса',
    '👨🏻‍🦳' => 'мушкарац: свијетла кожа и сиједа коса',
    '👨🏼‍🦳' => 'мушкарац: средње свијетла кожа и сиједа коса',
    '👨🏽‍🦳' => 'мушкарац: ни свијетла ни тамна кожа и сиједа коса',
    '👨🏾‍🦳' => 'мушкарац: средње тамна кожа и сиједа коса',
    '👨🏿‍🦳' => 'мушкарац: тамна кожа и сиједа коса',
    '👨🏻‍🦲' => 'мушкарац: свијетла кожа и ћелав',
    '👨🏼‍🦲' => 'мушкарац: средње свијетла кожа и ћелав',
    '👨🏽‍🦲' => 'мушкарац: ни свијетла ни тамна кожа и ћелав',
    '👨🏾‍🦲' => 'мушкарац: средње тамна кожа и ћелав',
    '👨🏿‍🦲' => 'мушкарац: тамна кожа и ћелав',
    '🧔🏻‍♀' => 'жена: свијетла кожа и брада',
    '🧔🏼‍♀' => 'жена: средње свијетла кожа и брада',
    '🧔🏽‍♀' => 'жена: ни свијетла ни тамна кожа и брада',
    '🧔🏾‍♀' => 'жена: средње тамна кожа и брада',
    '🧔🏿‍♀' => 'жена: тамна кожа и брада',
    '👱🏻‍♀' => 'плавуша: свијетла кожа',
    '👱🏼‍♀' => 'плавуша: средње свијетла кожа',
    '👱🏽‍♀' => 'плавуша: ни свијетла ни тамна кожа',
    '👱🏾‍♀' => 'плавуша: средње тамна кожа',
    '👱🏿‍♀' => 'плавуша: тамна кожа',
    '👩🏻‍🦰' => 'жена: свијетла кожа и црвена коса',
    '👩🏼‍🦰' => 'жена: средње свијетла кожа и црвена коса',
    '👩🏽‍🦰' => 'жена: ни свијетла ни тамна кожа и црвена коса',
    '👩🏾‍🦰' => 'жена: средње тамна кожа и црвена коса',
    '👩🏿‍🦰' => 'жена: тамна кожа и црвена коса',
    '👩🏻‍🦱' => 'жена: свијетла кожа и коврџава коса',
    '👩🏼‍🦱' => 'жена: средње свијетла кожа и коврџава коса',
    '👩🏽‍🦱' => 'жена: ни свијетла ни тамна кожа и коврџава коса',
    '👩🏾‍🦱' => 'жена: средње тамна кожа и коврџава коса',
    '👩🏿‍🦱' => 'жена: тамна кожа и коврџава коса',
    '👩🏻‍🦳' => 'жена: свијетла кожа и сиједа коса',
    '👩🏼‍🦳' => 'жена: средње свијетла кожа и сиједа коса',
    '👩🏽‍🦳' => 'жена: ни свијетла ни тамна кожа и сиједа коса',
    '👩🏾‍🦳' => 'жена: средње тамна кожа и сиједа коса',
    '👩🏿‍🦳' => 'жена: тамна кожа и сиједа коса',
    '👩🏻‍🦲' => 'жена: свијетла кожа и ћелав',
    '👩🏼‍🦲' => 'жена: средње свијетла кожа и ћелав',
    '👩🏽‍🦲' => 'жена: ни свијетла ни тамна кожа и ћелав',
    '👩🏾‍🦲' => 'жена: средње тамна кожа и ћелав',
    '👩🏿‍🦲' => 'жена: тамна кожа и ћелав',
    '🙍🏻‍♂' => 'намрштен мушкарац: свијетла кожа',
    '🙍🏼‍♂' => 'намрштен мушкарац: средње свијетла кожа',
    '🙍🏽‍♂' => 'намрштен мушкарац: ни свијетла ни тамна кожа',
    '🙍🏾‍♂' => 'намрштен мушкарац: средње тамна кожа',
    '🙍🏿‍♂' => 'намрштен мушкарац: тамна кожа',
    '🙍🏻‍♀' => 'намрштена жена: свијетла кожа',
    '🙍🏼‍♀' => 'намрштена жена: средње свијетла кожа',
    '🙍🏽‍♀' => 'намрштена жена: ни свијетла ни тамна кожа',
    '🙍🏾‍♀' => 'намрштена жена: средње тамна кожа',
    '🙍🏿‍♀' => 'намрштена жена: тамна кожа',
    '🙎🏻‍♂' => 'надурен мушкарац: свијетла кожа',
    '🙎🏼‍♂' => 'надурен мушкарац: средње свијетла кожа',
    '🙎🏽‍♂' => 'надурен мушкарац: ни свијетла ни тамна кожа',
    '🙎🏾‍♂' => 'надурен мушкарац: средње тамна кожа',
    '🙎🏿‍♂' => 'надурен мушкарац: тамна кожа',
    '🙎🏻‍♀' => 'надурена жена: свијетла кожа',
    '🙎🏼‍♀' => 'надурена жена: средње свијетла кожа',
    '🙎🏽‍♀' => 'надурена жена: ни свијетла ни тамна кожа',
    '🙎🏾‍♀' => 'надурена жена: средње тамна кожа',
    '🙎🏿‍♀' => 'надурена жена: тамна кожа',
    '🙅🏻‍♂' => 'мушкарац показује „не“: свијетла кожа',
    '🙅🏼‍♂' => 'мушкарац показује „не“: средње свијетла кожа',
    '🙅🏽‍♂' => 'мушкарац показује „не“: ни свијетла ни тамна кожа',
    '🙅🏾‍♂' => 'мушкарац показује „не“: средње тамна кожа',
    '🙅🏿‍♂' => 'мушкарац показује „не“: тамна кожа',
    '🙅🏻‍♀' => 'жена показује „не“: свијетла кожа',
    '🙅🏼‍♀' => 'жена показује „не“: средње свијетла кожа',
    '🙅🏽‍♀' => 'жена показује „не“: ни свијетла ни тамна кожа',
    '🙅🏾‍♀' => 'жена показује „не“: средње тамна кожа',
    '🙅🏿‍♀' => 'жена показује „не“: тамна кожа',
    '🙆🏻‍♂' => 'мушкарац показује „ок“: свијетла кожа',
    '🙆🏼‍♂' => 'мушкарац показује „ок“: средње свијетла кожа',
    '🙆🏽‍♂' => 'мушкарац показује „ок“: ни свијетла ни тамна кожа',
    '🙆🏾‍♂' => 'мушкарац показује „ок“: средње тамна кожа',
    '🙆🏿‍♂' => 'мушкарац показује „ок“: тамна кожа',
    '🙆🏻‍♀' => 'жена показује „ок“: свијетла кожа',
    '🙆🏼‍♀' => 'жена показује „ок“: средње свијетла кожа',
    '🙆🏽‍♀' => 'жена показује „ок“: ни свијетла ни тамна кожа',
    '🙆🏾‍♀' => 'жена показује „ок“: средње тамна кожа',
    '🙆🏿‍♀' => 'жена показује „ок“: тамна кожа',
    '💁🏻‍♂' => 'мушкарац открива намјере: свијетла кожа',
    '💁🏼‍♂' => 'мушкарац открива намјере: средње свијетла кожа',
    '💁🏽‍♂' => 'мушкарац открива намјере: ни свијетла ни тамна кожа',
    '💁🏾‍♂' => 'мушкарац открива намјере: средње тамна кожа',
    '💁🏿‍♂' => 'мушкарац открива намјере: тамна кожа',
    '💁🏻‍♀' => 'жена открива намјере: свијетла кожа',
    '💁🏼‍♀' => 'жена открива намјере: средње свијетла кожа',
    '💁🏽‍♀' => 'жена открива намјере: ни свијетла ни тамна кожа',
    '💁🏾‍♀' => 'жена открива намјере: средње тамна кожа',
    '💁🏿‍♀' => 'жена открива намјере: тамна кожа',
    '🙋🏻‍♂' => 'мушкарац подиже руку: свијетла кожа',
    '🙋🏼‍♂' => 'мушкарац подиже руку: средње свијетла кожа',
    '🙋🏽‍♂' => 'мушкарац подиже руку: ни свијетла ни тамна кожа',
    '🙋🏾‍♂' => 'мушкарац подиже руку: средње тамна кожа',
    '🙋🏿‍♂' => 'мушкарац подиже руку: тамна кожа',
    '🙋🏻‍♀' => 'жена подиже руку: свијетла кожа',
    '🙋🏼‍♀' => 'жена подиже руку: средње свијетла кожа',
    '🙋🏽‍♀' => 'жена подиже руку: ни свијетла ни тамна кожа',
    '🙋🏾‍♀' => 'жена подиже руку: средње тамна кожа',
    '🙋🏿‍♀' => 'жена подиже руку: тамна кожа',
    '🧏🏻‍♂' => 'глув човјек: свијетла кожа',
    '🧏🏼‍♂' => 'глув човјек: средње свијетла кожа',
    '🧏🏽‍♂' => 'глув човјек: ни свијетла ни тамна кожа',
    '🧏🏾‍♂' => 'глув човјек: средње тамна кожа',
    '🧏🏿‍♂' => 'глув човјек: тамна кожа',
    '🧏🏻‍♀' => 'глува жена: свијетла кожа',
    '🧏🏼‍♀' => 'глува жена: средње свијетла кожа',
    '🧏🏽‍♀' => 'глува жена: ни свијетла ни тамна кожа',
    '🧏🏾‍♀' => 'глува жена: средње тамна кожа',
    '🧏🏿‍♀' => 'глува жена: тамна кожа',
    '🙇🏻‍♂' => 'мушки дубоки наклон: свијетла кожа',
    '🙇🏼‍♂' => 'мушки дубоки наклон: средње свијетла кожа',
    '🙇🏽‍♂' => 'мушки дубоки наклон: ни свијетла ни тамна кожа',
    '🙇🏾‍♂' => 'мушки дубоки наклон: средње тамна кожа',
    '🙇🏿‍♂' => 'мушки дубоки наклон: тамна кожа',
    '🙇🏻‍♀' => 'женски дубоки наклон: свијетла кожа',
    '🙇🏼‍♀' => 'женски дубоки наклон: средње свијетла кожа',
    '🙇🏽‍♀' => 'женски дубоки наклон: ни свијетла ни тамна кожа',
    '🙇🏾‍♀' => 'женски дубоки наклон: средње тамна кожа',
    '🙇🏿‍♀' => 'женски дубоки наклон: тамна кожа',
    '🤦🏻‍♂' => 'мушкарац с руком на челу: свијетла кожа',
    '🤦🏼‍♂' => 'мушкарац с руком на челу: средње свијетла кожа',
    '🤦🏽‍♂' => 'мушкарац с руком на челу: ни свијетла ни тамна кожа',
    '🤦🏾‍♂' => 'мушкарац с руком на челу: средње тамна кожа',
    '🤦🏿‍♂' => 'мушкарац с руком на челу: тамна кожа',
    '🤦🏻‍♀' => 'жена с руком на челу: свијетла кожа',
    '🤦🏼‍♀' => 'жена с руком на челу: средње свијетла кожа',
    '🤦🏽‍♀' => 'жена с руком на челу: ни свијетла ни тамна кожа',
    '🤦🏾‍♀' => 'жена с руком на челу: средње тамна кожа',
    '🤦🏿‍♀' => 'жена с руком на челу: тамна кожа',
    '🤷🏻‍♂' => 'мушкарац слијеже раменима: свијетла кожа',
    '🤷🏼‍♂' => 'мушкарац слијеже раменима: средње свијетла кожа',
    '🤷🏽‍♂' => 'мушкарац слијеже раменима: ни свијетла ни тамна кожа',
    '🤷🏾‍♂' => 'мушкарац слијеже раменима: средње тамна кожа',
    '🤷🏿‍♂' => 'мушкарац слијеже раменима: тамна кожа',
    '🤷🏻‍♀' => 'жена слијеже раменима: свијетла кожа',
    '🤷🏼‍♀' => 'жена слијеже раменима: средње свијетла кожа',
    '🤷🏽‍♀' => 'жена слијеже раменима: ни свијетла ни тамна кожа',
    '🤷🏾‍♀' => 'жена слијеже раменима: средње тамна кожа',
    '🤷🏿‍♀' => 'жена слијеже раменима: тамна кожа',
    '🧑🏻‍⚕' => 'здравствени радник: свијетла кожа',
    '🧑🏼‍⚕' => 'здравствени радник: средње свијетла кожа',
    '🧑🏽‍⚕' => 'здравствени радник: ни свијетла ни тамна кожа',
    '🧑🏾‍⚕' => 'здравствени радник: средње тамна кожа',
    '🧑🏿‍⚕' => 'здравствени радник: тамна кожа',
    '👨🏻‍⚕' => 'мушкарац здравствени радник: свијетла кожа',
    '👨🏼‍⚕' => 'мушкарац здравствени радник: средње свијетла кожа',
    '👨🏽‍⚕' => 'мушкарац здравствени радник: ни свијетла ни тамна кожа',
    '👨🏾‍⚕' => 'мушкарац здравствени радник: средње тамна кожа',
    '👨🏿‍⚕' => 'мушкарац здравствени радник: тамна кожа',
    '👩🏻‍⚕' => 'здравствена радница: свијетла кожа',
    '👩🏼‍⚕' => 'здравствена радница: средње свијетла кожа',
    '👩🏽‍⚕' => 'здравствена радница: ни свијетла ни тамна кожа',
    '👩🏾‍⚕' => 'здравствена радница: средње тамна кожа',
    '👩🏿‍⚕' => 'здравствена радница: тамна кожа',
    '🧑🏻‍🎓' => 'студент(киња): свијетла кожа',
    '🧑🏼‍🎓' => 'студент(киња): средње свијетла кожа',
    '🧑🏽‍🎓' => 'студент(киња): ни свијетла ни тамна кожа',
    '🧑🏾‍🎓' => 'студент(киња): средње тамна кожа',
    '🧑🏿‍🎓' => 'студент(киња): тамна кожа',
    '👨🏻‍🎓' => 'студент: свијетла кожа',
    '👨🏼‍🎓' => 'студент: средње свијетла кожа',
    '👨🏽‍🎓' => 'студент: ни свијетла ни тамна кожа',
    '👨🏾‍🎓' => 'студент: средње тамна кожа',
    '👨🏿‍🎓' => 'студент: тамна кожа',
    '👩🏻‍🎓' => 'студенткиња: свијетла кожа',
    '👩🏼‍🎓' => 'студенткиња: средње свијетла кожа',
    '👩🏽‍🎓' => 'студенткиња: ни свијетла ни тамна кожа',
    '👩🏾‍🎓' => 'студенткиња: средње тамна кожа',
    '👩🏿‍🎓' => 'студенткиња: тамна кожа',
    '🧑🏻‍🏫' => 'учитељ: свијетла кожа',
    '🧑🏼‍🏫' => 'учитељ: средње свијетла кожа',
    '🧑🏽‍🏫' => 'учитељ: ни свијетла ни тамна кожа',
    '🧑🏾‍🏫' => 'учитељ: средње тамна кожа',
    '🧑🏿‍🏫' => 'учитељ: тамна кожа',
    '👨🏻‍🏫' => 'професор: свијетла кожа',
    '👨🏼‍🏫' => 'професор: средње свијетла кожа',
    '👨🏽‍🏫' => 'професор: ни свијетла ни тамна кожа',
    '👨🏾‍🏫' => 'професор: средње тамна кожа',
    '👨🏿‍🏫' => 'професор: тамна кожа',
    '👩🏻‍🏫' => 'професорка: свијетла кожа',
    '👩🏼‍🏫' => 'професорка: средње свијетла кожа',
    '👩🏽‍🏫' => 'професорка: ни свијетла ни тамна кожа',
    '👩🏾‍🏫' => 'професорка: средње тамна кожа',
    '👩🏿‍🏫' => 'професорка: тамна кожа',
    '🧑🏻‍⚖' => 'судија/ница: свијетла кожа',
    '🧑🏼‍⚖' => 'судија/ница: средње свијетла кожа',
    '🧑🏽‍⚖' => 'судија/ница: ни свијетла ни тамна кожа',
    '🧑🏾‍⚖' => 'судија/ница: средње тамна кожа',
    '🧑🏿‍⚖' => 'судија/ница: тамна кожа',
    '👨🏻‍⚖' => 'мушкарац судија: свијетла кожа',
    '👨🏼‍⚖' => 'мушкарац судија: средње свијетла кожа',
    '👨🏽‍⚖' => 'мушкарац судија: ни свијетла ни тамна кожа',
    '👨🏾‍⚖' => 'мушкарац судија: средње тамна кожа',
    '👨🏿‍⚖' => 'мушкарац судија: тамна кожа',
    '👩🏻‍⚖' => 'жена судија: свијетла кожа',
    '👩🏼‍⚖' => 'жена судија: средње свијетла кожа',
    '👩🏽‍⚖' => 'жена судија: ни свијетла ни тамна кожа',
    '👩🏾‍⚖' => 'жена судија: средње тамна кожа',
    '👩🏿‍⚖' => 'жена судија: тамна кожа',
    '🧑🏻‍🌾' => 'пољопривредник: свијетла кожа',
    '🧑🏼‍🌾' => 'пољопривредник: средње свијетла кожа',
    '🧑🏽‍🌾' => 'пољопривредник: ни свијетла ни тамна кожа',
    '🧑🏾‍🌾' => 'пољопривредник: средње тамна кожа',
    '🧑🏿‍🌾' => 'пољопривредник: тамна кожа',
    '👨🏻‍🌾' => 'мушкарац пољопривредник: свијетла кожа',
    '👨🏼‍🌾' => 'мушкарац пољопривредник: средње свијетла кожа',
    '👨🏽‍🌾' => 'мушкарац пољопривредник: ни свијетла ни тамна кожа',
    '👨🏾‍🌾' => 'мушкарац пољопривредник: средње тамна кожа',
    '👨🏿‍🌾' => 'мушкарац пољопривредник: тамна кожа',
    '👩🏻‍🌾' => 'пољопривредница: свијетла кожа',
    '👩🏼‍🌾' => 'пољопривредница: средње свијетла кожа',
    '👩🏽‍🌾' => 'пољопривредница: ни свијетла ни тамна кожа',
    '👩🏾‍🌾' => 'пољопривредница: средње тамна кожа',
    '👩🏿‍🌾' => 'пољопривредница: тамна кожа',
    '🧑🏻‍🍳' => 'кувар: свијетла кожа',
    '🧑🏼‍🍳' => 'кувар: средње свијетла кожа',
    '🧑🏽‍🍳' => 'кувар: ни свијетла ни тамна кожа',
    '🧑🏾‍🍳' => 'кувар: средње тамна кожа',
    '🧑🏿‍🍳' => 'кувар: тамна кожа',
    '👨🏻‍🍳' => 'мушкарац кувар: свијетла кожа',
    '👨🏼‍🍳' => 'мушкарац кувар: средње свијетла кожа',
    '👨🏽‍🍳' => 'мушкарац кувар: ни свијетла ни тамна кожа',
    '👨🏾‍🍳' => 'мушкарац кувар: средње тамна кожа',
    '👨🏿‍🍳' => 'мушкарац кувар: тамна кожа',
    '👩🏻‍🍳' => 'куварица: свијетла кожа',
    '👩🏼‍🍳' => 'куварица: средње свијетла кожа',
    '👩🏽‍🍳' => 'куварица: ни свијетла ни тамна кожа',
    '👩🏾‍🍳' => 'куварица: средње тамна кожа',
    '👩🏿‍🍳' => 'куварица: тамна кожа',
    '🧑🏻‍🔧' => 'механичар: свијетла кожа',
    '🧑🏼‍🔧' => 'механичар: средње свијетла кожа',
    '🧑🏽‍🔧' => 'механичар: ни свијетла ни тамна кожа',
    '🧑🏾‍🔧' => 'механичар: средње тамна кожа',
    '🧑🏿‍🔧' => 'механичар: тамна кожа',
    '👨🏻‍🔧' => 'мушкарац механичар: свијетла кожа',
    '👨🏼‍🔧' => 'мушкарац механичар: средње свијетла кожа',
    '👨🏽‍🔧' => 'мушкарац механичар: ни свијетла ни тамна кожа',
    '👨🏾‍🔧' => 'мушкарац механичар: средње тамна кожа',
    '👨🏿‍🔧' => 'мушкарац механичар: тамна кожа',
    '👩🏻‍🔧' => 'механичарка: свијетла кожа',
    '👩🏼‍🔧' => 'механичарка: средње свијетла кожа',
    '👩🏽‍🔧' => 'механичарка: ни свијетла ни тамна кожа',
    '👩🏾‍🔧' => 'механичарка: средње тамна кожа',
    '👩🏿‍🔧' => 'механичарка: тамна кожа',
    '🧑🏻‍🏭' => 'радник у фабрици: свијетла кожа',
    '🧑🏼‍🏭' => 'радник у фабрици: средње свијетла кожа',
    '🧑🏽‍🏭' => 'радник у фабрици: ни свијетла ни тамна кожа',
    '🧑🏾‍🏭' => 'радник у фабрици: средње тамна кожа',
    '🧑🏿‍🏭' => 'радник у фабрици: тамна кожа',
    '👨🏻‍🏭' => 'радник: свијетла кожа',
    '👨🏼‍🏭' => 'радник: средње свијетла кожа',
    '👨🏽‍🏭' => 'радник: ни свијетла ни тамна кожа',
    '👨🏾‍🏭' => 'радник: средње тамна кожа',
    '👨🏿‍🏭' => 'радник: тамна кожа',
    '👩🏻‍🏭' => 'радница: свијетла кожа',
    '👩🏼‍🏭' => 'радница: средње свијетла кожа',
    '👩🏽‍🏭' => 'радница: ни свијетла ни тамна кожа',
    '👩🏾‍🏭' => 'радница: средње тамна кожа',
    '👩🏿‍🏭' => 'радница: тамна кожа',
    '🧑🏻‍💼' => 'канцеларијски радник: свијетла кожа',
    '🧑🏼‍💼' => 'канцеларијски радник: средње свијетла кожа',
    '🧑🏽‍💼' => 'канцеларијски радник: ни свијетла ни тамна кожа',
    '🧑🏾‍💼' => 'канцеларијски радник: средње тамна кожа',
    '🧑🏿‍💼' => 'канцеларијски радник: тамна кожа',
    '👨🏻‍💼' => 'мушкарац у канцеларији: свијетла кожа',
    '👨🏼‍💼' => 'мушкарац у канцеларији: средње свијетла кожа',
    '👨🏽‍💼' => 'мушкарац у канцеларији: ни свијетла ни тамна кожа',
    '👨🏾‍💼' => 'мушкарац у канцеларији: средње тамна кожа',
    '👨🏿‍💼' => 'мушкарац у канцеларији: тамна кожа',
    '👩🏻‍💼' => 'жена у канцеларији: свијетла кожа',
    '👩🏼‍💼' => 'жена у канцеларији: средње свијетла кожа',
    '👩🏽‍💼' => 'жена у канцеларији: ни свијетла ни тамна кожа',
    '👩🏾‍💼' => 'жена у канцеларији: средње тамна кожа',
    '👩🏿‍💼' => 'жена у канцеларији: тамна кожа',
    '🧑🏻‍🔬' => 'научник/ца: свијетла кожа',
    '🧑🏼‍🔬' => 'научник/ца: средње свијетла кожа',
    '🧑🏽‍🔬' => 'научник/ца: ни свијетла ни тамна кожа',
    '🧑🏾‍🔬' => 'научник/ца: средње тамна кожа',
    '🧑🏿‍🔬' => 'научник/ца: тамна кожа',
    '👨🏻‍🔬' => 'научник: свијетла кожа',
    '👨🏼‍🔬' => 'научник: средње свијетла кожа',
    '👨🏽‍🔬' => 'научник: ни свијетла ни тамна кожа',
    '👨🏾‍🔬' => 'научник: средње тамна кожа',
    '👨🏿‍🔬' => 'научник: тамна кожа',
    '👩🏻‍🔬' => 'научница: свијетла кожа',
    '👩🏼‍🔬' => 'научница: средње свијетла кожа',
    '👩🏽‍🔬' => 'научница: ни свијетла ни тамна кожа',
    '👩🏾‍🔬' => 'научница: средње тамна кожа',
    '👩🏿‍🔬' => 'научница: тамна кожа',
    '🧑🏻‍💻' => 'технолог: свијетла кожа',
    '🧑🏼‍💻' => 'технолог: средње свијетла кожа',
    '🧑🏽‍💻' => 'технолог: ни свијетла ни тамна кожа',
    '🧑🏾‍💻' => 'технолог: средње тамна кожа',
    '🧑🏿‍💻' => 'технолог: тамна кожа',
    '👨🏻‍💻' => 'мушкарац технолог: свијетла кожа',
    '👨🏼‍💻' => 'мушкарац технолог: средње свијетла кожа',
    '👨🏽‍💻' => 'мушкарац технолог: ни свијетла ни тамна кожа',
    '👨🏾‍💻' => 'мушкарац технолог: средње тамна кожа',
    '👨🏿‍💻' => 'мушкарац технолог: тамна кожа',
    '👩🏻‍💻' => 'жена технолог: свијетла кожа',
    '👩🏼‍💻' => 'жена технолог: средње свијетла кожа',
    '👩🏽‍💻' => 'жена технолог: ни свијетла ни тамна кожа',
    '👩🏾‍💻' => 'жена технолог: средње тамна кожа',
    '👩🏿‍💻' => 'жена технолог: тамна кожа',
    '🧑🏻‍🎤' => 'пјевач: свијетла кожа',
    '🧑🏼‍🎤' => 'пјевач: средње свијетла кожа',
    '🧑🏽‍🎤' => 'пјевач: ни свијетла ни тамна кожа',
    '🧑🏾‍🎤' => 'пјевач: средње тамна кожа',
    '🧑🏿‍🎤' => 'пјевач: тамна кожа',
    '👨🏻‍🎤' => 'мушкарац пјевач: свијетла кожа',
    '👨🏼‍🎤' => 'мушкарац пјевач: средње свијетла кожа',
    '👨🏽‍🎤' => 'мушкарац пјевач: ни свијетла ни тамна кожа',
    '👨🏾‍🎤' => 'мушкарац пјевач: средње тамна кожа',
    '👨🏿‍🎤' => 'мушкарац пјевач: тамна кожа',
    '👩🏻‍🎤' => 'пјевачица: свијетла кожа',
    '👩🏼‍🎤' => 'пјевачица: средње свијетла кожа',
    '👩🏽‍🎤' => 'пјевачица: ни свијетла ни тамна кожа',
    '👩🏾‍🎤' => 'пјевачица: средње тамна кожа',
    '👩🏿‍🎤' => 'пјевачица: тамна кожа',
    '🧑🏻‍🎨' => 'умјетник: свијетла кожа',
    '🧑🏼‍🎨' => 'умјетник: средње свијетла кожа',
    '🧑🏽‍🎨' => 'умјетник: ни свијетла ни тамна кожа',
    '🧑🏾‍🎨' => 'умјетник: средње тамна кожа',
    '🧑🏿‍🎨' => 'умјетник: тамна кожа',
    '👨🏻‍🎨' => 'мушкарац умјетник: свијетла кожа',
    '👨🏼‍🎨' => 'мушкарац умјетник: средње свијетла кожа',
    '👨🏽‍🎨' => 'мушкарац умјетник: ни свијетла ни тамна кожа',
    '👨🏾‍🎨' => 'мушкарац умјетник: средње тамна кожа',
    '👨🏿‍🎨' => 'мушкарац умјетник: тамна кожа',
    '👩🏻‍🎨' => 'умјетница: свијетла кожа',
    '👩🏼‍🎨' => 'умјетница: средње свијетла кожа',
    '👩🏽‍🎨' => 'умјетница: ни свијетла ни тамна кожа',
    '👩🏾‍🎨' => 'умјетница: средње тамна кожа',
    '👩🏿‍🎨' => 'умјетница: тамна кожа',
    '🧑🏻‍✈' => 'пилот(киња): свијетла кожа',
    '🧑🏼‍✈' => 'пилот(киња): средње свијетла кожа',
    '🧑🏽‍✈' => 'пилот(киња): ни свијетла ни тамна кожа',
    '🧑🏾‍✈' => 'пилот(киња): средње тамна кожа',
    '🧑🏿‍✈' => 'пилот(киња): тамна кожа',
    '👨🏻‍✈' => 'пилот: свијетла кожа',
    '👨🏼‍✈' => 'пилот: средње свијетла кожа',
    '👨🏽‍✈' => 'пилот: ни свијетла ни тамна кожа',
    '👨🏾‍✈' => 'пилот: средње тамна кожа',
    '👨🏿‍✈' => 'пилот: тамна кожа',
    '👩🏻‍✈' => 'жена пилот: свијетла кожа',
    '👩🏼‍✈' => 'жена пилот: средње свијетла кожа',
    '👩🏽‍✈' => 'жена пилот: ни свијетла ни тамна кожа',
    '👩🏾‍✈' => 'жена пилот: средње тамна кожа',
    '👩🏿‍✈' => 'жена пилот: тамна кожа',
    '🧑🏻‍🚀' => 'астронаут: свијетла кожа',
    '🧑🏼‍🚀' => 'астронаут: средње свијетла кожа',
    '🧑🏽‍🚀' => 'астронаут: ни свијетла ни тамна кожа',
    '🧑🏾‍🚀' => 'астронаут: средње тамна кожа',
    '🧑🏿‍🚀' => 'астронаут: тамна кожа',
    '👨🏻‍🚀' => 'космонаут: свијетла кожа',
    '👨🏼‍🚀' => 'космонаут: средње свијетла кожа',
    '👨🏽‍🚀' => 'космонаут: ни свијетла ни тамна кожа',
    '👨🏾‍🚀' => 'космонаут: средње тамна кожа',
    '👨🏿‍🚀' => 'космонаут: тамна кожа',
    '👩🏻‍🚀' => 'космонауткиња: свијетла кожа',
    '👩🏼‍🚀' => 'космонауткиња: средње свијетла кожа',
    '👩🏽‍🚀' => 'космонауткиња: ни свијетла ни тамна кожа',
    '👩🏾‍🚀' => 'космонауткиња: средње тамна кожа',
    '👩🏿‍🚀' => 'космонауткиња: тамна кожа',
    '🧑🏻‍🚒' => 'ватрогасац / жена ватрогасац: свијетла кожа',
    '🧑🏼‍🚒' => 'ватрогасац / жена ватрогасац: средње свијетла кожа',
    '🧑🏽‍🚒' => 'ватрогасац / жена ватрогасац: ни свијетла ни тамна кожа',
    '🧑🏾‍🚒' => 'ватрогасац / жена ватрогасац: средње тамна кожа',
    '🧑🏿‍🚒' => 'ватрогасац / жена ватрогасац: тамна кожа',
    '👨🏻‍🚒' => 'ватрогасац: свијетла кожа',
    '👨🏼‍🚒' => 'ватрогасац: средње свијетла кожа',
    '👨🏽‍🚒' => 'ватрогасац: ни свијетла ни тамна кожа',
    '👨🏾‍🚒' => 'ватрогасац: средње тамна кожа',
    '👨🏿‍🚒' => 'ватрогасац: тамна кожа',
    '👩🏻‍🚒' => 'жена ватрогасац: свијетла кожа',
    '👩🏼‍🚒' => 'жена ватрогасац: средње свијетла кожа',
    '👩🏽‍🚒' => 'жена ватрогасац: ни свијетла ни тамна кожа',
    '👩🏾‍🚒' => 'жена ватрогасац: средње тамна кожа',
    '👩🏿‍🚒' => 'жена ватрогасац: тамна кожа',
    '👮🏻‍♂' => 'полицајац: свијетла кожа',
    '👮🏼‍♂' => 'полицајац: средње свијетла кожа',
    '👮🏽‍♂' => 'полицајац: ни свијетла ни тамна кожа',
    '👮🏾‍♂' => 'полицајац: средње тамна кожа',
    '👮🏿‍♂' => 'полицајац: тамна кожа',
    '👮🏻‍♀' => 'полицајка: свијетла кожа',
    '👮🏼‍♀' => 'полицајка: средње свијетла кожа',
    '👮🏽‍♀' => 'полицајка: ни свијетла ни тамна кожа',
    '👮🏾‍♀' => 'полицајка: средње тамна кожа',
    '👮🏿‍♀' => 'полицајка: тамна кожа',
    '🕵🏻‍♂' => 'детектив: свијетла кожа',
    '🕵🏼‍♂' => 'детектив: средње свијетла кожа',
    '🕵🏽‍♂' => 'детектив: ни свијетла ни тамна кожа',
    '🕵🏾‍♂' => 'детектив: средње тамна кожа',
    '🕵🏿‍♂' => 'детектив: тамна кожа',
    '🕵🏻‍♀' => 'детективка: свијетла кожа',
    '🕵🏼‍♀' => 'детективка: средње свијетла кожа',
    '🕵🏽‍♀' => 'детективка: ни свијетла ни тамна кожа',
    '🕵🏾‍♀' => 'детективка: средње тамна кожа',
    '🕵🏿‍♀' => 'детективка: тамна кожа',
    '💂🏻‍♂' => 'гардиста: свијетла кожа',
    '💂🏼‍♂' => 'гардиста: средње свијетла кожа',
    '💂🏽‍♂' => 'гардиста: ни свијетла ни тамна кожа',
    '💂🏾‍♂' => 'гардиста: средње тамна кожа',
    '💂🏿‍♂' => 'гардиста: тамна кожа',
    '💂🏻‍♀' => 'гардисткиња: свијетла кожа',
    '💂🏼‍♀' => 'гардисткиња: средње свијетла кожа',
    '💂🏽‍♀' => 'гардисткиња: ни свијетла ни тамна кожа',
    '💂🏾‍♀' => 'гардисткиња: средње тамна кожа',
    '💂🏿‍♀' => 'гардисткиња: тамна кожа',
    '👷🏻‍♂' => 'грађевинар: свијетла кожа',
    '👷🏼‍♂' => 'грађевинар: средње свијетла кожа',
    '👷🏽‍♂' => 'грађевинар: ни свијетла ни тамна кожа',
    '👷🏾‍♂' => 'грађевинар: средње тамна кожа',
    '👷🏿‍♂' => 'грађевинар: тамна кожа',
    '👷🏻‍♀' => 'грађевинарка: свијетла кожа',
    '👷🏼‍♀' => 'грађевинарка: средње свијетла кожа',
    '👷🏽‍♀' => 'грађевинарка: ни свијетла ни тамна кожа',
    '👷🏾‍♀' => 'грађевинарка: средње тамна кожа',
    '👷🏿‍♀' => 'грађевинарка: тамна кожа',
    '👳🏻‍♂' => 'човјек са турбаном: свијетла кожа',
    '👳🏼‍♂' => 'човјек са турбаном: средње свијетла кожа',
    '👳🏽‍♂' => 'човјек са турбаном: ни свијетла ни тамна кожа',
    '👳🏾‍♂' => 'човјек са турбаном: средње тамна кожа',
    '👳🏿‍♂' => 'човјек са турбаном: тамна кожа',
    '👳🏻‍♀' => 'жена са турбаном: свијетла кожа',
    '👳🏼‍♀' => 'жена са турбаном: средње свијетла кожа',
    '👳🏽‍♀' => 'жена са турбаном: ни свијетла ни тамна кожа',
    '👳🏾‍♀' => 'жена са турбаном: средње тамна кожа',
    '👳🏿‍♀' => 'жена са турбаном: тамна кожа',
    '🤵🏻‍♂' => 'мушкарац у смокингу: свијетла кожа',
    '🤵🏼‍♂' => 'мушкарац у смокингу: средње свијетла кожа',
    '🤵🏽‍♂' => 'мушкарац у смокингу: ни свијетла ни тамна кожа',
    '🤵🏾‍♂' => 'мушкарац у смокингу: средње тамна кожа',
    '🤵🏿‍♂' => 'мушкарац у смокингу: тамна кожа',
    '🤵🏻‍♀' => 'жена у смокингу: свијетла кожа',
    '🤵🏼‍♀' => 'жена у смокингу: средње свијетла кожа',
    '🤵🏽‍♀' => 'жена у смокингу: ни свијетла ни тамна кожа',
    '🤵🏾‍♀' => 'жена у смокингу: средње тамна кожа',
    '🤵🏿‍♀' => 'жена у смокингу: тамна кожа',
    '👰🏻‍♂' => 'мушкарац са велом: свијетла кожа',
    '👰🏼‍♂' => 'мушкарац са велом: средње свијетла кожа',
    '👰🏽‍♂' => 'мушкарац са велом: ни свијетла ни тамна кожа',
    '👰🏾‍♂' => 'мушкарац са велом: средње тамна кожа',
    '👰🏿‍♂' => 'мушкарац са велом: тамна кожа',
    '👰🏻‍♀' => 'жена са велом: свијетла кожа',
    '👰🏼‍♀' => 'жена са велом: средње свијетла кожа',
    '👰🏽‍♀' => 'жена са велом: ни свијетла ни тамна кожа',
    '👰🏾‍♀' => 'жена са велом: средње тамна кожа',
    '👰🏿‍♀' => 'жена са велом: тамна кожа',
    '👩🏻‍🍼' => 'жена храни бебу: свијетла кожа',
    '👩🏼‍🍼' => 'жена храни бебу: средње свијетла кожа',
    '👩🏽‍🍼' => 'жена храни бебу: ни свијетла ни тамна кожа',
    '👩🏾‍🍼' => 'жена храни бебу: средње тамна кожа',
    '👩🏿‍🍼' => 'жена храни бебу: тамна кожа',
    '👨🏻‍🍼' => 'мушкарац храни бебу: свијетла кожа',
    '👨🏼‍🍼' => 'мушкарац храни бебу: средње свијетла кожа',
    '👨🏽‍🍼' => 'мушкарац храни бебу: ни свијетла ни тамна кожа',
    '👨🏾‍🍼' => 'мушкарац храни бебу: средње тамна кожа',
    '👨🏿‍🍼' => 'мушкарац храни бебу: тамна кожа',
    '🧑🏻‍🍼' => 'особа храни бебу: свијетла кожа',
    '🧑🏼‍🍼' => 'особа храни бебу: средње свијетла кожа',
    '🧑🏽‍🍼' => 'особа храни бебу: ни свијетла ни тамна кожа',
    '🧑🏾‍🍼' => 'особа храни бебу: средње тамна кожа',
    '🧑🏿‍🍼' => 'особа храни бебу: тамна кожа',
    '🧑🏻‍🎄' => 'особа Мраз: свијетла кожа',
    '🧑🏼‍🎄' => 'особа Мраз: средње свијетла кожа',
    '🧑🏽‍🎄' => 'особа Мраз: ни свијетла ни тамна кожа',
    '🧑🏾‍🎄' => 'особа Мраз: средње тамна кожа',
    '🧑🏿‍🎄' => 'особа Мраз: тамна кожа',
    '🦸🏻‍♂' => 'мушкарац суперхерој: свијетла кожа',
    '🦸🏼‍♂' => 'мушкарац суперхерој: средње свијетла кожа',
    '🦸🏽‍♂' => 'мушкарац суперхерој: ни свијетла ни тамна кожа',
    '🦸🏾‍♂' => 'мушкарац суперхерој: средње тамна кожа',
    '🦸🏿‍♂' => 'мушкарац суперхерој: тамна кожа',
    '🦸🏻‍♀' => 'жена супер херој: свијетла кожа',
    '🦸🏼‍♀' => 'жена супер херој: средње свијетла кожа',
    '🦸🏽‍♀' => 'жена супер херој: ни свијетла ни тамна кожа',
    '🦸🏾‍♀' => 'жена супер херој: средње тамна кожа',
    '🦸🏿‍♀' => 'жена супер херој: тамна кожа',
    '🦹🏻‍♂' => 'мушкарац негативац: свијетла кожа',
    '🦹🏼‍♂' => 'мушкарац негативац: средње свијетла кожа',
    '🦹🏽‍♂' => 'мушкарац негативац: ни свијетла ни тамна кожа',
    '🦹🏾‍♂' => 'мушкарац негативац: средње тамна кожа',
    '🦹🏿‍♂' => 'мушкарац негативац: тамна кожа',
    '🦹🏻‍♀' => 'жена негативац: свијетла кожа',
    '🦹🏼‍♀' => 'жена негативац: средње свијетла кожа',
    '🦹🏽‍♀' => 'жена негативац: ни свијетла ни тамна кожа',
    '🦹🏾‍♀' => 'жена негативац: средње тамна кожа',
    '🦹🏿‍♀' => 'жена негативац: тамна кожа',
    '🧙🏻‍♂' => 'чаробњак: свијетла кожа',
    '🧙🏼‍♂' => 'чаробњак: средње свијетла кожа',
    '🧙🏽‍♂' => 'чаробњак: ни свијетла ни тамна кожа',
    '🧙🏾‍♂' => 'чаробњак: средње тамна кожа',
    '🧙🏿‍♂' => 'чаробњак: тамна кожа',
    '🧙🏻‍♀' => 'чаробница: свијетла кожа',
    '🧙🏼‍♀' => 'чаробница: средње свијетла кожа',
    '🧙🏽‍♀' => 'чаробница: ни свијетла ни тамна кожа',
    '🧙🏾‍♀' => 'чаробница: средње тамна кожа',
    '🧙🏿‍♀' => 'чаробница: тамна кожа',
    '🧚🏻‍♂' => 'вилењак: свијетла кожа',
    '🧚🏼‍♂' => 'вилењак: средње свијетла кожа',
    '🧚🏽‍♂' => 'вилењак: ни свијетла ни тамна кожа',
    '🧚🏾‍♂' => 'вилењак: средње тамна кожа',
    '🧚🏿‍♂' => 'вилењак: тамна кожа',
    '🧚🏻‍♀' => 'жена вила: свијетла кожа',
    '🧚🏼‍♀' => 'жена вила: средње свијетла кожа',
    '🧚🏽‍♀' => 'жена вила: ни свијетла ни тамна кожа',
    '🧚🏾‍♀' => 'жена вила: средње тамна кожа',
    '🧚🏿‍♀' => 'жена вила: тамна кожа',
    '🧛🏻‍♂' => 'мушки вампир: свијетла кожа',
    '🧛🏼‍♂' => 'мушки вампир: средње свијетла кожа',
    '🧛🏽‍♂' => 'мушки вампир: ни свијетла ни тамна кожа',
    '🧛🏾‍♂' => 'мушки вампир: средње тамна кожа',
    '🧛🏿‍♂' => 'мушки вампир: тамна кожа',
    '🧛🏻‍♀' => 'женски вампир: свијетла кожа',
    '🧛🏼‍♀' => 'женски вампир: средње свијетла кожа',
    '🧛🏽‍♀' => 'женски вампир: ни свијетла ни тамна кожа',
    '🧛🏾‍♀' => 'женски вампир: средње тамна кожа',
    '🧛🏿‍♀' => 'женски вампир: тамна кожа',
    '🧜🏻‍♂' => 'мушкарац из мора: свијетла кожа',
    '🧜🏼‍♂' => 'мушкарац из мора: средње свијетла кожа',
    '🧜🏽‍♂' => 'мушкарац из мора: ни свијетла ни тамна кожа',
    '🧜🏾‍♂' => 'мушкарац из мора: средње тамна кожа',
    '🧜🏿‍♂' => 'мушкарац из мора: тамна кожа',
    '🧜🏻‍♀' => 'сирена: свијетла кожа',
    '🧜🏼‍♀' => 'сирена: средње свијетла кожа',
    '🧜🏽‍♀' => 'сирена: ни свијетла ни тамна кожа',
    '🧜🏾‍♀' => 'сирена: средње тамна кожа',
    '🧜🏿‍♀' => 'сирена: тамна кожа',
    '🧝🏻‍♂' => 'мушкарац виловњак: свијетла кожа',
    '🧝🏼‍♂' => 'мушкарац виловњак: средње свијетла кожа',
    '🧝🏽‍♂' => 'мушкарац виловњак: ни свијетла ни тамна кожа',
    '🧝🏾‍♂' => 'мушкарац виловњак: средње тамна кожа',
    '🧝🏿‍♂' => 'мушкарац виловњак: тамна кожа',
    '🧝🏻‍♀' => 'жена виловњак: свијетла кожа',
    '🧝🏼‍♀' => 'жена виловњак: средње свијетла кожа',
    '🧝🏽‍♀' => 'жена виловњак: ни свијетла ни тамна кожа',
    '🧝🏾‍♀' => 'жена виловњак: средње тамна кожа',
    '🧝🏿‍♀' => 'жена виловњак: тамна кожа',
    '💆🏻‍♂' => 'мушка масажа лица: свијетла кожа',
    '💆🏼‍♂' => 'мушка масажа лица: средње свијетла кожа',
    '💆🏽‍♂' => 'мушка масажа лица: ни свијетла ни тамна кожа',
    '💆🏾‍♂' => 'мушка масажа лица: средње тамна кожа',
    '💆🏿‍♂' => 'мушка масажа лица: тамна кожа',
    '💆🏻‍♀' => 'женска масажа лица: свијетла кожа',
    '💆🏼‍♀' => 'женска масажа лица: средње свијетла кожа',
    '💆🏽‍♀' => 'женска масажа лица: ни свијетла ни тамна кожа',
    '💆🏾‍♀' => 'женска масажа лица: средње тамна кожа',
    '💆🏿‍♀' => 'женска масажа лица: тамна кожа',
    '💇🏻‍♂' => 'мушко шишање: свијетла кожа',
    '💇🏼‍♂' => 'мушко шишање: средње свијетла кожа',
    '💇🏽‍♂' => 'мушко шишање: ни свијетла ни тамна кожа',
    '💇🏾‍♂' => 'мушко шишање: средње тамна кожа',
    '💇🏿‍♂' => 'мушко шишање: тамна кожа',
    '💇🏻‍♀' => 'женско шишање: свијетла кожа',
    '💇🏼‍♀' => 'женско шишање: средње свијетла кожа',
    '💇🏽‍♀' => 'женско шишање: ни свијетла ни тамна кожа',
    '💇🏾‍♀' => 'женско шишање: средње тамна кожа',
    '💇🏿‍♀' => 'женско шишање: тамна кожа',
    '🚶🏻‍♂' => 'мушкарац хода: свијетла кожа',
    '🚶🏼‍♂' => 'мушкарац хода: средње свијетла кожа',
    '🚶🏽‍♂' => 'мушкарац хода: ни свијетла ни тамна кожа',
    '🚶🏾‍♂' => 'мушкарац хода: средње тамна кожа',
    '🚶🏿‍♂' => 'мушкарац хода: тамна кожа',
    '🚶🏻‍♀' => 'жена хода: свијетла кожа',
    '🚶🏼‍♀' => 'жена хода: средње свијетла кожа',
    '🚶🏽‍♀' => 'жена хода: ни свијетла ни тамна кожа',
    '🚶🏾‍♀' => 'жена хода: средње тамна кожа',
    '🚶🏿‍♀' => 'жена хода: тамна кожа',
    '🚶🏻‍➡' => 'пјешак: свијетла кожа и гледа удесно',
    '🚶🏼‍➡' => 'пјешак: средње свијетла кожа и гледа удесно',
    '🚶🏽‍➡' => 'пјешак: ни свијетла ни тамна кожа и гледа удесно',
    '🚶🏾‍➡' => 'пјешак: средње тамна кожа и гледа удесно',
    '🚶🏿‍➡' => 'пјешак: тамна кожа и гледа удесно',
    '🧍🏻‍♂' => 'човјек стоји: свијетла кожа',
    '🧍🏼‍♂' => 'човјек стоји: средње свијетла кожа',
    '🧍🏽‍♂' => 'човјек стоји: ни свијетла ни тамна кожа',
    '🧍🏾‍♂' => 'човјек стоји: средње тамна кожа',
    '🧍🏿‍♂' => 'човјек стоји: тамна кожа',
    '🧍🏻‍♀' => 'жена стоји: свијетла кожа',
    '🧍🏼‍♀' => 'жена стоји: средње свијетла кожа',
    '🧍🏽‍♀' => 'жена стоји: ни свијетла ни тамна кожа',
    '🧍🏾‍♀' => 'жена стоји: средње тамна кожа',
    '🧍🏿‍♀' => 'жена стоји: тамна кожа',
    '🧎🏻‍♂' => 'човек клечи: свијетла кожа',
    '🧎🏼‍♂' => 'човек клечи: средње свијетла кожа',
    '🧎🏽‍♂' => 'човек клечи: ни свијетла ни тамна кожа',
    '🧎🏾‍♂' => 'човек клечи: средње тамна кожа',
    '🧎🏿‍♂' => 'човек клечи: тамна кожа',
    '🧎🏻‍♀' => 'жена клечи: свијетла кожа',
    '🧎🏼‍♀' => 'жена клечи: средње свијетла кожа',
    '🧎🏽‍♀' => 'жена клечи: ни свијетла ни тамна кожа',
    '🧎🏾‍♀' => 'жена клечи: средње тамна кожа',
    '🧎🏿‍♀' => 'жена клечи: тамна кожа',
    '🧎🏻‍➡' => 'особа клечи: свијетла кожа и гледа удесно',
    '🧎🏼‍➡' => 'особа клечи: средње свијетла кожа и гледа удесно',
    '🧎🏽‍➡' => 'особа клечи: ни свијетла ни тамна кожа и гледа удесно',
    '🧎🏾‍➡' => 'особа клечи: средње тамна кожа и гледа удесно',
    '🧎🏿‍➡' => 'особа клечи: тамна кожа и гледа удесно',
    '🧑🏻‍🦯' => 'особа са помоћним штапом: свијетла кожа',
    '🧑🏼‍🦯' => 'особа са помоћним штапом: средње свијетла кожа',
    '🧑🏽‍🦯' => 'особа са помоћним штапом: ни свијетла ни тамна кожа',
    '🧑🏾‍🦯' => 'особа са помоћним штапом: средње тамна кожа',
    '🧑🏿‍🦯' => 'особа са помоћним штапом: тамна кожа',
    '👨🏻‍🦯' => 'човјек са помоћним штапом: свијетла кожа',
    '👨🏼‍🦯' => 'човјек са помоћним штапом: средње свијетла кожа',
    '👨🏽‍🦯' => 'човјек са помоћним штапом: ни свијетла ни тамна кожа',
    '👨🏾‍🦯' => 'човјек са помоћним штапом: средње тамна кожа',
    '👨🏿‍🦯' => 'човјек са помоћним штапом: тамна кожа',
    '👩🏻‍🦯' => 'жена са помоћним штапом: свијетла кожа',
    '👩🏼‍🦯' => 'жена са помоћним штапом: средње свијетла кожа',
    '👩🏽‍🦯' => 'жена са помоћним штапом: ни свијетла ни тамна кожа',
    '👩🏾‍🦯' => 'жена са помоћним штапом: средње тамна кожа',
    '👩🏿‍🦯' => 'жена са помоћним штапом: тамна кожа',
    '🧑🏻‍🦼' => 'особа у моторним колицима: свијетла кожа',
    '🧑🏼‍🦼' => 'особа у моторним колицима: средње свијетла кожа',
    '🧑🏽‍🦼' => 'особа у моторним колицима: ни свијетла ни тамна кожа',
    '🧑🏾‍🦼' => 'особа у моторним колицима: средње тамна кожа',
    '🧑🏿‍🦼' => 'особа у моторним колицима: тамна кожа',
    '👨🏻‍🦼' => 'човјек у моторним колицима: свијетла кожа',
    '👨🏼‍🦼' => 'човјек у моторним колицима: средње свијетла кожа',
    '👨🏽‍🦼' => 'човјек у моторним колицима: ни свијетла ни тамна кожа',
    '👨🏾‍🦼' => 'човјек у моторним колицима: средње тамна кожа',
    '👨🏿‍🦼' => 'човјек у моторним колицима: тамна кожа',
    '👩🏻‍🦼' => 'жена у моторним колицима: свијетла кожа',
    '👩🏼‍🦼' => 'жена у моторним колицима: средње свијетла кожа',
    '👩🏽‍🦼' => 'жена у моторним колицима: ни свијетла ни тамна кожа',
    '👩🏾‍🦼' => 'жена у моторним колицима: средње тамна кожа',
    '👩🏿‍🦼' => 'жена у моторним колицима: тамна кожа',
    '🧑🏻‍🦽' => 'особа у механичким колицима: свијетла кожа',
    '🧑🏼‍🦽' => 'особа у механичким колицима: средње свијетла кожа',
    '🧑🏽‍🦽' => 'особа у механичким колицима: ни свијетла ни тамна кожа',
    '🧑🏾‍🦽' => 'особа у механичким колицима: средње тамна кожа',
    '🧑🏿‍🦽' => 'особа у механичким колицима: тамна кожа',
    '👨🏻‍🦽' => 'човјек у механичким колицима: свијетла кожа',
    '👨🏼‍🦽' => 'човјек у механичким колицима: средње свијетла кожа',
    '👨🏽‍🦽' => 'човјек у механичким колицима: ни свијетла ни тамна кожа',
    '👨🏾‍🦽' => 'човјек у механичким колицима: средње тамна кожа',
    '👨🏿‍🦽' => 'човјек у механичким колицима: тамна кожа',
    '👩🏻‍🦽' => 'жена у механичким колицима: свијетла кожа',
    '👩🏼‍🦽' => 'жена у механичким колицима: средње свијетла кожа',
    '👩🏽‍🦽' => 'жена у механичким колицима: ни свијетла ни тамна кожа',
    '👩🏾‍🦽' => 'жена у механичким колицима: средње тамна кожа',
    '👩🏿‍🦽' => 'жена у механичким колицима: тамна кожа',
    '🏃🏻‍♂' => 'мушкарац трчи: свијетла кожа',
    '🏃🏼‍♂' => 'мушкарац трчи: средње свијетла кожа',
    '🏃🏽‍♂' => 'мушкарац трчи: ни свијетла ни тамна кожа',
    '🏃🏾‍♂' => 'мушкарац трчи: средње тамна кожа',
    '🏃🏿‍♂' => 'мушкарац трчи: тамна кожа',
    '🏃🏻‍♀' => 'жена трчи: свијетла кожа',
    '🏃🏼‍♀' => 'жена трчи: средње свијетла кожа',
    '🏃🏽‍♀' => 'жена трчи: ни свијетла ни тамна кожа',
    '🏃🏾‍♀' => 'жена трчи: средње тамна кожа',
    '🏃🏿‍♀' => 'жена трчи: тамна кожа',
    '🏃🏻‍➡' => 'тркач: свијетла кожа и гледа удесно',
    '🏃🏼‍➡' => 'тркач: средње свијетла кожа и гледа удесно',
    '🏃🏽‍➡' => 'тркач: ни свијетла ни тамна кожа и гледа удесно',
    '🏃🏾‍➡' => 'тркач: средње тамна кожа и гледа удесно',
    '🏃🏿‍➡' => 'тркач: тамна кожа и гледа удесно',
    '👯🏻‍♀' => 'жене у проводу: свијетла кожа',
    '👯🏼‍♀' => 'жене у проводу: средње свијетла кожа',
    '👯🏽‍♀' => 'жене у проводу: ни свијетла ни тамна кожа',
    '👯🏾‍♀' => 'жене у проводу: средње тамна кожа',
    '👯🏿‍♀' => 'жене у проводу: тамна кожа',
    '👯🏻‍♂' => 'мушкарци у проводу: свијетла кожа',
    '👯🏼‍♂' => 'мушкарци у проводу: средње свијетла кожа',
    '👯🏽‍♂' => 'мушкарци у проводу: ни свијетла ни тамна кожа',
    '👯🏾‍♂' => 'мушкарци у проводу: средње тамна кожа',
    '👯🏿‍♂' => 'мушкарци у проводу: тамна кожа',
    '🧖🏻‍♂' => 'мушкарац у парном купатилу: свијетла кожа',
    '🧖🏼‍♂' => 'мушкарац у парном купатилу: средње свијетла кожа',
    '🧖🏽‍♂' => 'мушкарац у парном купатилу: ни свијетла ни тамна кожа',
    '🧖🏾‍♂' => 'мушкарац у парном купатилу: средње тамна кожа',
    '🧖🏿‍♂' => 'мушкарац у парном купатилу: тамна кожа',
    '🧖🏻‍♀' => 'жена у парном купатилу: свијетла кожа',
    '🧖🏼‍♀' => 'жена у парном купатилу: средње свијетла кожа',
    '🧖🏽‍♀' => 'жена у парном купатилу: ни свијетла ни тамна кожа',
    '🧖🏾‍♀' => 'жена у парном купатилу: средње тамна кожа',
    '🧖🏿‍♀' => 'жена у парном купатилу: тамна кожа',
    '🧗🏻‍♂' => 'мушкарац се пење: свијетла кожа',
    '🧗🏼‍♂' => 'мушкарац се пење: средње свијетла кожа',
    '🧗🏽‍♂' => 'мушкарац се пење: ни свијетла ни тамна кожа',
    '🧗🏾‍♂' => 'мушкарац се пење: средње тамна кожа',
    '🧗🏿‍♂' => 'мушкарац се пење: тамна кожа',
    '🧗🏻‍♀' => 'жена се пење: свијетла кожа',
    '🧗🏼‍♀' => 'жена се пење: средње свијетла кожа',
    '🧗🏽‍♀' => 'жена се пење: ни свијетла ни тамна кожа',
    '🧗🏾‍♀' => 'жена се пење: средње тамна кожа',
    '🧗🏿‍♀' => 'жена се пење: тамна кожа',
    '🏌🏻‍♂' => 'голфер: свијетла кожа',
    '🏌🏼‍♂' => 'голфер: средње свијетла кожа',
    '🏌🏽‍♂' => 'голфер: ни свијетла ни тамна кожа',
    '🏌🏾‍♂' => 'голфер: средње тамна кожа',
    '🏌🏿‍♂' => 'голфер: тамна кожа',
    '🏌🏻‍♀' => 'голферка: свијетла кожа',
    '🏌🏼‍♀' => 'голферка: средње свијетла кожа',
    '🏌🏽‍♀' => 'голферка: ни свијетла ни тамна кожа',
    '🏌🏾‍♀' => 'голферка: средње тамна кожа',
    '🏌🏿‍♀' => 'голферка: тамна кожа',
    '🏄🏻‍♂' => 'сурфер: свијетла кожа',
    '🏄🏼‍♂' => 'сурфер: средње свијетла кожа',
    '🏄🏽‍♂' => 'сурфер: ни свијетла ни тамна кожа',
    '🏄🏾‍♂' => 'сурфер: средње тамна кожа',
    '🏄🏿‍♂' => 'сурфер: тамна кожа',
    '🏄🏻‍♀' => 'сурферка: свијетла кожа',
    '🏄🏼‍♀' => 'сурферка: средње свијетла кожа',
    '🏄🏽‍♀' => 'сурферка: ни свијетла ни тамна кожа',
    '🏄🏾‍♀' => 'сурферка: средње тамна кожа',
    '🏄🏿‍♀' => 'сурферка: тамна кожа',
    '🚣🏻‍♂' => 'веслач: свијетла кожа',
    '🚣🏼‍♂' => 'веслач: средње свијетла кожа',
    '🚣🏽‍♂' => 'веслач: ни свијетла ни тамна кожа',
    '🚣🏾‍♂' => 'веслач: средње тамна кожа',
    '🚣🏿‍♂' => 'веслач: тамна кожа',
    '🚣🏻‍♀' => 'веслачица: свијетла кожа',
    '🚣🏼‍♀' => 'веслачица: средње свијетла кожа',
    '🚣🏽‍♀' => 'веслачица: ни свијетла ни тамна кожа',
    '🚣🏾‍♀' => 'веслачица: средње тамна кожа',
    '🚣🏿‍♀' => 'веслачица: тамна кожа',
    '🏊🏻‍♂' => 'пливач: свијетла кожа',
    '🏊🏼‍♂' => 'пливач: средње свијетла кожа',
    '🏊🏽‍♂' => 'пливач: ни свијетла ни тамна кожа',
    '🏊🏾‍♂' => 'пливач: средње тамна кожа',
    '🏊🏿‍♂' => 'пливач: тамна кожа',
    '🏊🏻‍♀' => 'пливачица: свијетла кожа',
    '🏊🏼‍♀' => 'пливачица: средње свијетла кожа',
    '🏊🏽‍♀' => 'пливачица: ни свијетла ни тамна кожа',
    '🏊🏾‍♀' => 'пливачица: средње тамна кожа',
    '🏊🏿‍♀' => 'пливачица: тамна кожа',
    '⛹🏻‍♂' => 'мушкарац са лоптом: свијетла кожа',
    '⛹🏼‍♂' => 'мушкарац са лоптом: средње свијетла кожа',
    '⛹🏽‍♂' => 'мушкарац са лоптом: ни свијетла ни тамна кожа',
    '⛹🏾‍♂' => 'мушкарац са лоптом: средње тамна кожа',
    '⛹🏿‍♂' => 'мушкарац са лоптом: тамна кожа',
    '⛹🏻‍♀' => 'жена са лоптом: свијетла кожа',
    '⛹🏼‍♀' => 'жена са лоптом: средње свијетла кожа',
    '⛹🏽‍♀' => 'жена са лоптом: ни свијетла ни тамна кожа',
    '⛹🏾‍♀' => 'жена са лоптом: средње тамна кожа',
    '⛹🏿‍♀' => 'жена са лоптом: тамна кожа',
    '🏋🏻‍♂' => 'дизач тегова: свијетла кожа',
    '🏋🏼‍♂' => 'дизач тегова: средње свијетла кожа',
    '🏋🏽‍♂' => 'дизач тегова: ни свијетла ни тамна кожа',
    '🏋🏾‍♂' => 'дизач тегова: средње тамна кожа',
    '🏋🏿‍♂' => 'дизач тегова: тамна кожа',
    '🏋🏻‍♀' => 'дизачица тегова: свијетла кожа',
    '🏋🏼‍♀' => 'дизачица тегова: средње свијетла кожа',
    '🏋🏽‍♀' => 'дизачица тегова: ни свијетла ни тамна кожа',
    '🏋🏾‍♀' => 'дизачица тегова: средње тамна кожа',
    '🏋🏿‍♀' => 'дизачица тегова: тамна кожа',
    '🚴🏻‍♂' => 'бициклиста: свијетла кожа',
    '🚴🏼‍♂' => 'бициклиста: средње свијетла кожа',
    '🚴🏽‍♂' => 'бициклиста: ни свијетла ни тамна кожа',
    '🚴🏾‍♂' => 'бициклиста: средње тамна кожа',
    '🚴🏿‍♂' => 'бициклиста: тамна кожа',
    '🚴🏻‍♀' => 'бициклисткиња: свијетла кожа',
    '🚴🏼‍♀' => 'бициклисткиња: средње свијетла кожа',
    '🚴🏽‍♀' => 'бициклисткиња: ни свијетла ни тамна кожа',
    '🚴🏾‍♀' => 'бициклисткиња: средње тамна кожа',
    '🚴🏿‍♀' => 'бициклисткиња: тамна кожа',
    '🚵🏻‍♂' => 'брдски бициклиста: свијетла кожа',
    '🚵🏼‍♂' => 'брдски бициклиста: средње свијетла кожа',
    '🚵🏽‍♂' => 'брдски бициклиста: ни свијетла ни тамна кожа',
    '🚵🏾‍♂' => 'брдски бициклиста: средње тамна кожа',
    '🚵🏿‍♂' => 'брдски бициклиста: тамна кожа',
    '🚵🏻‍♀' => 'брдска бициклисткиња: свијетла кожа',
    '🚵🏼‍♀' => 'брдска бициклисткиња: средње свијетла кожа',
    '🚵🏽‍♀' => 'брдска бициклисткиња: ни свијетла ни тамна кожа',
    '🚵🏾‍♀' => 'брдска бициклисткиња: средње тамна кожа',
    '🚵🏿‍♀' => 'брдска бициклисткиња: тамна кожа',
    '🤸🏻‍♂' => 'гимнастичар: свијетла кожа',
    '🤸🏼‍♂' => 'гимнастичар: средње свијетла кожа',
    '🤸🏽‍♂' => 'гимнастичар: ни свијетла ни тамна кожа',
    '🤸🏾‍♂' => 'гимнастичар: средње тамна кожа',
    '🤸🏿‍♂' => 'гимнастичар: тамна кожа',
    '🤸🏻‍♀' => 'гимнастичарка: свијетла кожа',
    '🤸🏼‍♀' => 'гимнастичарка: средње свијетла кожа',
    '🤸🏽‍♀' => 'гимнастичарка: ни свијетла ни тамна кожа',
    '🤸🏾‍♀' => 'гимнастичарка: средње тамна кожа',
    '🤸🏿‍♀' => 'гимнастичарка: тамна кожа',
    '🤼🏻‍♀' => 'рвачице: свијетла кожа',
    '🤼🏼‍♀' => 'рвачице: средње свијетла кожа',
    '🤼🏽‍♀' => 'рвачице: ни свијетла ни тамна кожа',
    '🤼🏾‍♀' => 'рвачице: средње тамна кожа',
    '🤼🏿‍♀' => 'рвачице: тамна кожа',
    '🤼🏻‍♂' => 'рвачи: свијетла кожа',
    '🤼🏼‍♂' => 'рвачи: средње свијетла кожа',
    '🤼🏽‍♂' => 'рвачи: ни свијетла ни тамна кожа',
    '🤼🏾‍♂' => 'рвачи: средње тамна кожа',
    '🤼🏿‍♂' => 'рвачи: тамна кожа',
    '🤽🏻‍♂' => 'ватерполиста: свијетла кожа',
    '🤽🏼‍♂' => 'ватерполиста: средње свијетла кожа',
    '🤽🏽‍♂' => 'ватерполиста: ни свијетла ни тамна кожа',
    '🤽🏾‍♂' => 'ватерполиста: средње тамна кожа',
    '🤽🏿‍♂' => 'ватерполиста: тамна кожа',
    '🤽🏻‍♀' => 'ватерполисткиња: свијетла кожа',
    '🤽🏼‍♀' => 'ватерполисткиња: средње свијетла кожа',
    '🤽🏽‍♀' => 'ватерполисткиња: ни свијетла ни тамна кожа',
    '🤽🏾‍♀' => 'ватерполисткиња: средње тамна кожа',
    '🤽🏿‍♀' => 'ватерполисткиња: тамна кожа',
    '🤾🏻‍♂' => 'рукометаш: свијетла кожа',
    '🤾🏼‍♂' => 'рукометаш: средње свијетла кожа',
    '🤾🏽‍♂' => 'рукометаш: ни свијетла ни тамна кожа',
    '🤾🏾‍♂' => 'рукометаш: средње тамна кожа',
    '🤾🏿‍♂' => 'рукометаш: тамна кожа',
    '🤾🏻‍♀' => 'рукометашица: свијетла кожа',
    '🤾🏼‍♀' => 'рукометашица: средње свијетла кожа',
    '🤾🏽‍♀' => 'рукометашица: ни свијетла ни тамна кожа',
    '🤾🏾‍♀' => 'рукометашица: средње тамна кожа',
    '🤾🏿‍♀' => 'рукометашица: тамна кожа',
    '🤹🏻‍♂' => 'жонглер: свијетла кожа',
    '🤹🏼‍♂' => 'жонглер: средње свијетла кожа',
    '🤹🏽‍♂' => 'жонглер: ни свијетла ни тамна кожа',
    '🤹🏾‍♂' => 'жонглер: средње тамна кожа',
    '🤹🏿‍♂' => 'жонглер: тамна кожа',
    '🤹🏻‍♀' => 'жонглерка: свијетла кожа',
    '🤹🏼‍♀' => 'жонглерка: средње свијетла кожа',
    '🤹🏽‍♀' => 'жонглерка: ни свијетла ни тамна кожа',
    '🤹🏾‍♀' => 'жонглерка: средње тамна кожа',
    '🤹🏿‍♀' => 'жонглерка: тамна кожа',
    '🧘🏻‍♂' => 'мушкарац у лотос пози: свијетла кожа',
    '🧘🏼‍♂' => 'мушкарац у лотос пози: средње свијетла кожа',
    '🧘🏽‍♂' => 'мушкарац у лотос пози: ни свијетла ни тамна кожа',
    '🧘🏾‍♂' => 'мушкарац у лотос пози: средње тамна кожа',
    '🧘🏿‍♂' => 'мушкарац у лотос пози: тамна кожа',
    '🧘🏻‍♀' => 'жена у лотос пози: свијетла кожа',
    '🧘🏼‍♀' => 'жена у лотос пози: средње свијетла кожа',
    '🧘🏽‍♀' => 'жена у лотос пози: ни свијетла ни тамна кожа',
    '🧘🏾‍♀' => 'жена у лотос пози: средње тамна кожа',
    '🧘🏿‍♀' => 'жена у лотос пози: тамна кожа',
    '🧑‍🦰' => 'одрасла особа: црвена коса',
    '🧑‍🦱' => 'одрасла особа: коврџава коса',
    '🧑‍🦳' => 'одрасла особа: сиједа коса',
    '🧑‍🦲' => 'одрасла особа: ћелав',
    '👨‍🦰' => 'мушкарац: црвена коса',
    '👨‍🦱' => 'мушкарац: коврџава коса',
    '👨‍🦳' => 'мушкарац: сиједа коса',
    '👨‍🦲' => 'мушкарац: ћелав',
    '👩‍🦰' => 'жена: црвена коса',
    '👩‍🦱' => 'жена: коврџава коса',
    '👩‍🦳' => 'жена: сиједа коса',
    '👩‍🦲' => 'жена: ћелав',
    '🚶‍➡' => 'пјешак: гледа удесно',
    '🧎‍➡' => 'особа клечи: гледа удесно',
    '🏃‍➡' => 'тркач: гледа удесно',
    '👨‍👦' => 'породица: мушкарац и дјечак',
    '👨‍👧' => 'породица: мушкарац и дјевојчица',
    '👩‍👦' => 'породица: жена и дјечак',
    '👩‍👧' => 'породица: жена и дјевојчица',
    '😶‍🌫' => 'лице у облацима',
    '😮‍💨' => 'лице издише',
    '🙂‍↕' => 'глава тресе вертикално',
    '😵‍💫' => 'лице са спиралним очима',
    '❤‍🔥' => 'запаљено срце',
    '❤‍🩹' => 'срце које зацјељује',
    '👁‍🗨' => 'око у облачићу дијалога',
    '🧔‍♂' => 'мушкарац: брада',
    '👱‍♂' => 'плав мушкарац',
    '🧔‍♀' => 'жена: брада',
    '👱‍♀' => 'плавуша',
    '🙍‍♂' => 'намрштен мушкарац',
    '🙍‍♀' => 'намрштена жена',
    '🙎‍♂' => 'надурен мушкарац',
    '🙎‍♀' => 'надурена жена',
    '🙅‍♂' => 'мушкарац показује „не“',
    '🙅‍♀' => 'жена показује „не“',
    '🙆‍♂' => 'мушкарац показује „ок“',
    '🙆‍♀' => 'жена показује „ок“',
    '💁‍♂' => 'мушкарац открива намјере',
    '💁‍♀' => 'жена открива намјере',
    '🙋‍♂' => 'мушкарац подиже руку',
    '🙋‍♀' => 'жена подиже руку',
    '🧏‍♂' => 'глув човјек',
    '🧏‍♀' => 'глува жена',
    '🙇‍♂' => 'мушки дубоки наклон',
    '🙇‍♀' => 'женски дубоки наклон',
    '🤦‍♂' => 'мушкарац с руком на челу',
    '🤦‍♀' => 'жена с руком на челу',
    '🤷‍♂' => 'мушкарац слијеже раменима',
    '🤷‍♀' => 'жена слијеже раменима',
    '🧑‍⚕' => 'здравствени радник',
    '👨‍⚕' => 'мушкарац здравствени радник',
    '👩‍⚕' => 'здравствена радница',
    '🧑‍🎓' => 'студент(киња)',
    '👨‍🎓' => 'студент',
    '👩‍🎓' => 'студенткиња',
    '🧑‍🏫' => 'учитељ',
    '👨‍🏫' => 'професор',
    '👩‍🏫' => 'професорка',
    '🧑‍⚖' => 'судија/ница',
    '👨‍⚖' => 'мушкарац судија',
    '👩‍⚖' => 'жена судија',
    '🧑‍🌾' => 'пољопривредник',
    '👨‍🌾' => 'мушкарац пољопривредник',
    '👩‍🌾' => 'пољопривредница',
    '🧑‍🍳' => 'кувар',
    '👨‍🍳' => 'мушкарац кувар',
    '👩‍🍳' => 'куварица',
    '🧑‍🔧' => 'механичар',
    '👨‍🔧' => 'мушкарац механичар',
    '👩‍🔧' => 'механичарка',
    '🧑‍🏭' => 'радник у фабрици',
    '👨‍🏭' => 'радник',
    '👩‍🏭' => 'радница',
    '🧑‍💼' => 'канцеларијски радник',
    '👨‍💼' => 'мушкарац у канцеларији',
    '👩‍💼' => 'жена у канцеларији',
    '🧑‍🔬' => 'научник/ца',
    '👨‍🔬' => 'научник',
    '👩‍🔬' => 'научница',
    '🧑‍💻' => 'технолог',
    '👨‍💻' => 'мушкарац технолог',
    '👩‍💻' => 'жена технолог',
    '🧑‍🎤' => 'пјевач',
    '👨‍🎤' => 'мушкарац пјевач',
    '👩‍🎤' => 'пјевачица',
    '🧑‍🎨' => 'умјетник',
    '👨‍🎨' => 'мушкарац умјетник',
    '👩‍🎨' => 'умјетница',
    '🧑‍✈' => 'пилот(киња)',
    '👨‍✈' => 'пилот',
    '👩‍✈' => 'жена пилот',
    '🧑‍🚀' => 'астронаут',
    '👨‍🚀' => 'космонаут',
    '👩‍🚀' => 'космонауткиња',
    '🧑‍🚒' => 'ватрогасац / жена ватрогасац',
    '👨‍🚒' => 'ватрогасац',
    '👩‍🚒' => 'жена ватрогасац',
    '👮‍♂' => 'полицајац',
    '👮‍♀' => 'полицајка',
    '🕵‍♂' => 'детектив',
    '🕵‍♀' => 'детективка',
    '💂‍♂' => 'гардиста',
    '💂‍♀' => 'гардисткиња',
    '👷‍♂' => 'грађевинар',
    '👷‍♀' => 'грађевинарка',
    '👳‍♂' => 'човјек са турбаном',
    '👳‍♀' => 'жена са турбаном',
    '🤵‍♂' => 'мушкарац у смокингу',
    '🤵‍♀' => 'жена у смокингу',
    '👰‍♂' => 'мушкарац са велом',
    '👰‍♀' => 'жена са велом',
    '👩‍🍼' => 'жена храни бебу',
    '👨‍🍼' => 'мушкарац храни бебу',
    '🧑‍🍼' => 'особа храни бебу',
    '🧑‍🎄' => 'особа Мраз',
    '🦸‍♂' => 'мушкарац суперхерој',
    '🦸‍♀' => 'жена супер херој',
    '🦹‍♂' => 'мушкарац негативац',
    '🦹‍♀' => 'жена негативац',
    '🧙‍♂' => 'чаробњак',
    '🧙‍♀' => 'чаробница',
    '🧚‍♂' => 'вилењак',
    '🧚‍♀' => 'жена вила',
    '🧛‍♂' => 'мушки вампир',
    '🧛‍♀' => 'женски вампир',
    '🧜‍♂' => 'мушкарац из мора',
    '🧜‍♀' => 'сирена',
    '🧝‍♂' => 'мушкарац виловњак',
    '🧝‍♀' => 'жена виловњак',
    '🧞‍♂' => 'мушки добри дух',
    '🧞‍♀' => 'женски добри дух',
    '🧟‍♂' => 'мушкарац зомби',
    '🧟‍♀' => 'жена зомби',
    '💆‍♂' => 'мушка масажа лица',
    '💆‍♀' => 'женска масажа лица',
    '💇‍♂' => 'мушко шишање',
    '💇‍♀' => 'женско шишање',
    '🚶‍♂' => 'мушкарац хода',
    '🚶‍♀' => 'жена хода',
    '🧍‍♂' => 'човјек стоји',
    '🧍‍♀' => 'жена стоји',
    '🧎‍♂' => 'човек клечи',
    '🧎‍♀' => 'жена клечи',
    '🧑‍🦯' => 'особа са помоћним штапом',
    '👨‍🦯' => 'човјек са помоћним штапом',
    '👩‍🦯' => 'жена са помоћним штапом',
    '🧑‍🦼' => 'особа у моторним колицима',
    '👨‍🦼' => 'човјек у моторним колицима',
    '👩‍🦼' => 'жена у моторним колицима',
    '🧑‍🦽' => 'особа у механичким колицима',
    '👨‍🦽' => 'човјек у механичким колицима',
    '👩‍🦽' => 'жена у механичким колицима',
    '🏃‍♂' => 'мушкарац трчи',
    '🏃‍♀' => 'жена трчи',
    '🧑‍🩰' => 'балетан',
    '👯‍♂' => 'мушкарци у проводу',
    '👯‍♀' => 'жене у проводу',
    '🧖‍♂' => 'мушкарац у парном купатилу',
    '🧖‍♀' => 'жена у парном купатилу',
    '🧗‍♂' => 'мушкарац се пење',
    '🧗‍♀' => 'жена се пење',
    '🏌‍♂' => 'голфер',
    '🏌‍♀' => 'голферка',
    '🏄‍♂' => 'сурфер',
    '🏄‍♀' => 'сурферка',
    '🚣‍♂' => 'веслач',
    '🚣‍♀' => 'веслачица',
    '🏊‍♂' => 'пливач',
    '🏊‍♀' => 'пливачица',
    '⛹‍♂' => 'мушкарац са лоптом',
    '⛹‍♀' => 'жена са лоптом',
    '🏋‍♂' => 'дизач тегова',
    '🏋‍♀' => 'дизачица тегова',
    '🚴‍♂' => 'бициклиста',
    '🚴‍♀' => 'бициклисткиња',
    '🚵‍♂' => 'брдски бициклиста',
    '🚵‍♀' => 'брдска бициклисткиња',
    '🤸‍♂' => 'гимнастичар',
    '🤸‍♀' => 'гимнастичарка',
    '🤼‍♂' => 'рвачи',
    '🤼‍♀' => 'рвачице',
    '🤽‍♂' => 'ватерполиста',
    '🤽‍♀' => 'ватерполисткиња',
    '🤾‍♂' => 'рукометаш',
    '🤾‍♀' => 'рукометашица',
    '🤹‍♂' => 'жонглер',
    '🤹‍♀' => 'жонглерка',
    '🧘‍♂' => 'мушкарац у лотос пози',
    '🧘‍♀' => 'жена у лотос пози',
    '🧑‍🧒' => 'породица: одрасла особа, дијете',
    '🐕‍🦺' => 'службени пас',
    '🐈‍⬛' => 'црна мачка',
    '🐻‍❄' => 'поларни медвјед',
    '🐦‍⬛' => 'црна птица',
    '🐦‍🔥' => 'феникс',
    '🍋‍🟩' => 'лимета',
    '🍄‍🟫' => 'смеђа печурка',
    '⛓‍💥' => 'прекинут ланац',
    '🏳‍🌈' => 'дугина застава',
    '🏳‍⚧' => 'трансродна застава',
    '🏴‍☠' => 'пиратска застава',
    '👋🏻' => 'рука која маше: свијетла кожа',
    '👋🏼' => 'рука која маше: средње свијетла кожа',
    '👋🏽' => 'рука која маше: ни свијетла ни тамна кожа',
    '👋🏾' => 'рука која маше: средње тамна кожа',
    '👋🏿' => 'рука која маше: тамна кожа',
    '🤚🏻' => 'подигнут длан: свијетла кожа',
    '🤚🏼' => 'подигнут длан: средње свијетла кожа',
    '🤚🏽' => 'подигнут длан: ни свијетла ни тамна кожа',
    '🤚🏾' => 'подигнут длан: средње тамна кожа',
    '🤚🏿' => 'подигнут длан: тамна кожа',
    '🖐🏻' => 'шака са раширеним прстима: свијетла кожа',
    '🖐🏼' => 'шака са раширеним прстима: средње свијетла кожа',
    '🖐🏽' => 'шака са раширеним прстима: ни свијетла ни тамна кожа',
    '🖐🏾' => 'шака са раширеним прстима: средње тамна кожа',
    '🖐🏿' => 'шака са раширеним прстима: тамна кожа',
    '✋🏻' => 'подигнута рука: свијетла кожа',
    '✋🏼' => 'подигнута рука: средње свијетла кожа',
    '✋🏽' => 'подигнута рука: ни свијетла ни тамна кожа',
    '✋🏾' => 'подигнута рука: средње тамна кожа',
    '✋🏿' => 'подигнута рука: тамна кожа',
    '🖖🏻' => 'вулкански поздрав: свијетла кожа',
    '🖖🏼' => 'вулкански поздрав: средње свијетла кожа',
    '🖖🏽' => 'вулкански поздрав: ни свијетла ни тамна кожа',
    '🖖🏾' => 'вулкански поздрав: средње тамна кожа',
    '🖖🏿' => 'вулкански поздрав: тамна кожа',
    '🫱🏻' => 'рука окренута надесно: свијетла кожа',
    '🫱🏼' => 'рука окренута надесно: средње свијетла кожа',
    '🫱🏽' => 'рука окренута надесно: ни свијетла ни тамна кожа',
    '🫱🏾' => 'рука окренута надесно: средње тамна кожа',
    '🫱🏿' => 'рука окренута надесно: тамна кожа',
    '🫲🏻' => 'рука окренута налево: свијетла кожа',
    '🫲🏼' => 'рука окренута налево: средње свијетла кожа',
    '🫲🏽' => 'рука окренута налево: ни свијетла ни тамна кожа',
    '🫲🏾' => 'рука окренута налево: средње тамна кожа',
    '🫲🏿' => 'рука окренута налево: тамна кожа',
    '🫳🏻' => 'длан окренут надоле: свијетла кожа',
    '🫳🏼' => 'длан окренут надоле: средње свијетла кожа',
    '🫳🏽' => 'длан окренут надоле: ни свијетла ни тамна кожа',
    '🫳🏾' => 'длан окренут надоле: средње тамна кожа',
    '🫳🏿' => 'длан окренут надоле: тамна кожа',
    '🫴🏻' => 'длан окренут нагоре: свијетла кожа',
    '🫴🏼' => 'длан окренут нагоре: средње свијетла кожа',
    '🫴🏽' => 'длан окренут нагоре: ни свијетла ни тамна кожа',
    '🫴🏾' => 'длан окренут нагоре: средње тамна кожа',
    '🫴🏿' => 'длан окренут нагоре: тамна кожа',
    '🫷🏻' => 'рука гура улијево: свијетла кожа',
    '🫷🏼' => 'рука гура улијево: средње свијетла кожа',
    '🫷🏽' => 'рука гура улијево: ни свијетла ни тамна кожа',
    '🫷🏾' => 'рука гура улијево: средње тамна кожа',
    '🫷🏿' => 'рука гура улијево: тамна кожа',
    '🫸🏻' => 'рука гура удесно: свијетла кожа',
    '🫸🏼' => 'рука гура удесно: средње свијетла кожа',
    '🫸🏽' => 'рука гура удесно: ни свијетла ни тамна кожа',
    '🫸🏾' => 'рука гура удесно: средње тамна кожа',
    '🫸🏿' => 'рука гура удесно: тамна кожа',
    '👌🏻' => 'знак руком „у реду“: свијетла кожа',
    '👌🏼' => 'знак руком „у реду“: средње свијетла кожа',
    '👌🏽' => 'знак руком „у реду“: ни свијетла ни тамна кожа',
    '👌🏾' => 'знак руком „у реду“: средње тамна кожа',
    '👌🏿' => 'знак руком „у реду“: тамна кожа',
    '🤌🏻' => 'скупљени прсти: свијетла кожа',
    '🤌🏼' => 'скупљени прсти: средње свијетла кожа',
    '🤌🏽' => 'скупљени прсти: ни свијетла ни тамна кожа',
    '🤌🏾' => 'скупљени прсти: средње тамна кожа',
    '🤌🏿' => 'скупљени прсти: тамна кожа',
    '🤏🏻' => 'рука штипа: свијетла кожа',
    '🤏🏼' => 'рука штипа: средње свијетла кожа',
    '🤏🏽' => 'рука штипа: ни свијетла ни тамна кожа',
    '🤏🏾' => 'рука штипа: средње тамна кожа',
    '🤏🏿' => 'рука штипа: тамна кожа',
    '✌🏻' => 'знак побједе: свијетла кожа',
    '✌🏼' => 'знак побједе: средње свијетла кожа',
    '✌🏽' => 'знак побједе: ни свијетла ни тамна кожа',
    '✌🏾' => 'знак побједе: средње тамна кожа',
    '✌🏿' => 'знак побједе: тамна кожа',
    '🤞🏻' => 'прекрштени прсти: свијетла кожа',
    '🤞🏼' => 'прекрштени прсти: средње свијетла кожа',
    '🤞🏽' => 'прекрштени прсти: ни свијетла ни тамна кожа',
    '🤞🏾' => 'прекрштени прсти: средње тамна кожа',
    '🤞🏿' => 'прекрштени прсти: тамна кожа',
    '🫰🏻' => 'рука са прекрштеним палцем и кажипрстом: свијетла кожа',
    '🫰🏼' => 'рука са прекрштеним палцем и кажипрстом: средње свијетла кожа',
    '🫰🏽' => 'рука са прекрштеним палцем и кажипрстом: ни свијетла ни тамна кожа',
    '🫰🏾' => 'рука са прекрштеним палцем и кажипрстом: средње тамна кожа',
    '🫰🏿' => 'рука са прекрштеним палцем и кажипрстом: тамна кожа',
    '🤟🏻' => 'покрет волим те: свијетла кожа',
    '🤟🏼' => 'покрет волим те: средње свијетла кожа',
    '🤟🏽' => 'покрет волим те: ни свијетла ни тамна кожа',
    '🤟🏾' => 'покрет волим те: средње тамна кожа',
    '🤟🏿' => 'покрет волим те: тамна кожа',
    '🤘🏻' => 'знак рогова: свијетла кожа',
    '🤘🏼' => 'знак рогова: средње свијетла кожа',
    '🤘🏽' => 'знак рогова: ни свијетла ни тамна кожа',
    '🤘🏾' => 'знак рогова: средње тамна кожа',
    '🤘🏿' => 'знак рогова: тамна кожа',
    '🤙🏻' => 'знак руком за телефон: свијетла кожа',
    '🤙🏼' => 'знак руком за телефон: средње свијетла кожа',
    '🤙🏽' => 'знак руком за телефон: ни свијетла ни тамна кожа',
    '🤙🏾' => 'знак руком за телефон: средње тамна кожа',
    '🤙🏿' => 'знак руком за телефон: тамна кожа',
    '👈🏻' => 'кажипрст који показује улијево: свијетла кожа',
    '👈🏼' => 'кажипрст који показује улијево: средње свијетла кожа',
    '👈🏽' => 'кажипрст који показује улијево: ни свијетла ни тамна кожа',
    '👈🏾' => 'кажипрст који показује улијево: средње тамна кожа',
    '👈🏿' => 'кажипрст који показује улијево: тамна кожа',
    '👉🏻' => 'кажипрст који показује удесно: свијетла кожа',
    '👉🏼' => 'кажипрст који показује удесно: средње свијетла кожа',
    '👉🏽' => 'кажипрст који показује удесно: ни свијетла ни тамна кожа',
    '👉🏾' => 'кажипрст који показује удесно: средње тамна кожа',
    '👉🏿' => 'кажипрст који показује удесно: тамна кожа',
    '👆🏻' => 'кажипрст који показује нагоре отпозади: свијетла кожа',
    '👆🏼' => 'кажипрст који показује нагоре отпозади: средње свијетла кожа',
    '👆🏽' => 'кажипрст који показује нагоре отпозади: ни свијетла ни тамна кожа',
    '👆🏾' => 'кажипрст који показује нагоре отпозади: средње тамна кожа',
    '👆🏿' => 'кажипрст који показује нагоре отпозади: тамна кожа',
    '🖕🏻' => 'средњи прст: свијетла кожа',
    '🖕🏼' => 'средњи прст: средње свијетла кожа',
    '🖕🏽' => 'средњи прст: ни свијетла ни тамна кожа',
    '🖕🏾' => 'средњи прст: средње тамна кожа',
    '🖕🏿' => 'средњи прст: тамна кожа',
    '👇🏻' => 'кажипрст који показује надоље отпозади: свијетла кожа',
    '👇🏼' => 'кажипрст који показује надоље отпозади: средње свијетла кожа',
    '👇🏽' => 'кажипрст који показује надоље отпозади: ни свијетла ни тамна кожа',
    '👇🏾' => 'кажипрст који показује надоље отпозади: средње тамна кожа',
    '👇🏿' => 'кажипрст који показује надоље отпозади: тамна кожа',
    '☝🏻' => 'кажипрст који показује нагоре: свијетла кожа',
    '☝🏼' => 'кажипрст који показује нагоре: средње свијетла кожа',
    '☝🏽' => 'кажипрст који показује нагоре: ни свијетла ни тамна кожа',
    '☝🏾' => 'кажипрст који показује нагоре: средње тамна кожа',
    '☝🏿' => 'кажипрст који показује нагоре: тамна кожа',
    '🫵🏻' => 'кажипрст који показује према гледаоцу: свијетла кожа',
    '🫵🏼' => 'кажипрст који показује према гледаоцу: средње свијетла кожа',
    '🫵🏽' => 'кажипрст који показује према гледаоцу: ни свијетла ни тамна кожа',
    '🫵🏾' => 'кажипрст који показује према гледаоцу: средње тамна кожа',
    '🫵🏿' => 'кажипрст који показује према гледаоцу: тамна кожа',
    '👍🏻' => 'палац нагоре: свијетла кожа',
    '👍🏼' => 'палац нагоре: средње свијетла кожа',
    '👍🏽' => 'палац нагоре: ни свијетла ни тамна кожа',
    '👍🏾' => 'палац нагоре: средње тамна кожа',
    '👍🏿' => 'палац нагоре: тамна кожа',
    '👎🏻' => 'палац надоље: свијетла кожа',
    '👎🏼' => 'палац надоље: средње свијетла кожа',
    '👎🏽' => 'палац надоље: ни свијетла ни тамна кожа',
    '👎🏾' => 'палац надоље: средње тамна кожа',
    '👎🏿' => 'палац надоље: тамна кожа',
    '✊🏻' => 'песница: свијетла кожа',
    '✊🏼' => 'песница: средње свијетла кожа',
    '✊🏽' => 'песница: ни свијетла ни тамна кожа',
    '✊🏾' => 'песница: средње тамна кожа',
    '✊🏿' => 'песница: тамна кожа',
    '👊🏻' => 'усмјерена песница: свијетла кожа',
    '👊🏼' => 'усмјерена песница: средње свијетла кожа',
    '👊🏽' => 'усмјерена песница: ни свијетла ни тамна кожа',
    '👊🏾' => 'усмјерена песница: средње тамна кожа',
    '👊🏿' => 'усмјерена песница: тамна кожа',
    '🤛🏻' => 'песница улијево: свијетла кожа',
    '🤛🏼' => 'песница улијево: средње свијетла кожа',
    '🤛🏽' => 'песница улијево: ни свијетла ни тамна кожа',
    '🤛🏾' => 'песница улијево: средње тамна кожа',
    '🤛🏿' => 'песница улијево: тамна кожа',
    '🤜🏻' => 'песница удесно: свијетла кожа',
    '🤜🏼' => 'песница удесно: средње свијетла кожа',
    '🤜🏽' => 'песница удесно: ни свијетла ни тамна кожа',
    '🤜🏾' => 'песница удесно: средње тамна кожа',
    '🤜🏿' => 'песница удесно: тамна кожа',
    '👏🏻' => 'руке које тапшу: свијетла кожа',
    '👏🏼' => 'руке које тапшу: средње свијетла кожа',
    '👏🏽' => 'руке које тапшу: ни свијетла ни тамна кожа',
    '👏🏾' => 'руке које тапшу: средње тамна кожа',
    '👏🏿' => 'руке које тапшу: тамна кожа',
    '🙌🏻' => 'подигнуте руке: свијетла кожа',
    '🙌🏼' => 'подигнуте руке: средње свијетла кожа',
    '🙌🏽' => 'подигнуте руке: ни свијетла ни тамна кожа',
    '🙌🏾' => 'подигнуте руке: средње тамна кожа',
    '🙌🏿' => 'подигнуте руке: тамна кожа',
    '🫶🏻' => 'руке које праве срце: свијетла кожа',
    '🫶🏼' => 'руке које праве срце: средње свијетла кожа',
    '🫶🏽' => 'руке које праве срце: ни свијетла ни тамна кожа',
    '🫶🏾' => 'руке које праве срце: средње тамна кожа',
    '🫶🏿' => 'руке које праве срце: тамна кожа',
    '👐🏻' => 'расклопљене шаке: свијетла кожа',
    '👐🏼' => 'расклопљене шаке: средње свијетла кожа',
    '👐🏽' => 'расклопљене шаке: ни свијетла ни тамна кожа',
    '👐🏾' => 'расклопљене шаке: средње тамна кожа',
    '👐🏿' => 'расклопљене шаке: тамна кожа',
    '🤲🏻' => 'дланови нагоре заједно: свијетла кожа',
    '🤲🏼' => 'дланови нагоре заједно: средње свијетла кожа',
    '🤲🏽' => 'дланови нагоре заједно: ни свијетла ни тамна кожа',
    '🤲🏾' => 'дланови нагоре заједно: средње тамна кожа',
    '🤲🏿' => 'дланови нагоре заједно: тамна кожа',
    '🤝🏻' => 'руковање: свијетла кожа',
    '🤝🏼' => 'руковање: средње свијетла кожа',
    '🤝🏽' => 'руковање: ни свијетла ни тамна кожа',
    '🤝🏾' => 'руковање: средње тамна кожа',
    '🤝🏿' => 'руковање: тамна кожа',
    '🙏🏻' => 'спојени дланови: свијетла кожа',
    '🙏🏼' => 'спојени дланови: средње свијетла кожа',
    '🙏🏽' => 'спојени дланови: ни свијетла ни тамна кожа',
    '🙏🏾' => 'спојени дланови: средње тамна кожа',
    '🙏🏿' => 'спојени дланови: тамна кожа',
    '✍🏻' => 'рука која пише: свијетла кожа',
    '✍🏼' => 'рука која пише: средње свијетла кожа',
    '✍🏽' => 'рука која пише: ни свијетла ни тамна кожа',
    '✍🏾' => 'рука која пише: средње тамна кожа',
    '✍🏿' => 'рука која пише: тамна кожа',
    '💅🏻' => 'лак за нокте: свијетла кожа',
    '💅🏼' => 'лак за нокте: средње свијетла кожа',
    '💅🏽' => 'лак за нокте: ни свијетла ни тамна кожа',
    '💅🏾' => 'лак за нокте: средње тамна кожа',
    '💅🏿' => 'лак за нокте: тамна кожа',
    '🤳🏻' => 'селфи: свијетла кожа',
    '🤳🏼' => 'селфи: средње свијетла кожа',
    '🤳🏽' => 'селфи: ни свијетла ни тамна кожа',
    '🤳🏾' => 'селфи: средње тамна кожа',
    '🤳🏿' => 'селфи: тамна кожа',
    '💪🏻' => 'стегнути бицепс: свијетла кожа',
    '💪🏼' => 'стегнути бицепс: средње свијетла кожа',
    '💪🏽' => 'стегнути бицепс: ни свијетла ни тамна кожа',
    '💪🏾' => 'стегнути бицепс: средње тамна кожа',
    '💪🏿' => 'стегнути бицепс: тамна кожа',
    '🦵🏻' => 'нога: свијетла кожа',
    '🦵🏼' => 'нога: средње свијетла кожа',
    '🦵🏽' => 'нога: ни свијетла ни тамна кожа',
    '🦵🏾' => 'нога: средње тамна кожа',
    '🦵🏿' => 'нога: тамна кожа',
    '🦶🏻' => 'стопало: свијетла кожа',
    '🦶🏼' => 'стопало: средње свијетла кожа',
    '🦶🏽' => 'стопало: ни свијетла ни тамна кожа',
    '🦶🏾' => 'стопало: средње тамна кожа',
    '🦶🏿' => 'стопало: тамна кожа',
    '👂🏻' => 'уво: свијетла кожа',
    '👂🏼' => 'уво: средње свијетла кожа',
    '👂🏽' => 'уво: ни свијетла ни тамна кожа',
    '👂🏾' => 'уво: средње тамна кожа',
    '👂🏿' => 'уво: тамна кожа',
    '🦻🏻' => 'уво са слушним апаратом: свијетла кожа',
    '🦻🏼' => 'уво са слушним апаратом: средње свијетла кожа',
    '🦻🏽' => 'уво са слушним апаратом: ни свијетла ни тамна кожа',
    '🦻🏾' => 'уво са слушним апаратом: средње тамна кожа',
    '🦻🏿' => 'уво са слушним апаратом: тамна кожа',
    '👃🏻' => 'нос: свијетла кожа',
    '👃🏼' => 'нос: средње свијетла кожа',
    '👃🏽' => 'нос: ни свијетла ни тамна кожа',
    '👃🏾' => 'нос: средње тамна кожа',
    '👃🏿' => 'нос: тамна кожа',
    '👶🏻' => 'беба: свијетла кожа',
    '👶🏼' => 'беба: средње свијетла кожа',
    '👶🏽' => 'беба: ни свијетла ни тамна кожа',
    '👶🏾' => 'беба: средње тамна кожа',
    '👶🏿' => 'беба: тамна кожа',
    '🧒🏻' => 'дијете: свијетла кожа',
    '🧒🏼' => 'дијете: средње свијетла кожа',
    '🧒🏽' => 'дијете: ни свијетла ни тамна кожа',
    '🧒🏾' => 'дијете: средње тамна кожа',
    '🧒🏿' => 'дијете: тамна кожа',
    '👦🏻' => 'дјечак: свијетла кожа',
    '👦🏼' => 'дјечак: средње свијетла кожа',
    '👦🏽' => 'дјечак: ни свијетла ни тамна кожа',
    '👦🏾' => 'дјечак: средње тамна кожа',
    '👦🏿' => 'дјечак: тамна кожа',
    '👧🏻' => 'дјевојчица: свијетла кожа',
    '👧🏼' => 'дјевојчица: средње свијетла кожа',
    '👧🏽' => 'дјевојчица: ни свијетла ни тамна кожа',
    '👧🏾' => 'дјевојчица: средње тамна кожа',
    '👧🏿' => 'дјевојчица: тамна кожа',
    '🧑🏻' => 'одрасла особа: свијетла кожа',
    '🧑🏼' => 'одрасла особа: средње свијетла кожа',
    '🧑🏽' => 'одрасла особа: ни свијетла ни тамна кожа',
    '🧑🏾' => 'одрасла особа: средње тамна кожа',
    '🧑🏿' => 'одрасла особа: тамна кожа',
    '👱🏻' => 'особа са плавом косом: свијетла кожа',
    '👱🏼' => 'особа са плавом косом: средње свијетла кожа',
    '👱🏽' => 'особа са плавом косом: ни свијетла ни тамна кожа',
    '👱🏾' => 'особа са плавом косом: средње тамна кожа',
    '👱🏿' => 'особа са плавом косом: тамна кожа',
    '👨🏻' => 'мушкарац: свијетла кожа',
    '👨🏼' => 'мушкарац: средње свијетла кожа',
    '👨🏽' => 'мушкарац: ни свијетла ни тамна кожа',
    '👨🏾' => 'мушкарац: средње тамна кожа',
    '👨🏿' => 'мушкарац: тамна кожа',
    '🧔🏻' => 'особа са брадом: свијетла кожа',
    '🧔🏼' => 'особа са брадом: средње свијетла кожа',
    '🧔🏽' => 'особа са брадом: ни свијетла ни тамна кожа',
    '🧔🏾' => 'особа са брадом: средње тамна кожа',
    '🧔🏿' => 'особа са брадом: тамна кожа',
    '👩🏻' => 'жена: свијетла кожа',
    '👩🏼' => 'жена: средње свијетла кожа',
    '👩🏽' => 'жена: ни свијетла ни тамна кожа',
    '👩🏾' => 'жена: средње тамна кожа',
    '👩🏿' => 'жена: тамна кожа',
    '🧓🏻' => 'старија одрасла особа: свијетла кожа',
    '🧓🏼' => 'старија одрасла особа: средње свијетла кожа',
    '🧓🏽' => 'старија одрасла особа: ни свијетла ни тамна кожа',
    '🧓🏾' => 'старија одрасла особа: средње тамна кожа',
    '🧓🏿' => 'старија одрасла особа: тамна кожа',
    '👴🏻' => 'старац: свијетла кожа',
    '👴🏼' => 'старац: средње свијетла кожа',
    '👴🏽' => 'старац: ни свијетла ни тамна кожа',
    '👴🏾' => 'старац: средње тамна кожа',
    '👴🏿' => 'старац: тамна кожа',
    '👵🏻' => 'старица: свијетла кожа',
    '👵🏼' => 'старица: средње свијетла кожа',
    '👵🏽' => 'старица: ни свијетла ни тамна кожа',
    '👵🏾' => 'старица: средње тамна кожа',
    '👵🏿' => 'старица: тамна кожа',
    '🙍🏻' => 'намрштена особа: свијетла кожа',
    '🙍🏼' => 'намрштена особа: средње свијетла кожа',
    '🙍🏽' => 'намрштена особа: ни свијетла ни тамна кожа',
    '🙍🏾' => 'намрштена особа: средње тамна кожа',
    '🙍🏿' => 'намрштена особа: тамна кожа',
    '🙎🏻' => 'надурена особа: свијетла кожа',
    '🙎🏼' => 'надурена особа: средње свијетла кожа',
    '🙎🏽' => 'надурена особа: ни свијетла ни тамна кожа',
    '🙎🏾' => 'надурена особа: средње тамна кожа',
    '🙎🏿' => 'надурена особа: тамна кожа',
    '🙅🏻' => 'особа која показује „не“: свијетла кожа',
    '🙅🏼' => 'особа која показује „не“: средње свијетла кожа',
    '🙅🏽' => 'особа која показује „не“: ни свијетла ни тамна кожа',
    '🙅🏾' => 'особа која показује „не“: средње тамна кожа',
    '🙅🏿' => 'особа која показује „не“: тамна кожа',
    '🙆🏻' => 'особа која показује „у реду“: свијетла кожа',
    '🙆🏼' => 'особа која показује „у реду“: средње свијетла кожа',
    '🙆🏽' => 'особа која показује „у реду“: ни свијетла ни тамна кожа',
    '🙆🏾' => 'особа која показује „у реду“: средње тамна кожа',
    '🙆🏿' => 'особа која показује „у реду“: тамна кожа',
    '💁🏻' => 'особа која даје информације: свијетла кожа',
    '💁🏼' => 'особа која даје информације: средње свијетла кожа',
    '💁🏽' => 'особа која даје информације: ни свијетла ни тамна кожа',
    '💁🏾' => 'особа која даје информације: средње тамна кожа',
    '💁🏿' => 'особа која даје информације: тамна кожа',
    '🙋🏻' => 'срећна особа са подигнутом руком: свијетла кожа',
    '🙋🏼' => 'срећна особа са подигнутом руком: средње свијетла кожа',
    '🙋🏽' => 'срећна особа са подигнутом руком: ни свијетла ни тамна кожа',
    '🙋🏾' => 'срећна особа са подигнутом руком: средње тамна кожа',
    '🙋🏿' => 'срећна особа са подигнутом руком: тамна кожа',
    '🧏🏻' => 'глува особа: свијетла кожа',
    '🧏🏼' => 'глува особа: средње свијетла кожа',
    '🧏🏽' => 'глува особа: ни свијетла ни тамна кожа',
    '🧏🏾' => 'глува особа: средње тамна кожа',
    '🧏🏿' => 'глува особа: тамна кожа',
    '🙇🏻' => 'особа која се клања: свијетла кожа',
    '🙇🏼' => 'особа која се клања: средње свијетла кожа',
    '🙇🏽' => 'особа која се клања: ни свијетла ни тамна кожа',
    '🙇🏾' => 'особа која се клања: средње тамна кожа',
    '🙇🏿' => 'особа која се клања: тамна кожа',
    '🤦🏻' => 'шака о чело: свијетла кожа',
    '🤦🏼' => 'шака о чело: средње свијетла кожа',
    '🤦🏽' => 'шака о чело: ни свијетла ни тамна кожа',
    '🤦🏾' => 'шака о чело: средње тамна кожа',
    '🤦🏿' => 'шака о чело: тамна кожа',
    '🤷🏻' => 'слијегање раменима: свијетла кожа',
    '🤷🏼' => 'слијегање раменима: средње свијетла кожа',
    '🤷🏽' => 'слијегање раменима: ни свијетла ни тамна кожа',
    '🤷🏾' => 'слијегање раменима: средње тамна кожа',
    '🤷🏿' => 'слијегање раменима: тамна кожа',
    '👮🏻' => 'представник полиције: свијетла кожа',
    '👮🏼' => 'представник полиције: средње свијетла кожа',
    '👮🏽' => 'представник полиције: ни свијетла ни тамна кожа',
    '👮🏾' => 'представник полиције: средње тамна кожа',
    '👮🏿' => 'представник полиције: тамна кожа',
    '🕵🏻' => 'инспектор: свијетла кожа',
    '🕵🏼' => 'инспектор: средње свијетла кожа',
    '🕵🏽' => 'инспектор: ни свијетла ни тамна кожа',
    '🕵🏾' => 'инспектор: средње тамна кожа',
    '🕵🏿' => 'инспектор: тамна кожа',
    '💂🏻' => 'чувар: свијетла кожа',
    '💂🏼' => 'чувар: средње свијетла кожа',
    '💂🏽' => 'чувар: ни свијетла ни тамна кожа',
    '💂🏾' => 'чувар: средње тамна кожа',
    '💂🏿' => 'чувар: тамна кожа',
    '🥷🏻' => 'нинџа: свијетла кожа',
    '🥷🏼' => 'нинџа: средње свијетла кожа',
    '🥷🏽' => 'нинџа: ни свијетла ни тамна кожа',
    '🥷🏾' => 'нинџа: средње тамна кожа',
    '🥷🏿' => 'нинџа: тамна кожа',
    '👷🏻' => 'грађевински радник: свијетла кожа',
    '👷🏼' => 'грађевински радник: средње свијетла кожа',
    '👷🏽' => 'грађевински радник: ни свијетла ни тамна кожа',
    '👷🏾' => 'грађевински радник: средње тамна кожа',
    '👷🏿' => 'грађевински радник: тамна кожа',
    '🫅🏻' => 'особа са круном: свијетла кожа',
    '🫅🏼' => 'особа са круном: средње свијетла кожа',
    '🫅🏽' => 'особа са круном: ни свијетла ни тамна кожа',
    '🫅🏾' => 'особа са круном: средње тамна кожа',
    '🫅🏿' => 'особа са круном: тамна кожа',
    '🤴🏻' => 'принц: свијетла кожа',
    '🤴🏼' => 'принц: средње свијетла кожа',
    '🤴🏽' => 'принц: ни свијетла ни тамна кожа',
    '🤴🏾' => 'принц: средње тамна кожа',
    '🤴🏿' => 'принц: тамна кожа',
    '👸🏻' => 'принцеза: свијетла кожа',
    '👸🏼' => 'принцеза: средње свијетла кожа',
    '👸🏽' => 'принцеза: ни свијетла ни тамна кожа',
    '👸🏾' => 'принцеза: средње тамна кожа',
    '👸🏿' => 'принцеза: тамна кожа',
    '👳🏻' => 'особа са турбаном: свијетла кожа',
    '👳🏼' => 'особа са турбаном: средње свијетла кожа',
    '👳🏽' => 'особа са турбаном: ни свијетла ни тамна кожа',
    '👳🏾' => 'особа са турбаном: средње тамна кожа',
    '👳🏿' => 'особа са турбаном: тамна кожа',
    '👲🏻' => 'човјек са кинеском капом: свијетла кожа',
    '👲🏼' => 'човјек са кинеском капом: средње свијетла кожа',
    '👲🏽' => 'човјек са кинеском капом: ни свијетла ни тамна кожа',
    '👲🏾' => 'човјек са кинеском капом: средње тамна кожа',
    '👲🏿' => 'човјек са кинеском капом: тамна кожа',
    '🧕🏻' => 'жена са марамом на глави: свијетла кожа',
    '🧕🏼' => 'жена са марамом на глави: средње свијетла кожа',
    '🧕🏽' => 'жена са марамом на глави: ни свијетла ни тамна кожа',
    '🧕🏾' => 'жена са марамом на глави: средње тамна кожа',
    '🧕🏿' => 'жена са марамом на глави: тамна кожа',
    '🤵🏻' => 'човјек у смокингу: свијетла кожа',
    '🤵🏼' => 'човјек у смокингу: средње свијетла кожа',
    '🤵🏽' => 'човјек у смокингу: ни свијетла ни тамна кожа',
    '🤵🏾' => 'човјек у смокингу: средње тамна кожа',
    '🤵🏿' => 'човјек у смокингу: тамна кожа',
    '👰🏻' => 'невјеста са велом: свијетла кожа',
    '👰🏼' => 'невјеста са велом: средње свијетла кожа',
    '👰🏽' => 'невјеста са велом: ни свијетла ни тамна кожа',
    '👰🏾' => 'невјеста са велом: средње тамна кожа',
    '👰🏿' => 'невјеста са велом: тамна кожа',
    '🤰🏻' => 'трудница: свијетла кожа',
    '🤰🏼' => 'трудница: средње свијетла кожа',
    '🤰🏽' => 'трудница: ни свијетла ни тамна кожа',
    '🤰🏾' => 'трудница: средње тамна кожа',
    '🤰🏿' => 'трудница: тамна кожа',
    '🫃🏻' => 'трудни мушкарац: свијетла кожа',
    '🫃🏼' => 'трудни мушкарац: средње свијетла кожа',
    '🫃🏽' => 'трудни мушкарац: ни свијетла ни тамна кожа',
    '🫃🏾' => 'трудни мушкарац: средње тамна кожа',
    '🫃🏿' => 'трудни мушкарац: тамна кожа',
    '🫄🏻' => 'трудна особа: свијетла кожа',
    '🫄🏼' => 'трудна особа: средње свијетла кожа',
    '🫄🏽' => 'трудна особа: ни свијетла ни тамна кожа',
    '🫄🏾' => 'трудна особа: средње тамна кожа',
    '🫄🏿' => 'трудна особа: тамна кожа',
    '🤱🏻' => 'дојење: свијетла кожа',
    '🤱🏼' => 'дојење: средње свијетла кожа',
    '🤱🏽' => 'дојење: ни свијетла ни тамна кожа',
    '🤱🏾' => 'дојење: средње тамна кожа',
    '🤱🏿' => 'дојење: тамна кожа',
    '👼🏻' => 'беба анђео: свијетла кожа',
    '👼🏼' => 'беба анђео: средње свијетла кожа',
    '👼🏽' => 'беба анђео: ни свијетла ни тамна кожа',
    '👼🏾' => 'беба анђео: средње тамна кожа',
    '👼🏿' => 'беба анђео: тамна кожа',
    '🎅🏻' => 'Дјед Мраз: свијетла кожа',
    '🎅🏼' => 'Дјед Мраз: средње свијетла кожа',
    '🎅🏽' => 'Дјед Мраз: ни свијетла ни тамна кожа',
    '🎅🏾' => 'Дјед Мраз: средње тамна кожа',
    '🎅🏿' => 'Дјед Мраз: тамна кожа',
    '🤶🏻' => 'бака Мраз: свијетла кожа',
    '🤶🏼' => 'бака Мраз: средње свијетла кожа',
    '🤶🏽' => 'бака Мраз: ни свијетла ни тамна кожа',
    '🤶🏾' => 'бака Мраз: средње тамна кожа',
    '🤶🏿' => 'бака Мраз: тамна кожа',
    '🦸🏻' => 'суперхерој: свијетла кожа',
    '🦸🏼' => 'суперхерој: средње свијетла кожа',
    '🦸🏽' => 'суперхерој: ни свијетла ни тамна кожа',
    '🦸🏾' => 'суперхерој: средње тамна кожа',
    '🦸🏿' => 'суперхерој: тамна кожа',
    '🦹🏻' => 'негативац: свијетла кожа',
    '🦹🏼' => 'негативац: средње свијетла кожа',
    '🦹🏽' => 'негативац: ни свијетла ни тамна кожа',
    '🦹🏾' => 'негативац: средње тамна кожа',
    '🦹🏿' => 'негативац: тамна кожа',
    '🧙🏻' => 'маг: свијетла кожа',
    '🧙🏼' => 'маг: средње свијетла кожа',
    '🧙🏽' => 'маг: ни свијетла ни тамна кожа',
    '🧙🏾' => 'маг: средње тамна кожа',
    '🧙🏿' => 'маг: тамна кожа',
    '🧚🏻' => 'вила: свијетла кожа',
    '🧚🏼' => 'вила: средње свијетла кожа',
    '🧚🏽' => 'вила: ни свијетла ни тамна кожа',
    '🧚🏾' => 'вила: средње тамна кожа',
    '🧚🏿' => 'вила: тамна кожа',
    '🧛🏻' => 'вампир: свијетла кожа',
    '🧛🏼' => 'вампир: средње свијетла кожа',
    '🧛🏽' => 'вампир: ни свијетла ни тамна кожа',
    '🧛🏾' => 'вампир: средње тамна кожа',
    '🧛🏿' => 'вампир: тамна кожа',
    '🧜🏻' => 'особа из мора: свијетла кожа',
    '🧜🏼' => 'особа из мора: средње свијетла кожа',
    '🧜🏽' => 'особа из мора: ни свијетла ни тамна кожа',
    '🧜🏾' => 'особа из мора: средње тамна кожа',
    '🧜🏿' => 'особа из мора: тамна кожа',
    '🧝🏻' => 'виловњак: свијетла кожа',
    '🧝🏼' => 'виловњак: средње свијетла кожа',
    '🧝🏽' => 'виловњак: ни свијетла ни тамна кожа',
    '🧝🏾' => 'виловњак: средње тамна кожа',
    '🧝🏿' => 'виловњак: тамна кожа',
    '💆🏻' => 'масажа лица: свијетла кожа',
    '💆🏼' => 'масажа лица: средње свијетла кожа',
    '💆🏽' => 'масажа лица: ни свијетла ни тамна кожа',
    '💆🏾' => 'масажа лица: средње тамна кожа',
    '💆🏿' => 'масажа лица: тамна кожа',
    '💇🏻' => 'шишање: свијетла кожа',
    '💇🏼' => 'шишање: средње свијетла кожа',
    '💇🏽' => 'шишање: ни свијетла ни тамна кожа',
    '💇🏾' => 'шишање: средње тамна кожа',
    '💇🏿' => 'шишање: тамна кожа',
    '🚶🏻' => 'пјешак: свијетла кожа',
    '🚶🏼' => 'пјешак: средње свијетла кожа',
    '🚶🏽' => 'пјешак: ни свијетла ни тамна кожа',
    '🚶🏾' => 'пјешак: средње тамна кожа',
    '🚶🏿' => 'пјешак: тамна кожа',
    '🧍🏻' => 'особа стоји: свијетла кожа',
    '🧍🏼' => 'особа стоји: средње свијетла кожа',
    '🧍🏽' => 'особа стоји: ни свијетла ни тамна кожа',
    '🧍🏾' => 'особа стоји: средње тамна кожа',
    '🧍🏿' => 'особа стоји: тамна кожа',
    '🧎🏻' => 'особа клечи: свијетла кожа',
    '🧎🏼' => 'особа клечи: средње свијетла кожа',
    '🧎🏽' => 'особа клечи: ни свијетла ни тамна кожа',
    '🧎🏾' => 'особа клечи: средње тамна кожа',
    '🧎🏿' => 'особа клечи: тамна кожа',
    '🏃🏻' => 'тркач: свијетла кожа',
    '🏃🏼' => 'тркач: средње свијетла кожа',
    '🏃🏽' => 'тркач: ни свијетла ни тамна кожа',
    '🏃🏾' => 'тркач: средње тамна кожа',
    '🏃🏿' => 'тркач: тамна кожа',
    '💃🏻' => 'плесачица: свијетла кожа',
    '💃🏼' => 'плесачица: средње свијетла кожа',
    '💃🏽' => 'плесачица: ни свијетла ни тамна кожа',
    '💃🏾' => 'плесачица: средње тамна кожа',
    '💃🏿' => 'плесачица: тамна кожа',
    '🕺🏻' => 'плесач: свијетла кожа',
    '🕺🏼' => 'плесач: средње свијетла кожа',
    '🕺🏽' => 'плесач: ни свијетла ни тамна кожа',
    '🕺🏾' => 'плесач: средње тамна кожа',
    '🕺🏿' => 'плесач: тамна кожа',
    '🕴🏻' => 'мушкарац у пословном одијелу који лебди: свијетла кожа',
    '🕴🏼' => 'мушкарац у пословном одијелу који лебди: средње свијетла кожа',
    '🕴🏽' => 'мушкарац у пословном одијелу који лебди: ни свијетла ни тамна кожа',
    '🕴🏾' => 'мушкарац у пословном одијелу који лебди: средње тамна кожа',
    '🕴🏿' => 'мушкарац у пословном одијелу који лебди: тамна кожа',
    '👯🏻' => 'особе у проводу: свијетла кожа',
    '👯🏼' => 'особе у проводу: средње свијетла кожа',
    '👯🏽' => 'особе у проводу: ни свијетла ни тамна кожа',
    '👯🏾' => 'особе у проводу: средње тамна кожа',
    '👯🏿' => 'особе у проводу: тамна кожа',
    '🧖🏻' => 'особа у парном купатилу: свијетла кожа',
    '🧖🏼' => 'особа у парном купатилу: средње свијетла кожа',
    '🧖🏽' => 'особа у парном купатилу: ни свијетла ни тамна кожа',
    '🧖🏾' => 'особа у парном купатилу: средње тамна кожа',
    '🧖🏿' => 'особа у парном купатилу: тамна кожа',
    '🧗🏻' => 'пењање: свијетла кожа',
    '🧗🏼' => 'пењање: средње свијетла кожа',
    '🧗🏽' => 'пењање: ни свијетла ни тамна кожа',
    '🧗🏾' => 'пењање: средње тамна кожа',
    '🧗🏿' => 'пењање: тамна кожа',
    '🏇🏻' => 'трке коња: свијетла кожа',
    '🏇🏼' => 'трке коња: средње свијетла кожа',
    '🏇🏽' => 'трке коња: ни свијетла ни тамна кожа',
    '🏇🏾' => 'трке коња: средње тамна кожа',
    '🏇🏿' => 'трке коња: тамна кожа',
    '🏂🏻' => 'возач сноуборда: свијетла кожа',
    '🏂🏼' => 'возач сноуборда: средње свијетла кожа',
    '🏂🏽' => 'возач сноуборда: ни свијетла ни тамна кожа',
    '🏂🏾' => 'возач сноуборда: средње тамна кожа',
    '🏂🏿' => 'возач сноуборда: тамна кожа',
    '🏌🏻' => 'особа игра голф: свијетла кожа',
    '🏌🏼' => 'особа игра голф: средње свијетла кожа',
    '🏌🏽' => 'особа игра голф: ни свијетла ни тамна кожа',
    '🏌🏾' => 'особа игра голф: средње тамна кожа',
    '🏌🏿' => 'особа игра голф: тамна кожа',
    '🏄🏻' => 'особа сурфује: свијетла кожа',
    '🏄🏼' => 'особа сурфује: средње свијетла кожа',
    '🏄🏽' => 'особа сурфује: ни свијетла ни тамна кожа',
    '🏄🏾' => 'особа сурфује: средње тамна кожа',
    '🏄🏿' => 'особа сурфује: тамна кожа',
    '🚣🏻' => 'чамац на весла: свијетла кожа',
    '🚣🏼' => 'чамац на весла: средње свијетла кожа',
    '🚣🏽' => 'чамац на весла: ни свијетла ни тамна кожа',
    '🚣🏾' => 'чамац на весла: средње тамна кожа',
    '🚣🏿' => 'чамац на весла: тамна кожа',
    '🏊🏻' => 'особа плива: свијетла кожа',
    '🏊🏼' => 'особа плива: средње свијетла кожа',
    '🏊🏽' => 'особа плива: ни свијетла ни тамна кожа',
    '🏊🏾' => 'особа плива: средње тамна кожа',
    '🏊🏿' => 'особа плива: тамна кожа',
    '⛹🏻' => 'особа са лоптом: свијетла кожа',
    '⛹🏼' => 'особа са лоптом: средње свијетла кожа',
    '⛹🏽' => 'особа са лоптом: ни свијетла ни тамна кожа',
    '⛹🏾' => 'особа са лоптом: средње тамна кожа',
    '⛹🏿' => 'особа са лоптом: тамна кожа',
    '🏋🏻' => 'особа диже тегове: свијетла кожа',
    '🏋🏼' => 'особа диже тегове: средње свијетла кожа',
    '🏋🏽' => 'особа диже тегове: ни свијетла ни тамна кожа',
    '🏋🏾' => 'особа диже тегове: средње тамна кожа',
    '🏋🏿' => 'особа диже тегове: тамна кожа',
    '🚴🏻' => 'особа на бициклу: свијетла кожа',
    '🚴🏼' => 'особа на бициклу: средње свијетла кожа',
    '🚴🏽' => 'особа на бициклу: ни свијетла ни тамна кожа',
    '🚴🏾' => 'особа на бициклу: средње тамна кожа',
    '🚴🏿' => 'особа на бициклу: тамна кожа',
    '🚵🏻' => 'особа на брдском бициклу: свијетла кожа',
    '🚵🏼' => 'особа на брдском бициклу: средње свијетла кожа',
    '🚵🏽' => 'особа на брдском бициклу: ни свијетла ни тамна кожа',
    '🚵🏾' => 'особа на брдском бициклу: средње тамна кожа',
    '🚵🏿' => 'особа на брдском бициклу: тамна кожа',
    '🤸🏻' => 'гимнастичарска звезда: свијетла кожа',
    '🤸🏼' => 'гимнастичарска звезда: средње свијетла кожа',
    '🤸🏽' => 'гимнастичарска звезда: ни свијетла ни тамна кожа',
    '🤸🏾' => 'гимнастичарска звезда: средње тамна кожа',
    '🤸🏿' => 'гимнастичарска звезда: тамна кожа',
    '🤼🏻' => 'рвање: свијетла кожа',
    '🤼🏼' => 'рвање: средње свијетла кожа',
    '🤼🏽' => 'рвање: ни свијетла ни тамна кожа',
    '🤼🏾' => 'рвање: средње тамна кожа',
    '🤼🏿' => 'рвање: тамна кожа',
    '🤽🏻' => 'ватерполо: свијетла кожа',
    '🤽🏼' => 'ватерполо: средње свијетла кожа',
    '🤽🏽' => 'ватерполо: ни свијетла ни тамна кожа',
    '🤽🏾' => 'ватерполо: средње тамна кожа',
    '🤽🏿' => 'ватерполо: тамна кожа',
    '🤾🏻' => 'рукомет: свијетла кожа',
    '🤾🏼' => 'рукомет: средње свијетла кожа',
    '🤾🏽' => 'рукомет: ни свијетла ни тамна кожа',
    '🤾🏾' => 'рукомет: средње тамна кожа',
    '🤾🏿' => 'рукомет: тамна кожа',
    '🤹🏻' => 'особа жонглира: свијетла кожа',
    '🤹🏼' => 'особа жонглира: средње свијетла кожа',
    '🤹🏽' => 'особа жонглира: ни свијетла ни тамна кожа',
    '🤹🏾' => 'особа жонглира: средње тамна кожа',
    '🤹🏿' => 'особа жонглира: тамна кожа',
    '🧘🏻' => 'лотос поза: свијетла кожа',
    '🧘🏼' => 'лотос поза: средње свијетла кожа',
    '🧘🏽' => 'лотос поза: ни свијетла ни тамна кожа',
    '🧘🏾' => 'лотос поза: средње тамна кожа',
    '🧘🏿' => 'лотос поза: тамна кожа',
    '🛀🏻' => 'особа која се купа: свијетла кожа',
    '🛀🏼' => 'особа која се купа: средње свијетла кожа',
    '🛀🏽' => 'особа која се купа: ни свијетла ни тамна кожа',
    '🛀🏾' => 'особа која се купа: средње тамна кожа',
    '🛀🏿' => 'особа која се купа: тамна кожа',
    '🛌🏻' => 'особа у кревету: свијетла кожа',
    '🛌🏼' => 'особа у кревету: средње свијетла кожа',
    '🛌🏽' => 'особа у кревету: ни свијетла ни тамна кожа',
    '🛌🏾' => 'особа у кревету: средње тамна кожа',
    '🛌🏿' => 'особа у кревету: тамна кожа',
    '👭🏻' => 'жене се држе за руке: свијетла кожа',
    '👭🏼' => 'жене се држе за руке: средње свијетла кожа',
    '👭🏽' => 'жене се држе за руке: ни свијетла ни тамна кожа',
    '👭🏾' => 'жене се држе за руке: средње тамна кожа',
    '👭🏿' => 'жене се држе за руке: тамна кожа',
    '👫🏻' => 'жена и мушкарац се држе за руке: свијетла кожа',
    '👫🏼' => 'жена и мушкарац се држе за руке: средње свијетла кожа',
    '👫🏽' => 'жена и мушкарац се држе за руке: ни свијетла ни тамна кожа',
    '👫🏾' => 'жена и мушкарац се држе за руке: средње тамна кожа',
    '👫🏿' => 'жена и мушкарац се држе за руке: тамна кожа',
    '👬🏻' => 'мушкарци се држе за руке: свијетла кожа',
    '👬🏼' => 'мушкарци се држе за руке: средње свијетла кожа',
    '👬🏽' => 'мушкарци се држе за руке: ни свијетла ни тамна кожа',
    '👬🏾' => 'мушкарци се држе за руке: средње тамна кожа',
    '👬🏿' => 'мушкарци се држе за руке: тамна кожа',
    '💏🏻' => 'пољубац: свијетла кожа',
    '💏🏼' => 'пољубац: средње свијетла кожа',
    '💏🏽' => 'пољубац: ни свијетла ни тамна кожа',
    '💏🏾' => 'пољубац: средње тамна кожа',
    '💏🏿' => 'пољубац: тамна кожа',
    '💑🏻' => 'пар са срцем: свијетла кожа',
    '💑🏼' => 'пар са срцем: средње свијетла кожа',
    '💑🏽' => 'пар са срцем: ни свијетла ни тамна кожа',
    '💑🏾' => 'пар са срцем: средње тамна кожа',
    '💑🏿' => 'пар са срцем: тамна кожа',
    '🇦🇨' => 'застава: острво Асенсион',
    '🇦🇩' => 'застава: Андора',
    '🇦🇪' => 'застава: Уједињени Арапски Емирати',
    '🇦🇫' => 'застава: Авганистан',
    '🇦🇬' => 'застава: Антигва и Барбуда',
    '🇦🇮' => 'застава: Ангвила',
    '🇦🇱' => 'застава: Албанија',
    '🇦🇲' => 'застава: Јерменија',
    '🇦🇴' => 'застава: Ангола',
    '🇦🇶' => 'застава: Антарктик',
    '🇦🇷' => 'застава: Аргентина',
    '🇦🇸' => 'застава: Америчка Самоа',
    '🇦🇹' => 'застава: Аустрија',
    '🇦🇺' => 'застава: Аустралија',
    '🇦🇼' => 'застава: Аруба',
    '🇦🇽' => 'застава: Оландска острва',
    '🇦🇿' => 'застава: Азербејџан',
    '🇧🇦' => 'застава: Босна и Херцеговина',
    '🇧🇧' => 'застава: Барбадос',
    '🇧🇩' => 'застава: Бангладеш',
    '🇧🇪' => 'застава: Белгија',
    '🇧🇫' => 'застава: Буркина Фасо',
    '🇧🇬' => 'застава: Бугарска',
    '🇧🇭' => 'застава: Бахреин',
    '🇧🇮' => 'застава: Бурунди',
    '🇧🇯' => 'застава: Бенин',
    '🇧🇱' => 'застава: Сен Бартелеми',
    '🇧🇲' => 'застава: Бермуди',
    '🇧🇳' => 'застава: Брунеји',
    '🇧🇴' => 'застава: Боливија',
    '🇧🇶' => 'застава: Карипска Холандија',
    '🇧🇷' => 'застава: Бразил',
    '🇧🇸' => 'застава: Бахами',
    '🇧🇹' => 'застава: Бутан',
    '🇧🇻' => 'застава: острво Буве',
    '🇧🇼' => 'застава: Боцвана',
    '🇧🇾' => 'застава: Бјелорусија',
    '🇧🇿' => 'застава: Белизе',
    '🇨🇦' => 'застава: Канада',
    '🇨🇨' => 'застава: Кокосова (Килинг) острва',
    '🇨🇩' => 'застава: Конго - Киншаса',
    '🇨🇫' => 'застава: Централноафричка Република',
    '🇨🇬' => 'застава: Конго - Бразавил',
    '🇨🇭' => 'застава: Швајцарска',
    '🇨🇮' => 'застава: Обала Слоноваче (Кот д’Ивоар)',
    '🇨🇰' => 'застава: Кукова Острва',
    '🇨🇱' => 'застава: Чиле',
    '🇨🇲' => 'застава: Камерун',
    '🇨🇳' => 'застава: Кина',
    '🇨🇴' => 'застава: Колумбија',
    '🇨🇵' => 'застава: острво Клипертон',
    '🇨🇶' => 'застава: Сарк',
    '🇨🇷' => 'застава: Костарика',
    '🇨🇺' => 'застава: Куба',
    '🇨🇻' => 'застава: Зеленортска Острва',
    '🇨🇼' => 'застава: Курасао',
    '🇨🇽' => 'застава: Божићно Острво',
    '🇨🇾' => 'застава: Кипар',
    '🇨🇿' => 'застава: Чешка Република',
    '🇩🇪' => 'застава: Њемачка',
    '🇩🇬' => 'застава: Дијего Гарсија',
    '🇩🇯' => 'застава: Џибути',
    '🇩🇰' => 'застава: Данска',
    '🇩🇲' => 'застава: Доминика',
    '🇩🇴' => 'застава: Доминиканска Република',
    '🇩🇿' => 'застава: Алжир',
    '🇪🇦' => 'застава: Сеута и Мелиља',
    '🇪🇨' => 'застава: Еквадор',
    '🇪🇪' => 'застава: Естонија',
    '🇪🇬' => 'застава: Египат',
    '🇪🇭' => 'застава: Западна Сахара',
    '🇪🇷' => 'застава: Еритреја',
    '🇪🇸' => 'застава: Шпанија',
    '🇪🇹' => 'застава: Етиопија',
    '🇪🇺' => 'застава: Европска унија',
    '🇫🇮' => 'застава: Финска',
    '🇫🇯' => 'застава: Фиџи',
    '🇫🇰' => 'застава: Фокландска острва',
    '🇫🇲' => 'застава: Микронезија',
    '🇫🇴' => 'застава: Фарска острва',
    '🇫🇷' => 'застава: Француска',
    '🇬🇦' => 'застава: Габон',
    '🇬🇧' => 'застава: Уједињено Краљевство',
    '🇬🇩' => 'застава: Гренада',
    '🇬🇪' => 'застава: Грузија',
    '🇬🇫' => 'застава: Француска Гвајана',
    '🇬🇬' => 'застава: Гернзи',
    '🇬🇭' => 'застава: Гана',
    '🇬🇮' => 'застава: Гибралтар',
    '🇬🇱' => 'застава: Гренланд',
    '🇬🇲' => 'застава: Гамбија',
    '🇬🇳' => 'застава: Гвинеја',
    '🇬🇵' => 'застава: Гваделуп',
    '🇬🇶' => 'застава: Екваторијална Гвинеја',
    '🇬🇷' => 'застава: Грчка',
    '🇬🇸' => 'застава: Јужна Џорџија и Јужна Сендвичка острва',
    '🇬🇹' => 'застава: Гватемала',
    '🇬🇺' => 'застава: Гвам',
    '🇬🇼' => 'застава: Гвинеја Бисао',
    '🇬🇾' => 'застава: Гвајана',
    '🇭🇰' => 'застава: Хонгконг (САО Кине)',
    '🇭🇲' => 'застава: острво Херд и острва Макдоналд',
    '🇭🇳' => 'застава: Хондурас',
    '🇭🇷' => 'застава: Хрватска',
    '🇭🇹' => 'застава: Хаити',
    '🇭🇺' => 'застава: Мађарска',
    '🇮🇨' => 'застава: Канарска Острва',
    '🇮🇩' => 'застава: Индонезија',
    '🇮🇪' => 'застава: Ирска',
    '🇮🇱' => 'застава: Израел',
    '🇮🇲' => 'застава: Острво Ман',
    '🇮🇳' => 'застава: Индија',
    '🇮🇴' => 'застава: Британска територија Индијског океана',
    '🇮🇶' => 'застава: Ирак',
    '🇮🇷' => 'застава: Иран',
    '🇮🇸' => 'застава: Исланд',
    '🇮🇹' => 'застава: Италија',
    '🇯🇪' => 'застава: Џерзи',
    '🇯🇲' => 'застава: Јамајка',
    '🇯🇴' => 'застава: Јордан',
    '🇯🇵' => 'застава: Јапан',
    '🇰🇪' => 'застава: Кенија',
    '🇰🇬' => 'застава: Киргистан',
    '🇰🇭' => 'застава: Камбоџа',
    '🇰🇮' => 'застава: Кирибати',
    '🇰🇲' => 'застава: Комори',
    '🇰🇳' => 'застава: Сент Китс и Невис',
    '🇰🇵' => 'застава: Сјеверна Кореја',
    '🇰🇷' => 'застава: Јужна Кореја',
    '🇰🇼' => 'застава: Кувајт',
    '🇰🇾' => 'застава: Кајманска Острва',
    '🇰🇿' => 'застава: Казахстан',
    '🇱🇦' => 'застава: Лаос',
    '🇱🇧' => 'застава: Либан',
    '🇱🇨' => 'застава: Света Луција',
    '🇱🇮' => 'застава: Лихтенштајн',
    '🇱🇰' => 'застава: Шри Ланка',
    '🇱🇷' => 'застава: Либерија',
    '🇱🇸' => 'застава: Лесото',
    '🇱🇹' => 'застава: Литванија',
    '🇱🇺' => 'застава: Луксембург',
    '🇱🇻' => 'застава: Летонија',
    '🇱🇾' => 'застава: Либија',
    '🇲🇦' => 'застава: Мароко',
    '🇲🇨' => 'застава: Монако',
    '🇲🇩' => 'застава: Молдавија',
    '🇲🇪' => 'застава: Црна Гора',
    '🇲🇫' => 'застава: Свети Мартин (Француска)',
    '🇲🇬' => 'застава: Мадагаскар',
    '🇲🇭' => 'застава: Маршалска Острва',
    '🇲🇰' => 'застава: Сјеверна Македонија',
    '🇲🇱' => 'застава: Мали',
    '🇲🇲' => 'застава: Мјанмар (Бурма)',
    '🇲🇳' => 'застава: Монголија',
    '🇲🇴' => 'застава: САР Макао (Кина)',
    '🇲🇵' => 'застава: Сјеверна Маријанска острва',
    '🇲🇶' => 'застава: Мартиник',
    '🇲🇷' => 'застава: Мауританија',
    '🇲🇸' => 'застава: Монсерат',
    '🇲🇹' => 'застава: Малта',
    '🇲🇺' => 'застава: Маурицијус',
    '🇲🇻' => 'застава: Малдиви',
    '🇲🇼' => 'застава: Малави',
    '🇲🇽' => 'застава: Мексико',
    '🇲🇾' => 'застава: Малезија',
    '🇲🇿' => 'застава: Мозамбик',
    '🇳🇦' => 'застава: Намибија',
    '🇳🇨' => 'застава: Нова Каледонија',
    '🇳🇪' => 'застава: Нигер',
    '🇳🇫' => 'застава: острво Норфок',
    '🇳🇬' => 'застава: Нигерија',
    '🇳🇮' => 'застава: Никарагва',
    '🇳🇱' => 'застава: Холандија',
    '🇳🇴' => 'застава: Норвешка',
    '🇳🇵' => 'застава: Непал',
    '🇳🇷' => 'застава: Науру',
    '🇳🇺' => 'застава: Нијуе',
    '🇳🇿' => 'застава: Нови Зеланд',
    '🇴🇲' => 'застава: Оман',
    '🇵🇦' => 'застава: Панама',
    '🇵🇪' => 'застава: Перу',
    '🇵🇫' => 'застава: Француска Полинезија',
    '🇵🇬' => 'застава: Папуа Нова Гвинеја',
    '🇵🇭' => 'застава: Филипини',
    '🇵🇰' => 'застава: Пакистан',
    '🇵🇱' => 'застава: Пољска',
    '🇵🇲' => 'застава: Сен Пјер и Микелон',
    '🇵🇳' => 'застава: Питкерн',
    '🇵🇷' => 'застава: Порторико',
    '🇵🇸' => 'застава: палестинске територије',
    '🇵🇹' => 'застава: Португалија',
    '🇵🇼' => 'застава: Палау',
    '🇵🇾' => 'застава: Парагвај',
    '🇶🇦' => 'застава: Катар',
    '🇷🇪' => 'застава: Реунион',
    '🇷🇴' => 'застава: Румунија',
    '🇷🇸' => 'застава: Србија',
    '🇷🇺' => 'застава: Русија',
    '🇷🇼' => 'застава: Руанда',
    '🇸🇦' => 'застава: Саудијска Арабија',
    '🇸🇧' => 'застава: Соломонска Острва',
    '🇸🇨' => 'застава: Сејшели',
    '🇸🇩' => 'застава: Судан',
    '🇸🇪' => 'застава: Шведска',
    '🇸🇬' => 'застава: Сингапур',
    '🇸🇭' => 'застава: Света Јелена',
    '🇸🇮' => 'застава: Словенија',
    '🇸🇯' => 'застава: Свалбард и Јан Мајен',
    '🇸🇰' => 'застава: Словачка',
    '🇸🇱' => 'застава: Сијера Леоне',
    '🇸🇲' => 'застава: Сан Марино',
    '🇸🇳' => 'застава: Сенегал',
    '🇸🇴' => 'застава: Сомалија',
    '🇸🇷' => 'застава: Суринам',
    '🇸🇸' => 'застава: Јужни Судан',
    '🇸🇹' => 'застава: Сао Томе и Принципе',
    '🇸🇻' => 'застава: Салвадор',
    '🇸🇽' => 'застава: Свети Мартин (Холандија)',
    '🇸🇾' => 'застава: Сирија',
    '🇸🇿' => 'застава: Свазиленд',
    '🇹🇦' => 'застава: Тристан да Куња',
    '🇹🇨' => 'застава: Острва Туркс и Каикос',
    '🇹🇩' => 'застава: Чад',
    '🇹🇫' => 'застава: Француске јужне територије',
    '🇹🇬' => 'застава: Того',
    '🇹🇭' => 'застава: Тајланд',
    '🇹🇯' => 'застава: Таџикистан',
    '🇹🇰' => 'застава: Токелау',
    '🇹🇱' => 'застава: Тимор-Лесте (Источни Тимор)',
    '🇹🇲' => 'застава: Туркменистан',
    '🇹🇳' => 'застава: Тунис',
    '🇹🇴' => 'застава: Тонга',
    '🇹🇷' => 'застава: Турска',
    '🇹🇹' => 'застава: Тринидад и Тобаго',
    '🇹🇻' => 'застава: Тувалу',
    '🇹🇼' => 'застава: Тајван',
    '🇹🇿' => 'застава: Танзанија',
    '🇺🇦' => 'застава: Украјина',
    '🇺🇬' => 'застава: Уганда',
    '🇺🇲' => 'застава: Спољна острва САД',
    '🇺🇳' => 'застава: Уједињене нације',
    '🇺🇸' => 'застава: Сједињене Државе',
    '🇺🇾' => 'застава: Уругвај',
    '🇺🇿' => 'застава: Узбекистан',
    '🇻🇦' => 'застава: Ватикан',
    '🇻🇨' => 'застава: Свети Винсент и Гренадини',
    '🇻🇪' => 'застава: Венецуела',
    '🇻🇬' => 'застава: Британска Дјевичанска острва',
    '🇻🇮' => 'застава: Америчка Дјевичанска острва',
    '🇻🇳' => 'застава: Вијетнам',
    '🇻🇺' => 'застава: Вануату',
    '🇼🇫' => 'застава: Валис и Футуна',
    '🇼🇸' => 'застава: Самоа',
    '🇽🇰' => 'застава: Косово',
    '🇾🇪' => 'застава: Јемен',
    '🇾🇹' => 'застава: Мајот',
    '🇿🇦' => 'застава: Јужноафричка Република',
    '🇿🇲' => 'застава: Замбија',
    '🇿🇼' => 'застава: Зимбабве',
    '🔟' => 'тастер: 10',
    '🏻' => 'свијетла кожа',
    '🏼' => 'средње свијетла кожа',
    '🏽' => 'ни свијетла ни тамна кожа',
    '🏾' => 'средње тамна кожа',
    '🏿' => 'тамна кожа',
    '😀' => 'лице са широким осмијехом',
    '😃' => 'лице са одушевљеним осмијехом',
    '😄' => 'лице које се слатко смије',
    '😁' => 'лице са кезом',
    '😆' => 'лице са злочестим осмијехом',
    '😅' => 'лице са нервозним осмијехом',
    '🤣' => 'ваљање од смијеха',
    '😂' => 'лице са сузама радосницама',
    '🙂' => 'благо насмијано лице',
    '🙃' => 'лице окренуто наопако',
    '🫠' => 'лице се топи',
    '😉' => 'лице које намигује',
    '😊' => 'насмијано лице са насмијаним очима',
    '😇' => 'насмијано лице са ореолом',
    '🥰' => 'смајли са срцима',
    '😍' => 'насмијано лице са очима у облику срца',
    '🤩' => 'под срећном звијездом',
    '😘' => 'лице које шаље пољубац',
    '😗' => 'лице које љуби',
    '☺' => 'насмијано лице',
    '😚' => 'лице које љуби са затвореним очима',
    '😙' => 'лице које љуби са насмијаним очима',
    '🥲' => 'насмијано лице са сузом',
    '😋' => 'лице које ужива у укусној храни',
    '😛' => 'лице које се плази',
    '😜' => 'лице које се плази и намигује',
    '🤪' => 'лудачко лице',
    '😝' => 'лице које се плази са затвореним очима',
    '🤑' => 'похлепно лице',
    '🤗' => 'лице које грли',
    '🤭' => 'лице са руком преко уста',
    '🫢' => 'лице отворених очију са руком преко уста',
    '🫣' => 'гледање кроз прсте',
    '🤫' => 'ућуткујуће лице',
    '🤔' => 'лице које размишља',
    '🫡' => 'лице салутира',
    '🤐' => 'лице са запечаћеним устима',
    '🤨' => 'лице са уздигнутом обрвом',
    '😐' => 'лице са неутралним изразом',
    '😑' => 'безизражајно лице',
    '😶' => 'лице без уста',
    '🫥' => 'лице испрекиданом линијом',
    '😏' => 'лице које се злобно смјешка',
    '😒' => 'сморено лице',
    '🙄' => 'лице које колута очима',
    '😬' => 'лице са гримасом',
    '🤥' => 'лажљивац',
    '🫨' => 'дрхтеће лице',
    '😌' => 'спокојно лице',
    '😔' => 'замишљено лице',
    '😪' => 'поспано лице',
    '🤤' => 'лице којем иде вода на уста',
    '😴' => 'лице које спава',
    '🫩' => 'лице са подочњацима',
    '😷' => 'лице са медицинском маском',
    '🤒' => 'лице са топломјером',
    '🤕' => 'лице са завојем на глави',
    '🤢' => 'лице којем је мука',
    '🤮' => 'лице повраћа',
    '🤧' => 'лице које кија',
    '🥵' => 'вруће лице',
    '🥶' => 'хладно лице',
    '🥴' => 'погубљено лице',
    '😵' => 'лице са вртоглавицом',
    '🤯' => 'глава експлодира',
    '🤠' => 'лице каубоја',
    '🥳' => 'лице на журци',
    '🥸' => 'прерушено лице',
    '😎' => 'насмијано лице са наочарима за сунце',
    '🤓' => 'штреберско лице',
    '🧐' => 'лице са моноклом',
    '😕' => 'збуњено лице',
    '🫤' => 'лице са дијагоналним устима',
    '😟' => 'забринуто лице',
    '🙁' => 'лице које се благо мршти',
    '☹' => 'намрштено лице',
    '😮' => 'лице са отвореним устима',
    '😯' => 'изненађено лице',
    '😲' => 'запањено лице',
    '😳' => 'зајапурено лице',
    '🫪' => 'искривљено лице',
    '🥺' => 'молећиво лице',
    '🥹' => 'лице задржава сузе',
    '😦' => 'зачуђено лице',
    '😧' => 'избезумљено лице',
    '😨' => 'уплашено лице',
    '😰' => 'лице са отвореним устима, обливено хладним знојем',
    '😥' => 'разочарано лице коме је лакнуло',
    '😢' => 'лице које плаче',
    '😭' => 'лице које рида',
    '😱' => 'лице које вришти од страха',
    '😖' => 'лице у недоумици',
    '😣' => 'измучено лице',
    '😞' => 'разочарано лице',
    '😓' => 'лице обливено хладним знојем',
    '😩' => 'преморено лице',
    '😫' => 'уморно лице',
    '🥱' => 'лице зијева',
    '😤' => 'лице коме из носа излази пара',
    '😡' => 'надурено лице',
    '😠' => 'љутито лице',
    '🤬' => 'лице са симболима на уснама',
    '😈' => 'насмијано лице са роговима',
    '👿' => 'ђаволчић',
    '💀' => 'лобања',
    '☠' => 'лобања са укрштеним костима',
    '💩' => 'гомила каке',
    '🤡' => 'лице кловна',
    '👹' => 'чудовиште',
    '👺' => 'гоблин',
    '👻' => 'дух',
    '👽' => 'ванземаљац',
    '👾' => 'ванземаљско чудовиште',
    '🤖' => 'роботско лице',
    '😺' => 'насмијана мачка са отвореним устима',
    '😸' => 'мачка са широким осмијехом и насмијаним очима',
    '😹' => 'лице мачке са сузама радосницама',
    '😻' => 'насмијана мачка са очима у облику срца',
    '😼' => 'мачка са киселим осмијехом',
    '😽' => 'мачка која љуби са затвореним очима',
    '🙀' => 'уплашена мачка',
    '😿' => 'уплакана мачка',
    '😾' => 'надурена мачка',
    '🙈' => 'не види зло',
    '🙉' => 'не чује зло',
    '🙊' => 'не говори зло',
    '💌' => 'љубавно писмо',
    '💘' => 'срце прободено стријелом',
    '💝' => 'срце са машницом',
    '💖' => 'блиставо срце',
    '💗' => 'срце које расте',
    '💓' => 'срце које куца',
    '💞' => 'срца која се окрећу',
    '💕' => 'два срца',
    '💟' => 'украс са срцем',
    '❣' => 'украсни узвичник у облику великог срца',
    '💔' => 'сломљено срце',
    '❤' => 'црвено срце',
    '🩷' => 'розе срце',
    '🧡' => 'наранџасто срце',
    '💛' => 'жуто срце',
    '💚' => 'зелено срце',
    '💙' => 'плаво срце',
    '🩵' => 'свијетлоплаво срце',
    '💜' => 'љубичасто срце',
    '🤎' => 'браон срце',
    '🖤' => 'црно срце',
    '🩶' => 'сиво срце',
    '🤍' => 'бијело срце',
    '💋' => 'отисак пољупца',
    '💯' => 'сто поена',
    '💢' => 'симбол љутње',
    '🫯' => 'облак туче',
    '💥' => 'судар',
    '💫' => 'вртоглавица',
    '💦' => 'капљице зноја',
    '💨' => 'бјежање',
    '🕳' => 'рупа',
    '💬' => 'облачић за говор',
    '🗨' => 'облачић за говор усмјерен налијево',
    '🗯' => 'облачић за љутити говор усмјерен десно',
    '💭' => 'облачић за мисли',
    '💤' => 'спавање',
    '👋' => 'рука која маше',
    '🤚' => 'подигнут длан',
    '🖐' => 'шака са раширеним прстима',
    '✋' => 'подигнута рука',
    '🖖' => 'вулкански поздрав',
    '🫱' => 'рука окренута надесно',
    '🫲' => 'рука окренута налево',
    '🫳' => 'длан окренут надоле',
    '🫴' => 'длан окренут нагоре',
    '🫷' => 'рука гура улијево',
    '🫸' => 'рука гура удесно',
    '👌' => 'знак руком „у реду“',
    '🤌' => 'скупљени прсти',
    '🤏' => 'рука штипа',
    '✌' => 'знак побједе',
    '🤞' => 'прекрштени прсти',
    '🫰' => 'рука са прекрштеним палцем и кажипрстом',
    '🤟' => 'покрет волим те',
    '🤘' => 'знак рогова',
    '🤙' => 'знак руком за телефон',
    '👈' => 'кажипрст који показује улијево',
    '👉' => 'кажипрст који показује удесно',
    '👆' => 'кажипрст који показује нагоре отпозади',
    '🖕' => 'средњи прст',
    '👇' => 'кажипрст који показује надоље отпозади',
    '☝' => 'кажипрст који показује нагоре',
    '🫵' => 'кажипрст који показује према гледаоцу',
    '👍' => 'палац нагоре',
    '👎' => 'палац надоље',
    '✊' => 'песница',
    '👊' => 'усмјерена песница',
    '🤛' => 'песница улијево',
    '🤜' => 'песница удесно',
    '👏' => 'руке које тапшу',
    '🙌' => 'подигнуте руке',
    '🫶' => 'руке које праве срце',
    '👐' => 'расклопљене шаке',
    '🤲' => 'дланови нагоре заједно',
    '🤝' => 'руковање',
    '🙏' => 'спојени дланови',
    '✍' => 'рука која пише',
    '💅' => 'лак за нокте',
    '🤳' => 'селфи',
    '💪' => 'стегнути бицепс',
    '🦾' => 'механичка рука',
    '🦿' => 'механичка нога',
    '🦵' => 'нога',
    '🦶' => 'стопало',
    '👂' => 'уво',
    '🦻' => 'уво са слушним апаратом',
    '👃' => 'нос',
    '🧠' => 'мозак',
    '🫀' => 'анатомско срце',
    '🫁' => 'плућа',
    '🦷' => 'зуб',
    '🦴' => 'кост',
    '👀' => 'очи',
    '👁' => 'око',
    '👅' => 'језик',
    '👄' => 'уста',
    '🫦' => 'угриз усне',
    '👶' => 'беба',
    '🧒' => 'дијете',
    '👦' => 'дјечак',
    '👧' => 'дјевојчица',
    '🧑' => 'одрасла особа',
    '👱' => 'особа са плавом косом',
    '👨' => 'мушкарац',
    '🧔' => 'особа са брадом',
    '👩' => 'жена',
    '🧓' => 'старија одрасла особа',
    '👴' => 'старац',
    '👵' => 'старица',
    '🙍' => 'намрштена особа',
    '🙎' => 'надурена особа',
    '🙅' => 'особа која показује „не“',
    '🙆' => 'особа која показује „у реду“',
    '💁' => 'особа која даје информације',
    '🙋' => 'срећна особа са подигнутом руком',
    '🧏' => 'глува особа',
    '🙇' => 'особа која се клања',
    '🤦' => 'шака о чело',
    '🤷' => 'слијегање раменима',
    '👮' => 'представник полиције',
    '🕵' => 'инспектор',
    '💂' => 'чувар',
    '🥷' => 'нинџа',
    '👷' => 'грађевински радник',
    '🫅' => 'особа са круном',
    '🤴' => 'принц',
    '👸' => 'принцеза',
    '👳' => 'особа са турбаном',
    '👲' => 'човјек са кинеском капом',
    '🧕' => 'жена са марамом на глави',
    '🤵' => 'човјек у смокингу',
    '👰' => 'невјеста са велом',
    '🤰' => 'трудница',
    '🫃' => 'трудни мушкарац',
    '🫄' => 'трудна особа',
    '🤱' => 'дојење',
    '👼' => 'беба анђео',
    '🎅' => 'Дјед Мраз',
    '🤶' => 'бака Мраз',
    '🦸' => 'суперхерој',
    '🦹' => 'негативац',
    '🧙' => 'маг',
    '🧚' => 'вила',
    '🧛' => 'вампир',
    '🧜' => 'особа из мора',
    '🧝' => 'виловњак',
    '🧞' => 'добри дух',
    '🧟' => 'зомби',
    '🧌' => 'трол',
    '🫈' => 'длакаво створење',
    '💆' => 'масажа лица',
    '💇' => 'шишање',
    '🚶' => 'пјешак',
    '🧍' => 'особа стоји',
    '🧎' => 'особа клечи',
    '🏃' => 'тркач',
    '💃' => 'плесачица',
    '🕺' => 'плесач',
    '🕴' => 'мушкарац у пословном одијелу који лебди',
    '👯' => 'особе у проводу',
    '🧖' => 'особа у парном купатилу',
    '🧗' => 'пењање',
    '🤺' => 'мачевалац',
    '🏇' => 'трке коња',
    '⛷' => 'скијаш',
    '🏂' => 'возач сноуборда',
    '🏌' => 'особа игра голф',
    '🏄' => 'особа сурфује',
    '🚣' => 'чамац на весла',
    '🏊' => 'особа плива',
    '⛹' => 'особа са лоптом',
    '🏋' => 'особа диже тегове',
    '🚴' => 'особа на бициклу',
    '🚵' => 'особа на брдском бициклу',
    '🤸' => 'гимнастичарска звезда',
    '🤼' => 'рвање',
    '🤽' => 'ватерполо',
    '🤾' => 'рукомет',
    '🤹' => 'особа жонглира',
    '🧘' => 'лотос поза',
    '🛀' => 'особа која се купа',
    '🛌' => 'особа у кревету',
    '👭' => 'жене се држе за руке',
    '👫' => 'жена и мушкарац се држе за руке',
    '👬' => 'мушкарци се држе за руке',
    '💏' => 'пољубац',
    '💑' => 'пар са срцем',
    '🗣' => 'глава која говори',
    '👤' => 'силуета човјека',
    '👥' => 'силуете људи',
    '🫂' => 'људи се грле',
    '👪' => 'породица',
    '👣' => 'отисци стопала',
    '🫆' => 'отисак прста',
    '🦰' => 'црвена коса',
    '🦱' => 'коврџава коса',
    '🦳' => 'сиједа коса',
    '🦲' => 'ћелав',
    '🐵' => 'лице мајмуна',
    '🐒' => 'мајмун',
    '🦍' => 'горила',
    '🦧' => 'орангутан',
    '🐶' => 'лице пса',
    '🐕' => 'пас',
    '🦮' => 'пас водич',
    '🐩' => 'пудла',
    '🐺' => 'вук',
    '🦊' => 'лисица',
    '🦝' => 'ракун',
    '🐱' => 'лице мачке',
    '🐈' => 'мачка',
    '🦁' => 'лав',
    '🐯' => 'лице тигра',
    '🐅' => 'тигар',
    '🐆' => 'леопард',
    '🐴' => 'лице коња',
    '🫎' => 'лос',
    '🫏' => 'магарац',
    '🐎' => 'коњ',
    '🦄' => 'лице једнорога',
    '🦓' => 'зебра',
    '🦌' => 'јелен',
    '🦬' => 'бизон',
    '🐮' => 'лице краве',
    '🐂' => 'во',
    '🐃' => 'водени биво',
    '🐄' => 'крава',
    '🐷' => 'лице свиње',
    '🐖' => 'свиња',
    '🐗' => 'вепар',
    '🐽' => 'свињска њушка',
    '🐏' => 'ован',
    '🐑' => 'овца',
    '🐐' => 'коза',
    '🐪' => 'камила',
    '🐫' => 'двогрба камила',
    '🦙' => 'лама',
    '🦒' => 'жирафа',
    '🐘' => 'слон',
    '🦣' => 'мамут',
    '🦏' => 'носорог',
    '🦛' => 'нилски коњ',
    '🐭' => 'лице миша',
    '🐁' => 'миш',
    '🐀' => 'пацов',
    '🐹' => 'хрчак',
    '🐰' => 'лице зеца',
    '🐇' => 'зец',
    '🐿' => 'вјеверица',
    '🦫' => 'дабар',
    '🦔' => 'јеж',
    '🦇' => 'шишмиш',
    '🐻' => 'медвјед',
    '🐨' => 'коала',
    '🐼' => 'панда',
    '🦥' => 'љењивац',
    '🦦' => 'видра',
    '🦨' => 'твор',
    '🦘' => 'кенгур',
    '🦡' => 'јазавац',
    '🐾' => 'отисци шапа',
    '🦃' => 'ћурка',
    '🐔' => 'кокошка',
    '🐓' => 'пијевац',
    '🐣' => 'пиле у јајету',
    '🐤' => 'пиле',
    '🐥' => 'пиле сприједа',
    '🐦' => 'птица',
    '🐧' => 'пингвин',
    '🕊' => 'голубица',
    '🦅' => 'орао',
    '🦆' => 'патка',
    '🦢' => 'лабуд',
    '🦉' => 'сова',
    '🦤' => 'додо',
    '🪶' => 'перо',
    '🦩' => 'фламинго',
    '🦚' => 'паун',
    '🦜' => 'папагај',
    '🪽' => 'крило',
    '🪿' => 'гуска',
    '🐸' => 'жаба',
    '🐊' => 'крокодил',
    '🐢' => 'корњача',
    '🦎' => 'гуштер',
    '🐍' => 'змија',
    '🐲' => 'лице змаја',
    '🐉' => 'змај',
    '🦕' => 'сауропод',
    '🦖' => 'тираносаурус рекс',
    '🐳' => 'кит који прска',
    '🐋' => 'кит',
    '🐬' => 'делфин',
    '🫍' => 'орка',
    '🦭' => 'фока',
    '🐟' => 'риба',
    '🐠' => 'тропска риба',
    '🐡' => 'надувана риба',
    '🦈' => 'ајкула',
    '🐙' => 'октопод',
    '🐚' => 'спирална шкољка',
    '🪸' => 'корал',
    '🪼' => 'медуза',
    '🦀' => 'краба',
    '🦞' => 'јастог',
    '🦐' => 'рачић',
    '🦑' => 'хоботница',
    '🦪' => 'острига',
    '🐌' => 'пуж',
    '🦋' => 'лептир',
    '🐛' => 'гусјеница',
    '🐜' => 'мрав',
    '🐝' => 'пчела',
    '🪲' => 'буба',
    '🐞' => 'бубамара',
    '🦗' => 'зрикавац',
    '🪳' => 'бубашваба',
    '🕷' => 'паук',
    '🕸' => 'паукова мрежа',
    '🦂' => 'шкорпион',
    '🦟' => 'комарац',
    '🪰' => 'мува',
    '🪱' => 'црв',
    '🦠' => 'микроб',
    '💐' => 'букет',
    '🌸' => 'цвијет трешње',
    '💮' => 'бијели цвијет',
    '🪷' => 'лотус',
    '🏵' => 'розета',
    '🌹' => 'ружа',
    '🥀' => 'увели цвијет',
    '🌺' => 'хибискус',
    '🌻' => 'сунцокрет',
    '🌼' => 'цвијет',
    '🌷' => 'лала',
    '🪻' => 'зумбул',
    '🌱' => 'младица',
    '🪴' => 'биљка у саксији',
    '🌲' => 'четинар',
    '🌳' => 'листопадно дрво',
    '🌴' => 'палма',
    '🌵' => 'кактус',
    '🌾' => 'сноп риже',
    '🌿' => 'биљка',
    '☘' => 'дјетелина',
    '🍀' => 'дјетелина са четири листа',
    '🍁' => 'јаворов лист',
    '🍂' => 'опали лист',
    '🍃' => 'лист који лепрша на вјетру',
    '🪹' => 'празно гнијездо',
    '🪺' => 'гнијездо с јајима',
    '🍄' => 'печурка',
    '🪾' => 'дрво без лишћа',
    '🍇' => 'грожђе',
    '🍈' => 'диња',
    '🍉' => 'лубеница',
    '🍊' => 'мандарина',
    '🍋' => 'лимун',
    '🍌' => 'банана',
    '🍍' => 'ананас',
    '🥭' => 'манго',
    '🍎' => 'црвена јабука',
    '🍏' => 'зелена јабука',
    '🍐' => 'крушка',
    '🍑' => 'бресква',
    '🍒' => 'трешње',
    '🍓' => 'јагода',
    '🫐' => 'боровнице',
    '🥝' => 'киви',
    '🍅' => 'парадајз',
    '🫒' => 'маслина',
    '🥥' => 'кокос',
    '🥑' => 'авокадо',
    '🍆' => 'пaтлиџaн',
    '🥔' => 'кромпир',
    '🥕' => 'мрква',
    '🌽' => 'клип кукуруза',
    '🌶' => 'љута папричица',
    '🫑' => 'бабура',
    '🥒' => 'краставац',
    '🥬' => 'лиснато зелено поврће',
    '🥦' => 'броколи',
    '🧄' => 'бијели лук',
    '🧅' => 'црни лук',
    '🥜' => 'кикирики',
    '🫘' => 'пасуљ',
    '🌰' => 'кестен',
    '🫚' => 'коријен ђумбира',
    '🫛' => 'махуна грашка',
    '🫜' => 'корјенасто поврће',
    '🍞' => 'хљеб',
    '🥐' => 'кроасан',
    '🥖' => 'багет',
    '🫓' => 'пљоснат хљеб',
    '🥨' => 'переца',
    '🥯' => 'бејгл',
    '🥞' => 'палачинке',
    '🧇' => 'вафл',
    '🧀' => 'кришка сира',
    '🍖' => 'месо са коском',
    '🍗' => 'батак',
    '🥩' => 'парче меса',
    '🥓' => 'сланина',
    '🍔' => 'хамбургер',
    '🍟' => 'помфрит',
    '🍕' => 'пица',
    '🌭' => 'хот-дог',
    '🥪' => 'сендвич',
    '🌮' => 'тако',
    '🌯' => 'бурито',
    '🫔' => 'тамале',
    '🥙' => 'гирос',
    '🧆' => 'фалафел',
    '🥚' => 'јаје',
    '🍳' => 'јаје у тигању',
    '🥘' => 'тигањ хране',
    '🍲' => 'чинија хране',
    '🫕' => 'фонду',
    '🥣' => 'чинија са кашиком',
    '🥗' => 'зелена салата',
    '🍿' => 'кокице',
    '🧈' => 'путер',
    '🧂' => 'со',
    '🥫' => 'конзервирана храна',
    '🍱' => 'кутија са ручком',
    '🍘' => 'крекер од риже',
    '🍙' => 'куглица од риже',
    '🍚' => 'кувана рижа',
    '🍛' => 'рижа са каријем',
    '🍜' => 'врућа чинија',
    '🍝' => 'шпагете',
    '🍠' => 'печени слатки кромпир',
    '🍢' => 'оден',
    '🍣' => 'суши',
    '🍤' => 'пржени шкампи',
    '🍥' => 'рибља пљескавица са спиралом',
    '🥮' => 'мјесечев колач',
    '🍡' => 'данго',
    '🥟' => 'кнедла',
    '🥠' => 'колачић судбине',
    '🥡' => 'кутија за храну',
    '🍦' => 'сладолед у корнету',
    '🍧' => 'сорбе',
    '🍨' => 'сладолед',
    '🍩' => 'крофна',
    '🍪' => 'колачић',
    '🎂' => 'рођенданска торта',
    '🍰' => 'парче торте',
    '🧁' => 'капкејк',
    '🥧' => 'пита',
    '🍫' => 'чоколадица',
    '🍬' => 'бомбона',
    '🍭' => 'лизалица',
    '🍮' => 'кремпита',
    '🍯' => 'ћуп са медом',
    '🍼' => 'флашица за бебе',
    '🥛' => 'чаша млијека',
    '☕' => 'топли напитак',
    '🫖' => 'чајник',
    '🍵' => 'шољица без дршке',
    '🍶' => 'саке',
    '🍾' => 'боца из које излијеће чеп',
    '🍷' => 'чаша вина',
    '🍸' => 'коктел',
    '🍹' => 'тропско пиће',
    '🍺' => 'кригла пива',
    '🍻' => 'кригле пива које се куцају',
    '🥂' => 'чаше наздрављају',
    '🥃' => 'чаша за жестину',
    '🫗' => 'сипање течности',
    '🥤' => 'чаша са сламчицом',
    '🧋' => 'чај са бобицама',
    '🧃' => 'пиће у тетрапаку',
    '🧉' => 'мате',
    '🧊' => 'коцка леда',
    '🥢' => 'штапићи',
    '🍽' => 'виљушка и нож са тањиром',
    '🍴' => 'виљушка и нож',
    '🥄' => 'кашика',
    '🔪' => 'кухињски нож',
    '🫙' => 'тегла',
    '🏺' => 'амфора',
    '🌍' => 'глобус са Европом и Африком',
    '🌎' => 'глобус са Америком',
    '🌏' => 'глобус са Азијом и Аустралијом',
    '🌐' => 'глобус са меридијанима',
    '🗺' => 'мапа свијета',
    '🗾' => 'мапа Јапана',
    '🧭' => 'компас',
    '🏔' => 'сњежни врх планине',
    '⛰' => 'планина',
    '🛘' => 'одрон',
    '🌋' => 'вулкан',
    '🗻' => 'планина фуџи',
    '🏕' => 'камповање',
    '🏖' => 'плажа са сунцобраном',
    '🏜' => 'пустиња',
    '🏝' => 'пусто острво',
    '🏞' => 'национални парк',
    '🏟' => 'стадион',
    '🏛' => 'античка грађевина',
    '🏗' => 'градилиште',
    '🧱' => 'цигла',
    '🪨' => 'камен',
    '🪵' => 'дрво',
    '🛖' => 'колиба',
    '🏘' => 'куће',
    '🏚' => 'запуштена кућа',
    '🏠' => 'кућа',
    '🏡' => 'кућа са баштом',
    '🏢' => 'пословна зграда',
    '🏣' => 'јапанска пошта',
    '🏤' => 'пошта',
    '🏥' => 'болница',
    '🏦' => 'банка',
    '🏨' => 'хотел',
    '🏩' => 'љубавни хотел',
    '🏪' => 'продавница мјешовите робе',
    '🏫' => 'школа',
    '🏬' => 'робна кућа',
    '🏭' => 'фабрика',
    '🏯' => 'јапански дворац',
    '🏰' => 'дворац',
    '💒' => 'вјенчање',
    '🗼' => 'токијски торањ',
    '🗽' => 'кип слободе',
    '⛪' => 'црква',
    '🕌' => 'џамија',
    '🛕' => 'хинду храм',
    '🕍' => 'синагога',
    '⛩' => 'шинтоистички храм',
    '🕋' => 'каба',
    '⛲' => 'фонтана',
    '⛺' => 'шатор',
    '🌁' => 'магловито',
    '🌃' => 'звјездана ноћ',
    '🏙' => 'градски пејзаж',
    '🌄' => 'излазак сунца изнад планина',
    '🌅' => 'излазак сунца',
    '🌆' => 'град у сумрак',
    '🌇' => 'залазак сунца',
    '🌉' => 'мост ноћу',
    '♨' => 'термални извори',
    '🎠' => 'коњ са вртешке',
    '🛝' => 'тобоган',
    '🎡' => 'панорамска вртешка',
    '🎢' => 'ролеркостер',
    '💈' => 'знак за берберницу',
    '🎪' => 'циркуски шатор',
    '🚂' => 'локомотива',
    '🚃' => 'вагон',
    '🚄' => 'брзи воз',
    '🚅' => 'брзи воз са заобљеним врхом',
    '🚆' => 'воз',
    '🚇' => 'метро',
    '🚈' => 'градска жељезница',
    '🚉' => 'станица',
    '🚊' => 'трамвај',
    '🚝' => 'монорејл',
    '🚞' => 'планинска жељезница',
    '🚋' => 'вагон трамваја',
    '🚌' => 'аутобус',
    '🚍' => 'аутобус сприједа',
    '🚎' => 'тролејбус',
    '🚐' => 'минибус',
    '🚑' => 'хитна помоћ',
    '🚒' => 'ватрогасни камион',
    '🚓' => 'полицијски аутомобил',
    '🚔' => 'полицијски аутомобил сприједа',
    '🚕' => 'такси',
    '🚖' => 'такси спреда',
    '🚗' => 'аутомобил',
    '🚘' => 'аутомобил сприједа',
    '🚙' => 'камп-возило',
    '🛻' => 'пикап возило',
    '🚚' => 'теретни камион',
    '🚛' => 'камион са приколицом',
    '🚜' => 'трактор',
    '🏎' => 'тркачки аутомобил',
    '🏍' => 'мотоцикл',
    '🛵' => 'скутер',
    '🦽' => 'колица на ручни погон',
    '🦼' => 'моторна колица',
    '🛺' => 'ауто-рикша',
    '🚲' => 'бицикл',
    '🛴' => 'тротинет',
    '🛹' => 'скејтборд',
    '🛼' => 'ролшуа',
    '🚏' => 'аутобуска станица',
    '🛣' => 'ауто-пут',
    '🛤' => 'жељезничка пруга',
    '🛢' => 'буре нафте',
    '⛽' => 'пумпа за гориво',
    '🛞' => 'точак',
    '🚨' => 'полицијска ротација',
    '🚥' => 'хоризонтални семафор',
    '🚦' => 'вертикални семафор',
    '🛑' => 'знак стоп',
    '🚧' => 'радови у току',
    '⚓' => 'сидро',
    '🛟' => 'појас за спасавање',
    '⛵' => 'једрењак',
    '🛶' => 'кану',
    '🚤' => 'глисер',
    '🛳' => 'путнички брод',
    '⛴' => 'трајект',
    '🛥' => 'јахта',
    '🚢' => 'брод',
    '✈' => 'авион',
    '🛩' => 'мали авион',
    '🛫' => 'полијетање авиона',
    '🛬' => 'слијетање авиона',
    '🪂' => 'падобран',
    '💺' => 'сједиште',
    '🚁' => 'хеликоптер',
    '🚟' => 'висећа жељезница',
    '🚠' => 'планинска жичара',
    '🚡' => 'висећи трамвај',
    '🛰' => 'сателит',
    '🚀' => 'ракета',
    '🛸' => 'летећи тањир',
    '🛎' => 'звоно на рецепцији',
    '🧳' => 'пртљаг',
    '⌛' => 'пјешчани сат',
    '⏳' => 'пјешчани сат са пијеском који тече',
    '⌚' => 'сат',
    '⏰' => 'будилник',
    '⏱' => 'штоперица',
    '⏲' => 'тајмер',
    '🕰' => 'стони сат',
    '🕛' => 'дванаест сати',
    '🕧' => 'пола један',
    '🕐' => 'један сат',
    '🕜' => 'пола два',
    '🕑' => 'два сата',
    '🕝' => 'пола три',
    '🕒' => 'три сата',
    '🕞' => 'пола четири',
    '🕓' => 'четири сата',
    '🕟' => 'пола пет',
    '🕔' => 'пет сати',
    '🕠' => 'пола шест',
    '🕕' => 'шест сати',
    '🕡' => 'пола седам',
    '🕖' => 'седам сати',
    '🕢' => 'пола осам',
    '🕗' => 'осам сати',
    '🕣' => 'пола девет',
    '🕘' => 'девет сати',
    '🕤' => 'пола десет',
    '🕙' => 'десет сати',
    '🕥' => 'пола једанаест',
    '🕚' => 'једанаест сати',
    '🕦' => 'пола дванаест',
    '🌑' => 'млад мјесец',
    '🌒' => 'мјесечев срп у порасту',
    '🌓' => 'мјесец у првој четврти',
    '🌔' => 'скоро па пун мјесец',
    '🌕' => 'пун мјесец',
    '🌖' => 'мјесец послије пуног мјесеца',
    '🌗' => 'мјесец у посљедњој четврти',
    '🌘' => 'мјесечев срп у опадању',
    '🌙' => 'мјесечев срп',
    '🌚' => 'млад мјесец са лицем',
    '🌛' => 'мјесец у првој четврти са лицем',
    '🌜' => 'мјесец у посљедњој четврти са лицем',
    '🌡' => 'термометар',
    '☀' => 'сунце',
    '🌝' => 'пун мјесец са лицем',
    '🌞' => 'сунце са лицем',
    '🪐' => 'планета са прстеном',
    '⭐' => 'звијезда',
    '🌟' => 'звијезда која свијетли',
    '🌠' => 'звијезда падалица',
    '🌌' => 'млијечни пут',
    '☁' => 'облак',
    '⛅' => 'сунце иза облака',
    '⛈' => 'облак са муњом и кишом',
    '🌤' => 'сунце иза малог облака',
    '🌥' => 'сунце иза великог облака',
    '🌦' => 'сунце иза кишног облака',
    '🌧' => 'облак са кишом',
    '🌨' => 'облак са снијегом',
    '🌩' => 'облак са муњом',
    '🌪' => 'торнадо',
    '🌫' => 'магла',
    '🌬' => 'лице вјетра',
    '🌀' => 'циклон',
    '🌈' => 'дуга',
    '🌂' => 'затворени кишобран',
    '☂' => 'кишобран',
    '☔' => 'кишобран са капима кише',
    '⛱' => 'сунцобран на земљи',
    '⚡' => 'висок напон',
    '❄' => 'пахуља',
    '☃' => 'сњешко бијелић',
    '⛄' => 'сњешко бијелић без снијега',
    '☄' => 'комета',
    '🔥' => 'ватра',
    '💧' => 'капљица',
    '🌊' => 'талас',
    '🎃' => 'свјетиљка од бундеве',
    '🎄' => 'божићна јелка',
    '🎆' => 'ватромет',
    '🎇' => 'прскалица',
    '🧨' => 'петарда',
    '✨' => 'искре',
    '🎈' => 'балон',
    '🎉' => 'конфете у туби',
    '🎊' => 'конфете у лопти',
    '🎋' => 'дрво танабата',
    '🎍' => 'декорација боровима',
    '🎎' => 'јапанске лутке',
    '🎏' => 'вјетроказ у облику шарана',
    '🎐' => 'еолска звона',
    '🎑' => 'церемонија у част мјесеца',
    '🧧' => 'црвена коверта',
    '🎀' => 'машница',
    '🎁' => 'упакован поклон',
    '🎗' => 'спомен-трака',
    '🎟' => 'улазнице',
    '🎫' => 'карта',
    '🎖' => 'орден',
    '🏆' => 'пехар',
    '🏅' => 'спортска медаља',
    '🥇' => 'златна медаља',
    '🥈' => 'сребрна медаља',
    '🥉' => 'бронзана медаља',
    '⚽' => 'фудбалска лопта',
    '⚾' => 'лоптица за бејзбол',
    '🥎' => 'лопта за софтбол',
    '🏀' => 'кошаркашка лопта',
    '🏐' => 'лопта за одбојку',
    '🏈' => 'лопта за амерички фудбал',
    '🏉' => 'лопта за рагби',
    '🎾' => 'тенис',
    '🥏' => 'фризби',
    '🎳' => 'куглање',
    '🏏' => 'крикет',
    '🏑' => 'хокеј на трави',
    '🏒' => 'штап и пак за хокеј',
    '🥍' => 'лакрос',
    '🏓' => 'стони тенис',
    '🏸' => 'бадминтон',
    '🥊' => 'боксерска рукавица',
    '🥋' => 'борилачки кимоно',
    '🥅' => 'гол',
    '⛳' => 'заставица у рупи',
    '⛸' => 'клизаљка',
    '🎣' => 'штап за пецање',
    '🤿' => 'маска за роњење',
    '🎽' => 'мајица за трчање',
    '🎿' => 'скије',
    '🛷' => 'санке',
    '🥌' => 'камен за карлинг',
    '🎯' => 'погодак у центар',
    '🪀' => 'јојо',
    '🪁' => 'змај на вјетар',
    '🔫' => 'водени пиштољ',
    '🎱' => 'билијар',
    '🔮' => 'кристална кугла',
    '🪄' => 'чаробни штапић',
    '🎮' => 'видео игра',
    '🕹' => 'џојстик',
    '🎰' => 'слот-машина',
    '🎲' => 'коцкица за игру',
    '🧩' => 'дио слагалице',
    '🧸' => 'медвједић',
    '🪅' => 'пињата',
    '🪩' => 'диско кугла',
    '🪆' => 'лутка у лутки',
    '♠' => 'пик',
    '♥' => 'херц',
    '♦' => 'каро',
    '♣' => 'треф',
    '♟' => 'шаховски пјешак',
    '🃏' => 'џокер',
    '🀄' => 'црвени змај из маџонга',
    '🎴' => 'карте за играње са цвијетом',
    '🎭' => 'сценска умјетност',
    '🖼' => 'рам са сликом',
    '🎨' => 'сликарска палета',
    '🧵' => 'конац',
    '🪡' => 'игла за шивење',
    '🧶' => 'предиво',
    '🪢' => 'чвор',
    '👓' => 'наочари',
    '🕶' => 'наочари за сунце',
    '🥽' => 'заштитне наочари',
    '🥼' => 'бијели мантил',
    '🦺' => 'прслук за спасавање',
    '👔' => 'кравата',
    '👕' => 'мајица',
    '👖' => 'фармерке',
    '🧣' => 'шал',
    '🧤' => 'рукавице',
    '🧥' => 'капут',
    '🧦' => 'чарапе',
    '👗' => 'хаљина',
    '👘' => 'кимоно',
    '🥻' => 'сари',
    '🩱' => 'једнодијелни купаћи',
    '🩲' => 'гаће',
    '🩳' => 'шорц',
    '👙' => 'бикини',
    '👚' => 'женска одјећа',
    '🪭' => 'лепеза',
    '👛' => 'ташница',
    '👜' => 'ташна',
    '👝' => 'несесер',
    '🛍' => 'торбе за куповину',
    '🎒' => 'школски ранац',
    '🩴' => 'јапанка',
    '👞' => 'мушка ципела',
    '👟' => 'патика',
    '🥾' => 'ципела за планинарење',
    '🥿' => 'равна ципела',
    '👠' => 'ципела са штиклом',
    '👡' => 'женска сандала',
    '🩰' => 'балетске патике',
    '👢' => 'женска чизма',
    '🪮' => 'чешљић',
    '👑' => 'круна',
    '👒' => 'женски шешир',
    '🎩' => 'цилиндар',
    '🎓' => 'капа за дипломце',
    '🧢' => 'качкет',
    '🪖' => 'шљем',
    '⛑' => 'кацига са бијелим крстом',
    '📿' => 'бројаница',
    '💄' => 'кармин',
    '💍' => 'прстен',
    '💎' => 'драгуљ',
    '🔇' => 'искључен звучник',
    '🔈' => 'звучник',
    '🔉' => 'укључен звучник',
    '🔊' => 'појачан звучник',
    '📢' => 'разглас',
    '📣' => 'мегафон',
    '📯' => 'поштанска труба',
    '🔔' => 'звоно',
    '🔕' => 'прецртано звоно',
    '🎼' => 'нотни запис',
    '🎵' => 'нота',
    '🎶' => 'ноте',
    '🎙' => 'студијски микрофон',
    '🎚' => 'клизач за подешавање',
    '🎛' => 'контролна дугмад',
    '🎤' => 'микрофон',
    '🎧' => 'слушалица',
    '📻' => 'радио',
    '🎷' => 'саксофон',
    '🎺' => 'труба',
    '🪊' => 'тромбон',
    '🪗' => 'хармоника',
    '🎸' => 'гитара',
    '🎹' => 'клавијатура',
    '🎻' => 'виолина',
    '🪕' => 'бенџо',
    '🥁' => 'добош',
    '🪘' => 'тимпан',
    '🪇' => 'марака',
    '🪈' => 'флаута',
    '🪉' => 'харфа',
    '📱' => 'мобилни телефон',
    '📲' => 'мобилни телефон са стрелицом',
    '☎' => 'телефон',
    '📞' => 'телефонска слушалица',
    '📟' => 'пејџер',
    '📠' => 'факс',
    '🔋' => 'батерија',
    '🪫' => 'ниски ниво батерије',
    '🔌' => 'струјни утикач',
    '💻' => 'лаптоп рачунар',
    '🖥' => 'стони рачунар',
    '🖨' => 'штампач',
    '⌨' => 'тастатура',
    '🖱' => 'рачунарски миш',
    '🖲' => 'куглица за кретање',
    '💽' => 'мини-диск',
    '💾' => 'дискета',
    '💿' => 'оптички диск',
    '📀' => 'dvd',
    '🧮' => 'рачунаљка',
    '🎥' => 'филмска камера',
    '🎞' => 'кадрови филма',
    '📽' => 'филмски пројектор',
    '🎬' => 'режисерска клапа',
    '📺' => 'телевизија',
    '📷' => 'фотоапарат',
    '📸' => 'фотоапарат са блицем',
    '📹' => 'видео камера',
    '📼' => 'видео касета',
    '🔍' => 'лупа усмјерена налијево',
    '🔎' => 'лупа усмјерена надесно',
    '🕯' => 'свијећа',
    '💡' => 'сијалица',
    '🔦' => 'батеријска лампа',
    '🏮' => 'лампион од црвеног папира',
    '🪔' => 'уљана лампа',
    '📔' => 'свеска са украсним корицама',
    '📕' => 'затворена књига',
    '📖' => 'отворена књига',
    '📗' => 'зелена књига',
    '📘' => 'плава књига',
    '📙' => 'наранџаста књига',
    '📚' => 'књиге',
    '📓' => 'свеска',
    '📒' => 'биљежница',
    '📃' => 'страница са увијеном ивицом',
    '📜' => 'свитак',
    '📄' => 'страница окренута нагоре',
    '📰' => 'новине',
    '🗞' => 'умотане новине',
    '📑' => 'странице са биљешкама',
    '🔖' => 'обиљеживач страница у књизи',
    '🏷' => 'ознака',
    '🪙' => 'новчић',
    '💰' => 'врећа новца',
    '🪎' => 'ковчег с благом',
    '💴' => 'новчаница са знаком јена',
    '💵' => 'новчаница са знаком долара',
    '💶' => 'новчаница са знаком евра',
    '💷' => 'новчаница са знаком фунте',
    '💸' => 'новац са крилима',
    '💳' => 'кредитна картица',
    '🧾' => 'признаница',
    '💹' => 'графикон пораста са знаком јена',
    '✉' => 'коверта',
    '📧' => 'имејл',
    '📨' => 'коверта која стиже',
    '📩' => 'коверта са стрелицом',
    '📤' => 'преграда са одлазном поштом',
    '📥' => 'преграда са долазном поштом',
    '📦' => 'пакет',
    '📫' => 'затворено поштанско сандуче са подигнутом заставом',
    '📪' => 'затворено поштанско сандуче са спуштеном заставом',
    '📬' => 'отворено поштанско сандуче са подигнутом заставом',
    '📭' => 'отворено поштанско сандуче са спуштеном заставом',
    '📮' => 'поштанско сандуче',
    '🗳' => 'гласачка кутија са листићем',
    '✏' => 'оловка',
    '✒' => 'црно перо',
    '🖋' => 'наливперо',
    '🖊' => 'хемијска оловка',
    '🖌' => 'сликарска четкица',
    '🖍' => 'воштана бојица',
    '📝' => 'белешка',
    '💼' => 'торба',
    '📁' => 'фасцикла',
    '📂' => 'отворена фасцикла',
    '🗂' => 'раздјелници за каталог картица',
    '📅' => 'календар',
    '📆' => 'календар са одвојивим листовима',
    '🗒' => 'биљежница са спиралом',
    '🗓' => 'календар са спиралом',
    '📇' => 'каталог картица',
    '📈' => 'графикон са узлазним трендом',
    '📉' => 'графикон са опадајућим трендом',
    '📊' => 'тракасти графикон',
    '📋' => 'клипборд',
    '📌' => 'прибадача',
    '📍' => 'чиода',
    '📎' => 'спајалица',
    '🖇' => 'повезане спајалице',
    '📏' => 'лењир',
    '📐' => 'троугаони лењир',
    '✂' => 'маказе',
    '🗃' => 'кутија са картицама',
    '🗄' => 'ормар за картотеку',
    '🗑' => 'корпа за ђубре',
    '🔒' => 'катанац',
    '🔓' => 'отворен катанац',
    '🔏' => 'катанац са наливпером',
    '🔐' => 'затворен катанац са кључем',
    '🔑' => 'кључ',
    '🗝' => 'стари кључ',
    '🔨' => 'чекић',
    '🪓' => 'сјекира',
    '⛏' => 'пијук',
    '⚒' => 'чекић и пијук',
    '🛠' => 'чекић и француски кључ',
    '🗡' => 'бодеж',
    '⚔' => 'укрштени мачеви',
    '💣' => 'бомба',
    '🪃' => 'бумеранг',
    '🏹' => 'лук и стријела',
    '🛡' => 'штит',
    '🪚' => 'тестера',
    '🔧' => 'француски кључ',
    '🪛' => 'шрафцигер',
    '🔩' => 'навртка и завртањ',
    '⚙' => 'зупчаник',
    '🗜' => 'стега',
    '⚖' => 'теразије',
    '🦯' => 'бијели штап',
    '🔗' => 'карике',
    '⛓' => 'ланци',
    '🪝' => 'кука',
    '🧰' => 'кутија за алат',
    '🧲' => 'магнет',
    '🪜' => 'мердевине',
    '🪏' => 'лопата',
    '⚗' => 'алембик',
    '🧪' => 'епрувета',
    '🧫' => 'петријева шоља',
    '🧬' => 'днк',
    '🔬' => 'микроскоп',
    '🔭' => 'телескоп',
    '📡' => 'сателитска антена',
    '💉' => 'шприц',
    '🩸' => 'кап крви',
    '💊' => 'пилула',
    '🩹' => 'фластер',
    '🩼' => 'штака',
    '🩺' => 'стетоскоп',
    '🩻' => 'рендгенски зраци',
    '🚪' => 'врата',
    '🛗' => 'лифт',
    '🪞' => 'огледало',
    '🪟' => 'прозор',
    '🛏' => 'кревет',
    '🛋' => 'кауч и лампа',
    '🪑' => 'столица',
    '🚽' => 'ве-це шоља',
    '🪠' => 'отпушивач',
    '🚿' => 'туш',
    '🛁' => 'када',
    '🪤' => 'мишоловка',
    '🪒' => 'бријач',
    '🧴' => 'боца за лосион',
    '🧷' => 'зихернадла',
    '🧹' => 'метла',
    '🧺' => 'корпа',
    '🧻' => 'ролна папира',
    '🪣' => 'кофа',
    '🧼' => 'сапун',
    '🫧' => 'мјехурићи',
    '🪥' => 'четкица за зубе',
    '🧽' => 'сунђер',
    '🧯' => 'противпожарни апарат',
    '🛒' => 'колица за куповину',
    '🚬' => 'цигарета',
    '⚰' => 'ковчег',
    '🪦' => 'надгробни споменик',
    '⚱' => 'посмртна урна',
    '🧿' => 'назар',
    '🪬' => 'хамса',
    '🗿' => 'моаи',
    '🪧' => 'плакат',
    '🪪' => 'идентификацијска карта',
    '🏧' => 'знак за банкомат',
    '🚮' => 'бацање отпада у корпу',
    '🚰' => 'вода за пиће',
    '♿' => 'симбол за инвалидска колица',
    '🚹' => 'мушки тоалет',
    '🚺' => 'женски тоалет',
    '🚻' => 'тоалет',
    '🚼' => 'симбол за бебу',
    '🚾' => 'ве-це',
    '🛂' => 'контрола пасоша',
    '🛃' => 'царина',
    '🛄' => 'преузимање пртљага',
    '🛅' => 'остављени пртљаг',
    '⚠' => 'упозорење',
    '🚸' => 'прелаз за дјецу',
    '⛔' => 'забрањен улаз',
    '🚫' => 'забрањено',
    '🚳' => 'забрањено за бицикле',
    '🚭' => 'забрањено пушење',
    '🚯' => 'забрањено бацање отпада',
    '🚱' => 'вода није за пиће',
    '🚷' => 'забрањено за пјешаке',
    '📵' => 'забрањени мобилни телефони',
    '🔞' => 'забрањено за малољетне',
    '☢' => 'радиоактивно',
    '☣' => 'опасно по живот',
    '⬆' => 'стрелица нагоре',
    '↗' => 'стрелица нагоре и надесно',
    '➡' => 'стрелица надесно',
    '↘' => 'стрелица надоље и надесно',
    '⬇' => 'стрелица надоље',
    '↙' => 'стрелица надоље и налијево',
    '⬅' => 'стрелица налијево',
    '↖' => 'стрелица нагоре и налијево',
    '↕' => 'стрелица нагоре и надоље',
    '↔' => 'стрелица налијево и надесно',
    '↩' => 'стрелица за полукружни окрет удесно',
    '↪' => 'стрелица за полукружни окрет улијево',
    '⤴' => 'стрелица која скреће нагоре',
    '⤵' => 'стрелица која скреће надоље',
    '🔃' => 'стрелице које се врте удесно',
    '🔄' => 'стрелице које се врте улијево',
    '🔙' => 'стрелица за повратак',
    '🔚' => 'стрелица за крај',
    '🔛' => 'стрелица за укључено',
    '🔜' => 'стрелица за ускоро',
    '🔝' => 'стрелица за врх',
    '🛐' => 'вјерски објекат',
    '⚛' => 'симбол за атом',
    '🕉' => 'ом',
    '✡' => 'давидова звијезда',
    '☸' => 'дармин точак',
    '☯' => 'јин и јанг',
    '✝' => 'латински крст',
    '☦' => 'православни крст',
    '☪' => 'звијезда и полумјесец',
    '☮' => 'симбол мира',
    '🕎' => 'менора',
    '🔯' => 'шестокрака звијезда са тачком',
    '🪯' => 'канда',
    '♈' => 'ован у хороскопу',
    '♉' => 'бик у хороскопу',
    '♊' => 'близанци у хороскопу',
    '♋' => 'рак у хороскопу',
    '♌' => 'лав у хороскопу',
    '♍' => 'дјевица у хороскопу',
    '♎' => 'вага у хороскопу',
    '♏' => 'шкорпија у хороскопу',
    '♐' => 'стријелац у хороскопу',
    '♑' => 'јарац у хороскопу',
    '♒' => 'водолија у хороскопу',
    '♓' => 'рибе у хороскопу',
    '⛎' => 'змијоноша',
    '🔀' => 'дугме за насумично пуштање',
    '🔁' => 'дугме за понављање',
    '🔂' => 'дугме за понављање једне пјесме',
    '▶' => 'дугме за репродукцију',
    '⏩' => 'дугме за премотавање унапријед',
    '⏭' => 'дугме за сљедећу пјесму',
    '⏯' => 'дугме за репродукцију или паузу',
    '◀' => 'дугме за репродукцију уназад',
    '⏪' => 'дугме за премотавање уназад',
    '⏮' => 'дугме за посљедњу пјесму',
    '🔼' => 'дугме за кретање нагоре',
    '⏫' => 'дугме за брзо кретање нагоре',
    '🔽' => 'дугме за кретање надоље',
    '⏬' => 'дугме за брзо кретање надоље',
    '⏸' => 'дугме за паузу',
    '⏹' => 'дугме за заустављање',
    '⏺' => 'дугме за снимање',
    '⏏' => 'дугме за избацивање',
    '🎦' => 'биоскоп',
    '🔅' => 'дугме за затамњивање',
    '🔆' => 'дугме за повећавање освијетљености',
    '📶' => 'траке јачине сигнала',
    '🛜' => 'мобилна мрежа',
    '📳' => 'режим вибрације',
    '📴' => 'искључен мобилни телефон',
    '♀' => 'женски знак',
    '♂' => 'мушки знак',
    '⚧' => 'трансродни симбол',
    '✖' => 'црни знак за множење',
    '➕' => 'црни знак плус',
    '➖' => 'црни знак минус',
    '➗' => 'црни знак за дијељење',
    '🟰' => 'подебљани знак једнакости',
    '♾' => 'бесконачност',
    '‼' => 'двоструки узвичник',
    '⁉' => 'узвичник и упитник',
    '❓' => 'упитник',
    '❔' => 'бијели упитник',
    '❕' => 'бијели узвичник',
    '❗' => 'узвичник',
    '〰' => 'таласаста црта',
    '💱' => 'конверзија валута',
    '💲' => 'црни знак за долар',
    '⚕' => 'медицински знак',
    '♻' => 'симбол за рециклирање',
    '⚜' => 'љиљан',
    '🔱' => 'амблем трозупца',
    '📛' => 'значка са именом',
    '🔰' => 'јапански симбол за почетника',
    '⭕' => 'окс',
    '✅' => 'дугме са знаком потврде',
    '☑' => 'опција са знаком потврде',
    '✔' => 'црни знак потврде',
    '❌' => 'икс',
    '❎' => 'дугме са знаком икс',
    '➰' => 'петља',
    '➿' => 'двострука петља',
    '〽' => 'знак за раздвајање дијелова',
    '✳' => 'осмокрака звијезда',
    '✴' => 'осмокрака звјездица',
    '❇' => 'искра',
    '™' => 'жиг',
    '🫟' => 'просуто',
    '🔠' => 'унос великих слова',
    '🔡' => 'унос малих слова',
    '🔢' => 'унос бројева',
    '🔣' => 'унос симбола',
    '🔤' => 'унос латиничних слова',
    '🅰' => 'дугме са словом а',
    '🆎' => 'дугме са словима а и б',
    '🅱' => 'дугме са словом б',
    '🆑' => 'дугме CL',
    '🆒' => 'дугме COOL',
    '🆓' => 'дугме FREE',
    'ℹ' => 'извор информација',
    '🆔' => 'дугме ID',
    'Ⓜ' => 'слово м у кругу',
    '🆕' => 'дугме NEW',
    '🆖' => 'дугме NG',
    '🅾' => 'дугме o',
    '🆗' => 'дугме OK',
    '🅿' => 'знак за паркинг',
    '🆘' => 'С.О.С.',
    '🆙' => 'дугме UP!',
    '🆚' => 'дугме VS',
    '🈁' => 'катакана коко у квадрату',
    '🈂' => 'катакана са у квадрату',
    '🈷' => 'идеограф „мјесец“ у квадрату',
    '🈶' => 'јапанско дугме „није бесплатно“',
    '🈯' => 'идеограф „прст“ у квадрату',
    '🉐' => 'јапанско дугме „багатела“',
    '🈹' => 'јапанско дугме „снижење“',
    '🈚' => 'јапанско дугме „бесплатно“',
    '🈲' => 'јапанско дугме „забрањено“',
    '🉑' => 'јапанско дугме „прихватљиво“',
    '🈸' => 'јапанско дугме „примјена“',
    '🈴' => 'јапанско дугме „прелазна оцена“',
    '🈳' => 'јапанско дугме „празно“',
    '㊗' => 'јапанско дугме „честитке“',
    '㊙' => 'јапанско дугме „тајна“',
    '🈺' => 'јапанско дугме „отворено“',
    '🈵' => 'јапанско дугме „нема мјеста“',
    '🔴' => 'црвени круг',
    '🟠' => 'наранџаст круг',
    '🟡' => 'жут круг',
    '🟢' => 'зелен круг',
    '🔵' => 'плави круг',
    '🟣' => 'љубичаст круг',
    '🟤' => 'браон круг',
    '⚫' => 'црни круг',
    '⚪' => 'бијели круг',
    '🟥' => 'црвени квадрат',
    '🟧' => 'наранџасти квадрат',
    '🟨' => 'жути квадрат',
    '🟩' => 'зелени квадрат',
    '🟦' => 'плави квадрат',
    '🟪' => 'љубичасти квадрат',
    '🟫' => 'браон квадрат',
    '⬛' => 'велики црни квадрат',
    '⬜' => 'велики бијели квадрат',
    '◼' => 'црни квадрат средње величине',
    '◻' => 'бијели квадрат средње величине',
    '◾' => 'средњемали црни квадрат',
    '◽' => 'средњемали бијели квадрат',
    '▪' => 'мали црни квадрат',
    '▫' => 'мали бијели квадрат',
    '🔶' => 'велики наранџасти ромб',
    '🔷' => 'велики плави ромб',
    '🔸' => 'мали наранџасти ромб',
    '🔹' => 'мали плави ромб',
    '🔺' => 'црвени троугао окренут нагоре',
    '🔻' => 'црвени троугао окренут надоље',
    '💠' => 'ромб са тачком',
    '🔘' => 'дугме за избор',
    '🔳' => 'бијело квадратно дугме',
    '🔲' => 'црно квадратно дугме',
    '🏁' => 'застава за крај трке',
    '🚩' => 'троугласта застава',
    '🎌' => 'укрштене заставе',
    '🏴' => 'црна застава',
    '🏳' => 'бијела застава',
];
