<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'beso: persona adulta, persona adulta, tono de piel claro, tono de piel claro medio',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'beso: persona adulta, persona adulta, tono de piel claro, tono de piel medio',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'beso: persona adulta, persona adulta, tono de piel claro, tono de piel oscuro medio',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'beso: persona adulta, persona adulta, tono de piel claro, tono de piel oscuro',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'beso: persona adulta, persona adulta, tono de piel claro medio, tono de piel claro',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'beso: persona adulta, persona adulta, tono de piel claro medio, tono de piel medio',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'beso: persona adulta, persona adulta, tono de piel claro medio, tono de piel oscuro medio',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'beso: persona adulta, persona adulta, tono de piel claro medio, tono de piel oscuro',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'beso: persona adulta, persona adulta, tono de piel medio, tono de piel claro',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'beso: persona adulta, persona adulta, tono de piel medio, tono de piel claro medio',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'beso: persona adulta, persona adulta, tono de piel medio, tono de piel oscuro medio',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'beso: persona adulta, persona adulta, tono de piel medio, tono de piel oscuro',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'beso: persona adulta, persona adulta, tono de piel oscuro medio, tono de piel claro',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'beso: persona adulta, persona adulta, tono de piel oscuro medio, tono de piel claro medio',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'beso: persona adulta, persona adulta, tono de piel oscuro medio, tono de piel medio',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'beso: persona adulta, persona adulta, tono de piel oscuro medio, tono de piel oscuro',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'beso: persona adulta, persona adulta, tono de piel oscuro, tono de piel claro',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'beso: persona adulta, persona adulta, tono de piel oscuro, tono de piel claro medio',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'beso: persona adulta, persona adulta, tono de piel oscuro, tono de piel medio',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'beso: persona adulta, persona adulta, tono de piel oscuro, tono de piel oscuro medio',
    '👨🏻‍❤‍💋‍👨🏻' => 'beso: hombre, hombre, tono de piel claro',
    '👨🏻‍❤‍💋‍👨🏼' => 'beso: hombre, hombre, tono de piel claro, tono de piel claro medio',
    '👨🏻‍❤‍💋‍👨🏽' => 'beso: hombre, hombre, tono de piel claro, tono de piel medio',
    '👨🏻‍❤‍💋‍👨🏾' => 'beso: hombre, hombre, tono de piel claro, tono de piel oscuro medio',
    '👨🏻‍❤‍💋‍👨🏿' => 'beso: hombre, hombre, tono de piel claro, tono de piel oscuro',
    '👨🏼‍❤‍💋‍👨🏻' => 'beso: hombre, hombre, tono de piel claro medio, tono de piel claro',
    '👨🏼‍❤‍💋‍👨🏼' => 'beso: hombre, hombre, tono de piel claro medio',
    '👨🏼‍❤‍💋‍👨🏽' => 'beso: hombre, hombre, tono de piel claro medio, tono de piel medio',
    '👨🏼‍❤‍💋‍👨🏾' => 'beso: hombre, hombre, tono de piel claro medio, tono de piel oscuro medio',
    '👨🏼‍❤‍💋‍👨🏿' => 'beso: hombre, hombre, tono de piel claro medio, tono de piel oscuro',
    '👨🏽‍❤‍💋‍👨🏻' => 'beso: hombre, hombre, tono de piel medio, tono de piel claro',
    '👨🏽‍❤‍💋‍👨🏼' => 'beso: hombre, hombre, tono de piel medio, tono de piel claro medio',
    '👨🏽‍❤‍💋‍👨🏽' => 'beso: hombre, hombre, tono de piel medio',
    '👨🏽‍❤‍💋‍👨🏾' => 'beso: hombre, hombre, tono de piel medio, tono de piel oscuro medio',
    '👨🏽‍❤‍💋‍👨🏿' => 'beso: hombre, hombre, tono de piel medio, tono de piel oscuro',
    '👨🏾‍❤‍💋‍👨🏻' => 'beso: hombre, hombre, tono de piel oscuro medio, tono de piel claro',
    '👨🏾‍❤‍💋‍👨🏼' => 'beso: hombre, hombre, tono de piel oscuro medio, tono de piel claro medio',
    '👨🏾‍❤‍💋‍👨🏽' => 'beso: hombre, hombre, tono de piel oscuro medio, tono de piel medio',
    '👨🏾‍❤‍💋‍👨🏾' => 'beso: hombre, hombre, tono de piel oscuro medio',
    '👨🏾‍❤‍💋‍👨🏿' => 'beso: hombre, hombre, tono de piel oscuro medio, tono de piel oscuro',
    '👨🏿‍❤‍💋‍👨🏻' => 'beso: hombre, hombre, tono de piel oscuro, tono de piel claro',
    '👨🏿‍❤‍💋‍👨🏼' => 'beso: hombre, hombre, tono de piel oscuro, tono de piel claro medio',
    '👨🏿‍❤‍💋‍👨🏽' => 'beso: hombre, hombre, tono de piel oscuro, tono de piel medio',
    '👨🏿‍❤‍💋‍👨🏾' => 'beso: hombre, hombre, tono de piel oscuro, tono de piel oscuro medio',
    '👨🏿‍❤‍💋‍👨🏿' => 'beso: hombre, hombre, tono de piel oscuro',
    '👩🏻‍❤‍💋‍👨🏻' => 'beso: mujer, hombre, tono de piel claro',
    '👩🏻‍❤‍💋‍👨🏼' => 'beso: mujer, hombre, tono de piel claro, tono de piel claro medio',
    '👩🏻‍❤‍💋‍👨🏽' => 'beso: mujer, hombre, tono de piel claro, tono de piel medio',
    '👩🏻‍❤‍💋‍👨🏾' => 'beso: mujer, hombre, tono de piel claro, tono de piel oscuro medio',
    '👩🏻‍❤‍💋‍👨🏿' => 'beso: mujer, hombre, tono de piel claro, tono de piel oscuro',
    '👩🏼‍❤‍💋‍👨🏻' => 'beso: mujer, hombre, tono de piel claro medio, tono de piel claro',
    '👩🏼‍❤‍💋‍👨🏼' => 'beso: mujer, hombre, tono de piel claro medio',
    '👩🏼‍❤‍💋‍👨🏽' => 'beso: mujer, hombre, tono de piel claro medio, tono de piel medio',
    '👩🏼‍❤‍💋‍👨🏾' => 'beso: mujer, hombre, tono de piel claro medio, tono de piel oscuro medio',
    '👩🏼‍❤‍💋‍👨🏿' => 'beso: mujer, hombre, tono de piel claro medio, tono de piel oscuro',
    '👩🏽‍❤‍💋‍👨🏻' => 'beso: mujer, hombre, tono de piel medio, tono de piel claro',
    '👩🏽‍❤‍💋‍👨🏼' => 'beso: mujer, hombre, tono de piel medio, tono de piel claro medio',
    '👩🏽‍❤‍💋‍👨🏽' => 'beso: mujer, hombre, tono de piel medio',
    '👩🏽‍❤‍💋‍👨🏾' => 'beso: mujer, hombre, tono de piel medio, tono de piel oscuro medio',
    '👩🏽‍❤‍💋‍👨🏿' => 'beso: mujer, hombre, tono de piel medio, tono de piel oscuro',
    '👩🏾‍❤‍💋‍👨🏻' => 'beso: mujer, hombre, tono de piel oscuro medio, tono de piel claro',
    '👩🏾‍❤‍💋‍👨🏼' => 'beso: mujer, hombre, tono de piel oscuro medio, tono de piel claro medio',
    '👩🏾‍❤‍💋‍👨🏽' => 'beso: mujer, hombre, tono de piel oscuro medio, tono de piel medio',
    '👩🏾‍❤‍💋‍👨🏾' => 'beso: mujer, hombre, tono de piel oscuro medio',
    '👩🏾‍❤‍💋‍👨🏿' => 'beso: mujer, hombre, tono de piel oscuro medio, tono de piel oscuro',
    '👩🏿‍❤‍💋‍👨🏻' => 'beso: mujer, hombre, tono de piel oscuro, tono de piel claro',
    '👩🏿‍❤‍💋‍👨🏼' => 'beso: mujer, hombre, tono de piel oscuro, tono de piel claro medio',
    '👩🏿‍❤‍💋‍👨🏽' => 'beso: mujer, hombre, tono de piel oscuro, tono de piel medio',
    '👩🏿‍❤‍💋‍👨🏾' => 'beso: mujer, hombre, tono de piel oscuro, tono de piel oscuro medio',
    '👩🏿‍❤‍💋‍👨🏿' => 'beso: mujer, hombre, tono de piel oscuro',
    '👩🏻‍❤‍💋‍👩🏻' => 'beso: mujer, mujer, tono de piel claro',
    '👩🏻‍❤‍💋‍👩🏼' => 'beso: mujer, mujer, tono de piel claro, tono de piel claro medio',
    '👩🏻‍❤‍💋‍👩🏽' => 'beso: mujer, mujer, tono de piel claro, tono de piel medio',
    '👩🏻‍❤‍💋‍👩🏾' => 'beso: mujer, mujer, tono de piel claro, tono de piel oscuro medio',
    '👩🏻‍❤‍💋‍👩🏿' => 'beso: mujer, mujer, tono de piel claro, tono de piel oscuro',
    '👩🏼‍❤‍💋‍👩🏻' => 'beso: mujer, mujer, tono de piel claro medio, tono de piel claro',
    '👩🏼‍❤‍💋‍👩🏼' => 'beso: mujer, mujer, tono de piel claro medio',
    '👩🏼‍❤‍💋‍👩🏽' => 'beso: mujer, mujer, tono de piel claro medio, tono de piel medio',
    '👩🏼‍❤‍💋‍👩🏾' => 'beso: mujer, mujer, tono de piel claro medio, tono de piel oscuro medio',
    '👩🏼‍❤‍💋‍👩🏿' => 'beso: mujer, mujer, tono de piel claro medio, tono de piel oscuro',
    '👩🏽‍❤‍💋‍👩🏻' => 'beso: mujer, mujer, tono de piel medio, tono de piel claro',
    '👩🏽‍❤‍💋‍👩🏼' => 'beso: mujer, mujer, tono de piel medio, tono de piel claro medio',
    '👩🏽‍❤‍💋‍👩🏽' => 'beso: mujer, mujer, tono de piel medio',
    '👩🏽‍❤‍💋‍👩🏾' => 'beso: mujer, mujer, tono de piel medio, tono de piel oscuro medio',
    '👩🏽‍❤‍💋‍👩🏿' => 'beso: mujer, mujer, tono de piel medio, tono de piel oscuro',
    '👩🏾‍❤‍💋‍👩🏻' => 'beso: mujer, mujer, tono de piel oscuro medio, tono de piel claro',
    '👩🏾‍❤‍💋‍👩🏼' => 'beso: mujer, mujer, tono de piel oscuro medio, tono de piel claro medio',
    '👩🏾‍❤‍💋‍👩🏽' => 'beso: mujer, mujer, tono de piel oscuro medio, tono de piel medio',
    '👩🏾‍❤‍💋‍👩🏾' => 'beso: mujer, mujer, tono de piel oscuro medio',
    '👩🏾‍❤‍💋‍👩🏿' => 'beso: mujer, mujer, tono de piel oscuro medio, tono de piel oscuro',
    '👩🏿‍❤‍💋‍👩🏻' => 'beso: mujer, mujer, tono de piel oscuro, tono de piel claro',
    '👩🏿‍❤‍💋‍👩🏼' => 'beso: mujer, mujer, tono de piel oscuro, tono de piel claro medio',
    '👩🏿‍❤‍💋‍👩🏽' => 'beso: mujer, mujer, tono de piel oscuro, tono de piel medio',
    '👩🏿‍❤‍💋‍👩🏾' => 'beso: mujer, mujer, tono de piel oscuro, tono de piel oscuro medio',
    '👩🏿‍❤‍💋‍👩🏿' => 'beso: mujer, mujer, tono de piel oscuro',
    '🧑🏻‍🫯‍🧑🏼' => 'personas luchando: tono de piel claro y tono de piel claro medio',
    '🧑🏻‍🫯‍🧑🏽' => 'personas luchando: tono de piel claro y tono de piel medio',
    '🧑🏻‍🫯‍🧑🏾' => 'personas luchando: tono de piel claro y tono de piel oscuro medio',
    '🧑🏻‍🫯‍🧑🏿' => 'personas luchando: tono de piel claro y tono de piel oscuro',
    '🧑🏼‍🫯‍🧑🏻' => 'personas luchando: tono de piel claro medio y tono de piel claro',
    '🧑🏼‍🫯‍🧑🏽' => 'personas luchando: tono de piel claro medio y tono de piel medio',
    '🧑🏼‍🫯‍🧑🏾' => 'personas luchando: tono de piel claro medio y tono de piel oscuro medio',
    '🧑🏼‍🫯‍🧑🏿' => 'personas luchando: tono de piel claro medio y tono de piel oscuro',
    '🧑🏽‍🫯‍🧑🏻' => 'personas luchando: tono de piel medio y tono de piel claro',
    '🧑🏽‍🫯‍🧑🏼' => 'personas luchando: tono de piel medio y tono de piel claro medio',
    '🧑🏽‍🫯‍🧑🏾' => 'personas luchando: tono de piel medio y tono de piel oscuro medio',
    '🧑🏽‍🫯‍🧑🏿' => 'personas luchando: tono de piel medio y tono de piel oscuro',
    '🧑🏾‍🫯‍🧑🏻' => 'personas luchando: tono de piel oscuro medio y tono de piel claro',
    '🧑🏾‍🫯‍🧑🏼' => 'personas luchando: tono de piel oscuro medio y tono de piel claro medio',
    '🧑🏾‍🫯‍🧑🏽' => 'personas luchando: tono de piel oscuro medio y tono de piel medio',
    '🧑🏾‍🫯‍🧑🏿' => 'personas luchando: tono de piel oscuro medio y tono de piel oscuro',
    '🧑🏿‍🫯‍🧑🏻' => 'personas luchando: tono de piel oscuro y tono de piel claro',
    '🧑🏿‍🫯‍🧑🏼' => 'personas luchando: tono de piel oscuro y tono de piel claro medio',
    '🧑🏿‍🫯‍🧑🏽' => 'personas luchando: tono de piel oscuro y tono de piel medio',
    '🧑🏿‍🫯‍🧑🏾' => 'personas luchando: tono de piel oscuro y tono de piel oscuro medio',
    '🧑🏻‍❤‍🧑🏼' => 'pareja enamorada: persona adulta, persona adulta, tono de piel claro, tono de piel claro medio',
    '🧑🏻‍❤‍🧑🏽' => 'pareja enamorada: persona adulta, persona adulta, tono de piel claro, tono de piel medio',
    '🧑🏻‍❤‍🧑🏾' => 'pareja enamorada: persona adulta, persona adulta, tono de piel claro, tono de piel oscuro medio',
    '🧑🏻‍❤‍🧑🏿' => 'pareja enamorada: persona adulta, persona adulta, tono de piel claro, tono de piel oscuro',
    '🧑🏼‍❤‍🧑🏻' => 'pareja enamorada: persona adulta, persona adulta, tono de piel claro medio, tono de piel claro',
    '🧑🏼‍❤‍🧑🏽' => 'pareja enamorada: persona adulta, persona adulta, tono de piel claro medio, tono de piel medio',
    '🧑🏼‍❤‍🧑🏾' => 'pareja enamorada: persona adulta, persona adulta, tono de piel claro medio, tono de piel oscuro medio',
    '🧑🏼‍❤‍🧑🏿' => 'pareja enamorada: persona adulta, persona adulta, tono de piel claro medio, tono de piel oscuro',
    '🧑🏽‍❤‍🧑🏻' => 'pareja enamorada: persona adulta, persona adulta, tono de piel medio, tono de piel claro',
    '🧑🏽‍❤‍🧑🏼' => 'pareja enamorada: persona adulta, persona adulta, tono de piel medio, tono de piel claro medio',
    '🧑🏽‍❤‍🧑🏾' => 'pareja enamorada: persona adulta, persona adulta, tono de piel medio, tono de piel oscuro medio',
    '🧑🏽‍❤‍🧑🏿' => 'pareja enamorada: persona adulta, persona adulta, tono de piel medio, tono de piel oscuro',
    '🧑🏾‍❤‍🧑🏻' => 'pareja enamorada: persona adulta, persona adulta, tono de piel oscuro medio, tono de piel claro',
    '🧑🏾‍❤‍🧑🏼' => 'pareja enamorada: persona adulta, persona adulta, tono de piel oscuro medio, tono de piel claro medio',
    '🧑🏾‍❤‍🧑🏽' => 'pareja enamorada: persona adulta, persona adulta, tono de piel oscuro medio, tono de piel medio',
    '🧑🏾‍❤‍🧑🏿' => 'pareja enamorada: persona adulta, persona adulta, tono de piel oscuro medio, tono de piel oscuro',
    '🧑🏿‍❤‍🧑🏻' => 'pareja enamorada: persona adulta, persona adulta, tono de piel oscuro, tono de piel claro',
    '🧑🏿‍❤‍🧑🏼' => 'pareja enamorada: persona adulta, persona adulta, tono de piel oscuro, tono de piel claro medio',
    '🧑🏿‍❤‍🧑🏽' => 'pareja enamorada: persona adulta, persona adulta, tono de piel oscuro, tono de piel medio',
    '🧑🏿‍❤‍🧑🏾' => 'pareja enamorada: persona adulta, persona adulta, tono de piel oscuro, tono de piel oscuro medio',
    '🧑🏻‍🐰‍🧑🏼' => 'personas con orejas de conejo: tono de piel claro y tono de piel claro medio',
    '🧑🏻‍🐰‍🧑🏽' => 'personas con orejas de conejo: tono de piel claro y tono de piel medio',
    '🧑🏻‍🐰‍🧑🏾' => 'personas con orejas de conejo: tono de piel claro y tono de piel oscuro medio',
    '🧑🏻‍🐰‍🧑🏿' => 'personas con orejas de conejo: tono de piel claro y tono de piel oscuro',
    '🧑🏼‍🐰‍🧑🏻' => 'personas con orejas de conejo: tono de piel claro medio y tono de piel claro',
    '🧑🏼‍🐰‍🧑🏽' => 'personas con orejas de conejo: tono de piel claro medio y tono de piel medio',
    '🧑🏼‍🐰‍🧑🏾' => 'personas con orejas de conejo: tono de piel claro medio y tono de piel oscuro medio',
    '🧑🏼‍🐰‍🧑🏿' => 'personas con orejas de conejo: tono de piel claro medio y tono de piel oscuro',
    '🧑🏽‍🐰‍🧑🏻' => 'personas con orejas de conejo: tono de piel medio y tono de piel claro',
    '🧑🏽‍🐰‍🧑🏼' => 'personas con orejas de conejo: tono de piel medio y tono de piel claro medio',
    '🧑🏽‍🐰‍🧑🏾' => 'personas con orejas de conejo: tono de piel medio y tono de piel oscuro medio',
    '🧑🏽‍🐰‍🧑🏿' => 'personas con orejas de conejo: tono de piel medio y tono de piel oscuro',
    '🧑🏾‍🐰‍🧑🏻' => 'personas con orejas de conejo: tono de piel oscuro medio y tono de piel claro',
    '🧑🏾‍🐰‍🧑🏼' => 'personas con orejas de conejo: tono de piel oscuro medio y tono de piel claro medio',
    '🧑🏾‍🐰‍🧑🏽' => 'personas con orejas de conejo: tono de piel oscuro medio y tono de piel medio',
    '🧑🏾‍🐰‍🧑🏿' => 'personas con orejas de conejo: tono de piel oscuro medio y tono de piel oscuro',
    '🧑🏿‍🐰‍🧑🏻' => 'personas con orejas de conejo: tono de piel oscuro y tono de piel claro',
    '🧑🏿‍🐰‍🧑🏼' => 'personas con orejas de conejo: tono de piel oscuro y tono de piel claro medio',
    '🧑🏿‍🐰‍🧑🏽' => 'personas con orejas de conejo: tono de piel oscuro y tono de piel medio',
    '🧑🏿‍🐰‍🧑🏾' => 'personas con orejas de conejo: tono de piel oscuro y tono de piel oscuro medio',
    '👨🏻‍🫯‍👨🏼' => 'hombres luchando: tono de piel claro y tono de piel claro medio',
    '👨🏻‍🫯‍👨🏽' => 'hombres luchando: tono de piel claro y tono de piel medio',
    '👨🏻‍🫯‍👨🏾' => 'hombres luchando: tono de piel claro y tono de piel oscuro medio',
    '👨🏻‍🫯‍👨🏿' => 'hombres luchando: tono de piel claro y tono de piel oscuro',
    '👨🏼‍🫯‍👨🏻' => 'hombres luchando: tono de piel claro medio y tono de piel claro',
    '👨🏼‍🫯‍👨🏽' => 'hombres luchando: tono de piel claro medio y tono de piel medio',
    '👨🏼‍🫯‍👨🏾' => 'hombres luchando: tono de piel claro medio y tono de piel oscuro medio',
    '👨🏼‍🫯‍👨🏿' => 'hombres luchando: tono de piel claro medio y tono de piel oscuro',
    '👨🏽‍🫯‍👨🏻' => 'hombres luchando: tono de piel medio y tono de piel claro',
    '👨🏽‍🫯‍👨🏼' => 'hombres luchando: tono de piel medio y tono de piel claro medio',
    '👨🏽‍🫯‍👨🏾' => 'hombres luchando: tono de piel medio y tono de piel oscuro medio',
    '👨🏽‍🫯‍👨🏿' => 'hombres luchando: tono de piel medio y tono de piel oscuro',
    '👨🏾‍🫯‍👨🏻' => 'hombres luchando: tono de piel oscuro medio y tono de piel claro',
    '👨🏾‍🫯‍👨🏼' => 'hombres luchando: tono de piel oscuro medio y tono de piel claro medio',
    '👨🏾‍🫯‍👨🏽' => 'hombres luchando: tono de piel oscuro medio y tono de piel medio',
    '👨🏾‍🫯‍👨🏿' => 'hombres luchando: tono de piel oscuro medio y tono de piel oscuro',
    '👨🏿‍🫯‍👨🏻' => 'hombres luchando: tono de piel oscuro y tono de piel claro',
    '👨🏿‍🫯‍👨🏼' => 'hombres luchando: tono de piel oscuro y tono de piel claro medio',
    '👨🏿‍🫯‍👨🏽' => 'hombres luchando: tono de piel oscuro y tono de piel medio',
    '👨🏿‍🫯‍👨🏾' => 'hombres luchando: tono de piel oscuro y tono de piel oscuro medio',
    '👨🏻‍❤‍👨🏻' => 'pareja enamorada: hombre, hombre, tono de piel claro',
    '👨🏻‍❤‍👨🏼' => 'pareja enamorada: hombre, hombre, tono de piel claro, tono de piel claro medio',
    '👨🏻‍❤‍👨🏽' => 'pareja enamorada: hombre, hombre, tono de piel claro, tono de piel medio',
    '👨🏻‍❤‍👨🏾' => 'pareja enamorada: hombre, hombre, tono de piel claro, tono de piel oscuro medio',
    '👨🏻‍❤‍👨🏿' => 'pareja enamorada: hombre, hombre, tono de piel claro, tono de piel oscuro',
    '👨🏼‍❤‍👨🏻' => 'pareja enamorada: hombre, hombre, tono de piel claro medio, tono de piel claro',
    '👨🏼‍❤‍👨🏼' => 'pareja enamorada: hombre, hombre, tono de piel claro medio',
    '👨🏼‍❤‍👨🏽' => 'pareja enamorada: hombre, hombre, tono de piel claro medio, tono de piel medio',
    '👨🏼‍❤‍👨🏾' => 'pareja enamorada: hombre, hombre, tono de piel claro medio, tono de piel oscuro medio',
    '👨🏼‍❤‍👨🏿' => 'pareja enamorada: hombre, hombre, tono de piel claro medio, tono de piel oscuro',
    '👨🏽‍❤‍👨🏻' => 'pareja enamorada: hombre, hombre, tono de piel medio, tono de piel claro',
    '👨🏽‍❤‍👨🏼' => 'pareja enamorada: hombre, hombre, tono de piel medio, tono de piel claro medio',
    '👨🏽‍❤‍👨🏽' => 'pareja enamorada: hombre, hombre, tono de piel medio',
    '👨🏽‍❤‍👨🏾' => 'pareja enamorada: hombre, hombre, tono de piel medio, tono de piel oscuro medio',
    '👨🏽‍❤‍👨🏿' => 'pareja enamorada: hombre, hombre, tono de piel medio, tono de piel oscuro',
    '👨🏾‍❤‍👨🏻' => 'pareja enamorada: hombre, hombre, tono de piel oscuro medio, tono de piel claro',
    '👨🏾‍❤‍👨🏼' => 'pareja enamorada: hombre, hombre, tono de piel oscuro medio, tono de piel claro medio',
    '👨🏾‍❤‍👨🏽' => 'pareja enamorada: hombre, hombre, tono de piel oscuro medio, tono de piel medio',
    '👨🏾‍❤‍👨🏾' => 'pareja enamorada: hombre, hombre, tono de piel oscuro medio',
    '👨🏾‍❤‍👨🏿' => 'pareja enamorada: hombre, hombre, tono de piel oscuro medio, tono de piel oscuro',
    '👨🏿‍❤‍👨🏻' => 'pareja enamorada: hombre, hombre, tono de piel oscuro, tono de piel claro',
    '👨🏿‍❤‍👨🏼' => 'pareja enamorada: hombre, hombre, tono de piel oscuro, tono de piel claro medio',
    '👨🏿‍❤‍👨🏽' => 'pareja enamorada: hombre, hombre, tono de piel oscuro, tono de piel medio',
    '👨🏿‍❤‍👨🏾' => 'pareja enamorada: hombre, hombre, tono de piel oscuro, tono de piel oscuro medio',
    '👨🏿‍❤‍👨🏿' => 'pareja enamorada: hombre, hombre, tono de piel oscuro',
    '👨🏻‍🐰‍👨🏼' => 'hombres con orejas de conejo: tono de piel claro y tono de piel claro medio',
    '👨🏻‍🐰‍👨🏽' => 'hombres con orejas de conejo: tono de piel claro y tono de piel medio',
    '👨🏻‍🐰‍👨🏾' => 'hombres con orejas de conejo: tono de piel claro y tono de piel oscuro medio',
    '👨🏻‍🐰‍👨🏿' => 'hombres con orejas de conejo: tono de piel claro y tono de piel oscuro',
    '👨🏼‍🐰‍👨🏻' => 'hombres con orejas de conejo: tono de piel claro medio y tono de piel claro',
    '👨🏼‍🐰‍👨🏽' => 'hombres con orejas de conejo: tono de piel claro medio y tono de piel medio',
    '👨🏼‍🐰‍👨🏾' => 'hombres con orejas de conejo: tono de piel claro medio y tono de piel oscuro medio',
    '👨🏼‍🐰‍👨🏿' => 'hombres con orejas de conejo: tono de piel claro medio y tono de piel oscuro',
    '👨🏽‍🐰‍👨🏻' => 'hombres con orejas de conejo: tono de piel medio y tono de piel claro',
    '👨🏽‍🐰‍👨🏼' => 'hombres con orejas de conejo: tono de piel medio y tono de piel claro medio',
    '👨🏽‍🐰‍👨🏾' => 'hombres con orejas de conejo: tono de piel medio y tono de piel oscuro medio',
    '👨🏽‍🐰‍👨🏿' => 'hombres con orejas de conejo: tono de piel medio y tono de piel oscuro',
    '👨🏾‍🐰‍👨🏻' => 'hombres con orejas de conejo: tono de piel oscuro medio y tono de piel claro',
    '👨🏾‍🐰‍👨🏼' => 'hombres con orejas de conejo: tono de piel oscuro medio y tono de piel claro medio',
    '👨🏾‍🐰‍👨🏽' => 'hombres con orejas de conejo: tono de piel oscuro medio y tono de piel medio',
    '👨🏾‍🐰‍👨🏿' => 'hombres con orejas de conejo: tono de piel oscuro medio y tono de piel oscuro',
    '👨🏿‍🐰‍👨🏻' => 'hombres con orejas de conejo: tono de piel oscuro y tono de piel claro',
    '👨🏿‍🐰‍👨🏼' => 'hombres con orejas de conejo: tono de piel oscuro y tono de piel claro medio',
    '👨🏿‍🐰‍👨🏽' => 'hombres con orejas de conejo: tono de piel oscuro y tono de piel medio',
    '👨🏿‍🐰‍👨🏾' => 'hombres con orejas de conejo: tono de piel oscuro y tono de piel oscuro medio',
    '👩🏻‍🫯‍👩🏼' => 'mujeres luchando: tono de piel claro y tono de piel claro medio',
    '👩🏻‍🫯‍👩🏽' => 'mujeres luchando: tono de piel claro y tono de piel medio',
    '👩🏻‍🫯‍👩🏾' => 'mujeres luchando: tono de piel claro y tono de piel oscuro medio',
    '👩🏻‍🫯‍👩🏿' => 'mujeres luchando: tono de piel claro y tono de piel oscuro',
    '👩🏼‍🫯‍👩🏻' => 'mujeres luchando: tono de piel claro medio y tono de piel claro',
    '👩🏼‍🫯‍👩🏽' => 'mujeres luchando: tono de piel claro medio y tono de piel medio',
    '👩🏼‍🫯‍👩🏾' => 'mujeres luchando: tono de piel claro medio y tono de piel oscuro medio',
    '👩🏼‍🫯‍👩🏿' => 'mujeres luchando: tono de piel claro medio y tono de piel oscuro',
    '👩🏽‍🫯‍👩🏻' => 'mujeres luchando: tono de piel medio y tono de piel claro',
    '👩🏽‍🫯‍👩🏼' => 'mujeres luchando: tono de piel medio y tono de piel claro medio',
    '👩🏽‍🫯‍👩🏾' => 'mujeres luchando: tono de piel medio y tono de piel oscuro medio',
    '👩🏽‍🫯‍👩🏿' => 'mujeres luchando: tono de piel medio y tono de piel oscuro',
    '👩🏾‍🫯‍👩🏻' => 'mujeres luchando: tono de piel oscuro medio y tono de piel claro',
    '👩🏾‍🫯‍👩🏼' => 'mujeres luchando: tono de piel oscuro medio y tono de piel claro medio',
    '👩🏾‍🫯‍👩🏽' => 'mujeres luchando: tono de piel oscuro medio y tono de piel medio',
    '👩🏾‍🫯‍👩🏿' => 'mujeres luchando: tono de piel oscuro medio y tono de piel oscuro',
    '👩🏿‍🫯‍👩🏻' => 'mujeres luchando: tono de piel oscuro y tono de piel claro',
    '👩🏿‍🫯‍👩🏼' => 'mujeres luchando: tono de piel oscuro y tono de piel claro medio',
    '👩🏿‍🫯‍👩🏽' => 'mujeres luchando: tono de piel oscuro y tono de piel medio',
    '👩🏿‍🫯‍👩🏾' => 'mujeres luchando: tono de piel oscuro y tono de piel oscuro medio',
    '👩🏻‍❤‍👨🏻' => 'pareja enamorada: mujer, hombre, tono de piel claro',
    '👩🏻‍❤‍👨🏼' => 'pareja enamorada: mujer, hombre, tono de piel claro, tono de piel claro medio',
    '👩🏻‍❤‍👨🏽' => 'pareja enamorada: mujer, hombre, tono de piel claro, tono de piel medio',
    '👩🏻‍❤‍👨🏾' => 'pareja enamorada: mujer, hombre, tono de piel claro, tono de piel oscuro medio',
    '👩🏻‍❤‍👨🏿' => 'pareja enamorada: mujer, hombre, tono de piel claro, tono de piel oscuro',
    '👩🏼‍❤‍👨🏻' => 'pareja enamorada: mujer, hombre, tono de piel claro medio, tono de piel claro',
    '👩🏼‍❤‍👨🏼' => 'pareja enamorada: mujer, hombre, tono de piel claro medio',
    '👩🏼‍❤‍👨🏽' => 'pareja enamorada: mujer, hombre, tono de piel claro medio, tono de piel medio',
    '👩🏼‍❤‍👨🏾' => 'pareja enamorada: mujer, hombre, tono de piel claro medio, tono de piel oscuro medio',
    '👩🏼‍❤‍👨🏿' => 'pareja enamorada: mujer, hombre, tono de piel claro medio, tono de piel oscuro',
    '👩🏽‍❤‍👨🏻' => 'pareja enamorada: mujer, hombre, tono de piel medio, tono de piel claro',
    '👩🏽‍❤‍👨🏼' => 'pareja enamorada: mujer, hombre, tono de piel medio, tono de piel claro medio',
    '👩🏽‍❤‍👨🏽' => 'pareja enamorada: mujer, hombre, tono de piel medio',
    '👩🏽‍❤‍👨🏾' => 'pareja enamorada: mujer, hombre, tono de piel medio, tono de piel oscuro medio',
    '👩🏽‍❤‍👨🏿' => 'pareja enamorada: mujer, hombre, tono de piel medio, tono de piel oscuro',
    '👩🏾‍❤‍👨🏻' => 'pareja enamorada: mujer, hombre, tono de piel oscuro medio, tono de piel claro',
    '👩🏾‍❤‍👨🏼' => 'pareja enamorada: mujer, hombre, tono de piel oscuro medio, tono de piel claro medio',
    '👩🏾‍❤‍👨🏽' => 'pareja enamorada: mujer, hombre, tono de piel oscuro medio, tono de piel medio',
    '👩🏾‍❤‍👨🏾' => 'pareja enamorada: mujer, hombre, tono de piel oscuro medio',
    '👩🏾‍❤‍👨🏿' => 'pareja enamorada: mujer, hombre, tono de piel oscuro medio, tono de piel oscuro',
    '👩🏿‍❤‍👨🏻' => 'pareja enamorada: mujer, hombre, tono de piel oscuro, tono de piel claro',
    '👩🏿‍❤‍👨🏼' => 'pareja enamorada: mujer, hombre, tono de piel oscuro, tono de piel claro medio',
    '👩🏿‍❤‍👨🏽' => 'pareja enamorada: mujer, hombre, tono de piel oscuro, tono de piel medio',
    '👩🏿‍❤‍👨🏾' => 'pareja enamorada: mujer, hombre, tono de piel oscuro, tono de piel oscuro medio',
    '👩🏿‍❤‍👨🏿' => 'pareja enamorada: mujer, hombre, tono de piel oscuro',
    '👩🏻‍❤‍👩🏻' => 'pareja enamorada: mujer, mujer, tono de piel claro',
    '👩🏻‍❤‍👩🏼' => 'pareja enamorada: mujer, mujer, tono de piel claro, tono de piel claro medio',
    '👩🏻‍❤‍👩🏽' => 'pareja enamorada: mujer, mujer, tono de piel claro, tono de piel medio',
    '👩🏻‍❤‍👩🏾' => 'pareja enamorada: mujer, mujer, tono de piel claro, tono de piel oscuro medio',
    '👩🏻‍❤‍👩🏿' => 'pareja enamorada: mujer, mujer, tono de piel claro, tono de piel oscuro',
    '👩🏼‍❤‍👩🏻' => 'pareja enamorada: mujer, mujer, tono de piel claro medio, tono de piel claro',
    '👩🏼‍❤‍👩🏼' => 'pareja enamorada: mujer, mujer, tono de piel claro medio',
    '👩🏼‍❤‍👩🏽' => 'pareja enamorada: mujer, mujer, tono de piel claro medio, tono de piel medio',
    '👩🏼‍❤‍👩🏾' => 'pareja enamorada: mujer, mujer, tono de piel claro medio, tono de piel oscuro medio',
    '👩🏼‍❤‍👩🏿' => 'pareja enamorada: mujer, mujer, tono de piel claro medio, tono de piel oscuro',
    '👩🏽‍❤‍👩🏻' => 'pareja enamorada: mujer, mujer, tono de piel medio, tono de piel claro',
    '👩🏽‍❤‍👩🏼' => 'pareja enamorada: mujer, mujer, tono de piel medio, tono de piel claro medio',
    '👩🏽‍❤‍👩🏽' => 'pareja enamorada: mujer, mujer, tono de piel medio',
    '👩🏽‍❤‍👩🏾' => 'pareja enamorada: mujer, mujer, tono de piel medio, tono de piel oscuro medio',
    '👩🏽‍❤‍👩🏿' => 'pareja enamorada: mujer, mujer, tono de piel medio, tono de piel oscuro',
    '👩🏾‍❤‍👩🏻' => 'pareja enamorada: mujer, mujer, tono de piel oscuro medio, tono de piel claro',
    '👩🏾‍❤‍👩🏼' => 'pareja enamorada: mujer, mujer, tono de piel oscuro medio, tono de piel claro medio',
    '👩🏾‍❤‍👩🏽' => 'pareja enamorada: mujer, mujer, tono de piel oscuro medio, tono de piel medio',
    '👩🏾‍❤‍👩🏾' => 'pareja enamorada: mujer, mujer, tono de piel oscuro medio',
    '👩🏾‍❤‍👩🏿' => 'pareja enamorada: mujer, mujer, tono de piel oscuro medio, tono de piel oscuro',
    '👩🏿‍❤‍👩🏻' => 'pareja enamorada: mujer, mujer, tono de piel oscuro, tono de piel claro',
    '👩🏿‍❤‍👩🏼' => 'pareja enamorada: mujer, mujer, tono de piel oscuro, tono de piel claro medio',
    '👩🏿‍❤‍👩🏽' => 'pareja enamorada: mujer, mujer, tono de piel oscuro, tono de piel medio',
    '👩🏿‍❤‍👩🏾' => 'pareja enamorada: mujer, mujer, tono de piel oscuro, tono de piel oscuro medio',
    '👩🏿‍❤‍👩🏿' => 'pareja enamorada: mujer, mujer, tono de piel oscuro',
    '👩🏻‍🐰‍👩🏼' => 'mujeres con orejas de conejo: tono de piel claro y tono de piel claro medio',
    '👩🏻‍🐰‍👩🏽' => 'mujeres con orejas de conejo: tono de piel claro y tono de piel medio',
    '👩🏻‍🐰‍👩🏾' => 'mujeres con orejas de conejo: tono de piel claro y tono de piel oscuro medio',
    '👩🏻‍🐰‍👩🏿' => 'mujeres con orejas de conejo: tono de piel claro y tono de piel oscuro',
    '👩🏼‍🐰‍👩🏻' => 'mujeres con orejas de conejo: tono de piel claro medio y tono de piel claro',
    '👩🏼‍🐰‍👩🏽' => 'mujeres con orejas de conejo: tono de piel claro medio y tono de piel medio',
    '👩🏼‍🐰‍👩🏾' => 'mujeres con orejas de conejo: tono de piel claro medio y tono de piel oscuro medio',
    '👩🏼‍🐰‍👩🏿' => 'mujeres con orejas de conejo: tono de piel claro medio y tono de piel oscuro',
    '👩🏽‍🐰‍👩🏻' => 'mujeres con orejas de conejo: tono de piel medio y tono de piel claro',
    '👩🏽‍🐰‍👩🏼' => 'mujeres con orejas de conejo: tono de piel medio y tono de piel claro medio',
    '👩🏽‍🐰‍👩🏾' => 'mujeres con orejas de conejo: tono de piel medio y tono de piel oscuro medio',
    '👩🏽‍🐰‍👩🏿' => 'mujeres con orejas de conejo: tono de piel medio y tono de piel oscuro',
    '👩🏾‍🐰‍👩🏻' => 'mujeres con orejas de conejo: tono de piel oscuro medio y tono de piel claro',
    '👩🏾‍🐰‍👩🏼' => 'mujeres con orejas de conejo: tono de piel oscuro medio y tono de piel claro medio',
    '👩🏾‍🐰‍👩🏽' => 'mujeres con orejas de conejo: tono de piel oscuro medio y tono de piel medio',
    '👩🏾‍🐰‍👩🏿' => 'mujeres con orejas de conejo: tono de piel oscuro medio y tono de piel oscuro',
    '👩🏿‍🐰‍👩🏻' => 'mujeres con orejas de conejo: tono de piel oscuro y tono de piel claro',
    '👩🏿‍🐰‍👩🏼' => 'mujeres con orejas de conejo: tono de piel oscuro y tono de piel claro medio',
    '👩🏿‍🐰‍👩🏽' => 'mujeres con orejas de conejo: tono de piel oscuro y tono de piel medio',
    '👩🏿‍🐰‍👩🏾' => 'mujeres con orejas de conejo: tono de piel oscuro y tono de piel oscuro medio',
    '🧑🏻‍🤝‍🧑🏻' => 'dos personas de la mano: tono de piel claro',
    '🧑🏻‍🤝‍🧑🏼' => 'dos personas de la mano: tono de piel claro y tono de piel claro medio',
    '🧑🏻‍🤝‍🧑🏽' => 'dos personas de la mano: tono de piel claro y tono de piel medio',
    '🧑🏻‍🤝‍🧑🏾' => 'dos personas de la mano: tono de piel claro y tono de piel oscuro medio',
    '🧑🏻‍🤝‍🧑🏿' => 'dos personas de la mano: tono de piel claro y tono de piel oscuro',
    '🧑🏼‍🤝‍🧑🏻' => 'dos personas de la mano: tono de piel claro medio y tono de piel claro',
    '🧑🏼‍🤝‍🧑🏼' => 'dos personas de la mano: tono de piel claro medio',
    '🧑🏼‍🤝‍🧑🏽' => 'dos personas de la mano: tono de piel claro medio y tono de piel medio',
    '🧑🏼‍🤝‍🧑🏾' => 'dos personas de la mano: tono de piel claro medio y tono de piel oscuro medio',
    '🧑🏼‍🤝‍🧑🏿' => 'dos personas de la mano: tono de piel claro medio y tono de piel oscuro',
    '🧑🏽‍🤝‍🧑🏻' => 'dos personas de la mano: tono de piel medio y tono de piel claro',
    '🧑🏽‍🤝‍🧑🏼' => 'dos personas de la mano: tono de piel medio y tono de piel claro medio',
    '🧑🏽‍🤝‍🧑🏽' => 'dos personas de la mano: tono de piel medio',
    '🧑🏽‍🤝‍🧑🏾' => 'dos personas de la mano: tono de piel medio y tono de piel oscuro medio',
    '🧑🏽‍🤝‍🧑🏿' => 'dos personas de la mano: tono de piel medio y tono de piel oscuro',
    '🧑🏾‍🤝‍🧑🏻' => 'dos personas de la mano: tono de piel oscuro medio y tono de piel claro',
    '🧑🏾‍🤝‍🧑🏼' => 'dos personas de la mano: tono de piel oscuro medio y tono de piel claro medio',
    '🧑🏾‍🤝‍🧑🏽' => 'dos personas de la mano: tono de piel oscuro medio y tono de piel medio',
    '🧑🏾‍🤝‍🧑🏾' => 'dos personas de la mano: tono de piel oscuro medio',
    '🧑🏾‍🤝‍🧑🏿' => 'dos personas de la mano: tono de piel oscuro medio y tono de piel oscuro',
    '🧑🏿‍🤝‍🧑🏻' => 'dos personas de la mano: tono de piel oscuro y tono de piel claro',
    '🧑🏿‍🤝‍🧑🏼' => 'dos personas de la mano: tono de piel oscuro y tono de piel claro medio',
    '🧑🏿‍🤝‍🧑🏽' => 'dos personas de la mano: tono de piel oscuro y tono de piel medio',
    '🧑🏿‍🤝‍🧑🏾' => 'dos personas de la mano: tono de piel oscuro y tono de piel oscuro medio',
    '🧑🏿‍🤝‍🧑🏿' => 'dos personas de la mano: tono de piel oscuro',
    '👩🏻‍🤝‍👩🏼' => 'mujeres de la mano: tono de piel claro y tono de piel claro medio',
    '👩🏻‍🤝‍👩🏽' => 'mujeres de la mano: tono de piel claro y tono de piel medio',
    '👩🏻‍🤝‍👩🏾' => 'mujeres de la mano: tono de piel claro y tono de piel oscuro medio',
    '👩🏻‍🤝‍👩🏿' => 'mujeres de la mano: tono de piel claro y tono de piel oscuro',
    '👩🏼‍🤝‍👩🏻' => 'mujeres de la mano: tono de piel claro medio y tono de piel claro',
    '👩🏼‍🤝‍👩🏽' => 'mujeres de la mano: tono de piel claro medio y tono de piel medio',
    '👩🏼‍🤝‍👩🏾' => 'mujeres de la mano: tono de piel claro medio y tono de piel oscuro medio',
    '👩🏼‍🤝‍👩🏿' => 'mujeres de la mano: tono de piel claro medio y tono de piel oscuro',
    '👩🏽‍🤝‍👩🏻' => 'mujeres de la mano: tono de piel medio y tono de piel claro',
    '👩🏽‍🤝‍👩🏼' => 'mujeres de la mano: tono de piel medio y tono de piel claro medio',
    '👩🏽‍🤝‍👩🏾' => 'mujeres de la mano: tono de piel medio y tono de piel oscuro medio',
    '👩🏽‍🤝‍👩🏿' => 'mujeres de la mano: tono de piel medio y tono de piel oscuro',
    '👩🏾‍🤝‍👩🏻' => 'mujeres de la mano: tono de piel oscuro medio y tono de piel claro',
    '👩🏾‍🤝‍👩🏼' => 'mujeres de la mano: tono de piel oscuro medio y tono de piel claro medio',
    '👩🏾‍🤝‍👩🏽' => 'mujeres de la mano: tono de piel oscuro medio y tono de piel medio',
    '👩🏾‍🤝‍👩🏿' => 'mujeres de la mano: tono de piel oscuro medio y tono de piel oscuro',
    '👩🏿‍🤝‍👩🏻' => 'mujeres de la mano: tono de piel oscuro y tono de piel claro',
    '👩🏿‍🤝‍👩🏼' => 'mujeres de la mano: tono de piel oscuro y tono de piel claro medio',
    '👩🏿‍🤝‍👩🏽' => 'mujeres de la mano: tono de piel oscuro y tono de piel medio',
    '👩🏿‍🤝‍👩🏾' => 'mujeres de la mano: tono de piel oscuro y tono de piel oscuro medio',
    '👩🏻‍🤝‍👨🏼' => 'mujer y hombre de la mano: tono de piel claro y tono de piel claro medio',
    '👩🏻‍🤝‍👨🏽' => 'mujer y hombre de la mano: tono de piel claro y tono de piel medio',
    '👩🏻‍🤝‍👨🏾' => 'mujer y hombre de la mano: tono de piel claro y tono de piel oscuro medio',
    '👩🏻‍🤝‍👨🏿' => 'mujer y hombre de la mano: tono de piel claro y tono de piel oscuro',
    '👩🏼‍🤝‍👨🏻' => 'mujer y hombre de la mano: tono de piel claro medio y tono de piel claro',
    '👩🏼‍🤝‍👨🏽' => 'mujer y hombre de la mano: tono de piel claro medio y tono de piel medio',
    '👩🏼‍🤝‍👨🏾' => 'mujer y hombre de la mano: tono de piel claro medio y tono de piel oscuro medio',
    '👩🏼‍🤝‍👨🏿' => 'mujer y hombre de la mano: tono de piel claro medio y tono de piel oscuro',
    '👩🏽‍🤝‍👨🏻' => 'mujer y hombre de la mano: tono de piel medio y tono de piel claro',
    '👩🏽‍🤝‍👨🏼' => 'mujer y hombre de la mano: tono de piel medio y tono de piel claro medio',
    '👩🏽‍🤝‍👨🏾' => 'mujer y hombre de la mano: tono de piel medio y tono de piel oscuro medio',
    '👩🏽‍🤝‍👨🏿' => 'mujer y hombre de la mano: tono de piel medio y tono de piel oscuro',
    '👩🏾‍🤝‍👨🏻' => 'mujer y hombre de la mano: tono de piel oscuro medio y tono de piel claro',
    '👩🏾‍🤝‍👨🏼' => 'mujer y hombre de la mano: tono de piel oscuro medio y tono de piel claro medio',
    '👩🏾‍🤝‍👨🏽' => 'mujer y hombre de la mano: tono de piel oscuro medio y tono de piel medio',
    '👩🏾‍🤝‍👨🏿' => 'mujer y hombre de la mano: tono de piel oscuro medio y tono de piel oscuro',
    '👩🏿‍🤝‍👨🏻' => 'mujer y hombre de la mano: tono de piel oscuro y tono de piel claro',
    '👩🏿‍🤝‍👨🏼' => 'mujer y hombre de la mano: tono de piel oscuro y tono de piel claro medio',
    '👩🏿‍🤝‍👨🏽' => 'mujer y hombre de la mano: tono de piel oscuro y tono de piel medio',
    '👩🏿‍🤝‍👨🏾' => 'mujer y hombre de la mano: tono de piel oscuro y tono de piel oscuro medio',
    '👨🏻‍🤝‍👨🏼' => 'hombres de la mano: tono de piel claro y tono de piel claro medio',
    '👨🏻‍🤝‍👨🏽' => 'hombres de la mano: tono de piel claro y tono de piel medio',
    '👨🏻‍🤝‍👨🏾' => 'hombres de la mano: tono de piel claro y tono de piel oscuro medio',
    '👨🏻‍🤝‍👨🏿' => 'hombres de la mano: tono de piel claro y tono de piel oscuro',
    '👨🏼‍🤝‍👨🏻' => 'hombres de la mano: tono de piel claro medio y tono de piel claro',
    '👨🏼‍🤝‍👨🏽' => 'hombres de la mano: tono de piel claro medio y tono de piel medio',
    '👨🏼‍🤝‍👨🏾' => 'hombres de la mano: tono de piel claro medio y tono de piel oscuro medio',
    '👨🏼‍🤝‍👨🏿' => 'hombres de la mano: tono de piel claro medio y tono de piel oscuro',
    '👨🏽‍🤝‍👨🏻' => 'hombres de la mano: tono de piel medio y tono de piel claro',
    '👨🏽‍🤝‍👨🏼' => 'hombres de la mano: tono de piel medio y tono de piel claro medio',
    '👨🏽‍🤝‍👨🏾' => 'hombres de la mano: tono de piel medio y tono de piel oscuro medio',
    '👨🏽‍🤝‍👨🏿' => 'hombres de la mano: tono de piel medio y tono de piel oscuro',
    '👨🏾‍🤝‍👨🏻' => 'hombres de la mano: tono de piel oscuro medio y tono de piel claro',
    '👨🏾‍🤝‍👨🏼' => 'hombres de la mano: tono de piel oscuro medio y tono de piel claro medio',
    '👨🏾‍🤝‍👨🏽' => 'hombres de la mano: tono de piel oscuro medio y tono de piel medio',
    '👨🏾‍🤝‍👨🏿' => 'hombres de la mano: tono de piel oscuro medio y tono de piel oscuro',
    '👨🏿‍🤝‍👨🏻' => 'hombres de la mano: tono de piel oscuro y tono de piel claro',
    '👨🏿‍🤝‍👨🏼' => 'hombres de la mano: tono de piel oscuro y tono de piel claro medio',
    '👨🏿‍🤝‍👨🏽' => 'hombres de la mano: tono de piel oscuro y tono de piel medio',
    '👨🏿‍🤝‍👨🏾' => 'hombres de la mano: tono de piel oscuro y tono de piel oscuro medio',
    '👩‍❤‍💋‍👨' => 'beso: mujer y hombre',
    '👨‍❤‍💋‍👨' => 'beso: hombre y hombre',
    '👩‍❤‍💋‍👩' => 'beso: mujer y mujer',
    '👨‍👩‍👧‍👦' => 'familia: hombre, mujer, niña, niño',
    '👨‍👩‍👦‍👦' => 'familia: hombre, mujer, niño, niño',
    '👨‍👩‍👧‍👧' => 'familia: hombre, mujer, niña, niña',
    '👨‍👨‍👧‍👦' => 'familia: hombre, hombre, niña, niño',
    '👨‍👨‍👦‍👦' => 'familia: hombre, hombre, niño, niño',
    '👨‍👨‍👧‍👧' => 'familia: hombre, hombre, niña, niña',
    '👩‍👩‍👧‍👦' => 'familia: mujer, mujer, niña, niño',
    '👩‍👩‍👦‍👦' => 'familia: mujer, mujer, niño, niño',
    '👩‍👩‍👧‍👧' => 'familia: mujer, mujer, niña, niña',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'Bandera: Inglaterra',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'Bandera: Escocia',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'Bandera: Gales',
    '🧑‍🧑‍🧒‍🧒' => 'familia: adulto, adulto, niño, niño',
    '🚶🏻‍♀‍➡' => 'mujer caminando: tono de piel claro y hacia la derecha',
    '🚶🏼‍♀‍➡' => 'mujer caminando: tono de piel claro medio y hacia la derecha',
    '🚶🏽‍♀‍➡' => 'mujer caminando: tono de piel medio y hacia la derecha',
    '🚶🏾‍♀‍➡' => 'mujer caminando: tono de piel oscuro medio y hacia la derecha',
    '🚶🏿‍♀‍➡' => 'mujer caminando: tono de piel oscuro y hacia la derecha',
    '🚶🏻‍♂‍➡' => 'hombre caminando: tono de piel claro y hacia la derecha',
    '🚶🏼‍♂‍➡' => 'hombre caminando: tono de piel claro medio y hacia la derecha',
    '🚶🏽‍♂‍➡' => 'hombre caminando: tono de piel medio y hacia la derecha',
    '🚶🏾‍♂‍➡' => 'hombre caminando: tono de piel oscuro medio y hacia la derecha',
    '🚶🏿‍♂‍➡' => 'hombre caminando: tono de piel oscuro y hacia la derecha',
    '🧎🏻‍♀‍➡' => 'mujer de rodillas: tono de piel claro y hacia la derecha',
    '🧎🏼‍♀‍➡' => 'mujer de rodillas: tono de piel claro medio y hacia la derecha',
    '🧎🏽‍♀‍➡' => 'mujer de rodillas: tono de piel medio y hacia la derecha',
    '🧎🏾‍♀‍➡' => 'mujer de rodillas: tono de piel oscuro medio y hacia la derecha',
    '🧎🏿‍♀‍➡' => 'mujer de rodillas: tono de piel oscuro y hacia la derecha',
    '🧎🏻‍♂‍➡' => 'hombre de rodillas: tono de piel claro y hacia la derecha',
    '🧎🏼‍♂‍➡' => 'hombre de rodillas: tono de piel claro medio y hacia la derecha',
    '🧎🏽‍♂‍➡' => 'hombre de rodillas: tono de piel medio y hacia la derecha',
    '🧎🏾‍♂‍➡' => 'hombre de rodillas: tono de piel oscuro medio y hacia la derecha',
    '🧎🏿‍♂‍➡' => 'hombre de rodillas: tono de piel oscuro y hacia la derecha',
    '🧑🏻‍🦯‍➡' => 'persona con bastón: tono de piel claro y hacia la derecha',
    '🧑🏼‍🦯‍➡' => 'persona con bastón: tono de piel claro medio y hacia la derecha',
    '🧑🏽‍🦯‍➡' => 'persona con bastón: tono de piel medio y hacia la derecha',
    '🧑🏾‍🦯‍➡' => 'persona con bastón: tono de piel oscuro medio y hacia la derecha',
    '🧑🏿‍🦯‍➡' => 'persona con bastón: tono de piel oscuro y hacia la derecha',
    '👨🏻‍🦯‍➡' => 'hombre con bastón: tono de piel claro y hacia la derecha',
    '👨🏼‍🦯‍➡' => 'hombre con bastón: tono de piel claro medio y hacia la derecha',
    '👨🏽‍🦯‍➡' => 'hombre con bastón: tono de piel medio y hacia la derecha',
    '👨🏾‍🦯‍➡' => 'hombre con bastón: tono de piel oscuro medio y hacia la derecha',
    '👨🏿‍🦯‍➡' => 'hombre con bastón: tono de piel oscuro y hacia la derecha',
    '👩🏻‍🦯‍➡' => 'mujer con bastón: tono de piel claro y hacia la derecha',
    '👩🏼‍🦯‍➡' => 'mujer con bastón: tono de piel claro medio y hacia la derecha',
    '👩🏽‍🦯‍➡' => 'mujer con bastón: tono de piel medio y hacia la derecha',
    '👩🏾‍🦯‍➡' => 'mujer con bastón: tono de piel oscuro medio y hacia la derecha',
    '👩🏿‍🦯‍➡' => 'mujer con bastón: tono de piel oscuro y hacia la derecha',
    '🧑🏻‍🦼‍➡' => 'persona en silla de ruedas eléctrica: tono de piel claro y hacia la derecha',
    '🧑🏼‍🦼‍➡' => 'persona en silla de ruedas eléctrica: tono de piel claro medio y hacia la derecha',
    '🧑🏽‍🦼‍➡' => 'persona en silla de ruedas eléctrica: tono de piel medio y hacia la derecha',
    '🧑🏾‍🦼‍➡' => 'persona en silla de ruedas eléctrica: tono de piel oscuro medio y hacia la derecha',
    '🧑🏿‍🦼‍➡' => 'persona en silla de ruedas eléctrica: tono de piel oscuro y hacia la derecha',
    '👨🏻‍🦼‍➡' => 'hombre en silla de ruedas eléctrica: tono de piel claro y hacia la derecha',
    '👨🏼‍🦼‍➡' => 'hombre en silla de ruedas eléctrica: tono de piel claro medio y hacia la derecha',
    '👨🏽‍🦼‍➡' => 'hombre en silla de ruedas eléctrica: tono de piel medio y hacia la derecha',
    '👨🏾‍🦼‍➡' => 'hombre en silla de ruedas eléctrica: tono de piel oscuro medio y hacia la derecha',
    '👨🏿‍🦼‍➡' => 'hombre en silla de ruedas eléctrica: tono de piel oscuro y hacia la derecha',
    '👩🏻‍🦼‍➡' => 'mujer en silla de ruedas eléctrica: tono de piel claro y hacia la derecha',
    '👩🏼‍🦼‍➡' => 'mujer en silla de ruedas eléctrica: tono de piel claro medio y hacia la derecha',
    '👩🏽‍🦼‍➡' => 'mujer en silla de ruedas eléctrica: tono de piel medio y hacia la derecha',
    '👩🏾‍🦼‍➡' => 'mujer en silla de ruedas eléctrica: tono de piel oscuro medio y hacia la derecha',
    '👩🏿‍🦼‍➡' => 'mujer en silla de ruedas eléctrica: tono de piel oscuro y hacia la derecha',
    '🧑🏻‍🦽‍➡' => 'persona en silla de ruedas manual: tono de piel claro y hacia la derecha',
    '🧑🏼‍🦽‍➡' => 'persona en silla de ruedas manual: tono de piel claro medio y hacia la derecha',
    '🧑🏽‍🦽‍➡' => 'persona en silla de ruedas manual: tono de piel medio y hacia la derecha',
    '🧑🏾‍🦽‍➡' => 'persona en silla de ruedas manual: tono de piel oscuro medio y hacia la derecha',
    '🧑🏿‍🦽‍➡' => 'persona en silla de ruedas manual: tono de piel oscuro y hacia la derecha',
    '👨🏻‍🦽‍➡' => 'hombre en silla de ruedas manual: tono de piel claro y hacia la derecha',
    '👨🏼‍🦽‍➡' => 'hombre en silla de ruedas manual: tono de piel claro medio y hacia la derecha',
    '👨🏽‍🦽‍➡' => 'hombre en silla de ruedas manual: tono de piel medio y hacia la derecha',
    '👨🏾‍🦽‍➡' => 'hombre en silla de ruedas manual: tono de piel oscuro medio y hacia la derecha',
    '👨🏿‍🦽‍➡' => 'hombre en silla de ruedas manual: tono de piel oscuro y hacia la derecha',
    '👩🏻‍🦽‍➡' => 'mujer en silla de ruedas manual: tono de piel claro y hacia la derecha',
    '👩🏼‍🦽‍➡' => 'mujer en silla de ruedas manual: tono de piel claro medio y hacia la derecha',
    '👩🏽‍🦽‍➡' => 'mujer en silla de ruedas manual: tono de piel medio y hacia la derecha',
    '👩🏾‍🦽‍➡' => 'mujer en silla de ruedas manual: tono de piel oscuro medio y hacia la derecha',
    '👩🏿‍🦽‍➡' => 'mujer en silla de ruedas manual: tono de piel oscuro y hacia la derecha',
    '🏃🏻‍♀‍➡' => 'mujer corriendo: tono de piel claro y hacia la derecha',
    '🏃🏼‍♀‍➡' => 'mujer corriendo: tono de piel claro medio y hacia la derecha',
    '🏃🏽‍♀‍➡' => 'mujer corriendo: tono de piel medio y hacia la derecha',
    '🏃🏾‍♀‍➡' => 'mujer corriendo: tono de piel oscuro medio y hacia la derecha',
    '🏃🏿‍♀‍➡' => 'mujer corriendo: tono de piel oscuro y hacia la derecha',
    '🏃🏻‍♂‍➡' => 'hombre corriendo: tono de piel claro y hacia la derecha',
    '🏃🏼‍♂‍➡' => 'hombre corriendo: tono de piel claro medio y hacia la derecha',
    '🏃🏽‍♂‍➡' => 'hombre corriendo: tono de piel medio y hacia la derecha',
    '🏃🏾‍♂‍➡' => 'hombre corriendo: tono de piel oscuro medio y hacia la derecha',
    '🏃🏿‍♂‍➡' => 'hombre corriendo: tono de piel oscuro y hacia la derecha',
    '🫱🏻‍🫲🏼' => 'apretón de manos: tono de piel claro y tono de piel claro medio',
    '🫱🏻‍🫲🏽' => 'apretón de manos: tono de piel claro y tono de piel medio',
    '🫱🏻‍🫲🏾' => 'apretón de manos: tono de piel claro y tono de piel oscuro medio',
    '🫱🏻‍🫲🏿' => 'apretón de manos: tono de piel claro y tono de piel oscuro',
    '🫱🏼‍🫲🏻' => 'apretón de manos: tono de piel claro medio y tono de piel claro',
    '🫱🏼‍🫲🏽' => 'apretón de manos: tono de piel claro medio y tono de piel medio',
    '🫱🏼‍🫲🏾' => 'apretón de manos: tono de piel claro medio y tono de piel oscuro medio',
    '🫱🏼‍🫲🏿' => 'apretón de manos: tono de piel claro medio y tono de piel oscuro',
    '🫱🏽‍🫲🏻' => 'apretón de manos: tono de piel medio y tono de piel claro',
    '🫱🏽‍🫲🏼' => 'apretón de manos: tono de piel medio y tono de piel claro medio',
    '🫱🏽‍🫲🏾' => 'apretón de manos: tono de piel medio y tono de piel oscuro medio',
    '🫱🏽‍🫲🏿' => 'apretón de manos: tono de piel medio y tono de piel oscuro',
    '🫱🏾‍🫲🏻' => 'apretón de manos: tono de piel oscuro medio y tono de piel claro',
    '🫱🏾‍🫲🏼' => 'apretón de manos: tono de piel oscuro medio y tono de piel claro medio',
    '🫱🏾‍🫲🏽' => 'apretón de manos: tono de piel oscuro medio y tono de piel medio',
    '🫱🏾‍🫲🏿' => 'apretón de manos: tono de piel oscuro medio y tono de piel oscuro',
    '🫱🏿‍🫲🏻' => 'apretón de manos: tono de piel oscuro y tono de piel claro',
    '🫱🏿‍🫲🏼' => 'apretón de manos: tono de piel oscuro y tono de piel claro medio',
    '🫱🏿‍🫲🏽' => 'apretón de manos: tono de piel oscuro y tono de piel medio',
    '🫱🏿‍🫲🏾' => 'apretón de manos: tono de piel oscuro y tono de piel oscuro medio',
    '🚶‍♀‍➡' => 'mujer caminando: hacia la derecha',
    '🚶‍♂‍➡' => 'hombre caminando: hacia la derecha',
    '🧎‍♀‍➡' => 'mujer de rodillas: hacia la derecha',
    '🧎‍♂‍➡' => 'hombre de rodillas: hacia la derecha',
    '🧑‍🦯‍➡' => 'persona con bastón: hacia la derecha',
    '👨‍🦯‍➡' => 'hombre con bastón: hacia la derecha',
    '👩‍🦯‍➡' => 'mujer con bastón: hacia la derecha',
    '🧑‍🦼‍➡' => 'persona en silla de ruedas eléctrica: hacia la derecha',
    '👨‍🦼‍➡' => 'hombre en silla de ruedas eléctrica: hacia la derecha',
    '👩‍🦼‍➡' => 'mujer en silla de ruedas eléctrica: hacia la derecha',
    '🧑‍🦽‍➡' => 'persona en silla de ruedas manual: hacia la derecha',
    '👨‍🦽‍➡' => 'hombre en silla de ruedas manual: hacia la derecha',
    '👩‍🦽‍➡' => 'mujer en silla de ruedas manual: hacia la derecha',
    '🏃‍♀‍➡' => 'mujer corriendo: hacia la derecha',
    '🏃‍♂‍➡' => 'hombre corriendo: hacia la derecha',
    '👩‍❤‍👨' => 'pareja enamorada: mujer y hombre',
    '👨‍❤‍👨' => 'pareja enamorada: hombre y hombre',
    '👩‍❤‍👩' => 'pareja enamorada: mujer y mujer',
    '👨‍👩‍👦' => 'familia: hombre, mujer, niño',
    '👨‍👩‍👧' => 'familia: hombre, mujer, niña',
    '👨‍👨‍👦' => 'familia: hombre, hombre, niño',
    '👨‍👨‍👧' => 'familia: hombre, hombre, niña',
    '👩‍👩‍👦' => 'familia: mujer, mujer, niño',
    '👩‍👩‍👧' => 'familia: mujer, mujer, niña',
    '👨‍👦‍👦' => 'familia: hombre, niño, niño',
    '👨‍👧‍👦' => 'familia: hombre, niña, niño',
    '👨‍👧‍👧' => 'familia: hombre, niña, niña',
    '👩‍👦‍👦' => 'familia: mujer, niño, niño',
    '👩‍👧‍👦' => 'familia: mujer, niña, niño',
    '👩‍👧‍👧' => 'familia: mujer, niña, niña',
    '🧑‍🤝‍🧑' => 'dos personas de la mano',
    '🧑‍🧑‍🧒' => 'familia: adulto, adulto, niño',
    '🧑‍🧒‍🧒' => 'familia: adulto, niño, niño',
    '🧑🏻‍🦰' => 'persona adulta: tono de piel claro y pelo pelirrojo',
    '🧑🏼‍🦰' => 'persona adulta: tono de piel claro medio y pelo pelirrojo',
    '🧑🏽‍🦰' => 'persona adulta: tono de piel medio y pelo pelirrojo',
    '🧑🏾‍🦰' => 'persona adulta: tono de piel oscuro medio y pelo pelirrojo',
    '🧑🏿‍🦰' => 'persona adulta: tono de piel oscuro y pelo pelirrojo',
    '🧑🏻‍🦱' => 'persona adulta: tono de piel claro y pelo rizado',
    '🧑🏼‍🦱' => 'persona adulta: tono de piel claro medio y pelo rizado',
    '🧑🏽‍🦱' => 'persona adulta: tono de piel medio y pelo rizado',
    '🧑🏾‍🦱' => 'persona adulta: tono de piel oscuro medio y pelo rizado',
    '🧑🏿‍🦱' => 'persona adulta: tono de piel oscuro y pelo rizado',
    '🧑🏻‍🦳' => 'persona adulta: tono de piel claro y pelo blanco',
    '🧑🏼‍🦳' => 'persona adulta: tono de piel claro medio y pelo blanco',
    '🧑🏽‍🦳' => 'persona adulta: tono de piel medio y pelo blanco',
    '🧑🏾‍🦳' => 'persona adulta: tono de piel oscuro medio y pelo blanco',
    '🧑🏿‍🦳' => 'persona adulta: tono de piel oscuro y pelo blanco',
    '🧑🏻‍🦲' => 'persona adulta: tono de piel claro y sin pelo',
    '🧑🏼‍🦲' => 'persona adulta: tono de piel claro medio y sin pelo',
    '🧑🏽‍🦲' => 'persona adulta: tono de piel medio y sin pelo',
    '🧑🏾‍🦲' => 'persona adulta: tono de piel oscuro medio y sin pelo',
    '🧑🏿‍🦲' => 'persona adulta: tono de piel oscuro y sin pelo',
    '🧑🏻‍🩰' => 'bailarina de ballet: tono de piel claro',
    '🧑🏼‍🩰' => 'bailarina de ballet: tono de piel claro medio',
    '🧑🏽‍🩰' => 'bailarina de ballet: tono de piel medio',
    '🧑🏾‍🩰' => 'bailarina de ballet: tono de piel oscuro medio',
    '🧑🏿‍🩰' => 'bailarina de ballet: tono de piel oscuro',
    '🧔🏻‍♂' => 'hombre: tono de piel claro y barba',
    '🧔🏼‍♂' => 'hombre: tono de piel claro medio y barba',
    '🧔🏽‍♂' => 'hombre: tono de piel medio y barba',
    '🧔🏾‍♂' => 'hombre: tono de piel oscuro medio y barba',
    '🧔🏿‍♂' => 'hombre: tono de piel oscuro y barba',
    '👱🏻‍♂' => 'hombre rubio: tono de piel claro',
    '👱🏼‍♂' => 'hombre rubio: tono de piel claro medio',
    '👱🏽‍♂' => 'hombre rubio: tono de piel medio',
    '👱🏾‍♂' => 'hombre rubio: tono de piel oscuro medio',
    '👱🏿‍♂' => 'hombre rubio: tono de piel oscuro',
    '👨🏻‍🦰' => 'hombre: tono de piel claro y pelo pelirrojo',
    '👨🏼‍🦰' => 'hombre: tono de piel claro medio y pelo pelirrojo',
    '👨🏽‍🦰' => 'hombre: tono de piel medio y pelo pelirrojo',
    '👨🏾‍🦰' => 'hombre: tono de piel oscuro medio y pelo pelirrojo',
    '👨🏿‍🦰' => 'hombre: tono de piel oscuro y pelo pelirrojo',
    '👨🏻‍🦱' => 'hombre: tono de piel claro y pelo rizado',
    '👨🏼‍🦱' => 'hombre: tono de piel claro medio y pelo rizado',
    '👨🏽‍🦱' => 'hombre: tono de piel medio y pelo rizado',
    '👨🏾‍🦱' => 'hombre: tono de piel oscuro medio y pelo rizado',
    '👨🏿‍🦱' => 'hombre: tono de piel oscuro y pelo rizado',
    '👨🏻‍🦳' => 'hombre: tono de piel claro y pelo blanco',
    '👨🏼‍🦳' => 'hombre: tono de piel claro medio y pelo blanco',
    '👨🏽‍🦳' => 'hombre: tono de piel medio y pelo blanco',
    '👨🏾‍🦳' => 'hombre: tono de piel oscuro medio y pelo blanco',
    '👨🏿‍🦳' => 'hombre: tono de piel oscuro y pelo blanco',
    '👨🏻‍🦲' => 'hombre: tono de piel claro y sin pelo',
    '👨🏼‍🦲' => 'hombre: tono de piel claro medio y sin pelo',
    '👨🏽‍🦲' => 'hombre: tono de piel medio y sin pelo',
    '👨🏾‍🦲' => 'hombre: tono de piel oscuro medio y sin pelo',
    '👨🏿‍🦲' => 'hombre: tono de piel oscuro y sin pelo',
    '🧔🏻‍♀' => 'mujer: tono de piel claro y barba',
    '🧔🏼‍♀' => 'mujer: tono de piel claro medio y barba',
    '🧔🏽‍♀' => 'mujer: tono de piel medio y barba',
    '🧔🏾‍♀' => 'mujer: tono de piel oscuro medio y barba',
    '🧔🏿‍♀' => 'mujer: tono de piel oscuro y barba',
    '👱🏻‍♀' => 'mujer rubia: tono de piel claro',
    '👱🏼‍♀' => 'mujer rubia: tono de piel claro medio',
    '👱🏽‍♀' => 'mujer rubia: tono de piel medio',
    '👱🏾‍♀' => 'mujer rubia: tono de piel oscuro medio',
    '👱🏿‍♀' => 'mujer rubia: tono de piel oscuro',
    '👩🏻‍🦰' => 'mujer: tono de piel claro y pelo pelirrojo',
    '👩🏼‍🦰' => 'mujer: tono de piel claro medio y pelo pelirrojo',
    '👩🏽‍🦰' => 'mujer: tono de piel medio y pelo pelirrojo',
    '👩🏾‍🦰' => 'mujer: tono de piel oscuro medio y pelo pelirrojo',
    '👩🏿‍🦰' => 'mujer: tono de piel oscuro y pelo pelirrojo',
    '👩🏻‍🦱' => 'mujer: tono de piel claro y pelo rizado',
    '👩🏼‍🦱' => 'mujer: tono de piel claro medio y pelo rizado',
    '👩🏽‍🦱' => 'mujer: tono de piel medio y pelo rizado',
    '👩🏾‍🦱' => 'mujer: tono de piel oscuro medio y pelo rizado',
    '👩🏿‍🦱' => 'mujer: tono de piel oscuro y pelo rizado',
    '👩🏻‍🦳' => 'mujer: tono de piel claro y pelo blanco',
    '👩🏼‍🦳' => 'mujer: tono de piel claro medio y pelo blanco',
    '👩🏽‍🦳' => 'mujer: tono de piel medio y pelo blanco',
    '👩🏾‍🦳' => 'mujer: tono de piel oscuro medio y pelo blanco',
    '👩🏿‍🦳' => 'mujer: tono de piel oscuro y pelo blanco',
    '👩🏻‍🦲' => 'mujer: tono de piel claro y sin pelo',
    '👩🏼‍🦲' => 'mujer: tono de piel claro medio y sin pelo',
    '👩🏽‍🦲' => 'mujer: tono de piel medio y sin pelo',
    '👩🏾‍🦲' => 'mujer: tono de piel oscuro medio y sin pelo',
    '👩🏿‍🦲' => 'mujer: tono de piel oscuro y sin pelo',
    '🙍🏻‍♂' => 'hombre frunciendo el ceño: tono de piel claro',
    '🙍🏼‍♂' => 'hombre frunciendo el ceño: tono de piel claro medio',
    '🙍🏽‍♂' => 'hombre frunciendo el ceño: tono de piel medio',
    '🙍🏾‍♂' => 'hombre frunciendo el ceño: tono de piel oscuro medio',
    '🙍🏿‍♂' => 'hombre frunciendo el ceño: tono de piel oscuro',
    '🙍🏻‍♀' => 'mujer frunciendo el ceño: tono de piel claro',
    '🙍🏼‍♀' => 'mujer frunciendo el ceño: tono de piel claro medio',
    '🙍🏽‍♀' => 'mujer frunciendo el ceño: tono de piel medio',
    '🙍🏾‍♀' => 'mujer frunciendo el ceño: tono de piel oscuro medio',
    '🙍🏿‍♀' => 'mujer frunciendo el ceño: tono de piel oscuro',
    '🙎🏻‍♂' => 'hombre haciendo pucheros: tono de piel claro',
    '🙎🏼‍♂' => 'hombre haciendo pucheros: tono de piel claro medio',
    '🙎🏽‍♂' => 'hombre haciendo pucheros: tono de piel medio',
    '🙎🏾‍♂' => 'hombre haciendo pucheros: tono de piel oscuro medio',
    '🙎🏿‍♂' => 'hombre haciendo pucheros: tono de piel oscuro',
    '🙎🏻‍♀' => 'mujer haciendo pucheros: tono de piel claro',
    '🙎🏼‍♀' => 'mujer haciendo pucheros: tono de piel claro medio',
    '🙎🏽‍♀' => 'mujer haciendo pucheros: tono de piel medio',
    '🙎🏾‍♀' => 'mujer haciendo pucheros: tono de piel oscuro medio',
    '🙎🏿‍♀' => 'mujer haciendo pucheros: tono de piel oscuro',
    '🙅🏻‍♂' => 'hombre haciendo el gesto de "no": tono de piel claro',
    '🙅🏼‍♂' => 'hombre haciendo el gesto de "no": tono de piel claro medio',
    '🙅🏽‍♂' => 'hombre haciendo el gesto de "no": tono de piel medio',
    '🙅🏾‍♂' => 'hombre haciendo el gesto de "no": tono de piel oscuro medio',
    '🙅🏿‍♂' => 'hombre haciendo el gesto de "no": tono de piel oscuro',
    '🙅🏻‍♀' => 'mujer haciendo el gesto de "no": tono de piel claro',
    '🙅🏼‍♀' => 'mujer haciendo el gesto de "no": tono de piel claro medio',
    '🙅🏽‍♀' => 'mujer haciendo el gesto de "no": tono de piel medio',
    '🙅🏾‍♀' => 'mujer haciendo el gesto de "no": tono de piel oscuro medio',
    '🙅🏿‍♀' => 'mujer haciendo el gesto de "no": tono de piel oscuro',
    '🙆🏻‍♂' => 'hombre haciendo el gesto de "de acuerdo": tono de piel claro',
    '🙆🏼‍♂' => 'hombre haciendo el gesto de "de acuerdo": tono de piel claro medio',
    '🙆🏽‍♂' => 'hombre haciendo el gesto de "de acuerdo": tono de piel medio',
    '🙆🏾‍♂' => 'hombre haciendo el gesto de "de acuerdo": tono de piel oscuro medio',
    '🙆🏿‍♂' => 'hombre haciendo el gesto de "de acuerdo": tono de piel oscuro',
    '🙆🏻‍♀' => 'mujer haciendo el gesto de "de acuerdo": tono de piel claro',
    '🙆🏼‍♀' => 'mujer haciendo el gesto de "de acuerdo": tono de piel claro medio',
    '🙆🏽‍♀' => 'mujer haciendo el gesto de "de acuerdo": tono de piel medio',
    '🙆🏾‍♀' => 'mujer haciendo el gesto de "de acuerdo": tono de piel oscuro medio',
    '🙆🏿‍♀' => 'mujer haciendo el gesto de "de acuerdo": tono de piel oscuro',
    '💁🏻‍♂' => 'empleado de mostrador de información: tono de piel claro',
    '💁🏼‍♂' => 'empleado de mostrador de información: tono de piel claro medio',
    '💁🏽‍♂' => 'empleado de mostrador de información: tono de piel medio',
    '💁🏾‍♂' => 'empleado de mostrador de información: tono de piel oscuro medio',
    '💁🏿‍♂' => 'empleado de mostrador de información: tono de piel oscuro',
    '💁🏻‍♀' => 'empleada de mostrador de información: tono de piel claro',
    '💁🏼‍♀' => 'empleada de mostrador de información: tono de piel claro medio',
    '💁🏽‍♀' => 'empleada de mostrador de información: tono de piel medio',
    '💁🏾‍♀' => 'empleada de mostrador de información: tono de piel oscuro medio',
    '💁🏿‍♀' => 'empleada de mostrador de información: tono de piel oscuro',
    '🙋🏻‍♂' => 'hombre con la mano levantada: tono de piel claro',
    '🙋🏼‍♂' => 'hombre con la mano levantada: tono de piel claro medio',
    '🙋🏽‍♂' => 'hombre con la mano levantada: tono de piel medio',
    '🙋🏾‍♂' => 'hombre con la mano levantada: tono de piel oscuro medio',
    '🙋🏿‍♂' => 'hombre con la mano levantada: tono de piel oscuro',
    '🙋🏻‍♀' => 'mujer con la mano levantada: tono de piel claro',
    '🙋🏼‍♀' => 'mujer con la mano levantada: tono de piel claro medio',
    '🙋🏽‍♀' => 'mujer con la mano levantada: tono de piel medio',
    '🙋🏾‍♀' => 'mujer con la mano levantada: tono de piel oscuro medio',
    '🙋🏿‍♀' => 'mujer con la mano levantada: tono de piel oscuro',
    '🧏🏻‍♂' => 'hombre sordo: tono de piel claro',
    '🧏🏼‍♂' => 'hombre sordo: tono de piel claro medio',
    '🧏🏽‍♂' => 'hombre sordo: tono de piel medio',
    '🧏🏾‍♂' => 'hombre sordo: tono de piel oscuro medio',
    '🧏🏿‍♂' => 'hombre sordo: tono de piel oscuro',
    '🧏🏻‍♀' => 'mujer sorda: tono de piel claro',
    '🧏🏼‍♀' => 'mujer sorda: tono de piel claro medio',
    '🧏🏽‍♀' => 'mujer sorda: tono de piel medio',
    '🧏🏾‍♀' => 'mujer sorda: tono de piel oscuro medio',
    '🧏🏿‍♀' => 'mujer sorda: tono de piel oscuro',
    '🙇🏻‍♂' => 'hombre haciendo una reverencia: tono de piel claro',
    '🙇🏼‍♂' => 'hombre haciendo una reverencia: tono de piel claro medio',
    '🙇🏽‍♂' => 'hombre haciendo una reverencia: tono de piel medio',
    '🙇🏾‍♂' => 'hombre haciendo una reverencia: tono de piel oscuro medio',
    '🙇🏿‍♂' => 'hombre haciendo una reverencia: tono de piel oscuro',
    '🙇🏻‍♀' => 'mujer haciendo una reverencia: tono de piel claro',
    '🙇🏼‍♀' => 'mujer haciendo una reverencia: tono de piel claro medio',
    '🙇🏽‍♀' => 'mujer haciendo una reverencia: tono de piel medio',
    '🙇🏾‍♀' => 'mujer haciendo una reverencia: tono de piel oscuro medio',
    '🙇🏿‍♀' => 'mujer haciendo una reverencia: tono de piel oscuro',
    '🤦🏻‍♂' => 'hombre con la mano en la frente: tono de piel claro',
    '🤦🏼‍♂' => 'hombre con la mano en la frente: tono de piel claro medio',
    '🤦🏽‍♂' => 'hombre con la mano en la frente: tono de piel medio',
    '🤦🏾‍♂' => 'hombre con la mano en la frente: tono de piel oscuro medio',
    '🤦🏿‍♂' => 'hombre con la mano en la frente: tono de piel oscuro',
    '🤦🏻‍♀' => 'mujer con la mano en la frente: tono de piel claro',
    '🤦🏼‍♀' => 'mujer con la mano en la frente: tono de piel claro medio',
    '🤦🏽‍♀' => 'mujer con la mano en la frente: tono de piel medio',
    '🤦🏾‍♀' => 'mujer con la mano en la frente: tono de piel oscuro medio',
    '🤦🏿‍♀' => 'mujer con la mano en la frente: tono de piel oscuro',
    '🤷🏻‍♂' => 'hombre encogido de hombros: tono de piel claro',
    '🤷🏼‍♂' => 'hombre encogido de hombros: tono de piel claro medio',
    '🤷🏽‍♂' => 'hombre encogido de hombros: tono de piel medio',
    '🤷🏾‍♂' => 'hombre encogido de hombros: tono de piel oscuro medio',
    '🤷🏿‍♂' => 'hombre encogido de hombros: tono de piel oscuro',
    '🤷🏻‍♀' => 'mujer encogida de hombros: tono de piel claro',
    '🤷🏼‍♀' => 'mujer encogida de hombros: tono de piel claro medio',
    '🤷🏽‍♀' => 'mujer encogida de hombros: tono de piel medio',
    '🤷🏾‍♀' => 'mujer encogida de hombros: tono de piel oscuro medio',
    '🤷🏿‍♀' => 'mujer encogida de hombros: tono de piel oscuro',
    '🧑🏻‍⚕' => 'profesional sanitario: tono de piel claro',
    '🧑🏼‍⚕' => 'profesional sanitario: tono de piel claro medio',
    '🧑🏽‍⚕' => 'profesional sanitario: tono de piel medio',
    '🧑🏾‍⚕' => 'profesional sanitario: tono de piel oscuro medio',
    '🧑🏿‍⚕' => 'profesional sanitario: tono de piel oscuro',
    '👨🏻‍⚕' => 'profesional sanitario hombre: tono de piel claro',
    '👨🏼‍⚕' => 'profesional sanitario hombre: tono de piel claro medio',
    '👨🏽‍⚕' => 'profesional sanitario hombre: tono de piel medio',
    '👨🏾‍⚕' => 'profesional sanitario hombre: tono de piel oscuro medio',
    '👨🏿‍⚕' => 'profesional sanitario hombre: tono de piel oscuro',
    '👩🏻‍⚕' => 'profesional sanitario mujer: tono de piel claro',
    '👩🏼‍⚕' => 'profesional sanitario mujer: tono de piel claro medio',
    '👩🏽‍⚕' => 'profesional sanitario mujer: tono de piel medio',
    '👩🏾‍⚕' => 'profesional sanitario mujer: tono de piel oscuro medio',
    '👩🏿‍⚕' => 'profesional sanitario mujer: tono de piel oscuro',
    '🧑🏻‍🎓' => 'estudiante: tono de piel claro',
    '🧑🏼‍🎓' => 'estudiante: tono de piel claro medio',
    '🧑🏽‍🎓' => 'estudiante: tono de piel medio',
    '🧑🏾‍🎓' => 'estudiante: tono de piel oscuro medio',
    '🧑🏿‍🎓' => 'estudiante: tono de piel oscuro',
    '👨🏻‍🎓' => 'estudiante hombre: tono de piel claro',
    '👨🏼‍🎓' => 'estudiante hombre: tono de piel claro medio',
    '👨🏽‍🎓' => 'estudiante hombre: tono de piel medio',
    '👨🏾‍🎓' => 'estudiante hombre: tono de piel oscuro medio',
    '👨🏿‍🎓' => 'estudiante hombre: tono de piel oscuro',
    '👩🏻‍🎓' => 'estudiante mujer: tono de piel claro',
    '👩🏼‍🎓' => 'estudiante mujer: tono de piel claro medio',
    '👩🏽‍🎓' => 'estudiante mujer: tono de piel medio',
    '👩🏾‍🎓' => 'estudiante mujer: tono de piel oscuro medio',
    '👩🏿‍🎓' => 'estudiante mujer: tono de piel oscuro',
    '🧑🏻‍🏫' => 'docente: tono de piel claro',
    '🧑🏼‍🏫' => 'docente: tono de piel claro medio',
    '🧑🏽‍🏫' => 'docente: tono de piel medio',
    '🧑🏾‍🏫' => 'docente: tono de piel oscuro medio',
    '🧑🏿‍🏫' => 'docente: tono de piel oscuro',
    '👨🏻‍🏫' => 'docente hombre: tono de piel claro',
    '👨🏼‍🏫' => 'docente hombre: tono de piel claro medio',
    '👨🏽‍🏫' => 'docente hombre: tono de piel medio',
    '👨🏾‍🏫' => 'docente hombre: tono de piel oscuro medio',
    '👨🏿‍🏫' => 'docente hombre: tono de piel oscuro',
    '👩🏻‍🏫' => 'docente mujer: tono de piel claro',
    '👩🏼‍🏫' => 'docente mujer: tono de piel claro medio',
    '👩🏽‍🏫' => 'docente mujer: tono de piel medio',
    '👩🏾‍🏫' => 'docente mujer: tono de piel oscuro medio',
    '👩🏿‍🏫' => 'docente mujer: tono de piel oscuro',
    '🧑🏻‍⚖' => 'fiscal: tono de piel claro',
    '🧑🏼‍⚖' => 'fiscal: tono de piel claro medio',
    '🧑🏽‍⚖' => 'fiscal: tono de piel medio',
    '🧑🏾‍⚖' => 'fiscal: tono de piel oscuro medio',
    '🧑🏿‍⚖' => 'fiscal: tono de piel oscuro',
    '👨🏻‍⚖' => 'fiscal hombre: tono de piel claro',
    '👨🏼‍⚖' => 'fiscal hombre: tono de piel claro medio',
    '👨🏽‍⚖' => 'fiscal hombre: tono de piel medio',
    '👨🏾‍⚖' => 'fiscal hombre: tono de piel oscuro medio',
    '👨🏿‍⚖' => 'fiscal hombre: tono de piel oscuro',
    '👩🏻‍⚖' => 'fiscal mujer: tono de piel claro',
    '👩🏼‍⚖' => 'fiscal mujer: tono de piel claro medio',
    '👩🏽‍⚖' => 'fiscal mujer: tono de piel medio',
    '👩🏾‍⚖' => 'fiscal mujer: tono de piel oscuro medio',
    '👩🏿‍⚖' => 'fiscal mujer: tono de piel oscuro',
    '🧑🏻‍🌾' => 'profesional de la agricultura: tono de piel claro',
    '🧑🏼‍🌾' => 'profesional de la agricultura: tono de piel claro medio',
    '🧑🏽‍🌾' => 'profesional de la agricultura: tono de piel medio',
    '🧑🏾‍🌾' => 'profesional de la agricultura: tono de piel oscuro medio',
    '🧑🏿‍🌾' => 'profesional de la agricultura: tono de piel oscuro',
    '👨🏻‍🌾' => 'profesional de la agricultura hombre: tono de piel claro',
    '👨🏼‍🌾' => 'profesional de la agricultura hombre: tono de piel claro medio',
    '👨🏽‍🌾' => 'profesional de la agricultura hombre: tono de piel medio',
    '👨🏾‍🌾' => 'profesional de la agricultura hombre: tono de piel oscuro medio',
    '👨🏿‍🌾' => 'profesional de la agricultura hombre: tono de piel oscuro',
    '👩🏻‍🌾' => 'profesional de la agricultura mujer: tono de piel claro',
    '👩🏼‍🌾' => 'profesional de la agricultura mujer: tono de piel claro medio',
    '👩🏽‍🌾' => 'profesional de la agricultura mujer: tono de piel medio',
    '👩🏾‍🌾' => 'profesional de la agricultura mujer: tono de piel oscuro medio',
    '👩🏿‍🌾' => 'profesional de la agricultura mujer: tono de piel oscuro',
    '🧑🏻‍🍳' => 'chef: tono de piel claro',
    '🧑🏼‍🍳' => 'chef: tono de piel claro medio',
    '🧑🏽‍🍳' => 'chef: tono de piel medio',
    '🧑🏾‍🍳' => 'chef: tono de piel oscuro medio',
    '🧑🏿‍🍳' => 'chef: tono de piel oscuro',
    '👨🏻‍🍳' => 'chef hombre: tono de piel claro',
    '👨🏼‍🍳' => 'chef hombre: tono de piel claro medio',
    '👨🏽‍🍳' => 'chef hombre: tono de piel medio',
    '👨🏾‍🍳' => 'chef hombre: tono de piel oscuro medio',
    '👨🏿‍🍳' => 'chef hombre: tono de piel oscuro',
    '👩🏻‍🍳' => 'chef mujer: tono de piel claro',
    '👩🏼‍🍳' => 'chef mujer: tono de piel claro medio',
    '👩🏽‍🍳' => 'chef mujer: tono de piel medio',
    '👩🏾‍🍳' => 'chef mujer: tono de piel oscuro medio',
    '👩🏿‍🍳' => 'chef mujer: tono de piel oscuro',
    '🧑🏻‍🔧' => 'profesional de la mecánica: tono de piel claro',
    '🧑🏼‍🔧' => 'profesional de la mecánica: tono de piel claro medio',
    '🧑🏽‍🔧' => 'profesional de la mecánica: tono de piel medio',
    '🧑🏾‍🔧' => 'profesional de la mecánica: tono de piel oscuro medio',
    '🧑🏿‍🔧' => 'profesional de la mecánica: tono de piel oscuro',
    '👨🏻‍🔧' => 'profesional de la mecánica hombre: tono de piel claro',
    '👨🏼‍🔧' => 'profesional de la mecánica hombre: tono de piel claro medio',
    '👨🏽‍🔧' => 'profesional de la mecánica hombre: tono de piel medio',
    '👨🏾‍🔧' => 'profesional de la mecánica hombre: tono de piel oscuro medio',
    '👨🏿‍🔧' => 'profesional de la mecánica hombre: tono de piel oscuro',
    '👩🏻‍🔧' => 'profesional de la mecánica mujer: tono de piel claro',
    '👩🏼‍🔧' => 'profesional de la mecánica mujer: tono de piel claro medio',
    '👩🏽‍🔧' => 'profesional de la mecánica mujer: tono de piel medio',
    '👩🏾‍🔧' => 'profesional de la mecánica mujer: tono de piel oscuro medio',
    '👩🏿‍🔧' => 'profesional de la mecánica mujer: tono de piel oscuro',
    '🧑🏻‍🏭' => 'profesional industrial: tono de piel claro',
    '🧑🏼‍🏭' => 'profesional industrial: tono de piel claro medio',
    '🧑🏽‍🏭' => 'profesional industrial: tono de piel medio',
    '🧑🏾‍🏭' => 'profesional industrial: tono de piel oscuro medio',
    '🧑🏿‍🏭' => 'profesional industrial: tono de piel oscuro',
    '👨🏻‍🏭' => 'profesional industrial hombre: tono de piel claro',
    '👨🏼‍🏭' => 'profesional industrial hombre: tono de piel claro medio',
    '👨🏽‍🏭' => 'profesional industrial hombre: tono de piel medio',
    '👨🏾‍🏭' => 'profesional industrial hombre: tono de piel oscuro medio',
    '👨🏿‍🏭' => 'profesional industrial hombre: tono de piel oscuro',
    '👩🏻‍🏭' => 'profesional industrial mujer: tono de piel claro',
    '👩🏼‍🏭' => 'profesional industrial mujer: tono de piel claro medio',
    '👩🏽‍🏭' => 'profesional industrial mujer: tono de piel medio',
    '👩🏾‍🏭' => 'profesional industrial mujer: tono de piel oscuro medio',
    '👩🏿‍🏭' => 'profesional industrial mujer: tono de piel oscuro',
    '🧑🏻‍💼' => 'oficinista: tono de piel claro',
    '🧑🏼‍💼' => 'oficinista: tono de piel claro medio',
    '🧑🏽‍💼' => 'oficinista: tono de piel medio',
    '🧑🏾‍💼' => 'oficinista: tono de piel oscuro medio',
    '🧑🏿‍💼' => 'oficinista: tono de piel oscuro',
    '👨🏻‍💼' => 'oficinista hombre: tono de piel claro',
    '👨🏼‍💼' => 'oficinista hombre: tono de piel claro medio',
    '👨🏽‍💼' => 'oficinista hombre: tono de piel medio',
    '👨🏾‍💼' => 'oficinista hombre: tono de piel oscuro medio',
    '👨🏿‍💼' => 'oficinista hombre: tono de piel oscuro',
    '👩🏻‍💼' => 'oficinista mujer: tono de piel claro',
    '👩🏼‍💼' => 'oficinista mujer: tono de piel claro medio',
    '👩🏽‍💼' => 'oficinista mujer: tono de piel medio',
    '👩🏾‍💼' => 'oficinista mujer: tono de piel oscuro medio',
    '👩🏿‍💼' => 'oficinista mujer: tono de piel oscuro',
    '🧑🏻‍🔬' => 'profesional de la ciencia: tono de piel claro',
    '🧑🏼‍🔬' => 'profesional de la ciencia: tono de piel claro medio',
    '🧑🏽‍🔬' => 'profesional de la ciencia: tono de piel medio',
    '🧑🏾‍🔬' => 'profesional de la ciencia: tono de piel oscuro medio',
    '🧑🏿‍🔬' => 'profesional de la ciencia: tono de piel oscuro',
    '👨🏻‍🔬' => 'profesional de la ciencia hombre: tono de piel claro',
    '👨🏼‍🔬' => 'profesional de la ciencia hombre: tono de piel claro medio',
    '👨🏽‍🔬' => 'profesional de la ciencia hombre: tono de piel medio',
    '👨🏾‍🔬' => 'profesional de la ciencia hombre: tono de piel oscuro medio',
    '👨🏿‍🔬' => 'profesional de la ciencia hombre: tono de piel oscuro',
    '👩🏻‍🔬' => 'profesional de la ciencia mujer: tono de piel claro',
    '👩🏼‍🔬' => 'profesional de la ciencia mujer: tono de piel claro medio',
    '👩🏽‍🔬' => 'profesional de la ciencia mujer: tono de piel medio',
    '👩🏾‍🔬' => 'profesional de la ciencia mujer: tono de piel oscuro medio',
    '👩🏿‍🔬' => 'profesional de la ciencia mujer: tono de piel oscuro',
    '🧑🏻‍💻' => 'profesional de la tecnología: tono de piel claro',
    '🧑🏼‍💻' => 'profesional de la tecnología: tono de piel claro medio',
    '🧑🏽‍💻' => 'profesional de la tecnología: tono de piel medio',
    '🧑🏾‍💻' => 'profesional de la tecnología: tono de piel oscuro medio',
    '🧑🏿‍💻' => 'profesional de la tecnología: tono de piel oscuro',
    '👨🏻‍💻' => 'profesional de la tecnología hombre: tono de piel claro',
    '👨🏼‍💻' => 'profesional de la tecnología hombre: tono de piel claro medio',
    '👨🏽‍💻' => 'profesional de la tecnología hombre: tono de piel medio',
    '👨🏾‍💻' => 'profesional de la tecnología hombre: tono de piel oscuro medio',
    '👨🏿‍💻' => 'profesional de la tecnología hombre: tono de piel oscuro',
    '👩🏻‍💻' => 'profesional de la tecnología mujer: tono de piel claro',
    '👩🏼‍💻' => 'profesional de la tecnología mujer: tono de piel claro medio',
    '👩🏽‍💻' => 'profesional de la tecnología mujer: tono de piel medio',
    '👩🏾‍💻' => 'profesional de la tecnología mujer: tono de piel oscuro medio',
    '👩🏿‍💻' => 'profesional de la tecnología mujer: tono de piel oscuro',
    '🧑🏻‍🎤' => 'cantante: tono de piel claro',
    '🧑🏼‍🎤' => 'cantante: tono de piel claro medio',
    '🧑🏽‍🎤' => 'cantante: tono de piel medio',
    '🧑🏾‍🎤' => 'cantante: tono de piel oscuro medio',
    '🧑🏿‍🎤' => 'cantante: tono de piel oscuro',
    '👨🏻‍🎤' => 'cantante hombre: tono de piel claro',
    '👨🏼‍🎤' => 'cantante hombre: tono de piel claro medio',
    '👨🏽‍🎤' => 'cantante hombre: tono de piel medio',
    '👨🏾‍🎤' => 'cantante hombre: tono de piel oscuro medio',
    '👨🏿‍🎤' => 'cantante hombre: tono de piel oscuro',
    '👩🏻‍🎤' => 'cantante mujer: tono de piel claro',
    '👩🏼‍🎤' => 'cantante mujer: tono de piel claro medio',
    '👩🏽‍🎤' => 'cantante mujer: tono de piel medio',
    '👩🏾‍🎤' => 'cantante mujer: tono de piel oscuro medio',
    '👩🏿‍🎤' => 'cantante mujer: tono de piel oscuro',
    '🧑🏻‍🎨' => 'artista: tono de piel claro',
    '🧑🏼‍🎨' => 'artista: tono de piel claro medio',
    '🧑🏽‍🎨' => 'artista: tono de piel medio',
    '🧑🏾‍🎨' => 'artista: tono de piel oscuro medio',
    '🧑🏿‍🎨' => 'artista: tono de piel oscuro',
    '👨🏻‍🎨' => 'artista hombre: tono de piel claro',
    '👨🏼‍🎨' => 'artista hombre: tono de piel claro medio',
    '👨🏽‍🎨' => 'artista hombre: tono de piel medio',
    '👨🏾‍🎨' => 'artista hombre: tono de piel oscuro medio',
    '👨🏿‍🎨' => 'artista hombre: tono de piel oscuro',
    '👩🏻‍🎨' => 'artista mujer: tono de piel claro',
    '👩🏼‍🎨' => 'artista mujer: tono de piel claro medio',
    '👩🏽‍🎨' => 'artista mujer: tono de piel medio',
    '👩🏾‍🎨' => 'artista mujer: tono de piel oscuro medio',
    '👩🏿‍🎨' => 'artista mujer: tono de piel oscuro',
    '🧑🏻‍✈' => 'piloto: tono de piel claro',
    '🧑🏼‍✈' => 'piloto: tono de piel claro medio',
    '🧑🏽‍✈' => 'piloto: tono de piel medio',
    '🧑🏾‍✈' => 'piloto: tono de piel oscuro medio',
    '🧑🏿‍✈' => 'piloto: tono de piel oscuro',
    '👨🏻‍✈' => 'piloto hombre: tono de piel claro',
    '👨🏼‍✈' => 'piloto hombre: tono de piel claro medio',
    '👨🏽‍✈' => 'piloto hombre: tono de piel medio',
    '👨🏾‍✈' => 'piloto hombre: tono de piel oscuro medio',
    '👨🏿‍✈' => 'piloto hombre: tono de piel oscuro',
    '👩🏻‍✈' => 'piloto mujer: tono de piel claro',
    '👩🏼‍✈' => 'piloto mujer: tono de piel claro medio',
    '👩🏽‍✈' => 'piloto mujer: tono de piel medio',
    '👩🏾‍✈' => 'piloto mujer: tono de piel oscuro medio',
    '👩🏿‍✈' => 'piloto mujer: tono de piel oscuro',
    '🧑🏻‍🚀' => 'astronauta: tono de piel claro',
    '🧑🏼‍🚀' => 'astronauta: tono de piel claro medio',
    '🧑🏽‍🚀' => 'astronauta: tono de piel medio',
    '🧑🏾‍🚀' => 'astronauta: tono de piel oscuro medio',
    '🧑🏿‍🚀' => 'astronauta: tono de piel oscuro',
    '👨🏻‍🚀' => 'astronauta hombre: tono de piel claro',
    '👨🏼‍🚀' => 'astronauta hombre: tono de piel claro medio',
    '👨🏽‍🚀' => 'astronauta hombre: tono de piel medio',
    '👨🏾‍🚀' => 'astronauta hombre: tono de piel oscuro medio',
    '👨🏿‍🚀' => 'astronauta hombre: tono de piel oscuro',
    '👩🏻‍🚀' => 'astronauta mujer: tono de piel claro',
    '👩🏼‍🚀' => 'astronauta mujer: tono de piel claro medio',
    '👩🏽‍🚀' => 'astronauta mujer: tono de piel medio',
    '👩🏾‍🚀' => 'astronauta mujer: tono de piel oscuro medio',
    '👩🏿‍🚀' => 'astronauta mujer: tono de piel oscuro',
    '🧑🏻‍🚒' => 'bombero: tono de piel claro',
    '🧑🏼‍🚒' => 'bombero: tono de piel claro medio',
    '🧑🏽‍🚒' => 'bombero: tono de piel medio',
    '🧑🏾‍🚒' => 'bombero: tono de piel oscuro medio',
    '🧑🏿‍🚒' => 'bombero: tono de piel oscuro',
    '👨🏻‍🚒' => 'bombero hombre: tono de piel claro',
    '👨🏼‍🚒' => 'bombero hombre: tono de piel claro medio',
    '👨🏽‍🚒' => 'bombero hombre: tono de piel medio',
    '👨🏾‍🚒' => 'bombero hombre: tono de piel oscuro medio',
    '👨🏿‍🚒' => 'bombero hombre: tono de piel oscuro',
    '👩🏻‍🚒' => 'bombera: tono de piel claro',
    '👩🏼‍🚒' => 'bombera: tono de piel claro medio',
    '👩🏽‍🚒' => 'bombera: tono de piel medio',
    '👩🏾‍🚒' => 'bombera: tono de piel oscuro medio',
    '👩🏿‍🚒' => 'bombera: tono de piel oscuro',
    '👮🏻‍♂' => 'agente de policía hombre: tono de piel claro',
    '👮🏼‍♂' => 'agente de policía hombre: tono de piel claro medio',
    '👮🏽‍♂' => 'agente de policía hombre: tono de piel medio',
    '👮🏾‍♂' => 'agente de policía hombre: tono de piel oscuro medio',
    '👮🏿‍♂' => 'agente de policía hombre: tono de piel oscuro',
    '👮🏻‍♀' => 'agente de policía mujer: tono de piel claro',
    '👮🏼‍♀' => 'agente de policía mujer: tono de piel claro medio',
    '👮🏽‍♀' => 'agente de policía mujer: tono de piel medio',
    '👮🏾‍♀' => 'agente de policía mujer: tono de piel oscuro medio',
    '👮🏿‍♀' => 'agente de policía mujer: tono de piel oscuro',
    '🕵🏻‍♂' => 'detective hombre: tono de piel claro',
    '🕵🏼‍♂' => 'detective hombre: tono de piel claro medio',
    '🕵🏽‍♂' => 'detective hombre: tono de piel medio',
    '🕵🏾‍♂' => 'detective hombre: tono de piel oscuro medio',
    '🕵🏿‍♂' => 'detective hombre: tono de piel oscuro',
    '🕵🏻‍♀' => 'detective mujer: tono de piel claro',
    '🕵🏼‍♀' => 'detective mujer: tono de piel claro medio',
    '🕵🏽‍♀' => 'detective mujer: tono de piel medio',
    '🕵🏾‍♀' => 'detective mujer: tono de piel oscuro medio',
    '🕵🏿‍♀' => 'detective mujer: tono de piel oscuro',
    '💂🏻‍♂' => 'guardia hombre: tono de piel claro',
    '💂🏼‍♂' => 'guardia hombre: tono de piel claro medio',
    '💂🏽‍♂' => 'guardia hombre: tono de piel medio',
    '💂🏾‍♂' => 'guardia hombre: tono de piel oscuro medio',
    '💂🏿‍♂' => 'guardia hombre: tono de piel oscuro',
    '💂🏻‍♀' => 'guardia mujer: tono de piel claro',
    '💂🏼‍♀' => 'guardia mujer: tono de piel claro medio',
    '💂🏽‍♀' => 'guardia mujer: tono de piel medio',
    '💂🏾‍♀' => 'guardia mujer: tono de piel oscuro medio',
    '💂🏿‍♀' => 'guardia mujer: tono de piel oscuro',
    '👷🏻‍♂' => 'profesional de la construcción hombre: tono de piel claro',
    '👷🏼‍♂' => 'profesional de la construcción hombre: tono de piel claro medio',
    '👷🏽‍♂' => 'profesional de la construcción hombre: tono de piel medio',
    '👷🏾‍♂' => 'profesional de la construcción hombre: tono de piel oscuro medio',
    '👷🏿‍♂' => 'profesional de la construcción hombre: tono de piel oscuro',
    '👷🏻‍♀' => 'profesional de la construcción mujer: tono de piel claro',
    '👷🏼‍♀' => 'profesional de la construcción mujer: tono de piel claro medio',
    '👷🏽‍♀' => 'profesional de la construcción mujer: tono de piel medio',
    '👷🏾‍♀' => 'profesional de la construcción mujer: tono de piel oscuro medio',
    '👷🏿‍♀' => 'profesional de la construcción mujer: tono de piel oscuro',
    '👳🏻‍♂' => 'hombre con turbante: tono de piel claro',
    '👳🏼‍♂' => 'hombre con turbante: tono de piel claro medio',
    '👳🏽‍♂' => 'hombre con turbante: tono de piel medio',
    '👳🏾‍♂' => 'hombre con turbante: tono de piel oscuro medio',
    '👳🏿‍♂' => 'hombre con turbante: tono de piel oscuro',
    '👳🏻‍♀' => 'mujer con turbante: tono de piel claro',
    '👳🏼‍♀' => 'mujer con turbante: tono de piel claro medio',
    '👳🏽‍♀' => 'mujer con turbante: tono de piel medio',
    '👳🏾‍♀' => 'mujer con turbante: tono de piel oscuro medio',
    '👳🏿‍♀' => 'mujer con turbante: tono de piel oscuro',
    '🤵🏻‍♂' => 'hombre con esmoquin: tono de piel claro',
    '🤵🏼‍♂' => 'hombre con esmoquin: tono de piel claro medio',
    '🤵🏽‍♂' => 'hombre con esmoquin: tono de piel medio',
    '🤵🏾‍♂' => 'hombre con esmoquin: tono de piel oscuro medio',
    '🤵🏿‍♂' => 'hombre con esmoquin: tono de piel oscuro',
    '🤵🏻‍♀' => 'mujer con esmoquin: tono de piel claro',
    '🤵🏼‍♀' => 'mujer con esmoquin: tono de piel claro medio',
    '🤵🏽‍♀' => 'mujer con esmoquin: tono de piel medio',
    '🤵🏾‍♀' => 'mujer con esmoquin: tono de piel oscuro medio',
    '🤵🏿‍♀' => 'mujer con esmoquin: tono de piel oscuro',
    '👰🏻‍♂' => 'hombre con velo: tono de piel claro',
    '👰🏼‍♂' => 'hombre con velo: tono de piel claro medio',
    '👰🏽‍♂' => 'hombre con velo: tono de piel medio',
    '👰🏾‍♂' => 'hombre con velo: tono de piel oscuro medio',
    '👰🏿‍♂' => 'hombre con velo: tono de piel oscuro',
    '👰🏻‍♀' => 'mujer con velo: tono de piel claro',
    '👰🏼‍♀' => 'mujer con velo: tono de piel claro medio',
    '👰🏽‍♀' => 'mujer con velo: tono de piel medio',
    '👰🏾‍♀' => 'mujer con velo: tono de piel oscuro medio',
    '👰🏿‍♀' => 'mujer con velo: tono de piel oscuro',
    '👩🏻‍🍼' => 'mujer alimentando a bebé: tono de piel claro',
    '👩🏼‍🍼' => 'mujer alimentando a bebé: tono de piel claro medio',
    '👩🏽‍🍼' => 'mujer alimentando a bebé: tono de piel medio',
    '👩🏾‍🍼' => 'mujer alimentando a bebé: tono de piel oscuro medio',
    '👩🏿‍🍼' => 'mujer alimentando a bebé: tono de piel oscuro',
    '👨🏻‍🍼' => 'hombre alimentando a bebé: tono de piel claro',
    '👨🏼‍🍼' => 'hombre alimentando a bebé: tono de piel claro medio',
    '👨🏽‍🍼' => 'hombre alimentando a bebé: tono de piel medio',
    '👨🏾‍🍼' => 'hombre alimentando a bebé: tono de piel oscuro medio',
    '👨🏿‍🍼' => 'hombre alimentando a bebé: tono de piel oscuro',
    '🧑🏻‍🍼' => 'persona alimentando a bebé: tono de piel claro',
    '🧑🏼‍🍼' => 'persona alimentando a bebé: tono de piel claro medio',
    '🧑🏽‍🍼' => 'persona alimentando a bebé: tono de piel medio',
    '🧑🏾‍🍼' => 'persona alimentando a bebé: tono de piel oscuro medio',
    '🧑🏿‍🍼' => 'persona alimentando a bebé: tono de piel oscuro',
    '🧑🏻‍🎄' => 'Noel: tono de piel claro',
    '🧑🏼‍🎄' => 'Noel: tono de piel claro medio',
    '🧑🏽‍🎄' => 'Noel: tono de piel medio',
    '🧑🏾‍🎄' => 'Noel: tono de piel oscuro medio',
    '🧑🏿‍🎄' => 'Noel: tono de piel oscuro',
    '🦸🏻‍♂' => 'superhéroe: tono de piel claro',
    '🦸🏼‍♂' => 'superhéroe: tono de piel claro medio',
    '🦸🏽‍♂' => 'superhéroe: tono de piel medio',
    '🦸🏾‍♂' => 'superhéroe: tono de piel oscuro medio',
    '🦸🏿‍♂' => 'superhéroe: tono de piel oscuro',
    '🦸🏻‍♀' => 'superheroína: tono de piel claro',
    '🦸🏼‍♀' => 'superheroína: tono de piel claro medio',
    '🦸🏽‍♀' => 'superheroína: tono de piel medio',
    '🦸🏾‍♀' => 'superheroína: tono de piel oscuro medio',
    '🦸🏿‍♀' => 'superheroína: tono de piel oscuro',
    '🦹🏻‍♂' => 'supervillano: tono de piel claro',
    '🦹🏼‍♂' => 'supervillano: tono de piel claro medio',
    '🦹🏽‍♂' => 'supervillano: tono de piel medio',
    '🦹🏾‍♂' => 'supervillano: tono de piel oscuro medio',
    '🦹🏿‍♂' => 'supervillano: tono de piel oscuro',
    '🦹🏻‍♀' => 'supervillana: tono de piel claro',
    '🦹🏼‍♀' => 'supervillana: tono de piel claro medio',
    '🦹🏽‍♀' => 'supervillana: tono de piel medio',
    '🦹🏾‍♀' => 'supervillana: tono de piel oscuro medio',
    '🦹🏿‍♀' => 'supervillana: tono de piel oscuro',
    '🧙🏻‍♂' => 'mago: tono de piel claro',
    '🧙🏼‍♂' => 'mago: tono de piel claro medio',
    '🧙🏽‍♂' => 'mago: tono de piel medio',
    '🧙🏾‍♂' => 'mago: tono de piel oscuro medio',
    '🧙🏿‍♂' => 'mago: tono de piel oscuro',
    '🧙🏻‍♀' => 'maga: tono de piel claro',
    '🧙🏼‍♀' => 'maga: tono de piel claro medio',
    '🧙🏽‍♀' => 'maga: tono de piel medio',
    '🧙🏾‍♀' => 'maga: tono de piel oscuro medio',
    '🧙🏿‍♀' => 'maga: tono de piel oscuro',
    '🧚🏻‍♂' => 'hada hombre: tono de piel claro',
    '🧚🏼‍♂' => 'hada hombre: tono de piel claro medio',
    '🧚🏽‍♂' => 'hada hombre: tono de piel medio',
    '🧚🏾‍♂' => 'hada hombre: tono de piel oscuro medio',
    '🧚🏿‍♂' => 'hada hombre: tono de piel oscuro',
    '🧚🏻‍♀' => 'hada mujer: tono de piel claro',
    '🧚🏼‍♀' => 'hada mujer: tono de piel claro medio',
    '🧚🏽‍♀' => 'hada mujer: tono de piel medio',
    '🧚🏾‍♀' => 'hada mujer: tono de piel oscuro medio',
    '🧚🏿‍♀' => 'hada mujer: tono de piel oscuro',
    '🧛🏻‍♂' => 'vampiro hombre: tono de piel claro',
    '🧛🏼‍♂' => 'vampiro hombre: tono de piel claro medio',
    '🧛🏽‍♂' => 'vampiro hombre: tono de piel medio',
    '🧛🏾‍♂' => 'vampiro hombre: tono de piel oscuro medio',
    '🧛🏿‍♂' => 'vampiro hombre: tono de piel oscuro',
    '🧛🏻‍♀' => 'vampiresa: tono de piel claro',
    '🧛🏼‍♀' => 'vampiresa: tono de piel claro medio',
    '🧛🏽‍♀' => 'vampiresa: tono de piel medio',
    '🧛🏾‍♀' => 'vampiresa: tono de piel oscuro medio',
    '🧛🏿‍♀' => 'vampiresa: tono de piel oscuro',
    '🧜🏻‍♂' => 'sirena hombre: tono de piel claro',
    '🧜🏼‍♂' => 'sirena hombre: tono de piel claro medio',
    '🧜🏽‍♂' => 'sirena hombre: tono de piel medio',
    '🧜🏾‍♂' => 'sirena hombre: tono de piel oscuro medio',
    '🧜🏿‍♂' => 'sirena hombre: tono de piel oscuro',
    '🧜🏻‍♀' => 'sirena: tono de piel claro',
    '🧜🏼‍♀' => 'sirena: tono de piel claro medio',
    '🧜🏽‍♀' => 'sirena: tono de piel medio',
    '🧜🏾‍♀' => 'sirena: tono de piel oscuro medio',
    '🧜🏿‍♀' => 'sirena: tono de piel oscuro',
    '🧝🏻‍♂' => 'elfo hombre: tono de piel claro',
    '🧝🏼‍♂' => 'elfo hombre: tono de piel claro medio',
    '🧝🏽‍♂' => 'elfo hombre: tono de piel medio',
    '🧝🏾‍♂' => 'elfo hombre: tono de piel oscuro medio',
    '🧝🏿‍♂' => 'elfo hombre: tono de piel oscuro',
    '🧝🏻‍♀' => 'elfa: tono de piel claro',
    '🧝🏼‍♀' => 'elfa: tono de piel claro medio',
    '🧝🏽‍♀' => 'elfa: tono de piel medio',
    '🧝🏾‍♀' => 'elfa: tono de piel oscuro medio',
    '🧝🏿‍♀' => 'elfa: tono de piel oscuro',
    '💆🏻‍♂' => 'hombre recibiendo masaje: tono de piel claro',
    '💆🏼‍♂' => 'hombre recibiendo masaje: tono de piel claro medio',
    '💆🏽‍♂' => 'hombre recibiendo masaje: tono de piel medio',
    '💆🏾‍♂' => 'hombre recibiendo masaje: tono de piel oscuro medio',
    '💆🏿‍♂' => 'hombre recibiendo masaje: tono de piel oscuro',
    '💆🏻‍♀' => 'mujer recibiendo masaje: tono de piel claro',
    '💆🏼‍♀' => 'mujer recibiendo masaje: tono de piel claro medio',
    '💆🏽‍♀' => 'mujer recibiendo masaje: tono de piel medio',
    '💆🏾‍♀' => 'mujer recibiendo masaje: tono de piel oscuro medio',
    '💆🏿‍♀' => 'mujer recibiendo masaje: tono de piel oscuro',
    '💇🏻‍♂' => 'hombre cortándose el pelo: tono de piel claro',
    '💇🏼‍♂' => 'hombre cortándose el pelo: tono de piel claro medio',
    '💇🏽‍♂' => 'hombre cortándose el pelo: tono de piel medio',
    '💇🏾‍♂' => 'hombre cortándose el pelo: tono de piel oscuro medio',
    '💇🏿‍♂' => 'hombre cortándose el pelo: tono de piel oscuro',
    '💇🏻‍♀' => 'mujer cortándose el pelo: tono de piel claro',
    '💇🏼‍♀' => 'mujer cortándose el pelo: tono de piel claro medio',
    '💇🏽‍♀' => 'mujer cortándose el pelo: tono de piel medio',
    '💇🏾‍♀' => 'mujer cortándose el pelo: tono de piel oscuro medio',
    '💇🏿‍♀' => 'mujer cortándose el pelo: tono de piel oscuro',
    '🚶🏻‍♂' => 'hombre caminando: tono de piel claro',
    '🚶🏼‍♂' => 'hombre caminando: tono de piel claro medio',
    '🚶🏽‍♂' => 'hombre caminando: tono de piel medio',
    '🚶🏾‍♂' => 'hombre caminando: tono de piel oscuro medio',
    '🚶🏿‍♂' => 'hombre caminando: tono de piel oscuro',
    '🚶🏻‍♀' => 'mujer caminando: tono de piel claro',
    '🚶🏼‍♀' => 'mujer caminando: tono de piel claro medio',
    '🚶🏽‍♀' => 'mujer caminando: tono de piel medio',
    '🚶🏾‍♀' => 'mujer caminando: tono de piel oscuro medio',
    '🚶🏿‍♀' => 'mujer caminando: tono de piel oscuro',
    '🚶🏻‍➡' => 'persona caminando: tono de piel claro y hacia la derecha',
    '🚶🏼‍➡' => 'persona caminando: tono de piel claro medio y hacia la derecha',
    '🚶🏽‍➡' => 'persona caminando: tono de piel medio y hacia la derecha',
    '🚶🏾‍➡' => 'persona caminando: tono de piel oscuro medio y hacia la derecha',
    '🚶🏿‍➡' => 'persona caminando: tono de piel oscuro y hacia la derecha',
    '🧍🏻‍♂' => 'hombre de pie: tono de piel claro',
    '🧍🏼‍♂' => 'hombre de pie: tono de piel claro medio',
    '🧍🏽‍♂' => 'hombre de pie: tono de piel medio',
    '🧍🏾‍♂' => 'hombre de pie: tono de piel oscuro medio',
    '🧍🏿‍♂' => 'hombre de pie: tono de piel oscuro',
    '🧍🏻‍♀' => 'mujer de pie: tono de piel claro',
    '🧍🏼‍♀' => 'mujer de pie: tono de piel claro medio',
    '🧍🏽‍♀' => 'mujer de pie: tono de piel medio',
    '🧍🏾‍♀' => 'mujer de pie: tono de piel oscuro medio',
    '🧍🏿‍♀' => 'mujer de pie: tono de piel oscuro',
    '🧎🏻‍♂' => 'hombre de rodillas: tono de piel claro',
    '🧎🏼‍♂' => 'hombre de rodillas: tono de piel claro medio',
    '🧎🏽‍♂' => 'hombre de rodillas: tono de piel medio',
    '🧎🏾‍♂' => 'hombre de rodillas: tono de piel oscuro medio',
    '🧎🏿‍♂' => 'hombre de rodillas: tono de piel oscuro',
    '🧎🏻‍♀' => 'mujer de rodillas: tono de piel claro',
    '🧎🏼‍♀' => 'mujer de rodillas: tono de piel claro medio',
    '🧎🏽‍♀' => 'mujer de rodillas: tono de piel medio',
    '🧎🏾‍♀' => 'mujer de rodillas: tono de piel oscuro medio',
    '🧎🏿‍♀' => 'mujer de rodillas: tono de piel oscuro',
    '🧎🏻‍➡' => 'persona de rodillas: tono de piel claro y hacia la derecha',
    '🧎🏼‍➡' => 'persona de rodillas: tono de piel claro medio y hacia la derecha',
    '🧎🏽‍➡' => 'persona de rodillas: tono de piel medio y hacia la derecha',
    '🧎🏾‍➡' => 'persona de rodillas: tono de piel oscuro medio y hacia la derecha',
    '🧎🏿‍➡' => 'persona de rodillas: tono de piel oscuro y hacia la derecha',
    '🧑🏻‍🦯' => 'persona con bastón: tono de piel claro',
    '🧑🏼‍🦯' => 'persona con bastón: tono de piel claro medio',
    '🧑🏽‍🦯' => 'persona con bastón: tono de piel medio',
    '🧑🏾‍🦯' => 'persona con bastón: tono de piel oscuro medio',
    '🧑🏿‍🦯' => 'persona con bastón: tono de piel oscuro',
    '👨🏻‍🦯' => 'hombre con bastón: tono de piel claro',
    '👨🏼‍🦯' => 'hombre con bastón: tono de piel claro medio',
    '👨🏽‍🦯' => 'hombre con bastón: tono de piel medio',
    '👨🏾‍🦯' => 'hombre con bastón: tono de piel oscuro medio',
    '👨🏿‍🦯' => 'hombre con bastón: tono de piel oscuro',
    '👩🏻‍🦯' => 'mujer con bastón: tono de piel claro',
    '👩🏼‍🦯' => 'mujer con bastón: tono de piel claro medio',
    '👩🏽‍🦯' => 'mujer con bastón: tono de piel medio',
    '👩🏾‍🦯' => 'mujer con bastón: tono de piel oscuro medio',
    '👩🏿‍🦯' => 'mujer con bastón: tono de piel oscuro',
    '🧑🏻‍🦼' => 'persona en silla de ruedas eléctrica: tono de piel claro',
    '🧑🏼‍🦼' => 'persona en silla de ruedas eléctrica: tono de piel claro medio',
    '🧑🏽‍🦼' => 'persona en silla de ruedas eléctrica: tono de piel medio',
    '🧑🏾‍🦼' => 'persona en silla de ruedas eléctrica: tono de piel oscuro medio',
    '🧑🏿‍🦼' => 'persona en silla de ruedas eléctrica: tono de piel oscuro',
    '👨🏻‍🦼' => 'hombre en silla de ruedas eléctrica: tono de piel claro',
    '👨🏼‍🦼' => 'hombre en silla de ruedas eléctrica: tono de piel claro medio',
    '👨🏽‍🦼' => 'hombre en silla de ruedas eléctrica: tono de piel medio',
    '👨🏾‍🦼' => 'hombre en silla de ruedas eléctrica: tono de piel oscuro medio',
    '👨🏿‍🦼' => 'hombre en silla de ruedas eléctrica: tono de piel oscuro',
    '👩🏻‍🦼' => 'mujer en silla de ruedas eléctrica: tono de piel claro',
    '👩🏼‍🦼' => 'mujer en silla de ruedas eléctrica: tono de piel claro medio',
    '👩🏽‍🦼' => 'mujer en silla de ruedas eléctrica: tono de piel medio',
    '👩🏾‍🦼' => 'mujer en silla de ruedas eléctrica: tono de piel oscuro medio',
    '👩🏿‍🦼' => 'mujer en silla de ruedas eléctrica: tono de piel oscuro',
    '🧑🏻‍🦽' => 'persona en silla de ruedas manual: tono de piel claro',
    '🧑🏼‍🦽' => 'persona en silla de ruedas manual: tono de piel claro medio',
    '🧑🏽‍🦽' => 'persona en silla de ruedas manual: tono de piel medio',
    '🧑🏾‍🦽' => 'persona en silla de ruedas manual: tono de piel oscuro medio',
    '🧑🏿‍🦽' => 'persona en silla de ruedas manual: tono de piel oscuro',
    '👨🏻‍🦽' => 'hombre en silla de ruedas manual: tono de piel claro',
    '👨🏼‍🦽' => 'hombre en silla de ruedas manual: tono de piel claro medio',
    '👨🏽‍🦽' => 'hombre en silla de ruedas manual: tono de piel medio',
    '👨🏾‍🦽' => 'hombre en silla de ruedas manual: tono de piel oscuro medio',
    '👨🏿‍🦽' => 'hombre en silla de ruedas manual: tono de piel oscuro',
    '👩🏻‍🦽' => 'mujer en silla de ruedas manual: tono de piel claro',
    '👩🏼‍🦽' => 'mujer en silla de ruedas manual: tono de piel claro medio',
    '👩🏽‍🦽' => 'mujer en silla de ruedas manual: tono de piel medio',
    '👩🏾‍🦽' => 'mujer en silla de ruedas manual: tono de piel oscuro medio',
    '👩🏿‍🦽' => 'mujer en silla de ruedas manual: tono de piel oscuro',
    '🏃🏻‍♂' => 'hombre corriendo: tono de piel claro',
    '🏃🏼‍♂' => 'hombre corriendo: tono de piel claro medio',
    '🏃🏽‍♂' => 'hombre corriendo: tono de piel medio',
    '🏃🏾‍♂' => 'hombre corriendo: tono de piel oscuro medio',
    '🏃🏿‍♂' => 'hombre corriendo: tono de piel oscuro',
    '🏃🏻‍♀' => 'mujer corriendo: tono de piel claro',
    '🏃🏼‍♀' => 'mujer corriendo: tono de piel claro medio',
    '🏃🏽‍♀' => 'mujer corriendo: tono de piel medio',
    '🏃🏾‍♀' => 'mujer corriendo: tono de piel oscuro medio',
    '🏃🏿‍♀' => 'mujer corriendo: tono de piel oscuro',
    '🏃🏻‍➡' => 'persona corriendo: tono de piel claro y hacia la derecha',
    '🏃🏼‍➡' => 'persona corriendo: tono de piel claro medio y hacia la derecha',
    '🏃🏽‍➡' => 'persona corriendo: tono de piel medio y hacia la derecha',
    '🏃🏾‍➡' => 'persona corriendo: tono de piel oscuro medio y hacia la derecha',
    '🏃🏿‍➡' => 'persona corriendo: tono de piel oscuro y hacia la derecha',
    '👯🏻‍♀' => 'mujeres con orejas de conejo: tono de piel claro',
    '👯🏼‍♀' => 'mujeres con orejas de conejo: tono de piel claro medio',
    '👯🏽‍♀' => 'mujeres con orejas de conejo: tono de piel medio',
    '👯🏾‍♀' => 'mujeres con orejas de conejo: tono de piel oscuro medio',
    '👯🏿‍♀' => 'mujeres con orejas de conejo: tono de piel oscuro',
    '👯🏻‍♂' => 'hombres con orejas de conejo: tono de piel claro',
    '👯🏼‍♂' => 'hombres con orejas de conejo: tono de piel claro medio',
    '👯🏽‍♂' => 'hombres con orejas de conejo: tono de piel medio',
    '👯🏾‍♂' => 'hombres con orejas de conejo: tono de piel oscuro medio',
    '👯🏿‍♂' => 'hombres con orejas de conejo: tono de piel oscuro',
    '🧖🏻‍♂' => 'hombre en una sauna: tono de piel claro',
    '🧖🏼‍♂' => 'hombre en una sauna: tono de piel claro medio',
    '🧖🏽‍♂' => 'hombre en una sauna: tono de piel medio',
    '🧖🏾‍♂' => 'hombre en una sauna: tono de piel oscuro medio',
    '🧖🏿‍♂' => 'hombre en una sauna: tono de piel oscuro',
    '🧖🏻‍♀' => 'mujer en una sauna: tono de piel claro',
    '🧖🏼‍♀' => 'mujer en una sauna: tono de piel claro medio',
    '🧖🏽‍♀' => 'mujer en una sauna: tono de piel medio',
    '🧖🏾‍♀' => 'mujer en una sauna: tono de piel oscuro medio',
    '🧖🏿‍♀' => 'mujer en una sauna: tono de piel oscuro',
    '🧗🏻‍♂' => 'hombre escalando: tono de piel claro',
    '🧗🏼‍♂' => 'hombre escalando: tono de piel claro medio',
    '🧗🏽‍♂' => 'hombre escalando: tono de piel medio',
    '🧗🏾‍♂' => 'hombre escalando: tono de piel oscuro medio',
    '🧗🏿‍♂' => 'hombre escalando: tono de piel oscuro',
    '🧗🏻‍♀' => 'mujer escalando: tono de piel claro',
    '🧗🏼‍♀' => 'mujer escalando: tono de piel claro medio',
    '🧗🏽‍♀' => 'mujer escalando: tono de piel medio',
    '🧗🏾‍♀' => 'mujer escalando: tono de piel oscuro medio',
    '🧗🏿‍♀' => 'mujer escalando: tono de piel oscuro',
    '🏌🏻‍♂' => 'hombre jugando al golf: tono de piel claro',
    '🏌🏼‍♂' => 'hombre jugando al golf: tono de piel claro medio',
    '🏌🏽‍♂' => 'hombre jugando al golf: tono de piel medio',
    '🏌🏾‍♂' => 'hombre jugando al golf: tono de piel oscuro medio',
    '🏌🏿‍♂' => 'hombre jugando al golf: tono de piel oscuro',
    '🏌🏻‍♀' => 'mujer jugando al golf: tono de piel claro',
    '🏌🏼‍♀' => 'mujer jugando al golf: tono de piel claro medio',
    '🏌🏽‍♀' => 'mujer jugando al golf: tono de piel medio',
    '🏌🏾‍♀' => 'mujer jugando al golf: tono de piel oscuro medio',
    '🏌🏿‍♀' => 'mujer jugando al golf: tono de piel oscuro',
    '🏄🏻‍♂' => 'hombre haciendo surf: tono de piel claro',
    '🏄🏼‍♂' => 'hombre haciendo surf: tono de piel claro medio',
    '🏄🏽‍♂' => 'hombre haciendo surf: tono de piel medio',
    '🏄🏾‍♂' => 'hombre haciendo surf: tono de piel oscuro medio',
    '🏄🏿‍♂' => 'hombre haciendo surf: tono de piel oscuro',
    '🏄🏻‍♀' => 'mujer haciendo surf: tono de piel claro',
    '🏄🏼‍♀' => 'mujer haciendo surf: tono de piel claro medio',
    '🏄🏽‍♀' => 'mujer haciendo surf: tono de piel medio',
    '🏄🏾‍♀' => 'mujer haciendo surf: tono de piel oscuro medio',
    '🏄🏿‍♀' => 'mujer haciendo surf: tono de piel oscuro',
    '🚣🏻‍♂' => 'hombre remando en un bote: tono de piel claro',
    '🚣🏼‍♂' => 'hombre remando en un bote: tono de piel claro medio',
    '🚣🏽‍♂' => 'hombre remando en un bote: tono de piel medio',
    '🚣🏾‍♂' => 'hombre remando en un bote: tono de piel oscuro medio',
    '🚣🏿‍♂' => 'hombre remando en un bote: tono de piel oscuro',
    '🚣🏻‍♀' => 'mujer remando en un bote: tono de piel claro',
    '🚣🏼‍♀' => 'mujer remando en un bote: tono de piel claro medio',
    '🚣🏽‍♀' => 'mujer remando en un bote: tono de piel medio',
    '🚣🏾‍♀' => 'mujer remando en un bote: tono de piel oscuro medio',
    '🚣🏿‍♀' => 'mujer remando en un bote: tono de piel oscuro',
    '🏊🏻‍♂' => 'hombre nadando: tono de piel claro',
    '🏊🏼‍♂' => 'hombre nadando: tono de piel claro medio',
    '🏊🏽‍♂' => 'hombre nadando: tono de piel medio',
    '🏊🏾‍♂' => 'hombre nadando: tono de piel oscuro medio',
    '🏊🏿‍♂' => 'hombre nadando: tono de piel oscuro',
    '🏊🏻‍♀' => 'mujer nadando: tono de piel claro',
    '🏊🏼‍♀' => 'mujer nadando: tono de piel claro medio',
    '🏊🏽‍♀' => 'mujer nadando: tono de piel medio',
    '🏊🏾‍♀' => 'mujer nadando: tono de piel oscuro medio',
    '🏊🏿‍♀' => 'mujer nadando: tono de piel oscuro',
    '⛹🏻‍♂' => 'hombre botando un balón: tono de piel claro',
    '⛹🏼‍♂' => 'hombre botando un balón: tono de piel claro medio',
    '⛹🏽‍♂' => 'hombre botando un balón: tono de piel medio',
    '⛹🏾‍♂' => 'hombre botando un balón: tono de piel oscuro medio',
    '⛹🏿‍♂' => 'hombre botando un balón: tono de piel oscuro',
    '⛹🏻‍♀' => 'mujer botando un balón: tono de piel claro',
    '⛹🏼‍♀' => 'mujer botando un balón: tono de piel claro medio',
    '⛹🏽‍♀' => 'mujer botando un balón: tono de piel medio',
    '⛹🏾‍♀' => 'mujer botando un balón: tono de piel oscuro medio',
    '⛹🏿‍♀' => 'mujer botando un balón: tono de piel oscuro',
    '🏋🏻‍♂' => 'hombre levantando pesas: tono de piel claro',
    '🏋🏼‍♂' => 'hombre levantando pesas: tono de piel claro medio',
    '🏋🏽‍♂' => 'hombre levantando pesas: tono de piel medio',
    '🏋🏾‍♂' => 'hombre levantando pesas: tono de piel oscuro medio',
    '🏋🏿‍♂' => 'hombre levantando pesas: tono de piel oscuro',
    '🏋🏻‍♀' => 'mujer levantando pesas: tono de piel claro',
    '🏋🏼‍♀' => 'mujer levantando pesas: tono de piel claro medio',
    '🏋🏽‍♀' => 'mujer levantando pesas: tono de piel medio',
    '🏋🏾‍♀' => 'mujer levantando pesas: tono de piel oscuro medio',
    '🏋🏿‍♀' => 'mujer levantando pesas: tono de piel oscuro',
    '🚴🏻‍♂' => 'hombre en bicicleta: tono de piel claro',
    '🚴🏼‍♂' => 'hombre en bicicleta: tono de piel claro medio',
    '🚴🏽‍♂' => 'hombre en bicicleta: tono de piel medio',
    '🚴🏾‍♂' => 'hombre en bicicleta: tono de piel oscuro medio',
    '🚴🏿‍♂' => 'hombre en bicicleta: tono de piel oscuro',
    '🚴🏻‍♀' => 'mujer en bicicleta: tono de piel claro',
    '🚴🏼‍♀' => 'mujer en bicicleta: tono de piel claro medio',
    '🚴🏽‍♀' => 'mujer en bicicleta: tono de piel medio',
    '🚴🏾‍♀' => 'mujer en bicicleta: tono de piel oscuro medio',
    '🚴🏿‍♀' => 'mujer en bicicleta: tono de piel oscuro',
    '🚵🏻‍♂' => 'hombre en bicicleta de montaña: tono de piel claro',
    '🚵🏼‍♂' => 'hombre en bicicleta de montaña: tono de piel claro medio',
    '🚵🏽‍♂' => 'hombre en bicicleta de montaña: tono de piel medio',
    '🚵🏾‍♂' => 'hombre en bicicleta de montaña: tono de piel oscuro medio',
    '🚵🏿‍♂' => 'hombre en bicicleta de montaña: tono de piel oscuro',
    '🚵🏻‍♀' => 'mujer en bicicleta de montaña: tono de piel claro',
    '🚵🏼‍♀' => 'mujer en bicicleta de montaña: tono de piel claro medio',
    '🚵🏽‍♀' => 'mujer en bicicleta de montaña: tono de piel medio',
    '🚵🏾‍♀' => 'mujer en bicicleta de montaña: tono de piel oscuro medio',
    '🚵🏿‍♀' => 'mujer en bicicleta de montaña: tono de piel oscuro',
    '🤸🏻‍♂' => 'hombre dando una voltereta lateral: tono de piel claro',
    '🤸🏼‍♂' => 'hombre dando una voltereta lateral: tono de piel claro medio',
    '🤸🏽‍♂' => 'hombre dando una voltereta lateral: tono de piel medio',
    '🤸🏾‍♂' => 'hombre dando una voltereta lateral: tono de piel oscuro medio',
    '🤸🏿‍♂' => 'hombre dando una voltereta lateral: tono de piel oscuro',
    '🤸🏻‍♀' => 'mujer dando una voltereta lateral: tono de piel claro',
    '🤸🏼‍♀' => 'mujer dando una voltereta lateral: tono de piel claro medio',
    '🤸🏽‍♀' => 'mujer dando una voltereta lateral: tono de piel medio',
    '🤸🏾‍♀' => 'mujer dando una voltereta lateral: tono de piel oscuro medio',
    '🤸🏿‍♀' => 'mujer dando una voltereta lateral: tono de piel oscuro',
    '🤼🏻‍♀' => 'mujeres luchando: tono de piel claro',
    '🤼🏼‍♀' => 'mujeres luchando: tono de piel claro medio',
    '🤼🏽‍♀' => 'mujeres luchando: tono de piel medio',
    '🤼🏾‍♀' => 'mujeres luchando: tono de piel oscuro medio',
    '🤼🏿‍♀' => 'mujeres luchando: tono de piel oscuro',
    '🤼🏻‍♂' => 'hombres luchando: tono de piel claro',
    '🤼🏼‍♂' => 'hombres luchando: tono de piel claro medio',
    '🤼🏽‍♂' => 'hombres luchando: tono de piel medio',
    '🤼🏾‍♂' => 'hombres luchando: tono de piel oscuro medio',
    '🤼🏿‍♂' => 'hombres luchando: tono de piel oscuro',
    '🤽🏻‍♂' => 'hombre jugando al waterpolo: tono de piel claro',
    '🤽🏼‍♂' => 'hombre jugando al waterpolo: tono de piel claro medio',
    '🤽🏽‍♂' => 'hombre jugando al waterpolo: tono de piel medio',
    '🤽🏾‍♂' => 'hombre jugando al waterpolo: tono de piel oscuro medio',
    '🤽🏿‍♂' => 'hombre jugando al waterpolo: tono de piel oscuro',
    '🤽🏻‍♀' => 'mujer jugando al waterpolo: tono de piel claro',
    '🤽🏼‍♀' => 'mujer jugando al waterpolo: tono de piel claro medio',
    '🤽🏽‍♀' => 'mujer jugando al waterpolo: tono de piel medio',
    '🤽🏾‍♀' => 'mujer jugando al waterpolo: tono de piel oscuro medio',
    '🤽🏿‍♀' => 'mujer jugando al waterpolo: tono de piel oscuro',
    '🤾🏻‍♂' => 'hombre jugando al balonmano: tono de piel claro',
    '🤾🏼‍♂' => 'hombre jugando al balonmano: tono de piel claro medio',
    '🤾🏽‍♂' => 'hombre jugando al balonmano: tono de piel medio',
    '🤾🏾‍♂' => 'hombre jugando al balonmano: tono de piel oscuro medio',
    '🤾🏿‍♂' => 'hombre jugando al balonmano: tono de piel oscuro',
    '🤾🏻‍♀' => 'mujer jugando al balonmano: tono de piel claro',
    '🤾🏼‍♀' => 'mujer jugando al balonmano: tono de piel claro medio',
    '🤾🏽‍♀' => 'mujer jugando al balonmano: tono de piel medio',
    '🤾🏾‍♀' => 'mujer jugando al balonmano: tono de piel oscuro medio',
    '🤾🏿‍♀' => 'mujer jugando al balonmano: tono de piel oscuro',
    '🤹🏻‍♂' => 'hombre haciendo malabares: tono de piel claro',
    '🤹🏼‍♂' => 'hombre haciendo malabares: tono de piel claro medio',
    '🤹🏽‍♂' => 'hombre haciendo malabares: tono de piel medio',
    '🤹🏾‍♂' => 'hombre haciendo malabares: tono de piel oscuro medio',
    '🤹🏿‍♂' => 'hombre haciendo malabares: tono de piel oscuro',
    '🤹🏻‍♀' => 'mujer haciendo malabares: tono de piel claro',
    '🤹🏼‍♀' => 'mujer haciendo malabares: tono de piel claro medio',
    '🤹🏽‍♀' => 'mujer haciendo malabares: tono de piel medio',
    '🤹🏾‍♀' => 'mujer haciendo malabares: tono de piel oscuro medio',
    '🤹🏿‍♀' => 'mujer haciendo malabares: tono de piel oscuro',
    '🧘🏻‍♂' => 'hombre en posición de loto: tono de piel claro',
    '🧘🏼‍♂' => 'hombre en posición de loto: tono de piel claro medio',
    '🧘🏽‍♂' => 'hombre en posición de loto: tono de piel medio',
    '🧘🏾‍♂' => 'hombre en posición de loto: tono de piel oscuro medio',
    '🧘🏿‍♂' => 'hombre en posición de loto: tono de piel oscuro',
    '🧘🏻‍♀' => 'mujer en posición de loto: tono de piel claro',
    '🧘🏼‍♀' => 'mujer en posición de loto: tono de piel claro medio',
    '🧘🏽‍♀' => 'mujer en posición de loto: tono de piel medio',
    '🧘🏾‍♀' => 'mujer en posición de loto: tono de piel oscuro medio',
    '🧘🏿‍♀' => 'mujer en posición de loto: tono de piel oscuro',
    '🧑‍🦰' => 'persona adulta: pelo pelirrojo',
    '🧑‍🦱' => 'persona adulta: pelo rizado',
    '🧑‍🦳' => 'persona adulta: pelo blanco',
    '🧑‍🦲' => 'persona adulta: sin pelo',
    '👨‍🦰' => 'hombre: pelo pelirrojo',
    '👨‍🦱' => 'hombre: pelo rizado',
    '👨‍🦳' => 'hombre: pelo blanco',
    '👨‍🦲' => 'hombre: sin pelo',
    '👩‍🦰' => 'mujer: pelo pelirrojo',
    '👩‍🦱' => 'mujer: pelo rizado',
    '👩‍🦳' => 'mujer: pelo blanco',
    '👩‍🦲' => 'mujer: sin pelo',
    '🚶‍➡' => 'persona caminando: hacia la derecha',
    '🧎‍➡' => 'persona de rodillas: hacia la derecha',
    '🏃‍➡' => 'persona corriendo: hacia la derecha',
    '👨‍👦' => 'familia: hombre y niño',
    '👨‍👧' => 'familia: hombre y niña',
    '👩‍👦' => 'familia: mujer y niño',
    '👩‍👧' => 'familia: mujer y niña',
    '😶‍🌫' => 'cara entre las nubes',
    '😮‍💨' => 'cara exhalando',
    '🙂‍↕' => 'cabeza asintiendo',
    '😵‍💫' => 'cara con ojos en espiral',
    '❤‍🔥' => 'corazón en llamas',
    '❤‍🩹' => 'corazón vendado',
    '👁‍🗨' => 'ojo en bocadillo de texto',
    '🧔‍♂' => 'hombre: barba',
    '👱‍♂' => 'hombre rubio',
    '🧔‍♀' => 'mujer: barba',
    '👱‍♀' => 'mujer rubia',
    '🙍‍♂' => 'hombre frunciendo el ceño',
    '🙍‍♀' => 'mujer frunciendo el ceño',
    '🙎‍♂' => 'hombre haciendo pucheros',
    '🙎‍♀' => 'mujer haciendo pucheros',
    '🙅‍♂' => 'hombre haciendo el gesto de "no"',
    '🙅‍♀' => 'mujer haciendo el gesto de "no"',
    '🙆‍♂' => 'hombre haciendo el gesto de "de acuerdo"',
    '🙆‍♀' => 'mujer haciendo el gesto de "de acuerdo"',
    '💁‍♂' => 'empleado de mostrador de información',
    '💁‍♀' => 'empleada de mostrador de información',
    '🙋‍♂' => 'hombre con la mano levantada',
    '🙋‍♀' => 'mujer con la mano levantada',
    '🧏‍♂' => 'hombre sordo',
    '🧏‍♀' => 'mujer sorda',
    '🙇‍♂' => 'hombre haciendo una reverencia',
    '🙇‍♀' => 'mujer haciendo una reverencia',
    '🤦‍♂' => 'hombre con la mano en la frente',
    '🤦‍♀' => 'mujer con la mano en la frente',
    '🤷‍♂' => 'hombre encogido de hombros',
    '🤷‍♀' => 'mujer encogida de hombros',
    '🧑‍⚕' => 'profesional sanitario',
    '👨‍⚕' => 'profesional sanitario hombre',
    '👩‍⚕' => 'profesional sanitario mujer',
    '🧑‍🎓' => 'estudiante',
    '👨‍🎓' => 'estudiante hombre',
    '👩‍🎓' => 'estudiante mujer',
    '🧑‍🏫' => 'docente',
    '👨‍🏫' => 'docente hombre',
    '👩‍🏫' => 'docente mujer',
    '🧑‍⚖' => 'fiscal',
    '👨‍⚖' => 'fiscal hombre',
    '👩‍⚖' => 'fiscal mujer',
    '🧑‍🌾' => 'profesional de la agricultura',
    '👨‍🌾' => 'profesional de la agricultura hombre',
    '👩‍🌾' => 'profesional de la agricultura mujer',
    '🧑‍🍳' => 'chef',
    '👨‍🍳' => 'chef hombre',
    '👩‍🍳' => 'chef mujer',
    '🧑‍🔧' => 'profesional de la mecánica',
    '👨‍🔧' => 'profesional de la mecánica hombre',
    '👩‍🔧' => 'profesional de la mecánica mujer',
    '🧑‍🏭' => 'profesional industrial',
    '👨‍🏭' => 'profesional industrial hombre',
    '👩‍🏭' => 'profesional industrial mujer',
    '🧑‍💼' => 'oficinista',
    '👨‍💼' => 'oficinista hombre',
    '👩‍💼' => 'oficinista mujer',
    '🧑‍🔬' => 'profesional de la ciencia',
    '👨‍🔬' => 'profesional de la ciencia hombre',
    '👩‍🔬' => 'profesional de la ciencia mujer',
    '🧑‍💻' => 'profesional de la tecnología',
    '👨‍💻' => 'profesional de la tecnología hombre',
    '👩‍💻' => 'profesional de la tecnología mujer',
    '🧑‍🎤' => 'cantante',
    '👨‍🎤' => 'cantante hombre',
    '👩‍🎤' => 'cantante mujer',
    '🧑‍🎨' => 'artista',
    '👨‍🎨' => 'artista hombre',
    '👩‍🎨' => 'artista mujer',
    '🧑‍✈' => 'piloto',
    '👨‍✈' => 'piloto hombre',
    '👩‍✈' => 'piloto mujer',
    '🧑‍🚀' => 'astronauta',
    '👨‍🚀' => 'astronauta hombre',
    '👩‍🚀' => 'astronauta mujer',
    '🧑‍🚒' => 'bombero',
    '👨‍🚒' => 'bombero hombre',
    '👩‍🚒' => 'bombera',
    '👮‍♂' => 'agente de policía hombre',
    '👮‍♀' => 'agente de policía mujer',
    '🕵‍♂' => 'detective hombre',
    '🕵‍♀' => 'detective mujer',
    '💂‍♂' => 'guardia hombre',
    '💂‍♀' => 'guardia mujer',
    '👷‍♂' => 'profesional de la construcción hombre',
    '👷‍♀' => 'profesional de la construcción mujer',
    '👳‍♂' => 'hombre con turbante',
    '👳‍♀' => 'mujer con turbante',
    '🤵‍♂' => 'hombre con esmoquin',
    '🤵‍♀' => 'mujer con esmoquin',
    '👰‍♂' => 'hombre con velo',
    '👰‍♀' => 'mujer con velo',
    '👩‍🍼' => 'mujer alimentando a bebé',
    '👨‍🍼' => 'hombre alimentando a bebé',
    '🧑‍🍼' => 'persona alimentando a bebé',
    '🧑‍🎄' => 'Noel',
    '🦸‍♂' => 'superhéroe',
    '🦸‍♀' => 'superheroína',
    '🦹‍♂' => 'supervillano',
    '🦹‍♀' => 'supervillana',
    '🧙‍♂' => 'mago',
    '🧙‍♀' => 'maga',
    '🧚‍♂' => 'hada hombre',
    '🧚‍♀' => 'hada mujer',
    '🧛‍♂' => 'vampiro hombre',
    '🧛‍♀' => 'vampiresa',
    '🧜‍♂' => 'sirena hombre',
    '🧜‍♀' => 'sirena',
    '🧝‍♂' => 'elfo hombre',
    '🧝‍♀' => 'elfa',
    '🧞‍♂' => 'genio hombre',
    '🧞‍♀' => 'genio mujer',
    '🧟‍♂' => 'zombi hombre',
    '🧟‍♀' => 'zombi mujer',
    '💆‍♂' => 'hombre recibiendo masaje',
    '💆‍♀' => 'mujer recibiendo masaje',
    '💇‍♂' => 'hombre cortándose el pelo',
    '💇‍♀' => 'mujer cortándose el pelo',
    '🚶‍♂' => 'hombre caminando',
    '🚶‍♀' => 'mujer caminando',
    '🧍‍♂' => 'hombre de pie',
    '🧍‍♀' => 'mujer de pie',
    '🧎‍♂' => 'hombre de rodillas',
    '🧎‍♀' => 'mujer de rodillas',
    '🧑‍🦯' => 'persona con bastón',
    '👨‍🦯' => 'hombre con bastón',
    '👩‍🦯' => 'mujer con bastón',
    '🧑‍🦼' => 'persona en silla de ruedas eléctrica',
    '👨‍🦼' => 'hombre en silla de ruedas eléctrica',
    '👩‍🦼' => 'mujer en silla de ruedas eléctrica',
    '🧑‍🦽' => 'persona en silla de ruedas manual',
    '👨‍🦽' => 'hombre en silla de ruedas manual',
    '👩‍🦽' => 'mujer en silla de ruedas manual',
    '🏃‍♂' => 'hombre corriendo',
    '🏃‍♀' => 'mujer corriendo',
    '🧑‍🩰' => 'bailarina de ballet',
    '👯‍♂' => 'hombres con orejas de conejo',
    '👯‍♀' => 'mujeres con orejas de conejo',
    '🧖‍♂' => 'hombre en una sauna',
    '🧖‍♀' => 'mujer en una sauna',
    '🧗‍♂' => 'hombre escalando',
    '🧗‍♀' => 'mujer escalando',
    '🏌‍♂' => 'hombre jugando al golf',
    '🏌‍♀' => 'mujer jugando al golf',
    '🏄‍♂' => 'hombre haciendo surf',
    '🏄‍♀' => 'mujer haciendo surf',
    '🚣‍♂' => 'hombre remando en un bote',
    '🚣‍♀' => 'mujer remando en un bote',
    '🏊‍♂' => 'hombre nadando',
    '🏊‍♀' => 'mujer nadando',
    '⛹‍♂' => 'hombre botando un balón',
    '⛹‍♀' => 'mujer botando un balón',
    '🏋‍♂' => 'hombre levantando pesas',
    '🏋‍♀' => 'mujer levantando pesas',
    '🚴‍♂' => 'hombre en bicicleta',
    '🚴‍♀' => 'mujer en bicicleta',
    '🚵‍♂' => 'hombre en bicicleta de montaña',
    '🚵‍♀' => 'mujer en bicicleta de montaña',
    '🤸‍♂' => 'hombre dando una voltereta lateral',
    '🤸‍♀' => 'mujer dando una voltereta lateral',
    '🤼‍♂' => 'hombres luchando',
    '🤼‍♀' => 'mujeres luchando',
    '🤽‍♂' => 'hombre jugando al waterpolo',
    '🤽‍♀' => 'mujer jugando al waterpolo',
    '🤾‍♂' => 'hombre jugando al balonmano',
    '🤾‍♀' => 'mujer jugando al balonmano',
    '🤹‍♂' => 'hombre haciendo malabares',
    '🤹‍♀' => 'mujer haciendo malabares',
    '🧘‍♂' => 'hombre en posición de loto',
    '🧘‍♀' => 'mujer en posición de loto',
    '🧑‍🧒' => 'familia: adulto, niño',
    '🐕‍🦺' => 'perro de servicio',
    '🐈‍⬛' => 'gato negro',
    '🐻‍❄' => 'oso polar',
    '🐦‍⬛' => 'pájaro negro',
    '🐦‍🔥' => 'fénix',
    '🍋‍🟩' => 'lima',
    '🍄‍🟫' => 'champiñón marrón',
    '⛓‍💥' => 'cadena rota',
    '🏳‍🌈' => 'bandera del arcoíris',
    '🏳‍⚧' => 'bandera transgénero',
    '🏴‍☠' => 'bandera pirata',
    '👋🏻' => 'mano saludando: tono de piel claro',
    '👋🏼' => 'mano saludando: tono de piel claro medio',
    '👋🏽' => 'mano saludando: tono de piel medio',
    '👋🏾' => 'mano saludando: tono de piel oscuro medio',
    '👋🏿' => 'mano saludando: tono de piel oscuro',
    '🤚🏻' => 'dorso de la mano: tono de piel claro',
    '🤚🏼' => 'dorso de la mano: tono de piel claro medio',
    '🤚🏽' => 'dorso de la mano: tono de piel medio',
    '🤚🏾' => 'dorso de la mano: tono de piel oscuro medio',
    '🤚🏿' => 'dorso de la mano: tono de piel oscuro',
    '🖐🏻' => 'mano abierta: tono de piel claro',
    '🖐🏼' => 'mano abierta: tono de piel claro medio',
    '🖐🏽' => 'mano abierta: tono de piel medio',
    '🖐🏾' => 'mano abierta: tono de piel oscuro medio',
    '🖐🏿' => 'mano abierta: tono de piel oscuro',
    '✋🏻' => 'mano levantada: tono de piel claro',
    '✋🏼' => 'mano levantada: tono de piel claro medio',
    '✋🏽' => 'mano levantada: tono de piel medio',
    '✋🏾' => 'mano levantada: tono de piel oscuro medio',
    '✋🏿' => 'mano levantada: tono de piel oscuro',
    '🖖🏻' => 'saludo vulcano: tono de piel claro',
    '🖖🏼' => 'saludo vulcano: tono de piel claro medio',
    '🖖🏽' => 'saludo vulcano: tono de piel medio',
    '🖖🏾' => 'saludo vulcano: tono de piel oscuro medio',
    '🖖🏿' => 'saludo vulcano: tono de piel oscuro',
    '🫱🏻' => 'mano hacia la derecha: tono de piel claro',
    '🫱🏼' => 'mano hacia la derecha: tono de piel claro medio',
    '🫱🏽' => 'mano hacia la derecha: tono de piel medio',
    '🫱🏾' => 'mano hacia la derecha: tono de piel oscuro medio',
    '🫱🏿' => 'mano hacia la derecha: tono de piel oscuro',
    '🫲🏻' => 'mano hacia la izquierda: tono de piel claro',
    '🫲🏼' => 'mano hacia la izquierda: tono de piel claro medio',
    '🫲🏽' => 'mano hacia la izquierda: tono de piel medio',
    '🫲🏾' => 'mano hacia la izquierda: tono de piel oscuro medio',
    '🫲🏿' => 'mano hacia la izquierda: tono de piel oscuro',
    '🫳🏻' => 'mano con la palma hacia abajo: tono de piel claro',
    '🫳🏼' => 'mano con la palma hacia abajo: tono de piel claro medio',
    '🫳🏽' => 'mano con la palma hacia abajo: tono de piel medio',
    '🫳🏾' => 'mano con la palma hacia abajo: tono de piel oscuro medio',
    '🫳🏿' => 'mano con la palma hacia abajo: tono de piel oscuro',
    '🫴🏻' => 'mano con la palma hacia arriba: tono de piel claro',
    '🫴🏼' => 'mano con la palma hacia arriba: tono de piel claro medio',
    '🫴🏽' => 'mano con la palma hacia arriba: tono de piel medio',
    '🫴🏾' => 'mano con la palma hacia arriba: tono de piel oscuro medio',
    '🫴🏿' => 'mano con la palma hacia arriba: tono de piel oscuro',
    '🫷🏻' => 'mano empujando hacia la izquierda: tono de piel claro',
    '🫷🏼' => 'mano empujando hacia la izquierda: tono de piel claro medio',
    '🫷🏽' => 'mano empujando hacia la izquierda: tono de piel medio',
    '🫷🏾' => 'mano empujando hacia la izquierda: tono de piel oscuro medio',
    '🫷🏿' => 'mano empujando hacia la izquierda: tono de piel oscuro',
    '🫸🏻' => 'mano empujando hacia la derecha: tono de piel claro',
    '🫸🏼' => 'mano empujando hacia la derecha: tono de piel claro medio',
    '🫸🏽' => 'mano empujando hacia la derecha: tono de piel medio',
    '🫸🏾' => 'mano empujando hacia la derecha: tono de piel oscuro medio',
    '🫸🏿' => 'mano empujando hacia la derecha: tono de piel oscuro',
    '👌🏻' => 'señal de aprobación con la mano: tono de piel claro',
    '👌🏼' => 'señal de aprobación con la mano: tono de piel claro medio',
    '👌🏽' => 'señal de aprobación con la mano: tono de piel medio',
    '👌🏾' => 'señal de aprobación con la mano: tono de piel oscuro medio',
    '👌🏿' => 'señal de aprobación con la mano: tono de piel oscuro',
    '🤌🏻' => 'dedos juntos apuntando hacia arriba: tono de piel claro',
    '🤌🏼' => 'dedos juntos apuntando hacia arriba: tono de piel claro medio',
    '🤌🏽' => 'dedos juntos apuntando hacia arriba: tono de piel medio',
    '🤌🏾' => 'dedos juntos apuntando hacia arriba: tono de piel oscuro medio',
    '🤌🏿' => 'dedos juntos apuntando hacia arriba: tono de piel oscuro',
    '🤏🏻' => 'mano pellizcando: tono de piel claro',
    '🤏🏼' => 'mano pellizcando: tono de piel claro medio',
    '🤏🏽' => 'mano pellizcando: tono de piel medio',
    '🤏🏾' => 'mano pellizcando: tono de piel oscuro medio',
    '🤏🏿' => 'mano pellizcando: tono de piel oscuro',
    '✌🏻' => 'mano con señal de victoria: tono de piel claro',
    '✌🏼' => 'mano con señal de victoria: tono de piel claro medio',
    '✌🏽' => 'mano con señal de victoria: tono de piel medio',
    '✌🏾' => 'mano con señal de victoria: tono de piel oscuro medio',
    '✌🏿' => 'mano con señal de victoria: tono de piel oscuro',
    '🤞🏻' => 'dedos cruzados: tono de piel claro',
    '🤞🏼' => 'dedos cruzados: tono de piel claro medio',
    '🤞🏽' => 'dedos cruzados: tono de piel medio',
    '🤞🏾' => 'dedos cruzados: tono de piel oscuro medio',
    '🤞🏿' => 'dedos cruzados: tono de piel oscuro',
    '🫰🏻' => 'mano con dedo índice y pulgar cruzados: tono de piel claro',
    '🫰🏼' => 'mano con dedo índice y pulgar cruzados: tono de piel claro medio',
    '🫰🏽' => 'mano con dedo índice y pulgar cruzados: tono de piel medio',
    '🫰🏾' => 'mano con dedo índice y pulgar cruzados: tono de piel oscuro medio',
    '🫰🏿' => 'mano con dedo índice y pulgar cruzados: tono de piel oscuro',
    '🤟🏻' => 'gesto de te quiero: tono de piel claro',
    '🤟🏼' => 'gesto de te quiero: tono de piel claro medio',
    '🤟🏽' => 'gesto de te quiero: tono de piel medio',
    '🤟🏾' => 'gesto de te quiero: tono de piel oscuro medio',
    '🤟🏿' => 'gesto de te quiero: tono de piel oscuro',
    '🤘🏻' => 'mano haciendo el signo de cuernos: tono de piel claro',
    '🤘🏼' => 'mano haciendo el signo de cuernos: tono de piel claro medio',
    '🤘🏽' => 'mano haciendo el signo de cuernos: tono de piel medio',
    '🤘🏾' => 'mano haciendo el signo de cuernos: tono de piel oscuro medio',
    '🤘🏿' => 'mano haciendo el signo de cuernos: tono de piel oscuro',
    '🤙🏻' => 'mano haciendo el gesto de llamar: tono de piel claro',
    '🤙🏼' => 'mano haciendo el gesto de llamar: tono de piel claro medio',
    '🤙🏽' => 'mano haciendo el gesto de llamar: tono de piel medio',
    '🤙🏾' => 'mano haciendo el gesto de llamar: tono de piel oscuro medio',
    '🤙🏿' => 'mano haciendo el gesto de llamar: tono de piel oscuro',
    '👈🏻' => 'dorso de mano con índice a la izquierda: tono de piel claro',
    '👈🏼' => 'dorso de mano con índice a la izquierda: tono de piel claro medio',
    '👈🏽' => 'dorso de mano con índice a la izquierda: tono de piel medio',
    '👈🏾' => 'dorso de mano con índice a la izquierda: tono de piel oscuro medio',
    '👈🏿' => 'dorso de mano con índice a la izquierda: tono de piel oscuro',
    '👉🏻' => 'dorso de mano con índice a la derecha: tono de piel claro',
    '👉🏼' => 'dorso de mano con índice a la derecha: tono de piel claro medio',
    '👉🏽' => 'dorso de mano con índice a la derecha: tono de piel medio',
    '👉🏾' => 'dorso de mano con índice a la derecha: tono de piel oscuro medio',
    '👉🏿' => 'dorso de mano con índice a la derecha: tono de piel oscuro',
    '👆🏻' => 'dorso de mano con índice hacia arriba: tono de piel claro',
    '👆🏼' => 'dorso de mano con índice hacia arriba: tono de piel claro medio',
    '👆🏽' => 'dorso de mano con índice hacia arriba: tono de piel medio',
    '👆🏾' => 'dorso de mano con índice hacia arriba: tono de piel oscuro medio',
    '👆🏿' => 'dorso de mano con índice hacia arriba: tono de piel oscuro',
    '🖕🏻' => 'dedo corazón hacia arriba: tono de piel claro',
    '🖕🏼' => 'dedo corazón hacia arriba: tono de piel claro medio',
    '🖕🏽' => 'dedo corazón hacia arriba: tono de piel medio',
    '🖕🏾' => 'dedo corazón hacia arriba: tono de piel oscuro medio',
    '🖕🏿' => 'dedo corazón hacia arriba: tono de piel oscuro',
    '👇🏻' => 'dorso de mano con índice hacia abajo: tono de piel claro',
    '👇🏼' => 'dorso de mano con índice hacia abajo: tono de piel claro medio',
    '👇🏽' => 'dorso de mano con índice hacia abajo: tono de piel medio',
    '👇🏾' => 'dorso de mano con índice hacia abajo: tono de piel oscuro medio',
    '👇🏿' => 'dorso de mano con índice hacia abajo: tono de piel oscuro',
    '☝🏻' => 'dedo índice hacia arriba: tono de piel claro',
    '☝🏼' => 'dedo índice hacia arriba: tono de piel claro medio',
    '☝🏽' => 'dedo índice hacia arriba: tono de piel medio',
    '☝🏾' => 'dedo índice hacia arriba: tono de piel oscuro medio',
    '☝🏿' => 'dedo índice hacia arriba: tono de piel oscuro',
    '🫵🏻' => 'dedo índice apuntándote a ti: tono de piel claro',
    '🫵🏼' => 'dedo índice apuntándote a ti: tono de piel claro medio',
    '🫵🏽' => 'dedo índice apuntándote a ti: tono de piel medio',
    '🫵🏾' => 'dedo índice apuntándote a ti: tono de piel oscuro medio',
    '🫵🏿' => 'dedo índice apuntándote a ti: tono de piel oscuro',
    '👍🏻' => 'pulgar hacia arriba: tono de piel claro',
    '👍🏼' => 'pulgar hacia arriba: tono de piel claro medio',
    '👍🏽' => 'pulgar hacia arriba: tono de piel medio',
    '👍🏾' => 'pulgar hacia arriba: tono de piel oscuro medio',
    '👍🏿' => 'pulgar hacia arriba: tono de piel oscuro',
    '👎🏻' => 'pulgar hacia abajo: tono de piel claro',
    '👎🏼' => 'pulgar hacia abajo: tono de piel claro medio',
    '👎🏽' => 'pulgar hacia abajo: tono de piel medio',
    '👎🏾' => 'pulgar hacia abajo: tono de piel oscuro medio',
    '👎🏿' => 'pulgar hacia abajo: tono de piel oscuro',
    '✊🏻' => 'puño en alto: tono de piel claro',
    '✊🏼' => 'puño en alto: tono de piel claro medio',
    '✊🏽' => 'puño en alto: tono de piel medio',
    '✊🏾' => 'puño en alto: tono de piel oscuro medio',
    '✊🏿' => 'puño en alto: tono de piel oscuro',
    '👊🏻' => 'puño cerrado: tono de piel claro',
    '👊🏼' => 'puño cerrado: tono de piel claro medio',
    '👊🏽' => 'puño cerrado: tono de piel medio',
    '👊🏾' => 'puño cerrado: tono de piel oscuro medio',
    '👊🏿' => 'puño cerrado: tono de piel oscuro',
    '🤛🏻' => 'puño hacia la izquierda: tono de piel claro',
    '🤛🏼' => 'puño hacia la izquierda: tono de piel claro medio',
    '🤛🏽' => 'puño hacia la izquierda: tono de piel medio',
    '🤛🏾' => 'puño hacia la izquierda: tono de piel oscuro medio',
    '🤛🏿' => 'puño hacia la izquierda: tono de piel oscuro',
    '🤜🏻' => 'puño hacia la derecha: tono de piel claro',
    '🤜🏼' => 'puño hacia la derecha: tono de piel claro medio',
    '🤜🏽' => 'puño hacia la derecha: tono de piel medio',
    '🤜🏾' => 'puño hacia la derecha: tono de piel oscuro medio',
    '🤜🏿' => 'puño hacia la derecha: tono de piel oscuro',
    '👏🏻' => 'manos aplaudiendo: tono de piel claro',
    '👏🏼' => 'manos aplaudiendo: tono de piel claro medio',
    '👏🏽' => 'manos aplaudiendo: tono de piel medio',
    '👏🏾' => 'manos aplaudiendo: tono de piel oscuro medio',
    '👏🏿' => 'manos aplaudiendo: tono de piel oscuro',
    '🙌🏻' => 'manos levantadas celebrando: tono de piel claro',
    '🙌🏼' => 'manos levantadas celebrando: tono de piel claro medio',
    '🙌🏽' => 'manos levantadas celebrando: tono de piel medio',
    '🙌🏾' => 'manos levantadas celebrando: tono de piel oscuro medio',
    '🙌🏿' => 'manos levantadas celebrando: tono de piel oscuro',
    '🫶🏻' => 'manos formando un corazón: tono de piel claro',
    '🫶🏼' => 'manos formando un corazón: tono de piel claro medio',
    '🫶🏽' => 'manos formando un corazón: tono de piel medio',
    '🫶🏾' => 'manos formando un corazón: tono de piel oscuro medio',
    '🫶🏿' => 'manos formando un corazón: tono de piel oscuro',
    '👐🏻' => 'manos abiertas: tono de piel claro',
    '👐🏼' => 'manos abiertas: tono de piel claro medio',
    '👐🏽' => 'manos abiertas: tono de piel medio',
    '👐🏾' => 'manos abiertas: tono de piel oscuro medio',
    '👐🏿' => 'manos abiertas: tono de piel oscuro',
    '🤲🏻' => 'palmas hacia arriba juntas: tono de piel claro',
    '🤲🏼' => 'palmas hacia arriba juntas: tono de piel claro medio',
    '🤲🏽' => 'palmas hacia arriba juntas: tono de piel medio',
    '🤲🏾' => 'palmas hacia arriba juntas: tono de piel oscuro medio',
    '🤲🏿' => 'palmas hacia arriba juntas: tono de piel oscuro',
    '🤝🏻' => 'apretón de manos: tono de piel claro',
    '🤝🏼' => 'apretón de manos: tono de piel claro medio',
    '🤝🏽' => 'apretón de manos: tono de piel medio',
    '🤝🏾' => 'apretón de manos: tono de piel oscuro medio',
    '🤝🏿' => 'apretón de manos: tono de piel oscuro',
    '🙏🏻' => 'manos en oración: tono de piel claro',
    '🙏🏼' => 'manos en oración: tono de piel claro medio',
    '🙏🏽' => 'manos en oración: tono de piel medio',
    '🙏🏾' => 'manos en oración: tono de piel oscuro medio',
    '🙏🏿' => 'manos en oración: tono de piel oscuro',
    '✍🏻' => 'mano escribiendo: tono de piel claro',
    '✍🏼' => 'mano escribiendo: tono de piel claro medio',
    '✍🏽' => 'mano escribiendo: tono de piel medio',
    '✍🏾' => 'mano escribiendo: tono de piel oscuro medio',
    '✍🏿' => 'mano escribiendo: tono de piel oscuro',
    '💅🏻' => 'pintarse las uñas: tono de piel claro',
    '💅🏼' => 'pintarse las uñas: tono de piel claro medio',
    '💅🏽' => 'pintarse las uñas: tono de piel medio',
    '💅🏾' => 'pintarse las uñas: tono de piel oscuro medio',
    '💅🏿' => 'pintarse las uñas: tono de piel oscuro',
    '🤳🏻' => 'selfi: tono de piel claro',
    '🤳🏼' => 'selfi: tono de piel claro medio',
    '🤳🏽' => 'selfi: tono de piel medio',
    '🤳🏾' => 'selfi: tono de piel oscuro medio',
    '🤳🏿' => 'selfi: tono de piel oscuro',
    '💪🏻' => 'bíceps flexionado: tono de piel claro',
    '💪🏼' => 'bíceps flexionado: tono de piel claro medio',
    '💪🏽' => 'bíceps flexionado: tono de piel medio',
    '💪🏾' => 'bíceps flexionado: tono de piel oscuro medio',
    '💪🏿' => 'bíceps flexionado: tono de piel oscuro',
    '🦵🏻' => 'pierna: tono de piel claro',
    '🦵🏼' => 'pierna: tono de piel claro medio',
    '🦵🏽' => 'pierna: tono de piel medio',
    '🦵🏾' => 'pierna: tono de piel oscuro medio',
    '🦵🏿' => 'pierna: tono de piel oscuro',
    '🦶🏻' => 'pie: tono de piel claro',
    '🦶🏼' => 'pie: tono de piel claro medio',
    '🦶🏽' => 'pie: tono de piel medio',
    '🦶🏾' => 'pie: tono de piel oscuro medio',
    '🦶🏿' => 'pie: tono de piel oscuro',
    '👂🏻' => 'oreja: tono de piel claro',
    '👂🏼' => 'oreja: tono de piel claro medio',
    '👂🏽' => 'oreja: tono de piel medio',
    '👂🏾' => 'oreja: tono de piel oscuro medio',
    '👂🏿' => 'oreja: tono de piel oscuro',
    '🦻🏻' => 'oreja con audífono: tono de piel claro',
    '🦻🏼' => 'oreja con audífono: tono de piel claro medio',
    '🦻🏽' => 'oreja con audífono: tono de piel medio',
    '🦻🏾' => 'oreja con audífono: tono de piel oscuro medio',
    '🦻🏿' => 'oreja con audífono: tono de piel oscuro',
    '👃🏻' => 'nariz: tono de piel claro',
    '👃🏼' => 'nariz: tono de piel claro medio',
    '👃🏽' => 'nariz: tono de piel medio',
    '👃🏾' => 'nariz: tono de piel oscuro medio',
    '👃🏿' => 'nariz: tono de piel oscuro',
    '👶🏻' => 'bebé: tono de piel claro',
    '👶🏼' => 'bebé: tono de piel claro medio',
    '👶🏽' => 'bebé: tono de piel medio',
    '👶🏾' => 'bebé: tono de piel oscuro medio',
    '👶🏿' => 'bebé: tono de piel oscuro',
    '🧒🏻' => 'infante: tono de piel claro',
    '🧒🏼' => 'infante: tono de piel claro medio',
    '🧒🏽' => 'infante: tono de piel medio',
    '🧒🏾' => 'infante: tono de piel oscuro medio',
    '🧒🏿' => 'infante: tono de piel oscuro',
    '👦🏻' => 'niño: tono de piel claro',
    '👦🏼' => 'niño: tono de piel claro medio',
    '👦🏽' => 'niño: tono de piel medio',
    '👦🏾' => 'niño: tono de piel oscuro medio',
    '👦🏿' => 'niño: tono de piel oscuro',
    '👧🏻' => 'niña: tono de piel claro',
    '👧🏼' => 'niña: tono de piel claro medio',
    '👧🏽' => 'niña: tono de piel medio',
    '👧🏾' => 'niña: tono de piel oscuro medio',
    '👧🏿' => 'niña: tono de piel oscuro',
    '🧑🏻' => 'persona adulta: tono de piel claro',
    '🧑🏼' => 'persona adulta: tono de piel claro medio',
    '🧑🏽' => 'persona adulta: tono de piel medio',
    '🧑🏾' => 'persona adulta: tono de piel oscuro medio',
    '🧑🏿' => 'persona adulta: tono de piel oscuro',
    '👱🏻' => 'persona adulta rubia: tono de piel claro',
    '👱🏼' => 'persona adulta rubia: tono de piel claro medio',
    '👱🏽' => 'persona adulta rubia: tono de piel medio',
    '👱🏾' => 'persona adulta rubia: tono de piel oscuro medio',
    '👱🏿' => 'persona adulta rubia: tono de piel oscuro',
    '👨🏻' => 'hombre: tono de piel claro',
    '👨🏼' => 'hombre: tono de piel claro medio',
    '👨🏽' => 'hombre: tono de piel medio',
    '👨🏾' => 'hombre: tono de piel oscuro medio',
    '👨🏿' => 'hombre: tono de piel oscuro',
    '🧔🏻' => 'persona con barba: tono de piel claro',
    '🧔🏼' => 'persona con barba: tono de piel claro medio',
    '🧔🏽' => 'persona con barba: tono de piel medio',
    '🧔🏾' => 'persona con barba: tono de piel oscuro medio',
    '🧔🏿' => 'persona con barba: tono de piel oscuro',
    '👩🏻' => 'mujer: tono de piel claro',
    '👩🏼' => 'mujer: tono de piel claro medio',
    '👩🏽' => 'mujer: tono de piel medio',
    '👩🏾' => 'mujer: tono de piel oscuro medio',
    '👩🏿' => 'mujer: tono de piel oscuro',
    '🧓🏻' => 'persona mayor: tono de piel claro',
    '🧓🏼' => 'persona mayor: tono de piel claro medio',
    '🧓🏽' => 'persona mayor: tono de piel medio',
    '🧓🏾' => 'persona mayor: tono de piel oscuro medio',
    '🧓🏿' => 'persona mayor: tono de piel oscuro',
    '👴🏻' => 'anciano: tono de piel claro',
    '👴🏼' => 'anciano: tono de piel claro medio',
    '👴🏽' => 'anciano: tono de piel medio',
    '👴🏾' => 'anciano: tono de piel oscuro medio',
    '👴🏿' => 'anciano: tono de piel oscuro',
    '👵🏻' => 'anciana: tono de piel claro',
    '👵🏼' => 'anciana: tono de piel claro medio',
    '👵🏽' => 'anciana: tono de piel medio',
    '👵🏾' => 'anciana: tono de piel oscuro medio',
    '👵🏿' => 'anciana: tono de piel oscuro',
    '🙍🏻' => 'persona frunciendo el ceño: tono de piel claro',
    '🙍🏼' => 'persona frunciendo el ceño: tono de piel claro medio',
    '🙍🏽' => 'persona frunciendo el ceño: tono de piel medio',
    '🙍🏾' => 'persona frunciendo el ceño: tono de piel oscuro medio',
    '🙍🏿' => 'persona frunciendo el ceño: tono de piel oscuro',
    '🙎🏻' => 'persona haciendo pucheros: tono de piel claro',
    '🙎🏼' => 'persona haciendo pucheros: tono de piel claro medio',
    '🙎🏽' => 'persona haciendo pucheros: tono de piel medio',
    '🙎🏾' => 'persona haciendo pucheros: tono de piel oscuro medio',
    '🙎🏿' => 'persona haciendo pucheros: tono de piel oscuro',
    '🙅🏻' => 'persona haciendo el gesto de "no": tono de piel claro',
    '🙅🏼' => 'persona haciendo el gesto de "no": tono de piel claro medio',
    '🙅🏽' => 'persona haciendo el gesto de "no": tono de piel medio',
    '🙅🏾' => 'persona haciendo el gesto de "no": tono de piel oscuro medio',
    '🙅🏿' => 'persona haciendo el gesto de "no": tono de piel oscuro',
    '🙆🏻' => 'persona haciendo el gesto de "de acuerdo": tono de piel claro',
    '🙆🏼' => 'persona haciendo el gesto de "de acuerdo": tono de piel claro medio',
    '🙆🏽' => 'persona haciendo el gesto de "de acuerdo": tono de piel medio',
    '🙆🏾' => 'persona haciendo el gesto de "de acuerdo": tono de piel oscuro medio',
    '🙆🏿' => 'persona haciendo el gesto de "de acuerdo": tono de piel oscuro',
    '💁🏻' => 'persona de mostrador de información: tono de piel claro',
    '💁🏼' => 'persona de mostrador de información: tono de piel claro medio',
    '💁🏽' => 'persona de mostrador de información: tono de piel medio',
    '💁🏾' => 'persona de mostrador de información: tono de piel oscuro medio',
    '💁🏿' => 'persona de mostrador de información: tono de piel oscuro',
    '🙋🏻' => 'persona con la mano levantada: tono de piel claro',
    '🙋🏼' => 'persona con la mano levantada: tono de piel claro medio',
    '🙋🏽' => 'persona con la mano levantada: tono de piel medio',
    '🙋🏾' => 'persona con la mano levantada: tono de piel oscuro medio',
    '🙋🏿' => 'persona con la mano levantada: tono de piel oscuro',
    '🧏🏻' => 'persona sorda: tono de piel claro',
    '🧏🏼' => 'persona sorda: tono de piel claro medio',
    '🧏🏽' => 'persona sorda: tono de piel medio',
    '🧏🏾' => 'persona sorda: tono de piel oscuro medio',
    '🧏🏿' => 'persona sorda: tono de piel oscuro',
    '🙇🏻' => 'persona haciendo una reverencia: tono de piel claro',
    '🙇🏼' => 'persona haciendo una reverencia: tono de piel claro medio',
    '🙇🏽' => 'persona haciendo una reverencia: tono de piel medio',
    '🙇🏾' => 'persona haciendo una reverencia: tono de piel oscuro medio',
    '🙇🏿' => 'persona haciendo una reverencia: tono de piel oscuro',
    '🤦🏻' => 'persona con la mano en la frente: tono de piel claro',
    '🤦🏼' => 'persona con la mano en la frente: tono de piel claro medio',
    '🤦🏽' => 'persona con la mano en la frente: tono de piel medio',
    '🤦🏾' => 'persona con la mano en la frente: tono de piel oscuro medio',
    '🤦🏿' => 'persona con la mano en la frente: tono de piel oscuro',
    '🤷🏻' => 'persona encogida de hombros: tono de piel claro',
    '🤷🏼' => 'persona encogida de hombros: tono de piel claro medio',
    '🤷🏽' => 'persona encogida de hombros: tono de piel medio',
    '🤷🏾' => 'persona encogida de hombros: tono de piel oscuro medio',
    '🤷🏿' => 'persona encogida de hombros: tono de piel oscuro',
    '👮🏻' => 'agente de policía: tono de piel claro',
    '👮🏼' => 'agente de policía: tono de piel claro medio',
    '👮🏽' => 'agente de policía: tono de piel medio',
    '👮🏾' => 'agente de policía: tono de piel oscuro medio',
    '👮🏿' => 'agente de policía: tono de piel oscuro',
    '🕵🏻' => 'detective: tono de piel claro',
    '🕵🏼' => 'detective: tono de piel claro medio',
    '🕵🏽' => 'detective: tono de piel medio',
    '🕵🏾' => 'detective: tono de piel oscuro medio',
    '🕵🏿' => 'detective: tono de piel oscuro',
    '💂🏻' => 'guardia: tono de piel claro',
    '💂🏼' => 'guardia: tono de piel claro medio',
    '💂🏽' => 'guardia: tono de piel medio',
    '💂🏾' => 'guardia: tono de piel oscuro medio',
    '💂🏿' => 'guardia: tono de piel oscuro',
    '🥷🏻' => 'ninja: tono de piel claro',
    '🥷🏼' => 'ninja: tono de piel claro medio',
    '🥷🏽' => 'ninja: tono de piel medio',
    '🥷🏾' => 'ninja: tono de piel oscuro medio',
    '🥷🏿' => 'ninja: tono de piel oscuro',
    '👷🏻' => 'profesional de la construcción: tono de piel claro',
    '👷🏼' => 'profesional de la construcción: tono de piel claro medio',
    '👷🏽' => 'profesional de la construcción: tono de piel medio',
    '👷🏾' => 'profesional de la construcción: tono de piel oscuro medio',
    '👷🏿' => 'profesional de la construcción: tono de piel oscuro',
    '🫅🏻' => 'persona con corona: tono de piel claro',
    '🫅🏼' => 'persona con corona: tono de piel claro medio',
    '🫅🏽' => 'persona con corona: tono de piel medio',
    '🫅🏾' => 'persona con corona: tono de piel oscuro medio',
    '🫅🏿' => 'persona con corona: tono de piel oscuro',
    '🤴🏻' => 'príncipe: tono de piel claro',
    '🤴🏼' => 'príncipe: tono de piel claro medio',
    '🤴🏽' => 'príncipe: tono de piel medio',
    '🤴🏾' => 'príncipe: tono de piel oscuro medio',
    '🤴🏿' => 'príncipe: tono de piel oscuro',
    '👸🏻' => 'princesa: tono de piel claro',
    '👸🏼' => 'princesa: tono de piel claro medio',
    '👸🏽' => 'princesa: tono de piel medio',
    '👸🏾' => 'princesa: tono de piel oscuro medio',
    '👸🏿' => 'princesa: tono de piel oscuro',
    '👳🏻' => 'persona con turbante: tono de piel claro',
    '👳🏼' => 'persona con turbante: tono de piel claro medio',
    '👳🏽' => 'persona con turbante: tono de piel medio',
    '👳🏾' => 'persona con turbante: tono de piel oscuro medio',
    '👳🏿' => 'persona con turbante: tono de piel oscuro',
    '👲🏻' => 'persona con gorro chino: tono de piel claro',
    '👲🏼' => 'persona con gorro chino: tono de piel claro medio',
    '👲🏽' => 'persona con gorro chino: tono de piel medio',
    '👲🏾' => 'persona con gorro chino: tono de piel oscuro medio',
    '👲🏿' => 'persona con gorro chino: tono de piel oscuro',
    '🧕🏻' => 'mujer con hiyab: tono de piel claro',
    '🧕🏼' => 'mujer con hiyab: tono de piel claro medio',
    '🧕🏽' => 'mujer con hiyab: tono de piel medio',
    '🧕🏾' => 'mujer con hiyab: tono de piel oscuro medio',
    '🧕🏿' => 'mujer con hiyab: tono de piel oscuro',
    '🤵🏻' => 'persona con esmoquin: tono de piel claro',
    '🤵🏼' => 'persona con esmoquin: tono de piel claro medio',
    '🤵🏽' => 'persona con esmoquin: tono de piel medio',
    '🤵🏾' => 'persona con esmoquin: tono de piel oscuro medio',
    '🤵🏿' => 'persona con esmoquin: tono de piel oscuro',
    '👰🏻' => 'persona con velo: tono de piel claro',
    '👰🏼' => 'persona con velo: tono de piel claro medio',
    '👰🏽' => 'persona con velo: tono de piel medio',
    '👰🏾' => 'persona con velo: tono de piel oscuro medio',
    '👰🏿' => 'persona con velo: tono de piel oscuro',
    '🤰🏻' => 'mujer embarazada: tono de piel claro',
    '🤰🏼' => 'mujer embarazada: tono de piel claro medio',
    '🤰🏽' => 'mujer embarazada: tono de piel medio',
    '🤰🏾' => 'mujer embarazada: tono de piel oscuro medio',
    '🤰🏿' => 'mujer embarazada: tono de piel oscuro',
    '🫃🏻' => 'hombre embarazado: tono de piel claro',
    '🫃🏼' => 'hombre embarazado: tono de piel claro medio',
    '🫃🏽' => 'hombre embarazado: tono de piel medio',
    '🫃🏾' => 'hombre embarazado: tono de piel oscuro medio',
    '🫃🏿' => 'hombre embarazado: tono de piel oscuro',
    '🫄🏻' => 'persona embarazada: tono de piel claro',
    '🫄🏼' => 'persona embarazada: tono de piel claro medio',
    '🫄🏽' => 'persona embarazada: tono de piel medio',
    '🫄🏾' => 'persona embarazada: tono de piel oscuro medio',
    '🫄🏿' => 'persona embarazada: tono de piel oscuro',
    '🤱🏻' => 'lactancia materna: tono de piel claro',
    '🤱🏼' => 'lactancia materna: tono de piel claro medio',
    '🤱🏽' => 'lactancia materna: tono de piel medio',
    '🤱🏾' => 'lactancia materna: tono de piel oscuro medio',
    '🤱🏿' => 'lactancia materna: tono de piel oscuro',
    '👼🏻' => 'bebé ángel: tono de piel claro',
    '👼🏼' => 'bebé ángel: tono de piel claro medio',
    '👼🏽' => 'bebé ángel: tono de piel medio',
    '👼🏾' => 'bebé ángel: tono de piel oscuro medio',
    '👼🏿' => 'bebé ángel: tono de piel oscuro',
    '🎅🏻' => 'Papá Noel: tono de piel claro',
    '🎅🏼' => 'Papá Noel: tono de piel claro medio',
    '🎅🏽' => 'Papá Noel: tono de piel medio',
    '🎅🏾' => 'Papá Noel: tono de piel oscuro medio',
    '🎅🏿' => 'Papá Noel: tono de piel oscuro',
    '🤶🏻' => 'Mamá Noel: tono de piel claro',
    '🤶🏼' => 'Mamá Noel: tono de piel claro medio',
    '🤶🏽' => 'Mamá Noel: tono de piel medio',
    '🤶🏾' => 'Mamá Noel: tono de piel oscuro medio',
    '🤶🏿' => 'Mamá Noel: tono de piel oscuro',
    '🦸🏻' => 'personaje de superhéroe: tono de piel claro',
    '🦸🏼' => 'personaje de superhéroe: tono de piel claro medio',
    '🦸🏽' => 'personaje de superhéroe: tono de piel medio',
    '🦸🏾' => 'personaje de superhéroe: tono de piel oscuro medio',
    '🦸🏿' => 'personaje de superhéroe: tono de piel oscuro',
    '🦹🏻' => 'personaje de supervillano: tono de piel claro',
    '🦹🏼' => 'personaje de supervillano: tono de piel claro medio',
    '🦹🏽' => 'personaje de supervillano: tono de piel medio',
    '🦹🏾' => 'personaje de supervillano: tono de piel oscuro medio',
    '🦹🏿' => 'personaje de supervillano: tono de piel oscuro',
    '🧙🏻' => 'persona maga: tono de piel claro',
    '🧙🏼' => 'persona maga: tono de piel claro medio',
    '🧙🏽' => 'persona maga: tono de piel medio',
    '🧙🏾' => 'persona maga: tono de piel oscuro medio',
    '🧙🏿' => 'persona maga: tono de piel oscuro',
    '🧚🏻' => 'hada: tono de piel claro',
    '🧚🏼' => 'hada: tono de piel claro medio',
    '🧚🏽' => 'hada: tono de piel medio',
    '🧚🏾' => 'hada: tono de piel oscuro medio',
    '🧚🏿' => 'hada: tono de piel oscuro',
    '🧛🏻' => 'vampiro: tono de piel claro',
    '🧛🏼' => 'vampiro: tono de piel claro medio',
    '🧛🏽' => 'vampiro: tono de piel medio',
    '🧛🏾' => 'vampiro: tono de piel oscuro medio',
    '🧛🏿' => 'vampiro: tono de piel oscuro',
    '🧜🏻' => 'persona sirena: tono de piel claro',
    '🧜🏼' => 'persona sirena: tono de piel claro medio',
    '🧜🏽' => 'persona sirena: tono de piel medio',
    '🧜🏾' => 'persona sirena: tono de piel oscuro medio',
    '🧜🏿' => 'persona sirena: tono de piel oscuro',
    '🧝🏻' => 'elfo: tono de piel claro',
    '🧝🏼' => 'elfo: tono de piel claro medio',
    '🧝🏽' => 'elfo: tono de piel medio',
    '🧝🏾' => 'elfo: tono de piel oscuro medio',
    '🧝🏿' => 'elfo: tono de piel oscuro',
    '💆🏻' => 'persona recibiendo masaje: tono de piel claro',
    '💆🏼' => 'persona recibiendo masaje: tono de piel claro medio',
    '💆🏽' => 'persona recibiendo masaje: tono de piel medio',
    '💆🏾' => 'persona recibiendo masaje: tono de piel oscuro medio',
    '💆🏿' => 'persona recibiendo masaje: tono de piel oscuro',
    '💇🏻' => 'persona cortándose el pelo: tono de piel claro',
    '💇🏼' => 'persona cortándose el pelo: tono de piel claro medio',
    '💇🏽' => 'persona cortándose el pelo: tono de piel medio',
    '💇🏾' => 'persona cortándose el pelo: tono de piel oscuro medio',
    '💇🏿' => 'persona cortándose el pelo: tono de piel oscuro',
    '🚶🏻' => 'persona caminando: tono de piel claro',
    '🚶🏼' => 'persona caminando: tono de piel claro medio',
    '🚶🏽' => 'persona caminando: tono de piel medio',
    '🚶🏾' => 'persona caminando: tono de piel oscuro medio',
    '🚶🏿' => 'persona caminando: tono de piel oscuro',
    '🧍🏻' => 'persona de pie: tono de piel claro',
    '🧍🏼' => 'persona de pie: tono de piel claro medio',
    '🧍🏽' => 'persona de pie: tono de piel medio',
    '🧍🏾' => 'persona de pie: tono de piel oscuro medio',
    '🧍🏿' => 'persona de pie: tono de piel oscuro',
    '🧎🏻' => 'persona de rodillas: tono de piel claro',
    '🧎🏼' => 'persona de rodillas: tono de piel claro medio',
    '🧎🏽' => 'persona de rodillas: tono de piel medio',
    '🧎🏾' => 'persona de rodillas: tono de piel oscuro medio',
    '🧎🏿' => 'persona de rodillas: tono de piel oscuro',
    '🏃🏻' => 'persona corriendo: tono de piel claro',
    '🏃🏼' => 'persona corriendo: tono de piel claro medio',
    '🏃🏽' => 'persona corriendo: tono de piel medio',
    '🏃🏾' => 'persona corriendo: tono de piel oscuro medio',
    '🏃🏿' => 'persona corriendo: tono de piel oscuro',
    '💃🏻' => 'mujer bailando: tono de piel claro',
    '💃🏼' => 'mujer bailando: tono de piel claro medio',
    '💃🏽' => 'mujer bailando: tono de piel medio',
    '💃🏾' => 'mujer bailando: tono de piel oscuro medio',
    '💃🏿' => 'mujer bailando: tono de piel oscuro',
    '🕺🏻' => 'hombre bailando: tono de piel claro',
    '🕺🏼' => 'hombre bailando: tono de piel claro medio',
    '🕺🏽' => 'hombre bailando: tono de piel medio',
    '🕺🏾' => 'hombre bailando: tono de piel oscuro medio',
    '🕺🏿' => 'hombre bailando: tono de piel oscuro',
    '🕴🏻' => 'persona trajeada levitando: tono de piel claro',
    '🕴🏼' => 'persona trajeada levitando: tono de piel claro medio',
    '🕴🏽' => 'persona trajeada levitando: tono de piel medio',
    '🕴🏾' => 'persona trajeada levitando: tono de piel oscuro medio',
    '🕴🏿' => 'persona trajeada levitando: tono de piel oscuro',
    '👯🏻' => 'personas con orejas de conejo: tono de piel claro',
    '👯🏼' => 'personas con orejas de conejo: tono de piel claro medio',
    '👯🏽' => 'personas con orejas de conejo: tono de piel medio',
    '👯🏾' => 'personas con orejas de conejo: tono de piel oscuro medio',
    '👯🏿' => 'personas con orejas de conejo: tono de piel oscuro',
    '🧖🏻' => 'persona en una sauna: tono de piel claro',
    '🧖🏼' => 'persona en una sauna: tono de piel claro medio',
    '🧖🏽' => 'persona en una sauna: tono de piel medio',
    '🧖🏾' => 'persona en una sauna: tono de piel oscuro medio',
    '🧖🏿' => 'persona en una sauna: tono de piel oscuro',
    '🧗🏻' => 'persona escalando: tono de piel claro',
    '🧗🏼' => 'persona escalando: tono de piel claro medio',
    '🧗🏽' => 'persona escalando: tono de piel medio',
    '🧗🏾' => 'persona escalando: tono de piel oscuro medio',
    '🧗🏿' => 'persona escalando: tono de piel oscuro',
    '🏇🏻' => 'carrera de caballos: tono de piel claro',
    '🏇🏼' => 'carrera de caballos: tono de piel claro medio',
    '🏇🏽' => 'carrera de caballos: tono de piel medio',
    '🏇🏾' => 'carrera de caballos: tono de piel oscuro medio',
    '🏇🏿' => 'carrera de caballos: tono de piel oscuro',
    '🏂🏻' => 'practicante de snowboard: tono de piel claro',
    '🏂🏼' => 'practicante de snowboard: tono de piel claro medio',
    '🏂🏽' => 'practicante de snowboard: tono de piel medio',
    '🏂🏾' => 'practicante de snowboard: tono de piel oscuro medio',
    '🏂🏿' => 'practicante de snowboard: tono de piel oscuro',
    '🏌🏻' => 'persona jugando al golf: tono de piel claro',
    '🏌🏼' => 'persona jugando al golf: tono de piel claro medio',
    '🏌🏽' => 'persona jugando al golf: tono de piel medio',
    '🏌🏾' => 'persona jugando al golf: tono de piel oscuro medio',
    '🏌🏿' => 'persona jugando al golf: tono de piel oscuro',
    '🏄🏻' => 'persona haciendo surf: tono de piel claro',
    '🏄🏼' => 'persona haciendo surf: tono de piel claro medio',
    '🏄🏽' => 'persona haciendo surf: tono de piel medio',
    '🏄🏾' => 'persona haciendo surf: tono de piel oscuro medio',
    '🏄🏿' => 'persona haciendo surf: tono de piel oscuro',
    '🚣🏻' => 'persona remando en un bote: tono de piel claro',
    '🚣🏼' => 'persona remando en un bote: tono de piel claro medio',
    '🚣🏽' => 'persona remando en un bote: tono de piel medio',
    '🚣🏾' => 'persona remando en un bote: tono de piel oscuro medio',
    '🚣🏿' => 'persona remando en un bote: tono de piel oscuro',
    '🏊🏻' => 'persona nadando: tono de piel claro',
    '🏊🏼' => 'persona nadando: tono de piel claro medio',
    '🏊🏽' => 'persona nadando: tono de piel medio',
    '🏊🏾' => 'persona nadando: tono de piel oscuro medio',
    '🏊🏿' => 'persona nadando: tono de piel oscuro',
    '⛹🏻' => 'persona botando un balón: tono de piel claro',
    '⛹🏼' => 'persona botando un balón: tono de piel claro medio',
    '⛹🏽' => 'persona botando un balón: tono de piel medio',
    '⛹🏾' => 'persona botando un balón: tono de piel oscuro medio',
    '⛹🏿' => 'persona botando un balón: tono de piel oscuro',
    '🏋🏻' => 'persona levantando pesas: tono de piel claro',
    '🏋🏼' => 'persona levantando pesas: tono de piel claro medio',
    '🏋🏽' => 'persona levantando pesas: tono de piel medio',
    '🏋🏾' => 'persona levantando pesas: tono de piel oscuro medio',
    '🏋🏿' => 'persona levantando pesas: tono de piel oscuro',
    '🚴🏻' => 'persona en bicicleta: tono de piel claro',
    '🚴🏼' => 'persona en bicicleta: tono de piel claro medio',
    '🚴🏽' => 'persona en bicicleta: tono de piel medio',
    '🚴🏾' => 'persona en bicicleta: tono de piel oscuro medio',
    '🚴🏿' => 'persona en bicicleta: tono de piel oscuro',
    '🚵🏻' => 'persona en bicicleta de montaña: tono de piel claro',
    '🚵🏼' => 'persona en bicicleta de montaña: tono de piel claro medio',
    '🚵🏽' => 'persona en bicicleta de montaña: tono de piel medio',
    '🚵🏾' => 'persona en bicicleta de montaña: tono de piel oscuro medio',
    '🚵🏿' => 'persona en bicicleta de montaña: tono de piel oscuro',
    '🤸🏻' => 'persona haciendo voltereta lateral: tono de piel claro',
    '🤸🏼' => 'persona haciendo voltereta lateral: tono de piel claro medio',
    '🤸🏽' => 'persona haciendo voltereta lateral: tono de piel medio',
    '🤸🏾' => 'persona haciendo voltereta lateral: tono de piel oscuro medio',
    '🤸🏿' => 'persona haciendo voltereta lateral: tono de piel oscuro',
    '🤼🏻' => 'personas luchando: tono de piel claro',
    '🤼🏼' => 'personas luchando: tono de piel claro medio',
    '🤼🏽' => 'personas luchando: tono de piel medio',
    '🤼🏾' => 'personas luchando: tono de piel oscuro medio',
    '🤼🏿' => 'personas luchando: tono de piel oscuro',
    '🤽🏻' => 'persona jugando al waterpolo: tono de piel claro',
    '🤽🏼' => 'persona jugando al waterpolo: tono de piel claro medio',
    '🤽🏽' => 'persona jugando al waterpolo: tono de piel medio',
    '🤽🏾' => 'persona jugando al waterpolo: tono de piel oscuro medio',
    '🤽🏿' => 'persona jugando al waterpolo: tono de piel oscuro',
    '🤾🏻' => 'persona jugando al balonmano: tono de piel claro',
    '🤾🏼' => 'persona jugando al balonmano: tono de piel claro medio',
    '🤾🏽' => 'persona jugando al balonmano: tono de piel medio',
    '🤾🏾' => 'persona jugando al balonmano: tono de piel oscuro medio',
    '🤾🏿' => 'persona jugando al balonmano: tono de piel oscuro',
    '🤹🏻' => 'persona haciendo malabares: tono de piel claro',
    '🤹🏼' => 'persona haciendo malabares: tono de piel claro medio',
    '🤹🏽' => 'persona haciendo malabares: tono de piel medio',
    '🤹🏾' => 'persona haciendo malabares: tono de piel oscuro medio',
    '🤹🏿' => 'persona haciendo malabares: tono de piel oscuro',
    '🧘🏻' => 'persona en posición de loto: tono de piel claro',
    '🧘🏼' => 'persona en posición de loto: tono de piel claro medio',
    '🧘🏽' => 'persona en posición de loto: tono de piel medio',
    '🧘🏾' => 'persona en posición de loto: tono de piel oscuro medio',
    '🧘🏿' => 'persona en posición de loto: tono de piel oscuro',
    '🛀🏻' => 'persona en la bañera: tono de piel claro',
    '🛀🏼' => 'persona en la bañera: tono de piel claro medio',
    '🛀🏽' => 'persona en la bañera: tono de piel medio',
    '🛀🏾' => 'persona en la bañera: tono de piel oscuro medio',
    '🛀🏿' => 'persona en la bañera: tono de piel oscuro',
    '🛌🏻' => 'persona en la cama: tono de piel claro',
    '🛌🏼' => 'persona en la cama: tono de piel claro medio',
    '🛌🏽' => 'persona en la cama: tono de piel medio',
    '🛌🏾' => 'persona en la cama: tono de piel oscuro medio',
    '🛌🏿' => 'persona en la cama: tono de piel oscuro',
    '👭🏻' => 'mujeres de la mano: tono de piel claro',
    '👭🏼' => 'mujeres de la mano: tono de piel claro medio',
    '👭🏽' => 'mujeres de la mano: tono de piel medio',
    '👭🏾' => 'mujeres de la mano: tono de piel oscuro medio',
    '👭🏿' => 'mujeres de la mano: tono de piel oscuro',
    '👫🏻' => 'mujer y hombre de la mano: tono de piel claro',
    '👫🏼' => 'mujer y hombre de la mano: tono de piel claro medio',
    '👫🏽' => 'mujer y hombre de la mano: tono de piel medio',
    '👫🏾' => 'mujer y hombre de la mano: tono de piel oscuro medio',
    '👫🏿' => 'mujer y hombre de la mano: tono de piel oscuro',
    '👬🏻' => 'hombres de la mano: tono de piel claro',
    '👬🏼' => 'hombres de la mano: tono de piel claro medio',
    '👬🏽' => 'hombres de la mano: tono de piel medio',
    '👬🏾' => 'hombres de la mano: tono de piel oscuro medio',
    '👬🏿' => 'hombres de la mano: tono de piel oscuro',
    '💏🏻' => 'beso: tono de piel claro',
    '💏🏼' => 'beso: tono de piel claro medio',
    '💏🏽' => 'beso: tono de piel medio',
    '💏🏾' => 'beso: tono de piel oscuro medio',
    '💏🏿' => 'beso: tono de piel oscuro',
    '💑🏻' => 'pareja enamorada: tono de piel claro',
    '💑🏼' => 'pareja enamorada: tono de piel claro medio',
    '💑🏽' => 'pareja enamorada: tono de piel medio',
    '💑🏾' => 'pareja enamorada: tono de piel oscuro medio',
    '💑🏿' => 'pareja enamorada: tono de piel oscuro',
    '🇦🇨' => 'Bandera: Isla de la Ascensión',
    '🇦🇩' => 'Bandera: Andorra',
    '🇦🇪' => 'Bandera: Emiratos Árabes Unidos',
    '🇦🇫' => 'Bandera: Afganistán',
    '🇦🇬' => 'Bandera: Antigua y Barbuda',
    '🇦🇮' => 'Bandera: Anguila',
    '🇦🇱' => 'Bandera: Albania',
    '🇦🇲' => 'Bandera: Armenia',
    '🇦🇴' => 'Bandera: Angola',
    '🇦🇶' => 'Bandera: Antártida',
    '🇦🇷' => 'Bandera: Argentina',
    '🇦🇸' => 'Bandera: Samoa Americana',
    '🇦🇹' => 'Bandera: Austria',
    '🇦🇺' => 'Bandera: Australia',
    '🇦🇼' => 'Bandera: Aruba',
    '🇦🇽' => 'Bandera: Islas Aland',
    '🇦🇿' => 'Bandera: Azerbaiyán',
    '🇧🇦' => 'Bandera: Bosnia y Herzegovina',
    '🇧🇧' => 'Bandera: Barbados',
    '🇧🇩' => 'Bandera: Bangladés',
    '🇧🇪' => 'Bandera: Bélgica',
    '🇧🇫' => 'Bandera: Burkina Faso',
    '🇧🇬' => 'Bandera: Bulgaria',
    '🇧🇭' => 'Bandera: Baréin',
    '🇧🇮' => 'Bandera: Burundi',
    '🇧🇯' => 'Bandera: Benín',
    '🇧🇱' => 'Bandera: San Bartolomé',
    '🇧🇲' => 'Bandera: Bermudas',
    '🇧🇳' => 'Bandera: Brunéi',
    '🇧🇴' => 'Bandera: Bolivia',
    '🇧🇶' => 'Bandera: Caribe neerlandés',
    '🇧🇷' => 'Bandera: Brasil',
    '🇧🇸' => 'Bandera: Bahamas',
    '🇧🇹' => 'Bandera: Bután',
    '🇧🇻' => 'Bandera: Isla Bouvet',
    '🇧🇼' => 'Bandera: Botsuana',
    '🇧🇾' => 'Bandera: Bielorrusia',
    '🇧🇿' => 'Bandera: Belice',
    '🇨🇦' => 'Bandera: Canadá',
    '🇨🇨' => 'Bandera: Islas Cocos',
    '🇨🇩' => 'Bandera: República Democrática del Congo',
    '🇨🇫' => 'Bandera: República Centroafricana',
    '🇨🇬' => 'Bandera: Congo',
    '🇨🇭' => 'Bandera: Suiza',
    '🇨🇮' => 'Bandera: Côte d’Ivoire',
    '🇨🇰' => 'Bandera: Islas Cook',
    '🇨🇱' => 'Bandera: Chile',
    '🇨🇲' => 'Bandera: Camerún',
    '🇨🇳' => 'Bandera: China',
    '🇨🇴' => 'Bandera: Colombia',
    '🇨🇵' => 'Bandera: Isla Clipperton',
    '🇨🇶' => 'Bandera: Sark',
    '🇨🇷' => 'Bandera: Costa Rica',
    '🇨🇺' => 'Bandera: Cuba',
    '🇨🇻' => 'Bandera: Cabo Verde',
    '🇨🇼' => 'Bandera: Curazao',
    '🇨🇽' => 'Bandera: Isla de Navidad',
    '🇨🇾' => 'Bandera: Chipre',
    '🇨🇿' => 'Bandera: Chequia',
    '🇩🇪' => 'Bandera: Alemania',
    '🇩🇬' => 'Bandera: Diego García',
    '🇩🇯' => 'Bandera: Yibuti',
    '🇩🇰' => 'Bandera: Dinamarca',
    '🇩🇲' => 'Bandera: Dominica',
    '🇩🇴' => 'Bandera: República Dominicana',
    '🇩🇿' => 'Bandera: Argelia',
    '🇪🇦' => 'Bandera: Ceuta y Melilla',
    '🇪🇨' => 'Bandera: Ecuador',
    '🇪🇪' => 'Bandera: Estonia',
    '🇪🇬' => 'Bandera: Egipto',
    '🇪🇭' => 'Bandera: Sáhara Occidental',
    '🇪🇷' => 'Bandera: Eritrea',
    '🇪🇸' => 'Bandera: España',
    '🇪🇹' => 'Bandera: Etiopía',
    '🇪🇺' => 'Bandera: Unión Europea',
    '🇫🇮' => 'Bandera: Finlandia',
    '🇫🇯' => 'Bandera: Fiyi',
    '🇫🇰' => 'Bandera: Islas Malvinas',
    '🇫🇲' => 'Bandera: Micronesia',
    '🇫🇴' => 'Bandera: Islas Feroe',
    '🇫🇷' => 'Bandera: Francia',
    '🇬🇦' => 'Bandera: Gabón',
    '🇬🇧' => 'Bandera: Reino Unido',
    '🇬🇩' => 'Bandera: Granada',
    '🇬🇪' => 'Bandera: Georgia',
    '🇬🇫' => 'Bandera: Guayana Francesa',
    '🇬🇬' => 'Bandera: Guernesey',
    '🇬🇭' => 'Bandera: Ghana',
    '🇬🇮' => 'Bandera: Gibraltar',
    '🇬🇱' => 'Bandera: Groenlandia',
    '🇬🇲' => 'Bandera: Gambia',
    '🇬🇳' => 'Bandera: Guinea',
    '🇬🇵' => 'Bandera: Guadalupe',
    '🇬🇶' => 'Bandera: Guinea Ecuatorial',
    '🇬🇷' => 'Bandera: Grecia',
    '🇬🇸' => 'Bandera: Islas Georgia del Sur y Sandwich del Sur',
    '🇬🇹' => 'Bandera: Guatemala',
    '🇬🇺' => 'Bandera: Guam',
    '🇬🇼' => 'Bandera: Guinea-Bisáu',
    '🇬🇾' => 'Bandera: Guyana',
    '🇭🇰' => 'Bandera: RAE de Hong Kong (China)',
    '🇭🇲' => 'Bandera: Islas Heard y McDonald',
    '🇭🇳' => 'Bandera: Honduras',
    '🇭🇷' => 'Bandera: Croacia',
    '🇭🇹' => 'Bandera: Haití',
    '🇭🇺' => 'Bandera: Hungría',
    '🇮🇨' => 'Bandera: Canarias',
    '🇮🇩' => 'Bandera: Indonesia',
    '🇮🇪' => 'Bandera: Irlanda',
    '🇮🇱' => 'Bandera: Israel',
    '🇮🇲' => 'Bandera: Isla de Man',
    '🇮🇳' => 'Bandera: India',
    '🇮🇴' => 'Bandera: Territorio Británico del Océano Índico',
    '🇮🇶' => 'Bandera: Irak',
    '🇮🇷' => 'Bandera: Irán',
    '🇮🇸' => 'Bandera: Islandia',
    '🇮🇹' => 'Bandera: Italia',
    '🇯🇪' => 'Bandera: Jersey',
    '🇯🇲' => 'Bandera: Jamaica',
    '🇯🇴' => 'Bandera: Jordania',
    '🇯🇵' => 'Bandera: Japón',
    '🇰🇪' => 'Bandera: Kenia',
    '🇰🇬' => 'Bandera: Kirguistán',
    '🇰🇭' => 'Bandera: Camboya',
    '🇰🇮' => 'Bandera: Kiribati',
    '🇰🇲' => 'Bandera: Comoras',
    '🇰🇳' => 'Bandera: San Cristóbal y Nieves',
    '🇰🇵' => 'Bandera: Corea del Norte',
    '🇰🇷' => 'Bandera: Corea del Sur',
    '🇰🇼' => 'Bandera: Kuwait',
    '🇰🇾' => 'Bandera: Islas Caimán',
    '🇰🇿' => 'Bandera: Kazajistán',
    '🇱🇦' => 'Bandera: Laos',
    '🇱🇧' => 'Bandera: Líbano',
    '🇱🇨' => 'Bandera: Santa Lucía',
    '🇱🇮' => 'Bandera: Liechtenstein',
    '🇱🇰' => 'Bandera: Sri Lanka',
    '🇱🇷' => 'Bandera: Liberia',
    '🇱🇸' => 'Bandera: Lesoto',
    '🇱🇹' => 'Bandera: Lituania',
    '🇱🇺' => 'Bandera: Luxemburgo',
    '🇱🇻' => 'Bandera: Letonia',
    '🇱🇾' => 'Bandera: Libia',
    '🇲🇦' => 'Bandera: Marruecos',
    '🇲🇨' => 'Bandera: Mónaco',
    '🇲🇩' => 'Bandera: Moldavia',
    '🇲🇪' => 'Bandera: Montenegro',
    '🇲🇫' => 'Bandera: San Martín',
    '🇲🇬' => 'Bandera: Madagascar',
    '🇲🇭' => 'Bandera: Islas Marshall',
    '🇲🇰' => 'Bandera: Macedonia del Norte',
    '🇲🇱' => 'Bandera: Mali',
    '🇲🇲' => 'Bandera: Myanmar (Birmania)',
    '🇲🇳' => 'Bandera: Mongolia',
    '🇲🇴' => 'Bandera: RAE de Macao (China)',
    '🇲🇵' => 'Bandera: Islas Marianas del Norte',
    '🇲🇶' => 'Bandera: Martinica',
    '🇲🇷' => 'Bandera: Mauritania',
    '🇲🇸' => 'Bandera: Montserrat',
    '🇲🇹' => 'Bandera: Malta',
    '🇲🇺' => 'Bandera: Mauricio',
    '🇲🇻' => 'Bandera: Maldivas',
    '🇲🇼' => 'Bandera: Malaui',
    '🇲🇽' => 'Bandera: México',
    '🇲🇾' => 'Bandera: Malasia',
    '🇲🇿' => 'Bandera: Mozambique',
    '🇳🇦' => 'Bandera: Namibia',
    '🇳🇨' => 'Bandera: Nueva Caledonia',
    '🇳🇪' => 'Bandera: Níger',
    '🇳🇫' => 'Bandera: Isla Norfolk',
    '🇳🇬' => 'Bandera: Nigeria',
    '🇳🇮' => 'Bandera: Nicaragua',
    '🇳🇱' => 'Bandera: Países Bajos',
    '🇳🇴' => 'Bandera: Noruega',
    '🇳🇵' => 'Bandera: Nepal',
    '🇳🇷' => 'Bandera: Nauru',
    '🇳🇺' => 'Bandera: Niue',
    '🇳🇿' => 'Bandera: Nueva Zelanda',
    '🇴🇲' => 'Bandera: Omán',
    '🇵🇦' => 'Bandera: Panamá',
    '🇵🇪' => 'Bandera: Perú',
    '🇵🇫' => 'Bandera: Polinesia Francesa',
    '🇵🇬' => 'Bandera: Papúa Nueva Guinea',
    '🇵🇭' => 'Bandera: Filipinas',
    '🇵🇰' => 'Bandera: Pakistán',
    '🇵🇱' => 'Bandera: Polonia',
    '🇵🇲' => 'Bandera: San Pedro y Miquelón',
    '🇵🇳' => 'Bandera: Islas Pitcairn',
    '🇵🇷' => 'Bandera: Puerto Rico',
    '🇵🇸' => 'Bandera: Territorios Palestinos',
    '🇵🇹' => 'Bandera: Portugal',
    '🇵🇼' => 'Bandera: Palaos',
    '🇵🇾' => 'Bandera: Paraguay',
    '🇶🇦' => 'Bandera: Catar',
    '🇷🇪' => 'Bandera: Reunión',
    '🇷🇴' => 'Bandera: Rumanía',
    '🇷🇸' => 'Bandera: Serbia',
    '🇷🇺' => 'Bandera: Rusia',
    '🇷🇼' => 'Bandera: Ruanda',
    '🇸🇦' => 'Bandera: Arabia Saudí',
    '🇸🇧' => 'Bandera: Islas Salomón',
    '🇸🇨' => 'Bandera: Seychelles',
    '🇸🇩' => 'Bandera: Sudán',
    '🇸🇪' => 'Bandera: Suecia',
    '🇸🇬' => 'Bandera: Singapur',
    '🇸🇭' => 'Bandera: Santa Elena',
    '🇸🇮' => 'Bandera: Eslovenia',
    '🇸🇯' => 'Bandera: Svalbard y Jan Mayen',
    '🇸🇰' => 'Bandera: Eslovaquia',
    '🇸🇱' => 'Bandera: Sierra Leona',
    '🇸🇲' => 'Bandera: San Marino',
    '🇸🇳' => 'Bandera: Senegal',
    '🇸🇴' => 'Bandera: Somalia',
    '🇸🇷' => 'Bandera: Surinam',
    '🇸🇸' => 'Bandera: Sudán del Sur',
    '🇸🇹' => 'Bandera: Santo Tomé y Príncipe',
    '🇸🇻' => 'Bandera: El Salvador',
    '🇸🇽' => 'Bandera: Sint Maarten',
    '🇸🇾' => 'Bandera: Siria',
    '🇸🇿' => 'Bandera: Esuatini',
    '🇹🇦' => 'Bandera: Tristán de Acuña',
    '🇹🇨' => 'Bandera: Islas Turcas y Caicos',
    '🇹🇩' => 'Bandera: Chad',
    '🇹🇫' => 'Bandera: Territorios Australes Franceses',
    '🇹🇬' => 'Bandera: Togo',
    '🇹🇭' => 'Bandera: Tailandia',
    '🇹🇯' => 'Bandera: Tayikistán',
    '🇹🇰' => 'Bandera: Tokelau',
    '🇹🇱' => 'Bandera: Timor-Leste',
    '🇹🇲' => 'Bandera: Turkmenistán',
    '🇹🇳' => 'Bandera: Túnez',
    '🇹🇴' => 'Bandera: Tonga',
    '🇹🇷' => 'Bandera: Turquía',
    '🇹🇹' => 'Bandera: Trinidad y Tobago',
    '🇹🇻' => 'Bandera: Tuvalu',
    '🇹🇼' => 'Bandera: Taiwán',
    '🇹🇿' => 'Bandera: Tanzania',
    '🇺🇦' => 'Bandera: Ucrania',
    '🇺🇬' => 'Bandera: Uganda',
    '🇺🇲' => 'Bandera: Islas menores alejadas de EE. UU.',
    '🇺🇳' => 'Bandera: Naciones Unidas',
    '🇺🇸' => 'Bandera: Estados Unidos',
    '🇺🇾' => 'Bandera: Uruguay',
    '🇺🇿' => 'Bandera: Uzbekistán',
    '🇻🇦' => 'Bandera: Ciudad del Vaticano',
    '🇻🇨' => 'Bandera: San Vicente y las Granadinas',
    '🇻🇪' => 'Bandera: Venezuela',
    '🇻🇬' => 'Bandera: Islas Vírgenes Británicas',
    '🇻🇮' => 'Bandera: Islas Vírgenes de EE. UU.',
    '🇻🇳' => 'Bandera: Vietnam',
    '🇻🇺' => 'Bandera: Vanuatu',
    '🇼🇫' => 'Bandera: Wallis y Futuna',
    '🇼🇸' => 'Bandera: Samoa',
    '🇽🇰' => 'Bandera: Kosovo',
    '🇾🇪' => 'Bandera: Yemen',
    '🇾🇹' => 'Bandera: Mayotte',
    '🇿🇦' => 'Bandera: Sudáfrica',
    '🇿🇲' => 'Bandera: Zambia',
    '🇿🇼' => 'Bandera: Zimbabue',
    '🔟' => 'Teclas: 10',
    '🏻' => 'tono de piel claro',
    '🏼' => 'tono de piel claro medio',
    '🏽' => 'tono de piel medio',
    '🏾' => 'tono de piel oscuro medio',
    '🏿' => 'tono de piel oscuro',
    '😀' => 'cara sonriendo',
    '😃' => 'cara sonriendo con ojos grandes',
    '😄' => 'cara sonriendo con ojos sonrientes',
    '😁' => 'cara radiante con ojos sonrientes',
    '😆' => 'cara sonriendo con los ojos cerrados',
    '😅' => 'cara sonriendo con sudor frío',
    '🤣' => 'cara revolviéndose de la risa',
    '😂' => 'cara llorando de risa',
    '🙂' => 'cara sonriendo ligeramente',
    '🙃' => 'cara al revés',
    '🫠' => 'cara derritiéndose',
    '😉' => 'cara guiñando el ojo',
    '😊' => 'cara feliz con ojos sonrientes',
    '😇' => 'cara sonriendo con aureola',
    '🥰' => 'cara sonriendo con corazones',
    '😍' => 'cara sonriendo con ojos de corazón',
    '🤩' => 'cara sonriendo con estrellas',
    '😘' => 'cara lanzando un beso',
    '😗' => 'cara besando',
    '☺' => 'cara sonriente',
    '😚' => 'cara besando con los ojos cerrados',
    '😙' => 'cara besando con ojos sonrientes',
    '🥲' => 'cara sonriente con lágrima',
    '😋' => 'cara saboreando comida',
    '😛' => 'cara sacando la lengua',
    '😜' => 'cara sacando la lengua y guiñando un ojo',
    '🤪' => 'cara de loco',
    '😝' => 'cara con ojos cerrados y lengua fuera',
    '🤑' => 'cara con lengua de dinero',
    '🤗' => 'cara con manos abrazando',
    '🤭' => 'cara con mano sobre la boca',
    '🫢' => 'cara con ojos abiertos y boca tapada',
    '🫣' => 'cara tapada con ojo espiando',
    '🤫' => 'cara pidiendo silencio',
    '🤔' => 'cara pensativa',
    '🫡' => 'cara saludando',
    '🤐' => 'cara con la boca cerrada con cremallera',
    '🤨' => 'cara con ceja alzada',
    '😐' => 'cara neutral',
    '😑' => 'cara sin expresión',
    '😶' => 'cara sin boca',
    '🫥' => 'cara con línea de puntos',
    '😏' => 'cara sonriendo con superioridad',
    '😒' => 'cara de desaprobación',
    '🙄' => 'cara con ojos en blanco',
    '😬' => 'cara haciendo una mueca',
    '🤥' => 'cara de mentiroso',
    '🫨' => 'cara temblorosa',
    '😌' => 'cara de alivio',
    '😔' => 'cara desanimada',
    '😪' => 'cara de sueño',
    '🤤' => 'cara babeando',
    '😴' => 'cara durmiendo',
    '🫩' => 'cara con ojeras',
    '😷' => 'cara con mascarilla médica',
    '🤒' => 'cara con termómetro',
    '🤕' => 'cara con la cabeza vendada',
    '🤢' => 'cara de náuseas',
    '🤮' => 'cara vomitando',
    '🤧' => 'cara estornudando',
    '🥵' => 'cara con calor',
    '🥶' => 'cara con frío',
    '🥴' => 'cara de grogui',
    '😵' => 'cara mareada',
    '🤯' => 'cabeza explotando',
    '🤠' => 'cara con sombrero de vaquero',
    '🥳' => 'cara de fiesta',
    '🥸' => 'cara disfrazada',
    '😎' => 'cara sonriendo con gafas de sol',
    '🤓' => 'cara de empollón',
    '🧐' => 'cara con monóculo',
    '😕' => 'cara de confusión',
    '🫤' => 'cara con boca diagonal',
    '😟' => 'cara preocupada',
    '🙁' => 'cara con el ceño ligeramente fruncido',
    '☹' => 'cara con el ceño fruncido',
    '😮' => 'cara con la boca abierta',
    '😯' => 'cara estupefacta',
    '😲' => 'cara asombrada',
    '😳' => 'cara sonrojada',
    '🫪' => 'cara deformada',
    '🥺' => 'cara suplicante',
    '🥹' => 'cara aguantándose las lágrimas',
    '😦' => 'cara con el ceño fruncido y la boca abierta',
    '😧' => 'cara angustiada',
    '😨' => 'cara asustada',
    '😰' => 'cara con ansiedad y sudor',
    '😥' => 'cara triste pero aliviada',
    '😢' => 'cara llorando',
    '😭' => 'cara llorando fuerte',
    '😱' => 'cara gritando de miedo',
    '😖' => 'cara de frustración',
    '😣' => 'cara desesperada',
    '😞' => 'cara decepcionada',
    '😓' => 'cara con sudor frío',
    '😩' => 'cara agotada',
    '😫' => 'cara cansada',
    '🥱' => 'cara de bostezo',
    '😤' => 'cara resoplando',
    '😡' => 'cara cabreada',
    '😠' => 'cara enfadada',
    '🤬' => 'cara con símbolos en la boca',
    '😈' => 'cara sonriendo con cuernos',
    '👿' => 'cara enfadada con cuernos',
    '💀' => 'calavera',
    '☠' => 'calavera y huesos cruzados',
    '💩' => 'caca con ojos',
    '🤡' => 'cara de payaso',
    '👹' => 'demonio japonés oni',
    '👺' => 'demonio japonés tengu',
    '👻' => 'fantasma',
    '👽' => 'alienígena',
    '👾' => 'monstruo alienígena',
    '🤖' => 'robot',
    '😺' => 'gato sonriendo',
    '😸' => 'gato sonriendo con ojos sonrientes',
    '😹' => 'gato llorando de risa',
    '😻' => 'gato sonriendo con ojos de corazón',
    '😼' => 'gato haciendo una mueca',
    '😽' => 'gato besando',
    '🙀' => 'gato asustado',
    '😿' => 'gato llorando',
    '😾' => 'gato enfadado',
    '🙈' => 'mono con los ojos tapados',
    '🙉' => 'mono con los oídos tapados',
    '🙊' => 'mono con la boca tapada',
    '💌' => 'carta de amor',
    '💘' => 'corazón con flecha',
    '💝' => 'corazón con lazo',
    '💖' => 'corazón brillante',
    '💗' => 'corazón creciente',
    '💓' => 'corazón latiendo',
    '💞' => 'corazones giratorios',
    '💕' => 'dos corazones',
    '💟' => 'adorno de corazón',
    '❣' => 'exclamación de corazón',
    '💔' => 'corazón roto',
    '❤' => 'corazón rojo',
    '🩷' => 'corazón rosa',
    '🧡' => 'corazón naranja',
    '💛' => 'corazón amarillo',
    '💚' => 'corazón verde',
    '💙' => 'corazón azul',
    '🩵' => 'corazón azul claro',
    '💜' => 'corazón morado',
    '🤎' => 'corazón marrón',
    '🖤' => 'corazón negro',
    '🩶' => 'corazón gris',
    '🤍' => 'corazón blanco',
    '💋' => 'marca de beso',
    '💯' => 'cien puntos',
    '💢' => 'símbolo de enfado',
    '🫯' => 'nube de pelea',
    '💥' => 'colisión',
    '💫' => 'símbolo de mareo',
    '💦' => 'gotas de sudor',
    '💨' => 'salir corriendo',
    '🕳' => 'agujero',
    '💬' => 'bocadillo de diálogo',
    '🗨' => 'bocadillo de diálogo por la izquierda',
    '🗯' => 'bocadillo de enfado por la derecha',
    '💭' => 'bocadillo de pensamiento',
    '💤' => 'símbolo de sueño',
    '👋' => 'mano saludando',
    '🤚' => 'dorso de la mano',
    '🖐' => 'mano abierta',
    '✋' => 'mano levantada',
    '🖖' => 'saludo vulcano',
    '🫱' => 'mano hacia la derecha',
    '🫲' => 'mano hacia la izquierda',
    '🫳' => 'mano con la palma hacia abajo',
    '🫴' => 'mano con la palma hacia arriba',
    '🫷' => 'mano empujando hacia la izquierda',
    '🫸' => 'mano empujando hacia la derecha',
    '👌' => 'señal de aprobación con la mano',
    '🤌' => 'dedos juntos apuntando hacia arriba',
    '🤏' => 'mano pellizcando',
    '✌' => 'mano con señal de victoria',
    '🤞' => 'dedos cruzados',
    '🫰' => 'mano con dedo índice y pulgar cruzados',
    '🤟' => 'gesto de te quiero',
    '🤘' => 'mano haciendo el signo de cuernos',
    '🤙' => 'mano haciendo el gesto de llamar',
    '👈' => 'dorso de mano con índice a la izquierda',
    '👉' => 'dorso de mano con índice a la derecha',
    '👆' => 'dorso de mano con índice hacia arriba',
    '🖕' => 'dedo corazón hacia arriba',
    '👇' => 'dorso de mano con índice hacia abajo',
    '☝' => 'dedo índice hacia arriba',
    '🫵' => 'dedo índice apuntándote a ti',
    '👍' => 'pulgar hacia arriba',
    '👎' => 'pulgar hacia abajo',
    '✊' => 'puño en alto',
    '👊' => 'puño cerrado',
    '🤛' => 'puño hacia la izquierda',
    '🤜' => 'puño hacia la derecha',
    '👏' => 'manos aplaudiendo',
    '🙌' => 'manos levantadas celebrando',
    '🫶' => 'manos formando un corazón',
    '👐' => 'manos abiertas',
    '🤲' => 'palmas hacia arriba juntas',
    '🤝' => 'apretón de manos',
    '🙏' => 'manos en oración',
    '✍' => 'mano escribiendo',
    '💅' => 'pintarse las uñas',
    '🤳' => 'selfi',
    '💪' => 'bíceps flexionado',
    '🦾' => 'brazo mecánico',
    '🦿' => 'pierna mecánica',
    '🦵' => 'pierna',
    '🦶' => 'pie',
    '👂' => 'oreja',
    '🦻' => 'oreja con audífono',
    '👃' => 'nariz',
    '🧠' => 'cerebro',
    '🫀' => 'corazón humano',
    '🫁' => 'pulmones',
    '🦷' => 'diente',
    '🦴' => 'hueso',
    '👀' => 'ojos',
    '👁' => 'ojo',
    '👅' => 'lengua',
    '👄' => 'boca',
    '🫦' => 'labio mordido',
    '👶' => 'bebé',
    '🧒' => 'infante',
    '👦' => 'niño',
    '👧' => 'niña',
    '🧑' => 'persona adulta',
    '👱' => 'persona adulta rubia',
    '👨' => 'hombre',
    '🧔' => 'persona con barba',
    '👩' => 'mujer',
    '🧓' => 'persona mayor',
    '👴' => 'anciano',
    '👵' => 'anciana',
    '🙍' => 'persona frunciendo el ceño',
    '🙎' => 'persona haciendo pucheros',
    '🙅' => 'persona haciendo el gesto de "no"',
    '🙆' => 'persona haciendo el gesto de "de acuerdo"',
    '💁' => 'persona de mostrador de información',
    '🙋' => 'persona con la mano levantada',
    '🧏' => 'persona sorda',
    '🙇' => 'persona haciendo una reverencia',
    '🤦' => 'persona con la mano en la frente',
    '🤷' => 'persona encogida de hombros',
    '👮' => 'agente de policía',
    '🕵' => 'detective',
    '💂' => 'guardia',
    '🥷' => 'ninja',
    '👷' => 'profesional de la construcción',
    '🫅' => 'persona con corona',
    '🤴' => 'príncipe',
    '👸' => 'princesa',
    '👳' => 'persona con turbante',
    '👲' => 'persona con gorro chino',
    '🧕' => 'mujer con hiyab',
    '🤵' => 'persona con esmoquin',
    '👰' => 'persona con velo',
    '🤰' => 'mujer embarazada',
    '🫃' => 'hombre embarazado',
    '🫄' => 'persona embarazada',
    '🤱' => 'lactancia materna',
    '👼' => 'bebé ángel',
    '🎅' => 'Papá Noel',
    '🤶' => 'Mamá Noel',
    '🦸' => 'personaje de superhéroe',
    '🦹' => 'personaje de supervillano',
    '🧙' => 'persona maga',
    '🧚' => 'hada',
    '🧛' => 'vampiro',
    '🧜' => 'persona sirena',
    '🧝' => 'elfo',
    '🧞' => 'genio',
    '🧟' => 'zombi',
    '🧌' => 'trol',
    '🫈' => 'criatura peluda',
    '💆' => 'persona recibiendo masaje',
    '💇' => 'persona cortándose el pelo',
    '🚶' => 'persona caminando',
    '🧍' => 'persona de pie',
    '🧎' => 'persona de rodillas',
    '🏃' => 'persona corriendo',
    '💃' => 'mujer bailando',
    '🕺' => 'hombre bailando',
    '🕴' => 'persona trajeada levitando',
    '👯' => 'personas con orejas de conejo',
    '🧖' => 'persona en una sauna',
    '🧗' => 'persona escalando',
    '🤺' => 'persona haciendo esgrima',
    '🏇' => 'carrera de caballos',
    '⛷' => 'persona esquiando',
    '🏂' => 'practicante de snowboard',
    '🏌' => 'persona jugando al golf',
    '🏄' => 'persona haciendo surf',
    '🚣' => 'persona remando en un bote',
    '🏊' => 'persona nadando',
    '⛹' => 'persona botando un balón',
    '🏋' => 'persona levantando pesas',
    '🚴' => 'persona en bicicleta',
    '🚵' => 'persona en bicicleta de montaña',
    '🤸' => 'persona haciendo voltereta lateral',
    '🤼' => 'personas luchando',
    '🤽' => 'persona jugando al waterpolo',
    '🤾' => 'persona jugando al balonmano',
    '🤹' => 'persona haciendo malabares',
    '🧘' => 'persona en posición de loto',
    '🛀' => 'persona en la bañera',
    '🛌' => 'persona en la cama',
    '👭' => 'mujeres de la mano',
    '👫' => 'mujer y hombre de la mano',
    '👬' => 'hombres de la mano',
    '💏' => 'beso',
    '💑' => 'pareja enamorada',
    '🗣' => 'cabeza parlante',
    '👤' => 'silueta de busto',
    '👥' => 'dos siluetas de bustos',
    '🫂' => 'personas abrazándose',
    '👪' => 'familia',
    '👣' => 'huellas de pies',
    '🫆' => 'huella dactilar',
    '🦰' => 'pelo pelirrojo',
    '🦱' => 'pelo rizado',
    '🦳' => 'pelo blanco',
    '🦲' => 'sin pelo',
    '🐵' => 'cara de mono',
    '🐒' => 'mono',
    '🦍' => 'gorila',
    '🦧' => 'orangután',
    '🐶' => 'cara de perro',
    '🐕' => 'perro',
    '🦮' => 'perro guía',
    '🐩' => 'caniche',
    '🐺' => 'lobo',
    '🦊' => 'zorro',
    '🦝' => 'mapache',
    '🐱' => 'cara de gato',
    '🐈' => 'gato',
    '🦁' => 'león',
    '🐯' => 'cara de tigre',
    '🐅' => 'tigre',
    '🐆' => 'leopardo',
    '🐴' => 'cara de caballo',
    '🫎' => 'alce',
    '🫏' => 'burro',
    '🐎' => 'caballo',
    '🦄' => 'unicornio',
    '🦓' => 'cebra',
    '🦌' => 'ciervo',
    '🦬' => 'bisonte',
    '🐮' => 'cara de vaca',
    '🐂' => 'buey',
    '🐃' => 'búfalo de agua',
    '🐄' => 'vaca',
    '🐷' => 'cara de cerdo',
    '🐖' => 'cerdo',
    '🐗' => 'jabalí',
    '🐽' => 'nariz de cerdo',
    '🐏' => 'carnero',
    '🐑' => 'oveja',
    '🐐' => 'cabra',
    '🐪' => 'dromedario',
    '🐫' => 'camello',
    '🦙' => 'llama',
    '🦒' => 'jirafa',
    '🐘' => 'elefante',
    '🦣' => 'mamut',
    '🦏' => 'rinoceronte',
    '🦛' => 'hipopótamo',
    '🐭' => 'cara de ratón',
    '🐁' => 'ratón',
    '🐀' => 'rata',
    '🐹' => 'hámster',
    '🐰' => 'cara de conejo',
    '🐇' => 'conejo',
    '🐿' => 'ardilla',
    '🦫' => 'castor',
    '🦔' => 'erizo',
    '🦇' => 'murciélago',
    '🐻' => 'oso',
    '🐨' => 'koala',
    '🐼' => 'panda',
    '🦥' => 'perezoso',
    '🦦' => 'nutria',
    '🦨' => 'mofeta',
    '🦘' => 'canguro',
    '🦡' => 'tejón',
    '🐾' => 'huellas de pezuñas',
    '🦃' => 'pavo',
    '🐔' => 'gallina',
    '🐓' => 'gallo',
    '🐣' => 'pollito rompiendo el cascarón',
    '🐤' => 'pollito',
    '🐥' => 'pollito de frente',
    '🐦' => 'pájaro',
    '🐧' => 'pingüino',
    '🕊' => 'paloma',
    '🦅' => 'águila',
    '🦆' => 'pato',
    '🦢' => 'cisne',
    '🦉' => 'búho',
    '🦤' => 'dodo',
    '🪶' => 'pluma',
    '🦩' => 'flamenco',
    '🦚' => 'pavo real',
    '🦜' => 'loro',
    '🪽' => 'ala',
    '🪿' => 'oca',
    '🐸' => 'rana',
    '🐊' => 'cocodrilo',
    '🐢' => 'tortuga',
    '🦎' => 'lagarto',
    '🐍' => 'serpiente',
    '🐲' => 'cara de dragón',
    '🐉' => 'dragón',
    '🦕' => 'saurópodo',
    '🦖' => 't-rex',
    '🐳' => 'ballena soltando un chorro',
    '🐋' => 'ballena',
    '🐬' => 'delfín',
    '🫍' => 'orca',
    '🦭' => 'foca',
    '🐟' => 'pez',
    '🐠' => 'pez tropical',
    '🐡' => 'pez globo',
    '🦈' => 'tiburón',
    '🐙' => 'pulpo',
    '🐚' => 'caracola',
    '🪸' => 'coral',
    '🪼' => 'medusa',
    '🦀' => 'cangrejo',
    '🦞' => 'bogavante',
    '🦐' => 'gamba',
    '🦑' => 'calamar',
    '🦪' => 'ostra',
    '🐌' => 'caracol',
    '🦋' => 'mariposa',
    '🐛' => 'bicho',
    '🐜' => 'hormiga',
    '🐝' => 'abeja',
    '🪲' => 'escarabajo',
    '🐞' => 'mariquita',
    '🦗' => 'grillo',
    '🪳' => 'cucaracha',
    '🕷' => 'araña',
    '🕸' => 'tela de araña',
    '🦂' => 'escorpión',
    '🦟' => 'mosquito',
    '🪰' => 'mosca',
    '🪱' => 'gusano',
    '🦠' => 'microbio',
    '💐' => 'ramo de flores',
    '🌸' => 'flor de cerezo',
    '💮' => 'flor blanca',
    '🪷' => 'loto',
    '🏵' => 'roseta',
    '🌹' => 'rosa',
    '🥀' => 'flor marchita',
    '🌺' => 'flor de hibisco',
    '🌻' => 'girasol',
    '🌼' => 'flor',
    '🌷' => 'tulipán',
    '🪻' => 'campanilla',
    '🌱' => 'planta joven',
    '🪴' => 'planta de maceta',
    '🌲' => 'árbol de hoja perenne',
    '🌳' => 'árbol de hoja caduca',
    '🌴' => 'palmera',
    '🌵' => 'cactus',
    '🌾' => 'espiga de arroz',
    '🌿' => 'hierba',
    '☘' => 'trébol',
    '🍀' => 'trébol de cuatro hojas',
    '🍁' => 'hoja de arce',
    '🍂' => 'hojas caídas',
    '🍃' => 'hojas revoloteando al viento',
    '🪹' => 'nido vacío',
    '🪺' => 'nido con huevos',
    '🍄' => 'champiñón',
    '🪾' => 'árbol sin hojas',
    '🍇' => 'uvas',
    '🍈' => 'melón',
    '🍉' => 'sandía',
    '🍊' => 'mandarina',
    '🍋' => 'limón',
    '🍌' => 'plátano',
    '🍍' => 'piña',
    '🥭' => 'mango',
    '🍎' => 'manzana roja',
    '🍏' => 'manzana verde',
    '🍐' => 'pera',
    '🍑' => 'melocotón',
    '🍒' => 'cerezas',
    '🍓' => 'fresa',
    '🫐' => 'arándanos',
    '🥝' => 'kiwi',
    '🍅' => 'tomate',
    '🫒' => 'aceituna',
    '🥥' => 'coco',
    '🥑' => 'aguacate',
    '🍆' => 'berenjena',
    '🥔' => 'patata',
    '🥕' => 'zanahoria',
    '🌽' => 'espiga de maíz',
    '🌶' => 'chile picante',
    '🫑' => 'pimiento',
    '🥒' => 'pepino',
    '🥬' => 'verdura de hoja verde',
    '🥦' => 'brócoli',
    '🧄' => 'ajo',
    '🧅' => 'cebolla',
    '🥜' => 'cacahuetes',
    '🫘' => 'alubias',
    '🌰' => 'castaña',
    '🫚' => 'raíz de jengibre',
    '🫛' => 'vaina',
    '🫜' => 'túberculo comestible',
    '🍞' => 'pan de molde',
    '🥐' => 'cruasán',
    '🥖' => 'baguete',
    '🫓' => 'pan sin levadura',
    '🥨' => 'bretzel',
    '🥯' => 'bagel',
    '🥞' => 'tortitas',
    '🧇' => 'gofre',
    '🧀' => 'cuña de queso',
    '🍖' => 'carne con hueso',
    '🍗' => 'muslo de pollo',
    '🥩' => 'corte de carne',
    '🥓' => 'beicon',
    '🍔' => 'hamburguesa',
    '🍟' => 'patatas fritas',
    '🍕' => 'pizza',
    '🌭' => 'perrito caliente',
    '🥪' => 'sándwich',
    '🌮' => 'taco',
    '🌯' => 'burrito',
    '🫔' => 'tamal',
    '🥙' => 'pan relleno',
    '🧆' => 'falafel',
    '🥚' => 'huevo',
    '🍳' => 'cocinar',
    '🥘' => 'paella',
    '🍲' => 'olla de comida',
    '🫕' => 'fondue',
    '🥣' => 'cuenco con cuchara',
    '🥗' => 'ensalada',
    '🍿' => 'palomitas',
    '🧈' => 'mantequilla',
    '🧂' => 'sal',
    '🥫' => 'comida enlatada',
    '🍱' => 'caja de bento',
    '🍘' => 'galleta de arroz',
    '🍙' => 'bola de arroz',
    '🍚' => 'arroz cocido',
    '🍛' => 'arroz con curry',
    '🍜' => 'tazón de fideos',
    '🍝' => 'espagueti',
    '🍠' => 'patata asada',
    '🍢' => 'brocheta',
    '🍣' => 'sushi',
    '🍤' => 'gamba frita',
    '🍥' => 'pastel de pescado japonés',
    '🥮' => 'pastel de luna',
    '🍡' => 'dango',
    '🥟' => 'dumpling',
    '🥠' => 'galleta de la fortuna',
    '🥡' => 'caja para llevar',
    '🍦' => 'cucurucho de helado',
    '🍧' => 'granizado hawaiano',
    '🍨' => 'helado',
    '🍩' => 'dónut',
    '🍪' => 'galleta',
    '🎂' => 'tarta de cumpleaños',
    '🍰' => 'trozo de tarta',
    '🧁' => 'magdalena',
    '🥧' => 'pastel',
    '🍫' => 'tableta de chocolate',
    '🍬' => 'caramelo',
    '🍭' => 'piruleta',
    '🍮' => 'flan',
    '🍯' => 'tarro de miel',
    '🍼' => 'biberón',
    '🥛' => 'vaso de leche',
    '☕' => 'bebida caliente',
    '🫖' => 'tetera',
    '🍵' => 'tazón de té',
    '🍶' => 'sake',
    '🍾' => 'botella descorchada',
    '🍷' => 'copa de vino',
    '🍸' => 'copa de cóctel',
    '🍹' => 'bebida tropical',
    '🍺' => 'jarra de cerveza',
    '🍻' => 'jarras de cerveza brindando',
    '🥂' => 'copas brindando',
    '🥃' => 'vaso de whisky',
    '🫗' => 'líquido derramándose',
    '🥤' => 'vaso con pajita',
    '🧋' => 'té de burbujas',
    '🧃' => 'tetrabrik',
    '🧉' => 'mate',
    '🧊' => 'cubito de hielo',
    '🥢' => 'palillos',
    '🍽' => 'cuchillo y tenedor con un plato',
    '🍴' => 'tenedor y cuchillo',
    '🥄' => 'cuchara',
    '🔪' => 'cuchillo de cocina',
    '🫙' => 'tarro',
    '🏺' => 'ánfora',
    '🌍' => 'globo terráqueo mostrando Europa y África',
    '🌎' => 'globo terráqueo mostrando América',
    '🌏' => 'globo terráqueo mostrando Asia y Australia',
    '🌐' => 'globo terráqueo con meridianos',
    '🗺' => 'mapa mundial',
    '🗾' => 'mapa de Japón',
    '🧭' => 'brújula',
    '🏔' => 'montaña con nieve',
    '⛰' => 'montaña',
    '🛘' => 'desprendimiento',
    '🌋' => 'volcán',
    '🗻' => 'monte Fuji',
    '🏕' => 'camping',
    '🏖' => 'playa y sombrilla',
    '🏜' => 'desierto',
    '🏝' => 'isla desierta',
    '🏞' => 'parque nacional',
    '🏟' => 'estadio',
    '🏛' => 'edificio clásico',
    '🏗' => 'construcción',
    '🧱' => 'ladrillo',
    '🪨' => 'piedra',
    '🪵' => 'madera',
    '🛖' => 'cabaña',
    '🏘' => 'casas',
    '🏚' => 'casa abandonada',
    '🏠' => 'casa',
    '🏡' => 'casa con jardín',
    '🏢' => 'edificio de oficinas',
    '🏣' => 'oficina de correos japonesa',
    '🏤' => 'oficina de correos europea',
    '🏥' => 'hospital',
    '🏦' => 'banco',
    '🏨' => 'hotel',
    '🏩' => 'hotel del amor',
    '🏪' => 'tienda 24 horas',
    '🏫' => 'colegio',
    '🏬' => 'grandes almacenes',
    '🏭' => 'fábrica',
    '🏯' => 'castillo japonés',
    '🏰' => 'castillo europeo',
    '💒' => 'iglesia celebrando boda',
    '🗼' => 'Torre de Tokio',
    '🗽' => 'Estatua de la Libertad',
    '⛪' => 'iglesia',
    '🕌' => 'mezquita',
    '🛕' => 'templo hindú',
    '🕍' => 'sinagoga',
    '⛩' => 'santuario sintoísta',
    '🕋' => 'Kaaba',
    '⛲' => 'fuente',
    '⛺' => 'tienda de campaña',
    '🌁' => 'bruma',
    '🌃' => 'noche estrellada',
    '🏙' => 'paisaje urbano',
    '🌄' => 'amanecer sobre montañas',
    '🌅' => 'amanecer',
    '🌆' => 'ciudad al atardecer',
    '🌇' => 'puesta del sol',
    '🌉' => 'puente de noche',
    '♨' => 'aguas termales',
    '🎠' => 'caballo de tiovivo',
    '🛝' => 'tobogán',
    '🎡' => 'noria de feria',
    '🎢' => 'montaña rusa',
    '💈' => 'poste de barbero',
    '🎪' => 'carpa de circo',
    '🚂' => 'locomotora de vapor',
    '🚃' => 'vagón',
    '🚄' => 'tren de alta velocidad',
    '🚅' => 'tren bala',
    '🚆' => 'tren',
    '🚇' => 'metro',
    '🚈' => 'tren ligero',
    '🚉' => 'estación de tren',
    '🚊' => 'tranvía',
    '🚝' => 'monorraíl',
    '🚞' => 'ferrocarril de montaña',
    '🚋' => 'vagón de tranvía',
    '🚌' => 'autobús',
    '🚍' => 'autobús próximo',
    '🚎' => 'trolebús',
    '🚐' => 'minibús',
    '🚑' => 'ambulancia',
    '🚒' => 'coche de bomberos',
    '🚓' => 'coche de policía',
    '🚔' => 'coche de policía próximo',
    '🚕' => 'taxi',
    '🚖' => 'taxi próximo',
    '🚗' => 'coche',
    '🚘' => 'coche próximo',
    '🚙' => 'vehículo deportivo utilitario',
    '🛻' => 'camioneta',
    '🚚' => 'camión de reparto',
    '🚛' => 'camión articulado',
    '🚜' => 'tractor',
    '🏎' => 'coche de carreras',
    '🏍' => 'moto',
    '🛵' => 'scooter',
    '🦽' => 'silla de ruedas manual',
    '🦼' => 'silla de ruedas eléctrica',
    '🛺' => 'mototaxi',
    '🚲' => 'bicicleta',
    '🛴' => 'patinete',
    '🛹' => 'monopatín',
    '🛼' => 'patines',
    '🚏' => 'parada de autobús',
    '🛣' => 'autopista',
    '🛤' => 'vía de tren',
    '🛢' => 'barril de petróleo',
    '⛽' => 'surtidor de gasolina',
    '🛞' => 'rueda',
    '🚨' => 'luces de policía',
    '🚥' => 'semáforo horizontal',
    '🚦' => 'semáforo',
    '🛑' => 'señal de stop',
    '🚧' => 'obras',
    '⚓' => 'ancla',
    '🛟' => 'salvavidas',
    '⛵' => 'velero',
    '🛶' => 'canoa',
    '🚤' => 'lancha motora',
    '🛳' => 'barco de pasajeros',
    '⛴' => 'ferri',
    '🛥' => 'barco a motor',
    '🚢' => 'barco',
    '✈' => 'avión',
    '🛩' => 'avioneta',
    '🛫' => 'avión despegando',
    '🛬' => 'avión aterrizando',
    '🪂' => 'paracaídas',
    '💺' => 'asiento de transporte',
    '🚁' => 'helicóptero',
    '🚟' => 'ferrocarril de suspensión',
    '🚠' => 'teleférico de montaña',
    '🚡' => 'teleférico',
    '🛰' => 'satélite',
    '🚀' => 'cohete',
    '🛸' => 'platillo volante',
    '🛎' => 'timbre de hotel',
    '🧳' => 'equipaje',
    '⌛' => 'reloj de arena sin tiempo',
    '⏳' => 'reloj de arena con tiempo',
    '⌚' => 'reloj',
    '⏰' => 'reloj despertador',
    '⏱' => 'cronómetro',
    '⏲' => 'temporizador',
    '🕰' => 'reloj de sobremesa',
    '🕛' => '12 en punto',
    '🕧' => 'doce y media',
    '🕐' => '1 en punto',
    '🕜' => 'una y media',
    '🕑' => '2 en punto',
    '🕝' => 'dos y media',
    '🕒' => '3 en punto',
    '🕞' => 'tres y media',
    '🕓' => '4 en punto',
    '🕟' => 'cuatro y media',
    '🕔' => '5 en punto',
    '🕠' => 'cinco y media',
    '🕕' => '6 en punto',
    '🕡' => 'seis y media',
    '🕖' => '7 en punto',
    '🕢' => 'siete y media',
    '🕗' => '8 en punto',
    '🕣' => 'ocho y media',
    '🕘' => '9 en punto',
    '🕤' => 'nueve y media',
    '🕙' => '10 en punto',
    '🕥' => 'diez y media',
    '🕚' => '11 en punto',
    '🕦' => 'once y media',
    '🌑' => 'luna nueva',
    '🌒' => 'luna creciente',
    '🌓' => 'luna en cuarto creciente',
    '🌔' => 'luna gibosa creciente',
    '🌕' => 'luna llena',
    '🌖' => 'luna gibosa menguante',
    '🌗' => 'luna en cuarto menguante',
    '🌘' => 'luna menguante',
    '🌙' => 'luna',
    '🌚' => 'luna nueva con cara',
    '🌛' => 'luna de cuarto creciente con cara',
    '🌜' => 'luna de cuarto menguante con cara',
    '🌡' => 'termómetro',
    '☀' => 'sol',
    '🌝' => 'luna llena con cara',
    '🌞' => 'sol con cara',
    '🪐' => 'planeta con anillos',
    '⭐' => 'estrella',
    '🌟' => 'estrella brillante',
    '🌠' => 'estrella fugaz',
    '🌌' => 'Vía Láctea',
    '☁' => 'nube',
    '⛅' => 'sol detrás de una nube',
    '⛈' => 'nube con rayo y lluvia',
    '🌤' => 'sol detrás de una nube pequeña',
    '🌥' => 'sol detrás de una nube grande',
    '🌦' => 'sol detrás de una nube con lluvia',
    '🌧' => 'nube con lluvia',
    '🌨' => 'nube con nieve',
    '🌩' => 'nube con rayo',
    '🌪' => 'tornado',
    '🌫' => 'niebla',
    '🌬' => 'cara de viento',
    '🌀' => 'ciclón',
    '🌈' => 'arcoíris',
    '🌂' => 'paraguas cerrado',
    '☂' => 'paraguas',
    '☔' => 'paraguas con gotas de lluvia',
    '⛱' => 'sombrilla en la arena',
    '⚡' => 'alto voltaje',
    '❄' => 'copo de nieve',
    '☃' => 'muñeco de nieve con nieve',
    '⛄' => 'muñeco de nieve',
    '☄' => 'meteorito',
    '🔥' => 'fuego',
    '💧' => 'gota',
    '🌊' => 'ola de mar',
    '🎃' => 'calabaza de Halloween',
    '🎄' => 'árbol de Navidad',
    '🎆' => 'fuegos artificiales',
    '🎇' => 'bengala',
    '🧨' => 'petardo',
    '✨' => 'chispas',
    '🎈' => 'globo',
    '🎉' => 'cañón de confeti',
    '🎊' => 'bola de confeti',
    '🎋' => 'árbol de tanabata',
    '🎍' => 'decoración de pino',
    '🎎' => 'muñecas japonesas',
    '🎏' => 'banderín de carpas',
    '🎐' => 'campanilla de viento',
    '🎑' => 'ceremonia de contemplación de la luna',
    '🧧' => 'sobre rojo',
    '🎀' => 'lazo',
    '🎁' => 'regalo',
    '🎗' => 'lazo conmemorativo',
    '🎟' => 'entradas',
    '🎫' => 'tique',
    '🎖' => 'medalla militar',
    '🏆' => 'trofeo',
    '🏅' => 'medalla deportiva',
    '🥇' => 'medalla de oro',
    '🥈' => 'medalla de plata',
    '🥉' => 'medalla de bronce',
    '⚽' => 'balón de fútbol',
    '⚾' => 'béisbol',
    '🥎' => 'pelota de softball',
    '🏀' => 'balón de baloncesto',
    '🏐' => 'pelota de voleibol',
    '🏈' => 'balón de fútbol americano',
    '🏉' => 'balón de rugby',
    '🎾' => 'pelota de tenis',
    '🥏' => 'disco volador',
    '🎳' => 'bolos',
    '🏏' => 'críquet',
    '🏑' => 'hockey sobre hierba',
    '🏒' => 'hockey sobre hielo',
    '🥍' => 'lacrosse',
    '🏓' => 'tenis de mesa',
    '🏸' => 'bádminton',
    '🥊' => 'guante de boxeo',
    '🥋' => 'uniforme de artes marciales',
    '🥅' => 'portería',
    '⛳' => 'banderín en hoyo',
    '⛸' => 'patín de hielo',
    '🎣' => 'caña de pescar',
    '🤿' => 'máscara de buceo',
    '🎽' => 'camiseta sin mangas',
    '🎿' => 'esquís',
    '🛷' => 'trineo',
    '🥌' => 'piedra de curling',
    '🎯' => 'diana',
    '🪀' => 'yoyó',
    '🪁' => 'cometa',
    '🔫' => 'pistola de agua',
    '🎱' => 'bola negra de billar',
    '🔮' => 'bola de cristal',
    '🪄' => 'varita mágica',
    '🎮' => 'mando de videoconsola',
    '🕹' => 'joystick',
    '🎰' => 'máquina tragaperras',
    '🎲' => 'dado',
    '🧩' => 'pieza de puzle',
    '🧸' => 'osito de peluche',
    '🪅' => 'piñata',
    '🪩' => 'bola de espejos',
    '🪆' => 'muñeca rusa',
    '♠' => 'palo de picas',
    '♥' => 'palo de corazones',
    '♦' => 'palo de diamantes',
    '♣' => 'palo de tréboles',
    '♟' => 'peón de ajedrez',
    '🃏' => 'comodín',
    '🀄' => 'dragón rojo de mahjong',
    '🎴' => 'cartas de flores',
    '🎭' => 'máscaras de teatro',
    '🖼' => 'cuadro enmarcado',
    '🎨' => 'paleta de pintor',
    '🧵' => 'hilo',
    '🪡' => 'aguja de coser',
    '🧶' => 'ovillo',
    '🪢' => 'nudo',
    '👓' => 'gafas',
    '🕶' => 'gafas de sol',
    '🥽' => 'gafas de protección',
    '🥼' => 'bata de laboratorio',
    '🦺' => 'chaleco de seguridad',
    '👔' => 'corbata',
    '👕' => 'camiseta',
    '👖' => 'vaqueros',
    '🧣' => 'bufanda',
    '🧤' => 'guantes',
    '🧥' => 'abrigo',
    '🧦' => 'calcetines',
    '👗' => 'vestido',
    '👘' => 'kimono',
    '🥻' => 'sari',
    '🩱' => 'traje de baño de una pieza',
    '🩲' => 'ropa interior',
    '🩳' => 'pantalones cortos',
    '👙' => 'bikini',
    '👚' => 'ropa de mujer',
    '🪭' => 'abanico abierto',
    '👛' => 'monedero',
    '👜' => 'bolso',
    '👝' => 'bolso de mano',
    '🛍' => 'bolsas de compras',
    '🎒' => 'mochila escolar',
    '🩴' => 'chancla',
    '👞' => 'zapato de hombre',
    '👟' => 'zapatilla deportiva',
    '🥾' => 'bota de senderismo',
    '🥿' => 'bailarina',
    '👠' => 'zapato de tacón',
    '👡' => 'sandalia de mujer',
    '🩰' => 'zapatillas de ballet',
    '👢' => 'bota de mujer',
    '🪮' => 'peineta',
    '👑' => 'corona',
    '👒' => 'sombrero de mujer',
    '🎩' => 'sombrero de copa',
    '🎓' => 'birrete',
    '🧢' => 'gorra con visera',
    '🪖' => 'casco militar',
    '⛑' => 'casco con una cruz blanca',
    '📿' => 'rosario',
    '💄' => 'pintalabios',
    '💍' => 'anillo',
    '💎' => 'piedra preciosa',
    '🔇' => 'altavoz silenciado',
    '🔈' => 'altavoz a volumen bajo',
    '🔉' => 'altavoz a volumen medio',
    '🔊' => 'altavoz a volumen alto',
    '📢' => 'altavoz de mano',
    '📣' => 'megáfono',
    '📯' => 'corneta de posta',
    '🔔' => 'campana',
    '🔕' => 'campana con signo de cancelación',
    '🎼' => 'pentagrama',
    '🎵' => 'nota musical',
    '🎶' => 'notas musicales',
    '🎙' => 'micrófono de estudio',
    '🎚' => 'control de volumen',
    '🎛' => 'ruedas de control',
    '🎤' => 'micrófono',
    '🎧' => 'auricular',
    '📻' => 'radio',
    '🎷' => 'saxofón',
    '🎺' => 'trompeta',
    '🪊' => 'trombón',
    '🪗' => 'acordeón',
    '🎸' => 'guitarra',
    '🎹' => 'teclado musical',
    '🎻' => 'violín',
    '🪕' => 'banjo',
    '🥁' => 'tambor',
    '🪘' => 'tamboril',
    '🪇' => 'maracas',
    '🪈' => 'flauta',
    '🪉' => 'arpa',
    '📱' => 'teléfono móvil',
    '📲' => 'móvil con una flecha',
    '☎' => 'teléfono',
    '📞' => 'auricular de teléfono',
    '📟' => 'busca',
    '📠' => 'máquina de fax',
    '🔋' => 'pila',
    '🪫' => 'batería baja',
    '🔌' => 'enchufe eléctrico',
    '💻' => 'ordenador portátil',
    '🖥' => 'ordenador de sobremesa',
    '🖨' => 'impresora',
    '⌨' => 'teclado',
    '🖱' => 'ratón de ordenador',
    '🖲' => 'bola de desplazamiento',
    '💽' => 'minidisc',
    '💾' => 'disquete',
    '💿' => 'disco óptico',
    '📀' => 'disco DVD',
    '🧮' => 'ábaco',
    '🎥' => 'cámara de cine',
    '🎞' => 'fotograma de película',
    '📽' => 'proyector de cine',
    '🎬' => 'claqueta',
    '📺' => 'televisión',
    '📷' => 'cámara de fotos',
    '📸' => 'cámara con flash',
    '📹' => 'videocámara',
    '📼' => 'cinta de vídeo',
    '🔍' => 'lupa orientada hacia la izquierda',
    '🔎' => 'lupa orientada hacia la derecha',
    '🕯' => 'vela',
    '💡' => 'bombilla',
    '🔦' => 'linterna',
    '🏮' => 'lámpara japonesa',
    '🪔' => 'lámpara de aceite',
    '📔' => 'cuaderno con tapa decorativa',
    '📕' => 'libro cerrado',
    '📖' => 'libro abierto',
    '📗' => 'libro verde',
    '📘' => 'libro azul',
    '📙' => 'libro naranja',
    '📚' => 'libros',
    '📓' => 'cuaderno',
    '📒' => 'libro de contabilidad',
    '📃' => 'página doblada',
    '📜' => 'pergamino',
    '📄' => 'página hacia arriba',
    '📰' => 'periódico',
    '🗞' => 'periódico enrollado',
    '📑' => 'marcadores',
    '🔖' => 'marcapáginas',
    '🏷' => 'etiqueta',
    '🪙' => 'moneda',
    '💰' => 'bolsa de dinero',
    '🪎' => 'cofre de tesoro',
    '💴' => 'billete de yen',
    '💵' => 'billete de dólar',
    '💶' => 'billete de euro',
    '💷' => 'billete de libra',
    '💸' => 'billete con alas',
    '💳' => 'tarjeta de crédito',
    '🧾' => 'recibo',
    '💹' => 'mercado al alza',
    '✉' => 'sobre',
    '📧' => 'correo electrónico',
    '📨' => 'sobre entrante',
    '📩' => 'sobre con flecha',
    '📤' => 'bandeja de salida',
    '📥' => 'bandeja de entrada',
    '📦' => 'paquete',
    '📫' => 'buzón cerrado con la bandera levantada',
    '📪' => 'buzón cerrado con la bandera bajada',
    '📬' => 'buzón abierto con la bandera levantada',
    '📭' => 'buzón abierto con la bandera bajada',
    '📮' => 'buzón',
    '🗳' => 'urna con papeleta',
    '✏' => 'lápiz',
    '✒' => 'pluma negra',
    '🖋' => 'estilográfica',
    '🖊' => 'bolígrafo',
    '🖌' => 'pincel',
    '🖍' => 'lápiz de cera',
    '📝' => 'cuaderno de notas',
    '💼' => 'maletín',
    '📁' => 'carpeta de archivos',
    '📂' => 'carpeta de archivos abierta',
    '🗂' => 'separador de fichas',
    '📅' => 'calendario',
    '📆' => 'calendario recortable',
    '🗒' => 'bloc de notas de espiral',
    '🗓' => 'calendario de espiral',
    '📇' => 'organizador de fichas',
    '📈' => 'gráfica de evolución ascendente',
    '📉' => 'gráfica de evolución descendente',
    '📊' => 'gráfico de barras',
    '📋' => 'portapapeles',
    '📌' => 'chincheta',
    '📍' => 'chincheta redonda',
    '📎' => 'clip',
    '🖇' => 'clips unidos',
    '📏' => 'regla',
    '📐' => 'escuadra',
    '✂' => 'tijeras',
    '🗃' => 'archivador de tarjetas',
    '🗄' => 'archivador',
    '🗑' => 'papelera',
    '🔒' => 'candado cerrado',
    '🔓' => 'candado abierto',
    '🔏' => 'candado con pluma estilográfica',
    '🔐' => 'candado cerrado y llave',
    '🔑' => 'llave',
    '🗝' => 'llave antigua',
    '🔨' => 'martillo',
    '🪓' => 'hacha',
    '⛏' => 'pico',
    '⚒' => 'martillo y pico',
    '🛠' => 'martillo y llave inglesa',
    '🗡' => 'puñal',
    '⚔' => 'espadas cruzadas',
    '💣' => 'bomba',
    '🪃' => 'bumerán',
    '🏹' => 'arco y flecha',
    '🛡' => 'escudo',
    '🪚' => 'sierra de carpintería',
    '🔧' => 'llave inglesa',
    '🪛' => 'destornillador',
    '🔩' => 'tornillo y tuerca',
    '⚙' => 'engranaje',
    '🗜' => 'tornillo de banco',
    '⚖' => 'balanza',
    '🦯' => 'bastón',
    '🔗' => 'eslabón',
    '⛓' => 'cadenas',
    '🪝' => 'gancho',
    '🧰' => 'caja de herramientas',
    '🧲' => 'imán',
    '🪜' => 'escalera',
    '🪏' => 'pala',
    '⚗' => 'alambique',
    '🧪' => 'tubo de ensayo',
    '🧫' => 'placa de petri',
    '🧬' => 'adn',
    '🔬' => 'microscopio',
    '🔭' => 'telescopio',
    '📡' => 'antena de satélite',
    '💉' => 'jeringuilla',
    '🩸' => 'gota de sangre',
    '💊' => 'píldora',
    '🩹' => 'tirita',
    '🩼' => 'muleta',
    '🩺' => 'estetoscopio',
    '🩻' => 'radiografía',
    '🚪' => 'puerta',
    '🛗' => 'ascensor',
    '🪞' => 'espejo',
    '🪟' => 'ventana',
    '🛏' => 'cama',
    '🛋' => 'sofá y lámpara',
    '🪑' => 'silla',
    '🚽' => 'inodoro',
    '🪠' => 'desatascador',
    '🚿' => 'ducha',
    '🛁' => 'bañera',
    '🪤' => 'trampa de ratones',
    '🪒' => 'cuchilla de afeitar',
    '🧴' => 'bote de crema',
    '🧷' => 'imperdible',
    '🧹' => 'escoba',
    '🧺' => 'cesta',
    '🧻' => 'rollo de papel',
    '🪣' => 'cubo',
    '🧼' => 'jabón',
    '🫧' => 'burbujas',
    '🪥' => 'cepillo de dientes',
    '🧽' => 'esponja',
    '🧯' => 'extintor',
    '🛒' => 'carrito de la compra',
    '🚬' => 'cigarrillo',
    '⚰' => 'ataúd',
    '🪦' => 'lápida',
    '⚱' => 'urna funeraria',
    '🧿' => 'ojo turco',
    '🪬' => 'hamsa',
    '🗿' => 'estatua moái',
    '🪧' => 'letrero',
    '🪪' => 'carné de identidad',
    '🏧' => 'señal de cajero automático',
    '🚮' => 'señal de usar papelera',
    '🚰' => 'agua potable',
    '♿' => 'símbolo de silla de ruedas',
    '🚹' => 'aseo para hombres',
    '🚺' => 'señal de aseo para mujeres',
    '🚻' => 'señal de aseos',
    '🚼' => 'señal de bebé',
    '🚾' => 'aseos',
    '🛂' => 'control de pasaportes',
    '🛃' => 'aduana',
    '🛄' => 'recogida de equipajes',
    '🛅' => 'consigna',
    '⚠' => 'advertencia',
    '🚸' => 'niños cruzando',
    '⛔' => 'dirección prohibida',
    '🚫' => 'prohibido',
    '🚳' => 'bicicletas prohibidas',
    '🚭' => 'prohibido fumar',
    '🚯' => 'prohibido tirar basura',
    '🚱' => 'agua no potable',
    '🚷' => 'prohibido el paso de peatones',
    '📵' => 'prohibido el uso de móviles',
    '🔞' => 'prohibido para menos de 18 años',
    '☢' => 'radiactivo',
    '☣' => 'riesgo biológico',
    '⬆' => 'flecha hacia arriba',
    '↗' => 'flecha hacia la esquina superior derecha',
    '➡' => 'flecha hacia la derecha',
    '↘' => 'flecha hacia la esquina inferior derecha',
    '⬇' => 'flecha hacia abajo',
    '↙' => 'flecha hacia la esquina inferior izquierda',
    '⬅' => 'flecha hacia la izquierda',
    '↖' => 'flecha hacia la esquina superior izquierda',
    '↕' => 'flecha arriba y abajo',
    '↔' => 'flecha izquierda y derecha',
    '↩' => 'flecha derecha curvándose a la izquierda',
    '↪' => 'flecha izquierda curvándose a la derecha',
    '⤴' => 'flecha derecha curvándose hacia arriba',
    '⤵' => 'flecha derecha curvándose hacia abajo',
    '🔃' => 'flechas verticales en sentido horario',
    '🔄' => 'flechas en sentido antihorario',
    '🔙' => 'flecha BACK',
    '🔚' => 'flecha END',
    '🔛' => 'flecha ON!',
    '🔜' => 'flecha SOON',
    '🔝' => 'flecha TOP',
    '🛐' => 'lugar de culto',
    '⚛' => 'símbolo de átomo',
    '🕉' => 'om',
    '✡' => 'estrella de David',
    '☸' => 'rueda del dharma',
    '☯' => 'yin yang',
    '✝' => 'cruz latina',
    '☦' => 'cruz ortodoxa',
    '☪' => 'media luna y estrella',
    '☮' => 'símbolo de la paz',
    '🕎' => 'menorá',
    '🔯' => 'estrella de seis puntas',
    '🪯' => 'khanda',
    '♈' => 'Aries',
    '♉' => 'Tauro',
    '♊' => 'Géminis',
    '♋' => 'Cáncer',
    '♌' => 'Leo',
    '♍' => 'Virgo',
    '♎' => 'Libra',
    '♏' => 'Escorpio',
    '♐' => 'Sagitario',
    '♑' => 'Capricornio',
    '♒' => 'Acuario',
    '♓' => 'Piscis',
    '⛎' => 'Ofiuco',
    '🔀' => 'reproducción aleatoria',
    '🔁' => 'repetir',
    '🔂' => 'repetir una vez',
    '▶' => 'reproducir',
    '⏩' => 'avance rápido',
    '⏭' => 'pista siguiente',
    '⏯' => 'reproducir o pausa',
    '◀' => 'retroceso',
    '⏪' => 'retroceso rápido',
    '⏮' => 'pista anterior',
    '🔼' => 'triángulo hacia arriba',
    '⏫' => 'triángulo doble hacia arriba',
    '🔽' => 'triángulo hacia abajo',
    '⏬' => 'triángulo doble hacia abajo',
    '⏸' => 'pausa',
    '⏹' => 'detener',
    '⏺' => 'grabar',
    '⏏' => 'expulsar',
    '🎦' => 'cine',
    '🔅' => 'brillo bajo',
    '🔆' => 'brillo alto',
    '📶' => 'barras de cobertura',
    '🛜' => 'wifi',
    '📳' => 'modo vibración',
    '📴' => 'teléfono móvil apagado',
    '♀' => 'signo femenino',
    '♂' => 'signo masculino',
    '⚧' => 'símbolo de transgénero',
    '✖' => 'multiplicación',
    '➕' => 'más',
    '➖' => 'menos',
    '➗' => 'división',
    '🟰' => 'signo igual grueso',
    '♾' => 'infinito',
    '‼' => 'exclamación doble',
    '⁉' => 'exclamación e interrogación',
    '❓' => 'interrogación roja',
    '❔' => 'interrogación blanca',
    '❕' => 'exclamación blanca',
    '❗' => 'exclamación roja',
    '〰' => 'guion ondulado',
    '💱' => 'cambio de divisas',
    '💲' => 'símbolo de dólar',
    '⚕' => 'símbolo de medicina',
    '♻' => 'símbolo de reciclaje',
    '⚜' => 'flor de lis',
    '🔱' => 'emblema de tridente',
    '📛' => 'etiqueta identificativa',
    '🔰' => 'símbolo japonés para principiante',
    '⭕' => 'círculo rojo hueco',
    '✅' => 'botón de marca de verificación',
    '☑' => 'casilla con marca de verificación',
    '✔' => 'marca de verificación',
    '❌' => 'marca de cruz',
    '❎' => 'botón con marca de cruz',
    '➰' => 'bucle',
    '➿' => 'bucle doble',
    '〽' => 'marca de alternancia',
    '✳' => 'asterisco de ocho puntas',
    '✴' => 'estrella de ocho puntas',
    '❇' => 'chispa',
    '™' => 'símbolo de marca comercial',
    '🫟' => 'salpicadura',
    '🔠' => 'letras latinas mayúsculas',
    '🔡' => 'letras latinas minúsculas',
    '🔢' => 'números',
    '🔣' => 'símbolos',
    '🔤' => 'alfabeto latino',
    '🅰' => 'grupo sanguíneo A',
    '🆎' => 'grupo sanguíneo AB',
    '🅱' => 'grupo sanguíneo B',
    '🆑' => 'borrar',
    '🆒' => 'botón COOL',
    '🆓' => 'botón FREE',
    'ℹ' => 'información',
    '🆔' => 'símbolo de identificación',
    'Ⓜ' => 'm en círculo',
    '🆕' => 'botón NEW',
    '🆖' => 'botón NG',
    '🅾' => 'grupo sanguíneo tipo O',
    '🆗' => 'botón OK',
    '🅿' => 'aparcamiento',
    '🆘' => 'símbolo de socorro',
    '🆙' => 'botón UP!',
    '🆚' => 'botón VS',
    '🈁' => 'ideograma japonés para "aquí"',
    '🈂' => 'ideograma japonés para "de cortesía"',
    '🈷' => 'ideograma japonés para "cantidad mensual"',
    '🈶' => 'ideograma japonés para "de pago"',
    '🈯' => 'ideograma japonés para "reservado"',
    '🉐' => 'ideograma japonés para "ganga"',
    '🈹' => 'ideograma japonés para "descuento"',
    '🈚' => 'ideograma japonés para "gratis"',
    '🈲' => 'ideograma japonés para "prohibido"',
    '🉑' => 'ideograma japonés para "aceptable"',
    '🈸' => 'ideograma japonés para "aplicación"',
    '🈴' => 'ideograma japonés para "aprobado"',
    '🈳' => 'ideograma japonés para "vacante"',
    '㊗' => 'ideograma japonés para "enhorabuena"',
    '㊙' => 'ideograma japonés para "secreto"',
    '🈺' => 'ideograma japonés para "abierto"',
    '🈵' => 'ideograma japonés para "completo"',
    '🔴' => 'círculo rojo',
    '🟠' => 'círculo naranja',
    '🟡' => 'círculo amarillo',
    '🟢' => 'círculo verde',
    '🔵' => 'círculo azul',
    '🟣' => 'círculo morado',
    '🟤' => 'círculo marrón',
    '⚫' => 'círculo negro',
    '⚪' => 'círculo blanco',
    '🟥' => 'cuadrado rojo',
    '🟧' => 'cuadrado naranja',
    '🟨' => 'cuadrado amarillo',
    '🟩' => 'cuadrado verde',
    '🟦' => 'cuadrado azul',
    '🟪' => 'cuadrado morado',
    '🟫' => 'cuadrado marrón',
    '⬛' => 'cuadrado negro grande',
    '⬜' => 'cuadrado blanco grande',
    '◼' => 'cuadrado negro mediano',
    '◻' => 'cuadrado blanco mediano',
    '◾' => 'cuadrado negro mediano-pequeño',
    '◽' => 'cuadrado blanco mediano-pequeño',
    '▪' => 'cuadrado negro pequeño',
    '▫' => 'cuadrado blanco pequeño',
    '🔶' => 'rombo naranja grande',
    '🔷' => 'rombo azul grande',
    '🔸' => 'rombo naranja pequeño',
    '🔹' => 'rombo azul pequeño',
    '🔺' => 'triángulo rojo hacia arriba',
    '🔻' => 'triángulo rojo hacia abajo',
    '💠' => 'rombo con pétalo',
    '🔘' => 'botón de opción',
    '🔳' => 'botón cuadrado con borde blanco',
    '🔲' => 'botón cuadrado con borde negro',
    '🏁' => 'bandera de cuadros',
    '🚩' => 'bandera triangular',
    '🎌' => 'banderas cruzadas',
    '🏴' => 'bandera negra',
    '🏳' => 'bandera blanca',
];
