<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'өбіс: адам адам 1–2 тері түсі 3-тері түрі',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'өбіс: адам адам 1–2 тері түсі 4-тері түсі',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'өбіс: адам адам 1–2 тері түсі 5-тері түсі',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'өбіс: адам адам 1–2 тері түсі 6-тері түсі',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'өбіс: адам адам 3-тері түрі 1–2 тері түсі',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'өбіс: адам адам 3-тері түрі 4-тері түсі',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'өбіс: адам адам 3-тері түрі 5-тері түсі',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'өбіс: адам адам 3-тері түрі 6-тері түсі',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'өбіс: адам адам 4-тері түсі 1–2 тері түсі',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'өбіс: адам адам 4-тері түсі 3-тері түрі',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'өбіс: адам адам 4-тері түсі 5-тері түсі',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'өбіс: адам адам 4-тері түсі 6-тері түсі',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'өбіс: адам адам 5-тері түсі 1–2 тері түсі',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'өбіс: адам адам 5-тері түсі 3-тері түрі',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'өбіс: адам адам 5-тері түсі 4-тері түсі',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'өбіс: адам адам 5-тері түсі 6-тері түсі',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'өбіс: адам адам 6-тері түсі 1–2 тері түсі',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'өбіс: адам адам 6-тері түсі 3-тері түрі',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'өбіс: адам адам 6-тері түсі 4-тері түсі',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'өбіс: адам адам 6-тері түсі 5-тері түсі',
    '👨🏻‍❤‍💋‍👨🏻' => 'өбіс: ер адам ер адам 1–2 тері түсі',
    '👨🏻‍❤‍💋‍👨🏼' => 'өбіс: ер адам ер адам 1–2 тері түсі 3-тері түрі',
    '👨🏻‍❤‍💋‍👨🏽' => 'өбіс: ер адам ер адам 1–2 тері түсі 4-тері түсі',
    '👨🏻‍❤‍💋‍👨🏾' => 'өбіс: ер адам ер адам 1–2 тері түсі 5-тері түсі',
    '👨🏻‍❤‍💋‍👨🏿' => 'өбіс: ер адам ер адам 1–2 тері түсі 6-тері түсі',
    '👨🏼‍❤‍💋‍👨🏻' => 'өбіс: ер адам ер адам 3-тері түрі 1–2 тері түсі',
    '👨🏼‍❤‍💋‍👨🏼' => 'өбіс: ер адам ер адам 3-тері түрі',
    '👨🏼‍❤‍💋‍👨🏽' => 'өбіс: ер адам ер адам 3-тері түрі 4-тері түсі',
    '👨🏼‍❤‍💋‍👨🏾' => 'өбіс: ер адам ер адам 3-тері түрі 5-тері түсі',
    '👨🏼‍❤‍💋‍👨🏿' => 'өбіс: ер адам ер адам 3-тері түрі 6-тері түсі',
    '👨🏽‍❤‍💋‍👨🏻' => 'өбіс: ер адам ер адам 4-тері түсі 1–2 тері түсі',
    '👨🏽‍❤‍💋‍👨🏼' => 'өбіс: ер адам ер адам 4-тері түсі 3-тері түрі',
    '👨🏽‍❤‍💋‍👨🏽' => 'өбіс: ер адам ер адам 4-тері түсі',
    '👨🏽‍❤‍💋‍👨🏾' => 'өбіс: ер адам ер адам 4-тері түсі 5-тері түсі',
    '👨🏽‍❤‍💋‍👨🏿' => 'өбіс: ер адам ер адам 4-тері түсі 6-тері түсі',
    '👨🏾‍❤‍💋‍👨🏻' => 'өбіс: ер адам ер адам 5-тері түсі 1–2 тері түсі',
    '👨🏾‍❤‍💋‍👨🏼' => 'өбіс: ер адам ер адам 5-тері түсі 3-тері түрі',
    '👨🏾‍❤‍💋‍👨🏽' => 'өбіс: ер адам ер адам 5-тері түсі 4-тері түсі',
    '👨🏾‍❤‍💋‍👨🏾' => 'өбіс: ер адам ер адам 5-тері түсі',
    '👨🏾‍❤‍💋‍👨🏿' => 'өбіс: ер адам ер адам 5-тері түсі 6-тері түсі',
    '👨🏿‍❤‍💋‍👨🏻' => 'өбіс: ер адам ер адам 6-тері түсі 1–2 тері түсі',
    '👨🏿‍❤‍💋‍👨🏼' => 'өбіс: ер адам ер адам 6-тері түсі 3-тері түрі',
    '👨🏿‍❤‍💋‍👨🏽' => 'өбіс: ер адам ер адам 6-тері түсі 4-тері түсі',
    '👨🏿‍❤‍💋‍👨🏾' => 'өбіс: ер адам ер адам 6-тері түсі 5-тері түсі',
    '👨🏿‍❤‍💋‍👨🏿' => 'өбіс: ер адам ер адам 6-тері түсі',
    '👩🏻‍❤‍💋‍👨🏻' => 'өбіс: әйел ер адам 1–2 тері түсі',
    '👩🏻‍❤‍💋‍👨🏼' => 'өбіс: әйел ер адам 1–2 тері түсі 3-тері түрі',
    '👩🏻‍❤‍💋‍👨🏽' => 'өбіс: әйел ер адам 1–2 тері түсі 4-тері түсі',
    '👩🏻‍❤‍💋‍👨🏾' => 'өбіс: әйел ер адам 1–2 тері түсі 5-тері түсі',
    '👩🏻‍❤‍💋‍👨🏿' => 'өбіс: әйел ер адам 1–2 тері түсі 6-тері түсі',
    '👩🏼‍❤‍💋‍👨🏻' => 'өбіс: әйел ер адам 3-тері түрі 1–2 тері түсі',
    '👩🏼‍❤‍💋‍👨🏼' => 'өбіс: әйел ер адам 3-тері түрі',
    '👩🏼‍❤‍💋‍👨🏽' => 'өбіс: әйел ер адам 3-тері түрі 4-тері түсі',
    '👩🏼‍❤‍💋‍👨🏾' => 'өбіс: әйел ер адам 3-тері түрі 5-тері түсі',
    '👩🏼‍❤‍💋‍👨🏿' => 'өбіс: әйел ер адам 3-тері түрі 6-тері түсі',
    '👩🏽‍❤‍💋‍👨🏻' => 'өбіс: әйел ер адам 4-тері түсі 1–2 тері түсі',
    '👩🏽‍❤‍💋‍👨🏼' => 'өбіс: әйел ер адам 4-тері түсі 3-тері түрі',
    '👩🏽‍❤‍💋‍👨🏽' => 'өбіс: әйел ер адам 4-тері түсі',
    '👩🏽‍❤‍💋‍👨🏾' => 'өбіс: әйел ер адам 4-тері түсі 5-тері түсі',
    '👩🏽‍❤‍💋‍👨🏿' => 'өбіс: әйел ер адам 4-тері түсі 6-тері түсі',
    '👩🏾‍❤‍💋‍👨🏻' => 'өбіс: әйел ер адам 5-тері түсі 1–2 тері түсі',
    '👩🏾‍❤‍💋‍👨🏼' => 'өбіс: әйел ер адам 5-тері түсі 3-тері түрі',
    '👩🏾‍❤‍💋‍👨🏽' => 'өбіс: әйел ер адам 5-тері түсі 4-тері түсі',
    '👩🏾‍❤‍💋‍👨🏾' => 'өбіс: әйел ер адам 5-тері түсі',
    '👩🏾‍❤‍💋‍👨🏿' => 'өбіс: әйел ер адам 5-тері түсі 6-тері түсі',
    '👩🏿‍❤‍💋‍👨🏻' => 'өбіс: әйел ер адам 6-тері түсі 1–2 тері түсі',
    '👩🏿‍❤‍💋‍👨🏼' => 'өбіс: әйел ер адам 6-тері түсі 3-тері түрі',
    '👩🏿‍❤‍💋‍👨🏽' => 'өбіс: әйел ер адам 6-тері түсі 4-тері түсі',
    '👩🏿‍❤‍💋‍👨🏾' => 'өбіс: әйел ер адам 6-тері түсі 5-тері түсі',
    '👩🏿‍❤‍💋‍👨🏿' => 'өбіс: әйел ер адам 6-тері түсі',
    '👩🏻‍❤‍💋‍👩🏻' => 'өбіс: әйел әйел 1–2 тері түсі',
    '👩🏻‍❤‍💋‍👩🏼' => 'өбіс: әйел әйел 1–2 тері түсі 3-тері түрі',
    '👩🏻‍❤‍💋‍👩🏽' => 'өбіс: әйел әйел 1–2 тері түсі 4-тері түсі',
    '👩🏻‍❤‍💋‍👩🏾' => 'өбіс: әйел әйел 1–2 тері түсі 5-тері түсі',
    '👩🏻‍❤‍💋‍👩🏿' => 'өбіс: әйел әйел 1–2 тері түсі 6-тері түсі',
    '👩🏼‍❤‍💋‍👩🏻' => 'өбіс: әйел әйел 3-тері түрі 1–2 тері түсі',
    '👩🏼‍❤‍💋‍👩🏼' => 'өбіс: әйел әйел 3-тері түрі',
    '👩🏼‍❤‍💋‍👩🏽' => 'өбіс: әйел әйел 3-тері түрі 4-тері түсі',
    '👩🏼‍❤‍💋‍👩🏾' => 'өбіс: әйел әйел 3-тері түрі 5-тері түсі',
    '👩🏼‍❤‍💋‍👩🏿' => 'өбіс: әйел әйел 3-тері түрі 6-тері түсі',
    '👩🏽‍❤‍💋‍👩🏻' => 'өбіс: әйел әйел 4-тері түсі 1–2 тері түсі',
    '👩🏽‍❤‍💋‍👩🏼' => 'өбіс: әйел әйел 4-тері түсі 3-тері түрі',
    '👩🏽‍❤‍💋‍👩🏽' => 'өбіс: әйел әйел 4-тері түсі',
    '👩🏽‍❤‍💋‍👩🏾' => 'өбіс: әйел әйел 4-тері түсі 5-тері түсі',
    '👩🏽‍❤‍💋‍👩🏿' => 'өбіс: әйел әйел 4-тері түсі 6-тері түсі',
    '👩🏾‍❤‍💋‍👩🏻' => 'өбіс: әйел әйел 5-тері түсі 1–2 тері түсі',
    '👩🏾‍❤‍💋‍👩🏼' => 'өбіс: әйел әйел 5-тері түсі 3-тері түрі',
    '👩🏾‍❤‍💋‍👩🏽' => 'өбіс: әйел әйел 5-тері түсі 4-тері түсі',
    '👩🏾‍❤‍💋‍👩🏾' => 'өбіс: әйел әйел 5-тері түсі',
    '👩🏾‍❤‍💋‍👩🏿' => 'өбіс: әйел әйел 5-тері түсі 6-тері түсі',
    '👩🏿‍❤‍💋‍👩🏻' => 'өбіс: әйел әйел 6-тері түсі 1–2 тері түсі',
    '👩🏿‍❤‍💋‍👩🏼' => 'өбіс: әйел әйел 6-тері түсі 3-тері түрі',
    '👩🏿‍❤‍💋‍👩🏽' => 'өбіс: әйел әйел 6-тері түсі 4-тері түсі',
    '👩🏿‍❤‍💋‍👩🏾' => 'өбіс: әйел әйел 6-тері түсі 5-тері түсі',
    '👩🏿‍❤‍💋‍👩🏿' => 'өбіс: әйел әйел 6-тері түсі',
    '🧑🏻‍🫯‍🧑🏼' => 'күресшілер: 1–2 тері түсі 3-тері түрі',
    '🧑🏻‍🫯‍🧑🏽' => 'күресшілер: 1–2 тері түсі 4-тері түсі',
    '🧑🏻‍🫯‍🧑🏾' => 'күресшілер: 1–2 тері түсі 5-тері түсі',
    '🧑🏻‍🫯‍🧑🏿' => 'күресшілер: 1–2 тері түсі 6-тері түсі',
    '🧑🏼‍🫯‍🧑🏻' => 'күресшілер: 3-тері түрі 1–2 тері түсі',
    '🧑🏼‍🫯‍🧑🏽' => 'күресшілер: 3-тері түрі 4-тері түсі',
    '🧑🏼‍🫯‍🧑🏾' => 'күресшілер: 3-тері түрі 5-тері түсі',
    '🧑🏼‍🫯‍🧑🏿' => 'күресшілер: 3-тері түрі 6-тері түсі',
    '🧑🏽‍🫯‍🧑🏻' => 'күресшілер: 4-тері түсі 1–2 тері түсі',
    '🧑🏽‍🫯‍🧑🏼' => 'күресшілер: 4-тері түсі 3-тері түрі',
    '🧑🏽‍🫯‍🧑🏾' => 'күресшілер: 4-тері түсі 5-тері түсі',
    '🧑🏽‍🫯‍🧑🏿' => 'күресшілер: 4-тері түсі 6-тері түсі',
    '🧑🏾‍🫯‍🧑🏻' => 'күресшілер: 5-тері түсі 1–2 тері түсі',
    '🧑🏾‍🫯‍🧑🏼' => 'күресшілер: 5-тері түсі 3-тері түрі',
    '🧑🏾‍🫯‍🧑🏽' => 'күресшілер: 5-тері түсі 4-тері түсі',
    '🧑🏾‍🫯‍🧑🏿' => 'күресшілер: 5-тері түсі 6-тері түсі',
    '🧑🏿‍🫯‍🧑🏻' => 'күресшілер: 6-тері түсі 1–2 тері түсі',
    '🧑🏿‍🫯‍🧑🏼' => 'күресшілер: 6-тері түсі 3-тері түрі',
    '🧑🏿‍🫯‍🧑🏽' => 'күресшілер: 6-тері түсі 4-тері түсі',
    '🧑🏿‍🫯‍🧑🏾' => 'күресшілер: 6-тері түсі 5-тері түсі',
    '🧑🏻‍❤‍🧑🏼' => 'махаббат: адам адам 1–2 тері түсі 3-тері түрі',
    '🧑🏻‍❤‍🧑🏽' => 'махаббат: адам адам 1–2 тері түсі 4-тері түсі',
    '🧑🏻‍❤‍🧑🏾' => 'махаббат: адам адам 1–2 тері түсі 5-тері түсі',
    '🧑🏻‍❤‍🧑🏿' => 'махаббат: адам адам 1–2 тері түсі 6-тері түсі',
    '🧑🏼‍❤‍🧑🏻' => 'махаббат: адам адам 3-тері түрі 1–2 тері түсі',
    '🧑🏼‍❤‍🧑🏽' => 'махаббат: адам адам 3-тері түрі 4-тері түсі',
    '🧑🏼‍❤‍🧑🏾' => 'махаббат: адам адам 3-тері түрі 5-тері түсі',
    '🧑🏼‍❤‍🧑🏿' => 'махаббат: адам адам 3-тері түрі 6-тері түсі',
    '🧑🏽‍❤‍🧑🏻' => 'махаббат: адам адам 4-тері түсі 1–2 тері түсі',
    '🧑🏽‍❤‍🧑🏼' => 'махаббат: адам адам 4-тері түсі 3-тері түрі',
    '🧑🏽‍❤‍🧑🏾' => 'махаббат: адам адам 4-тері түсі 5-тері түсі',
    '🧑🏽‍❤‍🧑🏿' => 'махаббат: адам адам 4-тері түсі 6-тері түсі',
    '🧑🏾‍❤‍🧑🏻' => 'махаббат: адам адам 5-тері түсі 1–2 тері түсі',
    '🧑🏾‍❤‍🧑🏼' => 'махаббат: адам адам 5-тері түсі 3-тері түрі',
    '🧑🏾‍❤‍🧑🏽' => 'махаббат: адам адам 5-тері түсі 4-тері түсі',
    '🧑🏾‍❤‍🧑🏿' => 'махаббат: адам адам 5-тері түсі 6-тері түсі',
    '🧑🏿‍❤‍🧑🏻' => 'махаббат: адам адам 6-тері түсі 1–2 тері түсі',
    '🧑🏿‍❤‍🧑🏼' => 'махаббат: адам адам 6-тері түсі 3-тері түрі',
    '🧑🏿‍❤‍🧑🏽' => 'махаббат: адам адам 6-тері түсі 4-тері түсі',
    '🧑🏿‍❤‍🧑🏾' => 'махаббат: адам адам 6-тері түсі 5-тері түсі',
    '🧑🏻‍🐰‍🧑🏼' => 'билеп жатқан әйелдер: 1–2 тері түсі 3-тері түрі',
    '🧑🏻‍🐰‍🧑🏽' => 'билеп жатқан әйелдер: 1–2 тері түсі 4-тері түсі',
    '🧑🏻‍🐰‍🧑🏾' => 'билеп жатқан әйелдер: 1–2 тері түсі 5-тері түсі',
    '🧑🏻‍🐰‍🧑🏿' => 'билеп жатқан әйелдер: 1–2 тері түсі 6-тері түсі',
    '🧑🏼‍🐰‍🧑🏻' => 'билеп жатқан әйелдер: 3-тері түрі 1–2 тері түсі',
    '🧑🏼‍🐰‍🧑🏽' => 'билеп жатқан әйелдер: 3-тері түрі 4-тері түсі',
    '🧑🏼‍🐰‍🧑🏾' => 'билеп жатқан әйелдер: 3-тері түрі 5-тері түсі',
    '🧑🏼‍🐰‍🧑🏿' => 'билеп жатқан әйелдер: 3-тері түрі 6-тері түсі',
    '🧑🏽‍🐰‍🧑🏻' => 'билеп жатқан әйелдер: 4-тері түсі 1–2 тері түсі',
    '🧑🏽‍🐰‍🧑🏼' => 'билеп жатқан әйелдер: 4-тері түсі 3-тері түрі',
    '🧑🏽‍🐰‍🧑🏾' => 'билеп жатқан әйелдер: 4-тері түсі 5-тері түсі',
    '🧑🏽‍🐰‍🧑🏿' => 'билеп жатқан әйелдер: 4-тері түсі 6-тері түсі',
    '🧑🏾‍🐰‍🧑🏻' => 'билеп жатқан әйелдер: 5-тері түсі 1–2 тері түсі',
    '🧑🏾‍🐰‍🧑🏼' => 'билеп жатқан әйелдер: 5-тері түсі 3-тері түрі',
    '🧑🏾‍🐰‍🧑🏽' => 'билеп жатқан әйелдер: 5-тері түсі 4-тері түсі',
    '🧑🏾‍🐰‍🧑🏿' => 'билеп жатқан әйелдер: 5-тері түсі 6-тері түсі',
    '🧑🏿‍🐰‍🧑🏻' => 'билеп жатқан әйелдер: 6-тері түсі 1–2 тері түсі',
    '🧑🏿‍🐰‍🧑🏼' => 'билеп жатқан әйелдер: 6-тері түсі 3-тері түрі',
    '🧑🏿‍🐰‍🧑🏽' => 'билеп жатқан әйелдер: 6-тері түсі 4-тері түсі',
    '🧑🏿‍🐰‍🧑🏾' => 'билеп жатқан әйелдер: 6-тері түсі 5-тері түсі',
    '👨🏻‍🫯‍👨🏼' => 'күресші ер: 1–2 тері түсі 3-тері түрі',
    '👨🏻‍🫯‍👨🏽' => 'күресші ер: 1–2 тері түсі 4-тері түсі',
    '👨🏻‍🫯‍👨🏾' => 'күресші ер: 1–2 тері түсі 5-тері түсі',
    '👨🏻‍🫯‍👨🏿' => 'күресші ер: 1–2 тері түсі 6-тері түсі',
    '👨🏼‍🫯‍👨🏻' => 'күресші ер: 3-тері түрі 1–2 тері түсі',
    '👨🏼‍🫯‍👨🏽' => 'күресші ер: 3-тері түрі 4-тері түсі',
    '👨🏼‍🫯‍👨🏾' => 'күресші ер: 3-тері түрі 5-тері түсі',
    '👨🏼‍🫯‍👨🏿' => 'күресші ер: 3-тері түрі 6-тері түсі',
    '👨🏽‍🫯‍👨🏻' => 'күресші ер: 4-тері түсі 1–2 тері түсі',
    '👨🏽‍🫯‍👨🏼' => 'күресші ер: 4-тері түсі 3-тері түрі',
    '👨🏽‍🫯‍👨🏾' => 'күресші ер: 4-тері түсі 5-тері түсі',
    '👨🏽‍🫯‍👨🏿' => 'күресші ер: 4-тері түсі 6-тері түсі',
    '👨🏾‍🫯‍👨🏻' => 'күресші ер: 5-тері түсі 1–2 тері түсі',
    '👨🏾‍🫯‍👨🏼' => 'күресші ер: 5-тері түсі 3-тері түрі',
    '👨🏾‍🫯‍👨🏽' => 'күресші ер: 5-тері түсі 4-тері түсі',
    '👨🏾‍🫯‍👨🏿' => 'күресші ер: 5-тері түсі 6-тері түсі',
    '👨🏿‍🫯‍👨🏻' => 'күресші ер: 6-тері түсі 1–2 тері түсі',
    '👨🏿‍🫯‍👨🏼' => 'күресші ер: 6-тері түсі 3-тері түрі',
    '👨🏿‍🫯‍👨🏽' => 'күресші ер: 6-тері түсі 4-тері түсі',
    '👨🏿‍🫯‍👨🏾' => 'күресші ер: 6-тері түсі 5-тері түсі',
    '👨🏻‍❤‍👨🏻' => 'махаббат: ер адам ер адам 1–2 тері түсі',
    '👨🏻‍❤‍👨🏼' => 'махаббат: ер адам ер адам 1–2 тері түсі 3-тері түрі',
    '👨🏻‍❤‍👨🏽' => 'махаббат: ер адам ер адам 1–2 тері түсі 4-тері түсі',
    '👨🏻‍❤‍👨🏾' => 'махаббат: ер адам ер адам 1–2 тері түсі 5-тері түсі',
    '👨🏻‍❤‍👨🏿' => 'махаббат: ер адам ер адам 1–2 тері түсі 6-тері түсі',
    '👨🏼‍❤‍👨🏻' => 'махаббат: ер адам ер адам 3-тері түрі 1–2 тері түсі',
    '👨🏼‍❤‍👨🏼' => 'махаббат: ер адам ер адам 3-тері түрі',
    '👨🏼‍❤‍👨🏽' => 'махаббат: ер адам ер адам 3-тері түрі 4-тері түсі',
    '👨🏼‍❤‍👨🏾' => 'махаббат: ер адам ер адам 3-тері түрі 5-тері түсі',
    '👨🏼‍❤‍👨🏿' => 'махаббат: ер адам ер адам 3-тері түрі 6-тері түсі',
    '👨🏽‍❤‍👨🏻' => 'махаббат: ер адам ер адам 4-тері түсі 1–2 тері түсі',
    '👨🏽‍❤‍👨🏼' => 'махаббат: ер адам ер адам 4-тері түсі 3-тері түрі',
    '👨🏽‍❤‍👨🏽' => 'махаббат: ер адам ер адам 4-тері түсі',
    '👨🏽‍❤‍👨🏾' => 'махаббат: ер адам ер адам 4-тері түсі 5-тері түсі',
    '👨🏽‍❤‍👨🏿' => 'махаббат: ер адам ер адам 4-тері түсі 6-тері түсі',
    '👨🏾‍❤‍👨🏻' => 'махаббат: ер адам ер адам 5-тері түсі 1–2 тері түсі',
    '👨🏾‍❤‍👨🏼' => 'махаббат: ер адам ер адам 5-тері түсі 3-тері түрі',
    '👨🏾‍❤‍👨🏽' => 'махаббат: ер адам ер адам 5-тері түсі 4-тері түсі',
    '👨🏾‍❤‍👨🏾' => 'махаббат: ер адам ер адам 5-тері түсі',
    '👨🏾‍❤‍👨🏿' => 'махаббат: ер адам ер адам 5-тері түсі 6-тері түсі',
    '👨🏿‍❤‍👨🏻' => 'махаббат: ер адам ер адам 6-тері түсі 1–2 тері түсі',
    '👨🏿‍❤‍👨🏼' => 'махаббат: ер адам ер адам 6-тері түсі 3-тері түрі',
    '👨🏿‍❤‍👨🏽' => 'махаббат: ер адам ер адам 6-тері түсі 4-тері түсі',
    '👨🏿‍❤‍👨🏾' => 'махаббат: ер адам ер адам 6-тері түсі 5-тері түсі',
    '👨🏿‍❤‍👨🏿' => 'махаббат: ер адам ер адам 6-тері түсі',
    '👨🏻‍🐰‍👨🏼' => 'тойлатып жүрген ерлер: 1–2 тері түсі 3-тері түрі',
    '👨🏻‍🐰‍👨🏽' => 'тойлатып жүрген ерлер: 1–2 тері түсі 4-тері түсі',
    '👨🏻‍🐰‍👨🏾' => 'тойлатып жүрген ерлер: 1–2 тері түсі 5-тері түсі',
    '👨🏻‍🐰‍👨🏿' => 'тойлатып жүрген ерлер: 1–2 тері түсі 6-тері түсі',
    '👨🏼‍🐰‍👨🏻' => 'тойлатып жүрген ерлер: 3-тері түрі 1–2 тері түсі',
    '👨🏼‍🐰‍👨🏽' => 'тойлатып жүрген ерлер: 3-тері түрі 4-тері түсі',
    '👨🏼‍🐰‍👨🏾' => 'тойлатып жүрген ерлер: 3-тері түрі 5-тері түсі',
    '👨🏼‍🐰‍👨🏿' => 'тойлатып жүрген ерлер: 3-тері түрі 6-тері түсі',
    '👨🏽‍🐰‍👨🏻' => 'тойлатып жүрген ерлер: 4-тері түсі 1–2 тері түсі',
    '👨🏽‍🐰‍👨🏼' => 'тойлатып жүрген ерлер: 4-тері түсі 3-тері түрі',
    '👨🏽‍🐰‍👨🏾' => 'тойлатып жүрген ерлер: 4-тері түсі 5-тері түсі',
    '👨🏽‍🐰‍👨🏿' => 'тойлатып жүрген ерлер: 4-тері түсі 6-тері түсі',
    '👨🏾‍🐰‍👨🏻' => 'тойлатып жүрген ерлер: 5-тері түсі 1–2 тері түсі',
    '👨🏾‍🐰‍👨🏼' => 'тойлатып жүрген ерлер: 5-тері түсі 3-тері түрі',
    '👨🏾‍🐰‍👨🏽' => 'тойлатып жүрген ерлер: 5-тері түсі 4-тері түсі',
    '👨🏾‍🐰‍👨🏿' => 'тойлатып жүрген ерлер: 5-тері түсі 6-тері түсі',
    '👨🏿‍🐰‍👨🏻' => 'тойлатып жүрген ерлер: 6-тері түсі 1–2 тері түсі',
    '👨🏿‍🐰‍👨🏼' => 'тойлатып жүрген ерлер: 6-тері түсі 3-тері түрі',
    '👨🏿‍🐰‍👨🏽' => 'тойлатып жүрген ерлер: 6-тері түсі 4-тері түсі',
    '👨🏿‍🐰‍👨🏾' => 'тойлатып жүрген ерлер: 6-тері түсі 5-тері түсі',
    '👩🏻‍🫯‍👩🏼' => 'күресші әйел: 1–2 тері түсі 3-тері түрі',
    '👩🏻‍🫯‍👩🏽' => 'күресші әйел: 1–2 тері түсі 4-тері түсі',
    '👩🏻‍🫯‍👩🏾' => 'күресші әйел: 1–2 тері түсі 5-тері түсі',
    '👩🏻‍🫯‍👩🏿' => 'күресші әйел: 1–2 тері түсі 6-тері түсі',
    '👩🏼‍🫯‍👩🏻' => 'күресші әйел: 3-тері түрі 1–2 тері түсі',
    '👩🏼‍🫯‍👩🏽' => 'күресші әйел: 3-тері түрі 4-тері түсі',
    '👩🏼‍🫯‍👩🏾' => 'күресші әйел: 3-тері түрі 5-тері түсі',
    '👩🏼‍🫯‍👩🏿' => 'күресші әйел: 3-тері түрі 6-тері түсі',
    '👩🏽‍🫯‍👩🏻' => 'күресші әйел: 4-тері түсі 1–2 тері түсі',
    '👩🏽‍🫯‍👩🏼' => 'күресші әйел: 4-тері түсі 3-тері түрі',
    '👩🏽‍🫯‍👩🏾' => 'күресші әйел: 4-тері түсі 5-тері түсі',
    '👩🏽‍🫯‍👩🏿' => 'күресші әйел: 4-тері түсі 6-тері түсі',
    '👩🏾‍🫯‍👩🏻' => 'күресші әйел: 5-тері түсі 1–2 тері түсі',
    '👩🏾‍🫯‍👩🏼' => 'күресші әйел: 5-тері түсі 3-тері түрі',
    '👩🏾‍🫯‍👩🏽' => 'күресші әйел: 5-тері түсі 4-тері түсі',
    '👩🏾‍🫯‍👩🏿' => 'күресші әйел: 5-тері түсі 6-тері түсі',
    '👩🏿‍🫯‍👩🏻' => 'күресші әйел: 6-тері түсі 1–2 тері түсі',
    '👩🏿‍🫯‍👩🏼' => 'күресші әйел: 6-тері түсі 3-тері түрі',
    '👩🏿‍🫯‍👩🏽' => 'күресші әйел: 6-тері түсі 4-тері түсі',
    '👩🏿‍🫯‍👩🏾' => 'күресші әйел: 6-тері түсі 5-тері түсі',
    '👩🏻‍❤‍👨🏻' => 'махаббат: әйел ер адам 1–2 тері түсі',
    '👩🏻‍❤‍👨🏼' => 'махаббат: әйел ер адам 1–2 тері түсі 3-тері түрі',
    '👩🏻‍❤‍👨🏽' => 'махаббат: әйел ер адам 1–2 тері түсі 4-тері түсі',
    '👩🏻‍❤‍👨🏾' => 'махаббат: әйел ер адам 1–2 тері түсі 5-тері түсі',
    '👩🏻‍❤‍👨🏿' => 'махаббат: әйел ер адам 1–2 тері түсі 6-тері түсі',
    '👩🏼‍❤‍👨🏻' => 'махаббат: әйел ер адам 3-тері түрі 1–2 тері түсі',
    '👩🏼‍❤‍👨🏼' => 'махаббат: әйел ер адам 3-тері түрі',
    '👩🏼‍❤‍👨🏽' => 'махаббат: әйел ер адам 3-тері түрі 4-тері түсі',
    '👩🏼‍❤‍👨🏾' => 'махаббат: әйел ер адам 3-тері түрі 5-тері түсі',
    '👩🏼‍❤‍👨🏿' => 'махаббат: әйел ер адам 3-тері түрі 6-тері түсі',
    '👩🏽‍❤‍👨🏻' => 'махаббат: әйел ер адам 4-тері түсі 1–2 тері түсі',
    '👩🏽‍❤‍👨🏼' => 'махаббат: әйел ер адам 4-тері түсі 3-тері түрі',
    '👩🏽‍❤‍👨🏽' => 'махаббат: әйел ер адам 4-тері түсі',
    '👩🏽‍❤‍👨🏾' => 'махаббат: әйел ер адам 4-тері түсі 5-тері түсі',
    '👩🏽‍❤‍👨🏿' => 'махаббат: әйел ер адам 4-тері түсі 6-тері түсі',
    '👩🏾‍❤‍👨🏻' => 'махаббат: әйел ер адам 5-тері түсі 1–2 тері түсі',
    '👩🏾‍❤‍👨🏼' => 'махаббат: әйел ер адам 5-тері түсі 3-тері түрі',
    '👩🏾‍❤‍👨🏽' => 'махаббат: әйел ер адам 5-тері түсі 4-тері түсі',
    '👩🏾‍❤‍👨🏾' => 'махаббат: әйел ер адам 5-тері түсі',
    '👩🏾‍❤‍👨🏿' => 'махаббат: әйел ер адам 5-тері түсі 6-тері түсі',
    '👩🏿‍❤‍👨🏻' => 'махаббат: әйел ер адам 6-тері түсі 1–2 тері түсі',
    '👩🏿‍❤‍👨🏼' => 'махаббат: әйел ер адам 6-тері түсі 3-тері түрі',
    '👩🏿‍❤‍👨🏽' => 'махаббат: әйел ер адам 6-тері түсі 4-тері түсі',
    '👩🏿‍❤‍👨🏾' => 'махаббат: әйел ер адам 6-тері түсі 5-тері түсі',
    '👩🏿‍❤‍👨🏿' => 'махаббат: әйел ер адам 6-тері түсі',
    '👩🏻‍❤‍👩🏻' => 'махаббат: әйел әйел 1–2 тері түсі',
    '👩🏻‍❤‍👩🏼' => 'махаббат: әйел әйел 1–2 тері түсі 3-тері түрі',
    '👩🏻‍❤‍👩🏽' => 'махаббат: әйел әйел 1–2 тері түсі 4-тері түсі',
    '👩🏻‍❤‍👩🏾' => 'махаббат: әйел әйел 1–2 тері түсі 5-тері түсі',
    '👩🏻‍❤‍👩🏿' => 'махаббат: әйел әйел 1–2 тері түсі 6-тері түсі',
    '👩🏼‍❤‍👩🏻' => 'махаббат: әйел әйел 3-тері түрі 1–2 тері түсі',
    '👩🏼‍❤‍👩🏼' => 'махаббат: әйел әйел 3-тері түрі',
    '👩🏼‍❤‍👩🏽' => 'махаббат: әйел әйел 3-тері түрі 4-тері түсі',
    '👩🏼‍❤‍👩🏾' => 'махаббат: әйел әйел 3-тері түрі 5-тері түсі',
    '👩🏼‍❤‍👩🏿' => 'махаббат: әйел әйел 3-тері түрі 6-тері түсі',
    '👩🏽‍❤‍👩🏻' => 'махаббат: әйел әйел 4-тері түсі 1–2 тері түсі',
    '👩🏽‍❤‍👩🏼' => 'махаббат: әйел әйел 4-тері түсі 3-тері түрі',
    '👩🏽‍❤‍👩🏽' => 'махаббат: әйел әйел 4-тері түсі',
    '👩🏽‍❤‍👩🏾' => 'махаббат: әйел әйел 4-тері түсі 5-тері түсі',
    '👩🏽‍❤‍👩🏿' => 'махаббат: әйел әйел 4-тері түсі 6-тері түсі',
    '👩🏾‍❤‍👩🏻' => 'махаббат: әйел әйел 5-тері түсі 1–2 тері түсі',
    '👩🏾‍❤‍👩🏼' => 'махаббат: әйел әйел 5-тері түсі 3-тері түрі',
    '👩🏾‍❤‍👩🏽' => 'махаббат: әйел әйел 5-тері түсі 4-тері түсі',
    '👩🏾‍❤‍👩🏾' => 'махаббат: әйел әйел 5-тері түсі',
    '👩🏾‍❤‍👩🏿' => 'махаббат: әйел әйел 5-тері түсі 6-тері түсі',
    '👩🏿‍❤‍👩🏻' => 'махаббат: әйел әйел 6-тері түсі 1–2 тері түсі',
    '👩🏿‍❤‍👩🏼' => 'махаббат: әйел әйел 6-тері түсі 3-тері түрі',
    '👩🏿‍❤‍👩🏽' => 'махаббат: әйел әйел 6-тері түсі 4-тері түсі',
    '👩🏿‍❤‍👩🏾' => 'махаббат: әйел әйел 6-тері түсі 5-тері түсі',
    '👩🏿‍❤‍👩🏿' => 'махаббат: әйел әйел 6-тері түсі',
    '👩🏻‍🐰‍👩🏼' => 'тойлатып жүрген әйелдер: 1–2 тері түсі 3-тері түрі',
    '👩🏻‍🐰‍👩🏽' => 'тойлатып жүрген әйелдер: 1–2 тері түсі 4-тері түсі',
    '👩🏻‍🐰‍👩🏾' => 'тойлатып жүрген әйелдер: 1–2 тері түсі 5-тері түсі',
    '👩🏻‍🐰‍👩🏿' => 'тойлатып жүрген әйелдер: 1–2 тері түсі 6-тері түсі',
    '👩🏼‍🐰‍👩🏻' => 'тойлатып жүрген әйелдер: 3-тері түрі 1–2 тері түсі',
    '👩🏼‍🐰‍👩🏽' => 'тойлатып жүрген әйелдер: 3-тері түрі 4-тері түсі',
    '👩🏼‍🐰‍👩🏾' => 'тойлатып жүрген әйелдер: 3-тері түрі 5-тері түсі',
    '👩🏼‍🐰‍👩🏿' => 'тойлатып жүрген әйелдер: 3-тері түрі 6-тері түсі',
    '👩🏽‍🐰‍👩🏻' => 'тойлатып жүрген әйелдер: 4-тері түсі 1–2 тері түсі',
    '👩🏽‍🐰‍👩🏼' => 'тойлатып жүрген әйелдер: 4-тері түсі 3-тері түрі',
    '👩🏽‍🐰‍👩🏾' => 'тойлатып жүрген әйелдер: 4-тері түсі 5-тері түсі',
    '👩🏽‍🐰‍👩🏿' => 'тойлатып жүрген әйелдер: 4-тері түсі 6-тері түсі',
    '👩🏾‍🐰‍👩🏻' => 'тойлатып жүрген әйелдер: 5-тері түсі 1–2 тері түсі',
    '👩🏾‍🐰‍👩🏼' => 'тойлатып жүрген әйелдер: 5-тері түсі 3-тері түрі',
    '👩🏾‍🐰‍👩🏽' => 'тойлатып жүрген әйелдер: 5-тері түсі 4-тері түсі',
    '👩🏾‍🐰‍👩🏿' => 'тойлатып жүрген әйелдер: 5-тері түсі 6-тері түсі',
    '👩🏿‍🐰‍👩🏻' => 'тойлатып жүрген әйелдер: 6-тері түсі 1–2 тері түсі',
    '👩🏿‍🐰‍👩🏼' => 'тойлатып жүрген әйелдер: 6-тері түсі 3-тері түрі',
    '👩🏿‍🐰‍👩🏽' => 'тойлатып жүрген әйелдер: 6-тері түсі 4-тері түсі',
    '👩🏿‍🐰‍👩🏾' => 'тойлатып жүрген әйелдер: 6-тері түсі 5-тері түсі',
    '🧑🏻‍🤝‍🧑🏻' => 'қолдарын көтеріп тұрған адамдар: 1–2 тері түсі',
    '🧑🏻‍🤝‍🧑🏼' => 'қолдарын көтеріп тұрған адамдар: 1–2 тері түсі 3-тері түрі',
    '🧑🏻‍🤝‍🧑🏽' => 'қолдарын көтеріп тұрған адамдар: 1–2 тері түсі 4-тері түсі',
    '🧑🏻‍🤝‍🧑🏾' => 'қолдарын көтеріп тұрған адамдар: 1–2 тері түсі 5-тері түсі',
    '🧑🏻‍🤝‍🧑🏿' => 'қолдарын көтеріп тұрған адамдар: 1–2 тері түсі 6-тері түсі',
    '🧑🏼‍🤝‍🧑🏻' => 'қолдарын көтеріп тұрған адамдар: 3-тері түрі 1–2 тері түсі',
    '🧑🏼‍🤝‍🧑🏼' => 'қолдарын көтеріп тұрған адамдар: 3-тері түрі',
    '🧑🏼‍🤝‍🧑🏽' => 'қолдарын көтеріп тұрған адамдар: 3-тері түрі 4-тері түсі',
    '🧑🏼‍🤝‍🧑🏾' => 'қолдарын көтеріп тұрған адамдар: 3-тері түрі 5-тері түсі',
    '🧑🏼‍🤝‍🧑🏿' => 'қолдарын көтеріп тұрған адамдар: 3-тері түрі 6-тері түсі',
    '🧑🏽‍🤝‍🧑🏻' => 'қолдарын көтеріп тұрған адамдар: 4-тері түсі 1–2 тері түсі',
    '🧑🏽‍🤝‍🧑🏼' => 'қолдарын көтеріп тұрған адамдар: 4-тері түсі 3-тері түрі',
    '🧑🏽‍🤝‍🧑🏽' => 'қолдарын көтеріп тұрған адамдар: 4-тері түсі',
    '🧑🏽‍🤝‍🧑🏾' => 'қолдарын көтеріп тұрған адамдар: 4-тері түсі 5-тері түсі',
    '🧑🏽‍🤝‍🧑🏿' => 'қолдарын көтеріп тұрған адамдар: 4-тері түсі 6-тері түсі',
    '🧑🏾‍🤝‍🧑🏻' => 'қолдарын көтеріп тұрған адамдар: 5-тері түсі 1–2 тері түсі',
    '🧑🏾‍🤝‍🧑🏼' => 'қолдарын көтеріп тұрған адамдар: 5-тері түсі 3-тері түрі',
    '🧑🏾‍🤝‍🧑🏽' => 'қолдарын көтеріп тұрған адамдар: 5-тері түсі 4-тері түсі',
    '🧑🏾‍🤝‍🧑🏾' => 'қолдарын көтеріп тұрған адамдар: 5-тері түсі',
    '🧑🏾‍🤝‍🧑🏿' => 'қолдарын көтеріп тұрған адамдар: 5-тері түсі 6-тері түсі',
    '🧑🏿‍🤝‍🧑🏻' => 'қолдарын көтеріп тұрған адамдар: 6-тері түсі 1–2 тері түсі',
    '🧑🏿‍🤝‍🧑🏼' => 'қолдарын көтеріп тұрған адамдар: 6-тері түсі 3-тері түрі',
    '🧑🏿‍🤝‍🧑🏽' => 'қолдарын көтеріп тұрған адамдар: 6-тері түсі 4-тері түсі',
    '🧑🏿‍🤝‍🧑🏾' => 'қолдарын көтеріп тұрған адамдар: 6-тері түсі 5-тері түсі',
    '🧑🏿‍🤝‍🧑🏿' => 'қолдарын көтеріп тұрған адамдар: 6-тері түсі',
    '👩🏻‍🤝‍👩🏼' => 'қол ұстасып тұрған екі әйел: 1–2 тері түсі 3-тері түрі',
    '👩🏻‍🤝‍👩🏽' => 'қол ұстасып тұрған екі әйел: 1–2 тері түсі 4-тері түсі',
    '👩🏻‍🤝‍👩🏾' => 'қол ұстасып тұрған екі әйел: 1–2 тері түсі 5-тері түсі',
    '👩🏻‍🤝‍👩🏿' => 'қол ұстасып тұрған екі әйел: 1–2 тері түсі 6-тері түсі',
    '👩🏼‍🤝‍👩🏻' => 'қол ұстасып тұрған екі әйел: 3-тері түрі 1–2 тері түсі',
    '👩🏼‍🤝‍👩🏽' => 'қол ұстасып тұрған екі әйел: 3-тері түрі 4-тері түсі',
    '👩🏼‍🤝‍👩🏾' => 'қол ұстасып тұрған екі әйел: 3-тері түрі 5-тері түсі',
    '👩🏼‍🤝‍👩🏿' => 'қол ұстасып тұрған екі әйел: 3-тері түрі 6-тері түсі',
    '👩🏽‍🤝‍👩🏻' => 'қол ұстасып тұрған екі әйел: 4-тері түсі 1–2 тері түсі',
    '👩🏽‍🤝‍👩🏼' => 'қол ұстасып тұрған екі әйел: 4-тері түсі 3-тері түрі',
    '👩🏽‍🤝‍👩🏾' => 'қол ұстасып тұрған екі әйел: 4-тері түсі 5-тері түсі',
    '👩🏽‍🤝‍👩🏿' => 'қол ұстасып тұрған екі әйел: 4-тері түсі 6-тері түсі',
    '👩🏾‍🤝‍👩🏻' => 'қол ұстасып тұрған екі әйел: 5-тері түсі 1–2 тері түсі',
    '👩🏾‍🤝‍👩🏼' => 'қол ұстасып тұрған екі әйел: 5-тері түсі 3-тері түрі',
    '👩🏾‍🤝‍👩🏽' => 'қол ұстасып тұрған екі әйел: 5-тері түсі 4-тері түсі',
    '👩🏾‍🤝‍👩🏿' => 'қол ұстасып тұрған екі әйел: 5-тері түсі 6-тері түсі',
    '👩🏿‍🤝‍👩🏻' => 'қол ұстасып тұрған екі әйел: 6-тері түсі 1–2 тері түсі',
    '👩🏿‍🤝‍👩🏼' => 'қол ұстасып тұрған екі әйел: 6-тері түсі 3-тері түрі',
    '👩🏿‍🤝‍👩🏽' => 'қол ұстасып тұрған екі әйел: 6-тері түсі 4-тері түсі',
    '👩🏿‍🤝‍👩🏾' => 'қол ұстасып тұрған екі әйел: 6-тері түсі 5-тері түсі',
    '👩🏻‍🤝‍👨🏼' => 'қол ұстасып тұрған еркек пен әйел: 1–2 тері түсі 3-тері түрі',
    '👩🏻‍🤝‍👨🏽' => 'қол ұстасып тұрған еркек пен әйел: 1–2 тері түсі 4-тері түсі',
    '👩🏻‍🤝‍👨🏾' => 'қол ұстасып тұрған еркек пен әйел: 1–2 тері түсі 5-тері түсі',
    '👩🏻‍🤝‍👨🏿' => 'қол ұстасып тұрған еркек пен әйел: 1–2 тері түсі 6-тері түсі',
    '👩🏼‍🤝‍👨🏻' => 'қол ұстасып тұрған еркек пен әйел: 3-тері түрі 1–2 тері түсі',
    '👩🏼‍🤝‍👨🏽' => 'қол ұстасып тұрған еркек пен әйел: 3-тері түрі 4-тері түсі',
    '👩🏼‍🤝‍👨🏾' => 'қол ұстасып тұрған еркек пен әйел: 3-тері түрі 5-тері түсі',
    '👩🏼‍🤝‍👨🏿' => 'қол ұстасып тұрған еркек пен әйел: 3-тері түрі 6-тері түсі',
    '👩🏽‍🤝‍👨🏻' => 'қол ұстасып тұрған еркек пен әйел: 4-тері түсі 1–2 тері түсі',
    '👩🏽‍🤝‍👨🏼' => 'қол ұстасып тұрған еркек пен әйел: 4-тері түсі 3-тері түрі',
    '👩🏽‍🤝‍👨🏾' => 'қол ұстасып тұрған еркек пен әйел: 4-тері түсі 5-тері түсі',
    '👩🏽‍🤝‍👨🏿' => 'қол ұстасып тұрған еркек пен әйел: 4-тері түсі 6-тері түсі',
    '👩🏾‍🤝‍👨🏻' => 'қол ұстасып тұрған еркек пен әйел: 5-тері түсі 1–2 тері түсі',
    '👩🏾‍🤝‍👨🏼' => 'қол ұстасып тұрған еркек пен әйел: 5-тері түсі 3-тері түрі',
    '👩🏾‍🤝‍👨🏽' => 'қол ұстасып тұрған еркек пен әйел: 5-тері түсі 4-тері түсі',
    '👩🏾‍🤝‍👨🏿' => 'қол ұстасып тұрған еркек пен әйел: 5-тері түсі 6-тері түсі',
    '👩🏿‍🤝‍👨🏻' => 'қол ұстасып тұрған еркек пен әйел: 6-тері түсі 1–2 тері түсі',
    '👩🏿‍🤝‍👨🏼' => 'қол ұстасып тұрған еркек пен әйел: 6-тері түсі 3-тері түрі',
    '👩🏿‍🤝‍👨🏽' => 'қол ұстасып тұрған еркек пен әйел: 6-тері түсі 4-тері түсі',
    '👩🏿‍🤝‍👨🏾' => 'қол ұстасып тұрған еркек пен әйел: 6-тері түсі 5-тері түсі',
    '👨🏻‍🤝‍👨🏼' => 'қол ұстасып тұрған екі еркек: 1–2 тері түсі 3-тері түрі',
    '👨🏻‍🤝‍👨🏽' => 'қол ұстасып тұрған екі еркек: 1–2 тері түсі 4-тері түсі',
    '👨🏻‍🤝‍👨🏾' => 'қол ұстасып тұрған екі еркек: 1–2 тері түсі 5-тері түсі',
    '👨🏻‍🤝‍👨🏿' => 'қол ұстасып тұрған екі еркек: 1–2 тері түсі 6-тері түсі',
    '👨🏼‍🤝‍👨🏻' => 'қол ұстасып тұрған екі еркек: 3-тері түрі 1–2 тері түсі',
    '👨🏼‍🤝‍👨🏽' => 'қол ұстасып тұрған екі еркек: 3-тері түрі 4-тері түсі',
    '👨🏼‍🤝‍👨🏾' => 'қол ұстасып тұрған екі еркек: 3-тері түрі 5-тері түсі',
    '👨🏼‍🤝‍👨🏿' => 'қол ұстасып тұрған екі еркек: 3-тері түрі 6-тері түсі',
    '👨🏽‍🤝‍👨🏻' => 'қол ұстасып тұрған екі еркек: 4-тері түсі 1–2 тері түсі',
    '👨🏽‍🤝‍👨🏼' => 'қол ұстасып тұрған екі еркек: 4-тері түсі 3-тері түрі',
    '👨🏽‍🤝‍👨🏾' => 'қол ұстасып тұрған екі еркек: 4-тері түсі 5-тері түсі',
    '👨🏽‍🤝‍👨🏿' => 'қол ұстасып тұрған екі еркек: 4-тері түсі 6-тері түсі',
    '👨🏾‍🤝‍👨🏻' => 'қол ұстасып тұрған екі еркек: 5-тері түсі 1–2 тері түсі',
    '👨🏾‍🤝‍👨🏼' => 'қол ұстасып тұрған екі еркек: 5-тері түсі 3-тері түрі',
    '👨🏾‍🤝‍👨🏽' => 'қол ұстасып тұрған екі еркек: 5-тері түсі 4-тері түсі',
    '👨🏾‍🤝‍👨🏿' => 'қол ұстасып тұрған екі еркек: 5-тері түсі 6-тері түсі',
    '👨🏿‍🤝‍👨🏻' => 'қол ұстасып тұрған екі еркек: 6-тері түсі 1–2 тері түсі',
    '👨🏿‍🤝‍👨🏼' => 'қол ұстасып тұрған екі еркек: 6-тері түсі 3-тері түрі',
    '👨🏿‍🤝‍👨🏽' => 'қол ұстасып тұрған екі еркек: 6-тері түсі 4-тері түсі',
    '👨🏿‍🤝‍👨🏾' => 'қол ұстасып тұрған екі еркек: 6-тері түсі 5-тері түсі',
    '👩‍❤‍💋‍👨' => 'өбіс: әйел ер адам',
    '👨‍❤‍💋‍👨' => 'өбіс: ер адам ер адам',
    '👩‍❤‍💋‍👩' => 'өбіс: әйел әйел',
    '👨‍👩‍👧‍👦' => 'отбасы: ер адам әйел қыз ұл',
    '👨‍👩‍👦‍👦' => 'отбасы: ер адам әйел ұл ұл',
    '👨‍👩‍👧‍👧' => 'отбасы: ер адам әйел қыз қыз',
    '👨‍👨‍👧‍👦' => 'отбасы: ер адам ер адам қыз ұл',
    '👨‍👨‍👦‍👦' => 'отбасы: ер адам ер адам ұл ұл',
    '👨‍👨‍👧‍👧' => 'отбасы: ер адам ер адам қыз қыз',
    '👩‍👩‍👧‍👦' => 'отбасы: әйел әйел қыз ұл',
    '👩‍👩‍👦‍👦' => 'отбасы: әйел әйел ұл ұл',
    '👩‍👩‍👧‍👧' => 'отбасы: әйел әйел қыз қыз',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'ту: Англия',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'ту: Шотландия',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'ту: Уэльс',
    '🧑‍🧑‍🧒‍🧒' => 'отбасы: ересек, ересек, бала, бала',
    '🚶🏻‍♀‍➡' => 'жаяу әйел: 1–2 тері түсі оңға қаратылған',
    '🚶🏼‍♀‍➡' => 'жаяу әйел: 3-тері түрі оңға қаратылған',
    '🚶🏽‍♀‍➡' => 'жаяу әйел: 4-тері түсі оңға қаратылған',
    '🚶🏾‍♀‍➡' => 'жаяу әйел: 5-тері түсі оңға қаратылған',
    '🚶🏿‍♀‍➡' => 'жаяу әйел: 6-тері түсі оңға қаратылған',
    '🚶🏻‍♂‍➡' => 'жаяу ер: 1–2 тері түсі оңға қаратылған',
    '🚶🏼‍♂‍➡' => 'жаяу ер: 3-тері түрі оңға қаратылған',
    '🚶🏽‍♂‍➡' => 'жаяу ер: 4-тері түсі оңға қаратылған',
    '🚶🏾‍♂‍➡' => 'жаяу ер: 5-тері түсі оңға қаратылған',
    '🚶🏿‍♂‍➡' => 'жаяу ер: 6-тері түсі оңға қаратылған',
    '🧎🏻‍♀‍➡' => 'тізерлеп отырған әйел: 1–2 тері түсі оңға қаратылған',
    '🧎🏼‍♀‍➡' => 'тізерлеп отырған әйел: 3-тері түрі оңға қаратылған',
    '🧎🏽‍♀‍➡' => 'тізерлеп отырған әйел: 4-тері түсі оңға қаратылған',
    '🧎🏾‍♀‍➡' => 'тізерлеп отырған әйел: 5-тері түсі оңға қаратылған',
    '🧎🏿‍♀‍➡' => 'тізерлеп отырған әйел: 6-тері түсі оңға қаратылған',
    '🧎🏻‍♂‍➡' => 'тізерлеп отырған еркек: 1–2 тері түсі оңға қаратылған',
    '🧎🏼‍♂‍➡' => 'тізерлеп отырған еркек: 3-тері түрі оңға қаратылған',
    '🧎🏽‍♂‍➡' => 'тізерлеп отырған еркек: 4-тері түсі оңға қаратылған',
    '🧎🏾‍♂‍➡' => 'тізерлеп отырған еркек: 5-тері түсі оңға қаратылған',
    '🧎🏿‍♂‍➡' => 'тізерлеп отырған еркек: 6-тері түсі оңға қаратылған',
    '🧑🏻‍🦯‍➡' => 'таяғы бар адам: 1–2 тері түсі оңға қаратылған',
    '🧑🏼‍🦯‍➡' => 'таяғы бар адам: 3-тері түрі оңға қаратылған',
    '🧑🏽‍🦯‍➡' => 'таяғы бар адам: 4-тері түсі оңға қаратылған',
    '🧑🏾‍🦯‍➡' => 'таяғы бар адам: 5-тері түсі оңға қаратылған',
    '🧑🏿‍🦯‍➡' => 'таяғы бар адам: 6-тері түсі оңға қаратылған',
    '👨🏻‍🦯‍➡' => 'таяғы бар еркек: 1–2 тері түсі оңға қаратылған',
    '👨🏼‍🦯‍➡' => 'таяғы бар еркек: 3-тері түрі оңға қаратылған',
    '👨🏽‍🦯‍➡' => 'таяғы бар еркек: 4-тері түсі оңға қаратылған',
    '👨🏾‍🦯‍➡' => 'таяғы бар еркек: 5-тері түсі оңға қаратылған',
    '👨🏿‍🦯‍➡' => 'таяғы бар еркек: 6-тері түсі оңға қаратылған',
    '👩🏻‍🦯‍➡' => 'таяғы бар әйел: 1–2 тері түсі оңға қаратылған',
    '👩🏼‍🦯‍➡' => 'таяғы бар әйел: 3-тері түрі оңға қаратылған',
    '👩🏽‍🦯‍➡' => 'таяғы бар әйел: 4-тері түсі оңға қаратылған',
    '👩🏾‍🦯‍➡' => 'таяғы бар әйел: 5-тері түсі оңға қаратылған',
    '👩🏿‍🦯‍➡' => 'таяғы бар әйел: 6-тері түсі оңға қаратылған',
    '🧑🏻‍🦼‍➡' => 'моторлы арбадағы адам: 1–2 тері түсі оңға қаратылған',
    '🧑🏼‍🦼‍➡' => 'моторлы арбадағы адам: 3-тері түрі оңға қаратылған',
    '🧑🏽‍🦼‍➡' => 'моторлы арбадағы адам: 4-тері түсі оңға қаратылған',
    '🧑🏾‍🦼‍➡' => 'моторлы арбадағы адам: 5-тері түсі оңға қаратылған',
    '🧑🏿‍🦼‍➡' => 'моторлы арбадағы адам: 6-тері түсі оңға қаратылған',
    '👨🏻‍🦼‍➡' => 'электр жетегі бар арбашадағы еркек: 1–2 тері түсі оңға қаратылған',
    '👨🏼‍🦼‍➡' => 'электр жетегі бар арбашадағы еркек: 3-тері түрі оңға қаратылған',
    '👨🏽‍🦼‍➡' => 'электр жетегі бар арбашадағы еркек: 4-тері түсі оңға қаратылған',
    '👨🏾‍🦼‍➡' => 'электр жетегі бар арбашадағы еркек: 5-тері түсі оңға қаратылған',
    '👨🏿‍🦼‍➡' => 'электр жетегі бар арбашадағы еркек: 6-тері түсі оңға қаратылған',
    '👩🏻‍🦼‍➡' => 'электр жетегі бар арбашадағы әйел: 1–2 тері түсі оңға қаратылған',
    '👩🏼‍🦼‍➡' => 'электр жетегі бар арбашадағы әйел: 3-тері түрі оңға қаратылған',
    '👩🏽‍🦼‍➡' => 'электр жетегі бар арбашадағы әйел: 4-тері түсі оңға қаратылған',
    '👩🏾‍🦼‍➡' => 'электр жетегі бар арбашадағы әйел: 5-тері түсі оңға қаратылған',
    '👩🏿‍🦼‍➡' => 'электр жетегі бар арбашадағы әйел: 6-тері түсі оңға қаратылған',
    '🧑🏻‍🦽‍➡' => 'қол жетегі бар арбашадағы адам: 1–2 тері түсі оңға қаратылған',
    '🧑🏼‍🦽‍➡' => 'қол жетегі бар арбашадағы адам: 3-тері түрі оңға қаратылған',
    '🧑🏽‍🦽‍➡' => 'қол жетегі бар арбашадағы адам: 4-тері түсі оңға қаратылған',
    '🧑🏾‍🦽‍➡' => 'қол жетегі бар арбашадағы адам: 5-тері түсі оңға қаратылған',
    '🧑🏿‍🦽‍➡' => 'қол жетегі бар арбашадағы адам: 6-тері түсі оңға қаратылған',
    '👨🏻‍🦽‍➡' => 'қол жетегі бар арбашадағы еркек: 1–2 тері түсі оңға қаратылған',
    '👨🏼‍🦽‍➡' => 'қол жетегі бар арбашадағы еркек: 3-тері түрі оңға қаратылған',
    '👨🏽‍🦽‍➡' => 'қол жетегі бар арбашадағы еркек: 4-тері түсі оңға қаратылған',
    '👨🏾‍🦽‍➡' => 'қол жетегі бар арбашадағы еркек: 5-тері түсі оңға қаратылған',
    '👨🏿‍🦽‍➡' => 'қол жетегі бар арбашадағы еркек: 6-тері түсі оңға қаратылған',
    '👩🏻‍🦽‍➡' => 'қол жетегі бар арбашадағы әйел: 1–2 тері түсі оңға қаратылған',
    '👩🏼‍🦽‍➡' => 'қол жетегі бар арбашадағы әйел: 3-тері түрі оңға қаратылған',
    '👩🏽‍🦽‍➡' => 'қол жетегі бар арбашадағы әйел: 4-тері түсі оңға қаратылған',
    '👩🏾‍🦽‍➡' => 'қол жетегі бар арбашадағы әйел: 5-тері түсі оңға қаратылған',
    '👩🏿‍🦽‍➡' => 'қол жетегі бар арбашадағы әйел: 6-тері түсі оңға қаратылған',
    '🏃🏻‍♀‍➡' => 'жүгірген әйел: 1–2 тері түсі оңға қаратылған',
    '🏃🏼‍♀‍➡' => 'жүгірген әйел: 3-тері түрі оңға қаратылған',
    '🏃🏽‍♀‍➡' => 'жүгірген әйел: 4-тері түсі оңға қаратылған',
    '🏃🏾‍♀‍➡' => 'жүгірген әйел: 5-тері түсі оңға қаратылған',
    '🏃🏿‍♀‍➡' => 'жүгірген әйел: 6-тері түсі оңға қаратылған',
    '🏃🏻‍♂‍➡' => 'жүгірген ер: 1–2 тері түсі оңға қаратылған',
    '🏃🏼‍♂‍➡' => 'жүгірген ер: 3-тері түрі оңға қаратылған',
    '🏃🏽‍♂‍➡' => 'жүгірген ер: 4-тері түсі оңға қаратылған',
    '🏃🏾‍♂‍➡' => 'жүгірген ер: 5-тері түсі оңға қаратылған',
    '🏃🏿‍♂‍➡' => 'жүгірген ер: 6-тері түсі оңға қаратылған',
    '🫱🏻‍🫲🏼' => 'қол алысу: 1–2 тері түсі 3-тері түрі',
    '🫱🏻‍🫲🏽' => 'қол алысу: 1–2 тері түсі 4-тері түсі',
    '🫱🏻‍🫲🏾' => 'қол алысу: 1–2 тері түсі 5-тері түсі',
    '🫱🏻‍🫲🏿' => 'қол алысу: 1–2 тері түсі 6-тері түсі',
    '🫱🏼‍🫲🏻' => 'қол алысу: 3-тері түрі 1–2 тері түсі',
    '🫱🏼‍🫲🏽' => 'қол алысу: 3-тері түрі 4-тері түсі',
    '🫱🏼‍🫲🏾' => 'қол алысу: 3-тері түрі 5-тері түсі',
    '🫱🏼‍🫲🏿' => 'қол алысу: 3-тері түрі 6-тері түсі',
    '🫱🏽‍🫲🏻' => 'қол алысу: 4-тері түсі 1–2 тері түсі',
    '🫱🏽‍🫲🏼' => 'қол алысу: 4-тері түсі 3-тері түрі',
    '🫱🏽‍🫲🏾' => 'қол алысу: 4-тері түсі 5-тері түсі',
    '🫱🏽‍🫲🏿' => 'қол алысу: 4-тері түсі 6-тері түсі',
    '🫱🏾‍🫲🏻' => 'қол алысу: 5-тері түсі 1–2 тері түсі',
    '🫱🏾‍🫲🏼' => 'қол алысу: 5-тері түсі 3-тері түрі',
    '🫱🏾‍🫲🏽' => 'қол алысу: 5-тері түсі 4-тері түсі',
    '🫱🏾‍🫲🏿' => 'қол алысу: 5-тері түсі 6-тері түсі',
    '🫱🏿‍🫲🏻' => 'қол алысу: 6-тері түсі 1–2 тері түсі',
    '🫱🏿‍🫲🏼' => 'қол алысу: 6-тері түсі 3-тері түрі',
    '🫱🏿‍🫲🏽' => 'қол алысу: 6-тері түсі 4-тері түсі',
    '🫱🏿‍🫲🏾' => 'қол алысу: 6-тері түсі 5-тері түсі',
    '🚶‍♀‍➡' => 'жаяу әйел: оңға қаратылған',
    '🚶‍♂‍➡' => 'жаяу ер: оңға қаратылған',
    '🧎‍♀‍➡' => 'тізерлеп отырған әйел: оңға қаратылған',
    '🧎‍♂‍➡' => 'тізерлеп отырған еркек: оңға қаратылған',
    '🧑‍🦯‍➡' => 'таяғы бар адам: оңға қаратылған',
    '👨‍🦯‍➡' => 'таяғы бар еркек: оңға қаратылған',
    '👩‍🦯‍➡' => 'таяғы бар әйел: оңға қаратылған',
    '🧑‍🦼‍➡' => 'моторлы арбадағы адам: оңға қаратылған',
    '👨‍🦼‍➡' => 'электр жетегі бар арбашадағы еркек: оңға қаратылған',
    '👩‍🦼‍➡' => 'электр жетегі бар арбашадағы әйел: оңға қаратылған',
    '🧑‍🦽‍➡' => 'қол жетегі бар арбашадағы адам: оңға қаратылған',
    '👨‍🦽‍➡' => 'қол жетегі бар арбашадағы еркек: оңға қаратылған',
    '👩‍🦽‍➡' => 'қол жетегі бар арбашадағы әйел: оңға қаратылған',
    '🏃‍♀‍➡' => 'жүгірген әйел: оңға қаратылған',
    '🏃‍♂‍➡' => 'жүгірген ер: оңға қаратылған',
    '👩‍❤‍👨' => 'махаббат: әйел ер адам',
    '👨‍❤‍👨' => 'махаббат: ер адам ер адам',
    '👩‍❤‍👩' => 'махаббат: әйел әйел',
    '👨‍👩‍👦' => 'отбасы: ер адам әйел ұл',
    '👨‍👩‍👧' => 'отбасы: ер адам әйел қыз',
    '👨‍👨‍👦' => 'отбасы: ер адам ер адам ұл',
    '👨‍👨‍👧' => 'отбасы: ер адам ер адам қыз',
    '👩‍👩‍👦' => 'отбасы: әйел әйел ұл',
    '👩‍👩‍👧' => 'отбасы: әйел әйел қыз',
    '👨‍👦‍👦' => 'отбасы: ер адам ұл ұл',
    '👨‍👧‍👦' => 'отбасы: ер адам қыз ұл',
    '👨‍👧‍👧' => 'отбасы: ер адам қыз қыз',
    '👩‍👦‍👦' => 'отбасы: әйел ұл ұл',
    '👩‍👧‍👦' => 'отбасы: әйел қыз ұл',
    '👩‍👧‍👧' => 'отбасы: әйел қыз қыз',
    '🧑‍🤝‍🧑' => 'қолдарын көтеріп тұрған адамдар',
    '🧑‍🧑‍🧒' => 'отбасы: ересек, ересек, бала',
    '🧑‍🧒‍🧒' => 'отбасы: ересек, бала, бала',
    '🧑🏻‍🦰' => 'адам: 1–2 тері түсі жирен шаш',
    '🧑🏼‍🦰' => 'адам: 3-тері түрі жирен шаш',
    '🧑🏽‍🦰' => 'адам: 4-тері түсі жирен шаш',
    '🧑🏾‍🦰' => 'адам: 5-тері түсі жирен шаш',
    '🧑🏿‍🦰' => 'адам: 6-тері түсі жирен шаш',
    '🧑🏻‍🦱' => 'адам: 1–2 тері түсі бұйра шаш',
    '🧑🏼‍🦱' => 'адам: 3-тері түрі бұйра шаш',
    '🧑🏽‍🦱' => 'адам: 4-тері түсі бұйра шаш',
    '🧑🏾‍🦱' => 'адам: 5-тері түсі бұйра шаш',
    '🧑🏿‍🦱' => 'адам: 6-тері түсі бұйра шаш',
    '🧑🏻‍🦳' => 'адам: 1–2 тері түсі ақ шаш',
    '🧑🏼‍🦳' => 'адам: 3-тері түрі ақ шаш',
    '🧑🏽‍🦳' => 'адам: 4-тері түсі ақ шаш',
    '🧑🏾‍🦳' => 'адам: 5-тері түсі ақ шаш',
    '🧑🏿‍🦳' => 'адам: 6-тері түсі ақ шаш',
    '🧑🏻‍🦲' => 'адам: 1–2 тері түсі тақырбас',
    '🧑🏼‍🦲' => 'адам: 3-тері түрі тақырбас',
    '🧑🏽‍🦲' => 'адам: 4-тері түсі тақырбас',
    '🧑🏾‍🦲' => 'адам: 5-тері түсі тақырбас',
    '🧑🏿‍🦲' => 'адам: 6-тері түсі тақырбас',
    '🧑🏻‍🩰' => 'балет бишісі: 1–2 тері түсі',
    '🧑🏼‍🩰' => 'балет бишісі: 3-тері түрі',
    '🧑🏽‍🩰' => 'балет бишісі: 4-тері түсі',
    '🧑🏾‍🩰' => 'балет бишісі: 5-тері түсі',
    '🧑🏿‍🩰' => 'балет бишісі: 6-тері түсі',
    '🧔🏻‍♂' => 'ер адам: 1–2 тері түсі сақал',
    '🧔🏼‍♂' => 'ер адам: 3-тері түрі сақал',
    '🧔🏽‍♂' => 'ер адам: 4-тері түсі сақал',
    '🧔🏾‍♂' => 'ер адам: 5-тері түсі сақал',
    '🧔🏿‍♂' => 'ер адам: 6-тері түсі сақал',
    '👱🏻‍♂' => 'аққұба ер адам: 1–2 тері түсі',
    '👱🏼‍♂' => 'аққұба ер адам: 3-тері түрі',
    '👱🏽‍♂' => 'аққұба ер адам: 4-тері түсі',
    '👱🏾‍♂' => 'аққұба ер адам: 5-тері түсі',
    '👱🏿‍♂' => 'аққұба ер адам: 6-тері түсі',
    '👨🏻‍🦰' => 'ер адам: 1–2 тері түсі жирен шаш',
    '👨🏼‍🦰' => 'ер адам: 3-тері түрі жирен шаш',
    '👨🏽‍🦰' => 'ер адам: 4-тері түсі жирен шаш',
    '👨🏾‍🦰' => 'ер адам: 5-тері түсі жирен шаш',
    '👨🏿‍🦰' => 'ер адам: 6-тері түсі жирен шаш',
    '👨🏻‍🦱' => 'ер адам: 1–2 тері түсі бұйра шаш',
    '👨🏼‍🦱' => 'ер адам: 3-тері түрі бұйра шаш',
    '👨🏽‍🦱' => 'ер адам: 4-тері түсі бұйра шаш',
    '👨🏾‍🦱' => 'ер адам: 5-тері түсі бұйра шаш',
    '👨🏿‍🦱' => 'ер адам: 6-тері түсі бұйра шаш',
    '👨🏻‍🦳' => 'ер адам: 1–2 тері түсі ақ шаш',
    '👨🏼‍🦳' => 'ер адам: 3-тері түрі ақ шаш',
    '👨🏽‍🦳' => 'ер адам: 4-тері түсі ақ шаш',
    '👨🏾‍🦳' => 'ер адам: 5-тері түсі ақ шаш',
    '👨🏿‍🦳' => 'ер адам: 6-тері түсі ақ шаш',
    '👨🏻‍🦲' => 'ер адам: 1–2 тері түсі тақырбас',
    '👨🏼‍🦲' => 'ер адам: 3-тері түрі тақырбас',
    '👨🏽‍🦲' => 'ер адам: 4-тері түсі тақырбас',
    '👨🏾‍🦲' => 'ер адам: 5-тері түсі тақырбас',
    '👨🏿‍🦲' => 'ер адам: 6-тері түсі тақырбас',
    '🧔🏻‍♀' => 'әйел адам: 1–2 тері түсі сақал',
    '🧔🏼‍♀' => 'әйел адам: 3-тері түрі сақал',
    '🧔🏽‍♀' => 'әйел адам: 4-тері түсі сақал',
    '🧔🏾‍♀' => 'әйел адам: 5-тері түсі сақал',
    '🧔🏿‍♀' => 'әйел адам: 6-тері түсі сақал',
    '👱🏻‍♀' => 'аққұба әйел: 1–2 тері түсі',
    '👱🏼‍♀' => 'аққұба әйел: 3-тері түрі',
    '👱🏽‍♀' => 'аққұба әйел: 4-тері түсі',
    '👱🏾‍♀' => 'аққұба әйел: 5-тері түсі',
    '👱🏿‍♀' => 'аққұба әйел: 6-тері түсі',
    '👩🏻‍🦰' => 'әйел: 1–2 тері түсі жирен шаш',
    '👩🏼‍🦰' => 'әйел: 3-тері түрі жирен шаш',
    '👩🏽‍🦰' => 'әйел: 4-тері түсі жирен шаш',
    '👩🏾‍🦰' => 'әйел: 5-тері түсі жирен шаш',
    '👩🏿‍🦰' => 'әйел: 6-тері түсі жирен шаш',
    '👩🏻‍🦱' => 'әйел: 1–2 тері түсі бұйра шаш',
    '👩🏼‍🦱' => 'әйел: 3-тері түрі бұйра шаш',
    '👩🏽‍🦱' => 'әйел: 4-тері түсі бұйра шаш',
    '👩🏾‍🦱' => 'әйел: 5-тері түсі бұйра шаш',
    '👩🏿‍🦱' => 'әйел: 6-тері түсі бұйра шаш',
    '👩🏻‍🦳' => 'әйел: 1–2 тері түсі ақ шаш',
    '👩🏼‍🦳' => 'әйел: 3-тері түрі ақ шаш',
    '👩🏽‍🦳' => 'әйел: 4-тері түсі ақ шаш',
    '👩🏾‍🦳' => 'әйел: 5-тері түсі ақ шаш',
    '👩🏿‍🦳' => 'әйел: 6-тері түсі ақ шаш',
    '👩🏻‍🦲' => 'әйел: 1–2 тері түсі тақырбас',
    '👩🏼‍🦲' => 'әйел: 3-тері түрі тақырбас',
    '👩🏽‍🦲' => 'әйел: 4-тері түсі тақырбас',
    '👩🏾‍🦲' => 'әйел: 5-тері түсі тақырбас',
    '👩🏿‍🦲' => 'әйел: 6-тері түсі тақырбас',
    '🙍🏻‍♂' => 'ашулы ер: 1–2 тері түсі',
    '🙍🏼‍♂' => 'ашулы ер: 3-тері түрі',
    '🙍🏽‍♂' => 'ашулы ер: 4-тері түсі',
    '🙍🏾‍♂' => 'ашулы ер: 5-тері түсі',
    '🙍🏿‍♂' => 'ашулы ер: 6-тері түсі',
    '🙍🏻‍♀' => 'ашулы әйел: 1–2 тері түсі',
    '🙍🏼‍♀' => 'ашулы әйел: 3-тері түрі',
    '🙍🏽‍♀' => 'ашулы әйел: 4-тері түсі',
    '🙍🏾‍♀' => 'ашулы әйел: 5-тері түсі',
    '🙍🏿‍♀' => 'ашулы әйел: 6-тері түсі',
    '🙎🏻‍♂' => 'ренжулі ер: 1–2 тері түсі',
    '🙎🏼‍♂' => 'ренжулі ер: 3-тері түрі',
    '🙎🏽‍♂' => 'ренжулі ер: 4-тері түсі',
    '🙎🏾‍♂' => 'ренжулі ер: 5-тері түсі',
    '🙎🏿‍♂' => 'ренжулі ер: 6-тері түсі',
    '🙎🏻‍♀' => 'ренжулі әйел: 1–2 тері түсі',
    '🙎🏼‍♀' => 'ренжулі әйел: 3-тері түрі',
    '🙎🏽‍♀' => 'ренжулі әйел: 4-тері түсі',
    '🙎🏾‍♀' => 'ренжулі әйел: 5-тері түсі',
    '🙎🏿‍♀' => 'ренжулі әйел: 6-тері түсі',
    '🙅🏻‍♂' => 'қарсымын деп тұрған ер: 1–2 тері түсі',
    '🙅🏼‍♂' => 'қарсымын деп тұрған ер: 3-тері түрі',
    '🙅🏽‍♂' => 'қарсымын деп тұрған ер: 4-тері түсі',
    '🙅🏾‍♂' => 'қарсымын деп тұрған ер: 5-тері түсі',
    '🙅🏿‍♂' => 'қарсымын деп тұрған ер: 6-тері түсі',
    '🙅🏻‍♀' => 'қарсымын деп тұрған әйел: 1–2 тері түсі',
    '🙅🏼‍♀' => 'қарсымын деп тұрған әйел: 3-тері түрі',
    '🙅🏽‍♀' => 'қарсымын деп тұрған әйел: 4-тері түсі',
    '🙅🏾‍♀' => 'қарсымын деп тұрған әйел: 5-тері түсі',
    '🙅🏿‍♀' => 'қарсымын деп тұрған әйел: 6-тері түсі',
    '🙆🏻‍♂' => 'құптап тұрған ер: 1–2 тері түсі',
    '🙆🏼‍♂' => 'құптап тұрған ер: 3-тері түрі',
    '🙆🏽‍♂' => 'құптап тұрған ер: 4-тері түсі',
    '🙆🏾‍♂' => 'құптап тұрған ер: 5-тері түсі',
    '🙆🏿‍♂' => 'құптап тұрған ер: 6-тері түсі',
    '🙆🏻‍♀' => 'құптап тұрған әйел: 1–2 тері түсі',
    '🙆🏼‍♀' => 'құптап тұрған әйел: 3-тері түрі',
    '🙆🏽‍♀' => 'құптап тұрған әйел: 4-тері түсі',
    '🙆🏾‍♀' => 'құптап тұрған әйел: 5-тері түсі',
    '🙆🏿‍♀' => 'құптап тұрған әйел: 6-тері түсі',
    '💁🏻‍♂' => 'қолын созып тұрған ер: 1–2 тері түсі',
    '💁🏼‍♂' => 'қолын созып тұрған ер: 3-тері түрі',
    '💁🏽‍♂' => 'қолын созып тұрған ер: 4-тері түсі',
    '💁🏾‍♂' => 'қолын созып тұрған ер: 5-тері түсі',
    '💁🏿‍♂' => 'қолын созып тұрған ер: 6-тері түсі',
    '💁🏻‍♀' => 'қолын созып тұрған әйел: 1–2 тері түсі',
    '💁🏼‍♀' => 'қолын созып тұрған әйел: 3-тері түрі',
    '💁🏽‍♀' => 'қолын созып тұрған әйел: 4-тері түсі',
    '💁🏾‍♀' => 'қолын созып тұрған әйел: 5-тері түсі',
    '💁🏿‍♀' => 'қолын созып тұрған әйел: 6-тері түсі',
    '🙋🏻‍♂' => 'қолын көтеріп тұрған ер: 1–2 тері түсі',
    '🙋🏼‍♂' => 'қолын көтеріп тұрған ер: 3-тері түрі',
    '🙋🏽‍♂' => 'қолын көтеріп тұрған ер: 4-тері түсі',
    '🙋🏾‍♂' => 'қолын көтеріп тұрған ер: 5-тері түсі',
    '🙋🏿‍♂' => 'қолын көтеріп тұрған ер: 6-тері түсі',
    '🙋🏻‍♀' => 'қолын көтеріп тұрған әйел: 1–2 тері түсі',
    '🙋🏼‍♀' => 'қолын көтеріп тұрған әйел: 3-тері түрі',
    '🙋🏽‍♀' => 'қолын көтеріп тұрған әйел: 4-тері түсі',
    '🙋🏾‍♀' => 'қолын көтеріп тұрған әйел: 5-тері түсі',
    '🙋🏿‍♀' => 'қолын көтеріп тұрған әйел: 6-тері түсі',
    '🧏🏻‍♂' => 'саңырау еркек: 1–2 тері түсі',
    '🧏🏼‍♂' => 'саңырау еркек: 3-тері түрі',
    '🧏🏽‍♂' => 'саңырау еркек: 4-тері түсі',
    '🧏🏾‍♂' => 'саңырау еркек: 5-тері түсі',
    '🧏🏿‍♂' => 'саңырау еркек: 6-тері түсі',
    '🧏🏻‍♀' => 'саңырау әйел: 1–2 тері түсі',
    '🧏🏼‍♀' => 'саңырау әйел: 3-тері түрі',
    '🧏🏽‍♀' => 'саңырау әйел: 4-тері түсі',
    '🧏🏾‍♀' => 'саңырау әйел: 5-тері түсі',
    '🧏🏿‍♀' => 'саңырау әйел: 6-тері түсі',
    '🙇🏻‍♂' => 'басын иіп тұрған ер: 1–2 тері түсі',
    '🙇🏼‍♂' => 'басын иіп тұрған ер: 3-тері түрі',
    '🙇🏽‍♂' => 'басын иіп тұрған ер: 4-тері түсі',
    '🙇🏾‍♂' => 'басын иіп тұрған ер: 5-тері түсі',
    '🙇🏿‍♂' => 'басын иіп тұрған ер: 6-тері түсі',
    '🙇🏻‍♀' => 'басын иіп тұрған әйел: 1–2 тері түсі',
    '🙇🏼‍♀' => 'басын иіп тұрған әйел: 3-тері түрі',
    '🙇🏽‍♀' => 'басын иіп тұрған әйел: 4-тері түсі',
    '🙇🏾‍♀' => 'басын иіп тұрған әйел: 5-тері түсі',
    '🙇🏿‍♀' => 'басын иіп тұрған әйел: 6-тері түсі',
    '🤦🏻‍♂' => 'айтуға сөз таппай тұрған ер: 1–2 тері түсі',
    '🤦🏼‍♂' => 'айтуға сөз таппай тұрған ер: 3-тері түрі',
    '🤦🏽‍♂' => 'айтуға сөз таппай тұрған ер: 4-тері түсі',
    '🤦🏾‍♂' => 'айтуға сөз таппай тұрған ер: 5-тері түсі',
    '🤦🏿‍♂' => 'айтуға сөз таппай тұрған ер: 6-тері түсі',
    '🤦🏻‍♀' => 'айтуға сөз таппай тұрған әйел: 1–2 тері түсі',
    '🤦🏼‍♀' => 'айтуға сөз таппай тұрған әйел: 3-тері түрі',
    '🤦🏽‍♀' => 'айтуға сөз таппай тұрған әйел: 4-тері түсі',
    '🤦🏾‍♀' => 'айтуға сөз таппай тұрған әйел: 5-тері түсі',
    '🤦🏿‍♀' => 'айтуға сөз таппай тұрған әйел: 6-тері түсі',
    '🤷🏻‍♂' => 'иығын көтеріп тұрған ер: 1–2 тері түсі',
    '🤷🏼‍♂' => 'иығын көтеріп тұрған ер: 3-тері түрі',
    '🤷🏽‍♂' => 'иығын көтеріп тұрған ер: 4-тері түсі',
    '🤷🏾‍♂' => 'иығын көтеріп тұрған ер: 5-тері түсі',
    '🤷🏿‍♂' => 'иығын көтеріп тұрған ер: 6-тері түсі',
    '🤷🏻‍♀' => 'иығын көтеріп тұрған әйел: 1–2 тері түсі',
    '🤷🏼‍♀' => 'иығын көтеріп тұрған әйел: 3-тері түрі',
    '🤷🏽‍♀' => 'иығын көтеріп тұрған әйел: 4-тері түсі',
    '🤷🏾‍♀' => 'иығын көтеріп тұрған әйел: 5-тері түсі',
    '🤷🏿‍♀' => 'иығын көтеріп тұрған әйел: 6-тері түсі',
    '🧑🏻‍⚕' => 'медициналық қызметкер: 1–2 тері түсі',
    '🧑🏼‍⚕' => 'медициналық қызметкер: 3-тері түрі',
    '🧑🏽‍⚕' => 'медициналық қызметкер: 4-тері түсі',
    '🧑🏾‍⚕' => 'медициналық қызметкер: 5-тері түсі',
    '🧑🏿‍⚕' => 'медициналық қызметкер: 6-тері түсі',
    '👨🏻‍⚕' => 'дәрігер: 1–2 тері түсі',
    '👨🏼‍⚕' => 'дәрігер: 3-тері түрі',
    '👨🏽‍⚕' => 'дәрігер: 4-тері түсі',
    '👨🏾‍⚕' => 'дәрігер: 5-тері түсі',
    '👨🏿‍⚕' => 'дәрігер: 6-тері түсі',
    '👩🏻‍⚕' => 'дәрігер әйел: 1–2 тері түсі',
    '👩🏼‍⚕' => 'дәрігер әйел: 3-тері түрі',
    '👩🏽‍⚕' => 'дәрігер әйел: 4-тері түсі',
    '👩🏾‍⚕' => 'дәрігер әйел: 5-тері түсі',
    '👩🏿‍⚕' => 'дәрігер әйел: 6-тері түсі',
    '🧑🏻‍🎓' => 'студент: 1–2 тері түсі',
    '🧑🏼‍🎓' => 'студент: 3-тері түрі',
    '🧑🏽‍🎓' => 'студент: 4-тері түсі',
    '🧑🏾‍🎓' => 'студент: 5-тері түсі',
    '🧑🏿‍🎓' => 'студент: 6-тері түсі',
    '👨🏻‍🎓' => 'студент бала: 1–2 тері түсі',
    '👨🏼‍🎓' => 'студент бала: 3-тері түрі',
    '👨🏽‍🎓' => 'студент бала: 4-тері түсі',
    '👨🏾‍🎓' => 'студент бала: 5-тері түсі',
    '👨🏿‍🎓' => 'студент бала: 6-тері түсі',
    '👩🏻‍🎓' => 'студент қыз: 1–2 тері түсі',
    '👩🏼‍🎓' => 'студент қыз: 3-тері түрі',
    '👩🏽‍🎓' => 'студент қыз: 4-тері түсі',
    '👩🏾‍🎓' => 'студент қыз: 5-тері түсі',
    '👩🏿‍🎓' => 'студент қыз: 6-тері түсі',
    '🧑🏻‍🏫' => 'оқытушы: 1–2 тері түсі',
    '🧑🏼‍🏫' => 'оқытушы: 3-тері түрі',
    '🧑🏽‍🏫' => 'оқытушы: 4-тері түсі',
    '🧑🏾‍🏫' => 'оқытушы: 5-тері түсі',
    '🧑🏿‍🏫' => 'оқытушы: 6-тері түсі',
    '👨🏻‍🏫' => 'мұғалім: 1–2 тері түсі',
    '👨🏼‍🏫' => 'мұғалім: 3-тері түрі',
    '👨🏽‍🏫' => 'мұғалім: 4-тері түсі',
    '👨🏾‍🏫' => 'мұғалім: 5-тері түсі',
    '👨🏿‍🏫' => 'мұғалім: 6-тері түсі',
    '👩🏻‍🏫' => 'мұғалім әйел: 1–2 тері түсі',
    '👩🏼‍🏫' => 'мұғалім әйел: 3-тері түрі',
    '👩🏽‍🏫' => 'мұғалім әйел: 4-тері түсі',
    '👩🏾‍🏫' => 'мұғалім әйел: 5-тері түсі',
    '👩🏿‍🏫' => 'мұғалім әйел: 6-тері түсі',
    '🧑🏻‍⚖' => 'сот: 1–2 тері түсі',
    '🧑🏼‍⚖' => 'сот: 3-тері түрі',
    '🧑🏽‍⚖' => 'сот: 4-тері түсі',
    '🧑🏾‍⚖' => 'сот: 5-тері түсі',
    '🧑🏿‍⚖' => 'сот: 6-тері түсі',
    '👨🏻‍⚖' => 'сот ер: 1–2 тері түсі',
    '👨🏼‍⚖' => 'сот ер: 3-тері түрі',
    '👨🏽‍⚖' => 'сот ер: 4-тері түсі',
    '👨🏾‍⚖' => 'сот ер: 5-тері түсі',
    '👨🏿‍⚖' => 'сот ер: 6-тері түсі',
    '👩🏻‍⚖' => 'сот әйел: 1–2 тері түсі',
    '👩🏼‍⚖' => 'сот әйел: 3-тері түрі',
    '👩🏽‍⚖' => 'сот әйел: 4-тері түсі',
    '👩🏾‍⚖' => 'сот әйел: 5-тері түсі',
    '👩🏿‍⚖' => 'сот әйел: 6-тері түсі',
    '🧑🏻‍🌾' => 'фермер: 1–2 тері түсі',
    '🧑🏼‍🌾' => 'фермер: 3-тері түрі',
    '🧑🏽‍🌾' => 'фермер: 4-тері түсі',
    '🧑🏾‍🌾' => 'фермер: 5-тері түсі',
    '🧑🏿‍🌾' => 'фермер: 6-тері түсі',
    '👨🏻‍🌾' => 'ер фермер: 1–2 тері түсі',
    '👨🏼‍🌾' => 'ер фермер: 3-тері түрі',
    '👨🏽‍🌾' => 'ер фермер: 4-тері түсі',
    '👨🏾‍🌾' => 'ер фермер: 5-тері түсі',
    '👨🏿‍🌾' => 'ер фермер: 6-тері түсі',
    '👩🏻‍🌾' => 'фермер әйел: 1–2 тері түсі',
    '👩🏼‍🌾' => 'фермер әйел: 3-тері түрі',
    '👩🏽‍🌾' => 'фермер әйел: 4-тері түсі',
    '👩🏾‍🌾' => 'фермер әйел: 5-тері түсі',
    '👩🏿‍🌾' => 'фермер әйел: 6-тері түсі',
    '🧑🏻‍🍳' => 'аспаз: 1–2 тері түсі',
    '🧑🏼‍🍳' => 'аспаз: 3-тері түрі',
    '🧑🏽‍🍳' => 'аспаз: 4-тері түсі',
    '🧑🏾‍🍳' => 'аспаз: 5-тері түсі',
    '🧑🏿‍🍳' => 'аспаз: 6-тері түсі',
    '👨🏻‍🍳' => 'ер аспаз: 1–2 тері түсі',
    '👨🏼‍🍳' => 'ер аспаз: 3-тері түрі',
    '👨🏽‍🍳' => 'ер аспаз: 4-тері түсі',
    '👨🏾‍🍳' => 'ер аспаз: 5-тері түсі',
    '👨🏿‍🍳' => 'ер аспаз: 6-тері түсі',
    '👩🏻‍🍳' => 'аспаз әйел: 1–2 тері түсі',
    '👩🏼‍🍳' => 'аспаз әйел: 3-тері түрі',
    '👩🏽‍🍳' => 'аспаз әйел: 4-тері түсі',
    '👩🏾‍🍳' => 'аспаз әйел: 5-тері түсі',
    '👩🏿‍🍳' => 'аспаз әйел: 6-тері түсі',
    '🧑🏻‍🔧' => 'механик: 1–2 тері түсі',
    '🧑🏼‍🔧' => 'механик: 3-тері түрі',
    '🧑🏽‍🔧' => 'механик: 4-тері түсі',
    '🧑🏾‍🔧' => 'механик: 5-тері түсі',
    '🧑🏿‍🔧' => 'механик: 6-тері түсі',
    '👨🏻‍🔧' => 'ер механик: 1–2 тері түсі',
    '👨🏼‍🔧' => 'ер механик: 3-тері түрі',
    '👨🏽‍🔧' => 'ер механик: 4-тері түсі',
    '👨🏾‍🔧' => 'ер механик: 5-тері түсі',
    '👨🏿‍🔧' => 'ер механик: 6-тері түсі',
    '👩🏻‍🔧' => 'механик әйел: 1–2 тері түсі',
    '👩🏼‍🔧' => 'механик әйел: 3-тері түрі',
    '👩🏽‍🔧' => 'механик әйел: 4-тері түсі',
    '👩🏾‍🔧' => 'механик әйел: 5-тері түсі',
    '👩🏿‍🔧' => 'механик әйел: 6-тері түсі',
    '🧑🏻‍🏭' => 'зауыт жұмысшысы: 1–2 тері түсі',
    '🧑🏼‍🏭' => 'зауыт жұмысшысы: 3-тері түрі',
    '🧑🏽‍🏭' => 'зауыт жұмысшысы: 4-тері түсі',
    '🧑🏾‍🏭' => 'зауыт жұмысшысы: 5-тері түсі',
    '🧑🏿‍🏭' => 'зауыт жұмысшысы: 6-тері түсі',
    '👨🏻‍🏭' => 'жұмысшы: 1–2 тері түсі',
    '👨🏼‍🏭' => 'жұмысшы: 3-тері түрі',
    '👨🏽‍🏭' => 'жұмысшы: 4-тері түсі',
    '👨🏾‍🏭' => 'жұмысшы: 5-тері түсі',
    '👨🏿‍🏭' => 'жұмысшы: 6-тері түсі',
    '👩🏻‍🏭' => 'жұмысшы әйел: 1–2 тері түсі',
    '👩🏼‍🏭' => 'жұмысшы әйел: 3-тері түрі',
    '👩🏽‍🏭' => 'жұмысшы әйел: 4-тері түсі',
    '👩🏾‍🏭' => 'жұмысшы әйел: 5-тері түсі',
    '👩🏿‍🏭' => 'жұмысшы әйел: 6-тері түсі',
    '🧑🏻‍💼' => 'кеңсе қызметкері: 1–2 тері түсі',
    '🧑🏼‍💼' => 'кеңсе қызметкері: 3-тері түрі',
    '🧑🏽‍💼' => 'кеңсе қызметкері: 4-тері түсі',
    '🧑🏾‍💼' => 'кеңсе қызметкері: 5-тері түсі',
    '🧑🏿‍💼' => 'кеңсе қызметкері: 6-тері түсі',
    '👨🏻‍💼' => 'кеңседе жұмыс істейтін қызметкер: 1–2 тері түсі',
    '👨🏼‍💼' => 'кеңседе жұмыс істейтін қызметкер: 3-тері түрі',
    '👨🏽‍💼' => 'кеңседе жұмыс істейтін қызметкер: 4-тері түсі',
    '👨🏾‍💼' => 'кеңседе жұмыс істейтін қызметкер: 5-тері түсі',
    '👨🏿‍💼' => 'кеңседе жұмыс істейтін қызметкер: 6-тері түсі',
    '👩🏻‍💼' => 'кеңседе жұмыс істейтін қызметкер әйел: 1–2 тері түсі',
    '👩🏼‍💼' => 'кеңседе жұмыс істейтін қызметкер әйел: 3-тері түрі',
    '👩🏽‍💼' => 'кеңседе жұмыс істейтін қызметкер әйел: 4-тері түсі',
    '👩🏾‍💼' => 'кеңседе жұмыс істейтін қызметкер әйел: 5-тері түсі',
    '👩🏿‍💼' => 'кеңседе жұмыс істейтін қызметкер әйел: 6-тері түсі',
    '🧑🏻‍🔬' => 'ғалым: 1–2 тері түсі',
    '🧑🏼‍🔬' => 'ғалым: 3-тері түрі',
    '🧑🏽‍🔬' => 'ғалым: 4-тері түсі',
    '🧑🏾‍🔬' => 'ғалым: 5-тері түсі',
    '🧑🏿‍🔬' => 'ғалым: 6-тері түсі',
    '👨🏻‍🔬' => 'ер ғалым: 1–2 тері түсі',
    '👨🏼‍🔬' => 'ер ғалым: 3-тері түрі',
    '👨🏽‍🔬' => 'ер ғалым: 4-тері түсі',
    '👨🏾‍🔬' => 'ер ғалым: 5-тері түсі',
    '👨🏿‍🔬' => 'ер ғалым: 6-тері түсі',
    '👩🏻‍🔬' => 'ғалым әйел: 1–2 тері түсі',
    '👩🏼‍🔬' => 'ғалым әйел: 3-тері түрі',
    '👩🏽‍🔬' => 'ғалым әйел: 4-тері түсі',
    '👩🏾‍🔬' => 'ғалым әйел: 5-тері түсі',
    '👩🏿‍🔬' => 'ғалым әйел: 6-тері түсі',
    '🧑🏻‍💻' => 'технолог: 1–2 тері түсі',
    '🧑🏼‍💻' => 'технолог: 3-тері түрі',
    '🧑🏽‍💻' => 'технолог: 4-тері түсі',
    '🧑🏾‍💻' => 'технолог: 5-тері түсі',
    '🧑🏿‍💻' => 'технолог: 6-тері түсі',
    '👨🏻‍💻' => 'ер технолог: 1–2 тері түсі',
    '👨🏼‍💻' => 'ер технолог: 3-тері түрі',
    '👨🏽‍💻' => 'ер технолог: 4-тері түсі',
    '👨🏾‍💻' => 'ер технолог: 5-тері түсі',
    '👨🏿‍💻' => 'ер технолог: 6-тері түсі',
    '👩🏻‍💻' => 'технолог әйел: 1–2 тері түсі',
    '👩🏼‍💻' => 'технолог әйел: 3-тері түрі',
    '👩🏽‍💻' => 'технолог әйел: 4-тері түсі',
    '👩🏾‍💻' => 'технолог әйел: 5-тері түсі',
    '👩🏿‍💻' => 'технолог әйел: 6-тері түсі',
    '🧑🏻‍🎤' => 'әнші: 1–2 тері түсі',
    '🧑🏼‍🎤' => 'әнші: 3-тері түрі',
    '🧑🏽‍🎤' => 'әнші: 4-тері түсі',
    '🧑🏾‍🎤' => 'әнші: 5-тері түсі',
    '🧑🏿‍🎤' => 'әнші: 6-тері түсі',
    '👨🏻‍🎤' => 'ер әнші: 1–2 тері түсі',
    '👨🏼‍🎤' => 'ер әнші: 3-тері түрі',
    '👨🏽‍🎤' => 'ер әнші: 4-тері түсі',
    '👨🏾‍🎤' => 'ер әнші: 5-тері түсі',
    '👨🏿‍🎤' => 'ер әнші: 6-тері түсі',
    '👩🏻‍🎤' => 'әнші әйел: 1–2 тері түсі',
    '👩🏼‍🎤' => 'әнші әйел: 3-тері түрі',
    '👩🏽‍🎤' => 'әнші әйел: 4-тері түсі',
    '👩🏾‍🎤' => 'әнші әйел: 5-тері түсі',
    '👩🏿‍🎤' => 'әнші әйел: 6-тері түсі',
    '🧑🏻‍🎨' => 'суретші: 1–2 тері түсі',
    '🧑🏼‍🎨' => 'суретші: 3-тері түрі',
    '🧑🏽‍🎨' => 'суретші: 4-тері түсі',
    '🧑🏾‍🎨' => 'суретші: 5-тері түсі',
    '🧑🏿‍🎨' => 'суретші: 6-тері түсі',
    '👨🏻‍🎨' => 'ер суретші: 1–2 тері түсі',
    '👨🏼‍🎨' => 'ер суретші: 3-тері түрі',
    '👨🏽‍🎨' => 'ер суретші: 4-тері түсі',
    '👨🏾‍🎨' => 'ер суретші: 5-тері түсі',
    '👨🏿‍🎨' => 'ер суретші: 6-тері түсі',
    '👩🏻‍🎨' => 'суретші әйел: 1–2 тері түсі',
    '👩🏼‍🎨' => 'суретші әйел: 3-тері түрі',
    '👩🏽‍🎨' => 'суретші әйел: 4-тері түсі',
    '👩🏾‍🎨' => 'суретші әйел: 5-тері түсі',
    '👩🏿‍🎨' => 'суретші әйел: 6-тері түсі',
    '🧑🏻‍✈' => 'пилот: 1–2 тері түсі',
    '🧑🏼‍✈' => 'пилот: 3-тері түрі',
    '🧑🏽‍✈' => 'пилот: 4-тері түсі',
    '🧑🏾‍✈' => 'пилот: 5-тері түсі',
    '🧑🏿‍✈' => 'пилот: 6-тері түсі',
    '👨🏻‍✈' => 'ұшқыш: 1–2 тері түсі',
    '👨🏼‍✈' => 'ұшқыш: 3-тері түрі',
    '👨🏽‍✈' => 'ұшқыш: 4-тері түсі',
    '👨🏾‍✈' => 'ұшқыш: 5-тері түсі',
    '👨🏿‍✈' => 'ұшқыш: 6-тері түсі',
    '👩🏻‍✈' => 'ұшқыш әйел: 1–2 тері түсі',
    '👩🏼‍✈' => 'ұшқыш әйел: 3-тері түрі',
    '👩🏽‍✈' => 'ұшқыш әйел: 4-тері түсі',
    '👩🏾‍✈' => 'ұшқыш әйел: 5-тері түсі',
    '👩🏿‍✈' => 'ұшқыш әйел: 6-тері түсі',
    '🧑🏻‍🚀' => 'астронавт: 1–2 тері түсі',
    '🧑🏼‍🚀' => 'астронавт: 3-тері түрі',
    '🧑🏽‍🚀' => 'астронавт: 4-тері түсі',
    '🧑🏾‍🚀' => 'астронавт: 5-тері түсі',
    '🧑🏿‍🚀' => 'астронавт: 6-тері түсі',
    '👨🏻‍🚀' => 'ғарышкер: 1–2 тері түсі',
    '👨🏼‍🚀' => 'ғарышкер: 3-тері түрі',
    '👨🏽‍🚀' => 'ғарышкер: 4-тері түсі',
    '👨🏾‍🚀' => 'ғарышкер: 5-тері түсі',
    '👨🏿‍🚀' => 'ғарышкер: 6-тері түсі',
    '👩🏻‍🚀' => 'ғарышкер әйел: 1–2 тері түсі',
    '👩🏼‍🚀' => 'ғарышкер әйел: 3-тері түрі',
    '👩🏽‍🚀' => 'ғарышкер әйел: 4-тері түсі',
    '👩🏾‍🚀' => 'ғарышкер әйел: 5-тері түсі',
    '👩🏿‍🚀' => 'ғарышкер әйел: 6-тері түсі',
    '🧑🏻‍🚒' => 'өрт сөндіруші: 1–2 тері түсі',
    '🧑🏼‍🚒' => 'өрт сөндіруші: 3-тері түрі',
    '🧑🏽‍🚒' => 'өрт сөндіруші: 4-тері түсі',
    '🧑🏾‍🚒' => 'өрт сөндіруші: 5-тері түсі',
    '🧑🏿‍🚒' => 'өрт сөндіруші: 6-тері түсі',
    '👨🏻‍🚒' => 'ер өрт сөндіруші: 1–2 тері түсі',
    '👨🏼‍🚒' => 'ер өрт сөндіруші: 3-тері түрі',
    '👨🏽‍🚒' => 'ер өрт сөндіруші: 4-тері түсі',
    '👨🏾‍🚒' => 'ер өрт сөндіруші: 5-тері түсі',
    '👨🏿‍🚒' => 'ер өрт сөндіруші: 6-тері түсі',
    '👩🏻‍🚒' => 'өрт сөндіруші әйел: 1–2 тері түсі',
    '👩🏼‍🚒' => 'өрт сөндіруші әйел: 3-тері түрі',
    '👩🏽‍🚒' => 'өрт сөндіруші әйел: 4-тері түсі',
    '👩🏾‍🚒' => 'өрт сөндіруші әйел: 5-тері түсі',
    '👩🏿‍🚒' => 'өрт сөндіруші әйел: 6-тері түсі',
    '👮🏻‍♂' => 'ер полиция қызметкері: 1–2 тері түсі',
    '👮🏼‍♂' => 'ер полиция қызметкері: 3-тері түрі',
    '👮🏽‍♂' => 'ер полиция қызметкері: 4-тері түсі',
    '👮🏾‍♂' => 'ер полиция қызметкері: 5-тері түсі',
    '👮🏿‍♂' => 'ер полиция қызметкері: 6-тері түсі',
    '👮🏻‍♀' => 'әйел полиция қызметкері: 1–2 тері түсі',
    '👮🏼‍♀' => 'әйел полиция қызметкері: 3-тері түрі',
    '👮🏽‍♀' => 'әйел полиция қызметкері: 4-тері түсі',
    '👮🏾‍♀' => 'әйел полиция қызметкері: 5-тері түсі',
    '👮🏿‍♀' => 'әйел полиция қызметкері: 6-тері түсі',
    '🕵🏻‍♂' => 'детектив ер адам: 1–2 тері түсі',
    '🕵🏼‍♂' => 'детектив ер адам: 3-тері түрі',
    '🕵🏽‍♂' => 'детектив ер адам: 4-тері түсі',
    '🕵🏾‍♂' => 'детектив ер адам: 5-тері түсі',
    '🕵🏿‍♂' => 'детектив ер адам: 6-тері түсі',
    '🕵🏻‍♀' => 'детектив әйел: 1–2 тері түсі',
    '🕵🏼‍♀' => 'детектив әйел: 3-тері түрі',
    '🕵🏽‍♀' => 'детектив әйел: 4-тері түсі',
    '🕵🏾‍♀' => 'детектив әйел: 5-тері түсі',
    '🕵🏿‍♀' => 'детектив әйел: 6-тері түсі',
    '💂🏻‍♂' => 'күзетші ер адам: 1–2 тері түсі',
    '💂🏼‍♂' => 'күзетші ер адам: 3-тері түрі',
    '💂🏽‍♂' => 'күзетші ер адам: 4-тері түсі',
    '💂🏾‍♂' => 'күзетші ер адам: 5-тері түсі',
    '💂🏿‍♂' => 'күзетші ер адам: 6-тері түсі',
    '💂🏻‍♀' => 'күзетші әйел: 1–2 тері түсі',
    '💂🏼‍♀' => 'күзетші әйел: 3-тері түрі',
    '💂🏽‍♀' => 'күзетші әйел: 4-тері түсі',
    '💂🏾‍♀' => 'күзетші әйел: 5-тері түсі',
    '💂🏿‍♀' => 'күзетші әйел: 6-тері түсі',
    '👷🏻‍♂' => 'құрылысшы ер адам: 1–2 тері түсі',
    '👷🏼‍♂' => 'құрылысшы ер адам: 3-тері түрі',
    '👷🏽‍♂' => 'құрылысшы ер адам: 4-тері түсі',
    '👷🏾‍♂' => 'құрылысшы ер адам: 5-тері түсі',
    '👷🏿‍♂' => 'құрылысшы ер адам: 6-тері түсі',
    '👷🏻‍♀' => 'құрылысшы әйел: 1–2 тері түсі',
    '👷🏼‍♀' => 'құрылысшы әйел: 3-тері түрі',
    '👷🏽‍♀' => 'құрылысшы әйел: 4-тері түсі',
    '👷🏾‍♀' => 'құрылысшы әйел: 5-тері түсі',
    '👷🏿‍♀' => 'құрылысшы әйел: 6-тері түсі',
    '👳🏻‍♂' => 'сәлделі ер адам: 1–2 тері түсі',
    '👳🏼‍♂' => 'сәлделі ер адам: 3-тері түрі',
    '👳🏽‍♂' => 'сәлделі ер адам: 4-тері түсі',
    '👳🏾‍♂' => 'сәлделі ер адам: 5-тері түсі',
    '👳🏿‍♂' => 'сәлделі ер адам: 6-тері түсі',
    '👳🏻‍♀' => 'сәлделі әйел: 1–2 тері түсі',
    '👳🏼‍♀' => 'сәлделі әйел: 3-тері түрі',
    '👳🏽‍♀' => 'сәлделі әйел: 4-тері түсі',
    '👳🏾‍♀' => 'сәлделі әйел: 5-тері түсі',
    '👳🏿‍♀' => 'сәлделі әйел: 6-тері түсі',
    '🤵🏻‍♂' => 'смокинг киген ер адам: 1–2 тері түсі',
    '🤵🏼‍♂' => 'смокинг киген ер адам: 3-тері түрі',
    '🤵🏽‍♂' => 'смокинг киген ер адам: 4-тері түсі',
    '🤵🏾‍♂' => 'смокинг киген ер адам: 5-тері түсі',
    '🤵🏿‍♂' => 'смокинг киген ер адам: 6-тері түсі',
    '🤵🏻‍♀' => 'смокинг киген әйел адам: 1–2 тері түсі',
    '🤵🏼‍♀' => 'смокинг киген әйел адам: 3-тері түрі',
    '🤵🏽‍♀' => 'смокинг киген әйел адам: 4-тері түсі',
    '🤵🏾‍♀' => 'смокинг киген әйел адам: 5-тері түсі',
    '🤵🏿‍♀' => 'смокинг киген әйел адам: 6-тері түсі',
    '👰🏻‍♂' => 'жаулық таққан ер адам: 1–2 тері түсі',
    '👰🏼‍♂' => 'жаулық таққан ер адам: 3-тері түрі',
    '👰🏽‍♂' => 'жаулық таққан ер адам: 4-тері түсі',
    '👰🏾‍♂' => 'жаулық таққан ер адам: 5-тері түсі',
    '👰🏿‍♂' => 'жаулық таққан ер адам: 6-тері түсі',
    '👰🏻‍♀' => 'жаулық таққан әйел: 1–2 тері түсі',
    '👰🏼‍♀' => 'жаулық таққан әйел: 3-тері түрі',
    '👰🏽‍♀' => 'жаулық таққан әйел: 4-тері түсі',
    '👰🏾‍♀' => 'жаулық таққан әйел: 5-тері түсі',
    '👰🏿‍♀' => 'жаулық таққан әйел: 6-тері түсі',
    '👩🏻‍🍼' => 'бала емізіп отырған әйел: 1–2 тері түсі',
    '👩🏼‍🍼' => 'бала емізіп отырған әйел: 3-тері түрі',
    '👩🏽‍🍼' => 'бала емізіп отырған әйел: 4-тері түсі',
    '👩🏾‍🍼' => 'бала емізіп отырған әйел: 5-тері түсі',
    '👩🏿‍🍼' => 'бала емізіп отырған әйел: 6-тері түсі',
    '👨🏻‍🍼' => 'бала емізіп отырған еркек: 1–2 тері түсі',
    '👨🏼‍🍼' => 'бала емізіп отырған еркек: 3-тері түрі',
    '👨🏽‍🍼' => 'бала емізіп отырған еркек: 4-тері түсі',
    '👨🏾‍🍼' => 'бала емізіп отырған еркек: 5-тері түсі',
    '👨🏿‍🍼' => 'бала емізіп отырған еркек: 6-тері түсі',
    '🧑🏻‍🍼' => 'бала емізіп отырған адам: 1–2 тері түсі',
    '🧑🏼‍🍼' => 'бала емізіп отырған адам: 3-тері түрі',
    '🧑🏽‍🍼' => 'бала емізіп отырған адам: 4-тері түсі',
    '🧑🏾‍🍼' => 'бала емізіп отырған адам: 5-тері түсі',
    '🧑🏿‍🍼' => 'бала емізіп отырған адам: 6-тері түсі',
    '🧑🏻‍🎄' => 'клаус мырза: 1–2 тері түсі',
    '🧑🏼‍🎄' => 'клаус мырза: 3-тері түрі',
    '🧑🏽‍🎄' => 'клаус мырза: 4-тері түсі',
    '🧑🏾‍🎄' => 'клаус мырза: 5-тері түсі',
    '🧑🏿‍🎄' => 'клаус мырза: 6-тері түсі',
    '🦸🏻‍♂' => 'еркек супер батыр: 1–2 тері түсі',
    '🦸🏼‍♂' => 'еркек супер батыр: 3-тері түрі',
    '🦸🏽‍♂' => 'еркек супер батыр: 4-тері түсі',
    '🦸🏾‍♂' => 'еркек супер батыр: 5-тері түсі',
    '🦸🏿‍♂' => 'еркек супер батыр: 6-тері түсі',
    '🦸🏻‍♀' => 'батыр әйел: 1–2 тері түсі',
    '🦸🏼‍♀' => 'батыр әйел: 3-тері түрі',
    '🦸🏽‍♀' => 'батыр әйел: 4-тері түсі',
    '🦸🏾‍♀' => 'батыр әйел: 5-тері түсі',
    '🦸🏿‍♀' => 'батыр әйел: 6-тері түсі',
    '🦹🏻‍♂' => 'ер супер залым: 1–2 тері түсі',
    '🦹🏼‍♂' => 'ер супер залым: 3-тері түрі',
    '🦹🏽‍♂' => 'ер супер залым: 4-тері түсі',
    '🦹🏾‍♂' => 'ер супер залым: 5-тері түсі',
    '🦹🏿‍♂' => 'ер супер залым: 6-тері түсі',
    '🦹🏻‍♀' => 'әйел супер залым: 1–2 тері түсі',
    '🦹🏼‍♀' => 'әйел супер залым: 3-тері түрі',
    '🦹🏽‍♀' => 'әйел супер залым: 4-тері түсі',
    '🦹🏾‍♀' => 'әйел супер залым: 5-тері түсі',
    '🦹🏿‍♀' => 'әйел супер залым: 6-тері түсі',
    '🧙🏻‍♂' => 'ер сиқыршы: 1–2 тері түсі',
    '🧙🏼‍♂' => 'ер сиқыршы: 3-тері түрі',
    '🧙🏽‍♂' => 'ер сиқыршы: 4-тері түсі',
    '🧙🏾‍♂' => 'ер сиқыршы: 5-тері түсі',
    '🧙🏿‍♂' => 'ер сиқыршы: 6-тері түсі',
    '🧙🏻‍♀' => 'әйел сиқыршы: 1–2 тері түсі',
    '🧙🏼‍♀' => 'әйел сиқыршы: 3-тері түрі',
    '🧙🏽‍♀' => 'әйел сиқыршы: 4-тері түсі',
    '🧙🏾‍♀' => 'әйел сиқыршы: 5-тері түсі',
    '🧙🏿‍♀' => 'әйел сиқыршы: 6-тері түсі',
    '🧚🏻‍♂' => 'ер пері: 1–2 тері түсі',
    '🧚🏼‍♂' => 'ер пері: 3-тері түрі',
    '🧚🏽‍♂' => 'ер пері: 4-тері түсі',
    '🧚🏾‍♂' => 'ер пері: 5-тері түсі',
    '🧚🏿‍♂' => 'ер пері: 6-тері түсі',
    '🧚🏻‍♀' => 'әйел пері: 1–2 тері түсі',
    '🧚🏼‍♀' => 'әйел пері: 3-тері түрі',
    '🧚🏽‍♀' => 'әйел пері: 4-тері түсі',
    '🧚🏾‍♀' => 'әйел пері: 5-тері түсі',
    '🧚🏿‍♀' => 'әйел пері: 6-тері түсі',
    '🧛🏻‍♂' => 'ер вампир: 1–2 тері түсі',
    '🧛🏼‍♂' => 'ер вампир: 3-тері түрі',
    '🧛🏽‍♂' => 'ер вампир: 4-тері түсі',
    '🧛🏾‍♂' => 'ер вампир: 5-тері түсі',
    '🧛🏿‍♂' => 'ер вампир: 6-тері түсі',
    '🧛🏻‍♀' => 'әйел вампир: 1–2 тері түсі',
    '🧛🏼‍♀' => 'әйел вампир: 3-тері түрі',
    '🧛🏽‍♀' => 'әйел вампир: 4-тері түсі',
    '🧛🏾‍♀' => 'әйел вампир: 5-тері түсі',
    '🧛🏿‍♀' => 'әйел вампир: 6-тері түсі',
    '🧜🏻‍♂' => 'құйрықты: 1–2 тері түсі',
    '🧜🏼‍♂' => 'құйрықты: 3-тері түрі',
    '🧜🏽‍♂' => 'құйрықты: 4-тері түсі',
    '🧜🏾‍♂' => 'құйрықты: 5-тері түсі',
    '🧜🏿‍♂' => 'құйрықты: 6-тері түсі',
    '🧜🏻‍♀' => 'су перісі: 1–2 тері түсі',
    '🧜🏼‍♀' => 'су перісі: 3-тері түрі',
    '🧜🏽‍♀' => 'су перісі: 4-тері түсі',
    '🧜🏾‍♀' => 'су перісі: 5-тері түсі',
    '🧜🏿‍♀' => 'су перісі: 6-тері түсі',
    '🧝🏻‍♂' => 'ер ергежейлі: 1–2 тері түсі',
    '🧝🏼‍♂' => 'ер ергежейлі: 3-тері түрі',
    '🧝🏽‍♂' => 'ер ергежейлі: 4-тері түсі',
    '🧝🏾‍♂' => 'ер ергежейлі: 5-тері түсі',
    '🧝🏿‍♂' => 'ер ергежейлі: 6-тері түсі',
    '🧝🏻‍♀' => 'әйел ергежейлі: 1–2 тері түсі',
    '🧝🏼‍♀' => 'әйел ергежейлі: 3-тері түрі',
    '🧝🏽‍♀' => 'әйел ергежейлі: 4-тері түсі',
    '🧝🏾‍♀' => 'әйел ергежейлі: 5-тері түсі',
    '🧝🏿‍♀' => 'әйел ергежейлі: 6-тері түсі',
    '💆🏻‍♂' => 'бетін уақалатып отырған ер: 1–2 тері түсі',
    '💆🏼‍♂' => 'бетін уақалатып отырған ер: 3-тері түрі',
    '💆🏽‍♂' => 'бетін уақалатып отырған ер: 4-тері түсі',
    '💆🏾‍♂' => 'бетін уақалатып отырған ер: 5-тері түсі',
    '💆🏿‍♂' => 'бетін уақалатып отырған ер: 6-тері түсі',
    '💆🏻‍♀' => 'бетін уақалатып отырған әйел: 1–2 тері түсі',
    '💆🏼‍♀' => 'бетін уақалатып отырған әйел: 3-тері түрі',
    '💆🏽‍♀' => 'бетін уақалатып отырған әйел: 4-тері түсі',
    '💆🏾‍♀' => 'бетін уақалатып отырған әйел: 5-тері түсі',
    '💆🏿‍♀' => 'бетін уақалатып отырған әйел: 6-тері түсі',
    '💇🏻‍♂' => 'шашын қидырып отырған ер: 1–2 тері түсі',
    '💇🏼‍♂' => 'шашын қидырып отырған ер: 3-тері түрі',
    '💇🏽‍♂' => 'шашын қидырып отырған ер: 4-тері түсі',
    '💇🏾‍♂' => 'шашын қидырып отырған ер: 5-тері түсі',
    '💇🏿‍♂' => 'шашын қидырып отырған ер: 6-тері түсі',
    '💇🏻‍♀' => 'шашын қидырып отырған әйел: 1–2 тері түсі',
    '💇🏼‍♀' => 'шашын қидырып отырған әйел: 3-тері түрі',
    '💇🏽‍♀' => 'шашын қидырып отырған әйел: 4-тері түсі',
    '💇🏾‍♀' => 'шашын қидырып отырған әйел: 5-тері түсі',
    '💇🏿‍♀' => 'шашын қидырып отырған әйел: 6-тері түсі',
    '🚶🏻‍♂' => 'жаяу ер: 1–2 тері түсі',
    '🚶🏼‍♂' => 'жаяу ер: 3-тері түрі',
    '🚶🏽‍♂' => 'жаяу ер: 4-тері түсі',
    '🚶🏾‍♂' => 'жаяу ер: 5-тері түсі',
    '🚶🏿‍♂' => 'жаяу ер: 6-тері түсі',
    '🚶🏻‍♀' => 'жаяу әйел: 1–2 тері түсі',
    '🚶🏼‍♀' => 'жаяу әйел: 3-тері түрі',
    '🚶🏽‍♀' => 'жаяу әйел: 4-тері түсі',
    '🚶🏾‍♀' => 'жаяу әйел: 5-тері түсі',
    '🚶🏿‍♀' => 'жаяу әйел: 6-тері түсі',
    '🚶🏻‍➡' => 'жаяу: 1–2 тері түсі оңға қаратылған',
    '🚶🏼‍➡' => 'жаяу: 3-тері түрі оңға қаратылған',
    '🚶🏽‍➡' => 'жаяу: 4-тері түсі оңға қаратылған',
    '🚶🏾‍➡' => 'жаяу: 5-тері түсі оңға қаратылған',
    '🚶🏿‍➡' => 'жаяу: 6-тері түсі оңға қаратылған',
    '🧍🏻‍♂' => 'тұрып тұрған еркек: 1–2 тері түсі',
    '🧍🏼‍♂' => 'тұрып тұрған еркек: 3-тері түрі',
    '🧍🏽‍♂' => 'тұрып тұрған еркек: 4-тері түсі',
    '🧍🏾‍♂' => 'тұрып тұрған еркек: 5-тері түсі',
    '🧍🏿‍♂' => 'тұрып тұрған еркек: 6-тері түсі',
    '🧍🏻‍♀' => 'тұрып тұрған әйел: 1–2 тері түсі',
    '🧍🏼‍♀' => 'тұрып тұрған әйел: 3-тері түрі',
    '🧍🏽‍♀' => 'тұрып тұрған әйел: 4-тері түсі',
    '🧍🏾‍♀' => 'тұрып тұрған әйел: 5-тері түсі',
    '🧍🏿‍♀' => 'тұрып тұрған әйел: 6-тері түсі',
    '🧎🏻‍♂' => 'тізерлеп отырған еркек: 1–2 тері түсі',
    '🧎🏼‍♂' => 'тізерлеп отырған еркек: 3-тері түрі',
    '🧎🏽‍♂' => 'тізерлеп отырған еркек: 4-тері түсі',
    '🧎🏾‍♂' => 'тізерлеп отырған еркек: 5-тері түсі',
    '🧎🏿‍♂' => 'тізерлеп отырған еркек: 6-тері түсі',
    '🧎🏻‍♀' => 'тізерлеп отырған әйел: 1–2 тері түсі',
    '🧎🏼‍♀' => 'тізерлеп отырған әйел: 3-тері түрі',
    '🧎🏽‍♀' => 'тізерлеп отырған әйел: 4-тері түсі',
    '🧎🏾‍♀' => 'тізерлеп отырған әйел: 5-тері түсі',
    '🧎🏿‍♀' => 'тізерлеп отырған әйел: 6-тері түсі',
    '🧎🏻‍➡' => 'тізерлеп отырған адам: 1–2 тері түсі оңға қаратылған',
    '🧎🏼‍➡' => 'тізерлеп отырған адам: 3-тері түрі оңға қаратылған',
    '🧎🏽‍➡' => 'тізерлеп отырған адам: 4-тері түсі оңға қаратылған',
    '🧎🏾‍➡' => 'тізерлеп отырған адам: 5-тері түсі оңға қаратылған',
    '🧎🏿‍➡' => 'тізерлеп отырған адам: 6-тері түсі оңға қаратылған',
    '🧑🏻‍🦯' => 'таяғы бар адам: 1–2 тері түсі',
    '🧑🏼‍🦯' => 'таяғы бар адам: 3-тері түрі',
    '🧑🏽‍🦯' => 'таяғы бар адам: 4-тері түсі',
    '🧑🏾‍🦯' => 'таяғы бар адам: 5-тері түсі',
    '🧑🏿‍🦯' => 'таяғы бар адам: 6-тері түсі',
    '👨🏻‍🦯' => 'таяғы бар еркек: 1–2 тері түсі',
    '👨🏼‍🦯' => 'таяғы бар еркек: 3-тері түрі',
    '👨🏽‍🦯' => 'таяғы бар еркек: 4-тері түсі',
    '👨🏾‍🦯' => 'таяғы бар еркек: 5-тері түсі',
    '👨🏿‍🦯' => 'таяғы бар еркек: 6-тері түсі',
    '👩🏻‍🦯' => 'таяғы бар әйел: 1–2 тері түсі',
    '👩🏼‍🦯' => 'таяғы бар әйел: 3-тері түрі',
    '👩🏽‍🦯' => 'таяғы бар әйел: 4-тері түсі',
    '👩🏾‍🦯' => 'таяғы бар әйел: 5-тері түсі',
    '👩🏿‍🦯' => 'таяғы бар әйел: 6-тері түсі',
    '🧑🏻‍🦼' => 'моторлы арбадағы адам: 1–2 тері түсі',
    '🧑🏼‍🦼' => 'моторлы арбадағы адам: 3-тері түрі',
    '🧑🏽‍🦼' => 'моторлы арбадағы адам: 4-тері түсі',
    '🧑🏾‍🦼' => 'моторлы арбадағы адам: 5-тері түсі',
    '🧑🏿‍🦼' => 'моторлы арбадағы адам: 6-тері түсі',
    '👨🏻‍🦼' => 'электр жетегі бар арбашадағы еркек: 1–2 тері түсі',
    '👨🏼‍🦼' => 'электр жетегі бар арбашадағы еркек: 3-тері түрі',
    '👨🏽‍🦼' => 'электр жетегі бар арбашадағы еркек: 4-тері түсі',
    '👨🏾‍🦼' => 'электр жетегі бар арбашадағы еркек: 5-тері түсі',
    '👨🏿‍🦼' => 'электр жетегі бар арбашадағы еркек: 6-тері түсі',
    '👩🏻‍🦼' => 'электр жетегі бар арбашадағы әйел: 1–2 тері түсі',
    '👩🏼‍🦼' => 'электр жетегі бар арбашадағы әйел: 3-тері түрі',
    '👩🏽‍🦼' => 'электр жетегі бар арбашадағы әйел: 4-тері түсі',
    '👩🏾‍🦼' => 'электр жетегі бар арбашадағы әйел: 5-тері түсі',
    '👩🏿‍🦼' => 'электр жетегі бар арбашадағы әйел: 6-тері түсі',
    '🧑🏻‍🦽' => 'қол жетегі бар арбашадағы адам: 1–2 тері түсі',
    '🧑🏼‍🦽' => 'қол жетегі бар арбашадағы адам: 3-тері түрі',
    '🧑🏽‍🦽' => 'қол жетегі бар арбашадағы адам: 4-тері түсі',
    '🧑🏾‍🦽' => 'қол жетегі бар арбашадағы адам: 5-тері түсі',
    '🧑🏿‍🦽' => 'қол жетегі бар арбашадағы адам: 6-тері түсі',
    '👨🏻‍🦽' => 'қол жетегі бар арбашадағы еркек: 1–2 тері түсі',
    '👨🏼‍🦽' => 'қол жетегі бар арбашадағы еркек: 3-тері түрі',
    '👨🏽‍🦽' => 'қол жетегі бар арбашадағы еркек: 4-тері түсі',
    '👨🏾‍🦽' => 'қол жетегі бар арбашадағы еркек: 5-тері түсі',
    '👨🏿‍🦽' => 'қол жетегі бар арбашадағы еркек: 6-тері түсі',
    '👩🏻‍🦽' => 'қол жетегі бар арбашадағы әйел: 1–2 тері түсі',
    '👩🏼‍🦽' => 'қол жетегі бар арбашадағы әйел: 3-тері түрі',
    '👩🏽‍🦽' => 'қол жетегі бар арбашадағы әйел: 4-тері түсі',
    '👩🏾‍🦽' => 'қол жетегі бар арбашадағы әйел: 5-тері түсі',
    '👩🏿‍🦽' => 'қол жетегі бар арбашадағы әйел: 6-тері түсі',
    '🏃🏻‍♂' => 'жүгірген ер: 1–2 тері түсі',
    '🏃🏼‍♂' => 'жүгірген ер: 3-тері түрі',
    '🏃🏽‍♂' => 'жүгірген ер: 4-тері түсі',
    '🏃🏾‍♂' => 'жүгірген ер: 5-тері түсі',
    '🏃🏿‍♂' => 'жүгірген ер: 6-тері түсі',
    '🏃🏻‍♀' => 'жүгірген әйел: 1–2 тері түсі',
    '🏃🏼‍♀' => 'жүгірген әйел: 3-тері түрі',
    '🏃🏽‍♀' => 'жүгірген әйел: 4-тері түсі',
    '🏃🏾‍♀' => 'жүгірген әйел: 5-тері түсі',
    '🏃🏿‍♀' => 'жүгірген әйел: 6-тері түсі',
    '🏃🏻‍➡' => 'жүгіру: 1–2 тері түсі оңға қаратылған',
    '🏃🏼‍➡' => 'жүгіру: 3-тері түрі оңға қаратылған',
    '🏃🏽‍➡' => 'жүгіру: 4-тері түсі оңға қаратылған',
    '🏃🏾‍➡' => 'жүгіру: 5-тері түсі оңға қаратылған',
    '🏃🏿‍➡' => 'жүгіру: 6-тері түсі оңға қаратылған',
    '👯🏻‍♀' => 'тойлатып жүрген әйелдер: 1–2 тері түсі',
    '👯🏼‍♀' => 'тойлатып жүрген әйелдер: 3-тері түрі',
    '👯🏽‍♀' => 'тойлатып жүрген әйелдер: 4-тері түсі',
    '👯🏾‍♀' => 'тойлатып жүрген әйелдер: 5-тері түсі',
    '👯🏿‍♀' => 'тойлатып жүрген әйелдер: 6-тері түсі',
    '👯🏻‍♂' => 'тойлатып жүрген ерлер: 1–2 тері түсі',
    '👯🏼‍♂' => 'тойлатып жүрген ерлер: 3-тері түрі',
    '👯🏽‍♂' => 'тойлатып жүрген ерлер: 4-тері түсі',
    '👯🏾‍♂' => 'тойлатып жүрген ерлер: 5-тері түсі',
    '👯🏿‍♂' => 'тойлатып жүрген ерлер: 6-тері түсі',
    '🧖🏻‍♂' => 'бу бөлмедегі ер: 1–2 тері түсі',
    '🧖🏼‍♂' => 'бу бөлмедегі ер: 3-тері түрі',
    '🧖🏽‍♂' => 'бу бөлмедегі ер: 4-тері түсі',
    '🧖🏾‍♂' => 'бу бөлмедегі ер: 5-тері түсі',
    '🧖🏿‍♂' => 'бу бөлмедегі ер: 6-тері түсі',
    '🧖🏻‍♀' => 'бу бөлмедегі әйел: 1–2 тері түсі',
    '🧖🏼‍♀' => 'бу бөлмедегі әйел: 3-тері түрі',
    '🧖🏽‍♀' => 'бу бөлмедегі әйел: 4-тері түсі',
    '🧖🏾‍♀' => 'бу бөлмедегі әйел: 5-тері түсі',
    '🧖🏿‍♀' => 'бу бөлмедегі әйел: 6-тері түсі',
    '🧗🏻‍♂' => 'көтеріліп бара жатқан ер адам: 1–2 тері түсі',
    '🧗🏼‍♂' => 'көтеріліп бара жатқан ер адам: 3-тері түрі',
    '🧗🏽‍♂' => 'көтеріліп бара жатқан ер адам: 4-тері түсі',
    '🧗🏾‍♂' => 'көтеріліп бара жатқан ер адам: 5-тері түсі',
    '🧗🏿‍♂' => 'көтеріліп бара жатқан ер адам: 6-тері түсі',
    '🧗🏻‍♀' => 'көтеріліп бара жатқан әйел: 1–2 тері түсі',
    '🧗🏼‍♀' => 'көтеріліп бара жатқан әйел: 3-тері түрі',
    '🧗🏽‍♀' => 'көтеріліп бара жатқан әйел: 4-тері түсі',
    '🧗🏾‍♀' => 'көтеріліп бара жатқан әйел: 5-тері түсі',
    '🧗🏿‍♀' => 'көтеріліп бара жатқан әйел: 6-тері түсі',
    '🏌🏻‍♂' => 'гольф ойнаған ер: 1–2 тері түсі',
    '🏌🏼‍♂' => 'гольф ойнаған ер: 3-тері түрі',
    '🏌🏽‍♂' => 'гольф ойнаған ер: 4-тері түсі',
    '🏌🏾‍♂' => 'гольф ойнаған ер: 5-тері түсі',
    '🏌🏿‍♂' => 'гольф ойнаған ер: 6-тері түсі',
    '🏌🏻‍♀' => 'гольф ойнаған әйел: 1–2 тері түсі',
    '🏌🏼‍♀' => 'гольф ойнаған әйел: 3-тері түрі',
    '🏌🏽‍♀' => 'гольф ойнаған әйел: 4-тері түсі',
    '🏌🏾‍♀' => 'гольф ойнаған әйел: 5-тері түсі',
    '🏌🏿‍♀' => 'гольф ойнаған әйел: 6-тері түсі',
    '🏄🏻‍♂' => 'серфингші ер: 1–2 тері түсі',
    '🏄🏼‍♂' => 'серфингші ер: 3-тері түрі',
    '🏄🏽‍♂' => 'серфингші ер: 4-тері түсі',
    '🏄🏾‍♂' => 'серфингші ер: 5-тері түсі',
    '🏄🏿‍♂' => 'серфингші ер: 6-тері түсі',
    '🏄🏻‍♀' => 'серфингші әйел: 1–2 тері түсі',
    '🏄🏼‍♀' => 'серфингші әйел: 3-тері түрі',
    '🏄🏽‍♀' => 'серфингші әйел: 4-тері түсі',
    '🏄🏾‍♀' => 'серфингші әйел: 5-тері түсі',
    '🏄🏿‍♀' => 'серфингші әйел: 6-тері түсі',
    '🚣🏻‍♂' => 'қайық есуші ер: 1–2 тері түсі',
    '🚣🏼‍♂' => 'қайық есуші ер: 3-тері түрі',
    '🚣🏽‍♂' => 'қайық есуші ер: 4-тері түсі',
    '🚣🏾‍♂' => 'қайық есуші ер: 5-тері түсі',
    '🚣🏿‍♂' => 'қайық есуші ер: 6-тері түсі',
    '🚣🏻‍♀' => 'қайық есуші әйел: 1–2 тері түсі',
    '🚣🏼‍♀' => 'қайық есуші әйел: 3-тері түрі',
    '🚣🏽‍♀' => 'қайық есуші әйел: 4-тері түсі',
    '🚣🏾‍♀' => 'қайық есуші әйел: 5-тері түсі',
    '🚣🏿‍♀' => 'қайық есуші әйел: 6-тері түсі',
    '🏊🏻‍♂' => 'жүзуші ер: 1–2 тері түсі',
    '🏊🏼‍♂' => 'жүзуші ер: 3-тері түрі',
    '🏊🏽‍♂' => 'жүзуші ер: 4-тері түсі',
    '🏊🏾‍♂' => 'жүзуші ер: 5-тері түсі',
    '🏊🏿‍♂' => 'жүзуші ер: 6-тері түсі',
    '🏊🏻‍♀' => 'жүзуші әйел: 1–2 тері түсі',
    '🏊🏼‍♀' => 'жүзуші әйел: 3-тері түрі',
    '🏊🏽‍♀' => 'жүзуші әйел: 4-тері түсі',
    '🏊🏾‍♀' => 'жүзуші әйел: 5-тері түсі',
    '🏊🏿‍♀' => 'жүзуші әйел: 6-тері түсі',
    '⛹🏻‍♂' => 'доп ойнаған ер: 1–2 тері түсі',
    '⛹🏼‍♂' => 'доп ойнаған ер: 3-тері түрі',
    '⛹🏽‍♂' => 'доп ойнаған ер: 4-тері түсі',
    '⛹🏾‍♂' => 'доп ойнаған ер: 5-тері түсі',
    '⛹🏿‍♂' => 'доп ойнаған ер: 6-тері түсі',
    '⛹🏻‍♀' => 'доп ойнаған әйел: 1–2 тері түсі',
    '⛹🏼‍♀' => 'доп ойнаған әйел: 3-тері түрі',
    '⛹🏽‍♀' => 'доп ойнаған әйел: 4-тері түсі',
    '⛹🏾‍♀' => 'доп ойнаған әйел: 5-тері түсі',
    '⛹🏿‍♀' => 'доп ойнаған әйел: 6-тері түсі',
    '🏋🏻‍♂' => 'ауыр атлет ер: 1–2 тері түсі',
    '🏋🏼‍♂' => 'ауыр атлет ер: 3-тері түрі',
    '🏋🏽‍♂' => 'ауыр атлет ер: 4-тері түсі',
    '🏋🏾‍♂' => 'ауыр атлет ер: 5-тері түсі',
    '🏋🏿‍♂' => 'ауыр атлет ер: 6-тері түсі',
    '🏋🏻‍♀' => 'ауыр атлет әйел: 1–2 тері түсі',
    '🏋🏼‍♀' => 'ауыр атлет әйел: 3-тері түрі',
    '🏋🏽‍♀' => 'ауыр атлет әйел: 4-тері түсі',
    '🏋🏾‍♀' => 'ауыр атлет әйел: 5-тері түсі',
    '🏋🏿‍♀' => 'ауыр атлет әйел: 6-тері түсі',
    '🚴🏻‍♂' => 'велосипедші ер: 1–2 тері түсі',
    '🚴🏼‍♂' => 'велосипедші ер: 3-тері түрі',
    '🚴🏽‍♂' => 'велосипедші ер: 4-тері түсі',
    '🚴🏾‍♂' => 'велосипедші ер: 5-тері түсі',
    '🚴🏿‍♂' => 'велосипедші ер: 6-тері түсі',
    '🚴🏻‍♀' => 'велосипедші әйел: 1–2 тері түсі',
    '🚴🏼‍♀' => 'велосипедші әйел: 3-тері түрі',
    '🚴🏽‍♀' => 'велосипедші әйел: 4-тері түсі',
    '🚴🏾‍♀' => 'велосипедші әйел: 5-тері түсі',
    '🚴🏿‍♀' => 'велосипедші әйел: 6-тері түсі',
    '🚵🏻‍♂' => 'тау велосипедін мінген ер: 1–2 тері түсі',
    '🚵🏼‍♂' => 'тау велосипедін мінген ер: 3-тері түрі',
    '🚵🏽‍♂' => 'тау велосипедін мінген ер: 4-тері түсі',
    '🚵🏾‍♂' => 'тау велосипедін мінген ер: 5-тері түсі',
    '🚵🏿‍♂' => 'тау велосипедін мінген ер: 6-тері түсі',
    '🚵🏻‍♀' => 'тау велосипедін мінген әйел: 1–2 тері түсі',
    '🚵🏼‍♀' => 'тау велосипедін мінген әйел: 3-тері түрі',
    '🚵🏽‍♀' => 'тау велосипедін мінген әйел: 4-тері түсі',
    '🚵🏾‍♀' => 'тау велосипедін мінген әйел: 5-тері түсі',
    '🚵🏿‍♀' => 'тау велосипедін мінген әйел: 6-тері түсі',
    '🤸🏻‍♂' => 'акробат ер: 1–2 тері түсі',
    '🤸🏼‍♂' => 'акробат ер: 3-тері түрі',
    '🤸🏽‍♂' => 'акробат ер: 4-тері түсі',
    '🤸🏾‍♂' => 'акробат ер: 5-тері түсі',
    '🤸🏿‍♂' => 'акробат ер: 6-тері түсі',
    '🤸🏻‍♀' => 'акробат әйел: 1–2 тері түсі',
    '🤸🏼‍♀' => 'акробат әйел: 3-тері түрі',
    '🤸🏽‍♀' => 'акробат әйел: 4-тері түсі',
    '🤸🏾‍♀' => 'акробат әйел: 5-тері түсі',
    '🤸🏿‍♀' => 'акробат әйел: 6-тері түсі',
    '🤼🏻‍♀' => 'күресші әйел: 1–2 тері түсі',
    '🤼🏼‍♀' => 'күресші әйел: 3-тері түрі',
    '🤼🏽‍♀' => 'күресші әйел: 4-тері түсі',
    '🤼🏾‍♀' => 'күресші әйел: 5-тері түсі',
    '🤼🏿‍♀' => 'күресші әйел: 6-тері түсі',
    '🤼🏻‍♂' => 'күресші ер: 1–2 тері түсі',
    '🤼🏼‍♂' => 'күресші ер: 3-тері түрі',
    '🤼🏽‍♂' => 'күресші ер: 4-тері түсі',
    '🤼🏾‍♂' => 'күресші ер: 5-тері түсі',
    '🤼🏿‍♂' => 'күресші ер: 6-тері түсі',
    '🤽🏻‍♂' => 'су полосын ойнаған ер: 1–2 тері түсі',
    '🤽🏼‍♂' => 'су полосын ойнаған ер: 3-тері түрі',
    '🤽🏽‍♂' => 'су полосын ойнаған ер: 4-тері түсі',
    '🤽🏾‍♂' => 'су полосын ойнаған ер: 5-тері түсі',
    '🤽🏿‍♂' => 'су полосын ойнаған ер: 6-тері түсі',
    '🤽🏻‍♀' => 'су полосын ойнаған әйел: 1–2 тері түсі',
    '🤽🏼‍♀' => 'су полосын ойнаған әйел: 3-тері түрі',
    '🤽🏽‍♀' => 'су полосын ойнаған әйел: 4-тері түсі',
    '🤽🏾‍♀' => 'су полосын ойнаған әйел: 5-тері түсі',
    '🤽🏿‍♀' => 'су полосын ойнаған әйел: 6-тері түсі',
    '🤾🏻‍♂' => 'гандбол ойнаған ер: 1–2 тері түсі',
    '🤾🏼‍♂' => 'гандбол ойнаған ер: 3-тері түрі',
    '🤾🏽‍♂' => 'гандбол ойнаған ер: 4-тері түсі',
    '🤾🏾‍♂' => 'гандбол ойнаған ер: 5-тері түсі',
    '🤾🏿‍♂' => 'гандбол ойнаған ер: 6-тері түсі',
    '🤾🏻‍♀' => 'гандбол ойнаған әйел: 1–2 тері түсі',
    '🤾🏼‍♀' => 'гандбол ойнаған әйел: 3-тері түрі',
    '🤾🏽‍♀' => 'гандбол ойнаған әйел: 4-тері түсі',
    '🤾🏾‍♀' => 'гандбол ойнаған әйел: 5-тері түсі',
    '🤾🏿‍♀' => 'гандбол ойнаған әйел: 6-тері түсі',
    '🤹🏻‍♂' => 'жонглер ер: 1–2 тері түсі',
    '🤹🏼‍♂' => 'жонглер ер: 3-тері түрі',
    '🤹🏽‍♂' => 'жонглер ер: 4-тері түсі',
    '🤹🏾‍♂' => 'жонглер ер: 5-тері түсі',
    '🤹🏿‍♂' => 'жонглер ер: 6-тері түсі',
    '🤹🏻‍♀' => 'жонглер әйел: 1–2 тері түсі',
    '🤹🏼‍♀' => 'жонглер әйел: 3-тері түрі',
    '🤹🏽‍♀' => 'жонглер әйел: 4-тері түсі',
    '🤹🏾‍♀' => 'жонглер әйел: 5-тері түсі',
    '🤹🏿‍♀' => 'жонглер әйел: 6-тері түсі',
    '🧘🏻‍♂' => 'малдас құрып отырған ер адам: 1–2 тері түсі',
    '🧘🏼‍♂' => 'малдас құрып отырған ер адам: 3-тері түрі',
    '🧘🏽‍♂' => 'малдас құрып отырған ер адам: 4-тері түсі',
    '🧘🏾‍♂' => 'малдас құрып отырған ер адам: 5-тері түсі',
    '🧘🏿‍♂' => 'малдас құрып отырған ер адам: 6-тері түсі',
    '🧘🏻‍♀' => 'малдас құрып отырған әйел: 1–2 тері түсі',
    '🧘🏼‍♀' => 'малдас құрып отырған әйел: 3-тері түрі',
    '🧘🏽‍♀' => 'малдас құрып отырған әйел: 4-тері түсі',
    '🧘🏾‍♀' => 'малдас құрып отырған әйел: 5-тері түсі',
    '🧘🏿‍♀' => 'малдас құрып отырған әйел: 6-тері түсі',
    '🧑‍🦰' => 'адам: жирен шаш',
    '🧑‍🦱' => 'адам: бұйра шаш',
    '🧑‍🦳' => 'адам: ақ шаш',
    '🧑‍🦲' => 'адам: тақырбас',
    '👨‍🦰' => 'ер адам: жирен шаш',
    '👨‍🦱' => 'ер адам: бұйра шаш',
    '👨‍🦳' => 'ер адам: ақ шаш',
    '👨‍🦲' => 'ер адам: тақырбас',
    '👩‍🦰' => 'әйел: жирен шаш',
    '👩‍🦱' => 'әйел: бұйра шаш',
    '👩‍🦳' => 'әйел: ақ шаш',
    '👩‍🦲' => 'әйел: тақырбас',
    '🚶‍➡' => 'жаяу: оңға қаратылған',
    '🧎‍➡' => 'тізерлеп отырған адам: оңға қаратылған',
    '🏃‍➡' => 'жүгіру: оңға қаратылған',
    '👨‍👦' => 'отбасы: ер адам ұл',
    '👨‍👧' => 'отбасы: ер адам қыз',
    '👩‍👦' => 'отбасы: әйел ұл',
    '👩‍👧' => 'отбасы: әйел қыз',
    '😶‍🌫' => 'бұлт басқан бет',
    '😮‍💨' => 'ауаны шығарып тұрған бет',
    '🙂‍↕' => 'тігінен шайқалған бет',
    '😵‍💫' => 'көзі шиыршық бет',
    '❤‍🔥' => 'лаулап тұрған жүрек',
    '❤‍🩹' => 'емдік жүрек',
    '👁‍🗨' => 'куәгер белгішесі',
    '🧔‍♂' => 'ер адам: сақал',
    '👱‍♂' => 'аққұба ер адам',
    '🧔‍♀' => 'әйел адам: сақал',
    '👱‍♀' => 'аққұба әйел',
    '🙍‍♂' => 'ашулы ер',
    '🙍‍♀' => 'ашулы әйел',
    '🙎‍♂' => 'ренжулі ер',
    '🙎‍♀' => 'ренжулі әйел',
    '🙅‍♂' => 'қарсымын деп тұрған ер',
    '🙅‍♀' => 'қарсымын деп тұрған әйел',
    '🙆‍♂' => 'құптап тұрған ер',
    '🙆‍♀' => 'құптап тұрған әйел',
    '💁‍♂' => 'қолын созып тұрған ер',
    '💁‍♀' => 'қолын созып тұрған әйел',
    '🙋‍♂' => 'қолын көтеріп тұрған ер',
    '🙋‍♀' => 'қолын көтеріп тұрған әйел',
    '🧏‍♂' => 'саңырау еркек',
    '🧏‍♀' => 'саңырау әйел',
    '🙇‍♂' => 'басын иіп тұрған ер',
    '🙇‍♀' => 'басын иіп тұрған әйел',
    '🤦‍♂' => 'айтуға сөз таппай тұрған ер',
    '🤦‍♀' => 'айтуға сөз таппай тұрған әйел',
    '🤷‍♂' => 'иығын көтеріп тұрған ер',
    '🤷‍♀' => 'иығын көтеріп тұрған әйел',
    '🧑‍⚕' => 'медициналық қызметкер',
    '👨‍⚕' => 'дәрігер',
    '👩‍⚕' => 'дәрігер әйел',
    '🧑‍🎓' => 'студент',
    '👨‍🎓' => 'студент бала',
    '👩‍🎓' => 'студент қыз',
    '🧑‍🏫' => 'оқытушы',
    '👨‍🏫' => 'мұғалім',
    '👩‍🏫' => 'мұғалім әйел',
    '🧑‍⚖' => 'сот',
    '👨‍⚖' => 'сот ер',
    '👩‍⚖' => 'сот әйел',
    '🧑‍🌾' => 'фермер',
    '👨‍🌾' => 'ер фермер',
    '👩‍🌾' => 'фермер әйел',
    '🧑‍🍳' => 'аспаз',
    '👨‍🍳' => 'ер аспаз',
    '👩‍🍳' => 'аспаз әйел',
    '🧑‍🔧' => 'механик',
    '👨‍🔧' => 'ер механик',
    '👩‍🔧' => 'механик әйел',
    '🧑‍🏭' => 'зауыт жұмысшысы',
    '👨‍🏭' => 'жұмысшы',
    '👩‍🏭' => 'жұмысшы әйел',
    '🧑‍💼' => 'кеңсе қызметкері',
    '👨‍💼' => 'кеңседе жұмыс істейтін қызметкер',
    '👩‍💼' => 'кеңседе жұмыс істейтін қызметкер әйел',
    '🧑‍🔬' => 'ғалым',
    '👨‍🔬' => 'ер ғалым',
    '👩‍🔬' => 'ғалым әйел',
    '🧑‍💻' => 'технолог',
    '👨‍💻' => 'ер технолог',
    '👩‍💻' => 'технолог әйел',
    '🧑‍🎤' => 'әнші',
    '👨‍🎤' => 'ер әнші',
    '👩‍🎤' => 'әнші әйел',
    '🧑‍🎨' => 'суретші',
    '👨‍🎨' => 'ер суретші',
    '👩‍🎨' => 'суретші әйел',
    '🧑‍✈' => 'пилот',
    '👨‍✈' => 'ұшқыш',
    '👩‍✈' => 'ұшқыш әйел',
    '🧑‍🚀' => 'астронавт',
    '👨‍🚀' => 'ғарышкер',
    '👩‍🚀' => 'ғарышкер әйел',
    '🧑‍🚒' => 'өрт сөндіруші',
    '👨‍🚒' => 'ер өрт сөндіруші',
    '👩‍🚒' => 'өрт сөндіруші әйел',
    '👮‍♂' => 'ер полиция қызметкері',
    '👮‍♀' => 'әйел полиция қызметкері',
    '🕵‍♂' => 'детектив ер адам',
    '🕵‍♀' => 'детектив әйел',
    '💂‍♂' => 'күзетші ер адам',
    '💂‍♀' => 'күзетші әйел',
    '👷‍♂' => 'құрылысшы ер адам',
    '👷‍♀' => 'құрылысшы әйел',
    '👳‍♂' => 'сәлделі ер адам',
    '👳‍♀' => 'сәлделі әйел',
    '🤵‍♂' => 'смокинг киген ер адам',
    '🤵‍♀' => 'смокинг киген әйел адам',
    '👰‍♂' => 'жаулық таққан ер адам',
    '👰‍♀' => 'жаулық таққан әйел',
    '👩‍🍼' => 'бала емізіп отырған әйел',
    '👨‍🍼' => 'бала емізіп отырған еркек',
    '🧑‍🍼' => 'бала емізіп отырған адам',
    '🧑‍🎄' => 'клаус мырза',
    '🦸‍♂' => 'еркек супер батыр',
    '🦸‍♀' => 'батыр әйел',
    '🦹‍♂' => 'ер супер залым',
    '🦹‍♀' => 'әйел супер залым',
    '🧙‍♂' => 'ер сиқыршы',
    '🧙‍♀' => 'әйел сиқыршы',
    '🧚‍♂' => 'ер пері',
    '🧚‍♀' => 'әйел пері',
    '🧛‍♂' => 'ер вампир',
    '🧛‍♀' => 'әйел вампир',
    '🧜‍♂' => 'құйрықты',
    '🧜‍♀' => 'су перісі',
    '🧝‍♂' => 'ер ергежейлі',
    '🧝‍♀' => 'әйел ергежейлі',
    '🧞‍♂' => 'ер жын',
    '🧞‍♀' => 'әйел жын',
    '🧟‍♂' => 'ер зомби',
    '🧟‍♀' => 'әйел зомби',
    '💆‍♂' => 'бетін уақалатып отырған ер',
    '💆‍♀' => 'бетін уақалатып отырған әйел',
    '💇‍♂' => 'шашын қидырып отырған ер',
    '💇‍♀' => 'шашын қидырып отырған әйел',
    '🚶‍♂' => 'жаяу ер',
    '🚶‍♀' => 'жаяу әйел',
    '🧍‍♂' => 'тұрып тұрған еркек',
    '🧍‍♀' => 'тұрып тұрған әйел',
    '🧎‍♂' => 'тізерлеп отырған еркек',
    '🧎‍♀' => 'тізерлеп отырған әйел',
    '🧑‍🦯' => 'таяғы бар адам',
    '👨‍🦯' => 'таяғы бар еркек',
    '👩‍🦯' => 'таяғы бар әйел',
    '🧑‍🦼' => 'моторлы арбадағы адам',
    '👨‍🦼' => 'электр жетегі бар арбашадағы еркек',
    '👩‍🦼' => 'электр жетегі бар арбашадағы әйел',
    '🧑‍🦽' => 'қол жетегі бар арбашадағы адам',
    '👨‍🦽' => 'қол жетегі бар арбашадағы еркек',
    '👩‍🦽' => 'қол жетегі бар арбашадағы әйел',
    '🏃‍♂' => 'жүгірген ер',
    '🏃‍♀' => 'жүгірген әйел',
    '🧑‍🩰' => 'балет бишісі',
    '👯‍♂' => 'тойлатып жүрген ерлер',
    '👯‍♀' => 'тойлатып жүрген әйелдер',
    '🧖‍♂' => 'бу бөлмедегі ер',
    '🧖‍♀' => 'бу бөлмедегі әйел',
    '🧗‍♂' => 'көтеріліп бара жатқан ер адам',
    '🧗‍♀' => 'көтеріліп бара жатқан әйел',
    '🏌‍♂' => 'гольф ойнаған ер',
    '🏌‍♀' => 'гольф ойнаған әйел',
    '🏄‍♂' => 'серфингші ер',
    '🏄‍♀' => 'серфингші әйел',
    '🚣‍♂' => 'қайық есуші ер',
    '🚣‍♀' => 'қайық есуші әйел',
    '🏊‍♂' => 'жүзуші ер',
    '🏊‍♀' => 'жүзуші әйел',
    '⛹‍♂' => 'доп ойнаған ер',
    '⛹‍♀' => 'доп ойнаған әйел',
    '🏋‍♂' => 'ауыр атлет ер',
    '🏋‍♀' => 'ауыр атлет әйел',
    '🚴‍♂' => 'велосипедші ер',
    '🚴‍♀' => 'велосипедші әйел',
    '🚵‍♂' => 'тау велосипедін мінген ер',
    '🚵‍♀' => 'тау велосипедін мінген әйел',
    '🤸‍♂' => 'акробат ер',
    '🤸‍♀' => 'акробат әйел',
    '🤼‍♂' => 'күресші ер',
    '🤼‍♀' => 'күресші әйел',
    '🤽‍♂' => 'су полосын ойнаған ер',
    '🤽‍♀' => 'су полосын ойнаған әйел',
    '🤾‍♂' => 'гандбол ойнаған ер',
    '🤾‍♀' => 'гандбол ойнаған әйел',
    '🤹‍♂' => 'жонглер ер',
    '🤹‍♀' => 'жонглер әйел',
    '🧘‍♂' => 'малдас құрып отырған ер адам',
    '🧘‍♀' => 'малдас құрып отырған әйел',
    '🧑‍🧒' => 'отбасы: ересек, бала',
    '🐕‍🦺' => 'көмекші ит',
    '🐈‍⬛' => 'қара мысық',
    '🐻‍❄' => 'полярлық аю',
    '🐦‍⬛' => 'ұзақ',
    '🐦‍🔥' => 'феникс',
    '🍋‍🟩' => 'лайм',
    '🍄‍🟫' => 'қоңыр саңырауқұлақ',
    '⛓‍💥' => 'үзілген шынжыр',
    '🏳‍🌈' => 'кемпірқосақ түсті ту',
    '🏳‍⚧' => 'көк, қызғылт және ақ жалау',
    '🏴‍☠' => 'қарақшы жалауы',
    '👋🏻' => 'қол бұлғау: 1–2 тері түсі',
    '👋🏼' => 'қол бұлғау: 3-тері түрі',
    '👋🏽' => 'қол бұлғау: 4-тері түсі',
    '👋🏾' => 'қол бұлғау: 5-тері түсі',
    '👋🏿' => 'қол бұлғау: 6-тері түсі',
    '🤚🏻' => 'алақан сыртын көрсету: 1–2 тері түсі',
    '🤚🏼' => 'алақан сыртын көрсету: 3-тері түрі',
    '🤚🏽' => 'алақан сыртын көрсету: 4-тері түсі',
    '🤚🏾' => 'алақан сыртын көрсету: 5-тері түсі',
    '🤚🏿' => 'алақан сыртын көрсету: 6-тері түсі',
    '🖐🏻' => 'саусақтарының арасын ашып, қолды көтеру: 1–2 тері түсі',
    '🖐🏼' => 'саусақтарының арасын ашып, қолды көтеру: 3-тері түрі',
    '🖐🏽' => 'саусақтарының арасын ашып, қолды көтеру: 4-тері түсі',
    '🖐🏾' => 'саусақтарының арасын ашып, қолды көтеру: 5-тері түсі',
    '🖐🏿' => 'саусақтарының арасын ашып, қолды көтеру: 6-тері түсі',
    '✋🏻' => 'қол көтеру: 1–2 тері түсі',
    '✋🏼' => 'қол көтеру: 3-тері түрі',
    '✋🏽' => 'қол көтеру: 4-тері түсі',
    '✋🏾' => 'қол көтеру: 5-тері түсі',
    '✋🏿' => 'қол көтеру: 6-тері түсі',
    '🖖🏻' => 'вулканша сәлемдесу: 1–2 тері түсі',
    '🖖🏼' => 'вулканша сәлемдесу: 3-тері түрі',
    '🖖🏽' => 'вулканша сәлемдесу: 4-тері түсі',
    '🖖🏾' => 'вулканша сәлемдесу: 5-тері түсі',
    '🖖🏿' => 'вулканша сәлемдесу: 6-тері түсі',
    '🫱🏻' => 'оңға қаратылған қол: 1–2 тері түсі',
    '🫱🏼' => 'оңға қаратылған қол: 3-тері түрі',
    '🫱🏽' => 'оңға қаратылған қол: 4-тері түсі',
    '🫱🏾' => 'оңға қаратылған қол: 5-тері түсі',
    '🫱🏿' => 'оңға қаратылған қол: 6-тері түсі',
    '🫲🏻' => 'солға қаратылған қол: 1–2 тері түсі',
    '🫲🏼' => 'солға қаратылған қол: 3-тері түрі',
    '🫲🏽' => 'солға қаратылған қол: 4-тері түсі',
    '🫲🏾' => 'солға қаратылған қол: 5-тері түсі',
    '🫲🏿' => 'солға қаратылған қол: 6-тері түсі',
    '🫳🏻' => 'алақанымен төмен қаратылған қол: 1–2 тері түсі',
    '🫳🏼' => 'алақанымен төмен қаратылған қол: 3-тері түрі',
    '🫳🏽' => 'алақанымен төмен қаратылған қол: 4-тері түсі',
    '🫳🏾' => 'алақанымен төмен қаратылған қол: 5-тері түсі',
    '🫳🏿' => 'алақанымен төмен қаратылған қол: 6-тері түсі',
    '🫴🏻' => 'алақанымен жоғары қаратылған қол: 1–2 тері түсі',
    '🫴🏼' => 'алақанымен жоғары қаратылған қол: 3-тері түрі',
    '🫴🏽' => 'алақанымен жоғары қаратылған қол: 4-тері түсі',
    '🫴🏾' => 'алақанымен жоғары қаратылған қол: 5-тері түсі',
    '🫴🏿' => 'алақанымен жоғары қаратылған қол: 6-тері түсі',
    '🫷🏻' => 'солға итерген қол: 1–2 тері түсі',
    '🫷🏼' => 'солға итерген қол: 3-тері түрі',
    '🫷🏽' => 'солға итерген қол: 4-тері түсі',
    '🫷🏾' => 'солға итерген қол: 5-тері түсі',
    '🫷🏿' => 'солға итерген қол: 6-тері түсі',
    '🫸🏻' => 'оңға итерген қол: 1–2 тері түсі',
    '🫸🏼' => 'оңға итерген қол: 3-тері түрі',
    '🫸🏽' => 'оңға итерген қол: 4-тері түсі',
    '🫸🏾' => 'оңға итерген қол: 5-тері түсі',
    '🫸🏿' => 'оңға итерген қол: 6-тері түсі',
    '👌🏻' => 'ОК: 1–2 тері түсі',
    '👌🏼' => 'ОК: 3-тері түрі',
    '👌🏽' => 'ОК: 4-тері түсі',
    '👌🏾' => 'ОК: 5-тері түсі',
    '👌🏿' => 'ОК: 6-тері түсі',
    '🤌🏻' => 'түйістірілген бес саусақ: 1–2 тері түсі',
    '🤌🏼' => 'түйістірілген бес саусақ: 3-тері түрі',
    '🤌🏽' => 'түйістірілген бес саусақ: 4-тері түсі',
    '🤌🏾' => 'түйістірілген бес саусақ: 5-тері түсі',
    '🤌🏿' => 'түйістірілген бес саусақ: 6-тері түсі',
    '🤏🏻' => 'саусақпен қысып алу: 1–2 тері түсі',
    '🤏🏼' => 'саусақпен қысып алу: 3-тері түрі',
    '🤏🏽' => 'саусақпен қысып алу: 4-тері түсі',
    '🤏🏾' => 'саусақпен қысып алу: 5-тері түсі',
    '🤏🏿' => 'саусақпен қысып алу: 6-тері түсі',
    '✌🏻' => 'саусақтармен «V» әрпін көрсету: 1–2 тері түсі',
    '✌🏼' => 'саусақтармен «V» әрпін көрсету: 3-тері түрі',
    '✌🏽' => 'саусақтармен «V» әрпін көрсету: 4-тері түсі',
    '✌🏾' => 'саусақтармен «V» әрпін көрсету: 5-тері түсі',
    '✌🏿' => 'саусақтармен «V» әрпін көрсету: 6-тері түсі',
    '🤞🏻' => 'саусақтарын айқастырған: 1–2 тері түсі',
    '🤞🏼' => 'саусақтарын айқастырған: 3-тері түрі',
    '🤞🏽' => 'саусақтарын айқастырған: 4-тері түсі',
    '🤞🏾' => 'саусақтарын айқастырған: 5-тері түсі',
    '🤞🏿' => 'саусақтарын айқастырған: 6-тері түсі',
    '🫰🏻' => 'бас бармақ пен сұқ саусақ айқастырылған қол: 1–2 тері түсі',
    '🫰🏼' => 'бас бармақ пен сұқ саусақ айқастырылған қол: 3-тері түрі',
    '🫰🏽' => 'бас бармақ пен сұқ саусақ айқастырылған қол: 4-тері түсі',
    '🫰🏾' => 'бас бармақ пен сұқ саусақ айқастырылған қол: 5-тері түсі',
    '🫰🏿' => 'бас бармақ пен сұқ саусақ айқастырылған қол: 6-тері түсі',
    '🤟🏻' => 'сені сүйемін белгісі: 1–2 тері түсі',
    '🤟🏼' => 'сені сүйемін белгісі: 3-тері түрі',
    '🤟🏽' => 'сені сүйемін белгісі: 4-тері түсі',
    '🤟🏾' => 'сені сүйемін белгісі: 5-тері түсі',
    '🤟🏿' => 'сені сүйемін белгісі: 6-тері түсі',
    '🤘🏻' => 'мүйіз белгісі: 1–2 тері түсі',
    '🤘🏼' => 'мүйіз белгісі: 3-тері түрі',
    '🤘🏽' => 'мүйіз белгісі: 4-тері түсі',
    '🤘🏾' => 'мүйіз белгісі: 5-тері түсі',
    '🤘🏿' => 'мүйіз белгісі: 6-тері түсі',
    '🤙🏻' => 'хабарлас: 1–2 тері түсі',
    '🤙🏼' => 'хабарлас: 3-тері түрі',
    '🤙🏽' => 'хабарлас: 4-тері түсі',
    '🤙🏾' => 'хабарлас: 5-тері түсі',
    '🤙🏿' => 'хабарлас: 6-тері түсі',
    '👈🏻' => 'сол жаққа саусақпен қолды сыртқа қаратып көрсету: 1–2 тері түсі',
    '👈🏼' => 'сол жаққа саусақпен қолды сыртқа қаратып көрсету: 3-тері түрі',
    '👈🏽' => 'сол жаққа саусақпен қолды сыртқа қаратып көрсету: 4-тері түсі',
    '👈🏾' => 'сол жаққа саусақпен қолды сыртқа қаратып көрсету: 5-тері түсі',
    '👈🏿' => 'сол жаққа саусақпен қолды сыртқа қаратып көрсету: 6-тері түсі',
    '👉🏻' => 'оң жаққа саусақпен қолды сыртқа қаратып көрсету: 1–2 тері түсі',
    '👉🏼' => 'оң жаққа саусақпен қолды сыртқа қаратып көрсету: 3-тері түрі',
    '👉🏽' => 'оң жаққа саусақпен қолды сыртқа қаратып көрсету: 4-тері түсі',
    '👉🏾' => 'оң жаққа саусақпен қолды сыртқа қаратып көрсету: 5-тері түсі',
    '👉🏿' => 'оң жаққа саусақпен қолды сыртқа қаратып көрсету: 6-тері түсі',
    '👆🏻' => 'жоғары саусақпен қолды сыртқа қаратып көрсету: 1–2 тері түсі',
    '👆🏼' => 'жоғары саусақпен қолды сыртқа қаратып көрсету: 3-тері түрі',
    '👆🏽' => 'жоғары саусақпен қолды сыртқа қаратып көрсету: 4-тері түсі',
    '👆🏾' => 'жоғары саусақпен қолды сыртқа қаратып көрсету: 5-тері түсі',
    '👆🏿' => 'жоғары саусақпен қолды сыртқа қаратып көрсету: 6-тері түсі',
    '🖕🏻' => 'ортаңғы саусақ: 1–2 тері түсі',
    '🖕🏼' => 'ортаңғы саусақ: 3-тері түрі',
    '🖕🏽' => 'ортаңғы саусақ: 4-тері түсі',
    '🖕🏾' => 'ортаңғы саусақ: 5-тері түсі',
    '🖕🏿' => 'ортаңғы саусақ: 6-тері түсі',
    '👇🏻' => 'төмен саусақпен қолды сыртқа қаратып көрсету: 1–2 тері түсі',
    '👇🏼' => 'төмен саусақпен қолды сыртқа қаратып көрсету: 3-тері түрі',
    '👇🏽' => 'төмен саусақпен қолды сыртқа қаратып көрсету: 4-тері түсі',
    '👇🏾' => 'төмен саусақпен қолды сыртқа қаратып көрсету: 5-тері түсі',
    '👇🏿' => 'төмен саусақпен қолды сыртқа қаратып көрсету: 6-тері түсі',
    '☝🏻' => 'жоғарыға саусақпен көрсету: 1–2 тері түсі',
    '☝🏼' => 'жоғарыға саусақпен көрсету: 3-тері түрі',
    '☝🏽' => 'жоғарыға саусақпен көрсету: 4-тері түсі',
    '☝🏾' => 'жоғарыға саусақпен көрсету: 5-тері түсі',
    '☝🏿' => 'жоғарыға саусақпен көрсету: 6-тері түсі',
    '🫵🏻' => 'тіке қаратылған қол: 1–2 тері түсі',
    '🫵🏼' => 'тіке қаратылған қол: 3-тері түрі',
    '🫵🏽' => 'тіке қаратылған қол: 4-тері түсі',
    '🫵🏾' => 'тіке қаратылған қол: 5-тері түсі',
    '🫵🏿' => 'тіке қаратылған қол: 6-тері түсі',
    '👍🏻' => 'тамаша: 1–2 тері түсі',
    '👍🏼' => 'тамаша: 3-тері түрі',
    '👍🏽' => 'тамаша: 4-тері түсі',
    '👍🏾' => 'тамаша: 5-тері түсі',
    '👍🏿' => 'тамаша: 6-тері түсі',
    '👎🏻' => 'нашар: 1–2 тері түсі',
    '👎🏼' => 'нашар: 3-тері түрі',
    '👎🏽' => 'нашар: 4-тері түсі',
    '👎🏾' => 'нашар: 5-тері түсі',
    '👎🏿' => 'нашар: 6-тері түсі',
    '✊🏻' => 'жұдырық көтеру: 1–2 тері түсі',
    '✊🏼' => 'жұдырық көтеру: 3-тері түрі',
    '✊🏽' => 'жұдырық көтеру: 4-тері түсі',
    '✊🏾' => 'жұдырық көтеру: 5-тері түсі',
    '✊🏿' => 'жұдырық көтеру: 6-тері түсі',
    '👊🏻' => 'жұдырық: 1–2 тері түсі',
    '👊🏼' => 'жұдырық: 3-тері түрі',
    '👊🏽' => 'жұдырық: 4-тері түсі',
    '👊🏾' => 'жұдырық: 5-тері түсі',
    '👊🏿' => 'жұдырық: 6-тері түсі',
    '🤛🏻' => 'солға қаратылған жұдырық: 1–2 тері түсі',
    '🤛🏼' => 'солға қаратылған жұдырық: 3-тері түрі',
    '🤛🏽' => 'солға қаратылған жұдырық: 4-тері түсі',
    '🤛🏾' => 'солға қаратылған жұдырық: 5-тері түсі',
    '🤛🏿' => 'солға қаратылған жұдырық: 6-тері түсі',
    '🤜🏻' => 'оңға қаратылған жұдырық: 1–2 тері түсі',
    '🤜🏼' => 'оңға қаратылған жұдырық: 3-тері түрі',
    '🤜🏽' => 'оңға қаратылған жұдырық: 4-тері түсі',
    '🤜🏾' => 'оңға қаратылған жұдырық: 5-тері түсі',
    '🤜🏿' => 'оңға қаратылған жұдырық: 6-тері түсі',
    '👏🏻' => 'шапалақтау: 1–2 тері түсі',
    '👏🏼' => 'шапалақтау: 3-тері түрі',
    '👏🏽' => 'шапалақтау: 4-тері түсі',
    '👏🏾' => 'шапалақтау: 5-тері түсі',
    '👏🏿' => 'шапалақтау: 6-тері түсі',
    '🙌🏻' => 'қолдарды көтеру: 1–2 тері түсі',
    '🙌🏼' => 'қолдарды көтеру: 3-тері түрі',
    '🙌🏽' => 'қолдарды көтеру: 4-тері түсі',
    '🙌🏾' => 'қолдарды көтеру: 5-тері түсі',
    '🙌🏿' => 'қолдарды көтеру: 6-тері түсі',
    '🫶🏻' => 'жұректі көрсетіп тұрған қолдар: 1–2 тері түсі',
    '🫶🏼' => 'жұректі көрсетіп тұрған қолдар: 3-тері түрі',
    '🫶🏽' => 'жұректі көрсетіп тұрған қолдар: 4-тері түсі',
    '🫶🏾' => 'жұректі көрсетіп тұрған қолдар: 5-тері түсі',
    '🫶🏿' => 'жұректі көрсетіп тұрған қолдар: 6-тері түсі',
    '👐🏻' => 'алақанды көрсету: 1–2 тері түсі',
    '👐🏼' => 'алақанды көрсету: 3-тері түрі',
    '👐🏽' => 'алақанды көрсету: 4-тері түсі',
    '👐🏾' => 'алақанды көрсету: 5-тері түсі',
    '👐🏿' => 'алақанды көрсету: 6-тері түсі',
    '🤲🏻' => 'алақандарын көтеру: 1–2 тері түсі',
    '🤲🏼' => 'алақандарын көтеру: 3-тері түрі',
    '🤲🏽' => 'алақандарын көтеру: 4-тері түсі',
    '🤲🏾' => 'алақандарын көтеру: 5-тері түсі',
    '🤲🏿' => 'алақандарын көтеру: 6-тері түсі',
    '🤝🏻' => 'қол алысу: 1–2 тері түсі',
    '🤝🏼' => 'қол алысу: 3-тері түрі',
    '🤝🏽' => 'қол алысу: 4-тері түсі',
    '🤝🏾' => 'қол алысу: 5-тері түсі',
    '🤝🏿' => 'қол алысу: 6-тері түсі',
    '🙏🏻' => 'қолды түйістіру: 1–2 тері түсі',
    '🙏🏼' => 'қолды түйістіру: 3-тері түрі',
    '🙏🏽' => 'қолды түйістіру: 4-тері түсі',
    '🙏🏾' => 'қолды түйістіру: 5-тері түсі',
    '🙏🏿' => 'қолды түйістіру: 6-тері түсі',
    '✍🏻' => 'қолмен жазу: 1–2 тері түсі',
    '✍🏼' => 'қолмен жазу: 3-тері түрі',
    '✍🏽' => 'қолмен жазу: 4-тері түсі',
    '✍🏾' => 'қолмен жазу: 5-тері түсі',
    '✍🏿' => 'қолмен жазу: 6-тері түсі',
    '💅🏻' => 'маникюр: 1–2 тері түсі',
    '💅🏼' => 'маникюр: 3-тері түрі',
    '💅🏽' => 'маникюр: 4-тері түсі',
    '💅🏾' => 'маникюр: 5-тері түсі',
    '💅🏿' => 'маникюр: 6-тері түсі',
    '🤳🏻' => 'селфи: 1–2 тері түсі',
    '🤳🏼' => 'селфи: 3-тері түрі',
    '🤳🏽' => 'селфи: 4-тері түсі',
    '🤳🏾' => 'селфи: 5-тері түсі',
    '🤳🏿' => 'селфи: 6-тері түсі',
    '💪🏻' => 'бицепс: 1–2 тері түсі',
    '💪🏼' => 'бицепс: 3-тері түрі',
    '💪🏽' => 'бицепс: 4-тері түсі',
    '💪🏾' => 'бицепс: 5-тері түсі',
    '💪🏿' => 'бицепс: 6-тері түсі',
    '🦵🏻' => 'аяқ: 1–2 тері түсі',
    '🦵🏼' => 'аяқ: 3-тері түрі',
    '🦵🏽' => 'аяқ: 4-тері түсі',
    '🦵🏾' => 'аяқ: 5-тері түсі',
    '🦵🏿' => 'аяқ: 6-тері түсі',
    '🦶🏻' => 'табан: 1–2 тері түсі',
    '🦶🏼' => 'табан: 3-тері түрі',
    '🦶🏽' => 'табан: 4-тері түсі',
    '🦶🏾' => 'табан: 5-тері түсі',
    '🦶🏿' => 'табан: 6-тері түсі',
    '👂🏻' => 'құлақ: 1–2 тері түсі',
    '👂🏼' => 'құлақ: 3-тері түрі',
    '👂🏽' => 'құлақ: 4-тері түсі',
    '👂🏾' => 'құлақ: 5-тері түсі',
    '👂🏿' => 'құлақ: 6-тері түсі',
    '🦻🏻' => 'есту аппараты бар құлақ: 1–2 тері түсі',
    '🦻🏼' => 'есту аппараты бар құлақ: 3-тері түрі',
    '🦻🏽' => 'есту аппараты бар құлақ: 4-тері түсі',
    '🦻🏾' => 'есту аппараты бар құлақ: 5-тері түсі',
    '🦻🏿' => 'есту аппараты бар құлақ: 6-тері түсі',
    '👃🏻' => 'мұрын: 1–2 тері түсі',
    '👃🏼' => 'мұрын: 3-тері түрі',
    '👃🏽' => 'мұрын: 4-тері түсі',
    '👃🏾' => 'мұрын: 5-тері түсі',
    '👃🏿' => 'мұрын: 6-тері түсі',
    '👶🏻' => 'сәби: 1–2 тері түсі',
    '👶🏼' => 'сәби: 3-тері түрі',
    '👶🏽' => 'сәби: 4-тері түсі',
    '👶🏾' => 'сәби: 5-тері түсі',
    '👶🏿' => 'сәби: 6-тері түсі',
    '🧒🏻' => 'бала: 1–2 тері түсі',
    '🧒🏼' => 'бала: 3-тері түрі',
    '🧒🏽' => 'бала: 4-тері түсі',
    '🧒🏾' => 'бала: 5-тері түсі',
    '🧒🏿' => 'бала: 6-тері түсі',
    '👦🏻' => 'ұл: 1–2 тері түсі',
    '👦🏼' => 'ұл: 3-тері түрі',
    '👦🏽' => 'ұл: 4-тері түсі',
    '👦🏾' => 'ұл: 5-тері түсі',
    '👦🏿' => 'ұл: 6-тері түсі',
    '👧🏻' => 'қыз: 1–2 тері түсі',
    '👧🏼' => 'қыз: 3-тері түрі',
    '👧🏽' => 'қыз: 4-тері түсі',
    '👧🏾' => 'қыз: 5-тері түсі',
    '👧🏿' => 'қыз: 6-тері түсі',
    '🧑🏻' => 'адам: 1–2 тері түсі',
    '🧑🏼' => 'адам: 3-тері түрі',
    '🧑🏽' => 'адам: 4-тері түсі',
    '🧑🏾' => 'адам: 5-тері түсі',
    '🧑🏿' => 'адам: 6-тері түсі',
    '👱🏻' => 'аққұба адам: 1–2 тері түсі',
    '👱🏼' => 'аққұба адам: 3-тері түрі',
    '👱🏽' => 'аққұба адам: 4-тері түсі',
    '👱🏾' => 'аққұба адам: 5-тері түсі',
    '👱🏿' => 'аққұба адам: 6-тері түсі',
    '👨🏻' => 'ер адам: 1–2 тері түсі',
    '👨🏼' => 'ер адам: 3-тері түрі',
    '👨🏽' => 'ер адам: 4-тері түсі',
    '👨🏾' => 'ер адам: 5-тері түсі',
    '👨🏿' => 'ер адам: 6-тері түсі',
    '🧔🏻' => 'сақалды ер адам: 1–2 тері түсі',
    '🧔🏼' => 'сақалды ер адам: 3-тері түрі',
    '🧔🏽' => 'сақалды ер адам: 4-тері түсі',
    '🧔🏾' => 'сақалды ер адам: 5-тері түсі',
    '🧔🏿' => 'сақалды ер адам: 6-тері түсі',
    '👩🏻' => 'әйел: 1–2 тері түсі',
    '👩🏼' => 'әйел: 3-тері түрі',
    '👩🏽' => 'әйел: 4-тері түсі',
    '👩🏾' => 'әйел: 5-тері түсі',
    '👩🏿' => 'әйел: 6-тері түсі',
    '🧓🏻' => 'қарт адам: 1–2 тері түсі',
    '🧓🏼' => 'қарт адам: 3-тері түрі',
    '🧓🏽' => 'қарт адам: 4-тері түсі',
    '🧓🏾' => 'қарт адам: 5-тері түсі',
    '🧓🏿' => 'қарт адам: 6-тері түсі',
    '👴🏻' => 'қарт: 1–2 тері түсі',
    '👴🏼' => 'қарт: 3-тері түрі',
    '👴🏽' => 'қарт: 4-тері түсі',
    '👴🏾' => 'қарт: 5-тері түсі',
    '👴🏿' => 'қарт: 6-тері түсі',
    '👵🏻' => 'қарт әйел: 1–2 тері түсі',
    '👵🏼' => 'қарт әйел: 3-тері түрі',
    '👵🏽' => 'қарт әйел: 4-тері түсі',
    '👵🏾' => 'қарт әйел: 5-тері түсі',
    '👵🏿' => 'қарт әйел: 6-тері түсі',
    '🙍🏻' => 'қабағын түю: 1–2 тері түсі',
    '🙍🏼' => 'қабағын түю: 3-тері түрі',
    '🙍🏽' => 'қабағын түю: 4-тері түсі',
    '🙍🏾' => 'қабағын түю: 5-тері түсі',
    '🙍🏿' => 'қабағын түю: 6-тері түсі',
    '🙎🏻' => 'беті бұртию: 1–2 тері түсі',
    '🙎🏼' => 'беті бұртию: 3-тері түрі',
    '🙎🏽' => 'беті бұртию: 4-тері түсі',
    '🙎🏾' => 'беті бұртию: 5-тері түсі',
    '🙎🏿' => 'беті бұртию: 6-тері түсі',
    '🙅🏻' => 'жоқ: 1–2 тері түсі',
    '🙅🏼' => 'жоқ: 3-тері түрі',
    '🙅🏽' => 'жоқ: 4-тері түсі',
    '🙅🏾' => 'жоқ: 5-тері түсі',
    '🙅🏿' => 'жоқ: 6-тері түсі',
    '🙆🏻' => 'жарайды: 1–2 тері түсі',
    '🙆🏼' => 'жарайды: 3-тері түрі',
    '🙆🏽' => 'жарайды: 4-тері түсі',
    '🙆🏾' => 'жарайды: 5-тері түсі',
    '🙆🏿' => 'жарайды: 6-тері түсі',
    '💁🏻' => 'ақпарат орталығы: 1–2 тері түсі',
    '💁🏼' => 'ақпарат орталығы: 3-тері түрі',
    '💁🏽' => 'ақпарат орталығы: 4-тері түсі',
    '💁🏾' => 'ақпарат орталығы: 5-тері түсі',
    '💁🏿' => 'ақпарат орталығы: 6-тері түсі',
    '🙋🏻' => 'қолды көтеру: 1–2 тері түсі',
    '🙋🏼' => 'қолды көтеру: 3-тері түрі',
    '🙋🏽' => 'қолды көтеру: 4-тері түсі',
    '🙋🏾' => 'қолды көтеру: 5-тері түсі',
    '🙋🏿' => 'қолды көтеру: 6-тері түсі',
    '🧏🏻' => 'саңырау адам: 1–2 тері түсі',
    '🧏🏼' => 'саңырау адам: 3-тері түрі',
    '🧏🏽' => 'саңырау адам: 4-тері түсі',
    '🧏🏾' => 'саңырау адам: 5-тері түсі',
    '🧏🏿' => 'саңырау адам: 6-тері түсі',
    '🙇🏻' => 'иілген адам: 1–2 тері түсі',
    '🙇🏼' => 'иілген адам: 3-тері түрі',
    '🙇🏽' => 'иілген адам: 4-тері түсі',
    '🙇🏾' => 'иілген адам: 5-тері түсі',
    '🙇🏿' => 'иілген адам: 6-тері түсі',
    '🤦🏻' => 'бетін қолмен жапқан адам: 1–2 тері түсі',
    '🤦🏼' => 'бетін қолмен жапқан адам: 3-тері түрі',
    '🤦🏽' => 'бетін қолмен жапқан адам: 4-тері түсі',
    '🤦🏾' => 'бетін қолмен жапқан адам: 5-тері түсі',
    '🤦🏿' => 'бетін қолмен жапқан адам: 6-тері түсі',
    '🤷🏻' => 'білмегендік белгісі: 1–2 тері түсі',
    '🤷🏼' => 'білмегендік белгісі: 3-тері түрі',
    '🤷🏽' => 'білмегендік белгісі: 4-тері түсі',
    '🤷🏾' => 'білмегендік белгісі: 5-тері түсі',
    '🤷🏿' => 'білмегендік белгісі: 6-тері түсі',
    '👮🏻' => 'полиция қызметкері: 1–2 тері түсі',
    '👮🏼' => 'полиция қызметкері: 3-тері түрі',
    '👮🏽' => 'полиция қызметкері: 4-тері түсі',
    '👮🏾' => 'полиция қызметкері: 5-тері түсі',
    '👮🏿' => 'полиция қызметкері: 6-тері түсі',
    '🕵🏻' => 'детектив: 1–2 тері түсі',
    '🕵🏼' => 'детектив: 3-тері түрі',
    '🕵🏽' => 'детектив: 4-тері түсі',
    '🕵🏾' => 'детектив: 5-тері түсі',
    '🕵🏿' => 'детектив: 6-тері түсі',
    '💂🏻' => 'күзетші: 1–2 тері түсі',
    '💂🏼' => 'күзетші: 3-тері түрі',
    '💂🏽' => 'күзетші: 4-тері түсі',
    '💂🏾' => 'күзетші: 5-тері түсі',
    '💂🏿' => 'күзетші: 6-тері түсі',
    '🥷🏻' => 'ниндзя: 1–2 тері түсі',
    '🥷🏼' => 'ниндзя: 3-тері түрі',
    '🥷🏽' => 'ниндзя: 4-тері түсі',
    '🥷🏾' => 'ниндзя: 5-тері түсі',
    '🥷🏿' => 'ниндзя: 6-тері түсі',
    '👷🏻' => 'құрылысшы: 1–2 тері түсі',
    '👷🏼' => 'құрылысшы: 3-тері түрі',
    '👷🏽' => 'құрылысшы: 4-тері түсі',
    '👷🏾' => 'құрылысшы: 5-тері түсі',
    '👷🏿' => 'құрылысшы: 6-тері түсі',
    '🫅🏻' => 'тәж таққан адам: 1–2 тері түсі',
    '🫅🏼' => 'тәж таққан адам: 3-тері түрі',
    '🫅🏽' => 'тәж таққан адам: 4-тері түсі',
    '🫅🏾' => 'тәж таққан адам: 5-тері түсі',
    '🫅🏿' => 'тәж таққан адам: 6-тері түсі',
    '🤴🏻' => 'ханзада: 1–2 тері түсі',
    '🤴🏼' => 'ханзада: 3-тері түрі',
    '🤴🏽' => 'ханзада: 4-тері түсі',
    '🤴🏾' => 'ханзада: 5-тері түсі',
    '🤴🏿' => 'ханзада: 6-тері түсі',
    '👸🏻' => 'ханшайым: 1–2 тері түсі',
    '👸🏼' => 'ханшайым: 3-тері түрі',
    '👸🏽' => 'ханшайым: 4-тері түсі',
    '👸🏾' => 'ханшайым: 5-тері түсі',
    '👸🏿' => 'ханшайым: 6-тері түсі',
    '👳🏻' => 'сәлделі адам: 1–2 тері түсі',
    '👳🏼' => 'сәлделі адам: 3-тері түрі',
    '👳🏽' => 'сәлделі адам: 4-тері түсі',
    '👳🏾' => 'сәлделі адам: 5-тері түсі',
    '👳🏿' => 'сәлделі адам: 6-тері түсі',
    '👲🏻' => 'қытай қалпағын киген адам: 1–2 тері түсі',
    '👲🏼' => 'қытай қалпағын киген адам: 3-тері түрі',
    '👲🏽' => 'қытай қалпағын киген адам: 4-тері түсі',
    '👲🏾' => 'қытай қалпағын киген адам: 5-тері түсі',
    '👲🏿' => 'қытай қалпағын киген адам: 6-тері түсі',
    '🧕🏻' => 'орамал таққан әйел: 1–2 тері түсі',
    '🧕🏼' => 'орамал таққан әйел: 3-тері түрі',
    '🧕🏽' => 'орамал таққан әйел: 4-тері түсі',
    '🧕🏾' => 'орамал таққан әйел: 5-тері түсі',
    '🧕🏿' => 'орамал таққан әйел: 6-тері түсі',
    '🤵🏻' => 'смокинг киген адам: 1–2 тері түсі',
    '🤵🏼' => 'смокинг киген адам: 3-тері түрі',
    '🤵🏽' => 'смокинг киген адам: 4-тері түсі',
    '🤵🏾' => 'смокинг киген адам: 5-тері түсі',
    '🤵🏿' => 'смокинг киген адам: 6-тері түсі',
    '👰🏻' => 'қалыңдық: 1–2 тері түсі',
    '👰🏼' => 'қалыңдық: 3-тері түрі',
    '👰🏽' => 'қалыңдық: 4-тері түсі',
    '👰🏾' => 'қалыңдық: 5-тері түсі',
    '👰🏿' => 'қалыңдық: 6-тері түсі',
    '🤰🏻' => 'екіқабат әйел: 1–2 тері түсі',
    '🤰🏼' => 'екіқабат әйел: 3-тері түрі',
    '🤰🏽' => 'екіқабат әйел: 4-тері түсі',
    '🤰🏾' => 'екіқабат әйел: 5-тері түсі',
    '🤰🏿' => 'екіқабат әйел: 6-тері түсі',
    '🫃🏻' => 'жүкті ер адам: 1–2 тері түсі',
    '🫃🏼' => 'жүкті ер адам: 3-тері түрі',
    '🫃🏽' => 'жүкті ер адам: 4-тері түсі',
    '🫃🏾' => 'жүкті ер адам: 5-тері түсі',
    '🫃🏿' => 'жүкті ер адам: 6-тері түсі',
    '🫄🏻' => 'жүкті адам: 1–2 тері түсі',
    '🫄🏼' => 'жүкті адам: 3-тері түрі',
    '🫄🏽' => 'жүкті адам: 4-тері түсі',
    '🫄🏾' => 'жүкті адам: 5-тері түсі',
    '🫄🏿' => 'жүкті адам: 6-тері түсі',
    '🤱🏻' => 'бала емізу: 1–2 тері түсі',
    '🤱🏼' => 'бала емізу: 3-тері түрі',
    '🤱🏽' => 'бала емізу: 4-тері түсі',
    '🤱🏾' => 'бала емізу: 5-тері түсі',
    '🤱🏿' => 'бала емізу: 6-тері түсі',
    '👼🏻' => 'кішкентай періште: 1–2 тері түсі',
    '👼🏼' => 'кішкентай періште: 3-тері түрі',
    '👼🏽' => 'кішкентай періште: 4-тері түсі',
    '👼🏾' => 'кішкентай періште: 5-тері түсі',
    '👼🏿' => 'кішкентай періште: 6-тері түсі',
    '🎅🏻' => 'санта клаус: 1–2 тері түсі',
    '🎅🏼' => 'санта клаус: 3-тері түрі',
    '🎅🏽' => 'санта клаус: 4-тері түсі',
    '🎅🏾' => 'санта клаус: 5-тері түсі',
    '🎅🏿' => 'санта клаус: 6-тері түсі',
    '🤶🏻' => 'ақшақар: 1–2 тері түсі',
    '🤶🏼' => 'ақшақар: 3-тері түрі',
    '🤶🏽' => 'ақшақар: 4-тері түсі',
    '🤶🏾' => 'ақшақар: 5-тері түсі',
    '🤶🏿' => 'ақшақар: 6-тері түсі',
    '🦸🏻' => 'супер батыр: 1–2 тері түсі',
    '🦸🏼' => 'супер батыр: 3-тері түрі',
    '🦸🏽' => 'супер батыр: 4-тері түсі',
    '🦸🏾' => 'супер батыр: 5-тері түсі',
    '🦸🏿' => 'супер батыр: 6-тері түсі',
    '🦹🏻' => 'супер зұлым: 1–2 тері түсі',
    '🦹🏼' => 'супер зұлым: 3-тері түрі',
    '🦹🏽' => 'супер зұлым: 4-тері түсі',
    '🦹🏾' => 'супер зұлым: 5-тері түсі',
    '🦹🏿' => 'супер зұлым: 6-тері түсі',
    '🧙🏻' => 'сиқыршы: 1–2 тері түсі',
    '🧙🏼' => 'сиқыршы: 3-тері түрі',
    '🧙🏽' => 'сиқыршы: 4-тері түсі',
    '🧙🏾' => 'сиқыршы: 5-тері түсі',
    '🧙🏿' => 'сиқыршы: 6-тері түсі',
    '🧚🏻' => 'пері: 1–2 тері түсі',
    '🧚🏼' => 'пері: 3-тері түрі',
    '🧚🏽' => 'пері: 4-тері түсі',
    '🧚🏾' => 'пері: 5-тері түсі',
    '🧚🏿' => 'пері: 6-тері түсі',
    '🧛🏻' => 'вампир: 1–2 тері түсі',
    '🧛🏼' => 'вампир: 3-тері түрі',
    '🧛🏽' => 'вампир: 4-тері түсі',
    '🧛🏾' => 'вампир: 5-тері түсі',
    '🧛🏿' => 'вампир: 6-тері түсі',
    '🧜🏻' => 'теңіз тұрғыны: 1–2 тері түсі',
    '🧜🏼' => 'теңіз тұрғыны: 3-тері түрі',
    '🧜🏽' => 'теңіз тұрғыны: 4-тері түсі',
    '🧜🏾' => 'теңіз тұрғыны: 5-тері түсі',
    '🧜🏿' => 'теңіз тұрғыны: 6-тері түсі',
    '🧝🏻' => 'эльф: 1–2 тері түсі',
    '🧝🏼' => 'эльф: 3-тері түрі',
    '🧝🏽' => 'эльф: 4-тері түсі',
    '🧝🏾' => 'эльф: 5-тері түсі',
    '🧝🏿' => 'эльф: 6-тері түсі',
    '💆🏻' => 'бетке массаж жасау: 1–2 тері түсі',
    '💆🏼' => 'бетке массаж жасау: 3-тері түрі',
    '💆🏽' => 'бетке массаж жасау: 4-тері түсі',
    '💆🏾' => 'бетке массаж жасау: 5-тері түсі',
    '💆🏿' => 'бетке массаж жасау: 6-тері түсі',
    '💇🏻' => 'шаш қидыру: 1–2 тері түсі',
    '💇🏼' => 'шаш қидыру: 3-тері түрі',
    '💇🏽' => 'шаш қидыру: 4-тері түсі',
    '💇🏾' => 'шаш қидыру: 5-тері түсі',
    '💇🏿' => 'шаш қидыру: 6-тері түсі',
    '🚶🏻' => 'жаяу: 1–2 тері түсі',
    '🚶🏼' => 'жаяу: 3-тері түрі',
    '🚶🏽' => 'жаяу: 4-тері түсі',
    '🚶🏾' => 'жаяу: 5-тері түсі',
    '🚶🏿' => 'жаяу: 6-тері түсі',
    '🧍🏻' => 'тұрып тұрған адам: 1–2 тері түсі',
    '🧍🏼' => 'тұрып тұрған адам: 3-тері түрі',
    '🧍🏽' => 'тұрып тұрған адам: 4-тері түсі',
    '🧍🏾' => 'тұрып тұрған адам: 5-тері түсі',
    '🧍🏿' => 'тұрып тұрған адам: 6-тері түсі',
    '🧎🏻' => 'тізерлеп отырған адам: 1–2 тері түсі',
    '🧎🏼' => 'тізерлеп отырған адам: 3-тері түрі',
    '🧎🏽' => 'тізерлеп отырған адам: 4-тері түсі',
    '🧎🏾' => 'тізерлеп отырған адам: 5-тері түсі',
    '🧎🏿' => 'тізерлеп отырған адам: 6-тері түсі',
    '🏃🏻' => 'жүгіру: 1–2 тері түсі',
    '🏃🏼' => 'жүгіру: 3-тері түрі',
    '🏃🏽' => 'жүгіру: 4-тері түсі',
    '🏃🏾' => 'жүгіру: 5-тері түсі',
    '🏃🏿' => 'жүгіру: 6-тері түсі',
    '💃🏻' => 'билеген әйел: 1–2 тері түсі',
    '💃🏼' => 'билеген әйел: 3-тері түрі',
    '💃🏽' => 'билеген әйел: 4-тері түсі',
    '💃🏾' => 'билеген әйел: 5-тері түсі',
    '💃🏿' => 'билеген әйел: 6-тері түсі',
    '🕺🏻' => 'билеп тұрған ер адам: 1–2 тері түсі',
    '🕺🏼' => 'билеп тұрған ер адам: 3-тері түрі',
    '🕺🏽' => 'билеп тұрған ер адам: 4-тері түсі',
    '🕺🏾' => 'билеп тұрған ер адам: 5-тері түсі',
    '🕺🏿' => 'билеп тұрған ер адам: 6-тері түсі',
    '🕴🏻' => 'ауада қалқып тұрған іскер: 1–2 тері түсі',
    '🕴🏼' => 'ауада қалқып тұрған іскер: 3-тері түрі',
    '🕴🏽' => 'ауада қалқып тұрған іскер: 4-тері түсі',
    '🕴🏾' => 'ауада қалқып тұрған іскер: 5-тері түсі',
    '🕴🏿' => 'ауада қалқып тұрған іскер: 6-тері түсі',
    '👯🏻' => 'билеп жатқан әйелдер: 1–2 тері түсі',
    '👯🏼' => 'билеп жатқан әйелдер: 3-тері түрі',
    '👯🏽' => 'билеп жатқан әйелдер: 4-тері түсі',
    '👯🏾' => 'билеп жатқан әйелдер: 5-тері түсі',
    '👯🏿' => 'билеп жатқан әйелдер: 6-тері түсі',
    '🧖🏻' => 'бу бөлмедегі адам: 1–2 тері түсі',
    '🧖🏼' => 'бу бөлмедегі адам: 3-тері түрі',
    '🧖🏽' => 'бу бөлмедегі адам: 4-тері түсі',
    '🧖🏾' => 'бу бөлмедегі адам: 5-тері түсі',
    '🧖🏿' => 'бу бөлмедегі адам: 6-тері түсі',
    '🧗🏻' => 'өрмелеп бара жатқан адам: 1–2 тері түсі',
    '🧗🏼' => 'өрмелеп бара жатқан адам: 3-тері түрі',
    '🧗🏽' => 'өрмелеп бара жатқан адам: 4-тері түсі',
    '🧗🏾' => 'өрмелеп бара жатқан адам: 5-тері түсі',
    '🧗🏿' => 'өрмелеп бара жатқан адам: 6-тері түсі',
    '🏇🏻' => 'атшабар: 1–2 тері түсі',
    '🏇🏼' => 'атшабар: 3-тері түрі',
    '🏇🏽' => 'атшабар: 4-тері түсі',
    '🏇🏾' => 'атшабар: 5-тері түсі',
    '🏇🏿' => 'атшабар: 6-тері түсі',
    '🏂🏻' => 'сноубордшы: 1–2 тері түсі',
    '🏂🏼' => 'сноубордшы: 3-тері түрі',
    '🏂🏽' => 'сноубордшы: 4-тері түсі',
    '🏂🏾' => 'сноубордшы: 5-тері түсі',
    '🏂🏿' => 'сноубордшы: 6-тері түсі',
    '🏌🏻' => 'гольф ойыншысы: 1–2 тері түсі',
    '🏌🏼' => 'гольф ойыншысы: 3-тері түрі',
    '🏌🏽' => 'гольф ойыншысы: 4-тері түсі',
    '🏌🏾' => 'гольф ойыншысы: 5-тері түсі',
    '🏌🏿' => 'гольф ойыншысы: 6-тері түсі',
    '🏄🏻' => 'серфер: 1–2 тері түсі',
    '🏄🏼' => 'серфер: 3-тері түрі',
    '🏄🏽' => 'серфер: 4-тері түсі',
    '🏄🏾' => 'серфер: 5-тері түсі',
    '🏄🏿' => 'серфер: 6-тері түсі',
    '🚣🏻' => 'қайық есіп жатқан адам: 1–2 тері түсі',
    '🚣🏼' => 'қайық есіп жатқан адам: 3-тері түрі',
    '🚣🏽' => 'қайық есіп жатқан адам: 4-тері түсі',
    '🚣🏾' => 'қайық есіп жатқан адам: 5-тері түсі',
    '🚣🏿' => 'қайық есіп жатқан адам: 6-тері түсі',
    '🏊🏻' => 'жүзуші: 1–2 тері түсі',
    '🏊🏼' => 'жүзуші: 3-тері түрі',
    '🏊🏽' => 'жүзуші: 4-тері түсі',
    '🏊🏾' => 'жүзуші: 5-тері түсі',
    '🏊🏿' => 'жүзуші: 6-тері түсі',
    '⛹🏻' => 'доп ойнаған адам: 1–2 тері түсі',
    '⛹🏼' => 'доп ойнаған адам: 3-тері түрі',
    '⛹🏽' => 'доп ойнаған адам: 4-тері түсі',
    '⛹🏾' => 'доп ойнаған адам: 5-тері түсі',
    '⛹🏿' => 'доп ойнаған адам: 6-тері түсі',
    '🏋🏻' => 'зілтемірші: 1–2 тері түсі',
    '🏋🏼' => 'зілтемірші: 3-тері түрі',
    '🏋🏽' => 'зілтемірші: 4-тері түсі',
    '🏋🏾' => 'зілтемірші: 5-тері түсі',
    '🏋🏿' => 'зілтемірші: 6-тері түсі',
    '🚴🏻' => 'велосипедші: 1–2 тері түсі',
    '🚴🏼' => 'велосипедші: 3-тері түрі',
    '🚴🏽' => 'велосипедші: 4-тері түсі',
    '🚴🏾' => 'велосипедші: 5-тері түсі',
    '🚴🏿' => 'велосипедші: 6-тері түсі',
    '🚵🏻' => 'тау велосипедшісі: 1–2 тері түсі',
    '🚵🏼' => 'тау велосипедшісі: 3-тері түрі',
    '🚵🏽' => 'тау велосипедшісі: 4-тері түсі',
    '🚵🏾' => 'тау велосипедшісі: 5-тері түсі',
    '🚵🏿' => 'тау велосипедшісі: 6-тері түсі',
    '🤸🏻' => 'акробат трюгі: 1–2 тері түсі',
    '🤸🏼' => 'акробат трюгі: 3-тері түрі',
    '🤸🏽' => 'акробат трюгі: 4-тері түсі',
    '🤸🏾' => 'акробат трюгі: 5-тері түсі',
    '🤸🏿' => 'акробат трюгі: 6-тері түсі',
    '🤼🏻' => 'күресшілер: 1–2 тері түсі',
    '🤼🏼' => 'күресшілер: 3-тері түрі',
    '🤼🏽' => 'күресшілер: 4-тері түсі',
    '🤼🏾' => 'күресшілер: 5-тері түсі',
    '🤼🏿' => 'күресшілер: 6-тері түсі',
    '🤽🏻' => 'су полосы: 1–2 тері түсі',
    '🤽🏼' => 'су полосы: 3-тері түрі',
    '🤽🏽' => 'су полосы: 4-тері түсі',
    '🤽🏾' => 'су полосы: 5-тері түсі',
    '🤽🏿' => 'су полосы: 6-тері түсі',
    '🤾🏻' => 'гандбол: 1–2 тері түсі',
    '🤾🏼' => 'гандбол: 3-тері түрі',
    '🤾🏽' => 'гандбол: 4-тері түсі',
    '🤾🏾' => 'гандбол: 5-тері түсі',
    '🤾🏿' => 'гандбол: 6-тері түсі',
    '🤹🏻' => 'жонглер: 1–2 тері түсі',
    '🤹🏼' => 'жонглер: 3-тері түрі',
    '🤹🏽' => 'жонглер: 4-тері түсі',
    '🤹🏾' => 'жонглер: 5-тері түсі',
    '🤹🏿' => 'жонглер: 6-тері түсі',
    '🧘🏻' => 'малдас құрып отырған адам: 1–2 тері түсі',
    '🧘🏼' => 'малдас құрып отырған адам: 3-тері түрі',
    '🧘🏽' => 'малдас құрып отырған адам: 4-тері түсі',
    '🧘🏾' => 'малдас құрып отырған адам: 5-тері түсі',
    '🧘🏿' => 'малдас құрып отырған адам: 6-тері түсі',
    '🛀🏻' => 'ваннада жуыну: 1–2 тері түсі',
    '🛀🏼' => 'ваннада жуыну: 3-тері түрі',
    '🛀🏽' => 'ваннада жуыну: 4-тері түсі',
    '🛀🏾' => 'ваннада жуыну: 5-тері түсі',
    '🛀🏿' => 'ваннада жуыну: 6-тері түсі',
    '🛌🏻' => 'ұйықтап жатқан адам: 1–2 тері түсі',
    '🛌🏼' => 'ұйықтап жатқан адам: 3-тері түрі',
    '🛌🏽' => 'ұйықтап жатқан адам: 4-тері түсі',
    '🛌🏾' => 'ұйықтап жатқан адам: 5-тері түсі',
    '🛌🏿' => 'ұйықтап жатқан адам: 6-тері түсі',
    '👭🏻' => 'қол ұстасып тұрған екі әйел: 1–2 тері түсі',
    '👭🏼' => 'қол ұстасып тұрған екі әйел: 3-тері түрі',
    '👭🏽' => 'қол ұстасып тұрған екі әйел: 4-тері түсі',
    '👭🏾' => 'қол ұстасып тұрған екі әйел: 5-тері түсі',
    '👭🏿' => 'қол ұстасып тұрған екі әйел: 6-тері түсі',
    '👫🏻' => 'қол ұстасып тұрған еркек пен әйел: 1–2 тері түсі',
    '👫🏼' => 'қол ұстасып тұрған еркек пен әйел: 3-тері түрі',
    '👫🏽' => 'қол ұстасып тұрған еркек пен әйел: 4-тері түсі',
    '👫🏾' => 'қол ұстасып тұрған еркек пен әйел: 5-тері түсі',
    '👫🏿' => 'қол ұстасып тұрған еркек пен әйел: 6-тері түсі',
    '👬🏻' => 'қол ұстасып тұрған екі еркек: 1–2 тері түсі',
    '👬🏼' => 'қол ұстасып тұрған екі еркек: 3-тері түрі',
    '👬🏽' => 'қол ұстасып тұрған екі еркек: 4-тері түсі',
    '👬🏾' => 'қол ұстасып тұрған екі еркек: 5-тері түсі',
    '👬🏿' => 'қол ұстасып тұрған екі еркек: 6-тері түсі',
    '💏🏻' => 'өбіс: 1–2 тері түсі',
    '💏🏼' => 'өбіс: 3-тері түрі',
    '💏🏽' => 'өбіс: 4-тері түсі',
    '💏🏾' => 'өбіс: 5-тері түсі',
    '💏🏿' => 'өбіс: 6-тері түсі',
    '💑🏻' => 'махаббат: 1–2 тері түсі',
    '💑🏼' => 'махаббат: 3-тері түрі',
    '💑🏽' => 'махаббат: 4-тері түсі',
    '💑🏾' => 'махаббат: 5-тері түсі',
    '💑🏿' => 'махаббат: 6-тері түсі',
    '🇦🇨' => 'ту: Әскенжін аралы',
    '🇦🇩' => 'ту: Андорра',
    '🇦🇪' => 'ту: Біріккен Араб Әмірліктері',
    '🇦🇫' => 'ту: Ауғанстан',
    '🇦🇬' => 'ту: Антигуа және Барбуда',
    '🇦🇮' => 'ту: Ангилья',
    '🇦🇱' => 'ту: Албания',
    '🇦🇲' => 'ту: Армения',
    '🇦🇴' => 'ту: Ангола',
    '🇦🇶' => 'ту: Антарктида',
    '🇦🇷' => 'ту: Аргентина',
    '🇦🇸' => 'ту: Америкалық Самоа',
    '🇦🇹' => 'ту: Аустрия',
    '🇦🇺' => 'ту: Аустралия',
    '🇦🇼' => 'ту: Аруба',
    '🇦🇽' => 'ту: Аланд аралдары',
    '🇦🇿' => 'ту: Әзірбайжан',
    '🇧🇦' => 'ту: Босния және Герцеговина',
    '🇧🇧' => 'ту: Барбадос',
    '🇧🇩' => 'ту: Бангладеш',
    '🇧🇪' => 'ту: Бельгия',
    '🇧🇫' => 'ту: Буркина-Фасо',
    '🇧🇬' => 'ту: Болгария',
    '🇧🇭' => 'ту: Бахрейн',
    '🇧🇮' => 'ту: Бурунди',
    '🇧🇯' => 'ту: Бенин',
    '🇧🇱' => 'ту: Сен-Бартелеми',
    '🇧🇲' => 'ту: Бермуд аралдары',
    '🇧🇳' => 'ту: Бруней',
    '🇧🇴' => 'ту: Боливия',
    '🇧🇶' => 'ту: Бонэйр, Синт-Эстатиус және Саба',
    '🇧🇷' => 'ту: Бразилия',
    '🇧🇸' => 'ту: Багам аралдары',
    '🇧🇹' => 'ту: Бутан',
    '🇧🇻' => 'ту: Буве аралы',
    '🇧🇼' => 'ту: Ботсвана',
    '🇧🇾' => 'ту: Беларусь',
    '🇧🇿' => 'ту: Белиз',
    '🇨🇦' => 'ту: Канада',
    '🇨🇨' => 'ту: Кокос (Килинг) аралдары',
    '🇨🇩' => 'ту: Конго',
    '🇨🇫' => 'ту: Орталық Африка Республикасы',
    '🇨🇬' => 'ту: Конго-Браззавиль Республикасы',
    '🇨🇭' => 'ту: Швейцария',
    '🇨🇮' => 'ту: Кот-д’Ивуар',
    '🇨🇰' => 'ту: Кук аралдары',
    '🇨🇱' => 'ту: Чили',
    '🇨🇲' => 'ту: Камерун',
    '🇨🇳' => 'ту: Қытай',
    '🇨🇴' => 'ту: Колумбия',
    '🇨🇵' => 'ту: Клиппертон аралы',
    '🇨🇶' => 'ту: Сарк',
    '🇨🇷' => 'ту: Коста-Рика',
    '🇨🇺' => 'ту: Куба',
    '🇨🇻' => 'ту: Кабо-Верде',
    '🇨🇼' => 'ту: Кюрасао',
    '🇨🇽' => 'ту: Рождество аралы',
    '🇨🇾' => 'ту: Кипр',
    '🇨🇿' => 'ту: Чехия',
    '🇩🇪' => 'ту: Германия',
    '🇩🇬' => 'ту: Диего-Гарсия',
    '🇩🇯' => 'ту: Джибути',
    '🇩🇰' => 'ту: Дания',
    '🇩🇲' => 'ту: Доминика',
    '🇩🇴' => 'ту: Доминикан Республикасы',
    '🇩🇿' => 'ту: Алжир',
    '🇪🇦' => 'ту: Сеута және Мелилья',
    '🇪🇨' => 'ту: Эквадор',
    '🇪🇪' => 'ту: Эстония',
    '🇪🇬' => 'ту: Мысыр',
    '🇪🇭' => 'ту: Батыс Сахара',
    '🇪🇷' => 'ту: Эритрея',
    '🇪🇸' => 'ту: Испания',
    '🇪🇹' => 'ту: Эфиопия',
    '🇪🇺' => 'ту: Еуропалық Одақ',
    '🇫🇮' => 'ту: Финляндия',
    '🇫🇯' => 'ту: Фиджи',
    '🇫🇰' => 'ту: Фолкленд аралдары',
    '🇫🇲' => 'ту: Микронезия',
    '🇫🇴' => 'ту: Фарер аралдары',
    '🇫🇷' => 'ту: Франция',
    '🇬🇦' => 'ту: Габон',
    '🇬🇧' => 'ту: Ұлыбритания',
    '🇬🇩' => 'ту: Гренада',
    '🇬🇪' => 'ту: Грузия',
    '🇬🇫' => 'ту: Француз Гвианасы',
    '🇬🇬' => 'ту: Гернси',
    '🇬🇭' => 'ту: Гана',
    '🇬🇮' => 'ту: Гибралтар',
    '🇬🇱' => 'ту: Гренландия',
    '🇬🇲' => 'ту: Гамбия',
    '🇬🇳' => 'ту: Гвинея',
    '🇬🇵' => 'ту: Гваделупа',
    '🇬🇶' => 'ту: Экваторлық Гвинея',
    '🇬🇷' => 'ту: Грекия',
    '🇬🇸' => 'ту: Оңтүстік Георгия және Оңтүстік Сандвич аралдары',
    '🇬🇹' => 'ту: Гватемала',
    '🇬🇺' => 'ту: Гуам',
    '🇬🇼' => 'ту: Гвинея-Бисау',
    '🇬🇾' => 'ту: Гайана',
    '🇭🇰' => 'ту: Сянган АӘА',
    '🇭🇲' => 'ту: Херд аралы және Макдональд аралдары',
    '🇭🇳' => 'ту: Гондурас',
    '🇭🇷' => 'ту: Хорватия',
    '🇭🇹' => 'ту: Гаити',
    '🇭🇺' => 'ту: Венгрия',
    '🇮🇨' => 'ту: Канар аралдары',
    '🇮🇩' => 'ту: Индонезия',
    '🇮🇪' => 'ту: Ирландия',
    '🇮🇱' => 'ту: Израиль',
    '🇮🇲' => 'ту: Мэн аралы',
    '🇮🇳' => 'ту: Үндістан',
    '🇮🇴' => 'ту: Үнді мұхитындағы Британ аймағы',
    '🇮🇶' => 'ту: Ирак',
    '🇮🇷' => 'ту: Иран',
    '🇮🇸' => 'ту: Исландия',
    '🇮🇹' => 'ту: Италия',
    '🇯🇪' => 'ту: Джерси',
    '🇯🇲' => 'ту: Ямайка',
    '🇯🇴' => 'ту: Иордания',
    '🇯🇵' => 'ту: Жапония',
    '🇰🇪' => 'ту: Кения',
    '🇰🇬' => 'ту: Қырғызстан',
    '🇰🇭' => 'ту: Камбоджа',
    '🇰🇮' => 'ту: Кирибати',
    '🇰🇲' => 'ту: Комор аралдары',
    '🇰🇳' => 'ту: Сент-Китс және Невис',
    '🇰🇵' => 'ту: Солтүстік Корея',
    '🇰🇷' => 'ту: Оңтүстік Корея',
    '🇰🇼' => 'ту: Кувейт',
    '🇰🇾' => 'ту: Кайман аралдары',
    '🇰🇿' => 'ту: Қазақстан',
    '🇱🇦' => 'ту: Лаос',
    '🇱🇧' => 'ту: Ливан',
    '🇱🇨' => 'ту: Сент-Люсия',
    '🇱🇮' => 'ту: Лихтенштейн',
    '🇱🇰' => 'ту: Шри-Ланка',
    '🇱🇷' => 'ту: Либерия',
    '🇱🇸' => 'ту: Лесото',
    '🇱🇹' => 'ту: Литва',
    '🇱🇺' => 'ту: Люксембург',
    '🇱🇻' => 'ту: Латвия',
    '🇱🇾' => 'ту: Ливия',
    '🇲🇦' => 'ту: Марокко',
    '🇲🇨' => 'ту: Монако',
    '🇲🇩' => 'ту: Молдова',
    '🇲🇪' => 'ту: Черногория',
    '🇲🇫' => 'ту: Сен-Мартен',
    '🇲🇬' => 'ту: Мадагаскар',
    '🇲🇭' => 'ту: Маршалл аралдары',
    '🇲🇰' => 'ту: Солтүстік Македония',
    '🇲🇱' => 'ту: Мали',
    '🇲🇲' => 'ту: Мьянма (Бирма)',
    '🇲🇳' => 'ту: Моңғолия',
    '🇲🇴' => 'ту: Макао АӘА',
    '🇲🇵' => 'ту: Солтүстік Мариана аралдары',
    '🇲🇶' => 'ту: Мартиника',
    '🇲🇷' => 'ту: Мавритания',
    '🇲🇸' => 'ту: Монтсеррат',
    '🇲🇹' => 'ту: Мальта',
    '🇲🇺' => 'ту: Маврикий',
    '🇲🇻' => 'ту: Мальдив аралдары',
    '🇲🇼' => 'ту: Малави',
    '🇲🇽' => 'ту: Мексика',
    '🇲🇾' => 'ту: Малайзия',
    '🇲🇿' => 'ту: Мозамбик',
    '🇳🇦' => 'ту: Намибия',
    '🇳🇨' => 'ту: Жаңа Каледония',
    '🇳🇪' => 'ту: Нигер',
    '🇳🇫' => 'ту: Норфолк аралы',
    '🇳🇬' => 'ту: Нигерия',
    '🇳🇮' => 'ту: Никарагуа',
    '🇳🇱' => 'ту: Нидерланд',
    '🇳🇴' => 'ту: Норвегия',
    '🇳🇵' => 'ту: Непал',
    '🇳🇷' => 'ту: Науру',
    '🇳🇺' => 'ту: Ниуэ',
    '🇳🇿' => 'ту: Жаңа Зеландия',
    '🇴🇲' => 'ту: Оман',
    '🇵🇦' => 'ту: Панама',
    '🇵🇪' => 'ту: Перу',
    '🇵🇫' => 'ту: Француз Полинезиясы',
    '🇵🇬' => 'ту: Папуа — Жаңа Гвинея',
    '🇵🇭' => 'ту: Филиппин аралдары',
    '🇵🇰' => 'ту: Пәкістан',
    '🇵🇱' => 'ту: Польша',
    '🇵🇲' => 'ту: Сен-Пьер және Микелон',
    '🇵🇳' => 'ту: Питкэрн аралдары',
    '🇵🇷' => 'ту: Пуэрто-Рико',
    '🇵🇸' => 'ту: Палестина аймақтары',
    '🇵🇹' => 'ту: Португалия',
    '🇵🇼' => 'ту: Палау',
    '🇵🇾' => 'ту: Парагвай',
    '🇶🇦' => 'ту: Катар',
    '🇷🇪' => 'ту: Реюньон',
    '🇷🇴' => 'ту: Румыния',
    '🇷🇸' => 'ту: Сербия',
    '🇷🇺' => 'ту: Ресей',
    '🇷🇼' => 'ту: Руанда',
    '🇸🇦' => 'ту: Сауд Арабиясы',
    '🇸🇧' => 'ту: Соломон аралдары',
    '🇸🇨' => 'ту: Сейшель аралдары',
    '🇸🇩' => 'ту: Судан',
    '🇸🇪' => 'ту: Швеция',
    '🇸🇬' => 'ту: Сингапур',
    '🇸🇭' => 'ту: Әулие Елена аралы',
    '🇸🇮' => 'ту: Словения',
    '🇸🇯' => 'ту: Шпицберген және Ян-Майен',
    '🇸🇰' => 'ту: Словакия',
    '🇸🇱' => 'ту: Сьерра-Леоне',
    '🇸🇲' => 'ту: Сан-Марино',
    '🇸🇳' => 'ту: Сенегал',
    '🇸🇴' => 'ту: Сомали',
    '🇸🇷' => 'ту: Суринам',
    '🇸🇸' => 'ту: Оңтүстік Судан',
    '🇸🇹' => 'ту: Сан-Томе және Принсипи',
    '🇸🇻' => 'ту: Сальвадор',
    '🇸🇽' => 'ту: Синт-Мартен',
    '🇸🇾' => 'ту: Сирия',
    '🇸🇿' => 'ту: Эсватини',
    '🇹🇦' => 'ту: Тристан-да-Кунья',
    '🇹🇨' => 'ту: Теркс және Кайкос аралдары',
    '🇹🇩' => 'ту: Чад',
    '🇹🇫' => 'ту: Францияның оңтүстік аймақтары',
    '🇹🇬' => 'ту: Того',
    '🇹🇭' => 'ту: Таиланд',
    '🇹🇯' => 'ту: Тәжікстан',
    '🇹🇰' => 'ту: Токелау',
    '🇹🇱' => 'ту: Тимор-Лесте',
    '🇹🇲' => 'ту: Түрікменстан',
    '🇹🇳' => 'ту: Тунис',
    '🇹🇴' => 'ту: Тонга',
    '🇹🇷' => 'ту: Түркия',
    '🇹🇹' => 'ту: Тринидад және Тобаго',
    '🇹🇻' => 'ту: Тувалу',
    '🇹🇼' => 'ту: Тайвань',
    '🇹🇿' => 'ту: Танзания',
    '🇺🇦' => 'ту: Украина',
    '🇺🇬' => 'ту: Уганда',
    '🇺🇲' => 'ту: АҚШ-тың сыртқы кіші аралдары',
    '🇺🇳' => 'ту: Біріккен Ұлттар Ұйымы',
    '🇺🇸' => 'ту: Америка Құрама Штаттары',
    '🇺🇾' => 'ту: Уругвай',
    '🇺🇿' => 'ту: Өзбекстан',
    '🇻🇦' => 'ту: Ватикан',
    '🇻🇨' => 'ту: Сент-Винсент және Гренадин аралдары',
    '🇻🇪' => 'ту: Венесуэла',
    '🇻🇬' => 'ту: Британдық Виргин аралдары',
    '🇻🇮' => 'ту: АҚШ-тың Виргин аралдары',
    '🇻🇳' => 'ту: Вьетнам',
    '🇻🇺' => 'ту: Вануату',
    '🇼🇫' => 'ту: Уоллис және Футуна',
    '🇼🇸' => 'ту: Самоа',
    '🇽🇰' => 'ту: Косово',
    '🇾🇪' => 'ту: Йемен',
    '🇾🇹' => 'ту: Майотта',
    '🇿🇦' => 'ту: Оңтүстік Африка',
    '🇿🇲' => 'ту: Замбия',
    '🇿🇼' => 'ту: Зимбабве',
    '🔟' => 'перне: 10',
    '🏻' => '1–2 тері түсі',
    '🏼' => '3-тері түрі',
    '🏽' => '4-тері түсі',
    '🏾' => '5-тері түсі',
    '🏿' => '6-тері түсі',
    '😀' => 'езу тартып күлу',
    '😃' => 'аузын ашып күлу',
    '😄' => 'аузын ашып, ыржиып тұрып күлу',
    '😁' => 'бал-бұл жайнап күлу',
    '😆' => 'аузын ашып, көзін жұмып күлу',
    '😅' => 'сасқалақтап күлу',
    '🤣' => 'ішек-сілесі қатып күлу',
    '😂' => 'көзден жас шыққанша күлу',
    '🙂' => 'жымию',
    '🙃' => 'мысқыл',
    '🫠' => 'еріген бет',
    '😉' => 'көз қысу',
    '😊' => 'риза болып күлу',
    '😇' => 'бейуаз',
    '🥰' => 'жүрекшелері бар бет',
    '😍' => 'сүйсініп қарау',
    '🤩' => 'желігу',
    '😘' => 'көзді қысып қойып сүю',
    '😗' => 'сүю',
    '☺' => 'күлу',
    '😚' => 'көзді жұмып тұрып сүю',
    '😙' => 'күлімдеген көзбен сүю',
    '🥲' => 'жылап тұрып күлу',
    '😋' => 'тілін шығарған',
    '😛' => 'тілін шығару',
    '😜' => 'көзін қысып, тілін шығару',
    '🤪' => 'жынды',
    '😝' => 'көзін жұмып, тілін шығару',
    '🤑' => 'ақшадан көз айырмау',
    '🤗' => 'құшақтау',
    '🤭' => 'аузын қолмен жауып күлу',
    '🫢' => 'көзі ашық, ал аузын қолымен жапқан',
    '🫣' => 'астыртын қарау',
    '🤫' => 'үндеме',
    '🤔' => 'ойлану',
    '🫡' => 'салют беру',
    '🤐' => 'сөйлемеу',
    '🤨' => 'сенбеу',
    '😐' => 'бәрібір',
    '😑' => 'сезімсіз',
    '😶' => 'аузы жоқ бет',
    '🫥' => 'пунктирмен салынған бет',
    '😏' => 'мырс-мырс күлу',
    '😒' => 'қызық емес',
    '🙄' => 'көзі алару',
    '😬' => 'бет-аузын қисайту',
    '🤥' => 'өтірікші',
    '🫨' => 'шайқалған бет',
    '😌' => 'жеңілдеп қалу',
    '😔' => 'мұңды',
    '😪' => 'ұйқы басу',
    '🤤' => 'сілекейі ағып тұр',
    '😴' => 'ұйықтау',
    '🫩' => 'көзі ісіп тұр',
    '😷' => 'медициналық бетперде таққан бет',
    '🤒' => 'термометрі бар бет',
    '🤕' => 'басы бинттелген',
    '🤢' => 'жүрегі айнып тұр',
    '🤮' => 'құсу',
    '🤧' => 'түшкіру',
    '🥵' => 'ыстықтаған бет',
    '🥶' => 'тонған бет',
    '🥴' => 'әлсіреген жүз',
    '😵' => 'көзі кіреспен сызылған',
    '🤯' => 'бас жарылғалы тұр',
    '🤠' => 'ковбой қалпағы',
    '🥳' => 'тойлау',
    '🥸' => 'бетін бүркеп алу',
    '😎' => 'көзілдірік тағып жымию',
    '🤓' => 'көзілдірік таққан',
    '🧐' => 'монокль тағу',
    '😕' => 'абдырау',
    '🫤' => 'аузын қисайту',
    '😟' => 'уайымдау',
    '🙁' => 'аздап тұнжырау',
    '☹' => 'тұнжырау',
    '😮' => 'таңдану',
    '😯' => 'таңғалу',
    '😲' => 'аң-таң болу',
    '😳' => 'беті қызару',
    '🫪' => 'түрі өзгерген эмоджи',
    '🥺' => 'жалыну',
    '🥹' => 'көз жасын әрең ұстау',
    '😦' => 'аузын ашып, бұртию',
    '😧' => 'қиналу',
    '😨' => 'шошып кету',
    '😰' => 'қатты қобалжу',
    '😥' => 'жеңілдену',
    '😢' => 'жылау',
    '😭' => 'айқайлап жылау',
    '😱' => 'зәресі ұшу',
    '😖' => 'есі шығу',
    '😣' => 'шыдамдылық',
    '😞' => 'түңілу',
    '😓' => 'қатты шаршап, терлеу',
    '😩' => 'қалжырау',
    '😫' => 'қатты шаршау',
    '🥱' => 'есінеу',
    '😤' => 'мұрнынан бу шыққан',
    '😡' => 'ашулану',
    '😠' => 'ашулы',
    '🤬' => 'цензура',
    '😈' => 'күлімдеген ібіліс',
    '👿' => 'ашуланған ібіліс',
    '💀' => 'бас сүйек',
    '☠' => 'бас сүйек пен сүйектер',
    '💩' => 'боқ',
    '🤡' => 'клоун',
    '👹' => 'құбыжық',
    '👺' => 'гоблин',
    '👻' => 'елес',
    '👽' => 'гуманоид',
    '👾' => 'басқа планетадан келген құбыжық',
    '🤖' => 'робот',
    '😺' => 'күлімдеген мысық',
    '😸' => 'күліп тұрған мысық',
    '😹' => 'көзінен жас шыққанша күлген мысық',
    '😻' => 'сүйсініп қарап тұрған мысық',
    '😼' => 'мырс-мырс күліп тұрған мысық',
    '😽' => 'сүйіп тұрған мысық',
    '🙀' => 'зәресі ұшқан мысық',
    '😿' => 'жылап тұрған мысық',
    '😾' => 'ашуланған мысық',
    '🙈' => 'көзін жауып тұрған маймыл',
    '🙉' => 'құлағын жауып тұрған маймыл',
    '🙊' => 'аузын жауып тұрған маймыл',
    '💌' => 'махаббат хаты',
    '💘' => 'жебе тиген жүрек',
    '💝' => 'таспалы жүрек',
    '💖' => 'жылтыраған жүрек',
    '💗' => 'үлкейетін жүрек',
    '💓' => 'соғып тұрған жүрек',
    '💞' => 'айналып тұрған жүректер',
    '💕' => 'қос жүрек',
    '💟' => 'декоративтік жүрек',
    '❣' => 'леп белгісі тәрізді жүрек',
    '💔' => 'жаралы жүрек',
    '❤' => 'қызыл жүрек',
    '🩷' => 'қызғылт жүрек',
    '🧡' => 'қызғылт-сары жүрек',
    '💛' => 'сары жүрек',
    '💚' => 'жасыл жүрек',
    '💙' => 'көк жүрек',
    '🩵' => 'ақшыл көк жүрек',
    '💜' => 'күлгін жүрек',
    '🤎' => 'қоңыр жүрек',
    '🖤' => 'қара жүрек',
    '🩶' => 'сұр жүрек',
    '🤍' => 'ақ жүрек',
    '💋' => 'ерін',
    '💯' => 'жүз балл',
    '💢' => 'ашу',
    '🫯' => 'төбелес шаңы',
    '💥' => 'қақтығыс',
    '💫' => 'басы айналған',
    '💦' => 'тер тамшылары',
    '💨' => 'шапшаң',
    '🕳' => 'тесік',
    '💬' => 'әңгіме бұлты',
    '🗨' => 'сол жақ әңгіме бұлты',
    '🗯' => 'оң жақ ашулы сұхбаттасу көпіршігі',
    '💭' => 'ой бұлты',
    '💤' => 'ұйқы',
    '👋' => 'қол бұлғау',
    '🤚' => 'алақан сыртын көрсету',
    '🖐' => 'саусақтарының арасын ашып, қолды көтеру',
    '✋' => 'қол көтеру',
    '🖖' => 'вулканша сәлемдесу',
    '🫱' => 'оңға қаратылған қол',
    '🫲' => 'солға қаратылған қол',
    '🫳' => 'алақанымен төмен қаратылған қол',
    '🫴' => 'алақанымен жоғары қаратылған қол',
    '🫷' => 'солға итерген қол',
    '🫸' => 'оңға итерген қол',
    '👌' => 'ОК',
    '🤌' => 'түйістірілген бес саусақ',
    '🤏' => 'саусақпен қысып алу',
    '✌' => 'саусақтармен «V» әрпін көрсету',
    '🤞' => 'саусақтарын айқастырған',
    '🫰' => 'бас бармақ пен сұқ саусақ айқастырылған қол',
    '🤟' => 'сені сүйемін белгісі',
    '🤘' => 'мүйіз белгісі',
    '🤙' => 'хабарлас',
    '👈' => 'сол жаққа саусақпен қолды сыртқа қаратып көрсету',
    '👉' => 'оң жаққа саусақпен қолды сыртқа қаратып көрсету',
    '👆' => 'жоғары саусақпен қолды сыртқа қаратып көрсету',
    '🖕' => 'ортаңғы саусақ',
    '👇' => 'төмен саусақпен қолды сыртқа қаратып көрсету',
    '☝' => 'жоғарыға саусақпен көрсету',
    '🫵' => 'тіке қаратылған қол',
    '👍' => 'тамаша',
    '👎' => 'нашар',
    '✊' => 'жұдырық көтеру',
    '👊' => 'жұдырық',
    '🤛' => 'солға қаратылған жұдырық',
    '🤜' => 'оңға қаратылған жұдырық',
    '👏' => 'шапалақтау',
    '🙌' => 'қолдарды көтеру',
    '🫶' => 'жұректі көрсетіп тұрған қолдар',
    '👐' => 'алақанды көрсету',
    '🤲' => 'алақандарын көтеру',
    '🤝' => 'қол алысу',
    '🙏' => 'қолды түйістіру',
    '✍' => 'қолмен жазу',
    '💅' => 'маникюр',
    '🤳' => 'селфи',
    '💪' => 'бицепс',
    '🦾' => 'механикалық қол',
    '🦿' => 'механикалық аяқ',
    '🦵' => 'аяқ',
    '🦶' => 'табан',
    '👂' => 'құлақ',
    '🦻' => 'есту аппараты бар құлақ',
    '👃' => 'мұрын',
    '🧠' => 'ми',
    '🫀' => 'жүрек органы',
    '🫁' => 'өкпе',
    '🦷' => 'тіс',
    '🦴' => 'сүйек',
    '👀' => 'көздер',
    '👁' => 'көз',
    '👅' => 'тіл',
    '👄' => 'ауыз',
    '🫦' => 'ернін тістеу',
    '👶' => 'сәби',
    '🧒' => 'бала',
    '👦' => 'ұл',
    '👧' => 'қыз',
    '🧑' => 'адам',
    '👱' => 'аққұба адам',
    '👨' => 'ер адам',
    '🧔' => 'сақалды ер адам',
    '👩' => 'әйел',
    '🧓' => 'қарт адам',
    '👴' => 'қарт',
    '👵' => 'қарт әйел',
    '🙍' => 'қабағын түю',
    '🙎' => 'беті бұртию',
    '🙅' => 'жоқ',
    '🙆' => 'жарайды',
    '💁' => 'ақпарат орталығы',
    '🙋' => 'қолды көтеру',
    '🧏' => 'саңырау адам',
    '🙇' => 'иілген адам',
    '🤦' => 'бетін қолмен жапқан адам',
    '🤷' => 'білмегендік белгісі',
    '👮' => 'полиция қызметкері',
    '🕵' => 'детектив',
    '💂' => 'күзетші',
    '🥷' => 'ниндзя',
    '👷' => 'құрылысшы',
    '🫅' => 'тәж таққан адам',
    '🤴' => 'ханзада',
    '👸' => 'ханшайым',
    '👳' => 'сәлделі адам',
    '👲' => 'қытай қалпағын киген адам',
    '🧕' => 'орамал таққан әйел',
    '🤵' => 'смокинг киген адам',
    '👰' => 'қалыңдық',
    '🤰' => 'екіқабат әйел',
    '🫃' => 'жүкті ер адам',
    '🫄' => 'жүкті адам',
    '🤱' => 'бала емізу',
    '👼' => 'кішкентай періште',
    '🎅' => 'санта клаус',
    '🤶' => 'ақшақар',
    '🦸' => 'супер батыр',
    '🦹' => 'супер зұлым',
    '🧙' => 'сиқыршы',
    '🧚' => 'пері',
    '🧛' => 'вампир',
    '🧜' => 'теңіз тұрғыны',
    '🧝' => 'эльф',
    '🧞' => 'жын',
    '🧟' => 'зомби',
    '🧌' => 'тролль',
    '🫈' => 'түкті жаратылыс',
    '💆' => 'бетке массаж жасау',
    '💇' => 'шаш қидыру',
    '🚶' => 'жаяу',
    '🧍' => 'тұрып тұрған адам',
    '🧎' => 'тізерлеп отырған адам',
    '🏃' => 'жүгіру',
    '💃' => 'билеген әйел',
    '🕺' => 'билеп тұрған ер адам',
    '🕴' => 'ауада қалқып тұрған іскер',
    '👯' => 'билеп жатқан әйелдер',
    '🧖' => 'бу бөлмедегі адам',
    '🧗' => 'өрмелеп бара жатқан адам',
    '🤺' => 'семсерлесіп жатқан адам',
    '🏇' => 'атшабар',
    '⛷' => 'шаңғышы',
    '🏂' => 'сноубордшы',
    '🏌' => 'гольф ойыншысы',
    '🏄' => 'серфер',
    '🚣' => 'қайық есіп жатқан адам',
    '🏊' => 'жүзуші',
    '⛹' => 'доп ойнаған адам',
    '🏋' => 'зілтемірші',
    '🚴' => 'велосипедші',
    '🚵' => 'тау велосипедшісі',
    '🤸' => 'акробат трюгі',
    '🤼' => 'күресшілер',
    '🤽' => 'су полосы',
    '🤾' => 'гандбол',
    '🤹' => 'жонглер',
    '🧘' => 'малдас құрып отырған адам',
    '🛀' => 'ваннада жуыну',
    '🛌' => 'ұйықтап жатқан адам',
    '👭' => 'қол ұстасып тұрған екі әйел',
    '👫' => 'қол ұстасып тұрған еркек пен әйел',
    '👬' => 'қол ұстасып тұрған екі еркек',
    '💏' => 'өбіс',
    '💑' => 'махаббат',
    '🗣' => 'сөйлеу',
    '👤' => 'адам сұлбасы',
    '👥' => 'адамдар сұлбасы',
    '🫂' => 'құшақтасқан адамдар',
    '👪' => 'отбасы',
    '👣' => 'аяқ іздері',
    '🫆' => 'саусақ ізі',
    '🦰' => 'жирен шаш',
    '🦱' => 'бұйра шаш',
    '🦳' => 'ақ шаш',
    '🦲' => 'тақырбас',
    '🐵' => 'маймылдың беті',
    '🐒' => 'маймыл',
    '🦍' => 'горилла',
    '🦧' => 'орангутанг',
    '🐶' => 'иттің беті',
    '🐕' => 'ит',
    '🦮' => 'жетектеуші ит',
    '🐩' => 'пудель',
    '🐺' => 'қасқырдың беті',
    '🦊' => 'түлкінің беті',
    '🦝' => 'жанат',
    '🐱' => 'мысықтың беті',
    '🐈' => 'мысық',
    '🦁' => 'арыстанның беті',
    '🐯' => 'жолбарыстың беті',
    '🐅' => 'жолбарыс',
    '🐆' => 'қабылан',
    '🐴' => 'жылқының беті',
    '🫎' => 'бұлан',
    '🫏' => 'есек',
    '🐎' => 'жылқы',
    '🦄' => 'жалғыз мүйіздің беті',
    '🦓' => 'ала құлан',
    '🦌' => 'бұғы',
    '🦬' => 'бизон',
    '🐮' => 'сиырдың беті',
    '🐂' => 'бұқа',
    '🐃' => 'енеке',
    '🐄' => 'сиыр',
    '🐷' => 'шошқаның беті',
    '🐖' => 'шошқа',
    '🐗' => 'қабан',
    '🐽' => 'шошқаның мұрны',
    '🐏' => 'қошқар',
    '🐑' => 'қой',
    '🐐' => 'ешкі',
    '🐪' => 'түйе',
    '🐫' => 'қос өркешті түйе',
    '🦙' => 'лама',
    '🦒' => 'керік',
    '🐘' => 'піл',
    '🦣' => 'мамонт',
    '🦏' => 'мүйізтұмсық',
    '🦛' => 'бегемот',
    '🐭' => 'тышқанның беті',
    '🐁' => 'тышқан',
    '🐀' => 'егеуқұйрық',
    '🐹' => 'алақоржынның беті',
    '🐰' => 'қоянның беті',
    '🐇' => 'қоян',
    '🐿' => 'боршатышқан',
    '🦫' => 'құндыз',
    '🦔' => 'кірпі',
    '🦇' => 'жарқанат',
    '🐻' => 'аюдың беті',
    '🐨' => 'коала',
    '🐼' => 'панданың беті',
    '🦥' => 'жалқау аң',
    '🦦' => 'кәмшат',
    '🦨' => 'сасықиісті',
    '🦘' => 'кенгуру',
    '🦡' => 'борсық',
    '🐾' => 'табан іздері',
    '🦃' => 'күркетауық',
    '🐔' => 'тауық',
    '🐓' => 'әтеш',
    '🐣' => 'жұмыртқаны жарып шыққан балапан',
    '🐤' => 'балапан',
    '🐥' => 'алға қарап тұрған балапан',
    '🐦' => 'құс',
    '🐧' => 'пингвин',
    '🕊' => 'көгершін',
    '🦅' => 'бүркіт',
    '🦆' => 'үйрек',
    '🦢' => 'аққу',
    '🦉' => 'жапалақ',
    '🦤' => 'дронт',
    '🪶' => 'қауырсын',
    '🦩' => 'фламинго',
    '🦚' => 'тауыс',
    '🦜' => 'тотықұс',
    '🪽' => 'қанат',
    '🪿' => 'қаз',
    '🐸' => 'бақаның беті',
    '🐊' => 'қолтырауын',
    '🐢' => 'тасбақа',
    '🦎' => 'кесіртке',
    '🐍' => 'жылан',
    '🐲' => 'айдаһардың беті',
    '🐉' => 'айдаһар',
    '🦕' => 'зауропод',
    '🦖' => 'Ти-рекс',
    '🐳' => 'су бүркіп тұрған кит',
    '🐋' => 'кит',
    '🐬' => 'дельфин',
    '🫍' => 'косатка',
    '🦭' => 'итбалық',
    '🐟' => 'балық',
    '🐠' => 'тропикалық балық',
    '🐡' => 'кірпібалық',
    '🦈' => 'акула',
    '🐙' => 'сегізаяқ',
    '🐚' => 'шиыршықты бақалшық',
    '🪸' => 'маржан',
    '🪼' => 'медуза',
    '🦀' => 'теңіз шаяны',
    '🦞' => 'лобстер',
    '🦐' => 'асшаян',
    '🦑' => 'кальмар',
    '🦪' => 'устрица',
    '🐌' => 'ұлу',
    '🦋' => 'көбелек',
    '🐛' => 'жәндік',
    '🐜' => 'құмырсқа',
    '🐝' => 'бал ара',
    '🪲' => 'қоңыз',
    '🐞' => 'ханқызы',
    '🦗' => 'шегіртке',
    '🪳' => 'тарақан',
    '🕷' => 'өрмекші',
    '🕸' => 'өрмекші торы',
    '🦂' => 'сарышаян',
    '🦟' => 'маса',
    '🪰' => 'ұшу',
    '🪱' => 'құрт',
    '🦠' => 'микроб',
    '💐' => 'гул шоғы',
    '🌸' => 'шие гүлі',
    '💮' => 'ақ гүл',
    '🪷' => 'лотос',
    '🏵' => 'розетта',
    '🌹' => 'раушан',
    '🥀' => 'солған гүл',
    '🌺' => 'бөрітарақ',
    '🌻' => 'күнбағыс',
    '🌼' => 'гүлдеу',
    '🌷' => 'қызғалдақ',
    '🪻' => 'сүмбіл',
    '🌱' => 'көшет',
    '🪴' => 'бөлме өсімдігі',
    '🌲' => 'шырша',
    '🌳' => 'жапырақты ағаш',
    '🌴' => 'пальма',
    '🌵' => 'кактус',
    '🌾' => 'бір байлам күріш',
    '🌿' => 'шөп',
    '☘' => 'қоян саумалдық',
    '🍀' => 'төрт жапырақты жоңышқа',
    '🍁' => 'үйеңкі жапырағы',
    '🍂' => 'сарғайып түскен жапырақтар',
    '🍃' => 'желмен ұшқан жапырақ',
    '🪹' => 'бос ұя',
    '🪺' => 'ішінде жұмыртқалары бар ұя',
    '🍄' => 'саңырауқұлақ',
    '🪾' => 'жапырақсыз ағаш',
    '🍇' => 'жүзім',
    '🍈' => 'қауын',
    '🍉' => 'қарбыз',
    '🍊' => 'мандарин',
    '🍋' => 'лимон',
    '🍌' => 'банан',
    '🍍' => 'ананас',
    '🥭' => 'манго',
    '🍎' => 'қызыл алма',
    '🍏' => 'көк алма',
    '🍐' => 'алмұрт',
    '🍑' => 'шабдалы',
    '🍒' => 'шие',
    '🍓' => 'құлпынай',
    '🫐' => 'қаражидек',
    '🥝' => 'киви',
    '🍅' => 'қызанақ',
    '🫒' => 'зәйтүн',
    '🥥' => 'кокос',
    '🥑' => 'авокадо',
    '🍆' => 'баялды',
    '🥔' => 'картоп',
    '🥕' => 'сәбіз',
    '🌽' => 'жүгері собығы',
    '🌶' => 'ащы бұрыш',
    '🫑' => 'болгар бұрышы',
    '🥒' => 'қияр',
    '🥬' => 'жасыл жапырақ',
    '🥦' => 'брокколи',
    '🧄' => 'сарымсақ',
    '🧅' => 'пияз',
    '🥜' => 'жержаңғақ',
    '🫘' => 'бұршақ',
    '🌰' => 'каштан',
    '🫚' => 'зімбір тамыры',
    '🫛' => 'бұршаққынды асбұршақ',
    '🫜' => 'тамыр жеміс',
    '🍞' => 'нан',
    '🥐' => 'круассан',
    '🥖' => 'багет',
    '🫓' => 'шелпек нан',
    '🥨' => 'тұзды тоқаш',
    '🥯' => 'бейгл',
    '🥞' => 'құймақ',
    '🧇' => 'вафля',
    '🧀' => 'ірімшік бөлігі',
    '🍖' => 'сүйегі бар ет',
    '🍗' => 'тауықтың аяғы',
    '🥩' => 'ет кесімі',
    '🥓' => 'сүрсүбе',
    '🍔' => 'гамбургер',
    '🍟' => 'фри',
    '🍕' => 'пицца',
    '🌭' => 'хот-дог',
    '🥪' => 'сэндвич',
    '🌮' => 'тако',
    '🌯' => 'бурито',
    '🫔' => 'тамал',
    '🥙' => 'шаурма',
    '🧆' => 'фалафель',
    '🥚' => 'жұмыртқа',
    '🍳' => 'пісіру',
    '🥘' => 'табадағы рагу',
    '🍲' => 'тамақ толы кәстрөл',
    '🫕' => 'фондю',
    '🥣' => 'қасығы бар ыдыс',
    '🥗' => 'көкөніс салаты',
    '🍿' => 'попкорн',
    '🧈' => 'сары май',
    '🧂' => 'тұз',
    '🥫' => 'консервілер',
    '🍱' => 'бэнто',
    '🍘' => 'күріштен жасалған крекер',
    '🍙' => 'күріш шары',
    '🍚' => 'пісірілген күріш',
    '🍛' => 'карри қосылған күріш',
    '🍜' => 'буы шығып тұрған ыдыс',
    '🍝' => 'спагетти',
    '🍠' => 'қуырылған батат',
    '🍢' => 'оден',
    '🍣' => 'суши',
    '🍤' => 'қуырылған асшаян',
    '🍥' => 'иірім тәрізді балықтан жасалған котлет',
    '🥮' => 'қытай пирогы',
    '🍡' => 'данго',
    '🥟' => 'үзбе кеспе',
    '🥠' => 'болжау печеньесі',
    '🥡' => 'жол тағамы',
    '🍦' => 'жұмсақ балмұздақ',
    '🍧' => 'мұзды балмұздақ',
    '🍨' => 'балмұздақ',
    '🍩' => 'бүйрекше бәліш',
    '🍪' => 'печенье',
    '🎂' => 'туған күнге арналған торт',
    '🍰' => 'қатпарлы торт',
    '🧁' => 'кекс',
    '🥧' => 'бәліш',
    '🍫' => 'шоколад тақтасы',
    '🍬' => 'мұз кәмпит',
    '🍭' => 'таяқшалы мұз кәмпит',
    '🍮' => 'кастард',
    '🍯' => 'бал құтысы',
    '🍼' => 'сәби бөтелкесі',
    '🥛' => 'стақан сүт',
    '☕' => 'ыстық сусын',
    '🫖' => 'шәйнек',
    '🍵' => 'тұтқасы жоқ шынаяқ',
    '🍶' => 'сакэ',
    '🍾' => 'тығыны атылған бөтелке',
    '🍷' => 'шарап бокалы',
    '🍸' => 'коктейль бокалы',
    '🍹' => 'тропикалық сусын',
    '🍺' => 'сыра саптыаяғы',
    '🍻' => 'қағыстырылған сыра саптыаяқтары',
    '🥂' => 'стақан соғыстыру',
    '🥃' => 'стақан',
    '🫗' => 'сұйықтықты құю',
    '🥤' => 'түтікшелі ыдыс',
    '🧋' => 'көбікті шай',
    '🧃' => 'сусын пакеті',
    '🧉' => 'мате',
    '🧊' => 'мұз текшесі',
    '🥢' => 'тамақ таяқшалары',
    '🍽' => 'тәрелке, шанышқы және пышақ',
    '🍴' => 'шанышқы мен пышақ',
    '🥄' => 'қасық',
    '🔪' => 'асхана пышағы',
    '🫙' => 'құты',
    '🏺' => 'амфора',
    '🌍' => 'Еуропа мен Африка көрсетілген глобус',
    '🌎' => 'Екі Америка құрлығы көрсетілген глобус',
    '🌏' => 'Азия мен Аустралия көрсетілген глобус',
    '🌐' => 'Меридиандары көрсетілген глобус',
    '🗺' => 'карта',
    '🗾' => 'Жапония картасы',
    '🧭' => 'компас',
    '🏔' => 'төбесін қар басқан тау',
    '⛰' => 'тау',
    '🛘' => 'көшкін',
    '🌋' => 'жанартау',
    '🗻' => 'Фудзияма',
    '🏕' => 'кемпинг',
    '🏖' => 'жағажайда шатырмен',
    '🏜' => 'шөл',
    '🏝' => 'шөлді арал',
    '🏞' => 'ұлттық парк',
    '🏟' => 'стадион',
    '🏛' => 'классикалық ғимарат',
    '🏗' => 'ғимарат салу',
    '🧱' => 'кірпіш',
    '🪨' => 'тас',
    '🪵' => 'ағаш',
    '🛖' => 'лашық',
    '🏘' => 'үйлер',
    '🏚' => 'қараусыз қалған үй',
    '🏠' => 'үй салу',
    '🏡' => 'бақшасы бар үй',
    '🏢' => 'кеңселік ғимарат',
    '🏣' => 'жапондық пошта бөлімшесі',
    '🏤' => 'пошта бөлімшесі',
    '🏥' => 'аурухана',
    '🏦' => 'банк',
    '🏨' => 'қонақ үй',
    '🏩' => 'махаббат үйі',
    '🏪' => 'шағын маркет',
    '🏫' => 'мектеп',
    '🏬' => 'әмбебап дүкен',
    '🏭' => 'зауыт',
    '🏯' => 'жапондық сарай',
    '🏰' => 'сарай',
    '💒' => 'той',
    '🗼' => 'Токио мұнарасы',
    '🗽' => 'Азаттық мүсіні',
    '⛪' => 'шіркеу',
    '🕌' => 'мешіт',
    '🛕' => 'үнді ғибадатханасы',
    '🕍' => 'синагога',
    '⛩' => 'синтоистік храм',
    '🕋' => 'Қағба',
    '⛲' => 'фонтан',
    '⛺' => 'шатыр',
    '🌁' => 'тұманды',
    '🌃' => 'жұлдызды түн',
    '🏙' => 'қала көрінісі',
    '🌄' => 'таулардың артынан шыққан күн',
    '🌅' => 'күннің шығуы',
    '🌆' => 'ымырттағы қала көрінісі',
    '🌇' => 'күннің батуы',
    '🌉' => 'көпірдің түнгі көрінісі',
    '♨' => 'гейзер',
    '🎠' => 'әткеншектегі ат',
    '🛝' => 'төбешік',
    '🎡' => 'шолу дөңгелегі',
    '🎢' => 'аттракцион',
    '💈' => 'шаштараз бағаны',
    '🎪' => 'цирк шатыры',
    '🚂' => 'локомотив',
    '🚃' => 'темір жол вагоны',
    '🚄' => 'экспресс пойызы',
    '🚅' => 'тұмсығы оқ тәрізді экспресс пойызы',
    '🚆' => 'пойыз',
    '🚇' => 'метро',
    '🚈' => 'тар табанды темір жол',
    '🚉' => 'станция',
    '🚊' => 'трамвай',
    '🚝' => 'дара рельсті темір жол',
    '🚞' => 'таулы аймақтағы темір жол',
    '🚋' => 'трамвай вагоны',
    '🚌' => 'автобус',
    '🚍' => 'келе жатқан автобус',
    '🚎' => 'троллейбус',
    '🚐' => 'шағын автобус',
    '🚑' => 'жедел жәрдем',
    '🚒' => 'өрт сөндіру автокөлігі',
    '🚓' => 'полиция автокөлігі',
    '🚔' => 'келе жатқан полиция автокөлігі',
    '🚕' => 'такси',
    '🚖' => 'келе жатқан такси',
    '🚗' => 'автокөлік',
    '🚘' => 'келе жатқан автокөлік',
    '🚙' => 'кроссовер',
    '🛻' => 'пикап',
    '🚚' => 'жүк көлігі',
    '🚛' => 'автопойыз',
    '🚜' => 'трактор',
    '🏎' => 'жарыс автомобилі',
    '🏍' => 'мотоцикл',
    '🛵' => 'скутер',
    '🦽' => 'қол жетегі бар арбаша',
    '🦼' => 'электр жетегі бар арбаша',
    '🛺' => 'моторикша',
    '🚲' => 'велосипед',
    '🛴' => 'самокат',
    '🛹' => 'скейтборд',
    '🛼' => 'ролик',
    '🚏' => 'аялдама',
    '🛣' => 'автомагистраль',
    '🛤' => 'темір жол рельсі',
    '🛢' => 'мұнай өнімдеріне арналған бөшке',
    '⛽' => 'жанармай сорғысы',
    '🛞' => 'дөңгелек',
    '🚨' => 'полиция автокөлігінің шамы',
    '🚥' => 'көлденең бағдаршам',
    '🚦' => 'тік бағдаршам',
    '🛑' => 'тоқта белгісі',
    '🚧' => 'құрылыс',
    '⚓' => 'зәкір',
    '🛟' => 'құтқару шеңбері',
    '⛵' => 'желкенді қайық',
    '🛶' => 'каное',
    '🚤' => 'жылдам жүретін қайық',
    '🛳' => 'жолаушылар кемесі',
    '⛴' => 'паром',
    '🛥' => 'моторлы қайық',
    '🚢' => 'кеме',
    '✈' => 'ұшақ',
    '🛩' => 'шағын ұшақ',
    '🛫' => 'ұшақтық ұшып кетуі',
    '🛬' => 'ұшақтың қонуы',
    '🪂' => 'парашют',
    '💺' => 'орындық',
    '🚁' => 'тік ұшақ',
    '🚟' => 'аспалы темір жол',
    '🚠' => 'таудағы арқан жолы',
    '🚡' => 'аспалы арқан жолы',
    '🛰' => 'жерсерік',
    '🚀' => 'зымыран',
    '🛸' => 'ұшатын тарелка',
    '🛎' => 'шабарман қоңырауы',
    '🧳' => 'жүк',
    '⌛' => 'құмсағат',
    '⏳' => 'құмсағаттан құм ағуда',
    '⌚' => 'қол сағат',
    '⏰' => 'оятқыш',
    '⏱' => 'секунд өлшеуіш',
    '⏲' => 'таймер',
    '🕰' => 'сөреге қойылатын сағат',
    '🕛' => 'сағат он екі',
    '🕧' => 'он екі жарым',
    '🕐' => 'сағат бір',
    '🕜' => 'бір жарым',
    '🕑' => 'сағат екі',
    '🕝' => 'екі жарым',
    '🕒' => 'сағат үш',
    '🕞' => 'үш жарым',
    '🕓' => 'сағат төрт',
    '🕟' => 'төрт жарым',
    '🕔' => 'сағат бес',
    '🕠' => 'бес жарым',
    '🕕' => 'сағат алты',
    '🕡' => 'алты жарым',
    '🕖' => 'сағат жеті',
    '🕢' => 'жеті жарым',
    '🕗' => 'сағат сегіз',
    '🕣' => 'сегіз жарым',
    '🕘' => 'сағат тоғыз',
    '🕤' => 'тоғыз жарым',
    '🕙' => 'сағат он',
    '🕥' => 'он жарым',
    '🕚' => 'сағат он бір',
    '🕦' => 'он бір жарым',
    '🌑' => 'жаңа ай',
    '🌒' => 'толып жатқан жарты ай',
    '🌓' => 'айдың бірінші ширегі',
    '🌔' => 'толып жатқан дөңес ай',
    '🌕' => 'толған ай',
    '🌖' => 'кішірейіп жатқан дөңес ай',
    '🌗' => 'айдың соңғы ширегі',
    '🌘' => 'кішірейіп жатқан жарты ай',
    '🌙' => 'жарты ай',
    '🌚' => 'жаңа ай беті',
    '🌛' => 'беті бар бірінші ширек айы',
    '🌜' => 'беті бар соңғы ширек айы',
    '🌡' => 'термометр',
    '☀' => 'күн',
    '🌝' => 'толған ай беті',
    '🌞' => 'беті бейнеленген күн',
    '🪐' => 'сақинасы бар планета',
    '⭐' => 'жұлдыз',
    '🌟' => 'жарқырап тұрған жұлдыз',
    '🌠' => 'ұшқан жұлдыз',
    '🌌' => 'Құс жолы',
    '☁' => 'бұлт',
    '⛅' => 'бұлттың артындағы күн',
    '⛈' => 'найзағай мен жаңбыр',
    '🌤' => 'кіші бұлттың артындағы күн',
    '🌥' => 'үлкен бұлттың артындағы күн',
    '🌦' => 'жаңбыр жауып тұрған бұлттың артындағы күн',
    '🌧' => 'жаңбыр жауып тұрған бұлт',
    '🌨' => 'қар жауып тұрған бұлт',
    '🌩' => 'найзағай соғып тұрған бұлт',
    '🌪' => 'торнадо',
    '🌫' => 'тұман',
    '🌬' => 'бет көрінісіндегі жел',
    '🌀' => 'циклон',
    '🌈' => 'кемпірқосақ',
    '🌂' => 'жабылған қолшатыр',
    '☂' => 'қолшатыр',
    '☔' => 'жаңбыр тамшылары бар қолшатыр',
    '⛱' => 'қолшатыр жерде тұр',
    '⚡' => 'жоғары кернеу',
    '❄' => 'қар бүршігі',
    '☃' => 'аққала',
    '⛄' => 'қарсыз аққала',
    '☄' => 'комета',
    '🔥' => 'өрт',
    '💧' => 'тамшы',
    '🌊' => 'толқын',
    '🎃' => 'асқабақтан жасалған шам',
    '🎄' => 'Рождество шыршасы',
    '🎆' => 'фейерверк',
    '🎇' => 'бенгал оты',
    '🧨' => 'отшашу',
    '✨' => 'ұшқындар',
    '🎈' => 'шар',
    '🎉' => 'шартылдақ',
    '🎊' => 'конфетти шары',
    '🎋' => 'танабата ағашы',
    '🎍' => 'қарағай декорациясы',
    '🎎' => 'жапон қуыршақтары',
    '🎏' => 'тұқы таспа',
    '🎐' => 'қытай қоңырауы',
    '🎑' => 'цукуми',
    '🧧' => 'қызыл конверт',
    '🎀' => 'таспа',
    '🎁' => 'оралған сыйлық',
    '🎗' => 'еске салғыш таспасы',
    '🎟' => 'қабылдау билеттері',
    '🎫' => 'билет',
    '🎖' => 'әскери медаль',
    '🏆' => 'олжа',
    '🏅' => 'спорттық медаль',
    '🥇' => 'алтын медаль',
    '🥈' => 'күміс медаль',
    '🥉' => 'қола медаль',
    '⚽' => 'футбол добы',
    '⚾' => 'бейсбол',
    '🥎' => 'софтбол',
    '🏀' => 'баскетбол',
    '🏐' => 'волейбол',
    '🏈' => 'америкалық футбол',
    '🏉' => 'регби',
    '🎾' => 'теннис',
    '🥏' => 'ұшатын диск',
    '🎳' => 'боулинг',
    '🏏' => 'крикет',
    '🏑' => 'шөп үстіндегі хоккей',
    '🏒' => 'хоккей',
    '🥍' => 'лакросс',
    '🏓' => 'пинг-понг',
    '🏸' => 'бадминтон',
    '🥊' => 'бокс қолғабы',
    '🥋' => 'жауынгерлік өнер формасы',
    '🥅' => 'қақпа',
    '⛳' => 'саңылаудағы жалауша',
    '⛸' => 'коньки',
    '🎣' => 'қармақ',
    '🤿' => 'дайвингіге арналған маска',
    '🎽' => 'жүгіруге арналған футболка',
    '🎿' => 'шаңғы',
    '🛷' => 'шана',
    '🥌' => 'керлинг тасы',
    '🎯' => 'нысана ортасы',
    '🪀' => 'йо-йо',
    '🪁' => 'қағаз батпырауық',
    '🔫' => 'тапанша',
    '🎱' => 'пул-8',
    '🔮' => 'сыйқырлы шар',
    '🪄' => 'сиқырлы таяқша',
    '🎮' => 'бейне ойын',
    '🕹' => 'джойстик',
    '🎰' => 'ойын автоматы',
    '🎲' => 'ойын текшесі',
    '🧩' => 'мозаика',
    '🧸' => 'қыжым қонжық',
    '🪅' => 'пиньята',
    '🪩' => 'айналы шар',
    '🪆' => 'матрешка',
    '♠' => 'қарға',
    '♥' => 'жүрек',
    '♦' => 'қиық',
    '♣' => 'шыбын',
    '♟' => 'пешка',
    '🃏' => 'джокер',
    '🀄' => 'маджонг қызыл айдаһар',
    '🎴' => 'гүлді ойын карталары',
    '🎭' => 'театр өнері',
    '🖼' => 'жақтаулы сурет',
    '🎨' => 'палитра',
    '🧵' => 'жіп',
    '🪡' => 'тігін ине',
    '🧶' => 'иірімжіп',
    '🪢' => 'түйін',
    '👓' => 'көзілдірік',
    '🕶' => 'күннен қорғайтын көзілдірік',
    '🥽' => 'жаздық көзілдірік',
    '🥼' => 'зертханалық киім',
    '🦺' => 'сигналдық жилет',
    '👔' => 'галстук',
    '👕' => 'футболка',
    '👖' => 'джинс',
    '🧣' => 'шарф',
    '🧤' => 'қолғап',
    '🧥' => 'пальто',
    '🧦' => 'шұлық',
    '👗' => 'көйлек',
    '👘' => 'кимоно',
    '🥻' => 'сари',
    '🩱' => 'жабық шомылу киімі',
    '🩲' => 'плавки',
    '🩳' => 'шолақ шалбар',
    '👙' => 'бикини',
    '👚' => 'әйелдер киімі',
    '🪭' => 'желпуіш',
    '👛' => 'әйелдер әмияны',
    '👜' => 'қолдорба',
    '👝' => 'сөмке',
    '🛍' => 'сауда қалталары',
    '🎒' => 'папка',
    '🩴' => 'вьетнамдық сандал',
    '👞' => 'туфли',
    '👟' => 'кроссовка',
    '🥾' => 'туристік аяқкиім',
    '🥿' => 'жайпақ туфли',
    '👠' => 'биік өкшелі туфли',
    '👡' => 'әйелдер сандалы',
    '🩰' => 'балетшінің аяқ киімі',
    '👢' => 'әйелдер етігі',
    '🪮' => 'тарақ',
    '👑' => 'тәж',
    '👒' => 'әйелдер қалпағы',
    '🎩' => 'қоқырайма',
    '🎓' => 'бітіру қалпағы',
    '🧢' => 'күнқағар кепка',
    '🪖' => 'әскери каска',
    '⛑' => 'ақ крест бейнеленген дулыға',
    '📿' => 'таспиқ',
    '💄' => 'далап',
    '💍' => 'жүзік',
    '💎' => 'асыл тас',
    '🔇' => 'динамикті өшіру',
    '🔈' => 'динамик',
    '🔉' => 'динамикті қосу',
    '🔊' => 'динамиктің дыбысын шығару',
    '📢' => 'дауыс зорайтқыш',
    '📣' => 'мегафон',
    '📯' => 'керней',
    '🔔' => 'қоңырау',
    '🔕' => 'қоңырау дыбысы өшірілген',
    '🎼' => 'партитура',
    '🎵' => 'нота',
    '🎶' => 'ноталар',
    '🎙' => 'студио микрофоны',
    '🎚' => 'деңгей сырғытпасы',
    '🎛' => 'басқару түймелері',
    '🎤' => 'микрофон',
    '🎧' => 'құлақаспап',
    '📻' => 'радио',
    '🎷' => 'саксофон',
    '🎺' => 'труба',
    '🪊' => 'тромбон',
    '🪗' => 'аккордеон',
    '🎸' => 'гитара',
    '🎹' => 'музыкалық пернетақта',
    '🎻' => 'скрипка',
    '🪕' => 'банджо',
    '🥁' => 'барабан',
    '🪘' => 'цилиндрлік барабан',
    '🪇' => 'маракас',
    '🪈' => 'сыбызғы',
    '🪉' => 'арфа',
    '📱' => 'ұялы телефон',
    '📲' => 'ұялы телефонға қабылдау',
    '☎' => 'телефон',
    '📞' => 'телефон ресивері',
    '📟' => 'пейджер',
    '📠' => 'факс машина',
    '🔋' => 'батарея',
    '🪫' => 'батарея заряды төмен',
    '🔌' => 'тығын',
    '💻' => 'ноутбук',
    '🖥' => 'дербес компьютер',
    '🖨' => 'принтер',
    '⌨' => 'пернетақта',
    '🖱' => 'тінтуір',
    '🖲' => 'трекбол',
    '💽' => 'шағын диск',
    '💾' => 'алмалы диск',
    '💿' => 'оптикалық диск',
    '📀' => 'DVD',
    '🧮' => 'абакус',
    '🎥' => 'бейнефильм түсіретін камера',
    '🎞' => 'фильм кадрлары',
    '📽' => 'кинопроектор',
    '🎬' => 'шартылдақ нөмірлеуіш',
    '📺' => 'теледидар',
    '📷' => 'камера',
    '📸' => 'жарқылы бар камера',
    '📹' => 'бейнекамера',
    '📼' => 'бейне кассета',
    '🔍' => 'сол жақты көрсететін үлкейткіш әйнек',
    '🔎' => 'оң жақты көрсететін үлкейткіш әйнек',
    '🕯' => 'майшам',
    '💡' => 'лампа',
    '🔦' => 'жарқыл жарығы',
    '🏮' => 'қағаздан жасалған қызыл шам',
    '🪔' => 'дия',
    '📔' => 'декоративтік мұқабасы бар дәптер',
    '📕' => 'жабық кітап',
    '📖' => 'ашық кітап',
    '📗' => 'жасыл кітап',
    '📘' => 'көк кітап',
    '📙' => 'сарғыш кітап',
    '📚' => 'кітаптар',
    '📓' => 'дәптер',
    '📒' => 'басты кітап',
    '📃' => 'бір шеті оралған бет',
    '📜' => 'бұрама қағаз',
    '📄' => 'жоғары қарап тұрған бет',
    '📰' => 'газет',
    '🗞' => 'бүктелген газет',
    '📑' => 'бетбелгілер қойындысы',
    '🔖' => 'бетбелгі',
    '🏷' => 'затбелгі',
    '🪙' => 'тиын',
    '💰' => 'ақша салынған қалта',
    '🪎' => 'қазына сандығы',
    '💴' => 'йена банкнотасы',
    '💵' => 'доллар банкнотасы',
    '💶' => 'еуро банкнотасы',
    '💷' => 'фунт банкнотасы',
    '💸' => 'қанаты бар ақша',
    '💳' => 'несие картасы',
    '🧾' => 'түбіртек',
    '💹' => 'йена бағамы көтерілгенін көрсететін диаграмма',
    '✉' => 'конверт',
    '📧' => 'электрондық пошта',
    '📨' => 'келген конверт',
    '📩' => 'көрсеткісі бар конверт',
    '📤' => 'шығыс жәшігі',
    '📥' => 'кіріс жәшігі',
    '📦' => 'қорап',
    '📫' => 'жалаушасы көтерілген жабық пошта жәшігі',
    '📪' => 'жалаушасы түсірілген жабық пошта жәшігі',
    '📬' => 'жалаушасы көтерілген ашық пошта жәшігі',
    '📭' => 'жалаушасы түсірілген ашық пошта жәшігі',
    '📮' => 'пошта жәшігі',
    '🗳' => 'сайлау бюллетенін тастайтын жәшік',
    '✏' => 'қарындаш',
    '✒' => 'қара қауырсын',
    '🖋' => 'автоқалам',
    '🖊' => 'қалам',
    '🖌' => 'бояу щеткасы',
    '🖍' => 'пастель',
    '📝' => 'жаднама',
    '💼' => 'портфель',
    '📁' => 'файл қалтасы',
    '📂' => 'файл қалтасын ашу',
    '🗂' => 'карта индексін бөлгіштер',
    '📅' => 'күнтізбе',
    '📆' => 'жыртпалы күнтізбе',
    '🗒' => 'спиралды дәптер',
    '🗓' => 'спиралды күнтізбе',
    '📇' => 'карта индексі',
    '📈' => 'өсім туралы диаграмма',
    '📉' => 'кему туралы диаграмма',
    '📊' => 'гистограмма',
    '📋' => 'тақта',
    '📌' => 'кеңселік батырма',
    '📍' => 'басы доңғалақ батырма',
    '📎' => 'қағаз түйреуіш',
    '🖇' => 'байланысқан қағаз қысқыштары',
    '📏' => 'түзу сызғыш',
    '📐' => 'үшбұрышты сызғыш',
    '✂' => 'қайшы',
    '🗃' => 'карталық файлдарға арналған жәшік',
    '🗄' => 'картотекалық сөре',
    '🗑' => 'қоқыс себеті',
    '🔒' => 'құлып',
    '🔓' => 'ашық құлып',
    '🔏' => 'қалам мен құлып',
    '🔐' => 'кілті бар жабық құлып',
    '🔑' => 'кілт',
    '🗝' => 'ескі кілт',
    '🔨' => 'балға',
    '🪓' => 'балта',
    '⛏' => 'қайла',
    '⚒' => 'балға мен қайла',
    '🛠' => 'балға мен сомын кілт',
    '🗡' => 'қанжар',
    '⚔' => 'айқас қылыштар',
    '💣' => 'бомба',
    '🪃' => 'бумеранг',
    '🏹' => 'жебе мен садақ',
    '🛡' => 'қалқан',
    '🪚' => 'ара',
    '🔧' => 'сомын кілт',
    '🪛' => 'бұрағыш',
    '🔩' => 'сомын мен бұранда',
    '⚙' => 'тегершік',
    '🗜' => 'қысу',
    '⚖' => 'иінтіректі таразы',
    '🦯' => 'таяқ',
    '🔗' => 'шынжыр',
    '⛓' => 'тізбек',
    '🪝' => 'ілгек',
    '🧰' => 'құралдар жәшігі',
    '🧲' => 'магнит',
    '🪜' => 'саты',
    '🪏' => 'күрек',
    '⚗' => 'дистиллятор',
    '🧪' => 'шыны түтік',
    '🧫' => 'Петри ыдысы',
    '🧬' => 'днк',
    '🔬' => 'микроскоп',
    '🔭' => 'телескоп',
    '📡' => 'серіктік антенна',
    '💉' => 'шприц',
    '🩸' => 'қан тамшысы',
    '💊' => 'таблетка',
    '🩹' => 'жабысқақ пластырь',
    '🩼' => 'балдақ',
    '🩺' => 'стетоскоп',
    '🩻' => 'рентген сәулесі',
    '🚪' => 'есік',
    '🛗' => 'лифт',
    '🪞' => 'айна',
    '🪟' => 'терезе',
    '🛏' => 'кереует',
    '🛋' => 'диван мен шам',
    '🪑' => 'арқалығы бар орындық',
    '🚽' => 'унитаз',
    '🪠' => 'вантуз',
    '🚿' => 'душ',
    '🛁' => 'ванна',
    '🪤' => 'қақпан',
    '🪒' => 'ұстара',
    '🧴' => 'лосьон құтысы',
    '🧷' => 'түйреуіш',
    '🧹' => 'сыпырғы',
    '🧺' => 'себет',
    '🧻' => 'қағаз орамасы',
    '🪣' => 'шелек',
    '🧼' => 'сабын',
    '🫧' => 'көпіршіктер',
    '🪥' => 'тіс щеткасы',
    '🧽' => 'губка',
    '🧯' => 'өрт сөндіргіш',
    '🛒' => 'сауда арбасы',
    '🚬' => 'шылым шегу',
    '⚰' => 'табыт',
    '🪦' => 'сағана',
    '⚱' => 'өліктің күлін салатын сауыт',
    '🧿' => 'бойтұмар',
    '🪬' => 'хамса',
    '🗿' => 'моай',
    '🪧' => 'плакат',
    '🪪' => 'сәйкестендіру картасы',
    '🏧' => 'банкомат белгісі',
    '🚮' => 'қоқысты себетке тастау белгісі',
    '🚰' => 'ішетін су',
    '♿' => 'мүгедектер арбашасы',
    '🚹' => 'ерлер бөлмесі',
    '🚺' => 'әйелдер бөлмесі',
    '🚻' => 'әжетхана',
    '🚼' => 'сәбилер',
    '🚾' => 'ватерклозет',
    '🛂' => 'құжаттарды тексеру',
    '🛃' => 'кеден тексерісі',
    '🛄' => 'жолжүкті беру',
    '🛅' => 'сақтау камерасы',
    '⚠' => 'ескерту',
    '🚸' => 'балалар кесіп өтеді',
    '⛔' => 'жол жоқ',
    '🚫' => 'тыйым салынған',
    '🚳' => 'велосипед тебуге болмайды',
    '🚭' => 'шылым шегуге болмайды',
    '🚯' => 'қоқыс тастауға тыйым салынған',
    '🚱' => 'ішетін су емес',
    '🚷' => 'жаяу жүргіншілерге тыйым салынған',
    '📵' => 'ұялы телефондарды пайдалануға болмайды',
    '🔞' => '18 жастан кішілерге тыйым салынған',
    '☢' => 'радиоактивті аймақ',
    '☣' => 'биологиялық қауіп',
    '⬆' => 'жоғары қараған көрсеткі',
    '↗' => 'жоғарғы оң жақ көрсеткісі',
    '➡' => 'оң жақ бағытты көрсеткі',
    '↘' => 'төменгі оң жақ көрсеткісі',
    '⬇' => 'төмен қараған көрсеткі',
    '↙' => 'төменгі сол жақ көрсеткісі',
    '⬅' => 'сол жақ бағытты көрсеткі',
    '↖' => 'жоғарғы сол жақ көрсеткісі',
    '↕' => 'жоғары-төмен көрсеткісі',
    '↔' => 'сол-оң көрсеткісі',
    '↩' => 'оң жақтан шығып, сол жаққа бұрылатын көрсеткі',
    '↪' => 'сол жақтан шығып, оң жаққа бұрылатын көрсеткі',
    '⤴' => 'оң жақтан шығып, жоғарыға бұрылатын көрсеткі',
    '⤵' => 'оң жақтан шығып, төменге бұрылатын көрсеткі',
    '🔃' => 'сағат тілі бойынша тік көрсеткілер',
    '🔄' => 'сағат тіліне қарама-қарсы көрсеткілер түймесі',
    '🔙' => '«артқа» көрсеткісі',
    '🔚' => '«соңы» көрсеткісі',
    '🔛' => '«қосулы» көрсеткісі',
    '🔜' => '«жақында» көрсеткісі',
    '🔝' => '«негізгі» көрсеткісі',
    '🛐' => 'табыну орны',
    '⚛' => 'атом белгісі',
    '🕉' => 'ом белгісі',
    '✡' => 'Давид жұлдызы',
    '☸' => 'дхарма доңғалағы',
    '☯' => 'инь-ян белгісі',
    '✝' => 'латынша крест',
    '☦' => 'ортодоксалдық крест',
    '☪' => 'жұлдыз бен жарым ай',
    '☮' => 'тыныштық белгісі',
    '🕎' => 'менора',
    '🔯' => 'нүктелі алты бұрышты жұлдыз',
    '🪯' => 'кханда',
    '♈' => 'тоқты белгісі',
    '♉' => 'торпақ белгісі',
    '♊' => 'егіздер белгісі',
    '♋' => 'шаян белгісі',
    '♌' => 'арыстан белгісі',
    '♍' => 'бикеш белгісі',
    '♎' => 'таразы белгісі',
    '♏' => 'сарышаян белгісі',
    '♐' => 'мерген белгісі',
    '♑' => 'тауешкі белгісі',
    '♒' => 'суқұйғыш белгісі',
    '♓' => 'балықтар белгісі',
    '⛎' => 'жылан көтеруші белгісі',
    '🔀' => 'кездейсоқ тректер түймесі',
    '🔁' => 'қайталау түймесі',
    '🔂' => 'бір тректі қайталау түймесі',
    '▶' => 'ойнату түймесі',
    '⏩' => 'алға жылдам өткізу түймесі',
    '⏭' => 'келесі трек түймесі',
    '⏯' => 'ойнату не кідірту түймесі',
    '◀' => 'кері қайтару түймесі',
    '⏪' => 'артқа жылдам қайтару түймесі',
    '⏮' => 'соңғы трек түймесі',
    '🔼' => 'жоғары түймесі',
    '⏫' => 'жоғарыға жылдам өткізу түймесі',
    '🔽' => 'төмен түймесі',
    '⏬' => 'төменге жылдам өткізу түймесі',
    '⏸' => 'кідірту түймесі',
    '⏹' => 'тоқтату түймесі',
    '⏺' => 'жазып алу түймесу',
    '⏏' => 'шығарып алу түймесі',
    '🎦' => 'кино',
    '🔅' => 'күңгірттеу түймесі',
    '🔆' => 'жарықтандыру түймесі',
    '📶' => 'антенна таяқшалары',
    '🛜' => 'сымсыз желі',
    '📳' => 'дірілдеу режимі',
    '📴' => 'ұялы телефонды өшіру',
    '♀' => 'әйел таңбасы',
    '♂' => 'ер таңбасы',
    '⚧' => 'трансгендерлік таңба',
    '✖' => 'көбейту',
    '➕' => 'плюс',
    '➖' => 'минус',
    '➗' => 'бөлу',
    '🟰' => 'теңдік белгісі',
    '♾' => 'шексіздік',
    '‼' => 'қос леп белгісі',
    '⁉' => 'леп және сұрақ белгісі',
    '❓' => 'қызыл сұрақ белгісі',
    '❔' => 'ақ сұрақ белгісі',
    '❕' => 'ақ леп белгісі',
    '❗' => 'леп белгісі',
    '〰' => 'ирек сызықша',
    '💱' => 'валюта айырбастау',
    '💲' => 'қалың доллар белгісі',
    '⚕' => 'медицина таңбасы',
    '♻' => 'қайта өңдеу белгісі',
    '⚜' => 'француз лилиясы',
    '🔱' => 'үш ашалы айыр белгісі',
    '📛' => 'ат бейджигі',
    '🔰' => 'бастаушыларға арналған жапон белгісі',
    '⭕' => 'Қалың, үлкен шеңбер',
    '✅' => 'Ақ, қалың құсбелгі',
    '☑' => 'Құсбелгісі бар дауыс беру шаршысы',
    '✔' => 'қалың құсбелгі',
    '❌' => 'қиылысқан сызықтар белгісі',
    '❎' => 'қиылысқан сызықтар түймесі',
    '➰' => 'ілмек',
    '➿' => 'қос ілмек',
    '〽' => 'бөліктің өзгеру белгісі',
    '✳' => 'сегіз бұрышты жұлдыз',
    '✴' => 'сегіз қырлы жұлдыз',
    '❇' => 'ұшқын',
    '™' => 'сауда белгісі',
    '🫟' => 'шашыранды',
    '🔠' => 'үлкен латын әріптерін енгізу',
    '🔡' => 'кіші латын әріптерін енгізу',
    '🔢' => 'сандарды енгізу',
    '🔣' => 'белгілерді енгізу',
    '🔤' => 'латын әріптерін енгізу',
    '🅰' => 'А түймесі (қызыл түсті)',
    '🆎' => 'AB түймесі (қызыл түсті)',
    '🅱' => 'B түймесі (қызыл түсті)',
    '🆑' => 'CL түймесі',
    '🆒' => 'COOL түймесі',
    '🆓' => 'FREE түймесі',
    'ℹ' => 'ақпарат көзі',
    '🆔' => 'ID түймесі',
    'Ⓜ' => 'шеңбердегі M',
    '🆕' => 'NEW түймесі',
    '🆖' => 'NG түймесі',
    '🅾' => 'O түймесі (қызыл түсті)',
    '🆗' => 'OK түймесі',
    '🅿' => 'P түймесі',
    '🆘' => 'SOS түймесі',
    '🆙' => 'UP! түймесі',
    '🆚' => 'VS түймесі',
    '🈁' => 'шаршыдағы «катакана коко»',
    '🈂' => 'шаршыдағы «катакана са»',
    '🈷' => 'шаршыдағы «ай» иероглифі',
    '🈶' => 'шаршыдағы «болмыс» иероглифі',
    '🈯' => 'шаршыдағы «саусақ» иероглифі',
    '🉐' => 'доңғалақтағы «артықшылық» иероглифі',
    '🈹' => 'шаршыдағы «бөлу» иероглифі',
    '🈚' => 'шаршыдағы «бас тарту» иероглифі',
    '🈲' => 'шаршыдағы «тыйым салу» иероглифі',
    '🉑' => 'доңғалақтағы «қабылдау» иероглифі',
    '🈸' => 'шаршыдағы «қолдану» иероглифі',
    '🈴' => 'шаршыдағы «бірге» иероглифі',
    '🈳' => 'шаршыдағы «бос» иероглифі',
    '㊗' => 'доңғалақтағы «құттықтау» иероглифі',
    '㊙' => 'доңғалақтағы «құпия» иероглифі',
    '🈺' => 'шаршыдағы «жұмыс» иероглифі',
    '🈵' => 'шаршыдағы «толықтық» иероглифі',
    '🔴' => 'қызыл дөңгелек',
    '🟠' => 'қызғылт сары дөңгелек',
    '🟡' => 'сары дөңгелек',
    '🟢' => 'жасыл дөңгелек',
    '🔵' => 'көк дөңгелек',
    '🟣' => 'күлгін дөңгелек',
    '🟤' => 'қоңыр дөңгелек',
    '⚫' => 'қара дөңгелек',
    '⚪' => 'ақ дөңгелек',
    '🟥' => 'қызыл шаршы',
    '🟧' => 'қызғылт сары шаршы',
    '🟨' => 'сары шаршы',
    '🟩' => 'жасыл шаршы',
    '🟦' => 'көк шаршы',
    '🟪' => 'күлгін шаршы',
    '🟫' => 'қоңыр шаршы',
    '⬛' => 'үлкен қара шаршы',
    '⬜' => 'үлкен ақ шаршы',
    '◼' => 'орташа қара шаршы',
    '◻' => 'орташа ақ шаршы',
    '◾' => 'орташа-кіші қара шаршы',
    '◽' => 'орташа-кіші ақ шаршы',
    '▪' => 'кіші қара шаршы',
    '▫' => 'кіші ақ шаршы',
    '🔶' => 'үлкен сарғыш ромб',
    '🔷' => 'үлкен көк ромб',
    '🔸' => 'кіші сарғыш ромб',
    '🔹' => 'кіші көк ромб',
    '🔺' => 'жоғары қаратылған кіші үшбұрыш',
    '🔻' => 'төмен қаратылған кіші үшбұрыш',
    '💠' => 'нүктелі ромб',
    '🔘' => 'радио түймесі',
    '🔳' => 'ақ шаршы түймесі',
    '🔲' => 'қара шаршы түймесі',
    '🏁' => 'торлы жалауша',
    '🚩' => 'үшбұрышты жалау',
    '🎌' => 'айқастырылған жалаушалар',
    '🏴' => 'қара жалау',
    '🏳' => 'ақ жалау',
];
