<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'pusu: aikuinen, aikuinen, vaalea iho, keskivaalea iho',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'pusu: aikuinen, aikuinen, vaalea iho, tummanvaalea iho',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'pusu: aikuinen, aikuinen, vaalea iho, keskitumma iho',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'pusu: aikuinen, aikuinen, vaalea iho, tumma iho',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'pusu: aikuinen, aikuinen, keskivaalea iho, vaalea iho',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'pusu: aikuinen, aikuinen, keskivaalea iho, tummanvaalea iho',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'pusu: aikuinen, aikuinen, keskivaalea iho, keskitumma iho',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'pusu: aikuinen, aikuinen, keskivaalea iho, tumma iho',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'pusu: aikuinen, aikuinen, tummanvaalea iho, vaalea iho',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'pusu: aikuinen, aikuinen, tummanvaalea iho, keskivaalea iho',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'pusu: aikuinen, aikuinen, tummanvaalea iho, keskitumma iho',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'pusu: aikuinen, aikuinen, tummanvaalea iho, tumma iho',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'pusu: aikuinen, aikuinen, keskitumma iho, vaalea iho',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'pusu: aikuinen, aikuinen, keskitumma iho, keskivaalea iho',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'pusu: aikuinen, aikuinen, keskitumma iho, tummanvaalea iho',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'pusu: aikuinen, aikuinen, keskitumma iho, tumma iho',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'pusu: aikuinen, aikuinen, tumma iho, vaalea iho',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'pusu: aikuinen, aikuinen, tumma iho, keskivaalea iho',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'pusu: aikuinen, aikuinen, tumma iho, tummanvaalea iho',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'pusu: aikuinen, aikuinen, tumma iho, keskitumma iho',
    '👨🏻‍❤‍💋‍👨🏻' => 'pusu: mies, mies, vaalea iho',
    '👨🏻‍❤‍💋‍👨🏼' => 'pusu: mies, mies, vaalea iho, keskivaalea iho',
    '👨🏻‍❤‍💋‍👨🏽' => 'pusu: mies, mies, vaalea iho, tummanvaalea iho',
    '👨🏻‍❤‍💋‍👨🏾' => 'pusu: mies, mies, vaalea iho, keskitumma iho',
    '👨🏻‍❤‍💋‍👨🏿' => 'pusu: mies, mies, vaalea iho, tumma iho',
    '👨🏼‍❤‍💋‍👨🏻' => 'pusu: mies, mies, keskivaalea iho, vaalea iho',
    '👨🏼‍❤‍💋‍👨🏼' => 'pusu: mies, mies, keskivaalea iho',
    '👨🏼‍❤‍💋‍👨🏽' => 'pusu: mies, mies, keskivaalea iho, tummanvaalea iho',
    '👨🏼‍❤‍💋‍👨🏾' => 'pusu: mies, mies, keskivaalea iho, keskitumma iho',
    '👨🏼‍❤‍💋‍👨🏿' => 'pusu: mies, mies, keskivaalea iho, tumma iho',
    '👨🏽‍❤‍💋‍👨🏻' => 'pusu: mies, mies, tummanvaalea iho, vaalea iho',
    '👨🏽‍❤‍💋‍👨🏼' => 'pusu: mies, mies, tummanvaalea iho, keskivaalea iho',
    '👨🏽‍❤‍💋‍👨🏽' => 'pusu: mies, mies, tummanvaalea iho',
    '👨🏽‍❤‍💋‍👨🏾' => 'pusu: mies, mies, tummanvaalea iho, keskitumma iho',
    '👨🏽‍❤‍💋‍👨🏿' => 'pusu: mies, mies, tummanvaalea iho, tumma iho',
    '👨🏾‍❤‍💋‍👨🏻' => 'pusu: mies, mies, keskitumma iho, vaalea iho',
    '👨🏾‍❤‍💋‍👨🏼' => 'pusu: mies, mies, keskitumma iho, keskivaalea iho',
    '👨🏾‍❤‍💋‍👨🏽' => 'pusu: mies, mies, keskitumma iho, tummanvaalea iho',
    '👨🏾‍❤‍💋‍👨🏾' => 'pusu: mies, mies, keskitumma iho',
    '👨🏾‍❤‍💋‍👨🏿' => 'pusu: mies, mies, keskitumma iho, tumma iho',
    '👨🏿‍❤‍💋‍👨🏻' => 'pusu: mies, mies, tumma iho, vaalea iho',
    '👨🏿‍❤‍💋‍👨🏼' => 'pusu: mies, mies, tumma iho, keskivaalea iho',
    '👨🏿‍❤‍💋‍👨🏽' => 'pusu: mies, mies, tumma iho, tummanvaalea iho',
    '👨🏿‍❤‍💋‍👨🏾' => 'pusu: mies, mies, tumma iho, keskitumma iho',
    '👨🏿‍❤‍💋‍👨🏿' => 'pusu: mies, mies, tumma iho',
    '👩🏻‍❤‍💋‍👨🏻' => 'pusu: nainen, mies, vaalea iho',
    '👩🏻‍❤‍💋‍👨🏼' => 'pusu: nainen, mies, vaalea iho, keskivaalea iho',
    '👩🏻‍❤‍💋‍👨🏽' => 'pusu: nainen, mies, vaalea iho, tummanvaalea iho',
    '👩🏻‍❤‍💋‍👨🏾' => 'pusu: nainen, mies, vaalea iho, keskitumma iho',
    '👩🏻‍❤‍💋‍👨🏿' => 'pusu: nainen, mies, vaalea iho, tumma iho',
    '👩🏼‍❤‍💋‍👨🏻' => 'pusu: nainen, mies, keskivaalea iho, vaalea iho',
    '👩🏼‍❤‍💋‍👨🏼' => 'pusu: nainen, mies, keskivaalea iho',
    '👩🏼‍❤‍💋‍👨🏽' => 'pusu: nainen, mies, keskivaalea iho, tummanvaalea iho',
    '👩🏼‍❤‍💋‍👨🏾' => 'pusu: nainen, mies, keskivaalea iho, keskitumma iho',
    '👩🏼‍❤‍💋‍👨🏿' => 'pusu: nainen, mies, keskivaalea iho, tumma iho',
    '👩🏽‍❤‍💋‍👨🏻' => 'pusu: nainen, mies, tummanvaalea iho, vaalea iho',
    '👩🏽‍❤‍💋‍👨🏼' => 'pusu: nainen, mies, tummanvaalea iho, keskivaalea iho',
    '👩🏽‍❤‍💋‍👨🏽' => 'pusu: nainen, mies, tummanvaalea iho',
    '👩🏽‍❤‍💋‍👨🏾' => 'pusu: nainen, mies, tummanvaalea iho, keskitumma iho',
    '👩🏽‍❤‍💋‍👨🏿' => 'pusu: nainen, mies, tummanvaalea iho, tumma iho',
    '👩🏾‍❤‍💋‍👨🏻' => 'pusu: nainen, mies, keskitumma iho, vaalea iho',
    '👩🏾‍❤‍💋‍👨🏼' => 'pusu: nainen, mies, keskitumma iho, keskivaalea iho',
    '👩🏾‍❤‍💋‍👨🏽' => 'pusu: nainen, mies, keskitumma iho, tummanvaalea iho',
    '👩🏾‍❤‍💋‍👨🏾' => 'pusu: nainen, mies, keskitumma iho',
    '👩🏾‍❤‍💋‍👨🏿' => 'pusu: nainen, mies, keskitumma iho, tumma iho',
    '👩🏿‍❤‍💋‍👨🏻' => 'pusu: nainen, mies, tumma iho, vaalea iho',
    '👩🏿‍❤‍💋‍👨🏼' => 'pusu: nainen, mies, tumma iho, keskivaalea iho',
    '👩🏿‍❤‍💋‍👨🏽' => 'pusu: nainen, mies, tumma iho, tummanvaalea iho',
    '👩🏿‍❤‍💋‍👨🏾' => 'pusu: nainen, mies, tumma iho, keskitumma iho',
    '👩🏿‍❤‍💋‍👨🏿' => 'pusu: nainen, mies, tumma iho',
    '👩🏻‍❤‍💋‍👩🏻' => 'pusu: nainen, nainen, vaalea iho',
    '👩🏻‍❤‍💋‍👩🏼' => 'pusu: nainen, nainen, vaalea iho, keskivaalea iho',
    '👩🏻‍❤‍💋‍👩🏽' => 'pusu: nainen, nainen, vaalea iho, tummanvaalea iho',
    '👩🏻‍❤‍💋‍👩🏾' => 'pusu: nainen, nainen, vaalea iho, keskitumma iho',
    '👩🏻‍❤‍💋‍👩🏿' => 'pusu: nainen, nainen, vaalea iho, tumma iho',
    '👩🏼‍❤‍💋‍👩🏻' => 'pusu: nainen, nainen, keskivaalea iho, vaalea iho',
    '👩🏼‍❤‍💋‍👩🏼' => 'pusu: nainen, nainen, keskivaalea iho',
    '👩🏼‍❤‍💋‍👩🏽' => 'pusu: nainen, nainen, keskivaalea iho, tummanvaalea iho',
    '👩🏼‍❤‍💋‍👩🏾' => 'pusu: nainen, nainen, keskivaalea iho, keskitumma iho',
    '👩🏼‍❤‍💋‍👩🏿' => 'pusu: nainen, nainen, keskivaalea iho, tumma iho',
    '👩🏽‍❤‍💋‍👩🏻' => 'pusu: nainen, nainen, tummanvaalea iho, vaalea iho',
    '👩🏽‍❤‍💋‍👩🏼' => 'pusu: nainen, nainen, tummanvaalea iho, keskivaalea iho',
    '👩🏽‍❤‍💋‍👩🏽' => 'pusu: nainen, nainen, tummanvaalea iho',
    '👩🏽‍❤‍💋‍👩🏾' => 'pusu: nainen, nainen, tummanvaalea iho, keskitumma iho',
    '👩🏽‍❤‍💋‍👩🏿' => 'pusu: nainen, nainen, tummanvaalea iho, tumma iho',
    '👩🏾‍❤‍💋‍👩🏻' => 'pusu: nainen, nainen, keskitumma iho, vaalea iho',
    '👩🏾‍❤‍💋‍👩🏼' => 'pusu: nainen, nainen, keskitumma iho, keskivaalea iho',
    '👩🏾‍❤‍💋‍👩🏽' => 'pusu: nainen, nainen, keskitumma iho, tummanvaalea iho',
    '👩🏾‍❤‍💋‍👩🏾' => 'pusu: nainen, nainen, keskitumma iho',
    '👩🏾‍❤‍💋‍👩🏿' => 'pusu: nainen, nainen, keskitumma iho, tumma iho',
    '👩🏿‍❤‍💋‍👩🏻' => 'pusu: nainen, nainen, tumma iho, vaalea iho',
    '👩🏿‍❤‍💋‍👩🏼' => 'pusu: nainen, nainen, tumma iho, keskivaalea iho',
    '👩🏿‍❤‍💋‍👩🏽' => 'pusu: nainen, nainen, tumma iho, tummanvaalea iho',
    '👩🏿‍❤‍💋‍👩🏾' => 'pusu: nainen, nainen, tumma iho, keskitumma iho',
    '👩🏿‍❤‍💋‍👩🏿' => 'pusu: nainen, nainen, tumma iho',
    '🧑🏻‍🫯‍🧑🏼' => 'painijat: vaalea iho, keskivaalea iho',
    '🧑🏻‍🫯‍🧑🏽' => 'painijat: vaalea iho, tummanvaalea iho',
    '🧑🏻‍🫯‍🧑🏾' => 'painijat: vaalea iho, keskitumma iho',
    '🧑🏻‍🫯‍🧑🏿' => 'painijat: vaalea iho, tumma iho',
    '🧑🏼‍🫯‍🧑🏻' => 'painijat: keskivaalea iho, vaalea iho',
    '🧑🏼‍🫯‍🧑🏽' => 'painijat: keskivaalea iho, tummanvaalea iho',
    '🧑🏼‍🫯‍🧑🏾' => 'painijat: keskivaalea iho, keskitumma iho',
    '🧑🏼‍🫯‍🧑🏿' => 'painijat: keskivaalea iho, tumma iho',
    '🧑🏽‍🫯‍🧑🏻' => 'painijat: tummanvaalea iho, vaalea iho',
    '🧑🏽‍🫯‍🧑🏼' => 'painijat: tummanvaalea iho, keskivaalea iho',
    '🧑🏽‍🫯‍🧑🏾' => 'painijat: tummanvaalea iho, keskitumma iho',
    '🧑🏽‍🫯‍🧑🏿' => 'painijat: tummanvaalea iho, tumma iho',
    '🧑🏾‍🫯‍🧑🏻' => 'painijat: keskitumma iho, vaalea iho',
    '🧑🏾‍🫯‍🧑🏼' => 'painijat: keskitumma iho, keskivaalea iho',
    '🧑🏾‍🫯‍🧑🏽' => 'painijat: keskitumma iho, tummanvaalea iho',
    '🧑🏾‍🫯‍🧑🏿' => 'painijat: keskitumma iho, tumma iho',
    '🧑🏿‍🫯‍🧑🏻' => 'painijat: tumma iho, vaalea iho',
    '🧑🏿‍🫯‍🧑🏼' => 'painijat: tumma iho, keskivaalea iho',
    '🧑🏿‍🫯‍🧑🏽' => 'painijat: tumma iho, tummanvaalea iho',
    '🧑🏿‍🫯‍🧑🏾' => 'painijat: tumma iho, keskitumma iho',
    '🧑🏻‍❤‍🧑🏼' => 'pariskunta ja sydän: aikuinen, aikuinen, vaalea iho, keskivaalea iho',
    '🧑🏻‍❤‍🧑🏽' => 'pariskunta ja sydän: aikuinen, aikuinen, vaalea iho, tummanvaalea iho',
    '🧑🏻‍❤‍🧑🏾' => 'pariskunta ja sydän: aikuinen, aikuinen, vaalea iho, keskitumma iho',
    '🧑🏻‍❤‍🧑🏿' => 'pariskunta ja sydän: aikuinen, aikuinen, vaalea iho, tumma iho',
    '🧑🏼‍❤‍🧑🏻' => 'pariskunta ja sydän: aikuinen, aikuinen, keskivaalea iho, vaalea iho',
    '🧑🏼‍❤‍🧑🏽' => 'pariskunta ja sydän: aikuinen, aikuinen, keskivaalea iho, tummanvaalea iho',
    '🧑🏼‍❤‍🧑🏾' => 'pariskunta ja sydän: aikuinen, aikuinen, keskivaalea iho, keskitumma iho',
    '🧑🏼‍❤‍🧑🏿' => 'pariskunta ja sydän: aikuinen, aikuinen, keskivaalea iho, tumma iho',
    '🧑🏽‍❤‍🧑🏻' => 'pariskunta ja sydän: aikuinen, aikuinen, tummanvaalea iho, vaalea iho',
    '🧑🏽‍❤‍🧑🏼' => 'pariskunta ja sydän: aikuinen, aikuinen, tummanvaalea iho, keskivaalea iho',
    '🧑🏽‍❤‍🧑🏾' => 'pariskunta ja sydän: aikuinen, aikuinen, tummanvaalea iho, keskitumma iho',
    '🧑🏽‍❤‍🧑🏿' => 'pariskunta ja sydän: aikuinen, aikuinen, tummanvaalea iho, tumma iho',
    '🧑🏾‍❤‍🧑🏻' => 'pariskunta ja sydän: aikuinen, aikuinen, keskitumma iho, vaalea iho',
    '🧑🏾‍❤‍🧑🏼' => 'pariskunta ja sydän: aikuinen, aikuinen, keskitumma iho, keskivaalea iho',
    '🧑🏾‍❤‍🧑🏽' => 'pariskunta ja sydän: aikuinen, aikuinen, keskitumma iho, tummanvaalea iho',
    '🧑🏾‍❤‍🧑🏿' => 'pariskunta ja sydän: aikuinen, aikuinen, keskitumma iho, tumma iho',
    '🧑🏿‍❤‍🧑🏻' => 'pariskunta ja sydän: aikuinen, aikuinen, tumma iho, vaalea iho',
    '🧑🏿‍❤‍🧑🏼' => 'pariskunta ja sydän: aikuinen, aikuinen, tumma iho, keskivaalea iho',
    '🧑🏿‍❤‍🧑🏽' => 'pariskunta ja sydän: aikuinen, aikuinen, tumma iho, tummanvaalea iho',
    '🧑🏿‍❤‍🧑🏾' => 'pariskunta ja sydän: aikuinen, aikuinen, tumma iho, keskitumma iho',
    '🧑🏻‍🐰‍🧑🏼' => 'puputytöt: vaalea iho, keskivaalea iho',
    '🧑🏻‍🐰‍🧑🏽' => 'puputytöt: vaalea iho, tummanvaalea iho',
    '🧑🏻‍🐰‍🧑🏾' => 'puputytöt: vaalea iho, keskitumma iho',
    '🧑🏻‍🐰‍🧑🏿' => 'puputytöt: vaalea iho, tumma iho',
    '🧑🏼‍🐰‍🧑🏻' => 'puputytöt: keskivaalea iho, vaalea iho',
    '🧑🏼‍🐰‍🧑🏽' => 'puputytöt: keskivaalea iho, tummanvaalea iho',
    '🧑🏼‍🐰‍🧑🏾' => 'puputytöt: keskivaalea iho, keskitumma iho',
    '🧑🏼‍🐰‍🧑🏿' => 'puputytöt: keskivaalea iho, tumma iho',
    '🧑🏽‍🐰‍🧑🏻' => 'puputytöt: tummanvaalea iho, vaalea iho',
    '🧑🏽‍🐰‍🧑🏼' => 'puputytöt: tummanvaalea iho, keskivaalea iho',
    '🧑🏽‍🐰‍🧑🏾' => 'puputytöt: tummanvaalea iho, keskitumma iho',
    '🧑🏽‍🐰‍🧑🏿' => 'puputytöt: tummanvaalea iho, tumma iho',
    '🧑🏾‍🐰‍🧑🏻' => 'puputytöt: keskitumma iho, vaalea iho',
    '🧑🏾‍🐰‍🧑🏼' => 'puputytöt: keskitumma iho, keskivaalea iho',
    '🧑🏾‍🐰‍🧑🏽' => 'puputytöt: keskitumma iho, tummanvaalea iho',
    '🧑🏾‍🐰‍🧑🏿' => 'puputytöt: keskitumma iho, tumma iho',
    '🧑🏿‍🐰‍🧑🏻' => 'puputytöt: tumma iho, vaalea iho',
    '🧑🏿‍🐰‍🧑🏼' => 'puputytöt: tumma iho, keskivaalea iho',
    '🧑🏿‍🐰‍🧑🏽' => 'puputytöt: tumma iho, tummanvaalea iho',
    '🧑🏿‍🐰‍🧑🏾' => 'puputytöt: tumma iho, keskitumma iho',
    '👨🏻‍🫯‍👨🏼' => 'painivat miehet: vaalea iho, keskivaalea iho',
    '👨🏻‍🫯‍👨🏽' => 'painivat miehet: vaalea iho, tummanvaalea iho',
    '👨🏻‍🫯‍👨🏾' => 'painivat miehet: vaalea iho, keskitumma iho',
    '👨🏻‍🫯‍👨🏿' => 'painivat miehet: vaalea iho, tumma iho',
    '👨🏼‍🫯‍👨🏻' => 'painivat miehet: keskivaalea iho, vaalea iho',
    '👨🏼‍🫯‍👨🏽' => 'painivat miehet: keskivaalea iho, tummanvaalea iho',
    '👨🏼‍🫯‍👨🏾' => 'painivat miehet: keskivaalea iho, keskitumma iho',
    '👨🏼‍🫯‍👨🏿' => 'painivat miehet: keskivaalea iho, tumma iho',
    '👨🏽‍🫯‍👨🏻' => 'painivat miehet: tummanvaalea iho, vaalea iho',
    '👨🏽‍🫯‍👨🏼' => 'painivat miehet: tummanvaalea iho, keskivaalea iho',
    '👨🏽‍🫯‍👨🏾' => 'painivat miehet: tummanvaalea iho, keskitumma iho',
    '👨🏽‍🫯‍👨🏿' => 'painivat miehet: tummanvaalea iho, tumma iho',
    '👨🏾‍🫯‍👨🏻' => 'painivat miehet: keskitumma iho, vaalea iho',
    '👨🏾‍🫯‍👨🏼' => 'painivat miehet: keskitumma iho, keskivaalea iho',
    '👨🏾‍🫯‍👨🏽' => 'painivat miehet: keskitumma iho, tummanvaalea iho',
    '👨🏾‍🫯‍👨🏿' => 'painivat miehet: keskitumma iho, tumma iho',
    '👨🏿‍🫯‍👨🏻' => 'painivat miehet: tumma iho, vaalea iho',
    '👨🏿‍🫯‍👨🏼' => 'painivat miehet: tumma iho, keskivaalea iho',
    '👨🏿‍🫯‍👨🏽' => 'painivat miehet: tumma iho, tummanvaalea iho',
    '👨🏿‍🫯‍👨🏾' => 'painivat miehet: tumma iho, keskitumma iho',
    '👨🏻‍❤‍👨🏻' => 'pariskunta ja sydän: mies, mies, vaalea iho',
    '👨🏻‍❤‍👨🏼' => 'pariskunta ja sydän: mies, mies, vaalea iho, keskivaalea iho',
    '👨🏻‍❤‍👨🏽' => 'pariskunta ja sydän: mies, mies, vaalea iho, tummanvaalea iho',
    '👨🏻‍❤‍👨🏾' => 'pariskunta ja sydän: mies, mies, vaalea iho, keskitumma iho',
    '👨🏻‍❤‍👨🏿' => 'pariskunta ja sydän: mies, mies, vaalea iho, tumma iho',
    '👨🏼‍❤‍👨🏻' => 'pariskunta ja sydän: mies, mies, keskivaalea iho, vaalea iho',
    '👨🏼‍❤‍👨🏼' => 'pariskunta ja sydän: mies, mies, keskivaalea iho',
    '👨🏼‍❤‍👨🏽' => 'pariskunta ja sydän: mies, mies, keskivaalea iho, tummanvaalea iho',
    '👨🏼‍❤‍👨🏾' => 'pariskunta ja sydän: mies, mies, keskivaalea iho, keskitumma iho',
    '👨🏼‍❤‍👨🏿' => 'pariskunta ja sydän: mies, mies, keskivaalea iho, tumma iho',
    '👨🏽‍❤‍👨🏻' => 'pariskunta ja sydän: mies, mies, tummanvaalea iho, vaalea iho',
    '👨🏽‍❤‍👨🏼' => 'pariskunta ja sydän: mies, mies, tummanvaalea iho, keskivaalea iho',
    '👨🏽‍❤‍👨🏽' => 'pariskunta ja sydän: mies, mies, tummanvaalea iho',
    '👨🏽‍❤‍👨🏾' => 'pariskunta ja sydän: mies, mies, tummanvaalea iho, keskitumma iho',
    '👨🏽‍❤‍👨🏿' => 'pariskunta ja sydän: mies, mies, tummanvaalea iho, tumma iho',
    '👨🏾‍❤‍👨🏻' => 'pariskunta ja sydän: mies, mies, keskitumma iho, vaalea iho',
    '👨🏾‍❤‍👨🏼' => 'pariskunta ja sydän: mies, mies, keskitumma iho, keskivaalea iho',
    '👨🏾‍❤‍👨🏽' => 'pariskunta ja sydän: mies, mies, keskitumma iho, tummanvaalea iho',
    '👨🏾‍❤‍👨🏾' => 'pariskunta ja sydän: mies, mies, keskitumma iho',
    '👨🏾‍❤‍👨🏿' => 'pariskunta ja sydän: mies, mies, keskitumma iho, tumma iho',
    '👨🏿‍❤‍👨🏻' => 'pariskunta ja sydän: mies, mies, tumma iho, vaalea iho',
    '👨🏿‍❤‍👨🏼' => 'pariskunta ja sydän: mies, mies, tumma iho, keskivaalea iho',
    '👨🏿‍❤‍👨🏽' => 'pariskunta ja sydän: mies, mies, tumma iho, tummanvaalea iho',
    '👨🏿‍❤‍👨🏾' => 'pariskunta ja sydän: mies, mies, tumma iho, keskitumma iho',
    '👨🏿‍❤‍👨🏿' => 'pariskunta ja sydän: mies, mies, tumma iho',
    '👨🏻‍🐰‍👨🏼' => 'tanssivat pupupojat: vaalea iho, keskivaalea iho',
    '👨🏻‍🐰‍👨🏽' => 'tanssivat pupupojat: vaalea iho, tummanvaalea iho',
    '👨🏻‍🐰‍👨🏾' => 'tanssivat pupupojat: vaalea iho, keskitumma iho',
    '👨🏻‍🐰‍👨🏿' => 'tanssivat pupupojat: vaalea iho, tumma iho',
    '👨🏼‍🐰‍👨🏻' => 'tanssivat pupupojat: keskivaalea iho, vaalea iho',
    '👨🏼‍🐰‍👨🏽' => 'tanssivat pupupojat: keskivaalea iho, tummanvaalea iho',
    '👨🏼‍🐰‍👨🏾' => 'tanssivat pupupojat: keskivaalea iho, keskitumma iho',
    '👨🏼‍🐰‍👨🏿' => 'tanssivat pupupojat: keskivaalea iho, tumma iho',
    '👨🏽‍🐰‍👨🏻' => 'tanssivat pupupojat: tummanvaalea iho, vaalea iho',
    '👨🏽‍🐰‍👨🏼' => 'tanssivat pupupojat: tummanvaalea iho, keskivaalea iho',
    '👨🏽‍🐰‍👨🏾' => 'tanssivat pupupojat: tummanvaalea iho, keskitumma iho',
    '👨🏽‍🐰‍👨🏿' => 'tanssivat pupupojat: tummanvaalea iho, tumma iho',
    '👨🏾‍🐰‍👨🏻' => 'tanssivat pupupojat: keskitumma iho, vaalea iho',
    '👨🏾‍🐰‍👨🏼' => 'tanssivat pupupojat: keskitumma iho, keskivaalea iho',
    '👨🏾‍🐰‍👨🏽' => 'tanssivat pupupojat: keskitumma iho, tummanvaalea iho',
    '👨🏾‍🐰‍👨🏿' => 'tanssivat pupupojat: keskitumma iho, tumma iho',
    '👨🏿‍🐰‍👨🏻' => 'tanssivat pupupojat: tumma iho, vaalea iho',
    '👨🏿‍🐰‍👨🏼' => 'tanssivat pupupojat: tumma iho, keskivaalea iho',
    '👨🏿‍🐰‍👨🏽' => 'tanssivat pupupojat: tumma iho, tummanvaalea iho',
    '👨🏿‍🐰‍👨🏾' => 'tanssivat pupupojat: tumma iho, keskitumma iho',
    '👩🏻‍🫯‍👩🏼' => 'painivat naiset: vaalea iho, keskivaalea iho',
    '👩🏻‍🫯‍👩🏽' => 'painivat naiset: vaalea iho, tummanvaalea iho',
    '👩🏻‍🫯‍👩🏾' => 'painivat naiset: vaalea iho, keskitumma iho',
    '👩🏻‍🫯‍👩🏿' => 'painivat naiset: vaalea iho, tumma iho',
    '👩🏼‍🫯‍👩🏻' => 'painivat naiset: keskivaalea iho, vaalea iho',
    '👩🏼‍🫯‍👩🏽' => 'painivat naiset: keskivaalea iho, tummanvaalea iho',
    '👩🏼‍🫯‍👩🏾' => 'painivat naiset: keskivaalea iho, keskitumma iho',
    '👩🏼‍🫯‍👩🏿' => 'painivat naiset: keskivaalea iho, tumma iho',
    '👩🏽‍🫯‍👩🏻' => 'painivat naiset: tummanvaalea iho, vaalea iho',
    '👩🏽‍🫯‍👩🏼' => 'painivat naiset: tummanvaalea iho, keskivaalea iho',
    '👩🏽‍🫯‍👩🏾' => 'painivat naiset: tummanvaalea iho, keskitumma iho',
    '👩🏽‍🫯‍👩🏿' => 'painivat naiset: tummanvaalea iho, tumma iho',
    '👩🏾‍🫯‍👩🏻' => 'painivat naiset: keskitumma iho, vaalea iho',
    '👩🏾‍🫯‍👩🏼' => 'painivat naiset: keskitumma iho, keskivaalea iho',
    '👩🏾‍🫯‍👩🏽' => 'painivat naiset: keskitumma iho, tummanvaalea iho',
    '👩🏾‍🫯‍👩🏿' => 'painivat naiset: keskitumma iho, tumma iho',
    '👩🏿‍🫯‍👩🏻' => 'painivat naiset: tumma iho, vaalea iho',
    '👩🏿‍🫯‍👩🏼' => 'painivat naiset: tumma iho, keskivaalea iho',
    '👩🏿‍🫯‍👩🏽' => 'painivat naiset: tumma iho, tummanvaalea iho',
    '👩🏿‍🫯‍👩🏾' => 'painivat naiset: tumma iho, keskitumma iho',
    '👩🏻‍❤‍👨🏻' => 'pariskunta ja sydän: nainen, mies, vaalea iho',
    '👩🏻‍❤‍👨🏼' => 'pariskunta ja sydän: nainen, mies, vaalea iho, keskivaalea iho',
    '👩🏻‍❤‍👨🏽' => 'pariskunta ja sydän: nainen, mies, vaalea iho, tummanvaalea iho',
    '👩🏻‍❤‍👨🏾' => 'pariskunta ja sydän: nainen, mies, vaalea iho, keskitumma iho',
    '👩🏻‍❤‍👨🏿' => 'pariskunta ja sydän: nainen, mies, vaalea iho, tumma iho',
    '👩🏼‍❤‍👨🏻' => 'pariskunta ja sydän: nainen, mies, keskivaalea iho, vaalea iho',
    '👩🏼‍❤‍👨🏼' => 'pariskunta ja sydän: nainen, mies, keskivaalea iho',
    '👩🏼‍❤‍👨🏽' => 'pariskunta ja sydän: nainen, mies, keskivaalea iho, tummanvaalea iho',
    '👩🏼‍❤‍👨🏾' => 'pariskunta ja sydän: nainen, mies, keskivaalea iho, keskitumma iho',
    '👩🏼‍❤‍👨🏿' => 'pariskunta ja sydän: nainen, mies, keskivaalea iho, tumma iho',
    '👩🏽‍❤‍👨🏻' => 'pariskunta ja sydän: nainen, mies, tummanvaalea iho, vaalea iho',
    '👩🏽‍❤‍👨🏼' => 'pariskunta ja sydän: nainen, mies, tummanvaalea iho, keskivaalea iho',
    '👩🏽‍❤‍👨🏽' => 'pariskunta ja sydän: nainen, mies, tummanvaalea iho',
    '👩🏽‍❤‍👨🏾' => 'pariskunta ja sydän: nainen, mies, tummanvaalea iho, keskitumma iho',
    '👩🏽‍❤‍👨🏿' => 'pariskunta ja sydän: nainen, mies, tummanvaalea iho, tumma iho',
    '👩🏾‍❤‍👨🏻' => 'pariskunta ja sydän: nainen, mies, keskitumma iho, vaalea iho',
    '👩🏾‍❤‍👨🏼' => 'pariskunta ja sydän: nainen, mies, keskitumma iho, keskivaalea iho',
    '👩🏾‍❤‍👨🏽' => 'pariskunta ja sydän: nainen, mies, keskitumma iho, tummanvaalea iho',
    '👩🏾‍❤‍👨🏾' => 'pariskunta ja sydän: nainen, mies, keskitumma iho',
    '👩🏾‍❤‍👨🏿' => 'pariskunta ja sydän: nainen, mies, keskitumma iho, tumma iho',
    '👩🏿‍❤‍👨🏻' => 'pariskunta ja sydän: nainen, mies, tumma iho, vaalea iho',
    '👩🏿‍❤‍👨🏼' => 'pariskunta ja sydän: nainen, mies, tumma iho, keskivaalea iho',
    '👩🏿‍❤‍👨🏽' => 'pariskunta ja sydän: nainen, mies, tumma iho, tummanvaalea iho',
    '👩🏿‍❤‍👨🏾' => 'pariskunta ja sydän: nainen, mies, tumma iho, keskitumma iho',
    '👩🏿‍❤‍👨🏿' => 'pariskunta ja sydän: nainen, mies, tumma iho',
    '👩🏻‍❤‍👩🏻' => 'pariskunta ja sydän: nainen, nainen, vaalea iho',
    '👩🏻‍❤‍👩🏼' => 'pariskunta ja sydän: nainen, nainen, vaalea iho, keskivaalea iho',
    '👩🏻‍❤‍👩🏽' => 'pariskunta ja sydän: nainen, nainen, vaalea iho, tummanvaalea iho',
    '👩🏻‍❤‍👩🏾' => 'pariskunta ja sydän: nainen, nainen, vaalea iho, keskitumma iho',
    '👩🏻‍❤‍👩🏿' => 'pariskunta ja sydän: nainen, nainen, vaalea iho, tumma iho',
    '👩🏼‍❤‍👩🏻' => 'pariskunta ja sydän: nainen, nainen, keskivaalea iho, vaalea iho',
    '👩🏼‍❤‍👩🏼' => 'pariskunta ja sydän: nainen, nainen, keskivaalea iho',
    '👩🏼‍❤‍👩🏽' => 'pariskunta ja sydän: nainen, nainen, keskivaalea iho, tummanvaalea iho',
    '👩🏼‍❤‍👩🏾' => 'pariskunta ja sydän: nainen, nainen, keskivaalea iho, keskitumma iho',
    '👩🏼‍❤‍👩🏿' => 'pariskunta ja sydän: nainen, nainen, keskivaalea iho, tumma iho',
    '👩🏽‍❤‍👩🏻' => 'pariskunta ja sydän: nainen, nainen, tummanvaalea iho, vaalea iho',
    '👩🏽‍❤‍👩🏼' => 'pariskunta ja sydän: nainen, nainen, tummanvaalea iho, keskivaalea iho',
    '👩🏽‍❤‍👩🏽' => 'pariskunta ja sydän: nainen, nainen, tummanvaalea iho',
    '👩🏽‍❤‍👩🏾' => 'pariskunta ja sydän: nainen, nainen, tummanvaalea iho, keskitumma iho',
    '👩🏽‍❤‍👩🏿' => 'pariskunta ja sydän: nainen, nainen, tummanvaalea iho, tumma iho',
    '👩🏾‍❤‍👩🏻' => 'pariskunta ja sydän: nainen, nainen, keskitumma iho, vaalea iho',
    '👩🏾‍❤‍👩🏼' => 'pariskunta ja sydän: nainen, nainen, keskitumma iho, keskivaalea iho',
    '👩🏾‍❤‍👩🏽' => 'pariskunta ja sydän: nainen, nainen, keskitumma iho, tummanvaalea iho',
    '👩🏾‍❤‍👩🏾' => 'pariskunta ja sydän: nainen, nainen, keskitumma iho',
    '👩🏾‍❤‍👩🏿' => 'pariskunta ja sydän: nainen, nainen, keskitumma iho, tumma iho',
    '👩🏿‍❤‍👩🏻' => 'pariskunta ja sydän: nainen, nainen, tumma iho, vaalea iho',
    '👩🏿‍❤‍👩🏼' => 'pariskunta ja sydän: nainen, nainen, tumma iho, keskivaalea iho',
    '👩🏿‍❤‍👩🏽' => 'pariskunta ja sydän: nainen, nainen, tumma iho, tummanvaalea iho',
    '👩🏿‍❤‍👩🏾' => 'pariskunta ja sydän: nainen, nainen, tumma iho, keskitumma iho',
    '👩🏿‍❤‍👩🏿' => 'pariskunta ja sydän: nainen, nainen, tumma iho',
    '👩🏻‍🐰‍👩🏼' => 'tanssivat puputytöt: vaalea iho, keskivaalea iho',
    '👩🏻‍🐰‍👩🏽' => 'tanssivat puputytöt: vaalea iho, tummanvaalea iho',
    '👩🏻‍🐰‍👩🏾' => 'tanssivat puputytöt: vaalea iho, keskitumma iho',
    '👩🏻‍🐰‍👩🏿' => 'tanssivat puputytöt: vaalea iho, tumma iho',
    '👩🏼‍🐰‍👩🏻' => 'tanssivat puputytöt: keskivaalea iho, vaalea iho',
    '👩🏼‍🐰‍👩🏽' => 'tanssivat puputytöt: keskivaalea iho, tummanvaalea iho',
    '👩🏼‍🐰‍👩🏾' => 'tanssivat puputytöt: keskivaalea iho, keskitumma iho',
    '👩🏼‍🐰‍👩🏿' => 'tanssivat puputytöt: keskivaalea iho, tumma iho',
    '👩🏽‍🐰‍👩🏻' => 'tanssivat puputytöt: tummanvaalea iho, vaalea iho',
    '👩🏽‍🐰‍👩🏼' => 'tanssivat puputytöt: tummanvaalea iho, keskivaalea iho',
    '👩🏽‍🐰‍👩🏾' => 'tanssivat puputytöt: tummanvaalea iho, keskitumma iho',
    '👩🏽‍🐰‍👩🏿' => 'tanssivat puputytöt: tummanvaalea iho, tumma iho',
    '👩🏾‍🐰‍👩🏻' => 'tanssivat puputytöt: keskitumma iho, vaalea iho',
    '👩🏾‍🐰‍👩🏼' => 'tanssivat puputytöt: keskitumma iho, keskivaalea iho',
    '👩🏾‍🐰‍👩🏽' => 'tanssivat puputytöt: keskitumma iho, tummanvaalea iho',
    '👩🏾‍🐰‍👩🏿' => 'tanssivat puputytöt: keskitumma iho, tumma iho',
    '👩🏿‍🐰‍👩🏻' => 'tanssivat puputytöt: tumma iho, vaalea iho',
    '👩🏿‍🐰‍👩🏼' => 'tanssivat puputytöt: tumma iho, keskivaalea iho',
    '👩🏿‍🐰‍👩🏽' => 'tanssivat puputytöt: tumma iho, tummanvaalea iho',
    '👩🏿‍🐰‍👩🏾' => 'tanssivat puputytöt: tumma iho, keskitumma iho',
    '🧑🏻‍🤝‍🧑🏻' => 'ihmiset käsi kädessä: vaalea iho',
    '🧑🏻‍🤝‍🧑🏼' => 'ihmiset käsi kädessä: vaalea iho, keskivaalea iho',
    '🧑🏻‍🤝‍🧑🏽' => 'ihmiset käsi kädessä: vaalea iho, tummanvaalea iho',
    '🧑🏻‍🤝‍🧑🏾' => 'ihmiset käsi kädessä: vaalea iho, keskitumma iho',
    '🧑🏻‍🤝‍🧑🏿' => 'ihmiset käsi kädessä: vaalea iho, tumma iho',
    '🧑🏼‍🤝‍🧑🏻' => 'ihmiset käsi kädessä: keskivaalea iho, vaalea iho',
    '🧑🏼‍🤝‍🧑🏼' => 'ihmiset käsi kädessä: keskivaalea iho',
    '🧑🏼‍🤝‍🧑🏽' => 'ihmiset käsi kädessä: keskivaalea iho, tummanvaalea iho',
    '🧑🏼‍🤝‍🧑🏾' => 'ihmiset käsi kädessä: keskivaalea iho, keskitumma iho',
    '🧑🏼‍🤝‍🧑🏿' => 'ihmiset käsi kädessä: keskivaalea iho, tumma iho',
    '🧑🏽‍🤝‍🧑🏻' => 'ihmiset käsi kädessä: tummanvaalea iho, vaalea iho',
    '🧑🏽‍🤝‍🧑🏼' => 'ihmiset käsi kädessä: tummanvaalea iho, keskivaalea iho',
    '🧑🏽‍🤝‍🧑🏽' => 'ihmiset käsi kädessä: tummanvaalea iho',
    '🧑🏽‍🤝‍🧑🏾' => 'ihmiset käsi kädessä: tummanvaalea iho, keskitumma iho',
    '🧑🏽‍🤝‍🧑🏿' => 'ihmiset käsi kädessä: tummanvaalea iho, tumma iho',
    '🧑🏾‍🤝‍🧑🏻' => 'ihmiset käsi kädessä: keskitumma iho, vaalea iho',
    '🧑🏾‍🤝‍🧑🏼' => 'ihmiset käsi kädessä: keskitumma iho, keskivaalea iho',
    '🧑🏾‍🤝‍🧑🏽' => 'ihmiset käsi kädessä: keskitumma iho, tummanvaalea iho',
    '🧑🏾‍🤝‍🧑🏾' => 'ihmiset käsi kädessä: keskitumma iho',
    '🧑🏾‍🤝‍🧑🏿' => 'ihmiset käsi kädessä: keskitumma iho, tumma iho',
    '🧑🏿‍🤝‍🧑🏻' => 'ihmiset käsi kädessä: tumma iho, vaalea iho',
    '🧑🏿‍🤝‍🧑🏼' => 'ihmiset käsi kädessä: tumma iho, keskivaalea iho',
    '🧑🏿‍🤝‍🧑🏽' => 'ihmiset käsi kädessä: tumma iho, tummanvaalea iho',
    '🧑🏿‍🤝‍🧑🏾' => 'ihmiset käsi kädessä: tumma iho, keskitumma iho',
    '🧑🏿‍🤝‍🧑🏿' => 'ihmiset käsi kädessä: tumma iho',
    '👩🏻‍🤝‍👩🏼' => 'kaksi naista käsi kädessä: vaalea iho, keskivaalea iho',
    '👩🏻‍🤝‍👩🏽' => 'kaksi naista käsi kädessä: vaalea iho, tummanvaalea iho',
    '👩🏻‍🤝‍👩🏾' => 'kaksi naista käsi kädessä: vaalea iho, keskitumma iho',
    '👩🏻‍🤝‍👩🏿' => 'kaksi naista käsi kädessä: vaalea iho, tumma iho',
    '👩🏼‍🤝‍👩🏻' => 'kaksi naista käsi kädessä: keskivaalea iho, vaalea iho',
    '👩🏼‍🤝‍👩🏽' => 'kaksi naista käsi kädessä: keskivaalea iho, tummanvaalea iho',
    '👩🏼‍🤝‍👩🏾' => 'kaksi naista käsi kädessä: keskivaalea iho, keskitumma iho',
    '👩🏼‍🤝‍👩🏿' => 'kaksi naista käsi kädessä: keskivaalea iho, tumma iho',
    '👩🏽‍🤝‍👩🏻' => 'kaksi naista käsi kädessä: tummanvaalea iho, vaalea iho',
    '👩🏽‍🤝‍👩🏼' => 'kaksi naista käsi kädessä: tummanvaalea iho, keskivaalea iho',
    '👩🏽‍🤝‍👩🏾' => 'kaksi naista käsi kädessä: tummanvaalea iho, keskitumma iho',
    '👩🏽‍🤝‍👩🏿' => 'kaksi naista käsi kädessä: tummanvaalea iho, tumma iho',
    '👩🏾‍🤝‍👩🏻' => 'kaksi naista käsi kädessä: keskitumma iho, vaalea iho',
    '👩🏾‍🤝‍👩🏼' => 'kaksi naista käsi kädessä: keskitumma iho, keskivaalea iho',
    '👩🏾‍🤝‍👩🏽' => 'kaksi naista käsi kädessä: keskitumma iho, tummanvaalea iho',
    '👩🏾‍🤝‍👩🏿' => 'kaksi naista käsi kädessä: keskitumma iho, tumma iho',
    '👩🏿‍🤝‍👩🏻' => 'kaksi naista käsi kädessä: tumma iho, vaalea iho',
    '👩🏿‍🤝‍👩🏼' => 'kaksi naista käsi kädessä: tumma iho, keskivaalea iho',
    '👩🏿‍🤝‍👩🏽' => 'kaksi naista käsi kädessä: tumma iho, tummanvaalea iho',
    '👩🏿‍🤝‍👩🏾' => 'kaksi naista käsi kädessä: tumma iho, keskitumma iho',
    '👩🏻‍🤝‍👨🏼' => 'mies ja nainen käsi kädessä: vaalea iho, keskivaalea iho',
    '👩🏻‍🤝‍👨🏽' => 'mies ja nainen käsi kädessä: vaalea iho, tummanvaalea iho',
    '👩🏻‍🤝‍👨🏾' => 'mies ja nainen käsi kädessä: vaalea iho, keskitumma iho',
    '👩🏻‍🤝‍👨🏿' => 'mies ja nainen käsi kädessä: vaalea iho, tumma iho',
    '👩🏼‍🤝‍👨🏻' => 'mies ja nainen käsi kädessä: keskivaalea iho, vaalea iho',
    '👩🏼‍🤝‍👨🏽' => 'mies ja nainen käsi kädessä: keskivaalea iho, tummanvaalea iho',
    '👩🏼‍🤝‍👨🏾' => 'mies ja nainen käsi kädessä: keskivaalea iho, keskitumma iho',
    '👩🏼‍🤝‍👨🏿' => 'mies ja nainen käsi kädessä: keskivaalea iho, tumma iho',
    '👩🏽‍🤝‍👨🏻' => 'mies ja nainen käsi kädessä: tummanvaalea iho, vaalea iho',
    '👩🏽‍🤝‍👨🏼' => 'mies ja nainen käsi kädessä: tummanvaalea iho, keskivaalea iho',
    '👩🏽‍🤝‍👨🏾' => 'mies ja nainen käsi kädessä: tummanvaalea iho, keskitumma iho',
    '👩🏽‍🤝‍👨🏿' => 'mies ja nainen käsi kädessä: tummanvaalea iho, tumma iho',
    '👩🏾‍🤝‍👨🏻' => 'mies ja nainen käsi kädessä: keskitumma iho, vaalea iho',
    '👩🏾‍🤝‍👨🏼' => 'mies ja nainen käsi kädessä: keskitumma iho, keskivaalea iho',
    '👩🏾‍🤝‍👨🏽' => 'mies ja nainen käsi kädessä: keskitumma iho, tummanvaalea iho',
    '👩🏾‍🤝‍👨🏿' => 'mies ja nainen käsi kädessä: keskitumma iho, tumma iho',
    '👩🏿‍🤝‍👨🏻' => 'mies ja nainen käsi kädessä: tumma iho, vaalea iho',
    '👩🏿‍🤝‍👨🏼' => 'mies ja nainen käsi kädessä: tumma iho, keskivaalea iho',
    '👩🏿‍🤝‍👨🏽' => 'mies ja nainen käsi kädessä: tumma iho, tummanvaalea iho',
    '👩🏿‍🤝‍👨🏾' => 'mies ja nainen käsi kädessä: tumma iho, keskitumma iho',
    '👨🏻‍🤝‍👨🏼' => 'kaksi miestä käsi kädessä: vaalea iho, keskivaalea iho',
    '👨🏻‍🤝‍👨🏽' => 'kaksi miestä käsi kädessä: vaalea iho, tummanvaalea iho',
    '👨🏻‍🤝‍👨🏾' => 'kaksi miestä käsi kädessä: vaalea iho, keskitumma iho',
    '👨🏻‍🤝‍👨🏿' => 'kaksi miestä käsi kädessä: vaalea iho, tumma iho',
    '👨🏼‍🤝‍👨🏻' => 'kaksi miestä käsi kädessä: keskivaalea iho, vaalea iho',
    '👨🏼‍🤝‍👨🏽' => 'kaksi miestä käsi kädessä: keskivaalea iho, tummanvaalea iho',
    '👨🏼‍🤝‍👨🏾' => 'kaksi miestä käsi kädessä: keskivaalea iho, keskitumma iho',
    '👨🏼‍🤝‍👨🏿' => 'kaksi miestä käsi kädessä: keskivaalea iho, tumma iho',
    '👨🏽‍🤝‍👨🏻' => 'kaksi miestä käsi kädessä: tummanvaalea iho, vaalea iho',
    '👨🏽‍🤝‍👨🏼' => 'kaksi miestä käsi kädessä: tummanvaalea iho, keskivaalea iho',
    '👨🏽‍🤝‍👨🏾' => 'kaksi miestä käsi kädessä: tummanvaalea iho, keskitumma iho',
    '👨🏽‍🤝‍👨🏿' => 'kaksi miestä käsi kädessä: tummanvaalea iho, tumma iho',
    '👨🏾‍🤝‍👨🏻' => 'kaksi miestä käsi kädessä: keskitumma iho, vaalea iho',
    '👨🏾‍🤝‍👨🏼' => 'kaksi miestä käsi kädessä: keskitumma iho, keskivaalea iho',
    '👨🏾‍🤝‍👨🏽' => 'kaksi miestä käsi kädessä: keskitumma iho, tummanvaalea iho',
    '👨🏾‍🤝‍👨🏿' => 'kaksi miestä käsi kädessä: keskitumma iho, tumma iho',
    '👨🏿‍🤝‍👨🏻' => 'kaksi miestä käsi kädessä: tumma iho, vaalea iho',
    '👨🏿‍🤝‍👨🏼' => 'kaksi miestä käsi kädessä: tumma iho, keskivaalea iho',
    '👨🏿‍🤝‍👨🏽' => 'kaksi miestä käsi kädessä: tumma iho, tummanvaalea iho',
    '👨🏿‍🤝‍👨🏾' => 'kaksi miestä käsi kädessä: tumma iho, keskitumma iho',
    '👩‍❤‍💋‍👨' => 'pusu: nainen, mies',
    '👨‍❤‍💋‍👨' => 'pusu: mies, mies',
    '👩‍❤‍💋‍👩' => 'pusu: nainen, nainen',
    '👨‍👩‍👧‍👦' => 'perhe: mies, nainen, tyttö, poika',
    '👨‍👩‍👦‍👦' => 'perhe: mies, nainen, poika, poika',
    '👨‍👩‍👧‍👧' => 'perhe: mies, nainen, tyttö, tyttö',
    '👨‍👨‍👧‍👦' => 'perhe: mies, mies, tyttö, poika',
    '👨‍👨‍👦‍👦' => 'perhe: mies, mies, poika, poika',
    '👨‍👨‍👧‍👧' => 'perhe: mies, mies, tyttö, tyttö',
    '👩‍👩‍👧‍👦' => 'perhe: nainen, nainen, tyttö, poika',
    '👩‍👩‍👦‍👦' => 'perhe: nainen, nainen, poika, poika',
    '👩‍👩‍👧‍👧' => 'perhe: nainen, nainen, tyttö, tyttö',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'lippu: Englanti',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'lippu: Skotlanti',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'lippu: Wales',
    '🧑‍🧑‍🧒‍🧒' => 'perhe: aikuinen, aikuinen, lapsi, lapsi',
    '🚶🏻‍♀‍➡' => 'kävelevä nainen: vaalea iho, kohti oikeaa',
    '🚶🏼‍♀‍➡' => 'kävelevä nainen: keskivaalea iho, kohti oikeaa',
    '🚶🏽‍♀‍➡' => 'kävelevä nainen: tummanvaalea iho, kohti oikeaa',
    '🚶🏾‍♀‍➡' => 'kävelevä nainen: keskitumma iho, kohti oikeaa',
    '🚶🏿‍♀‍➡' => 'kävelevä nainen: tumma iho, kohti oikeaa',
    '🚶🏻‍♂‍➡' => 'kävelevä mies: vaalea iho, kohti oikeaa',
    '🚶🏼‍♂‍➡' => 'kävelevä mies: keskivaalea iho, kohti oikeaa',
    '🚶🏽‍♂‍➡' => 'kävelevä mies: tummanvaalea iho, kohti oikeaa',
    '🚶🏾‍♂‍➡' => 'kävelevä mies: keskitumma iho, kohti oikeaa',
    '🚶🏿‍♂‍➡' => 'kävelevä mies: tumma iho, kohti oikeaa',
    '🧎🏻‍♀‍➡' => 'polvistuva nainen: vaalea iho, kohti oikeaa',
    '🧎🏼‍♀‍➡' => 'polvistuva nainen: keskivaalea iho, kohti oikeaa',
    '🧎🏽‍♀‍➡' => 'polvistuva nainen: tummanvaalea iho, kohti oikeaa',
    '🧎🏾‍♀‍➡' => 'polvistuva nainen: keskitumma iho, kohti oikeaa',
    '🧎🏿‍♀‍➡' => 'polvistuva nainen: tumma iho, kohti oikeaa',
    '🧎🏻‍♂‍➡' => 'polvistuva mies: vaalea iho, kohti oikeaa',
    '🧎🏼‍♂‍➡' => 'polvistuva mies: keskivaalea iho, kohti oikeaa',
    '🧎🏽‍♂‍➡' => 'polvistuva mies: tummanvaalea iho, kohti oikeaa',
    '🧎🏾‍♂‍➡' => 'polvistuva mies: keskitumma iho, kohti oikeaa',
    '🧎🏿‍♂‍➡' => 'polvistuva mies: tumma iho, kohti oikeaa',
    '🧑🏻‍🦯‍➡' => 'henkilö ja valkoinen keppi: vaalea iho, kohti oikeaa',
    '🧑🏼‍🦯‍➡' => 'henkilö ja valkoinen keppi: keskivaalea iho, kohti oikeaa',
    '🧑🏽‍🦯‍➡' => 'henkilö ja valkoinen keppi: tummanvaalea iho, kohti oikeaa',
    '🧑🏾‍🦯‍➡' => 'henkilö ja valkoinen keppi: keskitumma iho, kohti oikeaa',
    '🧑🏿‍🦯‍➡' => 'henkilö ja valkoinen keppi: tumma iho, kohti oikeaa',
    '👨🏻‍🦯‍➡' => 'mies ja valkoinen keppi: vaalea iho, kohti oikeaa',
    '👨🏼‍🦯‍➡' => 'mies ja valkoinen keppi: keskivaalea iho, kohti oikeaa',
    '👨🏽‍🦯‍➡' => 'mies ja valkoinen keppi: tummanvaalea iho, kohti oikeaa',
    '👨🏾‍🦯‍➡' => 'mies ja valkoinen keppi: keskitumma iho, kohti oikeaa',
    '👨🏿‍🦯‍➡' => 'mies ja valkoinen keppi: tumma iho, kohti oikeaa',
    '👩🏻‍🦯‍➡' => 'nainen ja valkoinen keppi: vaalea iho, kohti oikeaa',
    '👩🏼‍🦯‍➡' => 'nainen ja valkoinen keppi: keskivaalea iho, kohti oikeaa',
    '👩🏽‍🦯‍➡' => 'nainen ja valkoinen keppi: tummanvaalea iho, kohti oikeaa',
    '👩🏾‍🦯‍➡' => 'nainen ja valkoinen keppi: keskitumma iho, kohti oikeaa',
    '👩🏿‍🦯‍➡' => 'nainen ja valkoinen keppi: tumma iho, kohti oikeaa',
    '🧑🏻‍🦼‍➡' => 'henkilö moottoroidussa pyörätuolissa: vaalea iho, kohti oikeaa',
    '🧑🏼‍🦼‍➡' => 'henkilö moottoroidussa pyörätuolissa: keskivaalea iho, kohti oikeaa',
    '🧑🏽‍🦼‍➡' => 'henkilö moottoroidussa pyörätuolissa: tummanvaalea iho, kohti oikeaa',
    '🧑🏾‍🦼‍➡' => 'henkilö moottoroidussa pyörätuolissa: keskitumma iho, kohti oikeaa',
    '🧑🏿‍🦼‍➡' => 'henkilö moottoroidussa pyörätuolissa: tumma iho, kohti oikeaa',
    '👨🏻‍🦼‍➡' => 'mies moottoroidussa pyörätuolissa: vaalea iho, kohti oikeaa',
    '👨🏼‍🦼‍➡' => 'mies moottoroidussa pyörätuolissa: keskivaalea iho, kohti oikeaa',
    '👨🏽‍🦼‍➡' => 'mies moottoroidussa pyörätuolissa: tummanvaalea iho, kohti oikeaa',
    '👨🏾‍🦼‍➡' => 'mies moottoroidussa pyörätuolissa: keskitumma iho, kohti oikeaa',
    '👨🏿‍🦼‍➡' => 'mies moottoroidussa pyörätuolissa: tumma iho, kohti oikeaa',
    '👩🏻‍🦼‍➡' => 'nainen moottoroidussa pyörätuolissa: vaalea iho, kohti oikeaa',
    '👩🏼‍🦼‍➡' => 'nainen moottoroidussa pyörätuolissa: keskivaalea iho, kohti oikeaa',
    '👩🏽‍🦼‍➡' => 'nainen moottoroidussa pyörätuolissa: tummanvaalea iho, kohti oikeaa',
    '👩🏾‍🦼‍➡' => 'nainen moottoroidussa pyörätuolissa: keskitumma iho, kohti oikeaa',
    '👩🏿‍🦼‍➡' => 'nainen moottoroidussa pyörätuolissa: tumma iho, kohti oikeaa',
    '🧑🏻‍🦽‍➡' => 'henkilö käsikäyttöisessä pyörätuolissa: vaalea iho, kohti oikeaa',
    '🧑🏼‍🦽‍➡' => 'henkilö käsikäyttöisessä pyörätuolissa: keskivaalea iho, kohti oikeaa',
    '🧑🏽‍🦽‍➡' => 'henkilö käsikäyttöisessä pyörätuolissa: tummanvaalea iho, kohti oikeaa',
    '🧑🏾‍🦽‍➡' => 'henkilö käsikäyttöisessä pyörätuolissa: keskitumma iho, kohti oikeaa',
    '🧑🏿‍🦽‍➡' => 'henkilö käsikäyttöisessä pyörätuolissa: tumma iho, kohti oikeaa',
    '👨🏻‍🦽‍➡' => 'mies käsikäyttöisessä pyörätuolissa: vaalea iho, kohti oikeaa',
    '👨🏼‍🦽‍➡' => 'mies käsikäyttöisessä pyörätuolissa: keskivaalea iho, kohti oikeaa',
    '👨🏽‍🦽‍➡' => 'mies käsikäyttöisessä pyörätuolissa: tummanvaalea iho, kohti oikeaa',
    '👨🏾‍🦽‍➡' => 'mies käsikäyttöisessä pyörätuolissa: keskitumma iho, kohti oikeaa',
    '👨🏿‍🦽‍➡' => 'mies käsikäyttöisessä pyörätuolissa: tumma iho, kohti oikeaa',
    '👩🏻‍🦽‍➡' => 'nainen käsikäyttöisessä pyörätuolissa: vaalea iho, kohti oikeaa',
    '👩🏼‍🦽‍➡' => 'nainen käsikäyttöisessä pyörätuolissa: keskivaalea iho, kohti oikeaa',
    '👩🏽‍🦽‍➡' => 'nainen käsikäyttöisessä pyörätuolissa: tummanvaalea iho, kohti oikeaa',
    '👩🏾‍🦽‍➡' => 'nainen käsikäyttöisessä pyörätuolissa: keskitumma iho, kohti oikeaa',
    '👩🏿‍🦽‍➡' => 'nainen käsikäyttöisessä pyörätuolissa: tumma iho, kohti oikeaa',
    '🏃🏻‍♀‍➡' => 'juokseva nainen: vaalea iho, kohti oikeaa',
    '🏃🏼‍♀‍➡' => 'juokseva nainen: keskivaalea iho, kohti oikeaa',
    '🏃🏽‍♀‍➡' => 'juokseva nainen: tummanvaalea iho, kohti oikeaa',
    '🏃🏾‍♀‍➡' => 'juokseva nainen: keskitumma iho, kohti oikeaa',
    '🏃🏿‍♀‍➡' => 'juokseva nainen: tumma iho, kohti oikeaa',
    '🏃🏻‍♂‍➡' => 'juokseva mies: vaalea iho, kohti oikeaa',
    '🏃🏼‍♂‍➡' => 'juokseva mies: keskivaalea iho, kohti oikeaa',
    '🏃🏽‍♂‍➡' => 'juokseva mies: tummanvaalea iho, kohti oikeaa',
    '🏃🏾‍♂‍➡' => 'juokseva mies: keskitumma iho, kohti oikeaa',
    '🏃🏿‍♂‍➡' => 'juokseva mies: tumma iho, kohti oikeaa',
    '🫱🏻‍🫲🏼' => 'kädenpuristus: vaalea iho, keskivaalea iho',
    '🫱🏻‍🫲🏽' => 'kädenpuristus: vaalea iho, tummanvaalea iho',
    '🫱🏻‍🫲🏾' => 'kädenpuristus: vaalea iho, keskitumma iho',
    '🫱🏻‍🫲🏿' => 'kädenpuristus: vaalea iho, tumma iho',
    '🫱🏼‍🫲🏻' => 'kädenpuristus: keskivaalea iho, vaalea iho',
    '🫱🏼‍🫲🏽' => 'kädenpuristus: keskivaalea iho, tummanvaalea iho',
    '🫱🏼‍🫲🏾' => 'kädenpuristus: keskivaalea iho, keskitumma iho',
    '🫱🏼‍🫲🏿' => 'kädenpuristus: keskivaalea iho, tumma iho',
    '🫱🏽‍🫲🏻' => 'kädenpuristus: tummanvaalea iho, vaalea iho',
    '🫱🏽‍🫲🏼' => 'kädenpuristus: tummanvaalea iho, keskivaalea iho',
    '🫱🏽‍🫲🏾' => 'kädenpuristus: tummanvaalea iho, keskitumma iho',
    '🫱🏽‍🫲🏿' => 'kädenpuristus: tummanvaalea iho, tumma iho',
    '🫱🏾‍🫲🏻' => 'kädenpuristus: keskitumma iho, vaalea iho',
    '🫱🏾‍🫲🏼' => 'kädenpuristus: keskitumma iho, keskivaalea iho',
    '🫱🏾‍🫲🏽' => 'kädenpuristus: keskitumma iho, tummanvaalea iho',
    '🫱🏾‍🫲🏿' => 'kädenpuristus: keskitumma iho, tumma iho',
    '🫱🏿‍🫲🏻' => 'kädenpuristus: tumma iho, vaalea iho',
    '🫱🏿‍🫲🏼' => 'kädenpuristus: tumma iho, keskivaalea iho',
    '🫱🏿‍🫲🏽' => 'kädenpuristus: tumma iho, tummanvaalea iho',
    '🫱🏿‍🫲🏾' => 'kädenpuristus: tumma iho, keskitumma iho',
    '🚶‍♀‍➡' => 'kävelevä nainen: kohti oikeaa',
    '🚶‍♂‍➡' => 'kävelevä mies: kohti oikeaa',
    '🧎‍♀‍➡' => 'polvistuva nainen: kohti oikeaa',
    '🧎‍♂‍➡' => 'polvistuva mies: kohti oikeaa',
    '🧑‍🦯‍➡' => 'henkilö ja valkoinen keppi: kohti oikeaa',
    '👨‍🦯‍➡' => 'mies ja valkoinen keppi: kohti oikeaa',
    '👩‍🦯‍➡' => 'nainen ja valkoinen keppi: kohti oikeaa',
    '🧑‍🦼‍➡' => 'henkilö moottoroidussa pyörätuolissa: kohti oikeaa',
    '👨‍🦼‍➡' => 'mies moottoroidussa pyörätuolissa: kohti oikeaa',
    '👩‍🦼‍➡' => 'nainen moottoroidussa pyörätuolissa: kohti oikeaa',
    '🧑‍🦽‍➡' => 'henkilö käsikäyttöisessä pyörätuolissa: kohti oikeaa',
    '👨‍🦽‍➡' => 'mies käsikäyttöisessä pyörätuolissa: kohti oikeaa',
    '👩‍🦽‍➡' => 'nainen käsikäyttöisessä pyörätuolissa: kohti oikeaa',
    '🏃‍♀‍➡' => 'juokseva nainen: kohti oikeaa',
    '🏃‍♂‍➡' => 'juokseva mies: kohti oikeaa',
    '👩‍❤‍👨' => 'pariskunta ja sydän: nainen, mies',
    '👨‍❤‍👨' => 'pariskunta ja sydän: mies, mies',
    '👩‍❤‍👩' => 'pariskunta ja sydän: nainen, nainen',
    '👨‍👩‍👦' => 'perhe: mies, nainen, poika',
    '👨‍👩‍👧' => 'perhe: mies, nainen, tyttö',
    '👨‍👨‍👦' => 'perhe: mies, mies, poika',
    '👨‍👨‍👧' => 'perhe: mies, mies, tyttö',
    '👩‍👩‍👦' => 'perhe: nainen, nainen, poika',
    '👩‍👩‍👧' => 'perhe: nainen, nainen, tyttö',
    '👨‍👦‍👦' => 'perhe: mies, poika, poika',
    '👨‍👧‍👦' => 'perhe: mies, tyttö, poika',
    '👨‍👧‍👧' => 'perhe: mies, tyttö, tyttö',
    '👩‍👦‍👦' => 'perhe: nainen, poika, poika',
    '👩‍👧‍👦' => 'perhe: nainen, tyttö, poika',
    '👩‍👧‍👧' => 'perhe: nainen, tyttö, tyttö',
    '🧑‍🤝‍🧑' => 'ihmiset käsi kädessä',
    '🧑‍🧑‍🧒' => 'perhe: aikuinen, aikuinen, lapsi',
    '🧑‍🧒‍🧒' => 'perhe: aikuinen, lapsi, lapsi',
    '🧑🏻‍🦰' => 'aikuinen: vaalea iho, punatukkainen',
    '🧑🏼‍🦰' => 'aikuinen: keskivaalea iho, punatukkainen',
    '🧑🏽‍🦰' => 'aikuinen: tummanvaalea iho, punatukkainen',
    '🧑🏾‍🦰' => 'aikuinen: keskitumma iho, punatukkainen',
    '🧑🏿‍🦰' => 'aikuinen: tumma iho, punatukkainen',
    '🧑🏻‍🦱' => 'aikuinen: vaalea iho, kiharatukkainen',
    '🧑🏼‍🦱' => 'aikuinen: keskivaalea iho, kiharatukkainen',
    '🧑🏽‍🦱' => 'aikuinen: tummanvaalea iho, kiharatukkainen',
    '🧑🏾‍🦱' => 'aikuinen: keskitumma iho, kiharatukkainen',
    '🧑🏿‍🦱' => 'aikuinen: tumma iho, kiharatukkainen',
    '🧑🏻‍🦳' => 'aikuinen: vaalea iho, valkotukkainen',
    '🧑🏼‍🦳' => 'aikuinen: keskivaalea iho, valkotukkainen',
    '🧑🏽‍🦳' => 'aikuinen: tummanvaalea iho, valkotukkainen',
    '🧑🏾‍🦳' => 'aikuinen: keskitumma iho, valkotukkainen',
    '🧑🏿‍🦳' => 'aikuinen: tumma iho, valkotukkainen',
    '🧑🏻‍🦲' => 'aikuinen: vaalea iho, kalju',
    '🧑🏼‍🦲' => 'aikuinen: keskivaalea iho, kalju',
    '🧑🏽‍🦲' => 'aikuinen: tummanvaalea iho, kalju',
    '🧑🏾‍🦲' => 'aikuinen: keskitumma iho, kalju',
    '🧑🏿‍🦲' => 'aikuinen: tumma iho, kalju',
    '🧑🏻‍🩰' => 'balettitanssija: vaalea iho',
    '🧑🏼‍🩰' => 'balettitanssija: keskivaalea iho',
    '🧑🏽‍🩰' => 'balettitanssija: tummanvaalea iho',
    '🧑🏾‍🩰' => 'balettitanssija: keskitumma iho',
    '🧑🏿‍🩰' => 'balettitanssija: tumma iho',
    '🧔🏻‍♂' => 'parrakas mies: vaalea iho',
    '🧔🏼‍♂' => 'parrakas mies: keskivaalea iho',
    '🧔🏽‍♂' => 'parrakas mies: tummanvaalea iho',
    '🧔🏾‍♂' => 'parrakas mies: keskitumma iho',
    '🧔🏿‍♂' => 'parrakas mies: tumma iho',
    '👱🏻‍♂' => 'vaaleatukkainen mies: vaalea iho',
    '👱🏼‍♂' => 'vaaleatukkainen mies: keskivaalea iho',
    '👱🏽‍♂' => 'vaaleatukkainen mies: tummanvaalea iho',
    '👱🏾‍♂' => 'vaaleatukkainen mies: keskitumma iho',
    '👱🏿‍♂' => 'vaaleatukkainen mies: tumma iho',
    '👨🏻‍🦰' => 'mies: vaalea iho, punatukkainen',
    '👨🏼‍🦰' => 'mies: keskivaalea iho, punatukkainen',
    '👨🏽‍🦰' => 'mies: tummanvaalea iho, punatukkainen',
    '👨🏾‍🦰' => 'mies: keskitumma iho, punatukkainen',
    '👨🏿‍🦰' => 'mies: tumma iho, punatukkainen',
    '👨🏻‍🦱' => 'mies: vaalea iho, kiharatukkainen',
    '👨🏼‍🦱' => 'mies: keskivaalea iho, kiharatukkainen',
    '👨🏽‍🦱' => 'mies: tummanvaalea iho, kiharatukkainen',
    '👨🏾‍🦱' => 'mies: keskitumma iho, kiharatukkainen',
    '👨🏿‍🦱' => 'mies: tumma iho, kiharatukkainen',
    '👨🏻‍🦳' => 'mies: vaalea iho, valkotukkainen',
    '👨🏼‍🦳' => 'mies: keskivaalea iho, valkotukkainen',
    '👨🏽‍🦳' => 'mies: tummanvaalea iho, valkotukkainen',
    '👨🏾‍🦳' => 'mies: keskitumma iho, valkotukkainen',
    '👨🏿‍🦳' => 'mies: tumma iho, valkotukkainen',
    '👨🏻‍🦲' => 'mies: vaalea iho, kalju',
    '👨🏼‍🦲' => 'mies: keskivaalea iho, kalju',
    '👨🏽‍🦲' => 'mies: tummanvaalea iho, kalju',
    '👨🏾‍🦲' => 'mies: keskitumma iho, kalju',
    '👨🏿‍🦲' => 'mies: tumma iho, kalju',
    '🧔🏻‍♀' => 'parrakas nainen: vaalea iho',
    '🧔🏼‍♀' => 'parrakas nainen: keskivaalea iho',
    '🧔🏽‍♀' => 'parrakas nainen: tummanvaalea iho',
    '🧔🏾‍♀' => 'parrakas nainen: keskitumma iho',
    '🧔🏿‍♀' => 'parrakas nainen: tumma iho',
    '👱🏻‍♀' => 'vaaleatukkainen nainen: vaalea iho',
    '👱🏼‍♀' => 'vaaleatukkainen nainen: keskivaalea iho',
    '👱🏽‍♀' => 'vaaleatukkainen nainen: tummanvaalea iho',
    '👱🏾‍♀' => 'vaaleatukkainen nainen: keskitumma iho',
    '👱🏿‍♀' => 'vaaleatukkainen nainen: tumma iho',
    '👩🏻‍🦰' => 'nainen: vaalea iho, punatukkainen',
    '👩🏼‍🦰' => 'nainen: keskivaalea iho, punatukkainen',
    '👩🏽‍🦰' => 'nainen: tummanvaalea iho, punatukkainen',
    '👩🏾‍🦰' => 'nainen: keskitumma iho, punatukkainen',
    '👩🏿‍🦰' => 'nainen: tumma iho, punatukkainen',
    '👩🏻‍🦱' => 'nainen: vaalea iho, kiharatukkainen',
    '👩🏼‍🦱' => 'nainen: keskivaalea iho, kiharatukkainen',
    '👩🏽‍🦱' => 'nainen: tummanvaalea iho, kiharatukkainen',
    '👩🏾‍🦱' => 'nainen: keskitumma iho, kiharatukkainen',
    '👩🏿‍🦱' => 'nainen: tumma iho, kiharatukkainen',
    '👩🏻‍🦳' => 'nainen: vaalea iho, valkotukkainen',
    '👩🏼‍🦳' => 'nainen: keskivaalea iho, valkotukkainen',
    '👩🏽‍🦳' => 'nainen: tummanvaalea iho, valkotukkainen',
    '👩🏾‍🦳' => 'nainen: keskitumma iho, valkotukkainen',
    '👩🏿‍🦳' => 'nainen: tumma iho, valkotukkainen',
    '👩🏻‍🦲' => 'nainen: vaalea iho, kalju',
    '👩🏼‍🦲' => 'nainen: keskivaalea iho, kalju',
    '👩🏽‍🦲' => 'nainen: tummanvaalea iho, kalju',
    '👩🏾‍🦲' => 'nainen: keskitumma iho, kalju',
    '👩🏿‍🦲' => 'nainen: tumma iho, kalju',
    '🙍🏻‍♂' => 'surullinen mies: vaalea iho',
    '🙍🏼‍♂' => 'surullinen mies: keskivaalea iho',
    '🙍🏽‍♂' => 'surullinen mies: tummanvaalea iho',
    '🙍🏾‍♂' => 'surullinen mies: keskitumma iho',
    '🙍🏿‍♂' => 'surullinen mies: tumma iho',
    '🙍🏻‍♀' => 'surullinen nainen: vaalea iho',
    '🙍🏼‍♀' => 'surullinen nainen: keskivaalea iho',
    '🙍🏽‍♀' => 'surullinen nainen: tummanvaalea iho',
    '🙍🏾‍♀' => 'surullinen nainen: keskitumma iho',
    '🙍🏿‍♀' => 'surullinen nainen: tumma iho',
    '🙎🏻‍♂' => 'mököttävä mies: vaalea iho',
    '🙎🏼‍♂' => 'mököttävä mies: keskivaalea iho',
    '🙎🏽‍♂' => 'mököttävä mies: tummanvaalea iho',
    '🙎🏾‍♂' => 'mököttävä mies: keskitumma iho',
    '🙎🏿‍♂' => 'mököttävä mies: tumma iho',
    '🙎🏻‍♀' => 'mököttävä nainen: vaalea iho',
    '🙎🏼‍♀' => 'mököttävä nainen: keskivaalea iho',
    '🙎🏽‍♀' => 'mököttävä nainen: tummanvaalea iho',
    '🙎🏾‍♀' => 'mököttävä nainen: keskitumma iho',
    '🙎🏿‍♀' => 'mököttävä nainen: tumma iho',
    '🙅🏻‍♂' => 'ei käy -merkkiä näyttävä mies: vaalea iho',
    '🙅🏼‍♂' => 'ei käy -merkkiä näyttävä mies: keskivaalea iho',
    '🙅🏽‍♂' => 'ei käy -merkkiä näyttävä mies: tummanvaalea iho',
    '🙅🏾‍♂' => 'ei käy -merkkiä näyttävä mies: keskitumma iho',
    '🙅🏿‍♂' => 'ei käy -merkkiä näyttävä mies: tumma iho',
    '🙅🏻‍♀' => 'ei käy -merkkiä näyttävä nainen: vaalea iho',
    '🙅🏼‍♀' => 'ei käy -merkkiä näyttävä nainen: keskivaalea iho',
    '🙅🏽‍♀' => 'ei käy -merkkiä näyttävä nainen: tummanvaalea iho',
    '🙅🏾‍♀' => 'ei käy -merkkiä näyttävä nainen: keskitumma iho',
    '🙅🏿‍♀' => 'ei käy -merkkiä näyttävä nainen: tumma iho',
    '🙆🏻‍♂' => 'ok-merkkiä näyttävä mies: vaalea iho',
    '🙆🏼‍♂' => 'ok-merkkiä näyttävä mies: keskivaalea iho',
    '🙆🏽‍♂' => 'ok-merkkiä näyttävä mies: tummanvaalea iho',
    '🙆🏾‍♂' => 'ok-merkkiä näyttävä mies: keskitumma iho',
    '🙆🏿‍♂' => 'ok-merkkiä näyttävä mies: tumma iho',
    '🙆🏻‍♀' => 'ok-merkkiä näyttävä nainen: vaalea iho',
    '🙆🏼‍♀' => 'ok-merkkiä näyttävä nainen: keskivaalea iho',
    '🙆🏽‍♀' => 'ok-merkkiä näyttävä nainen: tummanvaalea iho',
    '🙆🏾‍♀' => 'ok-merkkiä näyttävä nainen: keskitumma iho',
    '🙆🏿‍♀' => 'ok-merkkiä näyttävä nainen: tumma iho',
    '💁🏻‍♂' => 'kämmentä ylöspäin näyttävä mies: vaalea iho',
    '💁🏼‍♂' => 'kämmentä ylöspäin näyttävä mies: keskivaalea iho',
    '💁🏽‍♂' => 'kämmentä ylöspäin näyttävä mies: tummanvaalea iho',
    '💁🏾‍♂' => 'kämmentä ylöspäin näyttävä mies: keskitumma iho',
    '💁🏿‍♂' => 'kämmentä ylöspäin näyttävä mies: tumma iho',
    '💁🏻‍♀' => 'kämmentä ylöspäin näyttävä nainen: vaalea iho',
    '💁🏼‍♀' => 'kämmentä ylöspäin näyttävä nainen: keskivaalea iho',
    '💁🏽‍♀' => 'kämmentä ylöspäin näyttävä nainen: tummanvaalea iho',
    '💁🏾‍♀' => 'kämmentä ylöspäin näyttävä nainen: keskitumma iho',
    '💁🏿‍♀' => 'kämmentä ylöspäin näyttävä nainen: tumma iho',
    '🙋🏻‍♂' => 'viittaava mies: vaalea iho',
    '🙋🏼‍♂' => 'viittaava mies: keskivaalea iho',
    '🙋🏽‍♂' => 'viittaava mies: tummanvaalea iho',
    '🙋🏾‍♂' => 'viittaava mies: keskitumma iho',
    '🙋🏿‍♂' => 'viittaava mies: tumma iho',
    '🙋🏻‍♀' => 'viittaava nainen: vaalea iho',
    '🙋🏼‍♀' => 'viittaava nainen: keskivaalea iho',
    '🙋🏽‍♀' => 'viittaava nainen: tummanvaalea iho',
    '🙋🏾‍♀' => 'viittaava nainen: keskitumma iho',
    '🙋🏿‍♀' => 'viittaava nainen: tumma iho',
    '🧏🏻‍♂' => 'kuuro mies: vaalea iho',
    '🧏🏼‍♂' => 'kuuro mies: keskivaalea iho',
    '🧏🏽‍♂' => 'kuuro mies: tummanvaalea iho',
    '🧏🏾‍♂' => 'kuuro mies: keskitumma iho',
    '🧏🏿‍♂' => 'kuuro mies: tumma iho',
    '🧏🏻‍♀' => 'kuuro nainen: vaalea iho',
    '🧏🏼‍♀' => 'kuuro nainen: keskivaalea iho',
    '🧏🏽‍♀' => 'kuuro nainen: tummanvaalea iho',
    '🧏🏾‍♀' => 'kuuro nainen: keskitumma iho',
    '🧏🏿‍♀' => 'kuuro nainen: tumma iho',
    '🙇🏻‍♂' => 'syvään kumartava mies: vaalea iho',
    '🙇🏼‍♂' => 'syvään kumartava mies: keskivaalea iho',
    '🙇🏽‍♂' => 'syvään kumartava mies: tummanvaalea iho',
    '🙇🏾‍♂' => 'syvään kumartava mies: keskitumma iho',
    '🙇🏿‍♂' => 'syvään kumartava mies: tumma iho',
    '🙇🏻‍♀' => 'syvään kumartava nainen: vaalea iho',
    '🙇🏼‍♀' => 'syvään kumartava nainen: keskivaalea iho',
    '🙇🏽‍♀' => 'syvään kumartava nainen: tummanvaalea iho',
    '🙇🏾‍♀' => 'syvään kumartava nainen: keskitumma iho',
    '🙇🏿‍♀' => 'syvään kumartava nainen: tumma iho',
    '🤦🏻‍♂' => 'kasvonsa kädellä peittävä mies: vaalea iho',
    '🤦🏼‍♂' => 'kasvonsa kädellä peittävä mies: keskivaalea iho',
    '🤦🏽‍♂' => 'kasvonsa kädellä peittävä mies: tummanvaalea iho',
    '🤦🏾‍♂' => 'kasvonsa kädellä peittävä mies: keskitumma iho',
    '🤦🏿‍♂' => 'kasvonsa kädellä peittävä mies: tumma iho',
    '🤦🏻‍♀' => 'kasvonsa kädellä peittävä nainen: vaalea iho',
    '🤦🏼‍♀' => 'kasvonsa kädellä peittävä nainen: keskivaalea iho',
    '🤦🏽‍♀' => 'kasvonsa kädellä peittävä nainen: tummanvaalea iho',
    '🤦🏾‍♀' => 'kasvonsa kädellä peittävä nainen: keskitumma iho',
    '🤦🏿‍♀' => 'kasvonsa kädellä peittävä nainen: tumma iho',
    '🤷🏻‍♂' => 'olkapäitään kohauttava mies: vaalea iho',
    '🤷🏼‍♂' => 'olkapäitään kohauttava mies: keskivaalea iho',
    '🤷🏽‍♂' => 'olkapäitään kohauttava mies: tummanvaalea iho',
    '🤷🏾‍♂' => 'olkapäitään kohauttava mies: keskitumma iho',
    '🤷🏿‍♂' => 'olkapäitään kohauttava mies: tumma iho',
    '🤷🏻‍♀' => 'olkapäitään kohauttava nainen: vaalea iho',
    '🤷🏼‍♀' => 'olkapäitään kohauttava nainen: keskivaalea iho',
    '🤷🏽‍♀' => 'olkapäitään kohauttava nainen: tummanvaalea iho',
    '🤷🏾‍♀' => 'olkapäitään kohauttava nainen: keskitumma iho',
    '🤷🏿‍♀' => 'olkapäitään kohauttava nainen: tumma iho',
    '🧑🏻‍⚕' => 'hoitotyöntekijä: vaalea iho',
    '🧑🏼‍⚕' => 'hoitotyöntekijä: keskivaalea iho',
    '🧑🏽‍⚕' => 'hoitotyöntekijä: tummanvaalea iho',
    '🧑🏾‍⚕' => 'hoitotyöntekijä: keskitumma iho',
    '🧑🏿‍⚕' => 'hoitotyöntekijä: tumma iho',
    '👨🏻‍⚕' => 'mieshoitotyöntekijä: vaalea iho',
    '👨🏼‍⚕' => 'mieshoitotyöntekijä: keskivaalea iho',
    '👨🏽‍⚕' => 'mieshoitotyöntekijä: tummanvaalea iho',
    '👨🏾‍⚕' => 'mieshoitotyöntekijä: keskitumma iho',
    '👨🏿‍⚕' => 'mieshoitotyöntekijä: tumma iho',
    '👩🏻‍⚕' => 'naishoitotyöntekijä: vaalea iho',
    '👩🏼‍⚕' => 'naishoitotyöntekijä: keskivaalea iho',
    '👩🏽‍⚕' => 'naishoitotyöntekijä: tummanvaalea iho',
    '👩🏾‍⚕' => 'naishoitotyöntekijä: keskitumma iho',
    '👩🏿‍⚕' => 'naishoitotyöntekijä: tumma iho',
    '🧑🏻‍🎓' => 'opiskelija: vaalea iho',
    '🧑🏼‍🎓' => 'opiskelija: keskivaalea iho',
    '🧑🏽‍🎓' => 'opiskelija: tummanvaalea iho',
    '🧑🏾‍🎓' => 'opiskelija: keskitumma iho',
    '🧑🏿‍🎓' => 'opiskelija: tumma iho',
    '👨🏻‍🎓' => 'miesopiskelija: vaalea iho',
    '👨🏼‍🎓' => 'miesopiskelija: keskivaalea iho',
    '👨🏽‍🎓' => 'miesopiskelija: tummanvaalea iho',
    '👨🏾‍🎓' => 'miesopiskelija: keskitumma iho',
    '👨🏿‍🎓' => 'miesopiskelija: tumma iho',
    '👩🏻‍🎓' => 'naisopiskelija: vaalea iho',
    '👩🏼‍🎓' => 'naisopiskelija: keskivaalea iho',
    '👩🏽‍🎓' => 'naisopiskelija: tummanvaalea iho',
    '👩🏾‍🎓' => 'naisopiskelija: keskitumma iho',
    '👩🏿‍🎓' => 'naisopiskelija: tumma iho',
    '🧑🏻‍🏫' => 'opettaja: vaalea iho',
    '🧑🏼‍🏫' => 'opettaja: keskivaalea iho',
    '🧑🏽‍🏫' => 'opettaja: tummanvaalea iho',
    '🧑🏾‍🏫' => 'opettaja: keskitumma iho',
    '🧑🏿‍🏫' => 'opettaja: tumma iho',
    '👨🏻‍🏫' => 'miesopettaja: vaalea iho',
    '👨🏼‍🏫' => 'miesopettaja: keskivaalea iho',
    '👨🏽‍🏫' => 'miesopettaja: tummanvaalea iho',
    '👨🏾‍🏫' => 'miesopettaja: keskitumma iho',
    '👨🏿‍🏫' => 'miesopettaja: tumma iho',
    '👩🏻‍🏫' => 'naisopettaja: vaalea iho',
    '👩🏼‍🏫' => 'naisopettaja: keskivaalea iho',
    '👩🏽‍🏫' => 'naisopettaja: tummanvaalea iho',
    '👩🏾‍🏫' => 'naisopettaja: keskitumma iho',
    '👩🏿‍🏫' => 'naisopettaja: tumma iho',
    '🧑🏻‍⚖' => 'tuomari: vaalea iho',
    '🧑🏼‍⚖' => 'tuomari: keskivaalea iho',
    '🧑🏽‍⚖' => 'tuomari: tummanvaalea iho',
    '🧑🏾‍⚖' => 'tuomari: keskitumma iho',
    '🧑🏿‍⚖' => 'tuomari: tumma iho',
    '👨🏻‍⚖' => 'miestuomari: vaalea iho',
    '👨🏼‍⚖' => 'miestuomari: keskivaalea iho',
    '👨🏽‍⚖' => 'miestuomari: tummanvaalea iho',
    '👨🏾‍⚖' => 'miestuomari: keskitumma iho',
    '👨🏿‍⚖' => 'miestuomari: tumma iho',
    '👩🏻‍⚖' => 'naistuomari: vaalea iho',
    '👩🏼‍⚖' => 'naistuomari: keskivaalea iho',
    '👩🏽‍⚖' => 'naistuomari: tummanvaalea iho',
    '👩🏾‍⚖' => 'naistuomari: keskitumma iho',
    '👩🏿‍⚖' => 'naistuomari: tumma iho',
    '🧑🏻‍🌾' => 'maanviljelijä: vaalea iho',
    '🧑🏼‍🌾' => 'maanviljelijä: keskivaalea iho',
    '🧑🏽‍🌾' => 'maanviljelijä: tummanvaalea iho',
    '🧑🏾‍🌾' => 'maanviljelijä: keskitumma iho',
    '🧑🏿‍🌾' => 'maanviljelijä: tumma iho',
    '👨🏻‍🌾' => 'miesmaanviljelijä: vaalea iho',
    '👨🏼‍🌾' => 'miesmaanviljelijä: keskivaalea iho',
    '👨🏽‍🌾' => 'miesmaanviljelijä: tummanvaalea iho',
    '👨🏾‍🌾' => 'miesmaanviljelijä: keskitumma iho',
    '👨🏿‍🌾' => 'miesmaanviljelijä: tumma iho',
    '👩🏻‍🌾' => 'naismaanviljelijä: vaalea iho',
    '👩🏼‍🌾' => 'naismaanviljelijä: keskivaalea iho',
    '👩🏽‍🌾' => 'naismaanviljelijä: tummanvaalea iho',
    '👩🏾‍🌾' => 'naismaanviljelijä: keskitumma iho',
    '👩🏿‍🌾' => 'naismaanviljelijä: tumma iho',
    '🧑🏻‍🍳' => 'kokki: vaalea iho',
    '🧑🏼‍🍳' => 'kokki: keskivaalea iho',
    '🧑🏽‍🍳' => 'kokki: tummanvaalea iho',
    '🧑🏾‍🍳' => 'kokki: keskitumma iho',
    '🧑🏿‍🍳' => 'kokki: tumma iho',
    '👨🏻‍🍳' => 'mieskokki: vaalea iho',
    '👨🏼‍🍳' => 'mieskokki: keskivaalea iho',
    '👨🏽‍🍳' => 'mieskokki: tummanvaalea iho',
    '👨🏾‍🍳' => 'mieskokki: keskitumma iho',
    '👨🏿‍🍳' => 'mieskokki: tumma iho',
    '👩🏻‍🍳' => 'naiskokki: vaalea iho',
    '👩🏼‍🍳' => 'naiskokki: keskivaalea iho',
    '👩🏽‍🍳' => 'naiskokki: tummanvaalea iho',
    '👩🏾‍🍳' => 'naiskokki: keskitumma iho',
    '👩🏿‍🍳' => 'naiskokki: tumma iho',
    '🧑🏻‍🔧' => 'mekaanikko: vaalea iho',
    '🧑🏼‍🔧' => 'mekaanikko: keskivaalea iho',
    '🧑🏽‍🔧' => 'mekaanikko: tummanvaalea iho',
    '🧑🏾‍🔧' => 'mekaanikko: keskitumma iho',
    '🧑🏿‍🔧' => 'mekaanikko: tumma iho',
    '👨🏻‍🔧' => 'miesmekaanikko: vaalea iho',
    '👨🏼‍🔧' => 'miesmekaanikko: keskivaalea iho',
    '👨🏽‍🔧' => 'miesmekaanikko: tummanvaalea iho',
    '👨🏾‍🔧' => 'miesmekaanikko: keskitumma iho',
    '👨🏿‍🔧' => 'miesmekaanikko: tumma iho',
    '👩🏻‍🔧' => 'naismekaanikko: vaalea iho',
    '👩🏼‍🔧' => 'naismekaanikko: keskivaalea iho',
    '👩🏽‍🔧' => 'naismekaanikko: tummanvaalea iho',
    '👩🏾‍🔧' => 'naismekaanikko: keskitumma iho',
    '👩🏿‍🔧' => 'naismekaanikko: tumma iho',
    '🧑🏻‍🏭' => 'tehdastyöntekijä: vaalea iho',
    '🧑🏼‍🏭' => 'tehdastyöntekijä: keskivaalea iho',
    '🧑🏽‍🏭' => 'tehdastyöntekijä: tummanvaalea iho',
    '🧑🏾‍🏭' => 'tehdastyöntekijä: keskitumma iho',
    '🧑🏿‍🏭' => 'tehdastyöntekijä: tumma iho',
    '👨🏻‍🏭' => 'miestehdastyöntekijä: vaalea iho',
    '👨🏼‍🏭' => 'miestehdastyöntekijä: keskivaalea iho',
    '👨🏽‍🏭' => 'miestehdastyöntekijä: tummanvaalea iho',
    '👨🏾‍🏭' => 'miestehdastyöntekijä: keskitumma iho',
    '👨🏿‍🏭' => 'miestehdastyöntekijä: tumma iho',
    '👩🏻‍🏭' => 'naistehdastyöntekijä: vaalea iho',
    '👩🏼‍🏭' => 'naistehdastyöntekijä: keskivaalea iho',
    '👩🏽‍🏭' => 'naistehdastyöntekijä: tummanvaalea iho',
    '👩🏾‍🏭' => 'naistehdastyöntekijä: keskitumma iho',
    '👩🏿‍🏭' => 'naistehdastyöntekijä: tumma iho',
    '🧑🏻‍💼' => 'toimistotyöntekijä: vaalea iho',
    '🧑🏼‍💼' => 'toimistotyöntekijä: keskivaalea iho',
    '🧑🏽‍💼' => 'toimistotyöntekijä: tummanvaalea iho',
    '🧑🏾‍💼' => 'toimistotyöntekijä: keskitumma iho',
    '🧑🏿‍💼' => 'toimistotyöntekijä: tumma iho',
    '👨🏻‍💼' => 'miestoimistotyöntekijä: vaalea iho',
    '👨🏼‍💼' => 'miestoimistotyöntekijä: keskivaalea iho',
    '👨🏽‍💼' => 'miestoimistotyöntekijä: tummanvaalea iho',
    '👨🏾‍💼' => 'miestoimistotyöntekijä: keskitumma iho',
    '👨🏿‍💼' => 'miestoimistotyöntekijä: tumma iho',
    '👩🏻‍💼' => 'naistoimistotyöntekijä: vaalea iho',
    '👩🏼‍💼' => 'naistoimistotyöntekijä: keskivaalea iho',
    '👩🏽‍💼' => 'naistoimistotyöntekijä: tummanvaalea iho',
    '👩🏾‍💼' => 'naistoimistotyöntekijä: keskitumma iho',
    '👩🏿‍💼' => 'naistoimistotyöntekijä: tumma iho',
    '🧑🏻‍🔬' => 'tutkija: vaalea iho',
    '🧑🏼‍🔬' => 'tutkija: keskivaalea iho',
    '🧑🏽‍🔬' => 'tutkija: tummanvaalea iho',
    '🧑🏾‍🔬' => 'tutkija: keskitumma iho',
    '🧑🏿‍🔬' => 'tutkija: tumma iho',
    '👨🏻‍🔬' => 'miestutkija: vaalea iho',
    '👨🏼‍🔬' => 'miestutkija: keskivaalea iho',
    '👨🏽‍🔬' => 'miestutkija: tummanvaalea iho',
    '👨🏾‍🔬' => 'miestutkija: keskitumma iho',
    '👨🏿‍🔬' => 'miestutkija: tumma iho',
    '👩🏻‍🔬' => 'naistutkija: vaalea iho',
    '👩🏼‍🔬' => 'naistutkija: keskivaalea iho',
    '👩🏽‍🔬' => 'naistutkija: tummanvaalea iho',
    '👩🏾‍🔬' => 'naistutkija: keskitumma iho',
    '👩🏿‍🔬' => 'naistutkija: tumma iho',
    '🧑🏻‍💻' => 'IT-työntekijä: vaalea iho',
    '🧑🏼‍💻' => 'IT-työntekijä: keskivaalea iho',
    '🧑🏽‍💻' => 'IT-työntekijä: tummanvaalea iho',
    '🧑🏾‍💻' => 'IT-työntekijä: keskitumma iho',
    '🧑🏿‍💻' => 'IT-työntekijä: tumma iho',
    '👨🏻‍💻' => 'IT-mies: vaalea iho',
    '👨🏼‍💻' => 'IT-mies: keskivaalea iho',
    '👨🏽‍💻' => 'IT-mies: tummanvaalea iho',
    '👨🏾‍💻' => 'IT-mies: keskitumma iho',
    '👨🏿‍💻' => 'IT-mies: tumma iho',
    '👩🏻‍💻' => 'IT-nainen: vaalea iho',
    '👩🏼‍💻' => 'IT-nainen: keskivaalea iho',
    '👩🏽‍💻' => 'IT-nainen: tummanvaalea iho',
    '👩🏾‍💻' => 'IT-nainen: keskitumma iho',
    '👩🏿‍💻' => 'IT-nainen: tumma iho',
    '🧑🏻‍🎤' => 'laulaja: vaalea iho',
    '🧑🏼‍🎤' => 'laulaja: keskivaalea iho',
    '🧑🏽‍🎤' => 'laulaja: tummanvaalea iho',
    '🧑🏾‍🎤' => 'laulaja: keskitumma iho',
    '🧑🏿‍🎤' => 'laulaja: tumma iho',
    '👨🏻‍🎤' => 'mieslaulaja: vaalea iho',
    '👨🏼‍🎤' => 'mieslaulaja: keskivaalea iho',
    '👨🏽‍🎤' => 'mieslaulaja: tummanvaalea iho',
    '👨🏾‍🎤' => 'mieslaulaja: keskitumma iho',
    '👨🏿‍🎤' => 'mieslaulaja: tumma iho',
    '👩🏻‍🎤' => 'naislaulaja: vaalea iho',
    '👩🏼‍🎤' => 'naislaulaja: keskivaalea iho',
    '👩🏽‍🎤' => 'naislaulaja: tummanvaalea iho',
    '👩🏾‍🎤' => 'naislaulaja: keskitumma iho',
    '👩🏿‍🎤' => 'naislaulaja: tumma iho',
    '🧑🏻‍🎨' => 'artisti: vaalea iho',
    '🧑🏼‍🎨' => 'artisti: keskivaalea iho',
    '🧑🏽‍🎨' => 'artisti: tummanvaalea iho',
    '🧑🏾‍🎨' => 'artisti: keskitumma iho',
    '🧑🏿‍🎨' => 'artisti: tumma iho',
    '👨🏻‍🎨' => 'miestaiteilija: vaalea iho',
    '👨🏼‍🎨' => 'miestaiteilija: keskivaalea iho',
    '👨🏽‍🎨' => 'miestaiteilija: tummanvaalea iho',
    '👨🏾‍🎨' => 'miestaiteilija: keskitumma iho',
    '👨🏿‍🎨' => 'miestaiteilija: tumma iho',
    '👩🏻‍🎨' => 'naistaiteilija: vaalea iho',
    '👩🏼‍🎨' => 'naistaiteilija: keskivaalea iho',
    '👩🏽‍🎨' => 'naistaiteilija: tummanvaalea iho',
    '👩🏾‍🎨' => 'naistaiteilija: keskitumma iho',
    '👩🏿‍🎨' => 'naistaiteilija: tumma iho',
    '🧑🏻‍✈' => 'pilotti: vaalea iho',
    '🧑🏼‍✈' => 'pilotti: keskivaalea iho',
    '🧑🏽‍✈' => 'pilotti: tummanvaalea iho',
    '🧑🏾‍✈' => 'pilotti: keskitumma iho',
    '🧑🏿‍✈' => 'pilotti: tumma iho',
    '👨🏻‍✈' => 'miespilotti: vaalea iho',
    '👨🏼‍✈' => 'miespilotti: keskivaalea iho',
    '👨🏽‍✈' => 'miespilotti: tummanvaalea iho',
    '👨🏾‍✈' => 'miespilotti: keskitumma iho',
    '👨🏿‍✈' => 'miespilotti: tumma iho',
    '👩🏻‍✈' => 'naispilotti: vaalea iho',
    '👩🏼‍✈' => 'naispilotti: keskivaalea iho',
    '👩🏽‍✈' => 'naispilotti: tummanvaalea iho',
    '👩🏾‍✈' => 'naispilotti: keskitumma iho',
    '👩🏿‍✈' => 'naispilotti: tumma iho',
    '🧑🏻‍🚀' => 'astronautti: vaalea iho',
    '🧑🏼‍🚀' => 'astronautti: keskivaalea iho',
    '🧑🏽‍🚀' => 'astronautti: tummanvaalea iho',
    '🧑🏾‍🚀' => 'astronautti: keskitumma iho',
    '🧑🏿‍🚀' => 'astronautti: tumma iho',
    '👨🏻‍🚀' => 'miesastronautti: vaalea iho',
    '👨🏼‍🚀' => 'miesastronautti: keskivaalea iho',
    '👨🏽‍🚀' => 'miesastronautti: tummanvaalea iho',
    '👨🏾‍🚀' => 'miesastronautti: keskitumma iho',
    '👨🏿‍🚀' => 'miesastronautti: tumma iho',
    '👩🏻‍🚀' => 'naisastronautti: vaalea iho',
    '👩🏼‍🚀' => 'naisastronautti: keskivaalea iho',
    '👩🏽‍🚀' => 'naisastronautti: tummanvaalea iho',
    '👩🏾‍🚀' => 'naisastronautti: keskitumma iho',
    '👩🏿‍🚀' => 'naisastronautti: tumma iho',
    '🧑🏻‍🚒' => 'pelastaja: vaalea iho',
    '🧑🏼‍🚒' => 'pelastaja: keskivaalea iho',
    '🧑🏽‍🚒' => 'pelastaja: tummanvaalea iho',
    '🧑🏾‍🚒' => 'pelastaja: keskitumma iho',
    '🧑🏿‍🚒' => 'pelastaja: tumma iho',
    '👨🏻‍🚒' => 'palomies: vaalea iho',
    '👨🏼‍🚒' => 'palomies: keskivaalea iho',
    '👨🏽‍🚒' => 'palomies: tummanvaalea iho',
    '👨🏾‍🚒' => 'palomies: keskitumma iho',
    '👨🏿‍🚒' => 'palomies: tumma iho',
    '👩🏻‍🚒' => 'palonainen: vaalea iho',
    '👩🏼‍🚒' => 'palonainen: keskivaalea iho',
    '👩🏽‍🚒' => 'palonainen: tummanvaalea iho',
    '👩🏾‍🚒' => 'palonainen: keskitumma iho',
    '👩🏿‍🚒' => 'palonainen: tumma iho',
    '👮🏻‍♂' => 'miespoliisi: vaalea iho',
    '👮🏼‍♂' => 'miespoliisi: keskivaalea iho',
    '👮🏽‍♂' => 'miespoliisi: tummanvaalea iho',
    '👮🏾‍♂' => 'miespoliisi: keskitumma iho',
    '👮🏿‍♂' => 'miespoliisi: tumma iho',
    '👮🏻‍♀' => 'naispoliisi: vaalea iho',
    '👮🏼‍♀' => 'naispoliisi: keskivaalea iho',
    '👮🏽‍♀' => 'naispoliisi: tummanvaalea iho',
    '👮🏾‍♀' => 'naispoliisi: keskitumma iho',
    '👮🏿‍♀' => 'naispoliisi: tumma iho',
    '🕵🏻‍♂' => 'miesetsivä: vaalea iho',
    '🕵🏼‍♂' => 'miesetsivä: keskivaalea iho',
    '🕵🏽‍♂' => 'miesetsivä: tummanvaalea iho',
    '🕵🏾‍♂' => 'miesetsivä: keskitumma iho',
    '🕵🏿‍♂' => 'miesetsivä: tumma iho',
    '🕵🏻‍♀' => 'naisetsivä: vaalea iho',
    '🕵🏼‍♀' => 'naisetsivä: keskivaalea iho',
    '🕵🏽‍♀' => 'naisetsivä: tummanvaalea iho',
    '🕵🏾‍♀' => 'naisetsivä: keskitumma iho',
    '🕵🏿‍♀' => 'naisetsivä: tumma iho',
    '💂🏻‍♂' => 'miesvartija: vaalea iho',
    '💂🏼‍♂' => 'miesvartija: keskivaalea iho',
    '💂🏽‍♂' => 'miesvartija: tummanvaalea iho',
    '💂🏾‍♂' => 'miesvartija: keskitumma iho',
    '💂🏿‍♂' => 'miesvartija: tumma iho',
    '💂🏻‍♀' => 'naisvartija: vaalea iho',
    '💂🏼‍♀' => 'naisvartija: keskivaalea iho',
    '💂🏽‍♀' => 'naisvartija: tummanvaalea iho',
    '💂🏾‍♀' => 'naisvartija: keskitumma iho',
    '💂🏿‍♀' => 'naisvartija: tumma iho',
    '👷🏻‍♂' => 'rakennusmies: vaalea iho',
    '👷🏼‍♂' => 'rakennusmies: keskivaalea iho',
    '👷🏽‍♂' => 'rakennusmies: tummanvaalea iho',
    '👷🏾‍♂' => 'rakennusmies: keskitumma iho',
    '👷🏿‍♂' => 'rakennusmies: tumma iho',
    '👷🏻‍♀' => 'rakennusnainen: vaalea iho',
    '👷🏼‍♀' => 'rakennusnainen: keskivaalea iho',
    '👷🏽‍♀' => 'rakennusnainen: tummanvaalea iho',
    '👷🏾‍♀' => 'rakennusnainen: keskitumma iho',
    '👷🏿‍♀' => 'rakennusnainen: tumma iho',
    '👳🏻‍♂' => 'turbaanipäinen mies: vaalea iho',
    '👳🏼‍♂' => 'turbaanipäinen mies: keskivaalea iho',
    '👳🏽‍♂' => 'turbaanipäinen mies: tummanvaalea iho',
    '👳🏾‍♂' => 'turbaanipäinen mies: keskitumma iho',
    '👳🏿‍♂' => 'turbaanipäinen mies: tumma iho',
    '👳🏻‍♀' => 'turbaanipäinen nainen: vaalea iho',
    '👳🏼‍♀' => 'turbaanipäinen nainen: keskivaalea iho',
    '👳🏽‍♀' => 'turbaanipäinen nainen: tummanvaalea iho',
    '👳🏾‍♀' => 'turbaanipäinen nainen: keskitumma iho',
    '👳🏿‍♀' => 'turbaanipäinen nainen: tumma iho',
    '🤵🏻‍♂' => 'mies smokissa: vaalea iho',
    '🤵🏼‍♂' => 'mies smokissa: keskivaalea iho',
    '🤵🏽‍♂' => 'mies smokissa: tummanvaalea iho',
    '🤵🏾‍♂' => 'mies smokissa: keskitumma iho',
    '🤵🏿‍♂' => 'mies smokissa: tumma iho',
    '🤵🏻‍♀' => 'nainen smokissa: vaalea iho',
    '🤵🏼‍♀' => 'nainen smokissa: keskivaalea iho',
    '🤵🏽‍♀' => 'nainen smokissa: tummanvaalea iho',
    '🤵🏾‍♀' => 'nainen smokissa: keskitumma iho',
    '🤵🏿‍♀' => 'nainen smokissa: tumma iho',
    '👰🏻‍♂' => 'huntupäinen mies: vaalea iho',
    '👰🏼‍♂' => 'huntupäinen mies: keskivaalea iho',
    '👰🏽‍♂' => 'huntupäinen mies: tummanvaalea iho',
    '👰🏾‍♂' => 'huntupäinen mies: keskitumma iho',
    '👰🏿‍♂' => 'huntupäinen mies: tumma iho',
    '👰🏻‍♀' => 'huntupäinen nainen: vaalea iho',
    '👰🏼‍♀' => 'huntupäinen nainen: keskivaalea iho',
    '👰🏽‍♀' => 'huntupäinen nainen: tummanvaalea iho',
    '👰🏾‍♀' => 'huntupäinen nainen: keskitumma iho',
    '👰🏿‍♀' => 'huntupäinen nainen: tumma iho',
    '👩🏻‍🍼' => 'vauvaa syöttävä nainen: vaalea iho',
    '👩🏼‍🍼' => 'vauvaa syöttävä nainen: keskivaalea iho',
    '👩🏽‍🍼' => 'vauvaa syöttävä nainen: tummanvaalea iho',
    '👩🏾‍🍼' => 'vauvaa syöttävä nainen: keskitumma iho',
    '👩🏿‍🍼' => 'vauvaa syöttävä nainen: tumma iho',
    '👨🏻‍🍼' => 'vauvaa syöttävä mies: vaalea iho',
    '👨🏼‍🍼' => 'vauvaa syöttävä mies: keskivaalea iho',
    '👨🏽‍🍼' => 'vauvaa syöttävä mies: tummanvaalea iho',
    '👨🏾‍🍼' => 'vauvaa syöttävä mies: keskitumma iho',
    '👨🏿‍🍼' => 'vauvaa syöttävä mies: tumma iho',
    '🧑🏻‍🍼' => 'vauvaa syöttävä henkilö: vaalea iho',
    '🧑🏼‍🍼' => 'vauvaa syöttävä henkilö: keskivaalea iho',
    '🧑🏽‍🍼' => 'vauvaa syöttävä henkilö: tummanvaalea iho',
    '🧑🏾‍🍼' => 'vauvaa syöttävä henkilö: keskitumma iho',
    '🧑🏿‍🍼' => 'vauvaa syöttävä henkilö: tumma iho',
    '🧑🏻‍🎄' => 'tonttu: vaalea iho',
    '🧑🏼‍🎄' => 'tonttu: keskivaalea iho',
    '🧑🏽‍🎄' => 'tonttu: tummanvaalea iho',
    '🧑🏾‍🎄' => 'tonttu: keskitumma iho',
    '🧑🏿‍🎄' => 'tonttu: tumma iho',
    '🦸🏻‍♂' => 'miessupersankari: vaalea iho',
    '🦸🏼‍♂' => 'miessupersankari: keskivaalea iho',
    '🦸🏽‍♂' => 'miessupersankari: tummanvaalea iho',
    '🦸🏾‍♂' => 'miessupersankari: keskitumma iho',
    '🦸🏿‍♂' => 'miessupersankari: tumma iho',
    '🦸🏻‍♀' => 'naissupersankari: vaalea iho',
    '🦸🏼‍♀' => 'naissupersankari: keskivaalea iho',
    '🦸🏽‍♀' => 'naissupersankari: tummanvaalea iho',
    '🦸🏾‍♀' => 'naissupersankari: keskitumma iho',
    '🦸🏿‍♀' => 'naissupersankari: tumma iho',
    '🦹🏻‍♂' => 'miessuperpahis: vaalea iho',
    '🦹🏼‍♂' => 'miessuperpahis: keskivaalea iho',
    '🦹🏽‍♂' => 'miessuperpahis: tummanvaalea iho',
    '🦹🏾‍♂' => 'miessuperpahis: keskitumma iho',
    '🦹🏿‍♂' => 'miessuperpahis: tumma iho',
    '🦹🏻‍♀' => 'naissuperpahis: vaalea iho',
    '🦹🏼‍♀' => 'naissuperpahis: keskivaalea iho',
    '🦹🏽‍♀' => 'naissuperpahis: tummanvaalea iho',
    '🦹🏾‍♀' => 'naissuperpahis: keskitumma iho',
    '🦹🏿‍♀' => 'naissuperpahis: tumma iho',
    '🧙🏻‍♂' => 'miesvelho: vaalea iho',
    '🧙🏼‍♂' => 'miesvelho: keskivaalea iho',
    '🧙🏽‍♂' => 'miesvelho: tummanvaalea iho',
    '🧙🏾‍♂' => 'miesvelho: keskitumma iho',
    '🧙🏿‍♂' => 'miesvelho: tumma iho',
    '🧙🏻‍♀' => 'naisvelho: vaalea iho',
    '🧙🏼‍♀' => 'naisvelho: keskivaalea iho',
    '🧙🏽‍♀' => 'naisvelho: tummanvaalea iho',
    '🧙🏾‍♀' => 'naisvelho: keskitumma iho',
    '🧙🏿‍♀' => 'naisvelho: tumma iho',
    '🧚🏻‍♂' => 'mieskeiju: vaalea iho',
    '🧚🏼‍♂' => 'mieskeiju: keskivaalea iho',
    '🧚🏽‍♂' => 'mieskeiju: tummanvaalea iho',
    '🧚🏾‍♂' => 'mieskeiju: keskitumma iho',
    '🧚🏿‍♂' => 'mieskeiju: tumma iho',
    '🧚🏻‍♀' => 'naiskeiju: vaalea iho',
    '🧚🏼‍♀' => 'naiskeiju: keskivaalea iho',
    '🧚🏽‍♀' => 'naiskeiju: tummanvaalea iho',
    '🧚🏾‍♀' => 'naiskeiju: keskitumma iho',
    '🧚🏿‍♀' => 'naiskeiju: tumma iho',
    '🧛🏻‍♂' => 'miesvampyyri: vaalea iho',
    '🧛🏼‍♂' => 'miesvampyyri: keskivaalea iho',
    '🧛🏽‍♂' => 'miesvampyyri: tummanvaalea iho',
    '🧛🏾‍♂' => 'miesvampyyri: keskitumma iho',
    '🧛🏿‍♂' => 'miesvampyyri: tumma iho',
    '🧛🏻‍♀' => 'naisvampyyri: vaalea iho',
    '🧛🏼‍♀' => 'naisvampyyri: keskivaalea iho',
    '🧛🏽‍♀' => 'naisvampyyri: tummanvaalea iho',
    '🧛🏾‍♀' => 'naisvampyyri: keskitumma iho',
    '🧛🏿‍♀' => 'naisvampyyri: tumma iho',
    '🧜🏻‍♂' => 'merenmies: vaalea iho',
    '🧜🏼‍♂' => 'merenmies: keskivaalea iho',
    '🧜🏽‍♂' => 'merenmies: tummanvaalea iho',
    '🧜🏾‍♂' => 'merenmies: keskitumma iho',
    '🧜🏿‍♂' => 'merenmies: tumma iho',
    '🧜🏻‍♀' => 'merenneito: vaalea iho',
    '🧜🏼‍♀' => 'merenneito: keskivaalea iho',
    '🧜🏽‍♀' => 'merenneito: tummanvaalea iho',
    '🧜🏾‍♀' => 'merenneito: keskitumma iho',
    '🧜🏿‍♀' => 'merenneito: tumma iho',
    '🧝🏻‍♂' => 'mieshaltia: vaalea iho',
    '🧝🏼‍♂' => 'mieshaltia: keskivaalea iho',
    '🧝🏽‍♂' => 'mieshaltia: tummanvaalea iho',
    '🧝🏾‍♂' => 'mieshaltia: keskitumma iho',
    '🧝🏿‍♂' => 'mieshaltia: tumma iho',
    '🧝🏻‍♀' => 'haltiatar: vaalea iho',
    '🧝🏼‍♀' => 'haltiatar: keskivaalea iho',
    '🧝🏽‍♀' => 'haltiatar: tummanvaalea iho',
    '🧝🏾‍♀' => 'haltiatar: keskitumma iho',
    '🧝🏿‍♀' => 'haltiatar: tumma iho',
    '💆🏻‍♂' => 'hieronnassa oleva mies: vaalea iho',
    '💆🏼‍♂' => 'hieronnassa oleva mies: keskivaalea iho',
    '💆🏽‍♂' => 'hieronnassa oleva mies: tummanvaalea iho',
    '💆🏾‍♂' => 'hieronnassa oleva mies: keskitumma iho',
    '💆🏿‍♂' => 'hieronnassa oleva mies: tumma iho',
    '💆🏻‍♀' => 'hieronnassa oleva nainen: vaalea iho',
    '💆🏼‍♀' => 'hieronnassa oleva nainen: keskivaalea iho',
    '💆🏽‍♀' => 'hieronnassa oleva nainen: tummanvaalea iho',
    '💆🏾‍♀' => 'hieronnassa oleva nainen: keskitumma iho',
    '💆🏿‍♀' => 'hieronnassa oleva nainen: tumma iho',
    '💇🏻‍♂' => 'parturissa oleva mies: vaalea iho',
    '💇🏼‍♂' => 'parturissa oleva mies: keskivaalea iho',
    '💇🏽‍♂' => 'parturissa oleva mies: tummanvaalea iho',
    '💇🏾‍♂' => 'parturissa oleva mies: keskitumma iho',
    '💇🏿‍♂' => 'parturissa oleva mies: tumma iho',
    '💇🏻‍♀' => 'kampaajalla oleva nainen: vaalea iho',
    '💇🏼‍♀' => 'kampaajalla oleva nainen: keskivaalea iho',
    '💇🏽‍♀' => 'kampaajalla oleva nainen: tummanvaalea iho',
    '💇🏾‍♀' => 'kampaajalla oleva nainen: keskitumma iho',
    '💇🏿‍♀' => 'kampaajalla oleva nainen: tumma iho',
    '🚶🏻‍♂' => 'kävelevä mies: vaalea iho',
    '🚶🏼‍♂' => 'kävelevä mies: keskivaalea iho',
    '🚶🏽‍♂' => 'kävelevä mies: tummanvaalea iho',
    '🚶🏾‍♂' => 'kävelevä mies: keskitumma iho',
    '🚶🏿‍♂' => 'kävelevä mies: tumma iho',
    '🚶🏻‍♀' => 'kävelevä nainen: vaalea iho',
    '🚶🏼‍♀' => 'kävelevä nainen: keskivaalea iho',
    '🚶🏽‍♀' => 'kävelevä nainen: tummanvaalea iho',
    '🚶🏾‍♀' => 'kävelevä nainen: keskitumma iho',
    '🚶🏿‍♀' => 'kävelevä nainen: tumma iho',
    '🚶🏻‍➡' => 'jalankulkija: vaalea iho, kohti oikeaa',
    '🚶🏼‍➡' => 'jalankulkija: keskivaalea iho, kohti oikeaa',
    '🚶🏽‍➡' => 'jalankulkija: tummanvaalea iho, kohti oikeaa',
    '🚶🏾‍➡' => 'jalankulkija: keskitumma iho, kohti oikeaa',
    '🚶🏿‍➡' => 'jalankulkija: tumma iho, kohti oikeaa',
    '🧍🏻‍♂' => 'seisova mies: vaalea iho',
    '🧍🏼‍♂' => 'seisova mies: keskivaalea iho',
    '🧍🏽‍♂' => 'seisova mies: tummanvaalea iho',
    '🧍🏾‍♂' => 'seisova mies: keskitumma iho',
    '🧍🏿‍♂' => 'seisova mies: tumma iho',
    '🧍🏻‍♀' => 'seisova nainen: vaalea iho',
    '🧍🏼‍♀' => 'seisova nainen: keskivaalea iho',
    '🧍🏽‍♀' => 'seisova nainen: tummanvaalea iho',
    '🧍🏾‍♀' => 'seisova nainen: keskitumma iho',
    '🧍🏿‍♀' => 'seisova nainen: tumma iho',
    '🧎🏻‍♂' => 'polvistuva mies: vaalea iho',
    '🧎🏼‍♂' => 'polvistuva mies: keskivaalea iho',
    '🧎🏽‍♂' => 'polvistuva mies: tummanvaalea iho',
    '🧎🏾‍♂' => 'polvistuva mies: keskitumma iho',
    '🧎🏿‍♂' => 'polvistuva mies: tumma iho',
    '🧎🏻‍♀' => 'polvistuva nainen: vaalea iho',
    '🧎🏼‍♀' => 'polvistuva nainen: keskivaalea iho',
    '🧎🏽‍♀' => 'polvistuva nainen: tummanvaalea iho',
    '🧎🏾‍♀' => 'polvistuva nainen: keskitumma iho',
    '🧎🏿‍♀' => 'polvistuva nainen: tumma iho',
    '🧎🏻‍➡' => 'polvistuva ihminen: vaalea iho, kohti oikeaa',
    '🧎🏼‍➡' => 'polvistuva ihminen: keskivaalea iho, kohti oikeaa',
    '🧎🏽‍➡' => 'polvistuva ihminen: tummanvaalea iho, kohti oikeaa',
    '🧎🏾‍➡' => 'polvistuva ihminen: keskitumma iho, kohti oikeaa',
    '🧎🏿‍➡' => 'polvistuva ihminen: tumma iho, kohti oikeaa',
    '🧑🏻‍🦯' => 'henkilö ja valkoinen keppi: vaalea iho',
    '🧑🏼‍🦯' => 'henkilö ja valkoinen keppi: keskivaalea iho',
    '🧑🏽‍🦯' => 'henkilö ja valkoinen keppi: tummanvaalea iho',
    '🧑🏾‍🦯' => 'henkilö ja valkoinen keppi: keskitumma iho',
    '🧑🏿‍🦯' => 'henkilö ja valkoinen keppi: tumma iho',
    '👨🏻‍🦯' => 'mies ja valkoinen keppi: vaalea iho',
    '👨🏼‍🦯' => 'mies ja valkoinen keppi: keskivaalea iho',
    '👨🏽‍🦯' => 'mies ja valkoinen keppi: tummanvaalea iho',
    '👨🏾‍🦯' => 'mies ja valkoinen keppi: keskitumma iho',
    '👨🏿‍🦯' => 'mies ja valkoinen keppi: tumma iho',
    '👩🏻‍🦯' => 'nainen ja valkoinen keppi: vaalea iho',
    '👩🏼‍🦯' => 'nainen ja valkoinen keppi: keskivaalea iho',
    '👩🏽‍🦯' => 'nainen ja valkoinen keppi: tummanvaalea iho',
    '👩🏾‍🦯' => 'nainen ja valkoinen keppi: keskitumma iho',
    '👩🏿‍🦯' => 'nainen ja valkoinen keppi: tumma iho',
    '🧑🏻‍🦼' => 'henkilö moottoroidussa pyörätuolissa: vaalea iho',
    '🧑🏼‍🦼' => 'henkilö moottoroidussa pyörätuolissa: keskivaalea iho',
    '🧑🏽‍🦼' => 'henkilö moottoroidussa pyörätuolissa: tummanvaalea iho',
    '🧑🏾‍🦼' => 'henkilö moottoroidussa pyörätuolissa: keskitumma iho',
    '🧑🏿‍🦼' => 'henkilö moottoroidussa pyörätuolissa: tumma iho',
    '👨🏻‍🦼' => 'mies moottoroidussa pyörätuolissa: vaalea iho',
    '👨🏼‍🦼' => 'mies moottoroidussa pyörätuolissa: keskivaalea iho',
    '👨🏽‍🦼' => 'mies moottoroidussa pyörätuolissa: tummanvaalea iho',
    '👨🏾‍🦼' => 'mies moottoroidussa pyörätuolissa: keskitumma iho',
    '👨🏿‍🦼' => 'mies moottoroidussa pyörätuolissa: tumma iho',
    '👩🏻‍🦼' => 'nainen moottoroidussa pyörätuolissa: vaalea iho',
    '👩🏼‍🦼' => 'nainen moottoroidussa pyörätuolissa: keskivaalea iho',
    '👩🏽‍🦼' => 'nainen moottoroidussa pyörätuolissa: tummanvaalea iho',
    '👩🏾‍🦼' => 'nainen moottoroidussa pyörätuolissa: keskitumma iho',
    '👩🏿‍🦼' => 'nainen moottoroidussa pyörätuolissa: tumma iho',
    '🧑🏻‍🦽' => 'henkilö käsikäyttöisessä pyörätuolissa: vaalea iho',
    '🧑🏼‍🦽' => 'henkilö käsikäyttöisessä pyörätuolissa: keskivaalea iho',
    '🧑🏽‍🦽' => 'henkilö käsikäyttöisessä pyörätuolissa: tummanvaalea iho',
    '🧑🏾‍🦽' => 'henkilö käsikäyttöisessä pyörätuolissa: keskitumma iho',
    '🧑🏿‍🦽' => 'henkilö käsikäyttöisessä pyörätuolissa: tumma iho',
    '👨🏻‍🦽' => 'mies käsikäyttöisessä pyörätuolissa: vaalea iho',
    '👨🏼‍🦽' => 'mies käsikäyttöisessä pyörätuolissa: keskivaalea iho',
    '👨🏽‍🦽' => 'mies käsikäyttöisessä pyörätuolissa: tummanvaalea iho',
    '👨🏾‍🦽' => 'mies käsikäyttöisessä pyörätuolissa: keskitumma iho',
    '👨🏿‍🦽' => 'mies käsikäyttöisessä pyörätuolissa: tumma iho',
    '👩🏻‍🦽' => 'nainen käsikäyttöisessä pyörätuolissa: vaalea iho',
    '👩🏼‍🦽' => 'nainen käsikäyttöisessä pyörätuolissa: keskivaalea iho',
    '👩🏽‍🦽' => 'nainen käsikäyttöisessä pyörätuolissa: tummanvaalea iho',
    '👩🏾‍🦽' => 'nainen käsikäyttöisessä pyörätuolissa: keskitumma iho',
    '👩🏿‍🦽' => 'nainen käsikäyttöisessä pyörätuolissa: tumma iho',
    '🏃🏻‍♂' => 'juokseva mies: vaalea iho',
    '🏃🏼‍♂' => 'juokseva mies: keskivaalea iho',
    '🏃🏽‍♂' => 'juokseva mies: tummanvaalea iho',
    '🏃🏾‍♂' => 'juokseva mies: keskitumma iho',
    '🏃🏿‍♂' => 'juokseva mies: tumma iho',
    '🏃🏻‍♀' => 'juokseva nainen: vaalea iho',
    '🏃🏼‍♀' => 'juokseva nainen: keskivaalea iho',
    '🏃🏽‍♀' => 'juokseva nainen: tummanvaalea iho',
    '🏃🏾‍♀' => 'juokseva nainen: keskitumma iho',
    '🏃🏿‍♀' => 'juokseva nainen: tumma iho',
    '🏃🏻‍➡' => 'juoksija: vaalea iho, kohti oikeaa',
    '🏃🏼‍➡' => 'juoksija: keskivaalea iho, kohti oikeaa',
    '🏃🏽‍➡' => 'juoksija: tummanvaalea iho, kohti oikeaa',
    '🏃🏾‍➡' => 'juoksija: keskitumma iho, kohti oikeaa',
    '🏃🏿‍➡' => 'juoksija: tumma iho, kohti oikeaa',
    '👯🏻‍♀' => 'tanssivat puputytöt: vaalea iho',
    '👯🏼‍♀' => 'tanssivat puputytöt: keskivaalea iho',
    '👯🏽‍♀' => 'tanssivat puputytöt: tummanvaalea iho',
    '👯🏾‍♀' => 'tanssivat puputytöt: keskitumma iho',
    '👯🏿‍♀' => 'tanssivat puputytöt: tumma iho',
    '👯🏻‍♂' => 'tanssivat pupupojat: vaalea iho',
    '👯🏼‍♂' => 'tanssivat pupupojat: keskivaalea iho',
    '👯🏽‍♂' => 'tanssivat pupupojat: tummanvaalea iho',
    '👯🏾‍♂' => 'tanssivat pupupojat: keskitumma iho',
    '👯🏿‍♂' => 'tanssivat pupupojat: tumma iho',
    '🧖🏻‍♂' => 'mies saunassa: vaalea iho',
    '🧖🏼‍♂' => 'mies saunassa: keskivaalea iho',
    '🧖🏽‍♂' => 'mies saunassa: tummanvaalea iho',
    '🧖🏾‍♂' => 'mies saunassa: keskitumma iho',
    '🧖🏿‍♂' => 'mies saunassa: tumma iho',
    '🧖🏻‍♀' => 'nainen saunassa: vaalea iho',
    '🧖🏼‍♀' => 'nainen saunassa: keskivaalea iho',
    '🧖🏽‍♀' => 'nainen saunassa: tummanvaalea iho',
    '🧖🏾‍♀' => 'nainen saunassa: keskitumma iho',
    '🧖🏿‍♀' => 'nainen saunassa: tumma iho',
    '🧗🏻‍♂' => 'mieskiipeilijä: vaalea iho',
    '🧗🏼‍♂' => 'mieskiipeilijä: keskivaalea iho',
    '🧗🏽‍♂' => 'mieskiipeilijä: tummanvaalea iho',
    '🧗🏾‍♂' => 'mieskiipeilijä: keskitumma iho',
    '🧗🏿‍♂' => 'mieskiipeilijä: tumma iho',
    '🧗🏻‍♀' => 'naiskiipeilijä: vaalea iho',
    '🧗🏼‍♀' => 'naiskiipeilijä: keskivaalea iho',
    '🧗🏽‍♀' => 'naiskiipeilijä: tummanvaalea iho',
    '🧗🏾‍♀' => 'naiskiipeilijä: keskitumma iho',
    '🧗🏿‍♀' => 'naiskiipeilijä: tumma iho',
    '🏌🏻‍♂' => 'golfaajamies: vaalea iho',
    '🏌🏼‍♂' => 'golfaajamies: keskivaalea iho',
    '🏌🏽‍♂' => 'golfaajamies: tummanvaalea iho',
    '🏌🏾‍♂' => 'golfaajamies: keskitumma iho',
    '🏌🏿‍♂' => 'golfaajamies: tumma iho',
    '🏌🏻‍♀' => 'golfaajanainen: vaalea iho',
    '🏌🏼‍♀' => 'golfaajanainen: keskivaalea iho',
    '🏌🏽‍♀' => 'golfaajanainen: tummanvaalea iho',
    '🏌🏾‍♀' => 'golfaajanainen: keskitumma iho',
    '🏌🏿‍♀' => 'golfaajanainen: tumma iho',
    '🏄🏻‍♂' => 'surffaajamies: vaalea iho',
    '🏄🏼‍♂' => 'surffaajamies: keskivaalea iho',
    '🏄🏽‍♂' => 'surffaajamies: tummanvaalea iho',
    '🏄🏾‍♂' => 'surffaajamies: keskitumma iho',
    '🏄🏿‍♂' => 'surffaajamies: tumma iho',
    '🏄🏻‍♀' => 'surffaajanainen: vaalea iho',
    '🏄🏼‍♀' => 'surffaajanainen: keskivaalea iho',
    '🏄🏽‍♀' => 'surffaajanainen: tummanvaalea iho',
    '🏄🏾‍♀' => 'surffaajanainen: keskitumma iho',
    '🏄🏿‍♀' => 'surffaajanainen: tumma iho',
    '🚣🏻‍♂' => 'soutava mies: vaalea iho',
    '🚣🏼‍♂' => 'soutava mies: keskivaalea iho',
    '🚣🏽‍♂' => 'soutava mies: tummanvaalea iho',
    '🚣🏾‍♂' => 'soutava mies: keskitumma iho',
    '🚣🏿‍♂' => 'soutava mies: tumma iho',
    '🚣🏻‍♀' => 'soutava nainen: vaalea iho',
    '🚣🏼‍♀' => 'soutava nainen: keskivaalea iho',
    '🚣🏽‍♀' => 'soutava nainen: tummanvaalea iho',
    '🚣🏾‍♀' => 'soutava nainen: keskitumma iho',
    '🚣🏿‍♀' => 'soutava nainen: tumma iho',
    '🏊🏻‍♂' => 'uiva mies: vaalea iho',
    '🏊🏼‍♂' => 'uiva mies: keskivaalea iho',
    '🏊🏽‍♂' => 'uiva mies: tummanvaalea iho',
    '🏊🏾‍♂' => 'uiva mies: keskitumma iho',
    '🏊🏿‍♂' => 'uiva mies: tumma iho',
    '🏊🏻‍♀' => 'uiva nainen: vaalea iho',
    '🏊🏼‍♀' => 'uiva nainen: keskivaalea iho',
    '🏊🏽‍♀' => 'uiva nainen: tummanvaalea iho',
    '🏊🏾‍♀' => 'uiva nainen: keskitumma iho',
    '🏊🏿‍♀' => 'uiva nainen: tumma iho',
    '⛹🏻‍♂' => 'pallotteleva mies: vaalea iho',
    '⛹🏼‍♂' => 'pallotteleva mies: keskivaalea iho',
    '⛹🏽‍♂' => 'pallotteleva mies: tummanvaalea iho',
    '⛹🏾‍♂' => 'pallotteleva mies: keskitumma iho',
    '⛹🏿‍♂' => 'pallotteleva mies: tumma iho',
    '⛹🏻‍♀' => 'pallotteleva nainen: vaalea iho',
    '⛹🏼‍♀' => 'pallotteleva nainen: keskivaalea iho',
    '⛹🏽‍♀' => 'pallotteleva nainen: tummanvaalea iho',
    '⛹🏾‍♀' => 'pallotteleva nainen: keskitumma iho',
    '⛹🏿‍♀' => 'pallotteleva nainen: tumma iho',
    '🏋🏻‍♂' => 'painonnostajamies: vaalea iho',
    '🏋🏼‍♂' => 'painonnostajamies: keskivaalea iho',
    '🏋🏽‍♂' => 'painonnostajamies: tummanvaalea iho',
    '🏋🏾‍♂' => 'painonnostajamies: keskitumma iho',
    '🏋🏿‍♂' => 'painonnostajamies: tumma iho',
    '🏋🏻‍♀' => 'painonnostajanainen: vaalea iho',
    '🏋🏼‍♀' => 'painonnostajanainen: keskivaalea iho',
    '🏋🏽‍♀' => 'painonnostajanainen: tummanvaalea iho',
    '🏋🏾‍♀' => 'painonnostajanainen: keskitumma iho',
    '🏋🏿‍♀' => 'painonnostajanainen: tumma iho',
    '🚴🏻‍♂' => 'pyöräilevä mies: vaalea iho',
    '🚴🏼‍♂' => 'pyöräilevä mies: keskivaalea iho',
    '🚴🏽‍♂' => 'pyöräilevä mies: tummanvaalea iho',
    '🚴🏾‍♂' => 'pyöräilevä mies: keskitumma iho',
    '🚴🏿‍♂' => 'pyöräilevä mies: tumma iho',
    '🚴🏻‍♀' => 'pyöräileva nainen: vaalea iho',
    '🚴🏼‍♀' => 'pyöräileva nainen: keskivaalea iho',
    '🚴🏽‍♀' => 'pyöräileva nainen: tummanvaalea iho',
    '🚴🏾‍♀' => 'pyöräileva nainen: keskitumma iho',
    '🚴🏿‍♀' => 'pyöräileva nainen: tumma iho',
    '🚵🏻‍♂' => 'maastopyöräilevä mies: vaalea iho',
    '🚵🏼‍♂' => 'maastopyöräilevä mies: keskivaalea iho',
    '🚵🏽‍♂' => 'maastopyöräilevä mies: tummanvaalea iho',
    '🚵🏾‍♂' => 'maastopyöräilevä mies: keskitumma iho',
    '🚵🏿‍♂' => 'maastopyöräilevä mies: tumma iho',
    '🚵🏻‍♀' => 'maastopyöräilevä nainen: vaalea iho',
    '🚵🏼‍♀' => 'maastopyöräilevä nainen: keskivaalea iho',
    '🚵🏽‍♀' => 'maastopyöräilevä nainen: tummanvaalea iho',
    '🚵🏾‍♀' => 'maastopyöräilevä nainen: keskitumma iho',
    '🚵🏿‍♀' => 'maastopyöräilevä nainen: tumma iho',
    '🤸🏻‍♂' => 'kärrynpyörää tekevä mies: vaalea iho',
    '🤸🏼‍♂' => 'kärrynpyörää tekevä mies: keskivaalea iho',
    '🤸🏽‍♂' => 'kärrynpyörää tekevä mies: tummanvaalea iho',
    '🤸🏾‍♂' => 'kärrynpyörää tekevä mies: keskitumma iho',
    '🤸🏿‍♂' => 'kärrynpyörää tekevä mies: tumma iho',
    '🤸🏻‍♀' => 'kärrynpyörää tekevä nainen: vaalea iho',
    '🤸🏼‍♀' => 'kärrynpyörää tekevä nainen: keskivaalea iho',
    '🤸🏽‍♀' => 'kärrynpyörää tekevä nainen: tummanvaalea iho',
    '🤸🏾‍♀' => 'kärrynpyörää tekevä nainen: keskitumma iho',
    '🤸🏿‍♀' => 'kärrynpyörää tekevä nainen: tumma iho',
    '🤼🏻‍♀' => 'painivat naiset: vaalea iho',
    '🤼🏼‍♀' => 'painivat naiset: keskivaalea iho',
    '🤼🏽‍♀' => 'painivat naiset: tummanvaalea iho',
    '🤼🏾‍♀' => 'painivat naiset: keskitumma iho',
    '🤼🏿‍♀' => 'painivat naiset: tumma iho',
    '🤼🏻‍♂' => 'painivat miehet: vaalea iho',
    '🤼🏼‍♂' => 'painivat miehet: keskivaalea iho',
    '🤼🏽‍♂' => 'painivat miehet: tummanvaalea iho',
    '🤼🏾‍♂' => 'painivat miehet: keskitumma iho',
    '🤼🏿‍♂' => 'painivat miehet: tumma iho',
    '🤽🏻‍♂' => 'vesipalloa pelaava mies: vaalea iho',
    '🤽🏼‍♂' => 'vesipalloa pelaava mies: keskivaalea iho',
    '🤽🏽‍♂' => 'vesipalloa pelaava mies: tummanvaalea iho',
    '🤽🏾‍♂' => 'vesipalloa pelaava mies: keskitumma iho',
    '🤽🏿‍♂' => 'vesipalloa pelaava mies: tumma iho',
    '🤽🏻‍♀' => 'vesipalloa pelaava nainen: vaalea iho',
    '🤽🏼‍♀' => 'vesipalloa pelaava nainen: keskivaalea iho',
    '🤽🏽‍♀' => 'vesipalloa pelaava nainen: tummanvaalea iho',
    '🤽🏾‍♀' => 'vesipalloa pelaava nainen: keskitumma iho',
    '🤽🏿‍♀' => 'vesipalloa pelaava nainen: tumma iho',
    '🤾🏻‍♂' => 'käsipalloa pelaava mies: vaalea iho',
    '🤾🏼‍♂' => 'käsipalloa pelaava mies: keskivaalea iho',
    '🤾🏽‍♂' => 'käsipalloa pelaava mies: tummanvaalea iho',
    '🤾🏾‍♂' => 'käsipalloa pelaava mies: keskitumma iho',
    '🤾🏿‍♂' => 'käsipalloa pelaava mies: tumma iho',
    '🤾🏻‍♀' => 'käsipalloa pelaava nainen: vaalea iho',
    '🤾🏼‍♀' => 'käsipalloa pelaava nainen: keskivaalea iho',
    '🤾🏽‍♀' => 'käsipalloa pelaava nainen: tummanvaalea iho',
    '🤾🏾‍♀' => 'käsipalloa pelaava nainen: keskitumma iho',
    '🤾🏿‍♀' => 'käsipalloa pelaava nainen: tumma iho',
    '🤹🏻‍♂' => 'jongleeraava mies: vaalea iho',
    '🤹🏼‍♂' => 'jongleeraava mies: keskivaalea iho',
    '🤹🏽‍♂' => 'jongleeraava mies: tummanvaalea iho',
    '🤹🏾‍♂' => 'jongleeraava mies: keskitumma iho',
    '🤹🏿‍♂' => 'jongleeraava mies: tumma iho',
    '🤹🏻‍♀' => 'jongleeraava nainen: vaalea iho',
    '🤹🏼‍♀' => 'jongleeraava nainen: keskivaalea iho',
    '🤹🏽‍♀' => 'jongleeraava nainen: tummanvaalea iho',
    '🤹🏾‍♀' => 'jongleeraava nainen: keskitumma iho',
    '🤹🏿‍♀' => 'jongleeraava nainen: tumma iho',
    '🧘🏻‍♂' => 'mies lootusasennossa: vaalea iho',
    '🧘🏼‍♂' => 'mies lootusasennossa: keskivaalea iho',
    '🧘🏽‍♂' => 'mies lootusasennossa: tummanvaalea iho',
    '🧘🏾‍♂' => 'mies lootusasennossa: keskitumma iho',
    '🧘🏿‍♂' => 'mies lootusasennossa: tumma iho',
    '🧘🏻‍♀' => 'nainen lootusasennossa: vaalea iho',
    '🧘🏼‍♀' => 'nainen lootusasennossa: keskivaalea iho',
    '🧘🏽‍♀' => 'nainen lootusasennossa: tummanvaalea iho',
    '🧘🏾‍♀' => 'nainen lootusasennossa: keskitumma iho',
    '🧘🏿‍♀' => 'nainen lootusasennossa: tumma iho',
    '🧑‍🦰' => 'aikuinen: punatukkainen',
    '🧑‍🦱' => 'aikuinen: kiharatukkainen',
    '🧑‍🦳' => 'aikuinen: valkotukkainen',
    '🧑‍🦲' => 'aikuinen: kalju',
    '👨‍🦰' => 'mies: punatukkainen',
    '👨‍🦱' => 'mies: kiharatukkainen',
    '👨‍🦳' => 'mies: valkotukkainen',
    '👨‍🦲' => 'mies: kalju',
    '👩‍🦰' => 'nainen: punatukkainen',
    '👩‍🦱' => 'nainen: kiharatukkainen',
    '👩‍🦳' => 'nainen: valkotukkainen',
    '👩‍🦲' => 'nainen: kalju',
    '🚶‍➡' => 'jalankulkija: kohti oikeaa',
    '🧎‍➡' => 'polvistuva ihminen: kohti oikeaa',
    '🏃‍➡' => 'juoksija: kohti oikeaa',
    '👨‍👦' => 'perhe: mies, poika',
    '👨‍👧' => 'perhe: mies, tyttö',
    '👩‍👦' => 'perhe: nainen, poika',
    '👩‍👧' => 'perhe: nainen, tyttö',
    '😶‍🌫' => 'naama pilvissä',
    '😮‍💨' => 'hämmästynyt',
    '🙂‍↕' => 'ravistaa päätä pystysuunnassa',
    '😵‍💫' => 'naama jolla spiraalisilmät',
    '❤‍🔥' => 'palava sydän',
    '❤‍🩹' => 'parantuva sydän',
    '👁‍🗨' => 'puhekuplasilmä',
    '🧔‍♂' => 'parrakas mies',
    '👱‍♂' => 'vaaleatukkainen mies',
    '🧔‍♀' => 'parrakas nainen',
    '👱‍♀' => 'vaaleatukkainen nainen',
    '🙍‍♂' => 'surullinen mies',
    '🙍‍♀' => 'surullinen nainen',
    '🙎‍♂' => 'mököttävä mies',
    '🙎‍♀' => 'mököttävä nainen',
    '🙅‍♂' => 'ei käy -merkkiä näyttävä mies',
    '🙅‍♀' => 'ei käy -merkkiä näyttävä nainen',
    '🙆‍♂' => 'ok-merkkiä näyttävä mies',
    '🙆‍♀' => 'ok-merkkiä näyttävä nainen',
    '💁‍♂' => 'kämmentä ylöspäin näyttävä mies',
    '💁‍♀' => 'kämmentä ylöspäin näyttävä nainen',
    '🙋‍♂' => 'viittaava mies',
    '🙋‍♀' => 'viittaava nainen',
    '🧏‍♂' => 'kuuro mies',
    '🧏‍♀' => 'kuuro nainen',
    '🙇‍♂' => 'syvään kumartava mies',
    '🙇‍♀' => 'syvään kumartava nainen',
    '🤦‍♂' => 'kasvonsa kädellä peittävä mies',
    '🤦‍♀' => 'kasvonsa kädellä peittävä nainen',
    '🤷‍♂' => 'olkapäitään kohauttava mies',
    '🤷‍♀' => 'olkapäitään kohauttava nainen',
    '🧑‍⚕' => 'hoitotyöntekijä',
    '👨‍⚕' => 'mieshoitotyöntekijä',
    '👩‍⚕' => 'naishoitotyöntekijä',
    '🧑‍🎓' => 'opiskelija',
    '👨‍🎓' => 'miesopiskelija',
    '👩‍🎓' => 'naisopiskelija',
    '🧑‍🏫' => 'opettaja',
    '👨‍🏫' => 'miesopettaja',
    '👩‍🏫' => 'naisopettaja',
    '🧑‍⚖' => 'tuomari',
    '👨‍⚖' => 'miestuomari',
    '👩‍⚖' => 'naistuomari',
    '🧑‍🌾' => 'maanviljelijä',
    '👨‍🌾' => 'miesmaanviljelijä',
    '👩‍🌾' => 'naismaanviljelijä',
    '🧑‍🍳' => 'kokki',
    '👨‍🍳' => 'mieskokki',
    '👩‍🍳' => 'naiskokki',
    '🧑‍🔧' => 'mekaanikko',
    '👨‍🔧' => 'miesmekaanikko',
    '👩‍🔧' => 'naismekaanikko',
    '🧑‍🏭' => 'tehdastyöntekijä',
    '👨‍🏭' => 'miestehdastyöntekijä',
    '👩‍🏭' => 'naistehdastyöntekijä',
    '🧑‍💼' => 'toimistotyöntekijä',
    '👨‍💼' => 'miestoimistotyöntekijä',
    '👩‍💼' => 'naistoimistotyöntekijä',
    '🧑‍🔬' => 'tutkija',
    '👨‍🔬' => 'miestutkija',
    '👩‍🔬' => 'naistutkija',
    '🧑‍💻' => 'IT-työntekijä',
    '👨‍💻' => 'IT-mies',
    '👩‍💻' => 'IT-nainen',
    '🧑‍🎤' => 'laulaja',
    '👨‍🎤' => 'mieslaulaja',
    '👩‍🎤' => 'naislaulaja',
    '🧑‍🎨' => 'artisti',
    '👨‍🎨' => 'miestaiteilija',
    '👩‍🎨' => 'naistaiteilija',
    '🧑‍✈' => 'pilotti',
    '👨‍✈' => 'miespilotti',
    '👩‍✈' => 'naispilotti',
    '🧑‍🚀' => 'astronautti',
    '👨‍🚀' => 'miesastronautti',
    '👩‍🚀' => 'naisastronautti',
    '🧑‍🚒' => 'pelastaja',
    '👨‍🚒' => 'palomies',
    '👩‍🚒' => 'palonainen',
    '👮‍♂' => 'miespoliisi',
    '👮‍♀' => 'naispoliisi',
    '🕵‍♂' => 'miesetsivä',
    '🕵‍♀' => 'naisetsivä',
    '💂‍♂' => 'miesvartija',
    '💂‍♀' => 'naisvartija',
    '👷‍♂' => 'rakennusmies',
    '👷‍♀' => 'rakennusnainen',
    '👳‍♂' => 'turbaanipäinen mies',
    '👳‍♀' => 'turbaanipäinen nainen',
    '🤵‍♂' => 'mies smokissa',
    '🤵‍♀' => 'nainen smokissa',
    '👰‍♂' => 'huntupäinen mies',
    '👰‍♀' => 'huntupäinen nainen',
    '👩‍🍼' => 'vauvaa syöttävä nainen',
    '👨‍🍼' => 'vauvaa syöttävä mies',
    '🧑‍🍼' => 'vauvaa syöttävä henkilö',
    '🧑‍🎄' => 'tonttu',
    '🦸‍♂' => 'miessupersankari',
    '🦸‍♀' => 'naissupersankari',
    '🦹‍♂' => 'miessuperpahis',
    '🦹‍♀' => 'naissuperpahis',
    '🧙‍♂' => 'miesvelho',
    '🧙‍♀' => 'naisvelho',
    '🧚‍♂' => 'mieskeiju',
    '🧚‍♀' => 'naiskeiju',
    '🧛‍♂' => 'miesvampyyri',
    '🧛‍♀' => 'naisvampyyri',
    '🧜‍♂' => 'merenmies',
    '🧜‍♀' => 'merenneito',
    '🧝‍♂' => 'mieshaltia',
    '🧝‍♀' => 'haltiatar',
    '🧞‍♂' => 'mieshenki',
    '🧞‍♀' => 'naishenki',
    '🧟‍♂' => 'mieszombi',
    '🧟‍♀' => 'naiszombi',
    '💆‍♂' => 'hieronnassa oleva mies',
    '💆‍♀' => 'hieronnassa oleva nainen',
    '💇‍♂' => 'parturissa oleva mies',
    '💇‍♀' => 'kampaajalla oleva nainen',
    '🚶‍♂' => 'kävelevä mies',
    '🚶‍♀' => 'kävelevä nainen',
    '🧍‍♂' => 'seisova mies',
    '🧍‍♀' => 'seisova nainen',
    '🧎‍♂' => 'polvistuva mies',
    '🧎‍♀' => 'polvistuva nainen',
    '🧑‍🦯' => 'henkilö ja valkoinen keppi',
    '👨‍🦯' => 'mies ja valkoinen keppi',
    '👩‍🦯' => 'nainen ja valkoinen keppi',
    '🧑‍🦼' => 'henkilö moottoroidussa pyörätuolissa',
    '👨‍🦼' => 'mies moottoroidussa pyörätuolissa',
    '👩‍🦼' => 'nainen moottoroidussa pyörätuolissa',
    '🧑‍🦽' => 'henkilö käsikäyttöisessä pyörätuolissa',
    '👨‍🦽' => 'mies käsikäyttöisessä pyörätuolissa',
    '👩‍🦽' => 'nainen käsikäyttöisessä pyörätuolissa',
    '🏃‍♂' => 'juokseva mies',
    '🏃‍♀' => 'juokseva nainen',
    '🧑‍🩰' => 'balettitanssija',
    '👯‍♂' => 'tanssivat pupupojat',
    '👯‍♀' => 'tanssivat puputytöt',
    '🧖‍♂' => 'mies saunassa',
    '🧖‍♀' => 'nainen saunassa',
    '🧗‍♂' => 'mieskiipeilijä',
    '🧗‍♀' => 'naiskiipeilijä',
    '🏌‍♂' => 'golfaajamies',
    '🏌‍♀' => 'golfaajanainen',
    '🏄‍♂' => 'surffaajamies',
    '🏄‍♀' => 'surffaajanainen',
    '🚣‍♂' => 'soutava mies',
    '🚣‍♀' => 'soutava nainen',
    '🏊‍♂' => 'uiva mies',
    '🏊‍♀' => 'uiva nainen',
    '⛹‍♂' => 'pallotteleva mies',
    '⛹‍♀' => 'pallotteleva nainen',
    '🏋‍♂' => 'painonnostajamies',
    '🏋‍♀' => 'painonnostajanainen',
    '🚴‍♂' => 'pyöräilevä mies',
    '🚴‍♀' => 'pyöräileva nainen',
    '🚵‍♂' => 'maastopyöräilevä mies',
    '🚵‍♀' => 'maastopyöräilevä nainen',
    '🤸‍♂' => 'kärrynpyörää tekevä mies',
    '🤸‍♀' => 'kärrynpyörää tekevä nainen',
    '🤼‍♂' => 'painivat miehet',
    '🤼‍♀' => 'painivat naiset',
    '🤽‍♂' => 'vesipalloa pelaava mies',
    '🤽‍♀' => 'vesipalloa pelaava nainen',
    '🤾‍♂' => 'käsipalloa pelaava mies',
    '🤾‍♀' => 'käsipalloa pelaava nainen',
    '🤹‍♂' => 'jongleeraava mies',
    '🤹‍♀' => 'jongleeraava nainen',
    '🧘‍♂' => 'mies lootusasennossa',
    '🧘‍♀' => 'nainen lootusasennossa',
    '🧑‍🧒' => 'perhe: aikuinen, lapsi',
    '🐕‍🦺' => 'palveluskoira',
    '🐈‍⬛' => 'musta kissa',
    '🐻‍❄' => 'jääkarhu',
    '🐦‍⬛' => 'mustarastas',
    '🐦‍🔥' => 'feeniks',
    '🍋‍🟩' => 'limetti',
    '🍄‍🟫' => 'ruskea herkkusieni',
    '⛓‍💥' => 'katkennut ketju',
    '🏳‍🌈' => 'sateenkaarilippu',
    '🏳‍⚧' => 'translippu',
    '🏴‍☠' => 'merirosvolippu',
    '👋🏻' => 'käden heilautus: vaalea iho',
    '👋🏼' => 'käden heilautus: keskivaalea iho',
    '👋🏽' => 'käden heilautus: tummanvaalea iho',
    '👋🏾' => 'käden heilautus: keskitumma iho',
    '👋🏿' => 'käden heilautus: tumma iho',
    '🤚🏻' => 'kämmenselkä koholla: vaalea iho',
    '🤚🏼' => 'kämmenselkä koholla: keskivaalea iho',
    '🤚🏽' => 'kämmenselkä koholla: tummanvaalea iho',
    '🤚🏾' => 'kämmenselkä koholla: keskitumma iho',
    '🤚🏿' => 'kämmenselkä koholla: tumma iho',
    '🖐🏻' => 'nostettu käsi ja sormet erillään: vaalea iho',
    '🖐🏼' => 'nostettu käsi ja sormet erillään: keskivaalea iho',
    '🖐🏽' => 'nostettu käsi ja sormet erillään: tummanvaalea iho',
    '🖐🏾' => 'nostettu käsi ja sormet erillään: keskitumma iho',
    '🖐🏿' => 'nostettu käsi ja sormet erillään: tumma iho',
    '✋🏻' => 'nostettu käsi: vaalea iho',
    '✋🏼' => 'nostettu käsi: keskivaalea iho',
    '✋🏽' => 'nostettu käsi: tummanvaalea iho',
    '✋🏾' => 'nostettu käsi: keskitumma iho',
    '✋🏿' => 'nostettu käsi: tumma iho',
    '🖖🏻' => 'vulkanilaisten tervehdys: vaalea iho',
    '🖖🏼' => 'vulkanilaisten tervehdys: keskivaalea iho',
    '🖖🏽' => 'vulkanilaisten tervehdys: tummanvaalea iho',
    '🖖🏾' => 'vulkanilaisten tervehdys: keskitumma iho',
    '🖖🏿' => 'vulkanilaisten tervehdys: tumma iho',
    '🫱🏻' => 'oikealle ojentuva käsi: vaalea iho',
    '🫱🏼' => 'oikealle ojentuva käsi: keskivaalea iho',
    '🫱🏽' => 'oikealle ojentuva käsi: tummanvaalea iho',
    '🫱🏾' => 'oikealle ojentuva käsi: keskitumma iho',
    '🫱🏿' => 'oikealle ojentuva käsi: tumma iho',
    '🫲🏻' => 'vasemmalle ojentuva käsi: vaalea iho',
    '🫲🏼' => 'vasemmalle ojentuva käsi: keskivaalea iho',
    '🫲🏽' => 'vasemmalle ojentuva käsi: tummanvaalea iho',
    '🫲🏾' => 'vasemmalle ojentuva käsi: keskitumma iho',
    '🫲🏿' => 'vasemmalle ojentuva käsi: tumma iho',
    '🫳🏻' => 'käsi kämmen alaspäin: vaalea iho',
    '🫳🏼' => 'käsi kämmen alaspäin: keskivaalea iho',
    '🫳🏽' => 'käsi kämmen alaspäin: tummanvaalea iho',
    '🫳🏾' => 'käsi kämmen alaspäin: keskitumma iho',
    '🫳🏿' => 'käsi kämmen alaspäin: tumma iho',
    '🫴🏻' => 'käsi kämmen ylöspäin: vaalea iho',
    '🫴🏼' => 'käsi kämmen ylöspäin: keskivaalea iho',
    '🫴🏽' => 'käsi kämmen ylöspäin: tummanvaalea iho',
    '🫴🏾' => 'käsi kämmen ylöspäin: keskitumma iho',
    '🫴🏿' => 'käsi kämmen ylöspäin: tumma iho',
    '🫷🏻' => 'vasemmalle työntävä käsi: vaalea iho',
    '🫷🏼' => 'vasemmalle työntävä käsi: keskivaalea iho',
    '🫷🏽' => 'vasemmalle työntävä käsi: tummanvaalea iho',
    '🫷🏾' => 'vasemmalle työntävä käsi: keskitumma iho',
    '🫷🏿' => 'vasemmalle työntävä käsi: tumma iho',
    '🫸🏻' => 'oikealle työntävä käsi: vaalea iho',
    '🫸🏼' => 'oikealle työntävä käsi: keskivaalea iho',
    '🫸🏽' => 'oikealle työntävä käsi: tummanvaalea iho',
    '🫸🏾' => 'oikealle työntävä käsi: keskitumma iho',
    '🫸🏿' => 'oikealle työntävä käsi: tumma iho',
    '👌🏻' => 'ok-sormiele: vaalea iho',
    '👌🏼' => 'ok-sormiele: keskivaalea iho',
    '👌🏽' => 'ok-sormiele: tummanvaalea iho',
    '👌🏾' => 'ok-sormiele: keskitumma iho',
    '👌🏿' => 'ok-sormiele: tumma iho',
    '🤌🏻' => 'sormet supussa: vaalea iho',
    '🤌🏼' => 'sormet supussa: keskivaalea iho',
    '🤌🏽' => 'sormet supussa: tummanvaalea iho',
    '🤌🏾' => 'sormet supussa: keskitumma iho',
    '🤌🏿' => 'sormet supussa: tumma iho',
    '🤏🏻' => 'nipistävä käsi: vaalea iho',
    '🤏🏼' => 'nipistävä käsi: keskivaalea iho',
    '🤏🏽' => 'nipistävä käsi: tummanvaalea iho',
    '🤏🏾' => 'nipistävä käsi: keskitumma iho',
    '🤏🏿' => 'nipistävä käsi: tumma iho',
    '✌🏻' => 'voitonmerkki: vaalea iho',
    '✌🏼' => 'voitonmerkki: keskivaalea iho',
    '✌🏽' => 'voitonmerkki: tummanvaalea iho',
    '✌🏾' => 'voitonmerkki: keskitumma iho',
    '✌🏿' => 'voitonmerkki: tumma iho',
    '🤞🏻' => 'sormet ristissä: vaalea iho',
    '🤞🏼' => 'sormet ristissä: keskivaalea iho',
    '🤞🏽' => 'sormet ristissä: tummanvaalea iho',
    '🤞🏾' => 'sormet ristissä: keskitumma iho',
    '🤞🏿' => 'sormet ristissä: tumma iho',
    '🫰🏻' => 'etusormi ja peukalo ristissä: vaalea iho',
    '🫰🏼' => 'etusormi ja peukalo ristissä: keskivaalea iho',
    '🫰🏽' => 'etusormi ja peukalo ristissä: tummanvaalea iho',
    '🫰🏾' => 'etusormi ja peukalo ristissä: keskitumma iho',
    '🫰🏿' => 'etusormi ja peukalo ristissä: tumma iho',
    '🤟🏻' => 'rakastan sinua -ele: vaalea iho',
    '🤟🏼' => 'rakastan sinua -ele: keskivaalea iho',
    '🤟🏽' => 'rakastan sinua -ele: tummanvaalea iho',
    '🤟🏾' => 'rakastan sinua -ele: keskitumma iho',
    '🤟🏿' => 'rakastan sinua -ele: tumma iho',
    '🤘🏻' => 'sarviele: vaalea iho',
    '🤘🏼' => 'sarviele: keskivaalea iho',
    '🤘🏽' => 'sarviele: tummanvaalea iho',
    '🤘🏾' => 'sarviele: keskitumma iho',
    '🤘🏿' => 'sarviele: tumma iho',
    '🤙🏻' => 'soita minulle: vaalea iho',
    '🤙🏼' => 'soita minulle: keskivaalea iho',
    '🤙🏽' => 'soita minulle: tummanvaalea iho',
    '🤙🏾' => 'soita minulle: keskitumma iho',
    '🤙🏿' => 'soita minulle: tumma iho',
    '👈🏻' => 'kämmenselkä ja etusormi vasemmalle: vaalea iho',
    '👈🏼' => 'kämmenselkä ja etusormi vasemmalle: keskivaalea iho',
    '👈🏽' => 'kämmenselkä ja etusormi vasemmalle: tummanvaalea iho',
    '👈🏾' => 'kämmenselkä ja etusormi vasemmalle: keskitumma iho',
    '👈🏿' => 'kämmenselkä ja etusormi vasemmalle: tumma iho',
    '👉🏻' => 'kämmenselkä ja etusormi oikealle: vaalea iho',
    '👉🏼' => 'kämmenselkä ja etusormi oikealle: keskivaalea iho',
    '👉🏽' => 'kämmenselkä ja etusormi oikealle: tummanvaalea iho',
    '👉🏾' => 'kämmenselkä ja etusormi oikealle: keskitumma iho',
    '👉🏿' => 'kämmenselkä ja etusormi oikealle: tumma iho',
    '👆🏻' => 'kämmenselkä ja etusormi ylös: vaalea iho',
    '👆🏼' => 'kämmenselkä ja etusormi ylös: keskivaalea iho',
    '👆🏽' => 'kämmenselkä ja etusormi ylös: tummanvaalea iho',
    '👆🏾' => 'kämmenselkä ja etusormi ylös: keskitumma iho',
    '👆🏿' => 'kämmenselkä ja etusormi ylös: tumma iho',
    '🖕🏻' => 'keskisormi: vaalea iho',
    '🖕🏼' => 'keskisormi: keskivaalea iho',
    '🖕🏽' => 'keskisormi: tummanvaalea iho',
    '🖕🏾' => 'keskisormi: keskitumma iho',
    '🖕🏿' => 'keskisormi: tumma iho',
    '👇🏻' => 'kämmenselkä ja etusormi alas: vaalea iho',
    '👇🏼' => 'kämmenselkä ja etusormi alas: keskivaalea iho',
    '👇🏽' => 'kämmenselkä ja etusormi alas: tummanvaalea iho',
    '👇🏾' => 'kämmenselkä ja etusormi alas: keskitumma iho',
    '👇🏿' => 'kämmenselkä ja etusormi alas: tumma iho',
    '☝🏻' => 'ylös osoittava etusormi: vaalea iho',
    '☝🏼' => 'ylös osoittava etusormi: keskivaalea iho',
    '☝🏽' => 'ylös osoittava etusormi: tummanvaalea iho',
    '☝🏾' => 'ylös osoittava etusormi: keskitumma iho',
    '☝🏿' => 'ylös osoittava etusormi: tumma iho',
    '🫵🏻' => 'etusormi osoittaa katsojaa: vaalea iho',
    '🫵🏼' => 'etusormi osoittaa katsojaa: keskivaalea iho',
    '🫵🏽' => 'etusormi osoittaa katsojaa: tummanvaalea iho',
    '🫵🏾' => 'etusormi osoittaa katsojaa: keskitumma iho',
    '🫵🏿' => 'etusormi osoittaa katsojaa: tumma iho',
    '👍🏻' => 'peukalo ylös: vaalea iho',
    '👍🏼' => 'peukalo ylös: keskivaalea iho',
    '👍🏽' => 'peukalo ylös: tummanvaalea iho',
    '👍🏾' => 'peukalo ylös: keskitumma iho',
    '👍🏿' => 'peukalo ylös: tumma iho',
    '👎🏻' => 'peukalo alas: vaalea iho',
    '👎🏼' => 'peukalo alas: keskivaalea iho',
    '👎🏽' => 'peukalo alas: tummanvaalea iho',
    '👎🏾' => 'peukalo alas: keskitumma iho',
    '👎🏿' => 'peukalo alas: tumma iho',
    '✊🏻' => 'nostettu nyrkki: vaalea iho',
    '✊🏼' => 'nostettu nyrkki: keskivaalea iho',
    '✊🏽' => 'nostettu nyrkki: tummanvaalea iho',
    '✊🏾' => 'nostettu nyrkki: keskitumma iho',
    '✊🏿' => 'nostettu nyrkki: tumma iho',
    '👊🏻' => 'kohti tuleva nyrkki: vaalea iho',
    '👊🏼' => 'kohti tuleva nyrkki: keskivaalea iho',
    '👊🏽' => 'kohti tuleva nyrkki: tummanvaalea iho',
    '👊🏾' => 'kohti tuleva nyrkki: keskitumma iho',
    '👊🏿' => 'kohti tuleva nyrkki: tumma iho',
    '🤛🏻' => 'nyrkki vasemmalle: vaalea iho',
    '🤛🏼' => 'nyrkki vasemmalle: keskivaalea iho',
    '🤛🏽' => 'nyrkki vasemmalle: tummanvaalea iho',
    '🤛🏾' => 'nyrkki vasemmalle: keskitumma iho',
    '🤛🏿' => 'nyrkki vasemmalle: tumma iho',
    '🤜🏻' => 'nyrkki oikealle: vaalea iho',
    '🤜🏼' => 'nyrkki oikealle: keskivaalea iho',
    '🤜🏽' => 'nyrkki oikealle: tummanvaalea iho',
    '🤜🏾' => 'nyrkki oikealle: keskitumma iho',
    '🤜🏿' => 'nyrkki oikealle: tumma iho',
    '👏🏻' => 'käsien taputus: vaalea iho',
    '👏🏼' => 'käsien taputus: keskivaalea iho',
    '👏🏽' => 'käsien taputus: tummanvaalea iho',
    '👏🏾' => 'käsien taputus: keskitumma iho',
    '👏🏿' => 'käsien taputus: tumma iho',
    '🙌🏻' => 'nousevat kädet: vaalea iho',
    '🙌🏼' => 'nousevat kädet: keskivaalea iho',
    '🙌🏽' => 'nousevat kädet: tummanvaalea iho',
    '🙌🏾' => 'nousevat kädet: keskitumma iho',
    '🙌🏿' => 'nousevat kädet: tumma iho',
    '🫶🏻' => 'sydänkuvio käsillä: vaalea iho',
    '🫶🏼' => 'sydänkuvio käsillä: keskivaalea iho',
    '🫶🏽' => 'sydänkuvio käsillä: tummanvaalea iho',
    '🫶🏾' => 'sydänkuvio käsillä: keskitumma iho',
    '🫶🏿' => 'sydänkuvio käsillä: tumma iho',
    '👐🏻' => 'avoimet kädet: vaalea iho',
    '👐🏼' => 'avoimet kädet: keskivaalea iho',
    '👐🏽' => 'avoimet kädet: tummanvaalea iho',
    '👐🏾' => 'avoimet kädet: keskitumma iho',
    '👐🏿' => 'avoimet kädet: tumma iho',
    '🤲🏻' => 'kämmenet vierekkäin: vaalea iho',
    '🤲🏼' => 'kämmenet vierekkäin: keskivaalea iho',
    '🤲🏽' => 'kämmenet vierekkäin: tummanvaalea iho',
    '🤲🏾' => 'kämmenet vierekkäin: keskitumma iho',
    '🤲🏿' => 'kämmenet vierekkäin: tumma iho',
    '🤝🏻' => 'kädenpuristus: vaalea iho',
    '🤝🏼' => 'kädenpuristus: keskivaalea iho',
    '🤝🏽' => 'kädenpuristus: tummanvaalea iho',
    '🤝🏾' => 'kädenpuristus: keskitumma iho',
    '🤝🏿' => 'kädenpuristus: tumma iho',
    '🙏🏻' => 'kämmenet yhdessä: vaalea iho',
    '🙏🏼' => 'kämmenet yhdessä: keskivaalea iho',
    '🙏🏽' => 'kämmenet yhdessä: tummanvaalea iho',
    '🙏🏾' => 'kämmenet yhdessä: keskitumma iho',
    '🙏🏿' => 'kämmenet yhdessä: tumma iho',
    '✍🏻' => 'kirjoittava käsi: vaalea iho',
    '✍🏼' => 'kirjoittava käsi: keskivaalea iho',
    '✍🏽' => 'kirjoittava käsi: tummanvaalea iho',
    '✍🏾' => 'kirjoittava käsi: keskitumma iho',
    '✍🏿' => 'kirjoittava käsi: tumma iho',
    '💅🏻' => 'kynsilakka: vaalea iho',
    '💅🏼' => 'kynsilakka: keskivaalea iho',
    '💅🏽' => 'kynsilakka: tummanvaalea iho',
    '💅🏾' => 'kynsilakka: keskitumma iho',
    '💅🏿' => 'kynsilakka: tumma iho',
    '🤳🏻' => 'selfie: vaalea iho',
    '🤳🏼' => 'selfie: keskivaalea iho',
    '🤳🏽' => 'selfie: tummanvaalea iho',
    '🤳🏾' => 'selfie: keskitumma iho',
    '🤳🏿' => 'selfie: tumma iho',
    '💪🏻' => 'pullistettu hauis: vaalea iho',
    '💪🏼' => 'pullistettu hauis: keskivaalea iho',
    '💪🏽' => 'pullistettu hauis: tummanvaalea iho',
    '💪🏾' => 'pullistettu hauis: keskitumma iho',
    '💪🏿' => 'pullistettu hauis: tumma iho',
    '🦵🏻' => 'jalka: vaalea iho',
    '🦵🏼' => 'jalka: keskivaalea iho',
    '🦵🏽' => 'jalka: tummanvaalea iho',
    '🦵🏾' => 'jalka: keskitumma iho',
    '🦵🏿' => 'jalka: tumma iho',
    '🦶🏻' => 'jalkaterä: vaalea iho',
    '🦶🏼' => 'jalkaterä: keskivaalea iho',
    '🦶🏽' => 'jalkaterä: tummanvaalea iho',
    '🦶🏾' => 'jalkaterä: keskitumma iho',
    '🦶🏿' => 'jalkaterä: tumma iho',
    '👂🏻' => 'korva: vaalea iho',
    '👂🏼' => 'korva: keskivaalea iho',
    '👂🏽' => 'korva: tummanvaalea iho',
    '👂🏾' => 'korva: keskitumma iho',
    '👂🏿' => 'korva: tumma iho',
    '🦻🏻' => 'kuulolaite korvassa: vaalea iho',
    '🦻🏼' => 'kuulolaite korvassa: keskivaalea iho',
    '🦻🏽' => 'kuulolaite korvassa: tummanvaalea iho',
    '🦻🏾' => 'kuulolaite korvassa: keskitumma iho',
    '🦻🏿' => 'kuulolaite korvassa: tumma iho',
    '👃🏻' => 'nenä: vaalea iho',
    '👃🏼' => 'nenä: keskivaalea iho',
    '👃🏽' => 'nenä: tummanvaalea iho',
    '👃🏾' => 'nenä: keskitumma iho',
    '👃🏿' => 'nenä: tumma iho',
    '👶🏻' => 'vauva: vaalea iho',
    '👶🏼' => 'vauva: keskivaalea iho',
    '👶🏽' => 'vauva: tummanvaalea iho',
    '👶🏾' => 'vauva: keskitumma iho',
    '👶🏿' => 'vauva: tumma iho',
    '🧒🏻' => 'lapsi: vaalea iho',
    '🧒🏼' => 'lapsi: keskivaalea iho',
    '🧒🏽' => 'lapsi: tummanvaalea iho',
    '🧒🏾' => 'lapsi: keskitumma iho',
    '🧒🏿' => 'lapsi: tumma iho',
    '👦🏻' => 'poika: vaalea iho',
    '👦🏼' => 'poika: keskivaalea iho',
    '👦🏽' => 'poika: tummanvaalea iho',
    '👦🏾' => 'poika: keskitumma iho',
    '👦🏿' => 'poika: tumma iho',
    '👧🏻' => 'tyttö: vaalea iho',
    '👧🏼' => 'tyttö: keskivaalea iho',
    '👧🏽' => 'tyttö: tummanvaalea iho',
    '👧🏾' => 'tyttö: keskitumma iho',
    '👧🏿' => 'tyttö: tumma iho',
    '🧑🏻' => 'aikuinen: vaalea iho',
    '🧑🏼' => 'aikuinen: keskivaalea iho',
    '🧑🏽' => 'aikuinen: tummanvaalea iho',
    '🧑🏾' => 'aikuinen: keskitumma iho',
    '🧑🏿' => 'aikuinen: tumma iho',
    '👱🏻' => 'vaaleatukkainen henkilö: vaalea iho',
    '👱🏼' => 'vaaleatukkainen henkilö: keskivaalea iho',
    '👱🏽' => 'vaaleatukkainen henkilö: tummanvaalea iho',
    '👱🏾' => 'vaaleatukkainen henkilö: keskitumma iho',
    '👱🏿' => 'vaaleatukkainen henkilö: tumma iho',
    '👨🏻' => 'mies: vaalea iho',
    '👨🏼' => 'mies: keskivaalea iho',
    '👨🏽' => 'mies: tummanvaalea iho',
    '👨🏾' => 'mies: keskitumma iho',
    '👨🏿' => 'mies: tumma iho',
    '🧔🏻' => 'parrakas henkilö: vaalea iho',
    '🧔🏼' => 'parrakas henkilö: keskivaalea iho',
    '🧔🏽' => 'parrakas henkilö: tummanvaalea iho',
    '🧔🏾' => 'parrakas henkilö: keskitumma iho',
    '🧔🏿' => 'parrakas henkilö: tumma iho',
    '👩🏻' => 'nainen: vaalea iho',
    '👩🏼' => 'nainen: keskivaalea iho',
    '👩🏽' => 'nainen: tummanvaalea iho',
    '👩🏾' => 'nainen: keskitumma iho',
    '👩🏿' => 'nainen: tumma iho',
    '🧓🏻' => 'vanhus: vaalea iho',
    '🧓🏼' => 'vanhus: keskivaalea iho',
    '🧓🏽' => 'vanhus: tummanvaalea iho',
    '🧓🏾' => 'vanhus: keskitumma iho',
    '🧓🏿' => 'vanhus: tumma iho',
    '👴🏻' => 'vanha mies: vaalea iho',
    '👴🏼' => 'vanha mies: keskivaalea iho',
    '👴🏽' => 'vanha mies: tummanvaalea iho',
    '👴🏾' => 'vanha mies: keskitumma iho',
    '👴🏿' => 'vanha mies: tumma iho',
    '👵🏻' => 'vanha nainen: vaalea iho',
    '👵🏼' => 'vanha nainen: keskivaalea iho',
    '👵🏽' => 'vanha nainen: tummanvaalea iho',
    '👵🏾' => 'vanha nainen: keskitumma iho',
    '👵🏿' => 'vanha nainen: tumma iho',
    '🙍🏻' => 'surullinen henkilö: vaalea iho',
    '🙍🏼' => 'surullinen henkilö: keskivaalea iho',
    '🙍🏽' => 'surullinen henkilö: tummanvaalea iho',
    '🙍🏾' => 'surullinen henkilö: keskitumma iho',
    '🙍🏿' => 'surullinen henkilö: tumma iho',
    '🙎🏻' => 'mököttävä henkilö: vaalea iho',
    '🙎🏼' => 'mököttävä henkilö: keskivaalea iho',
    '🙎🏽' => 'mököttävä henkilö: tummanvaalea iho',
    '🙎🏾' => 'mököttävä henkilö: keskitumma iho',
    '🙎🏿' => 'mököttävä henkilö: tumma iho',
    '🙅🏻' => 'ei-ele: vaalea iho',
    '🙅🏼' => 'ei-ele: keskivaalea iho',
    '🙅🏽' => 'ei-ele: tummanvaalea iho',
    '🙅🏾' => 'ei-ele: keskitumma iho',
    '🙅🏿' => 'ei-ele: tumma iho',
    '🙆🏻' => 'ok-ele: vaalea iho',
    '🙆🏼' => 'ok-ele: keskivaalea iho',
    '🙆🏽' => 'ok-ele: tummanvaalea iho',
    '🙆🏾' => 'ok-ele: keskitumma iho',
    '🙆🏿' => 'ok-ele: tumma iho',
    '💁🏻' => 'kämmentä ylöspäin näyttävä henkilö: vaalea iho',
    '💁🏼' => 'kämmentä ylöspäin näyttävä henkilö: keskivaalea iho',
    '💁🏽' => 'kämmentä ylöspäin näyttävä henkilö: tummanvaalea iho',
    '💁🏾' => 'kämmentä ylöspäin näyttävä henkilö: keskitumma iho',
    '💁🏿' => 'kämmentä ylöspäin näyttävä henkilö: tumma iho',
    '🙋🏻' => 'iloinen henkilö viittaa: vaalea iho',
    '🙋🏼' => 'iloinen henkilö viittaa: keskivaalea iho',
    '🙋🏽' => 'iloinen henkilö viittaa: tummanvaalea iho',
    '🙋🏾' => 'iloinen henkilö viittaa: keskitumma iho',
    '🙋🏿' => 'iloinen henkilö viittaa: tumma iho',
    '🧏🏻' => 'kuuro henkilö: vaalea iho',
    '🧏🏼' => 'kuuro henkilö: keskivaalea iho',
    '🧏🏽' => 'kuuro henkilö: tummanvaalea iho',
    '🧏🏾' => 'kuuro henkilö: keskitumma iho',
    '🧏🏿' => 'kuuro henkilö: tumma iho',
    '🙇🏻' => 'kumartava henkilö: vaalea iho',
    '🙇🏼' => 'kumartava henkilö: keskivaalea iho',
    '🙇🏽' => 'kumartava henkilö: tummanvaalea iho',
    '🙇🏾' => 'kumartava henkilö: keskitumma iho',
    '🙇🏿' => 'kumartava henkilö: tumma iho',
    '🤦🏻' => 'peittää kasvot kädellä: vaalea iho',
    '🤦🏼' => 'peittää kasvot kädellä: keskivaalea iho',
    '🤦🏽' => 'peittää kasvot kädellä: tummanvaalea iho',
    '🤦🏾' => 'peittää kasvot kädellä: keskitumma iho',
    '🤦🏿' => 'peittää kasvot kädellä: tumma iho',
    '🤷🏻' => 'olkapäitään kohauttava henkilö: vaalea iho',
    '🤷🏼' => 'olkapäitään kohauttava henkilö: keskivaalea iho',
    '🤷🏽' => 'olkapäitään kohauttava henkilö: tummanvaalea iho',
    '🤷🏾' => 'olkapäitään kohauttava henkilö: keskitumma iho',
    '🤷🏿' => 'olkapäitään kohauttava henkilö: tumma iho',
    '👮🏻' => 'poliisi: vaalea iho',
    '👮🏼' => 'poliisi: keskivaalea iho',
    '👮🏽' => 'poliisi: tummanvaalea iho',
    '👮🏾' => 'poliisi: keskitumma iho',
    '👮🏿' => 'poliisi: tumma iho',
    '🕵🏻' => 'etsivä: vaalea iho',
    '🕵🏼' => 'etsivä: keskivaalea iho',
    '🕵🏽' => 'etsivä: tummanvaalea iho',
    '🕵🏾' => 'etsivä: keskitumma iho',
    '🕵🏿' => 'etsivä: tumma iho',
    '💂🏻' => 'vartija: vaalea iho',
    '💂🏼' => 'vartija: keskivaalea iho',
    '💂🏽' => 'vartija: tummanvaalea iho',
    '💂🏾' => 'vartija: keskitumma iho',
    '💂🏿' => 'vartija: tumma iho',
    '🥷🏻' => 'ninja: vaalea iho',
    '🥷🏼' => 'ninja: keskivaalea iho',
    '🥷🏽' => 'ninja: tummanvaalea iho',
    '🥷🏾' => 'ninja: keskitumma iho',
    '🥷🏿' => 'ninja: tumma iho',
    '👷🏻' => 'rakennustyöläinen: vaalea iho',
    '👷🏼' => 'rakennustyöläinen: keskivaalea iho',
    '👷🏽' => 'rakennustyöläinen: tummanvaalea iho',
    '👷🏾' => 'rakennustyöläinen: keskitumma iho',
    '👷🏿' => 'rakennustyöläinen: tumma iho',
    '🫅🏻' => 'kruunua kantava henkilö: vaalea iho',
    '🫅🏼' => 'kruunua kantava henkilö: keskivaalea iho',
    '🫅🏽' => 'kruunua kantava henkilö: tummanvaalea iho',
    '🫅🏾' => 'kruunua kantava henkilö: keskitumma iho',
    '🫅🏿' => 'kruunua kantava henkilö: tumma iho',
    '🤴🏻' => 'prinssi: vaalea iho',
    '🤴🏼' => 'prinssi: keskivaalea iho',
    '🤴🏽' => 'prinssi: tummanvaalea iho',
    '🤴🏾' => 'prinssi: keskitumma iho',
    '🤴🏿' => 'prinssi: tumma iho',
    '👸🏻' => 'prinsessa: vaalea iho',
    '👸🏼' => 'prinsessa: keskivaalea iho',
    '👸🏽' => 'prinsessa: tummanvaalea iho',
    '👸🏾' => 'prinsessa: keskitumma iho',
    '👸🏿' => 'prinsessa: tumma iho',
    '👳🏻' => 'turbaanipäinen henkilö: vaalea iho',
    '👳🏼' => 'turbaanipäinen henkilö: keskivaalea iho',
    '👳🏽' => 'turbaanipäinen henkilö: tummanvaalea iho',
    '👳🏾' => 'turbaanipäinen henkilö: keskitumma iho',
    '👳🏿' => 'turbaanipäinen henkilö: tumma iho',
    '👲🏻' => 'mies ja kiinalainen hattu: vaalea iho',
    '👲🏼' => 'mies ja kiinalainen hattu: keskivaalea iho',
    '👲🏽' => 'mies ja kiinalainen hattu: tummanvaalea iho',
    '👲🏾' => 'mies ja kiinalainen hattu: keskitumma iho',
    '👲🏿' => 'mies ja kiinalainen hattu: tumma iho',
    '🧕🏻' => 'huivipäinen nainen: vaalea iho',
    '🧕🏼' => 'huivipäinen nainen: keskivaalea iho',
    '🧕🏽' => 'huivipäinen nainen: tummanvaalea iho',
    '🧕🏾' => 'huivipäinen nainen: keskitumma iho',
    '🧕🏿' => 'huivipäinen nainen: tumma iho',
    '🤵🏻' => 'henkilö smokissa: vaalea iho',
    '🤵🏼' => 'henkilö smokissa: keskivaalea iho',
    '🤵🏽' => 'henkilö smokissa: tummanvaalea iho',
    '🤵🏾' => 'henkilö smokissa: keskitumma iho',
    '🤵🏿' => 'henkilö smokissa: tumma iho',
    '👰🏻' => 'huntupäinen henkilö: vaalea iho',
    '👰🏼' => 'huntupäinen henkilö: keskivaalea iho',
    '👰🏽' => 'huntupäinen henkilö: tummanvaalea iho',
    '👰🏾' => 'huntupäinen henkilö: keskitumma iho',
    '👰🏿' => 'huntupäinen henkilö: tumma iho',
    '🤰🏻' => 'raskaana oleva nainen: vaalea iho',
    '🤰🏼' => 'raskaana oleva nainen: keskivaalea iho',
    '🤰🏽' => 'raskaana oleva nainen: tummanvaalea iho',
    '🤰🏾' => 'raskaana oleva nainen: keskitumma iho',
    '🤰🏿' => 'raskaana oleva nainen: tumma iho',
    '🫃🏻' => 'raskaana oleva mies: vaalea iho',
    '🫃🏼' => 'raskaana oleva mies: keskivaalea iho',
    '🫃🏽' => 'raskaana oleva mies: tummanvaalea iho',
    '🫃🏾' => 'raskaana oleva mies: keskitumma iho',
    '🫃🏿' => 'raskaana oleva mies: tumma iho',
    '🫄🏻' => 'raskaana oleva henkilö: vaalea iho',
    '🫄🏼' => 'raskaana oleva henkilö: keskivaalea iho',
    '🫄🏽' => 'raskaana oleva henkilö: tummanvaalea iho',
    '🫄🏾' => 'raskaana oleva henkilö: keskitumma iho',
    '🫄🏿' => 'raskaana oleva henkilö: tumma iho',
    '🤱🏻' => 'imetys: vaalea iho',
    '🤱🏼' => 'imetys: keskivaalea iho',
    '🤱🏽' => 'imetys: tummanvaalea iho',
    '🤱🏾' => 'imetys: keskitumma iho',
    '🤱🏿' => 'imetys: tumma iho',
    '👼🏻' => 'vauvaenkeli: vaalea iho',
    '👼🏼' => 'vauvaenkeli: keskivaalea iho',
    '👼🏽' => 'vauvaenkeli: tummanvaalea iho',
    '👼🏾' => 'vauvaenkeli: keskitumma iho',
    '👼🏿' => 'vauvaenkeli: tumma iho',
    '🎅🏻' => 'joulupukki: vaalea iho',
    '🎅🏼' => 'joulupukki: keskivaalea iho',
    '🎅🏽' => 'joulupukki: tummanvaalea iho',
    '🎅🏾' => 'joulupukki: keskitumma iho',
    '🎅🏿' => 'joulupukki: tumma iho',
    '🤶🏻' => 'joulupukin muori: vaalea iho',
    '🤶🏼' => 'joulupukin muori: keskivaalea iho',
    '🤶🏽' => 'joulupukin muori: tummanvaalea iho',
    '🤶🏾' => 'joulupukin muori: keskitumma iho',
    '🤶🏿' => 'joulupukin muori: tumma iho',
    '🦸🏻' => 'supersankari: vaalea iho',
    '🦸🏼' => 'supersankari: keskivaalea iho',
    '🦸🏽' => 'supersankari: tummanvaalea iho',
    '🦸🏾' => 'supersankari: keskitumma iho',
    '🦸🏿' => 'supersankari: tumma iho',
    '🦹🏻' => 'superpahis: vaalea iho',
    '🦹🏼' => 'superpahis: keskivaalea iho',
    '🦹🏽' => 'superpahis: tummanvaalea iho',
    '🦹🏾' => 'superpahis: keskitumma iho',
    '🦹🏿' => 'superpahis: tumma iho',
    '🧙🏻' => 'velho: vaalea iho',
    '🧙🏼' => 'velho: keskivaalea iho',
    '🧙🏽' => 'velho: tummanvaalea iho',
    '🧙🏾' => 'velho: keskitumma iho',
    '🧙🏿' => 'velho: tumma iho',
    '🧚🏻' => 'keiju: vaalea iho',
    '🧚🏼' => 'keiju: keskivaalea iho',
    '🧚🏽' => 'keiju: tummanvaalea iho',
    '🧚🏾' => 'keiju: keskitumma iho',
    '🧚🏿' => 'keiju: tumma iho',
    '🧛🏻' => 'vampyyri: vaalea iho',
    '🧛🏼' => 'vampyyri: keskivaalea iho',
    '🧛🏽' => 'vampyyri: tummanvaalea iho',
    '🧛🏾' => 'vampyyri: keskitumma iho',
    '🧛🏿' => 'vampyyri: tumma iho',
    '🧜🏻' => 'merenväki: vaalea iho',
    '🧜🏼' => 'merenväki: keskivaalea iho',
    '🧜🏽' => 'merenväki: tummanvaalea iho',
    '🧜🏾' => 'merenväki: keskitumma iho',
    '🧜🏿' => 'merenväki: tumma iho',
    '🧝🏻' => 'haltia: vaalea iho',
    '🧝🏼' => 'haltia: keskivaalea iho',
    '🧝🏽' => 'haltia: tummanvaalea iho',
    '🧝🏾' => 'haltia: keskitumma iho',
    '🧝🏿' => 'haltia: tumma iho',
    '💆🏻' => 'hieronta: vaalea iho',
    '💆🏼' => 'hieronta: keskivaalea iho',
    '💆🏽' => 'hieronta: tummanvaalea iho',
    '💆🏾' => 'hieronta: keskitumma iho',
    '💆🏿' => 'hieronta: tumma iho',
    '💇🏻' => 'hiustenleikkaus: vaalea iho',
    '💇🏼' => 'hiustenleikkaus: keskivaalea iho',
    '💇🏽' => 'hiustenleikkaus: tummanvaalea iho',
    '💇🏾' => 'hiustenleikkaus: keskitumma iho',
    '💇🏿' => 'hiustenleikkaus: tumma iho',
    '🚶🏻' => 'jalankulkija: vaalea iho',
    '🚶🏼' => 'jalankulkija: keskivaalea iho',
    '🚶🏽' => 'jalankulkija: tummanvaalea iho',
    '🚶🏾' => 'jalankulkija: keskitumma iho',
    '🚶🏿' => 'jalankulkija: tumma iho',
    '🧍🏻' => 'seisova henkilö: vaalea iho',
    '🧍🏼' => 'seisova henkilö: keskivaalea iho',
    '🧍🏽' => 'seisova henkilö: tummanvaalea iho',
    '🧍🏾' => 'seisova henkilö: keskitumma iho',
    '🧍🏿' => 'seisova henkilö: tumma iho',
    '🧎🏻' => 'polvistuva ihminen: vaalea iho',
    '🧎🏼' => 'polvistuva ihminen: keskivaalea iho',
    '🧎🏽' => 'polvistuva ihminen: tummanvaalea iho',
    '🧎🏾' => 'polvistuva ihminen: keskitumma iho',
    '🧎🏿' => 'polvistuva ihminen: tumma iho',
    '🏃🏻' => 'juoksija: vaalea iho',
    '🏃🏼' => 'juoksija: keskivaalea iho',
    '🏃🏽' => 'juoksija: tummanvaalea iho',
    '🏃🏾' => 'juoksija: keskitumma iho',
    '🏃🏿' => 'juoksija: tumma iho',
    '💃🏻' => 'tanssiva nainen: vaalea iho',
    '💃🏼' => 'tanssiva nainen: keskivaalea iho',
    '💃🏽' => 'tanssiva nainen: tummanvaalea iho',
    '💃🏾' => 'tanssiva nainen: keskitumma iho',
    '💃🏿' => 'tanssiva nainen: tumma iho',
    '🕺🏻' => 'tanssiva mies: vaalea iho',
    '🕺🏼' => 'tanssiva mies: keskivaalea iho',
    '🕺🏽' => 'tanssiva mies: tummanvaalea iho',
    '🕺🏾' => 'tanssiva mies: keskitumma iho',
    '🕺🏿' => 'tanssiva mies: tumma iho',
    '🕴🏻' => 'levitoiva mies puvussa: vaalea iho',
    '🕴🏼' => 'levitoiva mies puvussa: keskivaalea iho',
    '🕴🏽' => 'levitoiva mies puvussa: tummanvaalea iho',
    '🕴🏾' => 'levitoiva mies puvussa: keskitumma iho',
    '🕴🏿' => 'levitoiva mies puvussa: tumma iho',
    '👯🏻' => 'puputytöt: vaalea iho',
    '👯🏼' => 'puputytöt: keskivaalea iho',
    '👯🏽' => 'puputytöt: tummanvaalea iho',
    '👯🏾' => 'puputytöt: keskitumma iho',
    '👯🏿' => 'puputytöt: tumma iho',
    '🧖🏻' => 'henkilö saunassa: vaalea iho',
    '🧖🏼' => 'henkilö saunassa: keskivaalea iho',
    '🧖🏽' => 'henkilö saunassa: tummanvaalea iho',
    '🧖🏾' => 'henkilö saunassa: keskitumma iho',
    '🧖🏿' => 'henkilö saunassa: tumma iho',
    '🧗🏻' => 'kiipeilijä: vaalea iho',
    '🧗🏼' => 'kiipeilijä: keskivaalea iho',
    '🧗🏽' => 'kiipeilijä: tummanvaalea iho',
    '🧗🏾' => 'kiipeilijä: keskitumma iho',
    '🧗🏿' => 'kiipeilijä: tumma iho',
    '🏇🏻' => 'ratsastus: vaalea iho',
    '🏇🏼' => 'ratsastus: keskivaalea iho',
    '🏇🏽' => 'ratsastus: tummanvaalea iho',
    '🏇🏾' => 'ratsastus: keskitumma iho',
    '🏇🏿' => 'ratsastus: tumma iho',
    '🏂🏻' => 'lumilautailija: vaalea iho',
    '🏂🏼' => 'lumilautailija: keskivaalea iho',
    '🏂🏽' => 'lumilautailija: tummanvaalea iho',
    '🏂🏾' => 'lumilautailija: keskitumma iho',
    '🏂🏿' => 'lumilautailija: tumma iho',
    '🏌🏻' => 'golfaaja: vaalea iho',
    '🏌🏼' => 'golfaaja: keskivaalea iho',
    '🏌🏽' => 'golfaaja: tummanvaalea iho',
    '🏌🏾' => 'golfaaja: keskitumma iho',
    '🏌🏿' => 'golfaaja: tumma iho',
    '🏄🏻' => 'surffaaja: vaalea iho',
    '🏄🏼' => 'surffaaja: keskivaalea iho',
    '🏄🏽' => 'surffaaja: tummanvaalea iho',
    '🏄🏾' => 'surffaaja: keskitumma iho',
    '🏄🏿' => 'surffaaja: tumma iho',
    '🚣🏻' => 'soutaja: vaalea iho',
    '🚣🏼' => 'soutaja: keskivaalea iho',
    '🚣🏽' => 'soutaja: tummanvaalea iho',
    '🚣🏾' => 'soutaja: keskitumma iho',
    '🚣🏿' => 'soutaja: tumma iho',
    '🏊🏻' => 'uimari: vaalea iho',
    '🏊🏼' => 'uimari: keskivaalea iho',
    '🏊🏽' => 'uimari: tummanvaalea iho',
    '🏊🏾' => 'uimari: keskitumma iho',
    '🏊🏿' => 'uimari: tumma iho',
    '⛹🏻' => 'pallottelija: vaalea iho',
    '⛹🏼' => 'pallottelija: keskivaalea iho',
    '⛹🏽' => 'pallottelija: tummanvaalea iho',
    '⛹🏾' => 'pallottelija: keskitumma iho',
    '⛹🏿' => 'pallottelija: tumma iho',
    '🏋🏻' => 'painonnostaja: vaalea iho',
    '🏋🏼' => 'painonnostaja: keskivaalea iho',
    '🏋🏽' => 'painonnostaja: tummanvaalea iho',
    '🏋🏾' => 'painonnostaja: keskitumma iho',
    '🏋🏿' => 'painonnostaja: tumma iho',
    '🚴🏻' => 'pyöräilijä: vaalea iho',
    '🚴🏼' => 'pyöräilijä: keskivaalea iho',
    '🚴🏽' => 'pyöräilijä: tummanvaalea iho',
    '🚴🏾' => 'pyöräilijä: keskitumma iho',
    '🚴🏿' => 'pyöräilijä: tumma iho',
    '🚵🏻' => 'maastopyöräilijä: vaalea iho',
    '🚵🏼' => 'maastopyöräilijä: keskivaalea iho',
    '🚵🏽' => 'maastopyöräilijä: tummanvaalea iho',
    '🚵🏾' => 'maastopyöräilijä: keskitumma iho',
    '🚵🏿' => 'maastopyöräilijä: tumma iho',
    '🤸🏻' => 'kärrynpyörä: vaalea iho',
    '🤸🏼' => 'kärrynpyörä: keskivaalea iho',
    '🤸🏽' => 'kärrynpyörä: tummanvaalea iho',
    '🤸🏾' => 'kärrynpyörä: keskitumma iho',
    '🤸🏿' => 'kärrynpyörä: tumma iho',
    '🤼🏻' => 'painijat: vaalea iho',
    '🤼🏼' => 'painijat: keskivaalea iho',
    '🤼🏽' => 'painijat: tummanvaalea iho',
    '🤼🏾' => 'painijat: keskitumma iho',
    '🤼🏿' => 'painijat: tumma iho',
    '🤽🏻' => 'vesipalloilija: vaalea iho',
    '🤽🏼' => 'vesipalloilija: keskivaalea iho',
    '🤽🏽' => 'vesipalloilija: tummanvaalea iho',
    '🤽🏾' => 'vesipalloilija: keskitumma iho',
    '🤽🏿' => 'vesipalloilija: tumma iho',
    '🤾🏻' => 'käsipalloilija: vaalea iho',
    '🤾🏼' => 'käsipalloilija: keskivaalea iho',
    '🤾🏽' => 'käsipalloilija: tummanvaalea iho',
    '🤾🏾' => 'käsipalloilija: keskitumma iho',
    '🤾🏿' => 'käsipalloilija: tumma iho',
    '🤹🏻' => 'jongleeraaja: vaalea iho',
    '🤹🏼' => 'jongleeraaja: keskivaalea iho',
    '🤹🏽' => 'jongleeraaja: tummanvaalea iho',
    '🤹🏾' => 'jongleeraaja: keskitumma iho',
    '🤹🏿' => 'jongleeraaja: tumma iho',
    '🧘🏻' => 'henkilö lootusasennossa: vaalea iho',
    '🧘🏼' => 'henkilö lootusasennossa: keskivaalea iho',
    '🧘🏽' => 'henkilö lootusasennossa: tummanvaalea iho',
    '🧘🏾' => 'henkilö lootusasennossa: keskitumma iho',
    '🧘🏿' => 'henkilö lootusasennossa: tumma iho',
    '🛀🏻' => 'kylpijä: vaalea iho',
    '🛀🏼' => 'kylpijä: keskivaalea iho',
    '🛀🏽' => 'kylpijä: tummanvaalea iho',
    '🛀🏾' => 'kylpijä: keskitumma iho',
    '🛀🏿' => 'kylpijä: tumma iho',
    '🛌🏻' => 'nukkuja: vaalea iho',
    '🛌🏼' => 'nukkuja: keskivaalea iho',
    '🛌🏽' => 'nukkuja: tummanvaalea iho',
    '🛌🏾' => 'nukkuja: keskitumma iho',
    '🛌🏿' => 'nukkuja: tumma iho',
    '👭🏻' => 'kaksi naista käsi kädessä: vaalea iho',
    '👭🏼' => 'kaksi naista käsi kädessä: keskivaalea iho',
    '👭🏽' => 'kaksi naista käsi kädessä: tummanvaalea iho',
    '👭🏾' => 'kaksi naista käsi kädessä: keskitumma iho',
    '👭🏿' => 'kaksi naista käsi kädessä: tumma iho',
    '👫🏻' => 'mies ja nainen käsi kädessä: vaalea iho',
    '👫🏼' => 'mies ja nainen käsi kädessä: keskivaalea iho',
    '👫🏽' => 'mies ja nainen käsi kädessä: tummanvaalea iho',
    '👫🏾' => 'mies ja nainen käsi kädessä: keskitumma iho',
    '👫🏿' => 'mies ja nainen käsi kädessä: tumma iho',
    '👬🏻' => 'kaksi miestä käsi kädessä: vaalea iho',
    '👬🏼' => 'kaksi miestä käsi kädessä: keskivaalea iho',
    '👬🏽' => 'kaksi miestä käsi kädessä: tummanvaalea iho',
    '👬🏾' => 'kaksi miestä käsi kädessä: keskitumma iho',
    '👬🏿' => 'kaksi miestä käsi kädessä: tumma iho',
    '💏🏻' => 'pusu: vaalea iho',
    '💏🏼' => 'pusu: keskivaalea iho',
    '💏🏽' => 'pusu: tummanvaalea iho',
    '💏🏾' => 'pusu: keskitumma iho',
    '💏🏿' => 'pusu: tumma iho',
    '💑🏻' => 'pariskunta ja sydän: vaalea iho',
    '💑🏼' => 'pariskunta ja sydän: keskivaalea iho',
    '💑🏽' => 'pariskunta ja sydän: tummanvaalea iho',
    '💑🏾' => 'pariskunta ja sydän: keskitumma iho',
    '💑🏿' => 'pariskunta ja sydän: tumma iho',
    '🇦🇨' => 'lippu: Ascension-saari',
    '🇦🇩' => 'lippu: Andorra',
    '🇦🇪' => 'lippu: Arabiemiirikunnat',
    '🇦🇫' => 'lippu: Afganistan',
    '🇦🇬' => 'lippu: Antigua ja Barbuda',
    '🇦🇮' => 'lippu: Anguilla',
    '🇦🇱' => 'lippu: Albania',
    '🇦🇲' => 'lippu: Armenia',
    '🇦🇴' => 'lippu: Angola',
    '🇦🇶' => 'lippu: Antarktis',
    '🇦🇷' => 'lippu: Argentiina',
    '🇦🇸' => 'lippu: Amerikan Samoa',
    '🇦🇹' => 'lippu: Itävalta',
    '🇦🇺' => 'lippu: Australia',
    '🇦🇼' => 'lippu: Aruba',
    '🇦🇽' => 'lippu: Ahvenanmaa',
    '🇦🇿' => 'lippu: Azerbaidžan',
    '🇧🇦' => 'lippu: Bosnia ja Hertsegovina',
    '🇧🇧' => 'lippu: Barbados',
    '🇧🇩' => 'lippu: Bangladesh',
    '🇧🇪' => 'lippu: Belgia',
    '🇧🇫' => 'lippu: Burkina Faso',
    '🇧🇬' => 'lippu: Bulgaria',
    '🇧🇭' => 'lippu: Bahrain',
    '🇧🇮' => 'lippu: Burundi',
    '🇧🇯' => 'lippu: Benin',
    '🇧🇱' => 'lippu: Saint-Barthélemy',
    '🇧🇲' => 'lippu: Bermuda',
    '🇧🇳' => 'lippu: Brunei',
    '🇧🇴' => 'lippu: Bolivia',
    '🇧🇶' => 'lippu: Karibian Alankomaat',
    '🇧🇷' => 'lippu: Brasilia',
    '🇧🇸' => 'lippu: Bahama',
    '🇧🇹' => 'lippu: Bhutan',
    '🇧🇻' => 'lippu: Bouvet’nsaari',
    '🇧🇼' => 'lippu: Botswana',
    '🇧🇾' => 'lippu: Valko-Venäjä',
    '🇧🇿' => 'lippu: Belize',
    '🇨🇦' => 'lippu: Kanada',
    '🇨🇨' => 'lippu: Kookossaaret (Keelingsaaret)',
    '🇨🇩' => 'lippu: Kongon demokraattinen tasavalta',
    '🇨🇫' => 'lippu: Keski-Afrikan tasavalta',
    '🇨🇬' => 'lippu: Kongon tasavalta',
    '🇨🇭' => 'lippu: Sveitsi',
    '🇨🇮' => 'lippu: Norsunluurannikko',
    '🇨🇰' => 'lippu: Cookinsaaret',
    '🇨🇱' => 'lippu: Chile',
    '🇨🇲' => 'lippu: Kamerun',
    '🇨🇳' => 'lippu: Kiina',
    '🇨🇴' => 'lippu: Kolumbia',
    '🇨🇵' => 'lippu: Clippertoninsaari',
    '🇨🇶' => 'lippu: Sark',
    '🇨🇷' => 'lippu: Costa Rica',
    '🇨🇺' => 'lippu: Kuuba',
    '🇨🇻' => 'lippu: Kap Verde',
    '🇨🇼' => 'lippu: Curaçao',
    '🇨🇽' => 'lippu: Joulusaari',
    '🇨🇾' => 'lippu: Kypros',
    '🇨🇿' => 'lippu: Tšekki',
    '🇩🇪' => 'lippu: Saksa',
    '🇩🇬' => 'lippu: Diego Garcia',
    '🇩🇯' => 'lippu: Djibouti',
    '🇩🇰' => 'lippu: Tanska',
    '🇩🇲' => 'lippu: Dominica',
    '🇩🇴' => 'lippu: Dominikaaninen tasavalta',
    '🇩🇿' => 'lippu: Algeria',
    '🇪🇦' => 'lippu: Ceuta ja Melilla',
    '🇪🇨' => 'lippu: Ecuador',
    '🇪🇪' => 'lippu: Viro',
    '🇪🇬' => 'lippu: Egypti',
    '🇪🇭' => 'lippu: Länsi-Sahara',
    '🇪🇷' => 'lippu: Eritrea',
    '🇪🇸' => 'lippu: Espanja',
    '🇪🇹' => 'lippu: Etiopia',
    '🇪🇺' => 'lippu: Euroopan unioni',
    '🇫🇮' => 'lippu: Suomi',
    '🇫🇯' => 'lippu: Fidži',
    '🇫🇰' => 'lippu: Falklandinsaaret',
    '🇫🇲' => 'lippu: Mikronesia',
    '🇫🇴' => 'lippu: Färsaaret',
    '🇫🇷' => 'lippu: Ranska',
    '🇬🇦' => 'lippu: Gabon',
    '🇬🇧' => 'lippu: Iso-Britannia',
    '🇬🇩' => 'lippu: Grenada',
    '🇬🇪' => 'lippu: Georgia',
    '🇬🇫' => 'lippu: Ranskan Guayana',
    '🇬🇬' => 'lippu: Guernsey',
    '🇬🇭' => 'lippu: Ghana',
    '🇬🇮' => 'lippu: Gibraltar',
    '🇬🇱' => 'lippu: Grönlanti',
    '🇬🇲' => 'lippu: Gambia',
    '🇬🇳' => 'lippu: Guinea',
    '🇬🇵' => 'lippu: Guadeloupe',
    '🇬🇶' => 'lippu: Päiväntasaajan Guinea',
    '🇬🇷' => 'lippu: Kreikka',
    '🇬🇸' => 'lippu: Etelä-Georgia ja Eteläiset Sandwichinsaaret',
    '🇬🇹' => 'lippu: Guatemala',
    '🇬🇺' => 'lippu: Guam',
    '🇬🇼' => 'lippu: Guinea-Bissau',
    '🇬🇾' => 'lippu: Guyana',
    '🇭🇰' => 'lippu: Hongkong – Kiinan erityishallintoalue',
    '🇭🇲' => 'lippu: Heard ja McDonaldinsaaret',
    '🇭🇳' => 'lippu: Honduras',
    '🇭🇷' => 'lippu: Kroatia',
    '🇭🇹' => 'lippu: Haiti',
    '🇭🇺' => 'lippu: Unkari',
    '🇮🇨' => 'lippu: Kanariansaaret',
    '🇮🇩' => 'lippu: Indonesia',
    '🇮🇪' => 'lippu: Irlanti',
    '🇮🇱' => 'lippu: Israel',
    '🇮🇲' => 'lippu: Mansaari',
    '🇮🇳' => 'lippu: Intia',
    '🇮🇴' => 'lippu: Brittiläinen Intian valtameren alue',
    '🇮🇶' => 'lippu: Irak',
    '🇮🇷' => 'lippu: Iran',
    '🇮🇸' => 'lippu: Islanti',
    '🇮🇹' => 'lippu: Italia',
    '🇯🇪' => 'lippu: Jersey',
    '🇯🇲' => 'lippu: Jamaika',
    '🇯🇴' => 'lippu: Jordania',
    '🇯🇵' => 'lippu: Japani',
    '🇰🇪' => 'lippu: Kenia',
    '🇰🇬' => 'lippu: Kirgisia',
    '🇰🇭' => 'lippu: Kambodža',
    '🇰🇮' => 'lippu: Kiribati',
    '🇰🇲' => 'lippu: Komorit',
    '🇰🇳' => 'lippu: Saint Kitts ja Nevis',
    '🇰🇵' => 'lippu: Pohjois-Korea',
    '🇰🇷' => 'lippu: Etelä-Korea',
    '🇰🇼' => 'lippu: Kuwait',
    '🇰🇾' => 'lippu: Caymansaaret',
    '🇰🇿' => 'lippu: Kazakstan',
    '🇱🇦' => 'lippu: Laos',
    '🇱🇧' => 'lippu: Libanon',
    '🇱🇨' => 'lippu: Saint Lucia',
    '🇱🇮' => 'lippu: Liechtenstein',
    '🇱🇰' => 'lippu: Sri Lanka',
    '🇱🇷' => 'lippu: Liberia',
    '🇱🇸' => 'lippu: Lesotho',
    '🇱🇹' => 'lippu: Liettua',
    '🇱🇺' => 'lippu: Luxemburg',
    '🇱🇻' => 'lippu: Latvia',
    '🇱🇾' => 'lippu: Libya',
    '🇲🇦' => 'lippu: Marokko',
    '🇲🇨' => 'lippu: Monaco',
    '🇲🇩' => 'lippu: Moldova',
    '🇲🇪' => 'lippu: Montenegro',
    '🇲🇫' => 'lippu: Saint-Martin',
    '🇲🇬' => 'lippu: Madagaskar',
    '🇲🇭' => 'lippu: Marshallinsaaret',
    '🇲🇰' => 'lippu: Pohjois-Makedonia',
    '🇲🇱' => 'lippu: Mali',
    '🇲🇲' => 'lippu: Myanmar (Burma)',
    '🇲🇳' => 'lippu: Mongolia',
    '🇲🇴' => 'lippu: Macao – Kiinan erityishallintoalue',
    '🇲🇵' => 'lippu: Pohjois-Mariaanit',
    '🇲🇶' => 'lippu: Martinique',
    '🇲🇷' => 'lippu: Mauritania',
    '🇲🇸' => 'lippu: Montserrat',
    '🇲🇹' => 'lippu: Malta',
    '🇲🇺' => 'lippu: Mauritius',
    '🇲🇻' => 'lippu: Malediivit',
    '🇲🇼' => 'lippu: Malawi',
    '🇲🇽' => 'lippu: Meksiko',
    '🇲🇾' => 'lippu: Malesia',
    '🇲🇿' => 'lippu: Mosambik',
    '🇳🇦' => 'lippu: Namibia',
    '🇳🇨' => 'lippu: Uusi-Kaledonia',
    '🇳🇪' => 'lippu: Niger',
    '🇳🇫' => 'lippu: Norfolkinsaari',
    '🇳🇬' => 'lippu: Nigeria',
    '🇳🇮' => 'lippu: Nicaragua',
    '🇳🇱' => 'lippu: Alankomaat',
    '🇳🇴' => 'lippu: Norja',
    '🇳🇵' => 'lippu: Nepal',
    '🇳🇷' => 'lippu: Nauru',
    '🇳🇺' => 'lippu: Niue',
    '🇳🇿' => 'lippu: Uusi-Seelanti',
    '🇴🇲' => 'lippu: Oman',
    '🇵🇦' => 'lippu: Panama',
    '🇵🇪' => 'lippu: Peru',
    '🇵🇫' => 'lippu: Ranskan Polynesia',
    '🇵🇬' => 'lippu: Papua-Uusi-Guinea',
    '🇵🇭' => 'lippu: Filippiinit',
    '🇵🇰' => 'lippu: Pakistan',
    '🇵🇱' => 'lippu: Puola',
    '🇵🇲' => 'lippu: Saint-Pierre ja Miquelon',
    '🇵🇳' => 'lippu: Pitcairn',
    '🇵🇷' => 'lippu: Puerto Rico',
    '🇵🇸' => 'lippu: Palestiinalaisalue',
    '🇵🇹' => 'lippu: Portugali',
    '🇵🇼' => 'lippu: Palau',
    '🇵🇾' => 'lippu: Paraguay',
    '🇶🇦' => 'lippu: Qatar',
    '🇷🇪' => 'lippu: Réunion',
    '🇷🇴' => 'lippu: Romania',
    '🇷🇸' => 'lippu: Serbia',
    '🇷🇺' => 'lippu: Venäjä',
    '🇷🇼' => 'lippu: Ruanda',
    '🇸🇦' => 'lippu: Saudi-Arabia',
    '🇸🇧' => 'lippu: Salomonsaaret',
    '🇸🇨' => 'lippu: Seychellit',
    '🇸🇩' => 'lippu: Sudan',
    '🇸🇪' => 'lippu: Ruotsi',
    '🇸🇬' => 'lippu: Singapore',
    '🇸🇭' => 'lippu: Saint Helena',
    '🇸🇮' => 'lippu: Slovenia',
    '🇸🇯' => 'lippu: Huippuvuoret ja Jan Mayen',
    '🇸🇰' => 'lippu: Slovakia',
    '🇸🇱' => 'lippu: Sierra Leone',
    '🇸🇲' => 'lippu: San Marino',
    '🇸🇳' => 'lippu: Senegal',
    '🇸🇴' => 'lippu: Somalia',
    '🇸🇷' => 'lippu: Suriname',
    '🇸🇸' => 'lippu: Etelä-Sudan',
    '🇸🇹' => 'lippu: São Tomé ja Príncipe',
    '🇸🇻' => 'lippu: El Salvador',
    '🇸🇽' => 'lippu: Sint Maarten',
    '🇸🇾' => 'lippu: Syyria',
    '🇸🇿' => 'lippu: Eswatini',
    '🇹🇦' => 'lippu: Tristan da Cunha',
    '🇹🇨' => 'lippu: Turks- ja Caicossaaret',
    '🇹🇩' => 'lippu: Tšad',
    '🇹🇫' => 'lippu: Ranskan eteläiset ja antarktiset alueet',
    '🇹🇬' => 'lippu: Togo',
    '🇹🇭' => 'lippu: Thaimaa',
    '🇹🇯' => 'lippu: Tadžikistan',
    '🇹🇰' => 'lippu: Tokelau',
    '🇹🇱' => 'lippu: Itä-Timor',
    '🇹🇲' => 'lippu: Turkmenistan',
    '🇹🇳' => 'lippu: Tunisia',
    '🇹🇴' => 'lippu: Tonga',
    '🇹🇷' => 'lippu: Turkki',
    '🇹🇹' => 'lippu: Trinidad ja Tobago',
    '🇹🇻' => 'lippu: Tuvalu',
    '🇹🇼' => 'lippu: Taiwan',
    '🇹🇿' => 'lippu: Tansania',
    '🇺🇦' => 'lippu: Ukraina',
    '🇺🇬' => 'lippu: Uganda',
    '🇺🇲' => 'lippu: Yhdysvaltain erillissaaret',
    '🇺🇳' => 'lippu: Yhdistyneet kansakunnat',
    '🇺🇸' => 'lippu: Yhdysvallat',
    '🇺🇾' => 'lippu: Uruguay',
    '🇺🇿' => 'lippu: Uzbekistan',
    '🇻🇦' => 'lippu: Vatikaani',
    '🇻🇨' => 'lippu: Saint Vincent ja Grenadiinit',
    '🇻🇪' => 'lippu: Venezuela',
    '🇻🇬' => 'lippu: Brittiläiset Neitsytsaaret',
    '🇻🇮' => 'lippu: Yhdysvaltain Neitsytsaaret',
    '🇻🇳' => 'lippu: Vietnam',
    '🇻🇺' => 'lippu: Vanuatu',
    '🇼🇫' => 'lippu: Wallis ja Futuna',
    '🇼🇸' => 'lippu: Samoa',
    '🇽🇰' => 'lippu: Kosovo',
    '🇾🇪' => 'lippu: Jemen',
    '🇾🇹' => 'lippu: Mayotte',
    '🇿🇦' => 'lippu: Etelä-Afrikka',
    '🇿🇲' => 'lippu: Sambia',
    '🇿🇼' => 'lippu: Zimbabwe',
    '🔟' => 'näppäin: 10',
    '🏻' => 'vaalea iho',
    '🏼' => 'keskivaalea iho',
    '🏽' => 'tummanvaalea iho',
    '🏾' => 'keskitumma iho',
    '🏿' => 'tumma iho',
    '😀' => 'leveä hymy',
    '😃' => 'hymy suu auki',
    '😄' => 'hymyilevät silmät ja suu',
    '😁' => 'virnistys ja hymyilevät silmät',
    '😆' => 'hymy ja tiukasti suljetut silmät',
    '😅' => 'hymy ja kylmänhiki',
    '🤣' => 'nauraa kippurassa',
    '😂' => 'kasvot naurunkyynelissä',
    '🙂' => 'pieni hymy',
    '🙃' => 'ylösalainen naama',
    '🫠' => 'sulava naama',
    '😉' => 'silmänisku',
    '😊' => 'punastunut hymy',
    '😇' => 'hymy ja sädekehä',
    '🥰' => 'hymy ja kolme sydäntä',
    '😍' => 'hymy ja sydänsilmät',
    '🤩' => 'tähtisilmä',
    '😘' => 'lentosuukko',
    '😗' => 'pusunaama',
    '☺' => 'hymynaama',
    '😚' => 'pusunaama ja suljetut silmät',
    '😙' => 'pusunaama ja hymyilevät silmät',
    '🥲' => 'hymyilevät kasvot ja kyynel',
    '😋' => 'herkullista ruokaa nauttinut',
    '😛' => 'kieli ulkona',
    '😜' => 'kieli ulkona ja silmänisku',
    '🤪' => 'mielipuoli',
    '😝' => 'kieli ulkona ja silmät tiukasti kiinni',
    '🤑' => 'dollarisilmät ja rahasuu',
    '🤗' => 'halaava naama',
    '🤭' => 'käsi suun edessä',
    '🫢' => 'silmät pyöreinä käsi suun edessä',
    '🫣' => 'kurkistus sormien takaa',
    '🤫' => 'hyssyttelevä',
    '🤔' => 'mietteliäs',
    '🫡' => 'kunnioittava tervehdys',
    '🤐' => 'vetoketjusuu',
    '🤨' => 'kohotetut kulmakarvat',
    '😐' => 'naama peruslukemilla',
    '😑' => 'ilmeetön',
    '😶' => 'naama ilman suuta',
    '🫥' => 'katkoviivalla piirretty naama',
    '😏' => 'virnistys',
    '😒' => 'ei naurata',
    '🙄' => 'silmien pyöritys',
    '😬' => 'irvistävä',
    '🤥' => 'valehteleva',
    '🫨' => 'tärisevä',
    '😌' => 'helpottunut',
    '😔' => 'pohdiskeleva',
    '😪' => 'unelias',
    '🤤' => 'kuolaava',
    '😴' => 'nukkuva',
    '🫩' => 'silmäpussit',
    '😷' => 'naama ja hengityssuoja',
    '🤒' => 'naama ja kuumemittari',
    '🤕' => 'naama ja pääside',
    '🤢' => 'pahoinvoiva',
    '🤮' => 'oksentava',
    '🤧' => 'aivastava',
    '🥵' => 'kuumottava',
    '🥶' => 'paleleva',
    '🥴' => 'tokkurainen naama',
    '😵' => 'tajuton',
    '🤯' => 'räjähdys päässä',
    '🤠' => 'cowboy-hattu',
    '🥳' => 'juhliva',
    '🥸' => 'naamioitunut',
    '😎' => 'aurinkolasihymy',
    '🤓' => 'nörtti',
    '🧐' => 'monokkeli silmässä',
    '😕' => 'hämmentynyt',
    '🫤' => 'naama suu vinossa',
    '😟' => 'huolestunut',
    '🙁' => 'hieman surullinen',
    '☹' => 'surullinen',
    '😮' => 'yllättynyt',
    '😯' => 'järkyttynyt',
    '😲' => 'ällistynyt',
    '😳' => 'punastunut naama',
    '🫪' => 'vääristyneet kasvot',
    '🥺' => 'anova',
    '🥹' => 'kyyneliä pidättelevä naama',
    '😦' => 'surullinen ja suu auki',
    '😧' => 'ahdistunut',
    '😨' => 'pelokas',
    '😰' => 'avoin suu ja kylmänhiki',
    '😥' => 'pettynyt mutta helpottunut',
    '😢' => 'itkevä',
    '😭' => 'ääneen itkevä',
    '😱' => 'pelokas huuto',
    '😖' => 'tyrmistynyt',
    '😣' => 'kärsivä',
    '😞' => 'pettynyt',
    '😓' => 'kylmänhiki',
    '😩' => 'uupunut',
    '😫' => 'väsynyt',
    '🥱' => 'haukotteleva naama',
    '😤' => 'höyryä nenästä',
    '😡' => 'mököttävä',
    '😠' => 'vihainen',
    '🤬' => 'sensuroitu suu',
    '😈' => 'pirullinen hymy ja sarvet',
    '👿' => 'pikkupaholainen',
    '💀' => 'pääkallo',
    '☠' => 'pääkallo ja reisiluut',
    '💩' => 'kakkakasa',
    '🤡' => 'pelle',
    '👹' => 'peikko',
    '👺' => 'hiisi',
    '👻' => 'kummitus',
    '👽' => 'avaruusolio',
    '👾' => 'avaruushirviö',
    '🤖' => 'robotti',
    '😺' => 'leveästi hymyilevä kissa',
    '😸' => 'virnistävä kissa ja hymyilevät silmät',
    '😹' => 'kissa ja naurunkyyneleet',
    '😻' => 'kissa ja sydänsilmät',
    '😼' => 'vinosti hymyilevä kissa',
    '😽' => 'kissan pusunaama ja suljetut silmät',
    '🙀' => 'yllättynyt kissa',
    '😿' => 'itkevä kissa',
    '😾' => 'mököttävä kissa',
    '🙈' => 'en näe pahaa',
    '🙉' => 'en kuule pahaa',
    '🙊' => 'en puhu pahaa',
    '💌' => 'rakkauskirje',
    '💘' => 'sydän ja nuoli',
    '💝' => 'sydän ja lahjanauha',
    '💖' => 'kimaltava sydän',
    '💗' => 'kasvava sydän',
    '💓' => 'sykkivä sydän',
    '💞' => 'toisiaan kiertävät sydämet',
    '💕' => 'kaksi sydäntä',
    '💟' => 'sydänkoriste',
    '❣' => 'sydänhuutomerkki',
    '💔' => 'särkynyt sydän',
    '❤' => 'punainen sydän',
    '🩷' => 'pinkki sydän',
    '🧡' => 'oranssi sydän',
    '💛' => 'keltainen sydän',
    '💚' => 'vihreä sydän',
    '💙' => 'sininen sydän',
    '🩵' => 'vaaleansininen sydän',
    '💜' => 'violetti sydän',
    '🤎' => 'ruskea sydän',
    '🖤' => 'musta sydän',
    '🩶' => 'harmaa sydän',
    '🤍' => 'valkoinen sydän',
    '💋' => 'huulipunajälki',
    '💯' => 'sata pistettä',
    '💢' => 'viha',
    '🫯' => 'tappelupilvi',
    '💥' => 'törmäys',
    '💫' => 'pyörryttävä',
    '💦' => 'hikipisarat',
    '💨' => 'pikalähtö',
    '🕳' => 'musta aukko',
    '💬' => 'puhekupla',
    '🗨' => 'vasen puhekupla',
    '🗯' => 'oikea vihainen puhekupla',
    '💭' => 'ajatuskupla',
    '💤' => 'zzz',
    '👋' => 'käden heilautus',
    '🤚' => 'kämmenselkä koholla',
    '🖐' => 'nostettu käsi ja sormet erillään',
    '✋' => 'nostettu käsi',
    '🖖' => 'vulkanilaisten tervehdys',
    '🫱' => 'oikealle ojentuva käsi',
    '🫲' => 'vasemmalle ojentuva käsi',
    '🫳' => 'käsi kämmen alaspäin',
    '🫴' => 'käsi kämmen ylöspäin',
    '🫷' => 'vasemmalle työntävä käsi',
    '🫸' => 'oikealle työntävä käsi',
    '👌' => 'ok-sormiele',
    '🤌' => 'sormet supussa',
    '🤏' => 'nipistävä käsi',
    '✌' => 'voitonmerkki',
    '🤞' => 'sormet ristissä',
    '🫰' => 'etusormi ja peukalo ristissä',
    '🤟' => 'rakastan sinua -ele',
    '🤘' => 'sarviele',
    '🤙' => 'soita minulle',
    '👈' => 'kämmenselkä ja etusormi vasemmalle',
    '👉' => 'kämmenselkä ja etusormi oikealle',
    '👆' => 'kämmenselkä ja etusormi ylös',
    '🖕' => 'keskisormi',
    '👇' => 'kämmenselkä ja etusormi alas',
    '☝' => 'ylös osoittava etusormi',
    '🫵' => 'etusormi osoittaa katsojaa',
    '👍' => 'peukalo ylös',
    '👎' => 'peukalo alas',
    '✊' => 'nostettu nyrkki',
    '👊' => 'kohti tuleva nyrkki',
    '🤛' => 'nyrkki vasemmalle',
    '🤜' => 'nyrkki oikealle',
    '👏' => 'käsien taputus',
    '🙌' => 'nousevat kädet',
    '🫶' => 'sydänkuvio käsillä',
    '👐' => 'avoimet kädet',
    '🤲' => 'kämmenet vierekkäin',
    '🤝' => 'kädenpuristus',
    '🙏' => 'kämmenet yhdessä',
    '✍' => 'kirjoittava käsi',
    '💅' => 'kynsilakka',
    '🤳' => 'selfie',
    '💪' => 'pullistettu hauis',
    '🦾' => 'tekokäsi',
    '🦿' => 'tekojalka',
    '🦵' => 'jalka',
    '🦶' => 'jalkaterä',
    '👂' => 'korva',
    '🦻' => 'kuulolaite korvassa',
    '👃' => 'nenä',
    '🧠' => 'aivot',
    '🫀' => 'sydän',
    '🫁' => 'keuhkot',
    '🦷' => 'hammas',
    '🦴' => 'luu',
    '👀' => 'silmät',
    '👁' => 'silmä',
    '👅' => 'kieli',
    '👄' => 'suu',
    '🫦' => 'purra huulta',
    '👶' => 'vauva',
    '🧒' => 'lapsi',
    '👦' => 'poika',
    '👧' => 'tyttö',
    '🧑' => 'aikuinen',
    '👱' => 'vaaleatukkainen henkilö',
    '👨' => 'mies',
    '🧔' => 'parrakas henkilö',
    '👩' => 'nainen',
    '🧓' => 'vanhus',
    '👴' => 'vanha mies',
    '👵' => 'vanha nainen',
    '🙍' => 'surullinen henkilö',
    '🙎' => 'mököttävä henkilö',
    '🙅' => 'ei-ele',
    '🙆' => 'ok-ele',
    '💁' => 'kämmentä ylöspäin näyttävä henkilö',
    '🙋' => 'iloinen henkilö viittaa',
    '🧏' => 'kuuro henkilö',
    '🙇' => 'kumartava henkilö',
    '🤦' => 'peittää kasvot kädellä',
    '🤷' => 'olkapäitään kohauttava henkilö',
    '👮' => 'poliisi',
    '🕵' => 'etsivä',
    '💂' => 'vartija',
    '🥷' => 'ninja',
    '👷' => 'rakennustyöläinen',
    '🫅' => 'kruunua kantava henkilö',
    '🤴' => 'prinssi',
    '👸' => 'prinsessa',
    '👳' => 'turbaanipäinen henkilö',
    '👲' => 'mies ja kiinalainen hattu',
    '🧕' => 'huivipäinen nainen',
    '🤵' => 'henkilö smokissa',
    '👰' => 'huntupäinen henkilö',
    '🤰' => 'raskaana oleva nainen',
    '🫃' => 'raskaana oleva mies',
    '🫄' => 'raskaana oleva henkilö',
    '🤱' => 'imetys',
    '👼' => 'vauvaenkeli',
    '🎅' => 'joulupukki',
    '🤶' => 'joulupukin muori',
    '🦸' => 'supersankari',
    '🦹' => 'superpahis',
    '🧙' => 'velho',
    '🧚' => 'keiju',
    '🧛' => 'vampyyri',
    '🧜' => 'merenväki',
    '🧝' => 'haltia',
    '🧞' => 'henki',
    '🧟' => 'zombi',
    '🧌' => 'trolli',
    '🫈' => 'karvainen otus',
    '💆' => 'hieronta',
    '💇' => 'hiustenleikkaus',
    '🚶' => 'jalankulkija',
    '🧍' => 'seisova henkilö',
    '🧎' => 'polvistuva ihminen',
    '🏃' => 'juoksija',
    '💃' => 'tanssiva nainen',
    '🕺' => 'tanssiva mies',
    '🕴' => 'levitoiva mies puvussa',
    '👯' => 'puputytöt',
    '🧖' => 'henkilö saunassa',
    '🧗' => 'kiipeilijä',
    '🤺' => 'miekkailija',
    '🏇' => 'ratsastus',
    '⛷' => 'hiihtäjä',
    '🏂' => 'lumilautailija',
    '🏌' => 'golfaaja',
    '🏄' => 'surffaaja',
    '🚣' => 'soutaja',
    '🏊' => 'uimari',
    '⛹' => 'pallottelija',
    '🏋' => 'painonnostaja',
    '🚴' => 'pyöräilijä',
    '🚵' => 'maastopyöräilijä',
    '🤸' => 'kärrynpyörä',
    '🤼' => 'painijat',
    '🤽' => 'vesipalloilija',
    '🤾' => 'käsipalloilija',
    '🤹' => 'jongleeraaja',
    '🧘' => 'henkilö lootusasennossa',
    '🛀' => 'kylpijä',
    '🛌' => 'nukkuja',
    '👭' => 'kaksi naista käsi kädessä',
    '👫' => 'mies ja nainen käsi kädessä',
    '👬' => 'kaksi miestä käsi kädessä',
    '💏' => 'pusu',
    '💑' => 'pariskunta ja sydän',
    '🗣' => 'puhuva pää',
    '👤' => 'rintasiluetti',
    '👥' => 'kaksi rintasiluettia',
    '🫂' => 'halaus',
    '👪' => 'perhe',
    '👣' => 'jalanjäljet',
    '🫆' => 'sormenjälki',
    '🦰' => 'punatukkainen',
    '🦱' => 'kiharatukkainen',
    '🦳' => 'valkotukkainen',
    '🦲' => 'kalju',
    '🐵' => 'apinan naama',
    '🐒' => 'apina',
    '🦍' => 'gorilla',
    '🦧' => 'oranki',
    '🐶' => 'koiran naama',
    '🐕' => 'koira',
    '🦮' => 'opaskoira',
    '🐩' => 'villakoira',
    '🐺' => 'susi',
    '🦊' => 'kettu',
    '🦝' => 'pesukarhu',
    '🐱' => 'kissan naama',
    '🐈' => 'kissa',
    '🦁' => 'leijona',
    '🐯' => 'tiikerin naama',
    '🐅' => 'tiikeri',
    '🐆' => 'leopardi',
    '🐴' => 'hevosen naama',
    '🫎' => 'hirvi',
    '🫏' => 'aasi',
    '🐎' => 'hevonen',
    '🦄' => 'yksisarvinen',
    '🦓' => 'seepra',
    '🦌' => 'peura',
    '🦬' => 'biisoni',
    '🐮' => 'lehmän naama',
    '🐂' => 'härkä',
    '🐃' => 'vesipuhveli',
    '🐄' => 'lehmä',
    '🐷' => 'sian naama',
    '🐖' => 'sika',
    '🐗' => 'villisika',
    '🐽' => 'sian kärsä',
    '🐏' => 'pässi',
    '🐑' => 'lammas',
    '🐐' => 'vuohi',
    '🐪' => 'kameli',
    '🐫' => 'kaksikyttyräinen kameli',
    '🦙' => 'laama',
    '🦒' => 'kirahvi',
    '🐘' => 'elefantti',
    '🦣' => 'mammutti',
    '🦏' => 'sarvikuono',
    '🦛' => 'virtahepo',
    '🐭' => 'hiiren naama',
    '🐁' => 'hiiri',
    '🐀' => 'rotta',
    '🐹' => 'hamsteri',
    '🐰' => 'jäniksen naama',
    '🐇' => 'kani',
    '🐿' => 'maaorava',
    '🦫' => 'majava',
    '🦔' => 'siili',
    '🦇' => 'lepakko',
    '🐻' => 'karhu',
    '🐨' => 'koala',
    '🐼' => 'panda',
    '🦥' => 'laiskiainen',
    '🦦' => 'saukko',
    '🦨' => 'haisunäätä',
    '🦘' => 'kenguru',
    '🦡' => 'mäyrä',
    '🐾' => 'tassunjäljet',
    '🦃' => 'kalkkuna',
    '🐔' => 'kana',
    '🐓' => 'kukko',
    '🐣' => 'kuoriutuva tipu',
    '🐤' => 'tipu',
    '🐥' => 'tipu edestäpäin',
    '🐦' => 'lintu',
    '🐧' => 'pingviini',
    '🕊' => 'kyyhky',
    '🦅' => 'kotka',
    '🦆' => 'sorsa',
    '🦢' => 'joutsen',
    '🦉' => 'pöllö',
    '🦤' => 'dodo',
    '🪶' => 'höyhen',
    '🦩' => 'flamingo',
    '🦚' => 'riikinkukko',
    '🦜' => 'papukaija',
    '🪽' => 'siipi',
    '🪿' => 'hanhi',
    '🐸' => 'sammakko',
    '🐊' => 'krokotiili',
    '🐢' => 'kilpikonna',
    '🦎' => 'lisko',
    '🐍' => 'käärme',
    '🐲' => 'lohikäärmeen naama',
    '🐉' => 'lohikäärme',
    '🦕' => 'sauropodi',
    '🦖' => 'tyrannosaurus rex',
    '🐳' => 'suihkuttava valas',
    '🐋' => 'valas',
    '🐬' => 'delfiini',
    '🫍' => 'miekkavalas',
    '🦭' => 'hylje',
    '🐟' => 'kala',
    '🐠' => 'trooppinen kala',
    '🐡' => 'pallokala',
    '🦈' => 'hai',
    '🐙' => 'mustekala',
    '🐚' => 'kotilo',
    '🪸' => 'koralli',
    '🪼' => 'meduusa',
    '🦀' => 'rapu',
    '🦞' => 'hummeri',
    '🦐' => 'katkarapu',
    '🦑' => 'kalmari',
    '🦪' => 'osteri',
    '🐌' => 'etana',
    '🦋' => 'perhonen',
    '🐛' => 'ötökkä',
    '🐜' => 'muurahainen',
    '🐝' => 'mehiläinen',
    '🪲' => 'kuoriainen',
    '🐞' => 'leppäkerttu',
    '🦗' => 'sirkka',
    '🪳' => 'torakka',
    '🕷' => 'hämähäkki',
    '🕸' => 'hämähäkin seitti',
    '🦂' => 'skorpioni',
    '🦟' => 'hyttynen',
    '🪰' => 'kärpänen',
    '🪱' => 'mato',
    '🦠' => 'mikrobi',
    '💐' => 'kukkakimppu',
    '🌸' => 'kirsikankukka',
    '💮' => 'valkoinen kukka',
    '🪷' => 'lootus',
    '🏵' => 'ruusuke',
    '🌹' => 'ruusu',
    '🥀' => 'nuutunut kukka',
    '🌺' => 'kiinanruusu',
    '🌻' => 'auringonkukka',
    '🌼' => 'kukinta',
    '🌷' => 'tulppaani',
    '🪻' => 'hyasintti',
    '🌱' => 'taimi',
    '🪴' => 'ruukkukasvi',
    '🌲' => 'ikivihreä',
    '🌳' => 'lehtipuu',
    '🌴' => 'palmu',
    '🌵' => 'kaktus',
    '🌾' => 'riisikasvi',
    '🌿' => 'yrtti',
    '☘' => 'kolmiapila',
    '🍀' => 'neliapila',
    '🍁' => 'vaahteranlehti',
    '🍂' => 'pudonnut lehti',
    '🍃' => 'lehti tuulessa',
    '🪹' => 'tyhjä pesä',
    '🪺' => 'munia pesässä',
    '🍄' => 'sieni',
    '🪾' => 'lehdetön puu',
    '🍇' => 'viinirypäleet',
    '🍈' => 'meloni',
    '🍉' => 'vesimeloni',
    '🍊' => 'mandariini',
    '🍋' => 'sitruuna',
    '🍌' => 'banaani',
    '🍍' => 'ananas',
    '🥭' => 'mango',
    '🍎' => 'punainen omena',
    '🍏' => 'vihreä omena',
    '🍐' => 'päärynä',
    '🍑' => 'persikka',
    '🍒' => 'kirsikat',
    '🍓' => 'mansikka',
    '🫐' => 'mustikat',
    '🥝' => 'kiivi',
    '🍅' => 'tomaatti',
    '🫒' => 'oliivi',
    '🥥' => 'kookospähkinä',
    '🥑' => 'avokado',
    '🍆' => 'munakoiso',
    '🥔' => 'peruna',
    '🥕' => 'porkkana',
    '🌽' => 'maissintähkä',
    '🌶' => 'jalapeno',
    '🫑' => 'paprika',
    '🥒' => 'kurkku',
    '🥬' => 'lehtivihannes',
    '🥦' => 'parsakaali',
    '🧄' => 'valkosipuli',
    '🧅' => 'sipuli',
    '🥜' => 'maapähkinä',
    '🫘' => 'pavut',
    '🌰' => 'kastanja',
    '🫚' => 'inkivääri',
    '🫛' => 'herneenpalko',
    '🫜' => 'juures',
    '🍞' => 'leipä',
    '🥐' => 'voisarvi',
    '🥖' => 'patonki',
    '🫓' => 'rieska',
    '🥨' => 'rinkilä',
    '🥯' => 'vesirinkeli',
    '🥞' => 'letut',
    '🧇' => 'vohveli',
    '🧀' => 'juustopala',
    '🍖' => 'lihaa luineen',
    '🍗' => 'kanankoipi',
    '🥩' => 'lihanpala',
    '🥓' => 'pekoni',
    '🍔' => 'hampurilainen',
    '🍟' => 'ranskalaiset',
    '🍕' => 'pizza',
    '🌭' => 'hodari',
    '🥪' => 'voileipä',
    '🌮' => 'taco',
    '🌯' => 'burrito',
    '🫔' => 'tamal',
    '🥙' => 'täytetty pita',
    '🧆' => 'falafel',
    '🥚' => 'kananmuna',
    '🍳' => 'kokkaus',
    '🥘' => 'paellapannu',
    '🍲' => 'ruokakulho',
    '🫕' => 'fondue',
    '🥣' => 'kulho ja lusikka',
    '🥗' => 'vihreä salaatti',
    '🍿' => 'popcorn',
    '🧈' => 'voi',
    '🧂' => 'suola',
    '🥫' => 'säilyketölkki',
    '🍱' => 'bento-rasia',
    '🍘' => 'riisikakku',
    '🍙' => 'riisipallo',
    '🍚' => 'keitetty riisi',
    '🍛' => 'curry-riisi',
    '🍜' => 'höyryävä kulho',
    '🍝' => 'spagetti',
    '🍠' => 'paahdettu bataatti',
    '🍢' => 'oden',
    '🍣' => 'sushi',
    '🍤' => 'paistettu katkarapu',
    '🍥' => 'kalakakku',
    '🥮' => 'kuukakku',
    '🍡' => 'dango',
    '🥟' => 'taikinanyytti',
    '🥠' => 'onnenkeksi',
    '🥡' => 'ateriarasia',
    '🍦' => 'pehmis',
    '🍧' => 'jäähilejälkiruoka',
    '🍨' => 'jäätelö',
    '🍩' => 'donitsi',
    '🍪' => 'keksi',
    '🎂' => 'syntymäpäiväkakku',
    '🍰' => 'kakkupala',
    '🧁' => 'vuokaleivos',
    '🥧' => 'piirakka',
    '🍫' => 'suklaapatukka',
    '🍬' => 'karkki',
    '🍭' => 'tikkari',
    '🍮' => 'vanukas',
    '🍯' => 'hunaja',
    '🍼' => 'tuttipullo',
    '🥛' => 'maitolasi',
    '☕' => 'kuuma juoma',
    '🫖' => 'teepannu',
    '🍵' => 'korvaton teekuppi',
    '🍶' => 'sake',
    '🍾' => 'pullo ja korkin poksautus',
    '🍷' => 'viinilasi',
    '🍸' => 'cocktaillasi',
    '🍹' => 'trooppinen drinkki',
    '🍺' => 'oluttuoppi',
    '🍻' => 'kilisevät oluttuopit',
    '🥂' => 'kilisevät lasit',
    '🥃' => 'juomalasi',
    '🫗' => 'nesteen kaataminen',
    '🥤' => 'lasi ja pilli',
    '🧋' => 'kuplatee',
    '🧃' => 'juomatetra',
    '🧉' => 'mate',
    '🧊' => 'jääkuutio',
    '🥢' => 'syömäpuikot',
    '🍽' => 'haarukka, veitsi ja lautanen',
    '🍴' => 'haarukka ja veitsi',
    '🥄' => 'lusikka',
    '🔪' => 'keittiöveitsi',
    '🫙' => 'purkki',
    '🏺' => 'amfora',
    '🌍' => 'maapallo jossa näkyy Eurooppa ja Afrikka',
    '🌎' => 'maapallo jossa näkyy Amerikka',
    '🌏' => 'maapallo jossa näkyy Aasia ja Australia',
    '🌐' => 'maapallo jossa näkyy pituuspiirit',
    '🗺' => 'maailmankartta',
    '🗾' => 'Japanin kartta',
    '🧭' => 'kompassi',
    '🏔' => 'lumihuippuinen vuori',
    '⛰' => 'vuori',
    '🛘' => 'maanvyörymä',
    '🌋' => 'tulivuori',
    '🗻' => 'Fuji-vuori',
    '🏕' => 'telttailu',
    '🏖' => 'ranta ja aurinkovarjo',
    '🏜' => 'autiomaa',
    '🏝' => 'autiosaari',
    '🏞' => 'kansallispuisto',
    '🏟' => 'stadion',
    '🏛' => 'klassinen rakennus',
    '🏗' => 'rakennustyömaa',
    '🧱' => 'tiili',
    '🪨' => 'kivi',
    '🪵' => 'halko',
    '🛖' => 'maja',
    '🏘' => 'taloryhmä',
    '🏚' => 'autiotalo',
    '🏠' => 'talo',
    '🏡' => 'talo ja puutarha',
    '🏢' => 'toimistorakennus',
    '🏣' => 'japanilainen postitoimisto',
    '🏤' => 'postitoimisto',
    '🏥' => 'sairaala',
    '🏦' => 'pankki',
    '🏨' => 'hotelli',
    '🏩' => 'tuntihotelli',
    '🏪' => 'lähikauppa',
    '🏫' => 'koulu',
    '🏬' => 'tavaratalo',
    '🏭' => 'tehdas',
    '🏯' => 'japanilainen linna',
    '🏰' => 'linna',
    '💒' => 'häät',
    '🗼' => 'Tokyo Tower',
    '🗽' => 'Vapaudenpatsas',
    '⛪' => 'kirkko',
    '🕌' => 'moskeija',
    '🛕' => 'hindutemppeli',
    '🕍' => 'synagoga',
    '⛩' => 'shinto-temppeli',
    '🕋' => 'Kaaba',
    '⛲' => 'suihkulähde',
    '⛺' => 'teltta',
    '🌁' => 'sumuinen',
    '🌃' => 'tähtitaivas',
    '🏙' => 'kaupunkimaisema',
    '🌄' => 'auringonnousu vuorten takaa',
    '🌅' => 'auringonnousu',
    '🌆' => 'kaupunkimaisema illanhämärässä',
    '🌇' => 'auringonlasku',
    '🌉' => 'silta yöllä',
    '♨' => 'kuumat lähteet',
    '🎠' => 'karusellihevonen',
    '🛝' => 'liukumäki',
    '🎡' => 'maailmanpyörä',
    '🎢' => 'vuoristorata',
    '💈' => 'punasiniraitainen pylväs',
    '🎪' => 'sirkusteltta',
    '🚂' => 'veturi',
    '🚃' => 'junavaunu',
    '🚄' => 'pikajuna',
    '🚅' => 'luotipikajuna',
    '🚆' => 'juna',
    '🚇' => 'metro',
    '🚈' => 'kevytraidejuna',
    '🚉' => 'asema',
    '🚊' => 'raitioliikenne',
    '🚝' => 'monorail',
    '🚞' => 'rinnerata',
    '🚋' => 'raitiovaunu',
    '🚌' => 'bussi',
    '🚍' => 'saapuva bussi',
    '🚎' => 'johdinbussi',
    '🚐' => 'minibussi',
    '🚑' => 'ambulanssi',
    '🚒' => 'paloauto',
    '🚓' => 'poliisiauto',
    '🚔' => 'saapuva poliisiauto',
    '🚕' => 'taksi',
    '🚖' => 'saapuva taksi',
    '🚗' => 'auto',
    '🚘' => 'saapuva auto',
    '🚙' => 'katumaasturi',
    '🛻' => 'lava-auto',
    '🚚' => 'kuljetusauto',
    '🚛' => 'rekka-auto',
    '🚜' => 'traktori',
    '🏎' => 'kilpa-auto',
    '🏍' => 'moottoripyörä',
    '🛵' => 'skootteri',
    '🦽' => 'käsikäyttöinen pyörätuoli',
    '🦼' => 'moottoroitu pyörätuoli',
    '🛺' => 'autorikša',
    '🚲' => 'polkupyörä',
    '🛴' => 'potkulauta',
    '🛹' => 'rullalauta',
    '🛼' => 'rullaluistin',
    '🚏' => 'bussipysäkki',
    '🛣' => 'moottoritie',
    '🛤' => 'junaraide',
    '🛢' => 'öljytynnyri',
    '⛽' => 'bensapumppu',
    '🛞' => 'rengas',
    '🚨' => 'poliisiauton valo',
    '🚥' => 'vaakasuuntaiset liikennevalot',
    '🚦' => 'pystysuuntaiset liikennevalot',
    '🛑' => 'pysähtymismerkki',
    '🚧' => 'rakennustyömaan merkki',
    '⚓' => 'ankkuri',
    '🛟' => 'pelastusrengas',
    '⛵' => 'purjevene',
    '🛶' => 'kanootti',
    '🚤' => 'pikavene',
    '🛳' => 'matkustajalaiva',
    '⛴' => 'lautta',
    '🛥' => 'moottorivene',
    '🚢' => 'laiva',
    '✈' => 'lentokone',
    '🛩' => 'pienkone',
    '🛫' => 'lähtevä lentokone',
    '🛬' => 'saapuva lentokone',
    '🪂' => 'laskuvarjo',
    '💺' => 'istuin',
    '🚁' => 'helikopteri',
    '🚟' => 'riippurata',
    '🚠' => 'gondolihissi',
    '🚡' => 'köysirata',
    '🛰' => 'satelliitti',
    '🚀' => 'raketti',
    '🛸' => 'lentävä lautanen',
    '🛎' => 'soittokello',
    '🧳' => 'matkatavara',
    '⌛' => 'tiimalasi',
    '⏳' => 'valuva tiimalasi',
    '⌚' => 'kello',
    '⏰' => 'herätyskello',
    '⏱' => 'sekuntikello',
    '⏲' => 'ajastin',
    '🕰' => 'pöytäkello',
    '🕛' => 'kello kaksitoista',
    '🕧' => 'puoli yksi',
    '🕐' => 'kello yksi',
    '🕜' => 'puoli kaksi',
    '🕑' => 'kello kaksi',
    '🕝' => 'puoli kolme',
    '🕒' => 'kello kolme',
    '🕞' => 'puoli neljä',
    '🕓' => 'kello neljä',
    '🕟' => 'puoli viisi',
    '🕔' => 'kello viisi',
    '🕠' => 'puoli kuusi',
    '🕕' => 'kello kuusi',
    '🕡' => 'puoli seitsemän',
    '🕖' => 'kello seitsemän',
    '🕢' => 'puoli kahdeksan',
    '🕗' => 'kello kahdeksan',
    '🕣' => 'puoli yhdeksän',
    '🕘' => 'kello yhdeksän',
    '🕤' => 'puoli kymmenen',
    '🕙' => 'kello kymmenen',
    '🕥' => 'puoli yksitoista',
    '🕚' => 'kello yksitoista',
    '🕦' => 'puoli kaksitoista',
    '🌑' => 'uusikuu',
    '🌒' => 'kasvava kuunsirppi',
    '🌓' => 'ensimmäinen neljänneskuu',
    '🌔' => 'kasvava puolikuu',
    '🌕' => 'täysikuu',
    '🌖' => 'vähenevä puolikuu',
    '🌗' => 'viimeinen neljänneskuu',
    '🌘' => 'vähenevä kuunsirppi',
    '🌙' => 'kuunsirppi',
    '🌚' => 'uudenkuun kasvot',
    '🌛' => 'kasvava puolikuu kasvoilla',
    '🌜' => 'vähenevä puolikuu kasvoilla',
    '🌡' => 'lämpömittari',
    '☀' => 'aurinko',
    '🌝' => 'täysikuu kasvoilla',
    '🌞' => 'aurinko kasvoilla',
    '🪐' => 'rengasplaneetta',
    '⭐' => 'valkoinen tähti',
    '🌟' => 'loistava tähti',
    '🌠' => 'tähdenlento',
    '🌌' => 'linnunrata',
    '☁' => 'pilvi',
    '⛅' => 'aurinko pilvessä',
    '⛈' => 'ukkospilvi ja sade',
    '🌤' => 'aurinko ja pieni pilvi',
    '🌥' => 'aurinko ja suuri pilvi',
    '🌦' => 'aurinko sadepilvessä',
    '🌧' => 'sadepilvi',
    '🌨' => 'lumisadepilvi',
    '🌩' => 'ukkospilvi',
    '🌪' => 'hurrikaani',
    '🌫' => 'sumu',
    '🌬' => 'puhuri',
    '🌀' => 'pyörremyrsky',
    '🌈' => 'sateenkaari',
    '🌂' => 'suljettu sateenvarjo',
    '☂' => 'sateenvarjo',
    '☔' => 'sateenvarjo ja pisarat',
    '⛱' => 'aurinkovarjo',
    '⚡' => 'korkeajännite',
    '❄' => 'lumihiutale',
    '☃' => 'lumiukko',
    '⛄' => 'lumiukko ilman lunta',
    '☄' => 'komeetta',
    '🔥' => 'tuli',
    '💧' => 'pisara',
    '🌊' => 'aalto',
    '🎃' => 'kurpitsalyhty',
    '🎄' => 'joulukuusi',
    '🎆' => 'ilotulitus',
    '🎇' => 'tähtisadetikku',
    '🧨' => 'sähikäinen',
    '✨' => 'säihke',
    '🎈' => 'ilmapallo',
    '🎉' => 'paukkuserpentiini',
    '🎊' => 'konfettipallo',
    '🎋' => 'tanabatapuu',
    '🎍' => 'puukoriste',
    '🎎' => 'japanilaiset nuket',
    '🎏' => 'karppiviiri',
    '🎐' => 'tuulikello',
    '🎑' => 'kuuseremonia',
    '🧧' => 'punainen kirjekuori',
    '🎀' => 'rusetti',
    '🎁' => 'lahjapaketti',
    '🎗' => 'tietoisuusnauha',
    '🎟' => 'pääsylippu',
    '🎫' => 'lippu',
    '🎖' => 'kunniamerkki',
    '🏆' => 'pokaali',
    '🏅' => 'urheilumitali',
    '🥇' => 'kultamitali',
    '🥈' => 'hopeamitali',
    '🥉' => 'pronssimitali',
    '⚽' => 'jalkapallo',
    '⚾' => 'pesäpallo',
    '🥎' => 'softball',
    '🏀' => 'koripallo',
    '🏐' => 'lentopallo',
    '🏈' => 'amerikkalainen jalkapallo',
    '🏉' => 'rugby-pallo',
    '🎾' => 'tennis',
    '🥏' => 'liitokiekko',
    '🎳' => 'keilailu',
    '🏏' => 'kriketti',
    '🏑' => 'maahockey',
    '🏒' => 'jääkiekko ja maila',
    '🥍' => 'lacrosse',
    '🏓' => 'pingis',
    '🏸' => 'sulkapallo',
    '🥊' => 'nyrkkeilyhanska',
    '🥋' => 'kamppailulajiasu',
    '🥅' => 'maaliverkko',
    '⛳' => 'lippu reiän päällä',
    '⛸' => 'luistin',
    '🎣' => 'onkivapa',
    '🤿' => 'sukellusmaski',
    '🎽' => 'juoksupaita',
    '🎿' => 'sukset',
    '🛷' => 'kelkka',
    '🥌' => 'curling-kivi',
    '🎯' => 'napakymppi',
    '🪀' => 'jojo',
    '🪁' => 'leija',
    '🔫' => 'vesipyssy',
    '🎱' => 'biljardi',
    '🔮' => 'kristallipallo',
    '🪄' => 'taikasauva',
    '🎮' => 'videopeli',
    '🕹' => 'joystick',
    '🎰' => 'pelikone',
    '🎲' => 'noppa',
    '🧩' => 'palapeli',
    '🧸' => 'nalle',
    '🪅' => 'piñata',
    '🪩' => 'peilipallo',
    '🪆' => 'maatuskanuket',
    '♠' => 'pata',
    '♥' => 'hertta',
    '♦' => 'ruutu',
    '♣' => 'risti',
    '♟' => 'šakkipelin sotilas',
    '🃏' => 'jokeri',
    '🀄' => 'mahjong',
    '🎴' => 'kukkapelikortit',
    '🎭' => 'näyttämötaiteet',
    '🖼' => 'kuva kehyksissä',
    '🎨' => 'taiteilijan paletti',
    '🧵' => 'lankarulla',
    '🪡' => 'ompeluneula',
    '🧶' => 'lankakerä',
    '🪢' => 'solmu',
    '👓' => 'silmälasit',
    '🕶' => 'aurinkolasit',
    '🥽' => 'suojalasit',
    '🥼' => 'laboratoriotakki',
    '🦺' => 'turvaliivi',
    '👔' => 'solmio',
    '👕' => 't-paita',
    '👖' => 'farkut',
    '🧣' => 'huivi',
    '🧤' => 'hansikkaat',
    '🧥' => 'takki',
    '🧦' => 'sukat',
    '👗' => 'mekko',
    '👘' => 'kimono',
    '🥻' => 'sari',
    '🩱' => 'uimapuku',
    '🩲' => 'uimahousut',
    '🩳' => 'uimashortsit',
    '👙' => 'bikinit',
    '👚' => 'naistenvaatteet',
    '🪭' => 'taittuva käsiviuhka',
    '👛' => 'rahakukkaro',
    '👜' => 'käsilaukku',
    '👝' => 'kirjekuorilaukku',
    '🛍' => 'ostoskassit',
    '🎒' => 'koulureppu',
    '🩴' => 'varvassandaali',
    '👞' => 'miehen kenkä',
    '👟' => 'juoksukenkä',
    '🥾' => 'vaelluskenkä',
    '🥿' => 'balleriina',
    '👠' => 'korkokenkä',
    '👡' => 'naisen sandaali',
    '🩰' => 'balettitossut',
    '👢' => 'naisen saapas',
    '🪮' => 'selvityskampa',
    '👑' => 'kruunu',
    '👒' => 'naisen hattu',
    '🎩' => 'silinteri',
    '🎓' => 'valmistujaislakki',
    '🧢' => 'lippalakki',
    '🪖' => 'sotilaskypärä',
    '⛑' => 'kypärä, jossa valkoinen risti',
    '📿' => 'rukoushelmet',
    '💄' => 'huulipuna',
    '💍' => 'sormus',
    '💎' => 'jalokivi',
    '🔇' => 'mykistetty kaiutin',
    '🔈' => 'hiljainen kaiutin',
    '🔉' => 'kaiutin normaalilla äänenvoimakkuudella',
    '🔊' => 'äänekäs kaiutin',
    '📢' => 'kovaääninen',
    '📣' => 'megafoni',
    '📯' => 'postitorvi',
    '🔔' => 'kirkonkello',
    '🔕' => 'mykistetty kello',
    '🎼' => 'nuottiviivasto',
    '🎵' => 'nuotti',
    '🎶' => 'nuotteja',
    '🎙' => 'studiomikrofoni',
    '🎚' => 'liukusäädin',
    '🎛' => 'säätimet',
    '🎤' => 'mikrofoni',
    '🎧' => 'kuuloke',
    '📻' => 'radio',
    '🎷' => 'saksofoni',
    '🎺' => 'trumpetti',
    '🪊' => 'pasuuna',
    '🪗' => 'harmonikka',
    '🎸' => 'kitara',
    '🎹' => 'koskettimet',
    '🎻' => 'viulu',
    '🪕' => 'banjo',
    '🥁' => 'rumpu',
    '🪘' => 'congarumpu',
    '🪇' => 'marakassit',
    '🪈' => 'huilu',
    '🪉' => 'harppu',
    '📱' => 'kännykkä',
    '📲' => 'kännykkä ja nuoli',
    '☎' => 'puhelin',
    '📞' => 'luuri',
    '📟' => 'hakulaite',
    '📠' => 'faksi',
    '🔋' => 'akku',
    '🪫' => 'akku vähissä',
    '🔌' => 'pistoke',
    '💻' => 'kannettava tietokone',
    '🖥' => 'pöytäkone',
    '🖨' => 'tulostin',
    '⌨' => 'näppäimistö',
    '🖱' => 'tietokoneen hiiri',
    '🖲' => 'ohjauspallo',
    '💽' => 'minidisk',
    '💾' => 'disketti',
    '💿' => 'CD',
    '📀' => 'DVD',
    '🧮' => 'helmitaulu',
    '🎥' => 'elokuvakamera',
    '🎞' => 'filminauha',
    '📽' => 'elokuvaprojektori',
    '🎬' => 'klaffitaulu',
    '📺' => 'televisio',
    '📷' => 'kamera',
    '📸' => 'kamera ja salama',
    '📹' => 'videokamera',
    '📼' => 'videokasetti',
    '🔍' => 'suurennuslasi vasemmalle',
    '🔎' => 'suurennuslasi oikealle',
    '🕯' => 'kynttilä',
    '💡' => 'hehkulamppu',
    '🔦' => 'taskulamppu',
    '🏮' => 'punainen paperilyhty',
    '🪔' => 'savilamppu',
    '📔' => 'koristeellinen muistikirja',
    '📕' => 'suljettu kirja',
    '📖' => 'avoin kirja',
    '📗' => 'vihreä kirja',
    '📘' => 'sininen kirja',
    '📙' => 'oranssi kirja',
    '📚' => 'kirjoja',
    '📓' => 'muistikirja',
    '📒' => 'tilikirja',
    '📃' => 'käännetty sivu',
    '📜' => 'kirjakäärö',
    '📄' => 'sivu',
    '📰' => 'sanomalehti',
    '🗞' => 'sanomalehti rullalla',
    '📑' => 'kirjanmerkkivälilehdet',
    '🔖' => 'kirjanmerkki',
    '🏷' => 'lappu',
    '🪙' => 'kolikko',
    '💰' => 'rahasäkki',
    '🪎' => 'aarrearkku',
    '💴' => 'yen-seteli',
    '💵' => 'dollariseteli',
    '💶' => 'euroseteli',
    '💷' => 'puntaseteli',
    '💸' => 'rahalla on siivet',
    '💳' => 'luottokortti',
    '🧾' => 'kuitti',
    '💹' => 'yen ja nouseva käyrä',
    '✉' => 'kirjekuori',
    '📧' => 'sähköposti',
    '📨' => 'saapuva kirjekuori',
    '📩' => 'kirjekuori ja nuoli',
    '📤' => 'lähtevät',
    '📥' => 'saapuvat',
    '📦' => 'paketti',
    '📫' => 'suljettu postilaatikko, lippu ylhäällä',
    '📪' => 'suljettu postilaatikko, lippu alhaalla',
    '📬' => 'avoin postilaatikko, lippu ylhäällä',
    '📭' => 'avoin postilaatikko, lippu alhaalla',
    '📮' => 'postilaatikko',
    '🗳' => 'ääniuurna',
    '✏' => 'lyijykynä',
    '✒' => 'musta kynänkärki',
    '🖋' => 'täytekynä',
    '🖊' => 'kuulakärkikynä',
    '🖌' => 'sivellin',
    '🖍' => 'väriliitu',
    '📝' => 'muistio',
    '💼' => 'salkku',
    '📁' => 'tiedostokansio',
    '📂' => 'avoin tiedostokansio',
    '🗂' => 'kortiston välilehdet',
    '📅' => 'kalenteri',
    '📆' => 'päiväkalenteri',
    '🗒' => 'kierrelehtiö',
    '🗓' => 'kierrekalenteri',
    '📇' => 'kortisto',
    '📈' => 'nouseva käyrä',
    '📉' => 'laskeva käyrä',
    '📊' => 'pylväskaavio',
    '📋' => 'leikepöytä',
    '📌' => 'nuppineula',
    '📍' => 'pyöreä nasta',
    '📎' => 'paperiliitin',
    '🖇' => 'klemmarit yhdessä',
    '📏' => 'viivoitin',
    '📐' => 'kolmioviivain',
    '✂' => 'sakset',
    '🗃' => 'arkistolaatikko',
    '🗄' => 'arkistokaappi',
    '🗑' => 'roskakori',
    '🔒' => 'lukko',
    '🔓' => 'lukko auki',
    '🔏' => 'lukko ja kynä',
    '🔐' => 'avain ja lukko kiinni',
    '🔑' => 'avain',
    '🗝' => 'vanha avain',
    '🔨' => 'vasara',
    '🪓' => 'kirves',
    '⛏' => 'hakku',
    '⚒' => 'hakku ja vasara',
    '🛠' => 'jakoavain ja vasara',
    '🗡' => 'tikari',
    '⚔' => 'miekat ristissä',
    '💣' => 'pommi',
    '🪃' => 'bumerangi',
    '🏹' => 'jousi ja nuoli',
    '🛡' => 'kilpi',
    '🪚' => 'käsisaha',
    '🔧' => 'jakoavain',
    '🪛' => 'ruuvimeisseli',
    '🔩' => 'ruuvi ja mutteri',
    '⚙' => 'hammasratas',
    '🗜' => 'ruuvipuristin',
    '⚖' => 'vaaka',
    '🦯' => 'valkoinen keppi',
    '🔗' => 'lenkki',
    '⛓' => 'ketjut',
    '🪝' => 'koukku',
    '🧰' => 'työkalulaatikko',
    '🧲' => 'magneetti',
    '🪜' => 'tikkaat',
    '🪏' => 'lapio',
    '⚗' => 'tislauskolvi',
    '🧪' => 'koeputki',
    '🧫' => 'petrimalja',
    '🧬' => 'dna',
    '🔬' => 'mikroskooppi',
    '🔭' => 'kaukoputki',
    '📡' => 'lautasantenni',
    '💉' => 'ruisku',
    '🩸' => 'veripisara',
    '💊' => 'pilleri',
    '🩹' => 'laastari',
    '🩼' => 'kainalosauva',
    '🩺' => 'stetoskooppi',
    '🩻' => 'röntgen',
    '🚪' => 'ovi',
    '🛗' => 'hissi',
    '🪞' => 'peili',
    '🪟' => 'ikkuna',
    '🛏' => 'sänky',
    '🛋' => 'sohva ja lamppu',
    '🪑' => 'tuoli',
    '🚽' => 'vessanpönttö',
    '🪠' => 'viemäripumppu',
    '🚿' => 'suihku',
    '🛁' => 'kylpyamme',
    '🪤' => 'hiirenloukku',
    '🪒' => 'partaveitsi',
    '🧴' => 'hoitoainepullo',
    '🧷' => 'hakaneula',
    '🧹' => 'luuta',
    '🧺' => 'kori',
    '🧻' => 'paperirulla',
    '🪣' => 'ämpäri',
    '🧼' => 'saippua',
    '🫧' => 'kuplat',
    '🪥' => 'hammasharja',
    '🧽' => 'pesusieni',
    '🧯' => 'sammutin',
    '🛒' => 'ostoskärryt',
    '🚬' => 'savuke',
    '⚰' => 'arkku',
    '🪦' => 'hautakivi',
    '⚱' => 'tuhkauurna',
    '🧿' => 'nazar-amuletti',
    '🪬' => 'hamsa',
    '🗿' => 'moai',
    '🪧' => 'kyltti',
    '🪪' => 'henkilökortti',
    '🏧' => 'pankkiautomaatti',
    '🚮' => 'roskat-merkki',
    '🚰' => 'juomakelpoista vettä',
    '♿' => 'pyörätuoli',
    '🚹' => 'miesten wc',
    '🚺' => 'naisten wc',
    '🚻' => 'wc',
    '🚼' => 'vauva-merkki',
    '🚾' => 'vessa',
    '🛂' => 'passintarkastus',
    '🛃' => 'tulli',
    '🛄' => 'matkatavarat',
    '🛅' => 'säilytyslokero',
    '⚠' => 'varoitus',
    '🚸' => 'lapsia liikenteessä',
    '⛔' => 'kielletty ajosuunta',
    '🚫' => 'pääsy kielletty',
    '🚳' => 'polkupyörällä ajo kielletty',
    '🚭' => 'tupakointi kielletty',
    '🚯' => 'roskaaminen kielletty',
    '🚱' => 'vesi ei juomakelpoista',
    '🚷' => 'jalankulku kielletty',
    '📵' => 'ei matkapuhelimia',
    '🔞' => 'kielletty alaikäisiltä',
    '☢' => 'säteilyvaara',
    '☣' => 'biologinen vaara',
    '⬆' => 'nuoli ylös',
    '↗' => 'nuoli yläoikealle',
    '➡' => 'nuoli oikealle',
    '↘' => 'nuoli alaoikealle',
    '⬇' => 'nuoli alas',
    '↙' => 'nuoli alavasemmalle',
    '⬅' => 'nuoli vasemmalle',
    '↖' => 'nuoli ylävasemmalle',
    '↕' => 'nuoli ylös ja alas',
    '↔' => 'nuoli oikealle ja vasemmalle',
    '↩' => 'vasemmalle kääntyvä nuoli',
    '↪' => 'oikealle kääntyvä nuoli',
    '⤴' => 'ylös kääntyvä nuoli',
    '⤵' => 'alas kääntyvä nuoli',
    '🔃' => 'pystynuolet myötäpäivään',
    '🔄' => 'nuolet vastapäivään',
    '🔙' => 'BACK-nuoli',
    '🔚' => 'END-nuoli',
    '🔛' => 'ON!-nuoli',
    '🔜' => 'SOON-nuoli',
    '🔝' => 'TOP-nuoli',
    '🛐' => 'pyhä rakennus',
    '⚛' => 'atomi',
    '🕉' => 'om-tavu',
    '✡' => 'Daavidin tähti',
    '☸' => 'dharma-pyörä',
    '☯' => 'jin ja jang',
    '✝' => 'latinalainen risti',
    '☦' => 'ortodoksiristi',
    '☪' => 'kuunsirppi ja tähti',
    '☮' => 'rauhansymboli',
    '🕎' => 'menora',
    '🔯' => 'kuusisakarainen tähti pisteellä',
    '🪯' => 'khanda',
    '♈' => 'oinas-merkki',
    '♉' => 'härkä-merkki',
    '♊' => 'kaksonen-merkki',
    '♋' => 'rapu-merkki',
    '♌' => 'leijona-merkki',
    '♍' => 'neitsyt-merkki',
    '♎' => 'vaaka-merkki',
    '♏' => 'skorpioni-merkki',
    '♐' => 'jousimies-merkki',
    '♑' => 'kauris-merkki',
    '♒' => 'vesimies-merkki',
    '♓' => 'kalat-merkki',
    '⛎' => 'käärmeenkantaja',
    '🔀' => 'sekoitus',
    '🔁' => 'toista uudelleen',
    '🔂' => 'toista kerran',
    '▶' => 'toista',
    '⏩' => 'kelaa eteenpäin',
    '⏭' => 'seuraava kappale',
    '⏯' => 'toista/pysäytä',
    '◀' => 'kelaa hitaasti taakse',
    '⏪' => 'kelaa taaksepäin',
    '⏮' => 'edellinen kappale',
    '🔼' => 'ylös',
    '⏫' => 'nopeasti ylös',
    '🔽' => 'alas',
    '⏬' => 'nopeasti alas',
    '⏸' => 'pysäytä',
    '⏹' => 'lopeta',
    '⏺' => 'tallenna',
    '⏏' => 'poista',
    '🎦' => 'videokuva',
    '🔅' => 'himmennä',
    '🔆' => 'kirkasta',
    '📶' => 'kuuluvuuspalkit',
    '🛜' => 'langaton',
    '📳' => 'värinätila',
    '📴' => 'matkapuhelin suljettava',
    '♀' => 'Venus-symboli',
    '♂' => 'Mars-symboli',
    '⚧' => 'transsymboli',
    '✖' => 'kertomerkki',
    '➕' => 'plusmerkki',
    '➖' => 'miinusmerkki',
    '➗' => 'jakomerkki',
    '🟰' => 'paksu yhtäsuuruusmerkki',
    '♾' => 'äärettömyys',
    '‼' => 'kaksoishuutomerkki',
    '⁉' => 'huuto-kysymysmerkki',
    '❓' => 'kysymysmerkki',
    '❔' => 'valkoinen kysymysmerkki',
    '❕' => 'valkoinen huutomerkki',
    '❗' => 'huutomerkki',
    '〰' => 'aaltoviiva',
    '💱' => 'valuutanvaihto',
    '💲' => 'paksu dollarimerkki',
    '⚕' => 'lääketieteen symboli',
    '♻' => 'kierrätyssymboli',
    '⚜' => 'Ranskan lilja',
    '🔱' => 'kolmikärki',
    '📛' => 'nimikyltti',
    '🔰' => 'japanilainen symboli aloittelijalle',
    '⭕' => 'suuri ympyrä',
    '✅' => 'valkoinen valintamerkki',
    '☑' => 'punainen valintamerkki',
    '✔' => 'paksu valintamerkki',
    '❌' => 'punainen rastimerkki',
    '❎' => 'rastimerkki',
    '➰' => 'silmukka',
    '➿' => 'kaksoissilmukka',
    '〽' => 'osanvaihtomerkki',
    '✳' => 'kahdeksanpiikkinen tähtimerkki',
    '✴' => 'kahdeksankärkinen tähti',
    '❇' => 'kipinä',
    '™' => 'tavaramerkki',
    '🫟' => 'roiske',
    '🔠' => 'syötä isoja kirjaimia',
    '🔡' => 'syötä pieniä kirjaimia',
    '🔢' => 'syötä numeroja',
    '🔣' => 'syötä merkkejä',
    '🔤' => 'syötä kirjaimia',
    '🅰' => 'A-veriryhmä',
    '🆎' => 'AB-veriryhmä',
    '🅱' => 'B-veriryhmä',
    '🆑' => 'pyyhi-näppäin',
    '🆒' => 'COOL',
    '🆓' => 'FREE',
    'ℹ' => 'info',
    '🆔' => 'ID',
    'Ⓜ' => 'm ympyrässä',
    '🆕' => 'NEW',
    '🆖' => 'NG',
    '🅾' => 'O-veriryhmä',
    '🆗' => 'OK',
    '🅿' => 'P',
    '🆘' => 'SOS',
    '🆙' => 'UP!',
    '🆚' => 'VS',
    '🈁' => 'täällä-kirjainmerkki',
    '🈂' => 'palvelumaksu-kirjainmerkki',
    '🈷' => 'kuukausittainen määrä -kirjainmerkki',
    '🈶' => 'maksullinen-kirjainmerkki',
    '🈯' => 'varattu-kirjainmerkki',
    '🉐' => 'hyvä ostos -kirjainmerkki',
    '🈹' => 'alennus-kirjoitusmerkki',
    '🈚' => 'maksuton-kirjainmerkki',
    '🈲' => 'kielletty-kirjoitusmerkki',
    '🉑' => 'hyväksyttävä-kirjoitusmerkki',
    '🈸' => 'hakemus-kirjoitusmerkki',
    '🈴' => 'hyväksytty arvosana -kirjoitusmerkki',
    '🈳' => 'tyhjä-kirjoitusmerkki',
    '㊗' => 'onnittelut-kirjoitusmerkki',
    '㊙' => 'salainen-kirjoitusmerkki',
    '🈺' => 'avoinna-kirjoitusmerkki',
    '🈵' => 'täynnä-kirjoitusmerkki',
    '🔴' => 'punainen ympyrä',
    '🟠' => 'oranssi ympyrä',
    '🟡' => 'keltainen ympyrä',
    '🟢' => 'vihreä ympyrä',
    '🔵' => 'sininen ympyrä',
    '🟣' => 'violetti ympyrä',
    '🟤' => 'ruskea ympyrä',
    '⚫' => 'musta ympyrä',
    '⚪' => 'valkoinen ympyrä',
    '🟥' => 'punainen neliö',
    '🟧' => 'oranssi neliö',
    '🟨' => 'keltainen neliö',
    '🟩' => 'vihreä neliö',
    '🟦' => 'sininen neliö',
    '🟪' => 'violetti neliö',
    '🟫' => 'ruskea neliö',
    '⬛' => 'iso musta neliö',
    '⬜' => 'iso valkoinen neliö',
    '◼' => 'keskikokoinen musta neliö',
    '◻' => 'keskikokoinen valkoinen neliö',
    '◾' => 'pienehkö musta neliö',
    '◽' => 'pienehkö valkoinen neliö',
    '▪' => 'pieni musta neliö',
    '▫' => 'pieni valkoinen neliö',
    '🔶' => 'iso oranssi vinoneliö',
    '🔷' => 'iso sininen vinoneliö',
    '🔸' => 'pieni oranssi vinoneliö',
    '🔹' => 'pieni sininen vinoneliö',
    '🔺' => 'punainen kolmio kärki ylös',
    '🔻' => 'punainen kolmio kärki alas',
    '💠' => 'vinoneliö/kukka',
    '🔘' => 'valintanappi',
    '🔳' => 'valkoinen neliöruutu',
    '🔲' => 'musta neliöruutu',
    '🏁' => 'ruutulippu',
    '🚩' => 'kolmiolippu',
    '🎌' => 'liput ristissä',
    '🏴' => 'musta lippu',
    '🏳' => 'valkoinen lippu',
];
