<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'נשיקה: אדם, אדם, גוון עור בהיר, גוון עור בהיר בינוני',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'נשיקה: אדם, אדם, גוון עור בהיר, גוון עור בינוני',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'נשיקה: אדם, אדם, גוון עור בהיר, גוון עור כהה בינוני',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'נשיקה: אדם, אדם, גוון עור בהיר, גוון עור כהה',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'נשיקה: אדם, אדם, גוון עור בהיר בינוני, גוון עור בהיר',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'נשיקה: אדם, אדם, גוון עור בהיר בינוני, גוון עור בינוני',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'נשיקה: אדם, אדם, גוון עור בהיר בינוני, גוון עור כהה בינוני',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'נשיקה: אדם, אדם, גוון עור בהיר בינוני, גוון עור כהה',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'נשיקה: אדם, אדם, גוון עור בינוני, גוון עור בהיר',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'נשיקה: אדם, אדם, גוון עור בינוני, גוון עור בהיר בינוני',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'נשיקה: אדם, אדם, גוון עור בינוני, גוון עור כהה בינוני',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'נשיקה: אדם, אדם, גוון עור בינוני, גוון עור כהה',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'נשיקה: אדם, אדם, גוון עור כהה בינוני, גוון עור בהיר',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'נשיקה: אדם, אדם, גוון עור כהה בינוני, גוון עור בהיר בינוני',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'נשיקה: אדם, אדם, גוון עור כהה בינוני, גוון עור בינוני',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'נשיקה: אדם, אדם, גוון עור כהה בינוני, גוון עור כהה',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'נשיקה: אדם, אדם, גוון עור כהה, גוון עור בהיר',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'נשיקה: אדם, אדם, גוון עור כהה, גוון עור בהיר בינוני',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'נשיקה: אדם, אדם, גוון עור כהה, גוון עור בינוני',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'נשיקה: אדם, אדם, גוון עור כהה, גוון עור כהה בינוני',
    '👨🏻‍❤‍💋‍👨🏻' => 'נשיקה: איש, איש, גוון עור בהיר',
    '👨🏻‍❤‍💋‍👨🏼' => 'נשיקה: איש, איש, גוון עור בהיר, גוון עור בהיר בינוני',
    '👨🏻‍❤‍💋‍👨🏽' => 'נשיקה: איש, איש, גוון עור בהיר, גוון עור בינוני',
    '👨🏻‍❤‍💋‍👨🏾' => 'נשיקה: איש, איש, גוון עור בהיר, גוון עור כהה בינוני',
    '👨🏻‍❤‍💋‍👨🏿' => 'נשיקה: איש, איש, גוון עור בהיר, גוון עור כהה',
    '👨🏼‍❤‍💋‍👨🏻' => 'נשיקה: איש, איש, גוון עור בהיר בינוני, גוון עור בהיר',
    '👨🏼‍❤‍💋‍👨🏼' => 'נשיקה: איש, איש, גוון עור בהיר בינוני',
    '👨🏼‍❤‍💋‍👨🏽' => 'נשיקה: איש, איש, גוון עור בהיר בינוני, גוון עור בינוני',
    '👨🏼‍❤‍💋‍👨🏾' => 'נשיקה: איש, איש, גוון עור בהיר בינוני, גוון עור כהה בינוני',
    '👨🏼‍❤‍💋‍👨🏿' => 'נשיקה: איש, איש, גוון עור בהיר בינוני, גוון עור כהה',
    '👨🏽‍❤‍💋‍👨🏻' => 'נשיקה: איש, איש, גוון עור בינוני, גוון עור בהיר',
    '👨🏽‍❤‍💋‍👨🏼' => 'נשיקה: איש, איש, גוון עור בינוני, גוון עור בהיר בינוני',
    '👨🏽‍❤‍💋‍👨🏽' => 'נשיקה: איש, איש, גוון עור בינוני',
    '👨🏽‍❤‍💋‍👨🏾' => 'נשיקה: איש, איש, גוון עור בינוני, גוון עור כהה בינוני',
    '👨🏽‍❤‍💋‍👨🏿' => 'נשיקה: איש, איש, גוון עור בינוני, גוון עור כהה',
    '👨🏾‍❤‍💋‍👨🏻' => 'נשיקה: איש, איש, גוון עור כהה בינוני, גוון עור בהיר',
    '👨🏾‍❤‍💋‍👨🏼' => 'נשיקה: איש, איש, גוון עור כהה בינוני, גוון עור בהיר בינוני',
    '👨🏾‍❤‍💋‍👨🏽' => 'נשיקה: איש, איש, גוון עור כהה בינוני, גוון עור בינוני',
    '👨🏾‍❤‍💋‍👨🏾' => 'נשיקה: איש, איש, גוון עור כהה בינוני',
    '👨🏾‍❤‍💋‍👨🏿' => 'נשיקה: איש, איש, גוון עור כהה בינוני, גוון עור כהה',
    '👨🏿‍❤‍💋‍👨🏻' => 'נשיקה: איש, איש, גוון עור כהה, גוון עור בהיר',
    '👨🏿‍❤‍💋‍👨🏼' => 'נשיקה: איש, איש, גוון עור כהה, גוון עור בהיר בינוני',
    '👨🏿‍❤‍💋‍👨🏽' => 'נשיקה: איש, איש, גוון עור כהה, גוון עור בינוני',
    '👨🏿‍❤‍💋‍👨🏾' => 'נשיקה: איש, איש, גוון עור כהה, גוון עור כהה בינוני',
    '👨🏿‍❤‍💋‍👨🏿' => 'נשיקה: איש, איש, גוון עור כהה',
    '👩🏻‍❤‍💋‍👨🏻' => 'נשיקה: אישה, איש, גוון עור בהיר',
    '👩🏻‍❤‍💋‍👨🏼' => 'נשיקה: אישה, איש, גוון עור בהיר, גוון עור בהיר בינוני',
    '👩🏻‍❤‍💋‍👨🏽' => 'נשיקה: אישה, איש, גוון עור בהיר, גוון עור בינוני',
    '👩🏻‍❤‍💋‍👨🏾' => 'נשיקה: אישה, איש, גוון עור בהיר, גוון עור כהה בינוני',
    '👩🏻‍❤‍💋‍👨🏿' => 'נשיקה: אישה, איש, גוון עור בהיר, גוון עור כהה',
    '👩🏼‍❤‍💋‍👨🏻' => 'נשיקה: אישה, איש, גוון עור בהיר בינוני, גוון עור בהיר',
    '👩🏼‍❤‍💋‍👨🏼' => 'נשיקה: אישה, איש, גוון עור בהיר בינוני',
    '👩🏼‍❤‍💋‍👨🏽' => 'נשיקה: אישה, איש, גוון עור בהיר בינוני, גוון עור בינוני',
    '👩🏼‍❤‍💋‍👨🏾' => 'נשיקה: אישה, איש, גוון עור בהיר בינוני, גוון עור כהה בינוני',
    '👩🏼‍❤‍💋‍👨🏿' => 'נשיקה: אישה, איש, גוון עור בהיר בינוני, גוון עור כהה',
    '👩🏽‍❤‍💋‍👨🏻' => 'נשיקה: אישה, איש, גוון עור בינוני, גוון עור בהיר',
    '👩🏽‍❤‍💋‍👨🏼' => 'נשיקה: אישה, איש, גוון עור בינוני, גוון עור בהיר בינוני',
    '👩🏽‍❤‍💋‍👨🏽' => 'נשיקה: אישה, איש, גוון עור בינוני',
    '👩🏽‍❤‍💋‍👨🏾' => 'נשיקה: אישה, איש, גוון עור בינוני, גוון עור כהה בינוני',
    '👩🏽‍❤‍💋‍👨🏿' => 'נשיקה: אישה, איש, גוון עור בינוני, גוון עור כהה',
    '👩🏾‍❤‍💋‍👨🏻' => 'נשיקה: אישה, איש, גוון עור כהה בינוני, גוון עור בהיר',
    '👩🏾‍❤‍💋‍👨🏼' => 'נשיקה: אישה, איש, גוון עור כהה בינוני, גוון עור בהיר בינוני',
    '👩🏾‍❤‍💋‍👨🏽' => 'נשיקה: אישה, איש, גוון עור כהה בינוני, גוון עור בינוני',
    '👩🏾‍❤‍💋‍👨🏾' => 'נשיקה: אישה, איש, גוון עור כהה בינוני',
    '👩🏾‍❤‍💋‍👨🏿' => 'נשיקה: אישה, איש, גוון עור כהה בינוני, גוון עור כהה',
    '👩🏿‍❤‍💋‍👨🏻' => 'נשיקה: אישה, איש, גוון עור כהה, גוון עור בהיר',
    '👩🏿‍❤‍💋‍👨🏼' => 'נשיקה: אישה, איש, גוון עור כהה, גוון עור בהיר בינוני',
    '👩🏿‍❤‍💋‍👨🏽' => 'נשיקה: אישה, איש, גוון עור כהה, גוון עור בינוני',
    '👩🏿‍❤‍💋‍👨🏾' => 'נשיקה: אישה, איש, גוון עור כהה, גוון עור כהה בינוני',
    '👩🏿‍❤‍💋‍👨🏿' => 'נשיקה: אישה, איש, גוון עור כהה',
    '👩🏻‍❤‍💋‍👩🏻' => 'נשיקה: אישה, אישה, גוון עור בהיר',
    '👩🏻‍❤‍💋‍👩🏼' => 'נשיקה: אישה, אישה, גוון עור בהיר, גוון עור בהיר בינוני',
    '👩🏻‍❤‍💋‍👩🏽' => 'נשיקה: אישה, אישה, גוון עור בהיר, גוון עור בינוני',
    '👩🏻‍❤‍💋‍👩🏾' => 'נשיקה: אישה, אישה, גוון עור בהיר, גוון עור כהה בינוני',
    '👩🏻‍❤‍💋‍👩🏿' => 'נשיקה: אישה, אישה, גוון עור בהיר, גוון עור כהה',
    '👩🏼‍❤‍💋‍👩🏻' => 'נשיקה: אישה, אישה, גוון עור בהיר בינוני, גוון עור בהיר',
    '👩🏼‍❤‍💋‍👩🏼' => 'נשיקה: אישה, אישה, גוון עור בהיר בינוני',
    '👩🏼‍❤‍💋‍👩🏽' => 'נשיקה: אישה, אישה, גוון עור בהיר בינוני, גוון עור בינוני',
    '👩🏼‍❤‍💋‍👩🏾' => 'נשיקה: אישה, אישה, גוון עור בהיר בינוני, גוון עור כהה בינוני',
    '👩🏼‍❤‍💋‍👩🏿' => 'נשיקה: אישה, אישה, גוון עור בהיר בינוני, גוון עור כהה',
    '👩🏽‍❤‍💋‍👩🏻' => 'נשיקה: אישה, אישה, גוון עור בינוני, גוון עור בהיר',
    '👩🏽‍❤‍💋‍👩🏼' => 'נשיקה: אישה, אישה, גוון עור בינוני, גוון עור בהיר בינוני',
    '👩🏽‍❤‍💋‍👩🏽' => 'נשיקה: אישה, אישה, גוון עור בינוני',
    '👩🏽‍❤‍💋‍👩🏾' => 'נשיקה: אישה, אישה, גוון עור בינוני, גוון עור כהה בינוני',
    '👩🏽‍❤‍💋‍👩🏿' => 'נשיקה: אישה, אישה, גוון עור בינוני, גוון עור כהה',
    '👩🏾‍❤‍💋‍👩🏻' => 'נשיקה: אישה, אישה, גוון עור כהה בינוני, גוון עור בהיר',
    '👩🏾‍❤‍💋‍👩🏼' => 'נשיקה: אישה, אישה, גוון עור כהה בינוני, גוון עור בהיר בינוני',
    '👩🏾‍❤‍💋‍👩🏽' => 'נשיקה: אישה, אישה, גוון עור כהה בינוני, גוון עור בינוני',
    '👩🏾‍❤‍💋‍👩🏾' => 'נשיקה: אישה, אישה, גוון עור כהה בינוני',
    '👩🏾‍❤‍💋‍👩🏿' => 'נשיקה: אישה, אישה, גוון עור כהה בינוני, גוון עור כהה',
    '👩🏿‍❤‍💋‍👩🏻' => 'נשיקה: אישה, אישה, גוון עור כהה, גוון עור בהיר',
    '👩🏿‍❤‍💋‍👩🏼' => 'נשיקה: אישה, אישה, גוון עור כהה, גוון עור בהיר בינוני',
    '👩🏿‍❤‍💋‍👩🏽' => 'נשיקה: אישה, אישה, גוון עור כהה, גוון עור בינוני',
    '👩🏿‍❤‍💋‍👩🏾' => 'נשיקה: אישה, אישה, גוון עור כהה, גוון עור כהה בינוני',
    '👩🏿‍❤‍💋‍👩🏿' => 'נשיקה: אישה, אישה, גוון עור כהה',
    '🧑🏻‍🫯‍🧑🏼' => 'מתאבקים: גוון עור בהיר, גוון עור בהיר בינוני',
    '🧑🏻‍🫯‍🧑🏽' => 'מתאבקים: גוון עור בהיר, גוון עור בינוני',
    '🧑🏻‍🫯‍🧑🏾' => 'מתאבקים: גוון עור בהיר, גוון עור כהה בינוני',
    '🧑🏻‍🫯‍🧑🏿' => 'מתאבקים: גוון עור בהיר, גוון עור כהה',
    '🧑🏼‍🫯‍🧑🏻' => 'מתאבקים: גוון עור בהיר בינוני, גוון עור בהיר',
    '🧑🏼‍🫯‍🧑🏽' => 'מתאבקים: גוון עור בהיר בינוני, גוון עור בינוני',
    '🧑🏼‍🫯‍🧑🏾' => 'מתאבקים: גוון עור בהיר בינוני, גוון עור כהה בינוני',
    '🧑🏼‍🫯‍🧑🏿' => 'מתאבקים: גוון עור בהיר בינוני, גוון עור כהה',
    '🧑🏽‍🫯‍🧑🏻' => 'מתאבקים: גוון עור בינוני, גוון עור בהיר',
    '🧑🏽‍🫯‍🧑🏼' => 'מתאבקים: גוון עור בינוני, גוון עור בהיר בינוני',
    '🧑🏽‍🫯‍🧑🏾' => 'מתאבקים: גוון עור בינוני, גוון עור כהה בינוני',
    '🧑🏽‍🫯‍🧑🏿' => 'מתאבקים: גוון עור בינוני, גוון עור כהה',
    '🧑🏾‍🫯‍🧑🏻' => 'מתאבקים: גוון עור כהה בינוני, גוון עור בהיר',
    '🧑🏾‍🫯‍🧑🏼' => 'מתאבקים: גוון עור כהה בינוני, גוון עור בהיר בינוני',
    '🧑🏾‍🫯‍🧑🏽' => 'מתאבקים: גוון עור כהה בינוני, גוון עור בינוני',
    '🧑🏾‍🫯‍🧑🏿' => 'מתאבקים: גוון עור כהה בינוני, גוון עור כהה',
    '🧑🏿‍🫯‍🧑🏻' => 'מתאבקים: גוון עור כהה, גוון עור בהיר',
    '🧑🏿‍🫯‍🧑🏼' => 'מתאבקים: גוון עור כהה, גוון עור בהיר בינוני',
    '🧑🏿‍🫯‍🧑🏽' => 'מתאבקים: גוון עור כהה, גוון עור בינוני',
    '🧑🏿‍🫯‍🧑🏾' => 'מתאבקים: גוון עור כהה, גוון עור כהה בינוני',
    '🧑🏻‍❤‍🧑🏼' => 'זוג עם לב: אדם, אדם, גוון עור בהיר, גוון עור בהיר בינוני',
    '🧑🏻‍❤‍🧑🏽' => 'זוג עם לב: אדם, אדם, גוון עור בהיר, גוון עור בינוני',
    '🧑🏻‍❤‍🧑🏾' => 'זוג עם לב: אדם, אדם, גוון עור בהיר, גוון עור כהה בינוני',
    '🧑🏻‍❤‍🧑🏿' => 'זוג עם לב: אדם, אדם, גוון עור בהיר, גוון עור כהה',
    '🧑🏼‍❤‍🧑🏻' => 'זוג עם לב: אדם, אדם, גוון עור בהיר בינוני, גוון עור בהיר',
    '🧑🏼‍❤‍🧑🏽' => 'זוג עם לב: אדם, אדם, גוון עור בהיר בינוני, גוון עור בינוני',
    '🧑🏼‍❤‍🧑🏾' => 'זוג עם לב: אדם, אדם, גוון עור בהיר בינוני, גוון עור כהה בינוני',
    '🧑🏼‍❤‍🧑🏿' => 'זוג עם לב: אדם, אדם, גוון עור בהיר בינוני, גוון עור כהה',
    '🧑🏽‍❤‍🧑🏻' => 'זוג עם לב: אדם, אדם, גוון עור בינוני, גוון עור בהיר',
    '🧑🏽‍❤‍🧑🏼' => 'זוג עם לב: אדם, אדם, גוון עור בינוני, גוון עור בהיר בינוני',
    '🧑🏽‍❤‍🧑🏾' => 'זוג עם לב: אדם, אדם, גוון עור בינוני, גוון עור כהה בינוני',
    '🧑🏽‍❤‍🧑🏿' => 'זוג עם לב: אדם, אדם, גוון עור בינוני, גוון עור כהה',
    '🧑🏾‍❤‍🧑🏻' => 'זוג עם לב: אדם, אדם, גוון עור כהה בינוני, גוון עור בהיר',
    '🧑🏾‍❤‍🧑🏼' => 'זוג עם לב: אדם, אדם, גוון עור כהה בינוני, גוון עור בהיר בינוני',
    '🧑🏾‍❤‍🧑🏽' => 'זוג עם לב: אדם, אדם, גוון עור כהה בינוני, גוון עור בינוני',
    '🧑🏾‍❤‍🧑🏿' => 'זוג עם לב: אדם, אדם, גוון עור כהה בינוני, גוון עור כהה',
    '🧑🏿‍❤‍🧑🏻' => 'זוג עם לב: אדם, אדם, גוון עור כהה, גוון עור בהיר',
    '🧑🏿‍❤‍🧑🏼' => 'זוג עם לב: אדם, אדם, גוון עור כהה, גוון עור בהיר בינוני',
    '🧑🏿‍❤‍🧑🏽' => 'זוג עם לב: אדם, אדם, גוון עור כהה, גוון עור בינוני',
    '🧑🏿‍❤‍🧑🏾' => 'זוג עם לב: אדם, אדם, גוון עור כהה, גוון עור כהה בינוני',
    '🧑🏻‍🐰‍🧑🏼' => 'נשים עם אוזני ארנב רוקדות: גוון עור בהיר, גוון עור בהיר בינוני',
    '🧑🏻‍🐰‍🧑🏽' => 'נשים עם אוזני ארנב רוקדות: גוון עור בהיר, גוון עור בינוני',
    '🧑🏻‍🐰‍🧑🏾' => 'נשים עם אוזני ארנב רוקדות: גוון עור בהיר, גוון עור כהה בינוני',
    '🧑🏻‍🐰‍🧑🏿' => 'נשים עם אוזני ארנב רוקדות: גוון עור בהיר, גוון עור כהה',
    '🧑🏼‍🐰‍🧑🏻' => 'נשים עם אוזני ארנב רוקדות: גוון עור בהיר בינוני, גוון עור בהיר',
    '🧑🏼‍🐰‍🧑🏽' => 'נשים עם אוזני ארנב רוקדות: גוון עור בהיר בינוני, גוון עור בינוני',
    '🧑🏼‍🐰‍🧑🏾' => 'נשים עם אוזני ארנב רוקדות: גוון עור בהיר בינוני, גוון עור כהה בינוני',
    '🧑🏼‍🐰‍🧑🏿' => 'נשים עם אוזני ארנב רוקדות: גוון עור בהיר בינוני, גוון עור כהה',
    '🧑🏽‍🐰‍🧑🏻' => 'נשים עם אוזני ארנב רוקדות: גוון עור בינוני, גוון עור בהיר',
    '🧑🏽‍🐰‍🧑🏼' => 'נשים עם אוזני ארנב רוקדות: גוון עור בינוני, גוון עור בהיר בינוני',
    '🧑🏽‍🐰‍🧑🏾' => 'נשים עם אוזני ארנב רוקדות: גוון עור בינוני, גוון עור כהה בינוני',
    '🧑🏽‍🐰‍🧑🏿' => 'נשים עם אוזני ארנב רוקדות: גוון עור בינוני, גוון עור כהה',
    '🧑🏾‍🐰‍🧑🏻' => 'נשים עם אוזני ארנב רוקדות: גוון עור כהה בינוני, גוון עור בהיר',
    '🧑🏾‍🐰‍🧑🏼' => 'נשים עם אוזני ארנב רוקדות: גוון עור כהה בינוני, גוון עור בהיר בינוני',
    '🧑🏾‍🐰‍🧑🏽' => 'נשים עם אוזני ארנב רוקדות: גוון עור כהה בינוני, גוון עור בינוני',
    '🧑🏾‍🐰‍🧑🏿' => 'נשים עם אוזני ארנב רוקדות: גוון עור כהה בינוני, גוון עור כהה',
    '🧑🏿‍🐰‍🧑🏻' => 'נשים עם אוזני ארנב רוקדות: גוון עור כהה, גוון עור בהיר',
    '🧑🏿‍🐰‍🧑🏼' => 'נשים עם אוזני ארנב רוקדות: גוון עור כהה, גוון עור בהיר בינוני',
    '🧑🏿‍🐰‍🧑🏽' => 'נשים עם אוזני ארנב רוקדות: גוון עור כהה, גוון עור בינוני',
    '🧑🏿‍🐰‍🧑🏾' => 'נשים עם אוזני ארנב רוקדות: גוון עור כהה, גוון עור כהה בינוני',
    '👨🏻‍🫯‍👨🏼' => 'גברים מתאבקים: גוון עור בהיר, גוון עור בהיר בינוני',
    '👨🏻‍🫯‍👨🏽' => 'גברים מתאבקים: גוון עור בהיר, גוון עור בינוני',
    '👨🏻‍🫯‍👨🏾' => 'גברים מתאבקים: גוון עור בהיר, גוון עור כהה בינוני',
    '👨🏻‍🫯‍👨🏿' => 'גברים מתאבקים: גוון עור בהיר, גוון עור כהה',
    '👨🏼‍🫯‍👨🏻' => 'גברים מתאבקים: גוון עור בהיר בינוני, גוון עור בהיר',
    '👨🏼‍🫯‍👨🏽' => 'גברים מתאבקים: גוון עור בהיר בינוני, גוון עור בינוני',
    '👨🏼‍🫯‍👨🏾' => 'גברים מתאבקים: גוון עור בהיר בינוני, גוון עור כהה בינוני',
    '👨🏼‍🫯‍👨🏿' => 'גברים מתאבקים: גוון עור בהיר בינוני, גוון עור כהה',
    '👨🏽‍🫯‍👨🏻' => 'גברים מתאבקים: גוון עור בינוני, גוון עור בהיר',
    '👨🏽‍🫯‍👨🏼' => 'גברים מתאבקים: גוון עור בינוני, גוון עור בהיר בינוני',
    '👨🏽‍🫯‍👨🏾' => 'גברים מתאבקים: גוון עור בינוני, גוון עור כהה בינוני',
    '👨🏽‍🫯‍👨🏿' => 'גברים מתאבקים: גוון עור בינוני, גוון עור כהה',
    '👨🏾‍🫯‍👨🏻' => 'גברים מתאבקים: גוון עור כהה בינוני, גוון עור בהיר',
    '👨🏾‍🫯‍👨🏼' => 'גברים מתאבקים: גוון עור כהה בינוני, גוון עור בהיר בינוני',
    '👨🏾‍🫯‍👨🏽' => 'גברים מתאבקים: גוון עור כהה בינוני, גוון עור בינוני',
    '👨🏾‍🫯‍👨🏿' => 'גברים מתאבקים: גוון עור כהה בינוני, גוון עור כהה',
    '👨🏿‍🫯‍👨🏻' => 'גברים מתאבקים: גוון עור כהה, גוון עור בהיר',
    '👨🏿‍🫯‍👨🏼' => 'גברים מתאבקים: גוון עור כהה, גוון עור בהיר בינוני',
    '👨🏿‍🫯‍👨🏽' => 'גברים מתאבקים: גוון עור כהה, גוון עור בינוני',
    '👨🏿‍🫯‍👨🏾' => 'גברים מתאבקים: גוון עור כהה, גוון עור כהה בינוני',
    '👨🏻‍❤‍👨🏻' => 'זוג עם לב: איש, איש, גוון עור בהיר',
    '👨🏻‍❤‍👨🏼' => 'זוג עם לב: איש, איש, גוון עור בהיר, גוון עור בהיר בינוני',
    '👨🏻‍❤‍👨🏽' => 'זוג עם לב: איש, איש, גוון עור בהיר, גוון עור בינוני',
    '👨🏻‍❤‍👨🏾' => 'זוג עם לב: איש, איש, גוון עור בהיר, גוון עור כהה בינוני',
    '👨🏻‍❤‍👨🏿' => 'זוג עם לב: איש, איש, גוון עור בהיר, גוון עור כהה',
    '👨🏼‍❤‍👨🏻' => 'זוג עם לב: איש, איש, גוון עור בהיר בינוני, גוון עור בהיר',
    '👨🏼‍❤‍👨🏼' => 'זוג עם לב: איש, איש, גוון עור בהיר בינוני',
    '👨🏼‍❤‍👨🏽' => 'זוג עם לב: איש, איש, גוון עור בהיר בינוני, גוון עור בינוני',
    '👨🏼‍❤‍👨🏾' => 'זוג עם לב: איש, איש, גוון עור בהיר בינוני, גוון עור כהה בינוני',
    '👨🏼‍❤‍👨🏿' => 'זוג עם לב: איש, איש, גוון עור בהיר בינוני, גוון עור כהה',
    '👨🏽‍❤‍👨🏻' => 'זוג עם לב: איש, איש, גוון עור בינוני, גוון עור בהיר',
    '👨🏽‍❤‍👨🏼' => 'זוג עם לב: איש, איש, גוון עור בינוני, גוון עור בהיר בינוני',
    '👨🏽‍❤‍👨🏽' => 'זוג עם לב: איש, איש, גוון עור בינוני',
    '👨🏽‍❤‍👨🏾' => 'זוג עם לב: איש, איש, גוון עור בינוני, גוון עור כהה בינוני',
    '👨🏽‍❤‍👨🏿' => 'זוג עם לב: איש, איש, גוון עור בינוני, גוון עור כהה',
    '👨🏾‍❤‍👨🏻' => 'זוג עם לב: איש, איש, גוון עור כהה בינוני, גוון עור בהיר',
    '👨🏾‍❤‍👨🏼' => 'זוג עם לב: איש, איש, גוון עור כהה בינוני, גוון עור בהיר בינוני',
    '👨🏾‍❤‍👨🏽' => 'זוג עם לב: איש, איש, גוון עור כהה בינוני, גוון עור בינוני',
    '👨🏾‍❤‍👨🏾' => 'זוג עם לב: איש, איש, גוון עור כהה בינוני',
    '👨🏾‍❤‍👨🏿' => 'זוג עם לב: איש, איש, גוון עור כהה בינוני, גוון עור כהה',
    '👨🏿‍❤‍👨🏻' => 'זוג עם לב: איש, איש, גוון עור כהה, גוון עור בהיר',
    '👨🏿‍❤‍👨🏼' => 'זוג עם לב: איש, איש, גוון עור כהה, גוון עור בהיר בינוני',
    '👨🏿‍❤‍👨🏽' => 'זוג עם לב: איש, איש, גוון עור כהה, גוון עור בינוני',
    '👨🏿‍❤‍👨🏾' => 'זוג עם לב: איש, איש, גוון עור כהה, גוון עור כהה בינוני',
    '👨🏿‍❤‍👨🏿' => 'זוג עם לב: איש, איש, גוון עור כהה',
    '👨🏻‍🐰‍👨🏼' => 'גברים עם אוזני ארנב רוקדים: גוון עור בהיר, גוון עור בהיר בינוני',
    '👨🏻‍🐰‍👨🏽' => 'גברים עם אוזני ארנב רוקדים: גוון עור בהיר, גוון עור בינוני',
    '👨🏻‍🐰‍👨🏾' => 'גברים עם אוזני ארנב רוקדים: גוון עור בהיר, גוון עור כהה בינוני',
    '👨🏻‍🐰‍👨🏿' => 'גברים עם אוזני ארנב רוקדים: גוון עור בהיר, גוון עור כהה',
    '👨🏼‍🐰‍👨🏻' => 'גברים עם אוזני ארנב רוקדים: גוון עור בהיר בינוני, גוון עור בהיר',
    '👨🏼‍🐰‍👨🏽' => 'גברים עם אוזני ארנב רוקדים: גוון עור בהיר בינוני, גוון עור בינוני',
    '👨🏼‍🐰‍👨🏾' => 'גברים עם אוזני ארנב רוקדים: גוון עור בהיר בינוני, גוון עור כהה בינוני',
    '👨🏼‍🐰‍👨🏿' => 'גברים עם אוזני ארנב רוקדים: גוון עור בהיר בינוני, גוון עור כהה',
    '👨🏽‍🐰‍👨🏻' => 'גברים עם אוזני ארנב רוקדים: גוון עור בינוני, גוון עור בהיר',
    '👨🏽‍🐰‍👨🏼' => 'גברים עם אוזני ארנב רוקדים: גוון עור בינוני, גוון עור בהיר בינוני',
    '👨🏽‍🐰‍👨🏾' => 'גברים עם אוזני ארנב רוקדים: גוון עור בינוני, גוון עור כהה בינוני',
    '👨🏽‍🐰‍👨🏿' => 'גברים עם אוזני ארנב רוקדים: גוון עור בינוני, גוון עור כהה',
    '👨🏾‍🐰‍👨🏻' => 'גברים עם אוזני ארנב רוקדים: גוון עור כהה בינוני, גוון עור בהיר',
    '👨🏾‍🐰‍👨🏼' => 'גברים עם אוזני ארנב רוקדים: גוון עור כהה בינוני, גוון עור בהיר בינוני',
    '👨🏾‍🐰‍👨🏽' => 'גברים עם אוזני ארנב רוקדים: גוון עור כהה בינוני, גוון עור בינוני',
    '👨🏾‍🐰‍👨🏿' => 'גברים עם אוזני ארנב רוקדים: גוון עור כהה בינוני, גוון עור כהה',
    '👨🏿‍🐰‍👨🏻' => 'גברים עם אוזני ארנב רוקדים: גוון עור כהה, גוון עור בהיר',
    '👨🏿‍🐰‍👨🏼' => 'גברים עם אוזני ארנב רוקדים: גוון עור כהה, גוון עור בהיר בינוני',
    '👨🏿‍🐰‍👨🏽' => 'גברים עם אוזני ארנב רוקדים: גוון עור כהה, גוון עור בינוני',
    '👨🏿‍🐰‍👨🏾' => 'גברים עם אוזני ארנב רוקדים: גוון עור כהה, גוון עור כהה בינוני',
    '👩🏻‍🫯‍👩🏼' => 'נשים מתאבקות: גוון עור בהיר, גוון עור בהיר בינוני',
    '👩🏻‍🫯‍👩🏽' => 'נשים מתאבקות: גוון עור בהיר, גוון עור בינוני',
    '👩🏻‍🫯‍👩🏾' => 'נשים מתאבקות: גוון עור בהיר, גוון עור כהה בינוני',
    '👩🏻‍🫯‍👩🏿' => 'נשים מתאבקות: גוון עור בהיר, גוון עור כהה',
    '👩🏼‍🫯‍👩🏻' => 'נשים מתאבקות: גוון עור בהיר בינוני, גוון עור בהיר',
    '👩🏼‍🫯‍👩🏽' => 'נשים מתאבקות: גוון עור בהיר בינוני, גוון עור בינוני',
    '👩🏼‍🫯‍👩🏾' => 'נשים מתאבקות: גוון עור בהיר בינוני, גוון עור כהה בינוני',
    '👩🏼‍🫯‍👩🏿' => 'נשים מתאבקות: גוון עור בהיר בינוני, גוון עור כהה',
    '👩🏽‍🫯‍👩🏻' => 'נשים מתאבקות: גוון עור בינוני, גוון עור בהיר',
    '👩🏽‍🫯‍👩🏼' => 'נשים מתאבקות: גוון עור בינוני, גוון עור בהיר בינוני',
    '👩🏽‍🫯‍👩🏾' => 'נשים מתאבקות: גוון עור בינוני, גוון עור כהה בינוני',
    '👩🏽‍🫯‍👩🏿' => 'נשים מתאבקות: גוון עור בינוני, גוון עור כהה',
    '👩🏾‍🫯‍👩🏻' => 'נשים מתאבקות: גוון עור כהה בינוני, גוון עור בהיר',
    '👩🏾‍🫯‍👩🏼' => 'נשים מתאבקות: גוון עור כהה בינוני, גוון עור בהיר בינוני',
    '👩🏾‍🫯‍👩🏽' => 'נשים מתאבקות: גוון עור כהה בינוני, גוון עור בינוני',
    '👩🏾‍🫯‍👩🏿' => 'נשים מתאבקות: גוון עור כהה בינוני, גוון עור כהה',
    '👩🏿‍🫯‍👩🏻' => 'נשים מתאבקות: גוון עור כהה, גוון עור בהיר',
    '👩🏿‍🫯‍👩🏼' => 'נשים מתאבקות: גוון עור כהה, גוון עור בהיר בינוני',
    '👩🏿‍🫯‍👩🏽' => 'נשים מתאבקות: גוון עור כהה, גוון עור בינוני',
    '👩🏿‍🫯‍👩🏾' => 'נשים מתאבקות: גוון עור כהה, גוון עור כהה בינוני',
    '👩🏻‍❤‍👨🏻' => 'זוג עם לב: אישה, איש, גוון עור בהיר',
    '👩🏻‍❤‍👨🏼' => 'זוג עם לב: אישה, איש, גוון עור בהיר, גוון עור בהיר בינוני',
    '👩🏻‍❤‍👨🏽' => 'זוג עם לב: אישה, איש, גוון עור בהיר, גוון עור בינוני',
    '👩🏻‍❤‍👨🏾' => 'זוג עם לב: אישה, איש, גוון עור בהיר, גוון עור כהה בינוני',
    '👩🏻‍❤‍👨🏿' => 'זוג עם לב: אישה, איש, גוון עור בהיר, גוון עור כהה',
    '👩🏼‍❤‍👨🏻' => 'זוג עם לב: אישה, איש, גוון עור בהיר בינוני, גוון עור בהיר',
    '👩🏼‍❤‍👨🏼' => 'זוג עם לב: אישה, איש, גוון עור בהיר בינוני',
    '👩🏼‍❤‍👨🏽' => 'זוג עם לב: אישה, איש, גוון עור בהיר בינוני, גוון עור בינוני',
    '👩🏼‍❤‍👨🏾' => 'זוג עם לב: אישה, איש, גוון עור בהיר בינוני, גוון עור כהה בינוני',
    '👩🏼‍❤‍👨🏿' => 'זוג עם לב: אישה, איש, גוון עור בהיר בינוני, גוון עור כהה',
    '👩🏽‍❤‍👨🏻' => 'זוג עם לב: אישה, איש, גוון עור בינוני, גוון עור בהיר',
    '👩🏽‍❤‍👨🏼' => 'זוג עם לב: אישה, איש, גוון עור בינוני, גוון עור בהיר בינוני',
    '👩🏽‍❤‍👨🏽' => 'זוג עם לב: אישה, איש, גוון עור בינוני',
    '👩🏽‍❤‍👨🏾' => 'זוג עם לב: אישה, איש, גוון עור בינוני, גוון עור כהה בינוני',
    '👩🏽‍❤‍👨🏿' => 'זוג עם לב: אישה, איש, גוון עור בינוני, גוון עור כהה',
    '👩🏾‍❤‍👨🏻' => 'זוג עם לב: אישה, איש, גוון עור כהה בינוני, גוון עור בהיר',
    '👩🏾‍❤‍👨🏼' => 'זוג עם לב: אישה, איש, גוון עור כהה בינוני, גוון עור בהיר בינוני',
    '👩🏾‍❤‍👨🏽' => 'זוג עם לב: אישה, איש, גוון עור כהה בינוני, גוון עור בינוני',
    '👩🏾‍❤‍👨🏾' => 'זוג עם לב: אישה, איש, גוון עור כהה בינוני',
    '👩🏾‍❤‍👨🏿' => 'זוג עם לב: אישה, איש, גוון עור כהה בינוני, גוון עור כהה',
    '👩🏿‍❤‍👨🏻' => 'זוג עם לב: אישה, איש, גוון עור כהה, גוון עור בהיר',
    '👩🏿‍❤‍👨🏼' => 'זוג עם לב: אישה, איש, גוון עור כהה, גוון עור בהיר בינוני',
    '👩🏿‍❤‍👨🏽' => 'זוג עם לב: אישה, איש, גוון עור כהה, גוון עור בינוני',
    '👩🏿‍❤‍👨🏾' => 'זוג עם לב: אישה, איש, גוון עור כהה, גוון עור כהה בינוני',
    '👩🏿‍❤‍👨🏿' => 'זוג עם לב: אישה, איש, גוון עור כהה',
    '👩🏻‍❤‍👩🏻' => 'זוג עם לב: אישה, אישה, גוון עור בהיר',
    '👩🏻‍❤‍👩🏼' => 'זוג עם לב: אישה, אישה, גוון עור בהיר, גוון עור בהיר בינוני',
    '👩🏻‍❤‍👩🏽' => 'זוג עם לב: אישה, אישה, גוון עור בהיר, גוון עור בינוני',
    '👩🏻‍❤‍👩🏾' => 'זוג עם לב: אישה, אישה, גוון עור בהיר, גוון עור כהה בינוני',
    '👩🏻‍❤‍👩🏿' => 'זוג עם לב: אישה, אישה, גוון עור בהיר, גוון עור כהה',
    '👩🏼‍❤‍👩🏻' => 'זוג עם לב: אישה, אישה, גוון עור בהיר בינוני, גוון עור בהיר',
    '👩🏼‍❤‍👩🏼' => 'זוג עם לב: אישה, אישה, גוון עור בהיר בינוני',
    '👩🏼‍❤‍👩🏽' => 'זוג עם לב: אישה, אישה, גוון עור בהיר בינוני, גוון עור בינוני',
    '👩🏼‍❤‍👩🏾' => 'זוג עם לב: אישה, אישה, גוון עור בהיר בינוני, גוון עור כהה בינוני',
    '👩🏼‍❤‍👩🏿' => 'זוג עם לב: אישה, אישה, גוון עור בהיר בינוני, גוון עור כהה',
    '👩🏽‍❤‍👩🏻' => 'זוג עם לב: אישה, אישה, גוון עור בינוני, גוון עור בהיר',
    '👩🏽‍❤‍👩🏼' => 'זוג עם לב: אישה, אישה, גוון עור בינוני, גוון עור בהיר בינוני',
    '👩🏽‍❤‍👩🏽' => 'זוג עם לב: אישה, אישה, גוון עור בינוני',
    '👩🏽‍❤‍👩🏾' => 'זוג עם לב: אישה, אישה, גוון עור בינוני, גוון עור כהה בינוני',
    '👩🏽‍❤‍👩🏿' => 'זוג עם לב: אישה, אישה, גוון עור בינוני, גוון עור כהה',
    '👩🏾‍❤‍👩🏻' => 'זוג עם לב: אישה, אישה, גוון עור כהה בינוני, גוון עור בהיר',
    '👩🏾‍❤‍👩🏼' => 'זוג עם לב: אישה, אישה, גוון עור כהה בינוני, גוון עור בהיר בינוני',
    '👩🏾‍❤‍👩🏽' => 'זוג עם לב: אישה, אישה, גוון עור כהה בינוני, גוון עור בינוני',
    '👩🏾‍❤‍👩🏾' => 'זוג עם לב: אישה, אישה, גוון עור כהה בינוני',
    '👩🏾‍❤‍👩🏿' => 'זוג עם לב: אישה, אישה, גוון עור כהה בינוני, גוון עור כהה',
    '👩🏿‍❤‍👩🏻' => 'זוג עם לב: אישה, אישה, גוון עור כהה, גוון עור בהיר',
    '👩🏿‍❤‍👩🏼' => 'זוג עם לב: אישה, אישה, גוון עור כהה, גוון עור בהיר בינוני',
    '👩🏿‍❤‍👩🏽' => 'זוג עם לב: אישה, אישה, גוון עור כהה, גוון עור בינוני',
    '👩🏿‍❤‍👩🏾' => 'זוג עם לב: אישה, אישה, גוון עור כהה, גוון עור כהה בינוני',
    '👩🏿‍❤‍👩🏿' => 'זוג עם לב: אישה, אישה, גוון עור כהה',
    '👩🏻‍🐰‍👩🏼' => 'נשים עם אוזני ארנב: גוון עור בהיר, גוון עור בהיר בינוני',
    '👩🏻‍🐰‍👩🏽' => 'נשים עם אוזני ארנב: גוון עור בהיר, גוון עור בינוני',
    '👩🏻‍🐰‍👩🏾' => 'נשים עם אוזני ארנב: גוון עור בהיר, גוון עור כהה בינוני',
    '👩🏻‍🐰‍👩🏿' => 'נשים עם אוזני ארנב: גוון עור בהיר, גוון עור כהה',
    '👩🏼‍🐰‍👩🏻' => 'נשים עם אוזני ארנב: גוון עור בהיר בינוני, גוון עור בהיר',
    '👩🏼‍🐰‍👩🏽' => 'נשים עם אוזני ארנב: גוון עור בהיר בינוני, גוון עור בינוני',
    '👩🏼‍🐰‍👩🏾' => 'נשים עם אוזני ארנב: גוון עור בהיר בינוני, גוון עור כהה בינוני',
    '👩🏼‍🐰‍👩🏿' => 'נשים עם אוזני ארנב: גוון עור בהיר בינוני, גוון עור כהה',
    '👩🏽‍🐰‍👩🏻' => 'נשים עם אוזני ארנב: גוון עור בינוני, גוון עור בהיר',
    '👩🏽‍🐰‍👩🏼' => 'נשים עם אוזני ארנב: גוון עור בינוני, גוון עור בהיר בינוני',
    '👩🏽‍🐰‍👩🏾' => 'נשים עם אוזני ארנב: גוון עור בינוני, גוון עור כהה בינוני',
    '👩🏽‍🐰‍👩🏿' => 'נשים עם אוזני ארנב: גוון עור בינוני, גוון עור כהה',
    '👩🏾‍🐰‍👩🏻' => 'נשים עם אוזני ארנב: גוון עור כהה בינוני, גוון עור בהיר',
    '👩🏾‍🐰‍👩🏼' => 'נשים עם אוזני ארנב: גוון עור כהה בינוני, גוון עור בהיר בינוני',
    '👩🏾‍🐰‍👩🏽' => 'נשים עם אוזני ארנב: גוון עור כהה בינוני, גוון עור בינוני',
    '👩🏾‍🐰‍👩🏿' => 'נשים עם אוזני ארנב: גוון עור כהה בינוני, גוון עור כהה',
    '👩🏿‍🐰‍👩🏻' => 'נשים עם אוזני ארנב: גוון עור כהה, גוון עור בהיר',
    '👩🏿‍🐰‍👩🏼' => 'נשים עם אוזני ארנב: גוון עור כהה, גוון עור בהיר בינוני',
    '👩🏿‍🐰‍👩🏽' => 'נשים עם אוזני ארנב: גוון עור כהה, גוון עור בינוני',
    '👩🏿‍🐰‍👩🏾' => 'נשים עם אוזני ארנב: גוון עור כהה, גוון עור כהה בינוני',
    '🧑🏻‍🤝‍🧑🏻' => 'אנשים מחזיקים ידיים: גוון עור בהיר',
    '🧑🏻‍🤝‍🧑🏼' => 'אנשים מחזיקים ידיים: גוון עור בהיר, גוון עור בהיר בינוני',
    '🧑🏻‍🤝‍🧑🏽' => 'אנשים מחזיקים ידיים: גוון עור בהיר, גוון עור בינוני',
    '🧑🏻‍🤝‍🧑🏾' => 'אנשים מחזיקים ידיים: גוון עור בהיר, גוון עור כהה בינוני',
    '🧑🏻‍🤝‍🧑🏿' => 'אנשים מחזיקים ידיים: גוון עור בהיר, גוון עור כהה',
    '🧑🏼‍🤝‍🧑🏻' => 'אנשים מחזיקים ידיים: גוון עור בהיר בינוני, גוון עור בהיר',
    '🧑🏼‍🤝‍🧑🏼' => 'אנשים מחזיקים ידיים: גוון עור בהיר בינוני',
    '🧑🏼‍🤝‍🧑🏽' => 'אנשים מחזיקים ידיים: גוון עור בהיר בינוני, גוון עור בינוני',
    '🧑🏼‍🤝‍🧑🏾' => 'אנשים מחזיקים ידיים: גוון עור בהיר בינוני, גוון עור כהה בינוני',
    '🧑🏼‍🤝‍🧑🏿' => 'אנשים מחזיקים ידיים: גוון עור בהיר בינוני, גוון עור כהה',
    '🧑🏽‍🤝‍🧑🏻' => 'אנשים מחזיקים ידיים: גוון עור בינוני, גוון עור בהיר',
    '🧑🏽‍🤝‍🧑🏼' => 'אנשים מחזיקים ידיים: גוון עור בינוני, גוון עור בהיר בינוני',
    '🧑🏽‍🤝‍🧑🏽' => 'אנשים מחזיקים ידיים: גוון עור בינוני',
    '🧑🏽‍🤝‍🧑🏾' => 'אנשים מחזיקים ידיים: גוון עור בינוני, גוון עור כהה בינוני',
    '🧑🏽‍🤝‍🧑🏿' => 'אנשים מחזיקים ידיים: גוון עור בינוני, גוון עור כהה',
    '🧑🏾‍🤝‍🧑🏻' => 'אנשים מחזיקים ידיים: גוון עור כהה בינוני, גוון עור בהיר',
    '🧑🏾‍🤝‍🧑🏼' => 'אנשים מחזיקים ידיים: גוון עור כהה בינוני, גוון עור בהיר בינוני',
    '🧑🏾‍🤝‍🧑🏽' => 'אנשים מחזיקים ידיים: גוון עור כהה בינוני, גוון עור בינוני',
    '🧑🏾‍🤝‍🧑🏾' => 'אנשים מחזיקים ידיים: גוון עור כהה בינוני',
    '🧑🏾‍🤝‍🧑🏿' => 'אנשים מחזיקים ידיים: גוון עור כהה בינוני, גוון עור כהה',
    '🧑🏿‍🤝‍🧑🏻' => 'אנשים מחזיקים ידיים: גוון עור כהה, גוון עור בהיר',
    '🧑🏿‍🤝‍🧑🏼' => 'אנשים מחזיקים ידיים: גוון עור כהה, גוון עור בהיר בינוני',
    '🧑🏿‍🤝‍🧑🏽' => 'אנשים מחזיקים ידיים: גוון עור כהה, גוון עור בינוני',
    '🧑🏿‍🤝‍🧑🏾' => 'אנשים מחזיקים ידיים: גוון עור כהה, גוון עור כהה בינוני',
    '🧑🏿‍🤝‍🧑🏿' => 'אנשים מחזיקים ידיים: גוון עור כהה',
    '👩🏻‍🤝‍👩🏼' => 'שתי נשים מחזיקות ידיים: גוון עור בהיר, גוון עור בהיר בינוני',
    '👩🏻‍🤝‍👩🏽' => 'שתי נשים מחזיקות ידיים: גוון עור בהיר, גוון עור בינוני',
    '👩🏻‍🤝‍👩🏾' => 'שתי נשים מחזיקות ידיים: גוון עור בהיר, גוון עור כהה בינוני',
    '👩🏻‍🤝‍👩🏿' => 'שתי נשים מחזיקות ידיים: גוון עור בהיר, גוון עור כהה',
    '👩🏼‍🤝‍👩🏻' => 'שתי נשים מחזיקות ידיים: גוון עור בהיר בינוני, גוון עור בהיר',
    '👩🏼‍🤝‍👩🏽' => 'שתי נשים מחזיקות ידיים: גוון עור בהיר בינוני, גוון עור בינוני',
    '👩🏼‍🤝‍👩🏾' => 'שתי נשים מחזיקות ידיים: גוון עור בהיר בינוני, גוון עור כהה בינוני',
    '👩🏼‍🤝‍👩🏿' => 'שתי נשים מחזיקות ידיים: גוון עור בהיר בינוני, גוון עור כהה',
    '👩🏽‍🤝‍👩🏻' => 'שתי נשים מחזיקות ידיים: גוון עור בינוני, גוון עור בהיר',
    '👩🏽‍🤝‍👩🏼' => 'שתי נשים מחזיקות ידיים: גוון עור בינוני, גוון עור בהיר בינוני',
    '👩🏽‍🤝‍👩🏾' => 'שתי נשים מחזיקות ידיים: גוון עור בינוני, גוון עור כהה בינוני',
    '👩🏽‍🤝‍👩🏿' => 'שתי נשים מחזיקות ידיים: גוון עור בינוני, גוון עור כהה',
    '👩🏾‍🤝‍👩🏻' => 'שתי נשים מחזיקות ידיים: גוון עור כהה בינוני, גוון עור בהיר',
    '👩🏾‍🤝‍👩🏼' => 'שתי נשים מחזיקות ידיים: גוון עור כהה בינוני, גוון עור בהיר בינוני',
    '👩🏾‍🤝‍👩🏽' => 'שתי נשים מחזיקות ידיים: גוון עור כהה בינוני, גוון עור בינוני',
    '👩🏾‍🤝‍👩🏿' => 'שתי נשים מחזיקות ידיים: גוון עור כהה בינוני, גוון עור כהה',
    '👩🏿‍🤝‍👩🏻' => 'שתי נשים מחזיקות ידיים: גוון עור כהה, גוון עור בהיר',
    '👩🏿‍🤝‍👩🏼' => 'שתי נשים מחזיקות ידיים: גוון עור כהה, גוון עור בהיר בינוני',
    '👩🏿‍🤝‍👩🏽' => 'שתי נשים מחזיקות ידיים: גוון עור כהה, גוון עור בינוני',
    '👩🏿‍🤝‍👩🏾' => 'שתי נשים מחזיקות ידיים: גוון עור כהה, גוון עור כהה בינוני',
    '👩🏻‍🤝‍👨🏼' => 'איש ואישה מחזיקים ידיים: גוון עור בהיר, גוון עור בהיר בינוני',
    '👩🏻‍🤝‍👨🏽' => 'איש ואישה מחזיקים ידיים: גוון עור בהיר, גוון עור בינוני',
    '👩🏻‍🤝‍👨🏾' => 'איש ואישה מחזיקים ידיים: גוון עור בהיר, גוון עור כהה בינוני',
    '👩🏻‍🤝‍👨🏿' => 'איש ואישה מחזיקים ידיים: גוון עור בהיר, גוון עור כהה',
    '👩🏼‍🤝‍👨🏻' => 'איש ואישה מחזיקים ידיים: גוון עור בהיר בינוני, גוון עור בהיר',
    '👩🏼‍🤝‍👨🏽' => 'איש ואישה מחזיקים ידיים: גוון עור בהיר בינוני, גוון עור בינוני',
    '👩🏼‍🤝‍👨🏾' => 'איש ואישה מחזיקים ידיים: גוון עור בהיר בינוני, גוון עור כהה בינוני',
    '👩🏼‍🤝‍👨🏿' => 'איש ואישה מחזיקים ידיים: גוון עור בהיר בינוני, גוון עור כהה',
    '👩🏽‍🤝‍👨🏻' => 'איש ואישה מחזיקים ידיים: גוון עור בינוני, גוון עור בהיר',
    '👩🏽‍🤝‍👨🏼' => 'איש ואישה מחזיקים ידיים: גוון עור בינוני, גוון עור בהיר בינוני',
    '👩🏽‍🤝‍👨🏾' => 'איש ואישה מחזיקים ידיים: גוון עור בינוני, גוון עור כהה בינוני',
    '👩🏽‍🤝‍👨🏿' => 'איש ואישה מחזיקים ידיים: גוון עור בינוני, גוון עור כהה',
    '👩🏾‍🤝‍👨🏻' => 'איש ואישה מחזיקים ידיים: גוון עור כהה בינוני, גוון עור בהיר',
    '👩🏾‍🤝‍👨🏼' => 'איש ואישה מחזיקים ידיים: גוון עור כהה בינוני, גוון עור בהיר בינוני',
    '👩🏾‍🤝‍👨🏽' => 'איש ואישה מחזיקים ידיים: גוון עור כהה בינוני, גוון עור בינוני',
    '👩🏾‍🤝‍👨🏿' => 'איש ואישה מחזיקים ידיים: גוון עור כהה בינוני, גוון עור כהה',
    '👩🏿‍🤝‍👨🏻' => 'איש ואישה מחזיקים ידיים: גוון עור כהה, גוון עור בהיר',
    '👩🏿‍🤝‍👨🏼' => 'איש ואישה מחזיקים ידיים: גוון עור כהה, גוון עור בהיר בינוני',
    '👩🏿‍🤝‍👨🏽' => 'איש ואישה מחזיקים ידיים: גוון עור כהה, גוון עור בינוני',
    '👩🏿‍🤝‍👨🏾' => 'איש ואישה מחזיקים ידיים: גוון עור כהה, גוון עור כהה בינוני',
    '👨🏻‍🤝‍👨🏼' => 'שני גברים מחזיקים ידיים: גוון עור בהיר, גוון עור בהיר בינוני',
    '👨🏻‍🤝‍👨🏽' => 'שני גברים מחזיקים ידיים: גוון עור בהיר, גוון עור בינוני',
    '👨🏻‍🤝‍👨🏾' => 'שני גברים מחזיקים ידיים: גוון עור בהיר, גוון עור כהה בינוני',
    '👨🏻‍🤝‍👨🏿' => 'שני גברים מחזיקים ידיים: גוון עור בהיר, גוון עור כהה',
    '👨🏼‍🤝‍👨🏻' => 'שני גברים מחזיקים ידיים: גוון עור בהיר בינוני, גוון עור בהיר',
    '👨🏼‍🤝‍👨🏽' => 'שני גברים מחזיקים ידיים: גוון עור בהיר בינוני, גוון עור בינוני',
    '👨🏼‍🤝‍👨🏾' => 'שני גברים מחזיקים ידיים: גוון עור בהיר בינוני, גוון עור כהה בינוני',
    '👨🏼‍🤝‍👨🏿' => 'שני גברים מחזיקים ידיים: גוון עור בהיר בינוני, גוון עור כהה',
    '👨🏽‍🤝‍👨🏻' => 'שני גברים מחזיקים ידיים: גוון עור בינוני, גוון עור בהיר',
    '👨🏽‍🤝‍👨🏼' => 'שני גברים מחזיקים ידיים: גוון עור בינוני, גוון עור בהיר בינוני',
    '👨🏽‍🤝‍👨🏾' => 'שני גברים מחזיקים ידיים: גוון עור בינוני, גוון עור כהה בינוני',
    '👨🏽‍🤝‍👨🏿' => 'שני גברים מחזיקים ידיים: גוון עור בינוני, גוון עור כהה',
    '👨🏾‍🤝‍👨🏻' => 'שני גברים מחזיקים ידיים: גוון עור כהה בינוני, גוון עור בהיר',
    '👨🏾‍🤝‍👨🏼' => 'שני גברים מחזיקים ידיים: גוון עור כהה בינוני, גוון עור בהיר בינוני',
    '👨🏾‍🤝‍👨🏽' => 'שני גברים מחזיקים ידיים: גוון עור כהה בינוני, גוון עור בינוני',
    '👨🏾‍🤝‍👨🏿' => 'שני גברים מחזיקים ידיים: גוון עור כהה בינוני, גוון עור כהה',
    '👨🏿‍🤝‍👨🏻' => 'שני גברים מחזיקים ידיים: גוון עור כהה, גוון עור בהיר',
    '👨🏿‍🤝‍👨🏼' => 'שני גברים מחזיקים ידיים: גוון עור כהה, גוון עור בהיר בינוני',
    '👨🏿‍🤝‍👨🏽' => 'שני גברים מחזיקים ידיים: גוון עור כהה, גוון עור בינוני',
    '👨🏿‍🤝‍👨🏾' => 'שני גברים מחזיקים ידיים: גוון עור כהה, גוון עור כהה בינוני',
    '👩‍❤‍💋‍👨' => 'נשיקה: אישה, איש',
    '👨‍❤‍💋‍👨' => 'נשיקה: איש, איש',
    '👩‍❤‍💋‍👩' => 'נשיקה: אישה, אישה',
    '👨‍👩‍👧‍👦' => 'משפחה: איש, אישה, בת, בן',
    '👨‍👩‍👦‍👦' => 'משפחה: איש, אישה, בן, בן',
    '👨‍👩‍👧‍👧' => 'משפחה: איש, אישה, בת, בת',
    '👨‍👨‍👧‍👦' => 'משפחה: איש, איש, בת, בן',
    '👨‍👨‍👦‍👦' => 'משפחה: איש, איש, בן, בן',
    '👨‍👨‍👧‍👧' => 'משפחה: איש, איש, בת, בת',
    '👩‍👩‍👧‍👦' => 'משפחה: אישה, אישה, בת, בן',
    '👩‍👩‍👦‍👦' => 'משפחה: אישה, אישה, בן, בן',
    '👩‍👩‍👧‍👧' => 'משפחה: אישה, אישה, בת, בת',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'דגל: אנגליה',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'דגל: סקוטלנד',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'דגל: וויילס',
    '🧑‍🧑‍🧒‍🧒' => 'משפחה: הורה, הורה, ילד, ילד',
    '🚶🏻‍♀‍➡' => 'אישה הולכת: גוון עור בהיר, פונה ימינה',
    '🚶🏼‍♀‍➡' => 'אישה הולכת: גוון עור בהיר בינוני, פונה ימינה',
    '🚶🏽‍♀‍➡' => 'אישה הולכת: גוון עור בינוני, פונה ימינה',
    '🚶🏾‍♀‍➡' => 'אישה הולכת: גוון עור כהה בינוני, פונה ימינה',
    '🚶🏿‍♀‍➡' => 'אישה הולכת: גוון עור כהה, פונה ימינה',
    '🚶🏻‍♂‍➡' => 'גבר הולך: גוון עור בהיר, פונה ימינה',
    '🚶🏼‍♂‍➡' => 'גבר הולך: גוון עור בהיר בינוני, פונה ימינה',
    '🚶🏽‍♂‍➡' => 'גבר הולך: גוון עור בינוני, פונה ימינה',
    '🚶🏾‍♂‍➡' => 'גבר הולך: גוון עור כהה בינוני, פונה ימינה',
    '🚶🏿‍♂‍➡' => 'גבר הולך: גוון עור כהה, פונה ימינה',
    '🧎🏻‍♀‍➡' => 'אישה כורעת ברך: גוון עור בהיר, פונה ימינה',
    '🧎🏼‍♀‍➡' => 'אישה כורעת ברך: גוון עור בהיר בינוני, פונה ימינה',
    '🧎🏽‍♀‍➡' => 'אישה כורעת ברך: גוון עור בינוני, פונה ימינה',
    '🧎🏾‍♀‍➡' => 'אישה כורעת ברך: גוון עור כהה בינוני, פונה ימינה',
    '🧎🏿‍♀‍➡' => 'אישה כורעת ברך: גוון עור כהה, פונה ימינה',
    '🧎🏻‍♂‍➡' => 'איש כורע ברך: גוון עור בהיר, פונה ימינה',
    '🧎🏼‍♂‍➡' => 'איש כורע ברך: גוון עור בהיר בינוני, פונה ימינה',
    '🧎🏽‍♂‍➡' => 'איש כורע ברך: גוון עור בינוני, פונה ימינה',
    '🧎🏾‍♂‍➡' => 'איש כורע ברך: גוון עור כהה בינוני, פונה ימינה',
    '🧎🏿‍♂‍➡' => 'איש כורע ברך: גוון עור כהה, פונה ימינה',
    '🧑🏻‍🦯‍➡' => 'אדם עם מקל נחייה: גוון עור בהיר, פונה ימינה',
    '🧑🏼‍🦯‍➡' => 'אדם עם מקל נחייה: גוון עור בהיר בינוני, פונה ימינה',
    '🧑🏽‍🦯‍➡' => 'אדם עם מקל נחייה: גוון עור בינוני, פונה ימינה',
    '🧑🏾‍🦯‍➡' => 'אדם עם מקל נחייה: גוון עור כהה בינוני, פונה ימינה',
    '🧑🏿‍🦯‍➡' => 'אדם עם מקל נחייה: גוון עור כהה, פונה ימינה',
    '👨🏻‍🦯‍➡' => 'איש עם מקל נחייה: גוון עור בהיר, פונה ימינה',
    '👨🏼‍🦯‍➡' => 'איש עם מקל נחייה: גוון עור בהיר בינוני, פונה ימינה',
    '👨🏽‍🦯‍➡' => 'איש עם מקל נחייה: גוון עור בינוני, פונה ימינה',
    '👨🏾‍🦯‍➡' => 'איש עם מקל נחייה: גוון עור כהה בינוני, פונה ימינה',
    '👨🏿‍🦯‍➡' => 'איש עם מקל נחייה: גוון עור כהה, פונה ימינה',
    '👩🏻‍🦯‍➡' => 'אישה עם מקל נחייה: גוון עור בהיר, פונה ימינה',
    '👩🏼‍🦯‍➡' => 'אישה עם מקל נחייה: גוון עור בהיר בינוני, פונה ימינה',
    '👩🏽‍🦯‍➡' => 'אישה עם מקל נחייה: גוון עור בינוני, פונה ימינה',
    '👩🏾‍🦯‍➡' => 'אישה עם מקל נחייה: גוון עור כהה בינוני, פונה ימינה',
    '👩🏿‍🦯‍➡' => 'אישה עם מקל נחייה: גוון עור כהה, פונה ימינה',
    '🧑🏻‍🦼‍➡' => 'אדם בכסא גלגלים ממונע: גוון עור בהיר, פונה ימינה',
    '🧑🏼‍🦼‍➡' => 'אדם בכסא גלגלים ממונע: גוון עור בהיר בינוני, פונה ימינה',
    '🧑🏽‍🦼‍➡' => 'אדם בכסא גלגלים ממונע: גוון עור בינוני, פונה ימינה',
    '🧑🏾‍🦼‍➡' => 'אדם בכסא גלגלים ממונע: גוון עור כהה בינוני, פונה ימינה',
    '🧑🏿‍🦼‍➡' => 'אדם בכסא גלגלים ממונע: גוון עור כהה, פונה ימינה',
    '👨🏻‍🦼‍➡' => 'איש בכסא גלגלים ממונע: גוון עור בהיר, פונה ימינה',
    '👨🏼‍🦼‍➡' => 'איש בכסא גלגלים ממונע: גוון עור בהיר בינוני, פונה ימינה',
    '👨🏽‍🦼‍➡' => 'איש בכסא גלגלים ממונע: גוון עור בינוני, פונה ימינה',
    '👨🏾‍🦼‍➡' => 'איש בכסא גלגלים ממונע: גוון עור כהה בינוני, פונה ימינה',
    '👨🏿‍🦼‍➡' => 'איש בכסא גלגלים ממונע: גוון עור כהה, פונה ימינה',
    '👩🏻‍🦼‍➡' => 'אישה בכסא גלגלים ממונע: גוון עור בהיר, פונה ימינה',
    '👩🏼‍🦼‍➡' => 'אישה בכסא גלגלים ממונע: גוון עור בהיר בינוני, פונה ימינה',
    '👩🏽‍🦼‍➡' => 'אישה בכסא גלגלים ממונע: גוון עור בינוני, פונה ימינה',
    '👩🏾‍🦼‍➡' => 'אישה בכסא גלגלים ממונע: גוון עור כהה בינוני, פונה ימינה',
    '👩🏿‍🦼‍➡' => 'אישה בכסא גלגלים ממונע: גוון עור כהה, פונה ימינה',
    '🧑🏻‍🦽‍➡' => 'אדם בכסא גלגלים ידני: גוון עור בהיר, פונה ימינה',
    '🧑🏼‍🦽‍➡' => 'אדם בכסא גלגלים ידני: גוון עור בהיר בינוני, פונה ימינה',
    '🧑🏽‍🦽‍➡' => 'אדם בכסא גלגלים ידני: גוון עור בינוני, פונה ימינה',
    '🧑🏾‍🦽‍➡' => 'אדם בכסא גלגלים ידני: גוון עור כהה בינוני, פונה ימינה',
    '🧑🏿‍🦽‍➡' => 'אדם בכסא גלגלים ידני: גוון עור כהה, פונה ימינה',
    '👨🏻‍🦽‍➡' => 'איש בכסא גלגלים ידני: גוון עור בהיר, פונה ימינה',
    '👨🏼‍🦽‍➡' => 'איש בכסא גלגלים ידני: גוון עור בהיר בינוני, פונה ימינה',
    '👨🏽‍🦽‍➡' => 'איש בכסא גלגלים ידני: גוון עור בינוני, פונה ימינה',
    '👨🏾‍🦽‍➡' => 'איש בכסא גלגלים ידני: גוון עור כהה בינוני, פונה ימינה',
    '👨🏿‍🦽‍➡' => 'איש בכסא גלגלים ידני: גוון עור כהה, פונה ימינה',
    '👩🏻‍🦽‍➡' => 'אישה בכסא גלגלים ידני: גוון עור בהיר, פונה ימינה',
    '👩🏼‍🦽‍➡' => 'אישה בכסא גלגלים ידני: גוון עור בהיר בינוני, פונה ימינה',
    '👩🏽‍🦽‍➡' => 'אישה בכסא גלגלים ידני: גוון עור בינוני, פונה ימינה',
    '👩🏾‍🦽‍➡' => 'אישה בכסא גלגלים ידני: גוון עור כהה בינוני, פונה ימינה',
    '👩🏿‍🦽‍➡' => 'אישה בכסא גלגלים ידני: גוון עור כהה, פונה ימינה',
    '🏃🏻‍♀‍➡' => 'אישה רצה: גוון עור בהיר, פונה ימינה',
    '🏃🏼‍♀‍➡' => 'אישה רצה: גוון עור בהיר בינוני, פונה ימינה',
    '🏃🏽‍♀‍➡' => 'אישה רצה: גוון עור בינוני, פונה ימינה',
    '🏃🏾‍♀‍➡' => 'אישה רצה: גוון עור כהה בינוני, פונה ימינה',
    '🏃🏿‍♀‍➡' => 'אישה רצה: גוון עור כהה, פונה ימינה',
    '🏃🏻‍♂‍➡' => 'גבר רץ: גוון עור בהיר, פונה ימינה',
    '🏃🏼‍♂‍➡' => 'גבר רץ: גוון עור בהיר בינוני, פונה ימינה',
    '🏃🏽‍♂‍➡' => 'גבר רץ: גוון עור בינוני, פונה ימינה',
    '🏃🏾‍♂‍➡' => 'גבר רץ: גוון עור כהה בינוני, פונה ימינה',
    '🏃🏿‍♂‍➡' => 'גבר רץ: גוון עור כהה, פונה ימינה',
    '🫱🏻‍🫲🏼' => 'לחיצת יד: גוון עור בהיר, גוון עור בהיר בינוני',
    '🫱🏻‍🫲🏽' => 'לחיצת יד: גוון עור בהיר, גוון עור בינוני',
    '🫱🏻‍🫲🏾' => 'לחיצת יד: גוון עור בהיר, גוון עור כהה בינוני',
    '🫱🏻‍🫲🏿' => 'לחיצת יד: גוון עור בהיר, גוון עור כהה',
    '🫱🏼‍🫲🏻' => 'לחיצת יד: גוון עור בהיר בינוני, גוון עור בהיר',
    '🫱🏼‍🫲🏽' => 'לחיצת יד: גוון עור בהיר בינוני, גוון עור בינוני',
    '🫱🏼‍🫲🏾' => 'לחיצת יד: גוון עור בהיר בינוני, גוון עור כהה בינוני',
    '🫱🏼‍🫲🏿' => 'לחיצת יד: גוון עור בהיר בינוני, גוון עור כהה',
    '🫱🏽‍🫲🏻' => 'לחיצת יד: גוון עור בינוני, גוון עור בהיר',
    '🫱🏽‍🫲🏼' => 'לחיצת יד: גוון עור בינוני, גוון עור בהיר בינוני',
    '🫱🏽‍🫲🏾' => 'לחיצת יד: גוון עור בינוני, גוון עור כהה בינוני',
    '🫱🏽‍🫲🏿' => 'לחיצת יד: גוון עור בינוני, גוון עור כהה',
    '🫱🏾‍🫲🏻' => 'לחיצת יד: גוון עור כהה בינוני, גוון עור בהיר',
    '🫱🏾‍🫲🏼' => 'לחיצת יד: גוון עור כהה בינוני, גוון עור בהיר בינוני',
    '🫱🏾‍🫲🏽' => 'לחיצת יד: גוון עור כהה בינוני, גוון עור בינוני',
    '🫱🏾‍🫲🏿' => 'לחיצת יד: גוון עור כהה בינוני, גוון עור כהה',
    '🫱🏿‍🫲🏻' => 'לחיצת יד: גוון עור כהה, גוון עור בהיר',
    '🫱🏿‍🫲🏼' => 'לחיצת יד: גוון עור כהה, גוון עור בהיר בינוני',
    '🫱🏿‍🫲🏽' => 'לחיצת יד: גוון עור כהה, גוון עור בינוני',
    '🫱🏿‍🫲🏾' => 'לחיצת יד: גוון עור כהה, גוון עור כהה בינוני',
    '🚶‍♀‍➡' => 'אישה הולכת: פונה ימינה',
    '🚶‍♂‍➡' => 'גבר הולך: פונה ימינה',
    '🧎‍♀‍➡' => 'אישה כורעת ברך: פונה ימינה',
    '🧎‍♂‍➡' => 'איש כורע ברך: פונה ימינה',
    '🧑‍🦯‍➡' => 'אדם עם מקל נחייה: פונה ימינה',
    '👨‍🦯‍➡' => 'איש עם מקל נחייה: פונה ימינה',
    '👩‍🦯‍➡' => 'אישה עם מקל נחייה: פונה ימינה',
    '🧑‍🦼‍➡' => 'אדם בכסא גלגלים ממונע: פונה ימינה',
    '👨‍🦼‍➡' => 'איש בכסא גלגלים ממונע: פונה ימינה',
    '👩‍🦼‍➡' => 'אישה בכסא גלגלים ממונע: פונה ימינה',
    '🧑‍🦽‍➡' => 'אדם בכסא גלגלים ידני: פונה ימינה',
    '👨‍🦽‍➡' => 'איש בכסא גלגלים ידני: פונה ימינה',
    '👩‍🦽‍➡' => 'אישה בכסא גלגלים ידני: פונה ימינה',
    '🏃‍♀‍➡' => 'אישה רצה: פונה ימינה',
    '🏃‍♂‍➡' => 'גבר רץ: פונה ימינה',
    '👩‍❤‍👨' => 'זוג עם לב: אישה, איש',
    '👨‍❤‍👨' => 'זוג עם לב: איש, איש',
    '👩‍❤‍👩' => 'זוג עם לב: אישה, אישה',
    '👨‍👩‍👦' => 'משפחה: איש, אישה, בן',
    '👨‍👩‍👧' => 'משפחה: איש, אישה, בת',
    '👨‍👨‍👦' => 'משפחה: איש, איש, בן',
    '👨‍👨‍👧' => 'משפחה: איש, איש, בת',
    '👩‍👩‍👦' => 'משפחה: אישה, אישה, בן',
    '👩‍👩‍👧' => 'משפחה: אישה, אישה, בת',
    '👨‍👦‍👦' => 'משפחה: איש, בן, בן',
    '👨‍👧‍👦' => 'משפחה: איש, בת, בן',
    '👨‍👧‍👧' => 'משפחה: איש, בת, בת',
    '👩‍👦‍👦' => 'משפחה: אישה, בן, בן',
    '👩‍👧‍👦' => 'משפחה: אישה, בת, בן',
    '👩‍👧‍👧' => 'משפחה: אישה, בת, בת',
    '🧑‍🤝‍🧑' => 'אנשים מחזיקים ידיים',
    '🧑‍🧑‍🧒' => 'משפחה: הורה, הורה, ילד',
    '🧑‍🧒‍🧒' => 'משפחה: מבוגר, מבוגרת, ילד, ילדה',
    '🧑🏻‍🦰' => 'אדם: גוון עור בהיר, שיער ג׳ינג׳י',
    '🧑🏼‍🦰' => 'אדם: גוון עור בהיר בינוני, שיער ג׳ינג׳י',
    '🧑🏽‍🦰' => 'אדם: גוון עור בינוני, שיער ג׳ינג׳י',
    '🧑🏾‍🦰' => 'אדם: גוון עור כהה בינוני, שיער ג׳ינג׳י',
    '🧑🏿‍🦰' => 'אדם: גוון עור כהה, שיער ג׳ינג׳י',
    '🧑🏻‍🦱' => 'אדם: גוון עור בהיר, שיער מתולתל',
    '🧑🏼‍🦱' => 'אדם: גוון עור בהיר בינוני, שיער מתולתל',
    '🧑🏽‍🦱' => 'אדם: גוון עור בינוני, שיער מתולתל',
    '🧑🏾‍🦱' => 'אדם: גוון עור כהה בינוני, שיער מתולתל',
    '🧑🏿‍🦱' => 'אדם: גוון עור כהה, שיער מתולתל',
    '🧑🏻‍🦳' => 'אדם: גוון עור בהיר, שיער לבן',
    '🧑🏼‍🦳' => 'אדם: גוון עור בהיר בינוני, שיער לבן',
    '🧑🏽‍🦳' => 'אדם: גוון עור בינוני, שיער לבן',
    '🧑🏾‍🦳' => 'אדם: גוון עור כהה בינוני, שיער לבן',
    '🧑🏿‍🦳' => 'אדם: גוון עור כהה, שיער לבן',
    '🧑🏻‍🦲' => 'אדם: גוון עור בהיר, קירח',
    '🧑🏼‍🦲' => 'אדם: גוון עור בהיר בינוני, קירח',
    '🧑🏽‍🦲' => 'אדם: גוון עור בינוני, קירח',
    '🧑🏾‍🦲' => 'אדם: גוון עור כהה בינוני, קירח',
    '🧑🏿‍🦲' => 'אדם: גוון עור כהה, קירח',
    '🧑🏻‍🩰' => 'רקדן בלט: גוון עור בהיר',
    '🧑🏼‍🩰' => 'רקדן בלט: גוון עור בהיר בינוני',
    '🧑🏽‍🩰' => 'רקדן בלט: גוון עור בינוני',
    '🧑🏾‍🩰' => 'רקדן בלט: גוון עור כהה בינוני',
    '🧑🏿‍🩰' => 'רקדן בלט: גוון עור כהה',
    '🧔🏻‍♂' => 'גבר עם זקן: גוון עור בהיר',
    '🧔🏼‍♂' => 'גבר עם זקן: גוון עור בהיר בינוני',
    '🧔🏽‍♂' => 'גבר עם זקן: גוון עור בינוני',
    '🧔🏾‍♂' => 'גבר עם זקן: גוון עור כהה בינוני',
    '🧔🏿‍♂' => 'גבר עם זקן: גוון עור כהה',
    '👱🏻‍♂' => 'בלונדיני: גוון עור בהיר',
    '👱🏼‍♂' => 'בלונדיני: גוון עור בהיר בינוני',
    '👱🏽‍♂' => 'בלונדיני: גוון עור בינוני',
    '👱🏾‍♂' => 'בלונדיני: גוון עור כהה בינוני',
    '👱🏿‍♂' => 'בלונדיני: גוון עור כהה',
    '👨🏻‍🦰' => 'איש: גוון עור בהיר, שיער ג׳ינג׳י',
    '👨🏼‍🦰' => 'איש: גוון עור בהיר בינוני, שיער ג׳ינג׳י',
    '👨🏽‍🦰' => 'איש: גוון עור בינוני, שיער ג׳ינג׳י',
    '👨🏾‍🦰' => 'איש: גוון עור כהה בינוני, שיער ג׳ינג׳י',
    '👨🏿‍🦰' => 'איש: גוון עור כהה, שיער ג׳ינג׳י',
    '👨🏻‍🦱' => 'איש: גוון עור בהיר, שיער מתולתל',
    '👨🏼‍🦱' => 'איש: גוון עור בהיר בינוני, שיער מתולתל',
    '👨🏽‍🦱' => 'איש: גוון עור בינוני, שיער מתולתל',
    '👨🏾‍🦱' => 'איש: גוון עור כהה בינוני, שיער מתולתל',
    '👨🏿‍🦱' => 'איש: גוון עור כהה, שיער מתולתל',
    '👨🏻‍🦳' => 'איש: גוון עור בהיר, שיער לבן',
    '👨🏼‍🦳' => 'איש: גוון עור בהיר בינוני, שיער לבן',
    '👨🏽‍🦳' => 'איש: גוון עור בינוני, שיער לבן',
    '👨🏾‍🦳' => 'איש: גוון עור כהה בינוני, שיער לבן',
    '👨🏿‍🦳' => 'איש: גוון עור כהה, שיער לבן',
    '👨🏻‍🦲' => 'איש: גוון עור בהיר, קירח',
    '👨🏼‍🦲' => 'איש: גוון עור בהיר בינוני, קירח',
    '👨🏽‍🦲' => 'איש: גוון עור בינוני, קירח',
    '👨🏾‍🦲' => 'איש: גוון עור כהה בינוני, קירח',
    '👨🏿‍🦲' => 'איש: גוון עור כהה, קירח',
    '🧔🏻‍♀' => 'אישה עם זקן: גוון עור בהיר',
    '🧔🏼‍♀' => 'אישה עם זקן: גוון עור בהיר בינוני',
    '🧔🏽‍♀' => 'אישה עם זקן: גוון עור בינוני',
    '🧔🏾‍♀' => 'אישה עם זקן: גוון עור כהה בינוני',
    '🧔🏿‍♀' => 'אישה עם זקן: גוון עור כהה',
    '👱🏻‍♀' => 'בלונדינית: גוון עור בהיר',
    '👱🏼‍♀' => 'בלונדינית: גוון עור בהיר בינוני',
    '👱🏽‍♀' => 'בלונדינית: גוון עור בינוני',
    '👱🏾‍♀' => 'בלונדינית: גוון עור כהה בינוני',
    '👱🏿‍♀' => 'בלונדינית: גוון עור כהה',
    '👩🏻‍🦰' => 'אישה: גוון עור בהיר, שיער ג׳ינג׳י',
    '👩🏼‍🦰' => 'אישה: גוון עור בהיר בינוני, שיער ג׳ינג׳י',
    '👩🏽‍🦰' => 'אישה: גוון עור בינוני, שיער ג׳ינג׳י',
    '👩🏾‍🦰' => 'אישה: גוון עור כהה בינוני, שיער ג׳ינג׳י',
    '👩🏿‍🦰' => 'אישה: גוון עור כהה, שיער ג׳ינג׳י',
    '👩🏻‍🦱' => 'אישה: גוון עור בהיר, שיער מתולתל',
    '👩🏼‍🦱' => 'אישה: גוון עור בהיר בינוני, שיער מתולתל',
    '👩🏽‍🦱' => 'אישה: גוון עור בינוני, שיער מתולתל',
    '👩🏾‍🦱' => 'אישה: גוון עור כהה בינוני, שיער מתולתל',
    '👩🏿‍🦱' => 'אישה: גוון עור כהה, שיער מתולתל',
    '👩🏻‍🦳' => 'אישה: גוון עור בהיר, שיער לבן',
    '👩🏼‍🦳' => 'אישה: גוון עור בהיר בינוני, שיער לבן',
    '👩🏽‍🦳' => 'אישה: גוון עור בינוני, שיער לבן',
    '👩🏾‍🦳' => 'אישה: גוון עור כהה בינוני, שיער לבן',
    '👩🏿‍🦳' => 'אישה: גוון עור כהה, שיער לבן',
    '👩🏻‍🦲' => 'אישה: גוון עור בהיר, קירח',
    '👩🏼‍🦲' => 'אישה: גוון עור בהיר בינוני, קירח',
    '👩🏽‍🦲' => 'אישה: גוון עור בינוני, קירח',
    '👩🏾‍🦲' => 'אישה: גוון עור כהה בינוני, קירח',
    '👩🏿‍🦲' => 'אישה: גוון עור כהה, קירח',
    '🙍🏻‍♂' => 'גבר מדוכדך: גוון עור בהיר',
    '🙍🏼‍♂' => 'גבר מדוכדך: גוון עור בהיר בינוני',
    '🙍🏽‍♂' => 'גבר מדוכדך: גוון עור בינוני',
    '🙍🏾‍♂' => 'גבר מדוכדך: גוון עור כהה בינוני',
    '🙍🏿‍♂' => 'גבר מדוכדך: גוון עור כהה',
    '🙍🏻‍♀' => 'אישה מדוכדכת: גוון עור בהיר',
    '🙍🏼‍♀' => 'אישה מדוכדכת: גוון עור בהיר בינוני',
    '🙍🏽‍♀' => 'אישה מדוכדכת: גוון עור בינוני',
    '🙍🏾‍♀' => 'אישה מדוכדכת: גוון עור כהה בינוני',
    '🙍🏿‍♀' => 'אישה מדוכדכת: גוון עור כהה',
    '🙎🏻‍♂' => 'גבר מבואס: גוון עור בהיר',
    '🙎🏼‍♂' => 'גבר מבואס: גוון עור בהיר בינוני',
    '🙎🏽‍♂' => 'גבר מבואס: גוון עור בינוני',
    '🙎🏾‍♂' => 'גבר מבואס: גוון עור כהה בינוני',
    '🙎🏿‍♂' => 'גבר מבואס: גוון עור כהה',
    '🙎🏻‍♀' => 'אישה מבואסת: גוון עור בהיר',
    '🙎🏼‍♀' => 'אישה מבואסת: גוון עור בהיר בינוני',
    '🙎🏽‍♀' => 'אישה מבואסת: גוון עור בינוני',
    '🙎🏾‍♀' => 'אישה מבואסת: גוון עור כהה בינוני',
    '🙎🏿‍♀' => 'אישה מבואסת: גוון עור כהה',
    '🙅🏻‍♂' => 'גבר מסמן ״לא״: גוון עור בהיר',
    '🙅🏼‍♂' => 'גבר מסמן ״לא״: גוון עור בהיר בינוני',
    '🙅🏽‍♂' => 'גבר מסמן ״לא״: גוון עור בינוני',
    '🙅🏾‍♂' => 'גבר מסמן ״לא״: גוון עור כהה בינוני',
    '🙅🏿‍♂' => 'גבר מסמן ״לא״: גוון עור כהה',
    '🙅🏻‍♀' => 'אישה מסמנת ״לא״: גוון עור בהיר',
    '🙅🏼‍♀' => 'אישה מסמנת ״לא״: גוון עור בהיר בינוני',
    '🙅🏽‍♀' => 'אישה מסמנת ״לא״: גוון עור בינוני',
    '🙅🏾‍♀' => 'אישה מסמנת ״לא״: גוון עור כהה בינוני',
    '🙅🏿‍♀' => 'אישה מסמנת ״לא״: גוון עור כהה',
    '🙆🏻‍♂' => 'גבר עם הידיים על הראש: גוון עור בהיר',
    '🙆🏼‍♂' => 'גבר עם הידיים על הראש: גוון עור בהיר בינוני',
    '🙆🏽‍♂' => 'גבר עם הידיים על הראש: גוון עור בינוני',
    '🙆🏾‍♂' => 'גבר עם הידיים על הראש: גוון עור כהה בינוני',
    '🙆🏿‍♂' => 'גבר עם הידיים על הראש: גוון עור כהה',
    '🙆🏻‍♀' => 'אישה עם ידיים על הראש: גוון עור בהיר',
    '🙆🏼‍♀' => 'אישה עם ידיים על הראש: גוון עור בהיר בינוני',
    '🙆🏽‍♀' => 'אישה עם ידיים על הראש: גוון עור בינוני',
    '🙆🏾‍♀' => 'אישה עם ידיים על הראש: גוון עור כהה בינוני',
    '🙆🏿‍♀' => 'אישה עם ידיים על הראש: גוון עור כהה',
    '💁🏻‍♂' => 'איש בדלפק מידע או מבקש טיפ: גוון עור בהיר',
    '💁🏼‍♂' => 'איש בדלפק מידע או מבקש טיפ: גוון עור בהיר בינוני',
    '💁🏽‍♂' => 'איש בדלפק מידע או מבקש טיפ: גוון עור בינוני',
    '💁🏾‍♂' => 'איש בדלפק מידע או מבקש טיפ: גוון עור כהה בינוני',
    '💁🏿‍♂' => 'איש בדלפק מידע או מבקש טיפ: גוון עור כהה',
    '💁🏻‍♀' => 'אישה מבקשת טיפ: גוון עור בהיר',
    '💁🏼‍♀' => 'אישה מבקשת טיפ: גוון עור בהיר בינוני',
    '💁🏽‍♀' => 'אישה מבקשת טיפ: גוון עור בינוני',
    '💁🏾‍♀' => 'אישה מבקשת טיפ: גוון עור כהה בינוני',
    '💁🏿‍♀' => 'אישה מבקשת טיפ: גוון עור כהה',
    '🙋🏻‍♂' => 'גבר מרים את היד: גוון עור בהיר',
    '🙋🏼‍♂' => 'גבר מרים את היד: גוון עור בהיר בינוני',
    '🙋🏽‍♂' => 'גבר מרים את היד: גוון עור בינוני',
    '🙋🏾‍♂' => 'גבר מרים את היד: גוון עור כהה בינוני',
    '🙋🏿‍♂' => 'גבר מרים את היד: גוון עור כהה',
    '🙋🏻‍♀' => 'אישה מנופפת בידה: גוון עור בהיר',
    '🙋🏼‍♀' => 'אישה מנופפת בידה: גוון עור בהיר בינוני',
    '🙋🏽‍♀' => 'אישה מנופפת בידה: גוון עור בינוני',
    '🙋🏾‍♀' => 'אישה מנופפת בידה: גוון עור כהה בינוני',
    '🙋🏿‍♀' => 'אישה מנופפת בידה: גוון עור כהה',
    '🧏🏻‍♂' => 'איש כבד שמיעה: גוון עור בהיר',
    '🧏🏼‍♂' => 'איש כבד שמיעה: גוון עור בהיר בינוני',
    '🧏🏽‍♂' => 'איש כבד שמיעה: גוון עור בינוני',
    '🧏🏾‍♂' => 'איש כבד שמיעה: גוון עור כהה בינוני',
    '🧏🏿‍♂' => 'איש כבד שמיעה: גוון עור כהה',
    '🧏🏻‍♀' => 'אישה כבדת שמיעה: גוון עור בהיר',
    '🧏🏼‍♀' => 'אישה כבדת שמיעה: גוון עור בהיר בינוני',
    '🧏🏽‍♀' => 'אישה כבדת שמיעה: גוון עור בינוני',
    '🧏🏾‍♀' => 'אישה כבדת שמיעה: גוון עור כהה בינוני',
    '🧏🏿‍♀' => 'אישה כבדת שמיעה: גוון עור כהה',
    '🙇🏻‍♂' => 'גבר משתחווה: גוון עור בהיר',
    '🙇🏼‍♂' => 'גבר משתחווה: גוון עור בהיר בינוני',
    '🙇🏽‍♂' => 'גבר משתחווה: גוון עור בינוני',
    '🙇🏾‍♂' => 'גבר משתחווה: גוון עור כהה בינוני',
    '🙇🏿‍♂' => 'גבר משתחווה: גוון עור כהה',
    '🙇🏻‍♀' => 'אישה משתחווה: גוון עור בהיר',
    '🙇🏼‍♀' => 'אישה משתחווה: גוון עור בהיר בינוני',
    '🙇🏽‍♀' => 'אישה משתחווה: גוון עור בינוני',
    '🙇🏾‍♀' => 'אישה משתחווה: גוון עור כהה בינוני',
    '🙇🏿‍♀' => 'אישה משתחווה: גוון עור כהה',
    '🤦🏻‍♂' => 'גבר מתוסכל: גוון עור בהיר',
    '🤦🏼‍♂' => 'גבר מתוסכל: גוון עור בהיר בינוני',
    '🤦🏽‍♂' => 'גבר מתוסכל: גוון עור בינוני',
    '🤦🏾‍♂' => 'גבר מתוסכל: גוון עור כהה בינוני',
    '🤦🏿‍♂' => 'גבר מתוסכל: גוון עור כהה',
    '🤦🏻‍♀' => 'אישה מתוסכלת: גוון עור בהיר',
    '🤦🏼‍♀' => 'אישה מתוסכלת: גוון עור בהיר בינוני',
    '🤦🏽‍♀' => 'אישה מתוסכלת: גוון עור בינוני',
    '🤦🏾‍♀' => 'אישה מתוסכלת: גוון עור כהה בינוני',
    '🤦🏿‍♀' => 'אישה מתוסכלת: גוון עור כהה',
    '🤷🏻‍♂' => 'גבר מושך בכתפיו: גוון עור בהיר',
    '🤷🏼‍♂' => 'גבר מושך בכתפיו: גוון עור בהיר בינוני',
    '🤷🏽‍♂' => 'גבר מושך בכתפיו: גוון עור בינוני',
    '🤷🏾‍♂' => 'גבר מושך בכתפיו: גוון עור כהה בינוני',
    '🤷🏿‍♂' => 'גבר מושך בכתפיו: גוון עור כהה',
    '🤷🏻‍♀' => 'אישה מושכת בכתפיה: גוון עור בהיר',
    '🤷🏼‍♀' => 'אישה מושכת בכתפיה: גוון עור בהיר בינוני',
    '🤷🏽‍♀' => 'אישה מושכת בכתפיה: גוון עור בינוני',
    '🤷🏾‍♀' => 'אישה מושכת בכתפיה: גוון עור כהה בינוני',
    '🤷🏿‍♀' => 'אישה מושכת בכתפיה: גוון עור כהה',
    '🧑🏻‍⚕' => 'עובד בשירותי הבריאות: גוון עור בהיר',
    '🧑🏼‍⚕' => 'עובד בשירותי הבריאות: גוון עור בהיר בינוני',
    '🧑🏽‍⚕' => 'עובד בשירותי הבריאות: גוון עור בינוני',
    '🧑🏾‍⚕' => 'עובד בשירותי הבריאות: גוון עור כהה בינוני',
    '🧑🏿‍⚕' => 'עובד בשירותי הבריאות: גוון עור כהה',
    '👨🏻‍⚕' => 'רופא: גוון עור בהיר',
    '👨🏼‍⚕' => 'רופא: גוון עור בהיר בינוני',
    '👨🏽‍⚕' => 'רופא: גוון עור בינוני',
    '👨🏾‍⚕' => 'רופא: גוון עור כהה בינוני',
    '👨🏿‍⚕' => 'רופא: גוון עור כהה',
    '👩🏻‍⚕' => 'רופאה: גוון עור בהיר',
    '👩🏼‍⚕' => 'רופאה: גוון עור בהיר בינוני',
    '👩🏽‍⚕' => 'רופאה: גוון עור בינוני',
    '👩🏾‍⚕' => 'רופאה: גוון עור כהה בינוני',
    '👩🏿‍⚕' => 'רופאה: גוון עור כהה',
    '🧑🏻‍🎓' => 'סטודנט/ית: גוון עור בהיר',
    '🧑🏼‍🎓' => 'סטודנט/ית: גוון עור בהיר בינוני',
    '🧑🏽‍🎓' => 'סטודנט/ית: גוון עור בינוני',
    '🧑🏾‍🎓' => 'סטודנט/ית: גוון עור כהה בינוני',
    '🧑🏿‍🎓' => 'סטודנט/ית: גוון עור כהה',
    '👨🏻‍🎓' => 'סטודנט: גוון עור בהיר',
    '👨🏼‍🎓' => 'סטודנט: גוון עור בהיר בינוני',
    '👨🏽‍🎓' => 'סטודנט: גוון עור בינוני',
    '👨🏾‍🎓' => 'סטודנט: גוון עור כהה בינוני',
    '👨🏿‍🎓' => 'סטודנט: גוון עור כהה',
    '👩🏻‍🎓' => 'סטודנטית: גוון עור בהיר',
    '👩🏼‍🎓' => 'סטודנטית: גוון עור בהיר בינוני',
    '👩🏽‍🎓' => 'סטודנטית: גוון עור בינוני',
    '👩🏾‍🎓' => 'סטודנטית: גוון עור כהה בינוני',
    '👩🏿‍🎓' => 'סטודנטית: גוון עור כהה',
    '🧑🏻‍🏫' => 'מצוות המורים: גוון עור בהיר',
    '🧑🏼‍🏫' => 'מצוות המורים: גוון עור בהיר בינוני',
    '🧑🏽‍🏫' => 'מצוות המורים: גוון עור בינוני',
    '🧑🏾‍🏫' => 'מצוות המורים: גוון עור כהה בינוני',
    '🧑🏿‍🏫' => 'מצוות המורים: גוון עור כהה',
    '👨🏻‍🏫' => 'מורה: גוון עור בהיר',
    '👨🏼‍🏫' => 'מורה: גוון עור בהיר בינוני',
    '👨🏽‍🏫' => 'מורה: גוון עור בינוני',
    '👨🏾‍🏫' => 'מורה: גוון עור כהה בינוני',
    '👨🏿‍🏫' => 'מורה: גוון עור כהה',
    '👩🏻‍🏫' => 'מוֹרָה: גוון עור בהיר',
    '👩🏼‍🏫' => 'מוֹרָה: גוון עור בהיר בינוני',
    '👩🏽‍🏫' => 'מוֹרָה: גוון עור בינוני',
    '👩🏾‍🏫' => 'מוֹרָה: גוון עור כהה בינוני',
    '👩🏿‍🏫' => 'מוֹרָה: גוון עור כהה',
    '🧑🏻‍⚖' => 'שופט/ת: גוון עור בהיר',
    '🧑🏼‍⚖' => 'שופט/ת: גוון עור בהיר בינוני',
    '🧑🏽‍⚖' => 'שופט/ת: גוון עור בינוני',
    '🧑🏾‍⚖' => 'שופט/ת: גוון עור כהה בינוני',
    '🧑🏿‍⚖' => 'שופט/ת: גוון עור כהה',
    '👨🏻‍⚖' => 'שופט: גוון עור בהיר',
    '👨🏼‍⚖' => 'שופט: גוון עור בהיר בינוני',
    '👨🏽‍⚖' => 'שופט: גוון עור בינוני',
    '👨🏾‍⚖' => 'שופט: גוון עור כהה בינוני',
    '👨🏿‍⚖' => 'שופט: גוון עור כהה',
    '👩🏻‍⚖' => 'שופטת: גוון עור בהיר',
    '👩🏼‍⚖' => 'שופטת: גוון עור בהיר בינוני',
    '👩🏽‍⚖' => 'שופטת: גוון עור בינוני',
    '👩🏾‍⚖' => 'שופטת: גוון עור כהה בינוני',
    '👩🏿‍⚖' => 'שופטת: גוון עור כהה',
    '🧑🏻‍🌾' => 'חקלאי/ת: גוון עור בהיר',
    '🧑🏼‍🌾' => 'חקלאי/ת: גוון עור בהיר בינוני',
    '🧑🏽‍🌾' => 'חקלאי/ת: גוון עור בינוני',
    '🧑🏾‍🌾' => 'חקלאי/ת: גוון עור כהה בינוני',
    '🧑🏿‍🌾' => 'חקלאי/ת: גוון עור כהה',
    '👨🏻‍🌾' => 'חקלאי: גוון עור בהיר',
    '👨🏼‍🌾' => 'חקלאי: גוון עור בהיר בינוני',
    '👨🏽‍🌾' => 'חקלאי: גוון עור בינוני',
    '👨🏾‍🌾' => 'חקלאי: גוון עור כהה בינוני',
    '👨🏿‍🌾' => 'חקלאי: גוון עור כהה',
    '👩🏻‍🌾' => 'חקלאית: גוון עור בהיר',
    '👩🏼‍🌾' => 'חקלאית: גוון עור בהיר בינוני',
    '👩🏽‍🌾' => 'חקלאית: גוון עור בינוני',
    '👩🏾‍🌾' => 'חקלאית: גוון עור כהה בינוני',
    '👩🏿‍🌾' => 'חקלאית: גוון עור כהה',
    '🧑🏻‍🍳' => 'טבח/ית: גוון עור בהיר',
    '🧑🏼‍🍳' => 'טבח/ית: גוון עור בהיר בינוני',
    '🧑🏽‍🍳' => 'טבח/ית: גוון עור בינוני',
    '🧑🏾‍🍳' => 'טבח/ית: גוון עור כהה בינוני',
    '🧑🏿‍🍳' => 'טבח/ית: גוון עור כהה',
    '👨🏻‍🍳' => 'טבח: גוון עור בהיר',
    '👨🏼‍🍳' => 'טבח: גוון עור בהיר בינוני',
    '👨🏽‍🍳' => 'טבח: גוון עור בינוני',
    '👨🏾‍🍳' => 'טבח: גוון עור כהה בינוני',
    '👨🏿‍🍳' => 'טבח: גוון עור כהה',
    '👩🏻‍🍳' => 'טבחית: גוון עור בהיר',
    '👩🏼‍🍳' => 'טבחית: גוון עור בהיר בינוני',
    '👩🏽‍🍳' => 'טבחית: גוון עור בינוני',
    '👩🏾‍🍳' => 'טבחית: גוון עור כהה בינוני',
    '👩🏿‍🍳' => 'טבחית: גוון עור כהה',
    '🧑🏻‍🔧' => 'מכונאי/ת: גוון עור בהיר',
    '🧑🏼‍🔧' => 'מכונאי/ת: גוון עור בהיר בינוני',
    '🧑🏽‍🔧' => 'מכונאי/ת: גוון עור בינוני',
    '🧑🏾‍🔧' => 'מכונאי/ת: גוון עור כהה בינוני',
    '🧑🏿‍🔧' => 'מכונאי/ת: גוון עור כהה',
    '👨🏻‍🔧' => 'מכונאי: גוון עור בהיר',
    '👨🏼‍🔧' => 'מכונאי: גוון עור בהיר בינוני',
    '👨🏽‍🔧' => 'מכונאי: גוון עור בינוני',
    '👨🏾‍🔧' => 'מכונאי: גוון עור כהה בינוני',
    '👨🏿‍🔧' => 'מכונאי: גוון עור כהה',
    '👩🏻‍🔧' => 'מכונאית: גוון עור בהיר',
    '👩🏼‍🔧' => 'מכונאית: גוון עור בהיר בינוני',
    '👩🏽‍🔧' => 'מכונאית: גוון עור בינוני',
    '👩🏾‍🔧' => 'מכונאית: גוון עור כהה בינוני',
    '👩🏿‍🔧' => 'מכונאית: גוון עור כהה',
    '🧑🏻‍🏭' => 'פועל/ת: גוון עור בהיר',
    '🧑🏼‍🏭' => 'פועל/ת: גוון עור בהיר בינוני',
    '🧑🏽‍🏭' => 'פועל/ת: גוון עור בינוני',
    '🧑🏾‍🏭' => 'פועל/ת: גוון עור כהה בינוני',
    '🧑🏿‍🏭' => 'פועל/ת: גוון עור כהה',
    '👨🏻‍🏭' => 'פועל: גוון עור בהיר',
    '👨🏼‍🏭' => 'פועל: גוון עור בהיר בינוני',
    '👨🏽‍🏭' => 'פועל: גוון עור בינוני',
    '👨🏾‍🏭' => 'פועל: גוון עור כהה בינוני',
    '👨🏿‍🏭' => 'פועל: גוון עור כהה',
    '👩🏻‍🏭' => 'פועלת: גוון עור בהיר',
    '👩🏼‍🏭' => 'פועלת: גוון עור בהיר בינוני',
    '👩🏽‍🏭' => 'פועלת: גוון עור בינוני',
    '👩🏾‍🏭' => 'פועלת: גוון עור כהה בינוני',
    '👩🏿‍🏭' => 'פועלת: גוון עור כהה',
    '🧑🏻‍💼' => 'עובד/ת משרד: גוון עור בהיר',
    '🧑🏼‍💼' => 'עובד/ת משרד: גוון עור בהיר בינוני',
    '🧑🏽‍💼' => 'עובד/ת משרד: גוון עור בינוני',
    '🧑🏾‍💼' => 'עובד/ת משרד: גוון עור כהה בינוני',
    '🧑🏿‍💼' => 'עובד/ת משרד: גוון עור כהה',
    '👨🏻‍💼' => 'עובד משרד: גוון עור בהיר',
    '👨🏼‍💼' => 'עובד משרד: גוון עור בהיר בינוני',
    '👨🏽‍💼' => 'עובד משרד: גוון עור בינוני',
    '👨🏾‍💼' => 'עובד משרד: גוון עור כהה בינוני',
    '👨🏿‍💼' => 'עובד משרד: גוון עור כהה',
    '👩🏻‍💼' => 'עובדת משרד: גוון עור בהיר',
    '👩🏼‍💼' => 'עובדת משרד: גוון עור בהיר בינוני',
    '👩🏽‍💼' => 'עובדת משרד: גוון עור בינוני',
    '👩🏾‍💼' => 'עובדת משרד: גוון עור כהה בינוני',
    '👩🏿‍💼' => 'עובדת משרד: גוון עור כהה',
    '🧑🏻‍🔬' => 'מדען/ית: גוון עור בהיר',
    '🧑🏼‍🔬' => 'מדען/ית: גוון עור בהיר בינוני',
    '🧑🏽‍🔬' => 'מדען/ית: גוון עור בינוני',
    '🧑🏾‍🔬' => 'מדען/ית: גוון עור כהה בינוני',
    '🧑🏿‍🔬' => 'מדען/ית: גוון עור כהה',
    '👨🏻‍🔬' => 'מדען: גוון עור בהיר',
    '👨🏼‍🔬' => 'מדען: גוון עור בהיר בינוני',
    '👨🏽‍🔬' => 'מדען: גוון עור בינוני',
    '👨🏾‍🔬' => 'מדען: גוון עור כהה בינוני',
    '👨🏿‍🔬' => 'מדען: גוון עור כהה',
    '👩🏻‍🔬' => 'מדענית: גוון עור בהיר',
    '👩🏼‍🔬' => 'מדענית: גוון עור בהיר בינוני',
    '👩🏽‍🔬' => 'מדענית: גוון עור בינוני',
    '👩🏾‍🔬' => 'מדענית: גוון עור כהה בינוני',
    '👩🏿‍🔬' => 'מדענית: גוון עור כהה',
    '🧑🏻‍💻' => 'טכנולוג/ית: גוון עור בהיר',
    '🧑🏼‍💻' => 'טכנולוג/ית: גוון עור בהיר בינוני',
    '🧑🏽‍💻' => 'טכנולוג/ית: גוון עור בינוני',
    '🧑🏾‍💻' => 'טכנולוג/ית: גוון עור כהה בינוני',
    '🧑🏿‍💻' => 'טכנולוג/ית: גוון עור כהה',
    '👨🏻‍💻' => 'טכנולוג: גוון עור בהיר',
    '👨🏼‍💻' => 'טכנולוג: גוון עור בהיר בינוני',
    '👨🏽‍💻' => 'טכנולוג: גוון עור בינוני',
    '👨🏾‍💻' => 'טכנולוג: גוון עור כהה בינוני',
    '👨🏿‍💻' => 'טכנולוג: גוון עור כהה',
    '👩🏻‍💻' => 'טכנולוגית: גוון עור בהיר',
    '👩🏼‍💻' => 'טכנולוגית: גוון עור בהיר בינוני',
    '👩🏽‍💻' => 'טכנולוגית: גוון עור בינוני',
    '👩🏾‍💻' => 'טכנולוגית: גוון עור כהה בינוני',
    '👩🏿‍💻' => 'טכנולוגית: גוון עור כהה',
    '🧑🏻‍🎤' => 'זמר/ת: גוון עור בהיר',
    '🧑🏼‍🎤' => 'זמר/ת: גוון עור בהיר בינוני',
    '🧑🏽‍🎤' => 'זמר/ת: גוון עור בינוני',
    '🧑🏾‍🎤' => 'זמר/ת: גוון עור כהה בינוני',
    '🧑🏿‍🎤' => 'זמר/ת: גוון עור כהה',
    '👨🏻‍🎤' => 'זמר: גוון עור בהיר',
    '👨🏼‍🎤' => 'זמר: גוון עור בהיר בינוני',
    '👨🏽‍🎤' => 'זמר: גוון עור בינוני',
    '👨🏾‍🎤' => 'זמר: גוון עור כהה בינוני',
    '👨🏿‍🎤' => 'זמר: גוון עור כהה',
    '👩🏻‍🎤' => 'זמרת: גוון עור בהיר',
    '👩🏼‍🎤' => 'זמרת: גוון עור בהיר בינוני',
    '👩🏽‍🎤' => 'זמרת: גוון עור בינוני',
    '👩🏾‍🎤' => 'זמרת: גוון עור כהה בינוני',
    '👩🏿‍🎤' => 'זמרת: גוון עור כהה',
    '🧑🏻‍🎨' => 'אומן/ית: גוון עור בהיר',
    '🧑🏼‍🎨' => 'אומן/ית: גוון עור בהיר בינוני',
    '🧑🏽‍🎨' => 'אומן/ית: גוון עור בינוני',
    '🧑🏾‍🎨' => 'אומן/ית: גוון עור כהה בינוני',
    '🧑🏿‍🎨' => 'אומן/ית: גוון עור כהה',
    '👨🏻‍🎨' => 'אמן: גוון עור בהיר',
    '👨🏼‍🎨' => 'אמן: גוון עור בהיר בינוני',
    '👨🏽‍🎨' => 'אמן: גוון עור בינוני',
    '👨🏾‍🎨' => 'אמן: גוון עור כהה בינוני',
    '👨🏿‍🎨' => 'אמן: גוון עור כהה',
    '👩🏻‍🎨' => 'אמנית: גוון עור בהיר',
    '👩🏼‍🎨' => 'אמנית: גוון עור בהיר בינוני',
    '👩🏽‍🎨' => 'אמנית: גוון עור בינוני',
    '👩🏾‍🎨' => 'אמנית: גוון עור כהה בינוני',
    '👩🏿‍🎨' => 'אמנית: גוון עור כהה',
    '🧑🏻‍✈' => 'טייס/ת: גוון עור בהיר',
    '🧑🏼‍✈' => 'טייס/ת: גוון עור בהיר בינוני',
    '🧑🏽‍✈' => 'טייס/ת: גוון עור בינוני',
    '🧑🏾‍✈' => 'טייס/ת: גוון עור כהה בינוני',
    '🧑🏿‍✈' => 'טייס/ת: גוון עור כהה',
    '👨🏻‍✈' => 'טייס: גוון עור בהיר',
    '👨🏼‍✈' => 'טייס: גוון עור בהיר בינוני',
    '👨🏽‍✈' => 'טייס: גוון עור בינוני',
    '👨🏾‍✈' => 'טייס: גוון עור כהה בינוני',
    '👨🏿‍✈' => 'טייס: גוון עור כהה',
    '👩🏻‍✈' => 'טייסת: גוון עור בהיר',
    '👩🏼‍✈' => 'טייסת: גוון עור בהיר בינוני',
    '👩🏽‍✈' => 'טייסת: גוון עור בינוני',
    '👩🏾‍✈' => 'טייסת: גוון עור כהה בינוני',
    '👩🏿‍✈' => 'טייסת: גוון עור כהה',
    '🧑🏻‍🚀' => 'אסטרונאוט/ית: גוון עור בהיר',
    '🧑🏼‍🚀' => 'אסטרונאוט/ית: גוון עור בהיר בינוני',
    '🧑🏽‍🚀' => 'אסטרונאוט/ית: גוון עור בינוני',
    '🧑🏾‍🚀' => 'אסטרונאוט/ית: גוון עור כהה בינוני',
    '🧑🏿‍🚀' => 'אסטרונאוט/ית: גוון עור כהה',
    '👨🏻‍🚀' => 'אסטרונאוט: גוון עור בהיר',
    '👨🏼‍🚀' => 'אסטרונאוט: גוון עור בהיר בינוני',
    '👨🏽‍🚀' => 'אסטרונאוט: גוון עור בינוני',
    '👨🏾‍🚀' => 'אסטרונאוט: גוון עור כהה בינוני',
    '👨🏿‍🚀' => 'אסטרונאוט: גוון עור כהה',
    '👩🏻‍🚀' => 'אסטרונאוטית: גוון עור בהיר',
    '👩🏼‍🚀' => 'אסטרונאוטית: גוון עור בהיר בינוני',
    '👩🏽‍🚀' => 'אסטרונאוטית: גוון עור בינוני',
    '👩🏾‍🚀' => 'אסטרונאוטית: גוון עור כהה בינוני',
    '👩🏿‍🚀' => 'אסטרונאוטית: גוון עור כהה',
    '🧑🏻‍🚒' => 'לוחם/ת אש: גוון עור בהיר',
    '🧑🏼‍🚒' => 'לוחם/ת אש: גוון עור בהיר בינוני',
    '🧑🏽‍🚒' => 'לוחם/ת אש: גוון עור בינוני',
    '🧑🏾‍🚒' => 'לוחם/ת אש: גוון עור כהה בינוני',
    '🧑🏿‍🚒' => 'לוחם/ת אש: גוון עור כהה',
    '👨🏻‍🚒' => 'לוחם אש: גוון עור בהיר',
    '👨🏼‍🚒' => 'לוחם אש: גוון עור בהיר בינוני',
    '👨🏽‍🚒' => 'לוחם אש: גוון עור בינוני',
    '👨🏾‍🚒' => 'לוחם אש: גוון עור כהה בינוני',
    '👨🏿‍🚒' => 'לוחם אש: גוון עור כהה',
    '👩🏻‍🚒' => 'לוחמת אש: גוון עור בהיר',
    '👩🏼‍🚒' => 'לוחמת אש: גוון עור בהיר בינוני',
    '👩🏽‍🚒' => 'לוחמת אש: גוון עור בינוני',
    '👩🏾‍🚒' => 'לוחמת אש: גוון עור כהה בינוני',
    '👩🏿‍🚒' => 'לוחמת אש: גוון עור כהה',
    '👮🏻‍♂' => 'קצין משטרה: גוון עור בהיר',
    '👮🏼‍♂' => 'קצין משטרה: גוון עור בהיר בינוני',
    '👮🏽‍♂' => 'קצין משטרה: גוון עור בינוני',
    '👮🏾‍♂' => 'קצין משטרה: גוון עור כהה בינוני',
    '👮🏿‍♂' => 'קצין משטרה: גוון עור כהה',
    '👮🏻‍♀' => 'קצינת משטרה: גוון עור בהיר',
    '👮🏼‍♀' => 'קצינת משטרה: גוון עור בהיר בינוני',
    '👮🏽‍♀' => 'קצינת משטרה: גוון עור בינוני',
    '👮🏾‍♀' => 'קצינת משטרה: גוון עור כהה בינוני',
    '👮🏿‍♀' => 'קצינת משטרה: גוון עור כהה',
    '🕵🏻‍♂' => 'חוקר פרטי: גוון עור בהיר',
    '🕵🏼‍♂' => 'חוקר פרטי: גוון עור בהיר בינוני',
    '🕵🏽‍♂' => 'חוקר פרטי: גוון עור בינוני',
    '🕵🏾‍♂' => 'חוקר פרטי: גוון עור כהה בינוני',
    '🕵🏿‍♂' => 'חוקר פרטי: גוון עור כהה',
    '🕵🏻‍♀' => 'חוקרת פרטית: גוון עור בהיר',
    '🕵🏼‍♀' => 'חוקרת פרטית: גוון עור בהיר בינוני',
    '🕵🏽‍♀' => 'חוקרת פרטית: גוון עור בינוני',
    '🕵🏾‍♀' => 'חוקרת פרטית: גוון עור כהה בינוני',
    '🕵🏿‍♀' => 'חוקרת פרטית: גוון עור כהה',
    '💂🏻‍♂' => 'מאבטח: גוון עור בהיר',
    '💂🏼‍♂' => 'מאבטח: גוון עור בהיר בינוני',
    '💂🏽‍♂' => 'מאבטח: גוון עור בינוני',
    '💂🏾‍♂' => 'מאבטח: גוון עור כהה בינוני',
    '💂🏿‍♂' => 'מאבטח: גוון עור כהה',
    '💂🏻‍♀' => 'שומרת: גוון עור בהיר',
    '💂🏼‍♀' => 'שומרת: גוון עור בהיר בינוני',
    '💂🏽‍♀' => 'שומרת: גוון עור בינוני',
    '💂🏾‍♀' => 'שומרת: גוון עור כהה בינוני',
    '💂🏿‍♀' => 'שומרת: גוון עור כהה',
    '👷🏻‍♂' => 'בנאי: גוון עור בהיר',
    '👷🏼‍♂' => 'בנאי: גוון עור בהיר בינוני',
    '👷🏽‍♂' => 'בנאי: גוון עור בינוני',
    '👷🏾‍♂' => 'בנאי: גוון עור כהה בינוני',
    '👷🏿‍♂' => 'בנאי: גוון עור כהה',
    '👷🏻‍♀' => 'פועלת בניין: גוון עור בהיר',
    '👷🏼‍♀' => 'פועלת בניין: גוון עור בהיר בינוני',
    '👷🏽‍♀' => 'פועלת בניין: גוון עור בינוני',
    '👷🏾‍♀' => 'פועלת בניין: גוון עור כהה בינוני',
    '👷🏿‍♀' => 'פועלת בניין: גוון עור כהה',
    '👳🏻‍♂' => 'גבר עם טורבן: גוון עור בהיר',
    '👳🏼‍♂' => 'גבר עם טורבן: גוון עור בהיר בינוני',
    '👳🏽‍♂' => 'גבר עם טורבן: גוון עור בינוני',
    '👳🏾‍♂' => 'גבר עם טורבן: גוון עור כהה בינוני',
    '👳🏿‍♂' => 'גבר עם טורבן: גוון עור כהה',
    '👳🏻‍♀' => 'אישה עם טורבן: גוון עור בהיר',
    '👳🏼‍♀' => 'אישה עם טורבן: גוון עור בהיר בינוני',
    '👳🏽‍♀' => 'אישה עם טורבן: גוון עור בינוני',
    '👳🏾‍♀' => 'אישה עם טורבן: גוון עור כהה בינוני',
    '👳🏿‍♀' => 'אישה עם טורבן: גוון עור כהה',
    '🤵🏻‍♂' => 'גבר בטוקסידו: גוון עור בהיר',
    '🤵🏼‍♂' => 'גבר בטוקסידו: גוון עור בהיר בינוני',
    '🤵🏽‍♂' => 'גבר בטוקסידו: גוון עור בינוני',
    '🤵🏾‍♂' => 'גבר בטוקסידו: גוון עור כהה בינוני',
    '🤵🏿‍♂' => 'גבר בטוקסידו: גוון עור כהה',
    '🤵🏻‍♀' => 'אישה בטוקסידו: גוון עור בהיר',
    '🤵🏼‍♀' => 'אישה בטוקסידו: גוון עור בהיר בינוני',
    '🤵🏽‍♀' => 'אישה בטוקסידו: גוון עור בינוני',
    '🤵🏾‍♀' => 'אישה בטוקסידו: גוון עור כהה בינוני',
    '🤵🏿‍♀' => 'אישה בטוקסידו: גוון עור כהה',
    '👰🏻‍♂' => 'איש עם הינומה: גוון עור בהיר',
    '👰🏼‍♂' => 'איש עם הינומה: גוון עור בהיר בינוני',
    '👰🏽‍♂' => 'איש עם הינומה: גוון עור בינוני',
    '👰🏾‍♂' => 'איש עם הינומה: גוון עור כהה בינוני',
    '👰🏿‍♂' => 'איש עם הינומה: גוון עור כהה',
    '👰🏻‍♀' => 'אישה עם הינומה: גוון עור בהיר',
    '👰🏼‍♀' => 'אישה עם הינומה: גוון עור בהיר בינוני',
    '👰🏽‍♀' => 'אישה עם הינומה: גוון עור בינוני',
    '👰🏾‍♀' => 'אישה עם הינומה: גוון עור כהה בינוני',
    '👰🏿‍♀' => 'אישה עם הינומה: גוון עור כהה',
    '👩🏻‍🍼' => 'אישה מניקה תינוק: גוון עור בהיר',
    '👩🏼‍🍼' => 'אישה מניקה תינוק: גוון עור בהיר בינוני',
    '👩🏽‍🍼' => 'אישה מניקה תינוק: גוון עור בינוני',
    '👩🏾‍🍼' => 'אישה מניקה תינוק: גוון עור כהה בינוני',
    '👩🏿‍🍼' => 'אישה מניקה תינוק: גוון עור כהה',
    '👨🏻‍🍼' => 'איש מניק תינוק: גוון עור בהיר',
    '👨🏼‍🍼' => 'איש מניק תינוק: גוון עור בהיר בינוני',
    '👨🏽‍🍼' => 'איש מניק תינוק: גוון עור בינוני',
    '👨🏾‍🍼' => 'איש מניק תינוק: גוון עור כהה בינוני',
    '👨🏿‍🍼' => 'איש מניק תינוק: גוון עור כהה',
    '🧑🏻‍🍼' => 'הנקה של תינוק: גוון עור בהיר',
    '🧑🏼‍🍼' => 'הנקה של תינוק: גוון עור בהיר בינוני',
    '🧑🏽‍🍼' => 'הנקה של תינוק: גוון עור בינוני',
    '🧑🏾‍🍼' => 'הנקה של תינוק: גוון עור כהה בינוני',
    '🧑🏿‍🍼' => 'הנקה של תינוק: גוון עור כהה',
    '🧑🏻‍🎄' => 'קלאוס: גוון עור בהיר',
    '🧑🏼‍🎄' => 'קלאוס: גוון עור בהיר בינוני',
    '🧑🏽‍🎄' => 'קלאוס: גוון עור בינוני',
    '🧑🏾‍🎄' => 'קלאוס: גוון עור כהה בינוני',
    '🧑🏿‍🎄' => 'קלאוס: גוון עור כהה',
    '🦸🏻‍♂' => 'סופרמן: גוון עור בהיר',
    '🦸🏼‍♂' => 'סופרמן: גוון עור בהיר בינוני',
    '🦸🏽‍♂' => 'סופרמן: גוון עור בינוני',
    '🦸🏾‍♂' => 'סופרמן: גוון עור כהה בינוני',
    '🦸🏿‍♂' => 'סופרמן: גוון עור כהה',
    '🦸🏻‍♀' => 'סופרוומן: גוון עור בהיר',
    '🦸🏼‍♀' => 'סופרוומן: גוון עור בהיר בינוני',
    '🦸🏽‍♀' => 'סופרוומן: גוון עור בינוני',
    '🦸🏾‍♀' => 'סופרוומן: גוון עור כהה בינוני',
    '🦸🏿‍♀' => 'סופרוומן: גוון עור כהה',
    '🦹🏻‍♂' => 'רשע בעל כוחות על: גוון עור בהיר',
    '🦹🏼‍♂' => 'רשע בעל כוחות על: גוון עור בהיר בינוני',
    '🦹🏽‍♂' => 'רשע בעל כוחות על: גוון עור בינוני',
    '🦹🏾‍♂' => 'רשע בעל כוחות על: גוון עור כהה בינוני',
    '🦹🏿‍♂' => 'רשע בעל כוחות על: גוון עור כהה',
    '🦹🏻‍♀' => 'מרשעת על: גוון עור בהיר',
    '🦹🏼‍♀' => 'מרשעת על: גוון עור בהיר בינוני',
    '🦹🏽‍♀' => 'מרשעת על: גוון עור בינוני',
    '🦹🏾‍♀' => 'מרשעת על: גוון עור כהה בינוני',
    '🦹🏿‍♀' => 'מרשעת על: גוון עור כהה',
    '🧙🏻‍♂' => 'קוסם עם זקן: גוון עור בהיר',
    '🧙🏼‍♂' => 'קוסם עם זקן: גוון עור בהיר בינוני',
    '🧙🏽‍♂' => 'קוסם עם זקן: גוון עור בינוני',
    '🧙🏾‍♂' => 'קוסם עם זקן: גוון עור כהה בינוני',
    '🧙🏿‍♂' => 'קוסם עם זקן: גוון עור כהה',
    '🧙🏻‍♀' => 'קוסמת: גוון עור בהיר',
    '🧙🏼‍♀' => 'קוסמת: גוון עור בהיר בינוני',
    '🧙🏽‍♀' => 'קוסמת: גוון עור בינוני',
    '🧙🏾‍♀' => 'קוסמת: גוון עור כהה בינוני',
    '🧙🏿‍♀' => 'קוסמת: גוון עור כהה',
    '🧚🏻‍♂' => 'פיה בן: גוון עור בהיר',
    '🧚🏼‍♂' => 'פיה בן: גוון עור בהיר בינוני',
    '🧚🏽‍♂' => 'פיה בן: גוון עור בינוני',
    '🧚🏾‍♂' => 'פיה בן: גוון עור כהה בינוני',
    '🧚🏿‍♂' => 'פיה בן: גוון עור כהה',
    '🧚🏻‍♀' => 'פיה בת: גוון עור בהיר',
    '🧚🏼‍♀' => 'פיה בת: גוון עור בהיר בינוני',
    '🧚🏽‍♀' => 'פיה בת: גוון עור בינוני',
    '🧚🏾‍♀' => 'פיה בת: גוון עור כהה בינוני',
    '🧚🏿‍♀' => 'פיה בת: גוון עור כהה',
    '🧛🏻‍♂' => 'ערפד בן: גוון עור בהיר',
    '🧛🏼‍♂' => 'ערפד בן: גוון עור בהיר בינוני',
    '🧛🏽‍♂' => 'ערפד בן: גוון עור בינוני',
    '🧛🏾‍♂' => 'ערפד בן: גוון עור כהה בינוני',
    '🧛🏿‍♂' => 'ערפד בן: גוון עור כהה',
    '🧛🏻‍♀' => 'ערפדית: גוון עור בהיר',
    '🧛🏼‍♀' => 'ערפדית: גוון עור בהיר בינוני',
    '🧛🏽‍♀' => 'ערפדית: גוון עור בינוני',
    '🧛🏾‍♀' => 'ערפדית: גוון עור כהה בינוני',
    '🧛🏿‍♀' => 'ערפדית: גוון עור כהה',
    '🧜🏻‍♂' => 'בן ים: גוון עור בהיר',
    '🧜🏼‍♂' => 'בן ים: גוון עור בהיר בינוני',
    '🧜🏽‍♂' => 'בן ים: גוון עור בינוני',
    '🧜🏾‍♂' => 'בן ים: גוון עור כהה בינוני',
    '🧜🏿‍♂' => 'בן ים: גוון עור כהה',
    '🧜🏻‍♀' => 'בת הים: גוון עור בהיר',
    '🧜🏼‍♀' => 'בת הים: גוון עור בהיר בינוני',
    '🧜🏽‍♀' => 'בת הים: גוון עור בינוני',
    '🧜🏾‍♀' => 'בת הים: גוון עור כהה בינוני',
    '🧜🏿‍♀' => 'בת הים: גוון עור כהה',
    '🧝🏻‍♂' => 'אלף בן: גוון עור בהיר',
    '🧝🏼‍♂' => 'אלף בן: גוון עור בהיר בינוני',
    '🧝🏽‍♂' => 'אלף בן: גוון עור בינוני',
    '🧝🏾‍♂' => 'אלף בן: גוון עור כהה בינוני',
    '🧝🏿‍♂' => 'אלף בן: גוון עור כהה',
    '🧝🏻‍♀' => 'אלפית: גוון עור בהיר',
    '🧝🏼‍♀' => 'אלפית: גוון עור בהיר בינוני',
    '🧝🏽‍♀' => 'אלפית: גוון עור בינוני',
    '🧝🏾‍♀' => 'אלפית: גוון עור כהה בינוני',
    '🧝🏿‍♀' => 'אלפית: גוון עור כהה',
    '💆🏻‍♂' => 'גבר מקבל עיסוי פנים: גוון עור בהיר',
    '💆🏼‍♂' => 'גבר מקבל עיסוי פנים: גוון עור בהיר בינוני',
    '💆🏽‍♂' => 'גבר מקבל עיסוי פנים: גוון עור בינוני',
    '💆🏾‍♂' => 'גבר מקבל עיסוי פנים: גוון עור כהה בינוני',
    '💆🏿‍♂' => 'גבר מקבל עיסוי פנים: גוון עור כהה',
    '💆🏻‍♀' => 'אישה מקבלת עיסוי פנים: גוון עור בהיר',
    '💆🏼‍♀' => 'אישה מקבלת עיסוי פנים: גוון עור בהיר בינוני',
    '💆🏽‍♀' => 'אישה מקבלת עיסוי פנים: גוון עור בינוני',
    '💆🏾‍♀' => 'אישה מקבלת עיסוי פנים: גוון עור כהה בינוני',
    '💆🏿‍♀' => 'אישה מקבלת עיסוי פנים: גוון עור כהה',
    '💇🏻‍♂' => 'גבר מסתפר: גוון עור בהיר',
    '💇🏼‍♂' => 'גבר מסתפר: גוון עור בהיר בינוני',
    '💇🏽‍♂' => 'גבר מסתפר: גוון עור בינוני',
    '💇🏾‍♂' => 'גבר מסתפר: גוון עור כהה בינוני',
    '💇🏿‍♂' => 'גבר מסתפר: גוון עור כהה',
    '💇🏻‍♀' => 'אישה מסתפרת: גוון עור בהיר',
    '💇🏼‍♀' => 'אישה מסתפרת: גוון עור בהיר בינוני',
    '💇🏽‍♀' => 'אישה מסתפרת: גוון עור בינוני',
    '💇🏾‍♀' => 'אישה מסתפרת: גוון עור כהה בינוני',
    '💇🏿‍♀' => 'אישה מסתפרת: גוון עור כהה',
    '🚶🏻‍♂' => 'גבר הולך: גוון עור בהיר',
    '🚶🏼‍♂' => 'גבר הולך: גוון עור בהיר בינוני',
    '🚶🏽‍♂' => 'גבר הולך: גוון עור בינוני',
    '🚶🏾‍♂' => 'גבר הולך: גוון עור כהה בינוני',
    '🚶🏿‍♂' => 'גבר הולך: גוון עור כהה',
    '🚶🏻‍♀' => 'אישה הולכת: גוון עור בהיר',
    '🚶🏼‍♀' => 'אישה הולכת: גוון עור בהיר בינוני',
    '🚶🏽‍♀' => 'אישה הולכת: גוון עור בינוני',
    '🚶🏾‍♀' => 'אישה הולכת: גוון עור כהה בינוני',
    '🚶🏿‍♀' => 'אישה הולכת: גוון עור כהה',
    '🚶🏻‍➡' => 'איש הולך: גוון עור בהיר, פונה ימינה',
    '🚶🏼‍➡' => 'איש הולך: גוון עור בהיר בינוני, פונה ימינה',
    '🚶🏽‍➡' => 'איש הולך: גוון עור בינוני, פונה ימינה',
    '🚶🏾‍➡' => 'איש הולך: גוון עור כהה בינוני, פונה ימינה',
    '🚶🏿‍➡' => 'איש הולך: גוון עור כהה, פונה ימינה',
    '🧍🏻‍♂' => 'איש עומד: גוון עור בהיר',
    '🧍🏼‍♂' => 'איש עומד: גוון עור בהיר בינוני',
    '🧍🏽‍♂' => 'איש עומד: גוון עור בינוני',
    '🧍🏾‍♂' => 'איש עומד: גוון עור כהה בינוני',
    '🧍🏿‍♂' => 'איש עומד: גוון עור כהה',
    '🧍🏻‍♀' => 'אישה עומדת: גוון עור בהיר',
    '🧍🏼‍♀' => 'אישה עומדת: גוון עור בהיר בינוני',
    '🧍🏽‍♀' => 'אישה עומדת: גוון עור בינוני',
    '🧍🏾‍♀' => 'אישה עומדת: גוון עור כהה בינוני',
    '🧍🏿‍♀' => 'אישה עומדת: גוון עור כהה',
    '🧎🏻‍♂' => 'איש כורע ברך: גוון עור בהיר',
    '🧎🏼‍♂' => 'איש כורע ברך: גוון עור בהיר בינוני',
    '🧎🏽‍♂' => 'איש כורע ברך: גוון עור בינוני',
    '🧎🏾‍♂' => 'איש כורע ברך: גוון עור כהה בינוני',
    '🧎🏿‍♂' => 'איש כורע ברך: גוון עור כהה',
    '🧎🏻‍♀' => 'אישה כורעת ברך: גוון עור בהיר',
    '🧎🏼‍♀' => 'אישה כורעת ברך: גוון עור בהיר בינוני',
    '🧎🏽‍♀' => 'אישה כורעת ברך: גוון עור בינוני',
    '🧎🏾‍♀' => 'אישה כורעת ברך: גוון עור כהה בינוני',
    '🧎🏿‍♀' => 'אישה כורעת ברך: גוון עור כהה',
    '🧎🏻‍➡' => 'אדם כורע ברך: גוון עור בהיר, פונה ימינה',
    '🧎🏼‍➡' => 'אדם כורע ברך: גוון עור בהיר בינוני, פונה ימינה',
    '🧎🏽‍➡' => 'אדם כורע ברך: גוון עור בינוני, פונה ימינה',
    '🧎🏾‍➡' => 'אדם כורע ברך: גוון עור כהה בינוני, פונה ימינה',
    '🧎🏿‍➡' => 'אדם כורע ברך: גוון עור כהה, פונה ימינה',
    '🧑🏻‍🦯' => 'אדם עם מקל נחייה: גוון עור בהיר',
    '🧑🏼‍🦯' => 'אדם עם מקל נחייה: גוון עור בהיר בינוני',
    '🧑🏽‍🦯' => 'אדם עם מקל נחייה: גוון עור בינוני',
    '🧑🏾‍🦯' => 'אדם עם מקל נחייה: גוון עור כהה בינוני',
    '🧑🏿‍🦯' => 'אדם עם מקל נחייה: גוון עור כהה',
    '👨🏻‍🦯' => 'איש עם מקל נחייה: גוון עור בהיר',
    '👨🏼‍🦯' => 'איש עם מקל נחייה: גוון עור בהיר בינוני',
    '👨🏽‍🦯' => 'איש עם מקל נחייה: גוון עור בינוני',
    '👨🏾‍🦯' => 'איש עם מקל נחייה: גוון עור כהה בינוני',
    '👨🏿‍🦯' => 'איש עם מקל נחייה: גוון עור כהה',
    '👩🏻‍🦯' => 'אישה עם מקל נחייה: גוון עור בהיר',
    '👩🏼‍🦯' => 'אישה עם מקל נחייה: גוון עור בהיר בינוני',
    '👩🏽‍🦯' => 'אישה עם מקל נחייה: גוון עור בינוני',
    '👩🏾‍🦯' => 'אישה עם מקל נחייה: גוון עור כהה בינוני',
    '👩🏿‍🦯' => 'אישה עם מקל נחייה: גוון עור כהה',
    '🧑🏻‍🦼' => 'אדם בכסא גלגלים ממונע: גוון עור בהיר',
    '🧑🏼‍🦼' => 'אדם בכסא גלגלים ממונע: גוון עור בהיר בינוני',
    '🧑🏽‍🦼' => 'אדם בכסא גלגלים ממונע: גוון עור בינוני',
    '🧑🏾‍🦼' => 'אדם בכסא גלגלים ממונע: גוון עור כהה בינוני',
    '🧑🏿‍🦼' => 'אדם בכסא גלגלים ממונע: גוון עור כהה',
    '👨🏻‍🦼' => 'איש בכסא גלגלים ממונע: גוון עור בהיר',
    '👨🏼‍🦼' => 'איש בכסא גלגלים ממונע: גוון עור בהיר בינוני',
    '👨🏽‍🦼' => 'איש בכסא גלגלים ממונע: גוון עור בינוני',
    '👨🏾‍🦼' => 'איש בכסא גלגלים ממונע: גוון עור כהה בינוני',
    '👨🏿‍🦼' => 'איש בכסא גלגלים ממונע: גוון עור כהה',
    '👩🏻‍🦼' => 'אישה בכסא גלגלים ממונע: גוון עור בהיר',
    '👩🏼‍🦼' => 'אישה בכסא גלגלים ממונע: גוון עור בהיר בינוני',
    '👩🏽‍🦼' => 'אישה בכסא גלגלים ממונע: גוון עור בינוני',
    '👩🏾‍🦼' => 'אישה בכסא גלגלים ממונע: גוון עור כהה בינוני',
    '👩🏿‍🦼' => 'אישה בכסא גלגלים ממונע: גוון עור כהה',
    '🧑🏻‍🦽' => 'אדם בכסא גלגלים ידני: גוון עור בהיר',
    '🧑🏼‍🦽' => 'אדם בכסא גלגלים ידני: גוון עור בהיר בינוני',
    '🧑🏽‍🦽' => 'אדם בכסא גלגלים ידני: גוון עור בינוני',
    '🧑🏾‍🦽' => 'אדם בכסא גלגלים ידני: גוון עור כהה בינוני',
    '🧑🏿‍🦽' => 'אדם בכסא גלגלים ידני: גוון עור כהה',
    '👨🏻‍🦽' => 'איש בכסא גלגלים ידני: גוון עור בהיר',
    '👨🏼‍🦽' => 'איש בכסא גלגלים ידני: גוון עור בהיר בינוני',
    '👨🏽‍🦽' => 'איש בכסא גלגלים ידני: גוון עור בינוני',
    '👨🏾‍🦽' => 'איש בכסא גלגלים ידני: גוון עור כהה בינוני',
    '👨🏿‍🦽' => 'איש בכסא גלגלים ידני: גוון עור כהה',
    '👩🏻‍🦽' => 'אישה בכסא גלגלים ידני: גוון עור בהיר',
    '👩🏼‍🦽' => 'אישה בכסא גלגלים ידני: גוון עור בהיר בינוני',
    '👩🏽‍🦽' => 'אישה בכסא גלגלים ידני: גוון עור בינוני',
    '👩🏾‍🦽' => 'אישה בכסא גלגלים ידני: גוון עור כהה בינוני',
    '👩🏿‍🦽' => 'אישה בכסא גלגלים ידני: גוון עור כהה',
    '🏃🏻‍♂' => 'גבר רץ: גוון עור בהיר',
    '🏃🏼‍♂' => 'גבר רץ: גוון עור בהיר בינוני',
    '🏃🏽‍♂' => 'גבר רץ: גוון עור בינוני',
    '🏃🏾‍♂' => 'גבר רץ: גוון עור כהה בינוני',
    '🏃🏿‍♂' => 'גבר רץ: גוון עור כהה',
    '🏃🏻‍♀' => 'אישה רצה: גוון עור בהיר',
    '🏃🏼‍♀' => 'אישה רצה: גוון עור בהיר בינוני',
    '🏃🏽‍♀' => 'אישה רצה: גוון עור בינוני',
    '🏃🏾‍♀' => 'אישה רצה: גוון עור כהה בינוני',
    '🏃🏿‍♀' => 'אישה רצה: גוון עור כהה',
    '🏃🏻‍➡' => 'רץ: גוון עור בהיר, פונה ימינה',
    '🏃🏼‍➡' => 'רץ: גוון עור בהיר בינוני, פונה ימינה',
    '🏃🏽‍➡' => 'רץ: גוון עור בינוני, פונה ימינה',
    '🏃🏾‍➡' => 'רץ: גוון עור כהה בינוני, פונה ימינה',
    '🏃🏿‍➡' => 'רץ: גוון עור כהה, פונה ימינה',
    '👯🏻‍♀' => 'נשים עם אוזני ארנב: גוון עור בהיר',
    '👯🏼‍♀' => 'נשים עם אוזני ארנב: גוון עור בהיר בינוני',
    '👯🏽‍♀' => 'נשים עם אוזני ארנב: גוון עור בינוני',
    '👯🏾‍♀' => 'נשים עם אוזני ארנב: גוון עור כהה בינוני',
    '👯🏿‍♀' => 'נשים עם אוזני ארנב: גוון עור כהה',
    '👯🏻‍♂' => 'גברים עם אוזני ארנב רוקדים: גוון עור בהיר',
    '👯🏼‍♂' => 'גברים עם אוזני ארנב רוקדים: גוון עור בהיר בינוני',
    '👯🏽‍♂' => 'גברים עם אוזני ארנב רוקדים: גוון עור בינוני',
    '👯🏾‍♂' => 'גברים עם אוזני ארנב רוקדים: גוון עור כהה בינוני',
    '👯🏿‍♂' => 'גברים עם אוזני ארנב רוקדים: גוון עור כהה',
    '🧖🏻‍♂' => 'גבר בסאונה: גוון עור בהיר',
    '🧖🏼‍♂' => 'גבר בסאונה: גוון עור בהיר בינוני',
    '🧖🏽‍♂' => 'גבר בסאונה: גוון עור בינוני',
    '🧖🏾‍♂' => 'גבר בסאונה: גוון עור כהה בינוני',
    '🧖🏿‍♂' => 'גבר בסאונה: גוון עור כהה',
    '🧖🏻‍♀' => 'אישה בסאונה: גוון עור בהיר',
    '🧖🏼‍♀' => 'אישה בסאונה: גוון עור בהיר בינוני',
    '🧖🏽‍♀' => 'אישה בסאונה: גוון עור בינוני',
    '🧖🏾‍♀' => 'אישה בסאונה: גוון עור כהה בינוני',
    '🧖🏿‍♀' => 'אישה בסאונה: גוון עור כהה',
    '🧗🏻‍♂' => 'איש מטפס: גוון עור בהיר',
    '🧗🏼‍♂' => 'איש מטפס: גוון עור בהיר בינוני',
    '🧗🏽‍♂' => 'איש מטפס: גוון עור בינוני',
    '🧗🏾‍♂' => 'איש מטפס: גוון עור כהה בינוני',
    '🧗🏿‍♂' => 'איש מטפס: גוון עור כהה',
    '🧗🏻‍♀' => 'אישה מטפסת: גוון עור בהיר',
    '🧗🏼‍♀' => 'אישה מטפסת: גוון עור בהיר בינוני',
    '🧗🏽‍♀' => 'אישה מטפסת: גוון עור בינוני',
    '🧗🏾‍♀' => 'אישה מטפסת: גוון עור כהה בינוני',
    '🧗🏿‍♀' => 'אישה מטפסת: גוון עור כהה',
    '🏌🏻‍♂' => 'גבר משחק גולף: גוון עור בהיר',
    '🏌🏼‍♂' => 'גבר משחק גולף: גוון עור בהיר בינוני',
    '🏌🏽‍♂' => 'גבר משחק גולף: גוון עור בינוני',
    '🏌🏾‍♂' => 'גבר משחק גולף: גוון עור כהה בינוני',
    '🏌🏿‍♂' => 'גבר משחק גולף: גוון עור כהה',
    '🏌🏻‍♀' => 'אישה משחקת גולף: גוון עור בהיר',
    '🏌🏼‍♀' => 'אישה משחקת גולף: גוון עור בהיר בינוני',
    '🏌🏽‍♀' => 'אישה משחקת גולף: גוון עור בינוני',
    '🏌🏾‍♀' => 'אישה משחקת גולף: גוון עור כהה בינוני',
    '🏌🏿‍♀' => 'אישה משחקת גולף: גוון עור כהה',
    '🏄🏻‍♂' => 'גבר גולש: גוון עור בהיר',
    '🏄🏼‍♂' => 'גבר גולש: גוון עור בהיר בינוני',
    '🏄🏽‍♂' => 'גבר גולש: גוון עור בינוני',
    '🏄🏾‍♂' => 'גבר גולש: גוון עור כהה בינוני',
    '🏄🏿‍♂' => 'גבר גולש: גוון עור כהה',
    '🏄🏻‍♀' => 'אישה גולשת: גוון עור בהיר',
    '🏄🏼‍♀' => 'אישה גולשת: גוון עור בהיר בינוני',
    '🏄🏽‍♀' => 'אישה גולשת: גוון עור בינוני',
    '🏄🏾‍♀' => 'אישה גולשת: גוון עור כהה בינוני',
    '🏄🏿‍♀' => 'אישה גולשת: גוון עור כהה',
    '🚣🏻‍♂' => 'גבר חותר בסירה: גוון עור בהיר',
    '🚣🏼‍♂' => 'גבר חותר בסירה: גוון עור בהיר בינוני',
    '🚣🏽‍♂' => 'גבר חותר בסירה: גוון עור בינוני',
    '🚣🏾‍♂' => 'גבר חותר בסירה: גוון עור כהה בינוני',
    '🚣🏿‍♂' => 'גבר חותר בסירה: גוון עור כהה',
    '🚣🏻‍♀' => 'אישה חותרת בסירה: גוון עור בהיר',
    '🚣🏼‍♀' => 'אישה חותרת בסירה: גוון עור בהיר בינוני',
    '🚣🏽‍♀' => 'אישה חותרת בסירה: גוון עור בינוני',
    '🚣🏾‍♀' => 'אישה חותרת בסירה: גוון עור כהה בינוני',
    '🚣🏿‍♀' => 'אישה חותרת בסירה: גוון עור כהה',
    '🏊🏻‍♂' => 'גבר שוחה: גוון עור בהיר',
    '🏊🏼‍♂' => 'גבר שוחה: גוון עור בהיר בינוני',
    '🏊🏽‍♂' => 'גבר שוחה: גוון עור בינוני',
    '🏊🏾‍♂' => 'גבר שוחה: גוון עור כהה בינוני',
    '🏊🏿‍♂' => 'גבר שוחה: גוון עור כהה',
    '🏊🏻‍♀' => 'אישה שוחה: גוון עור בהיר',
    '🏊🏼‍♀' => 'אישה שוחה: גוון עור בהיר בינוני',
    '🏊🏽‍♀' => 'אישה שוחה: גוון עור בינוני',
    '🏊🏾‍♀' => 'אישה שוחה: גוון עור כהה בינוני',
    '🏊🏿‍♀' => 'אישה שוחה: גוון עור כהה',
    '⛹🏻‍♂' => 'גבר מקפיץ כדור: גוון עור בהיר',
    '⛹🏼‍♂' => 'גבר מקפיץ כדור: גוון עור בהיר בינוני',
    '⛹🏽‍♂' => 'גבר מקפיץ כדור: גוון עור בינוני',
    '⛹🏾‍♂' => 'גבר מקפיץ כדור: גוון עור כהה בינוני',
    '⛹🏿‍♂' => 'גבר מקפיץ כדור: גוון עור כהה',
    '⛹🏻‍♀' => 'אישה מקפיצה כדור: גוון עור בהיר',
    '⛹🏼‍♀' => 'אישה מקפיצה כדור: גוון עור בהיר בינוני',
    '⛹🏽‍♀' => 'אישה מקפיצה כדור: גוון עור בינוני',
    '⛹🏾‍♀' => 'אישה מקפיצה כדור: גוון עור כהה בינוני',
    '⛹🏿‍♀' => 'אישה מקפיצה כדור: גוון עור כהה',
    '🏋🏻‍♂' => 'גבר מרים משקולות: גוון עור בהיר',
    '🏋🏼‍♂' => 'גבר מרים משקולות: גוון עור בהיר בינוני',
    '🏋🏽‍♂' => 'גבר מרים משקולות: גוון עור בינוני',
    '🏋🏾‍♂' => 'גבר מרים משקולות: גוון עור כהה בינוני',
    '🏋🏿‍♂' => 'גבר מרים משקולות: גוון עור כהה',
    '🏋🏻‍♀' => 'אישה מרימה משקולות: גוון עור בהיר',
    '🏋🏼‍♀' => 'אישה מרימה משקולות: גוון עור בהיר בינוני',
    '🏋🏽‍♀' => 'אישה מרימה משקולות: גוון עור בינוני',
    '🏋🏾‍♀' => 'אישה מרימה משקולות: גוון עור כהה בינוני',
    '🏋🏿‍♀' => 'אישה מרימה משקולות: גוון עור כהה',
    '🚴🏻‍♂' => 'גבר רוכב על אופניים: גוון עור בהיר',
    '🚴🏼‍♂' => 'גבר רוכב על אופניים: גוון עור בהיר בינוני',
    '🚴🏽‍♂' => 'גבר רוכב על אופניים: גוון עור בינוני',
    '🚴🏾‍♂' => 'גבר רוכב על אופניים: גוון עור כהה בינוני',
    '🚴🏿‍♂' => 'גבר רוכב על אופניים: גוון עור כהה',
    '🚴🏻‍♀' => 'אישה רוכבת על אופניים: גוון עור בהיר',
    '🚴🏼‍♀' => 'אישה רוכבת על אופניים: גוון עור בהיר בינוני',
    '🚴🏽‍♀' => 'אישה רוכבת על אופניים: גוון עור בינוני',
    '🚴🏾‍♀' => 'אישה רוכבת על אופניים: גוון עור כהה בינוני',
    '🚴🏿‍♀' => 'אישה רוכבת על אופניים: גוון עור כהה',
    '🚵🏻‍♂' => 'גבר רוכב על אופני הרים: גוון עור בהיר',
    '🚵🏼‍♂' => 'גבר רוכב על אופני הרים: גוון עור בהיר בינוני',
    '🚵🏽‍♂' => 'גבר רוכב על אופני הרים: גוון עור בינוני',
    '🚵🏾‍♂' => 'גבר רוכב על אופני הרים: גוון עור כהה בינוני',
    '🚵🏿‍♂' => 'גבר רוכב על אופני הרים: גוון עור כהה',
    '🚵🏻‍♀' => 'אישה רוכבת על אופני הרים: גוון עור בהיר',
    '🚵🏼‍♀' => 'אישה רוכבת על אופני הרים: גוון עור בהיר בינוני',
    '🚵🏽‍♀' => 'אישה רוכבת על אופני הרים: גוון עור בינוני',
    '🚵🏾‍♀' => 'אישה רוכבת על אופני הרים: גוון עור כהה בינוני',
    '🚵🏿‍♀' => 'אישה רוכבת על אופני הרים: גוון עור כהה',
    '🤸🏻‍♂' => 'גבר מבצע גלגלון: גוון עור בהיר',
    '🤸🏼‍♂' => 'גבר מבצע גלגלון: גוון עור בהיר בינוני',
    '🤸🏽‍♂' => 'גבר מבצע גלגלון: גוון עור בינוני',
    '🤸🏾‍♂' => 'גבר מבצע גלגלון: גוון עור כהה בינוני',
    '🤸🏿‍♂' => 'גבר מבצע גלגלון: גוון עור כהה',
    '🤸🏻‍♀' => 'אישה מבצעת גלגלון: גוון עור בהיר',
    '🤸🏼‍♀' => 'אישה מבצעת גלגלון: גוון עור בהיר בינוני',
    '🤸🏽‍♀' => 'אישה מבצעת גלגלון: גוון עור בינוני',
    '🤸🏾‍♀' => 'אישה מבצעת גלגלון: גוון עור כהה בינוני',
    '🤸🏿‍♀' => 'אישה מבצעת גלגלון: גוון עור כהה',
    '🤼🏻‍♀' => 'נשים מתאבקות: גוון עור בהיר',
    '🤼🏼‍♀' => 'נשים מתאבקות: גוון עור בהיר בינוני',
    '🤼🏽‍♀' => 'נשים מתאבקות: גוון עור בינוני',
    '🤼🏾‍♀' => 'נשים מתאבקות: גוון עור כהה בינוני',
    '🤼🏿‍♀' => 'נשים מתאבקות: גוון עור כהה',
    '🤼🏻‍♂' => 'גברים מתאבקים: גוון עור בהיר',
    '🤼🏼‍♂' => 'גברים מתאבקים: גוון עור בהיר בינוני',
    '🤼🏽‍♂' => 'גברים מתאבקים: גוון עור בינוני',
    '🤼🏾‍♂' => 'גברים מתאבקים: גוון עור כהה בינוני',
    '🤼🏿‍♂' => 'גברים מתאבקים: גוון עור כהה',
    '🤽🏻‍♂' => 'גבר משחק כדור-מים: גוון עור בהיר',
    '🤽🏼‍♂' => 'גבר משחק כדור-מים: גוון עור בהיר בינוני',
    '🤽🏽‍♂' => 'גבר משחק כדור-מים: גוון עור בינוני',
    '🤽🏾‍♂' => 'גבר משחק כדור-מים: גוון עור כהה בינוני',
    '🤽🏿‍♂' => 'גבר משחק כדור-מים: גוון עור כהה',
    '🤽🏻‍♀' => 'אישה משחקת כדור-מים: גוון עור בהיר',
    '🤽🏼‍♀' => 'אישה משחקת כדור-מים: גוון עור בהיר בינוני',
    '🤽🏽‍♀' => 'אישה משחקת כדור-מים: גוון עור בינוני',
    '🤽🏾‍♀' => 'אישה משחקת כדור-מים: גוון עור כהה בינוני',
    '🤽🏿‍♀' => 'אישה משחקת כדור-מים: גוון עור כהה',
    '🤾🏻‍♂' => 'גבר משחק כדוריד: גוון עור בהיר',
    '🤾🏼‍♂' => 'גבר משחק כדוריד: גוון עור בהיר בינוני',
    '🤾🏽‍♂' => 'גבר משחק כדוריד: גוון עור בינוני',
    '🤾🏾‍♂' => 'גבר משחק כדוריד: גוון עור כהה בינוני',
    '🤾🏿‍♂' => 'גבר משחק כדוריד: גוון עור כהה',
    '🤾🏻‍♀' => 'אישה משחקת כדור יד: גוון עור בהיר',
    '🤾🏼‍♀' => 'אישה משחקת כדור יד: גוון עור בהיר בינוני',
    '🤾🏽‍♀' => 'אישה משחקת כדור יד: גוון עור בינוני',
    '🤾🏾‍♀' => 'אישה משחקת כדור יד: גוון עור כהה בינוני',
    '🤾🏿‍♀' => 'אישה משחקת כדור יד: גוון עור כהה',
    '🤹🏻‍♂' => 'גבר עושה ג׳גלינג: גוון עור בהיר',
    '🤹🏼‍♂' => 'גבר עושה ג׳גלינג: גוון עור בהיר בינוני',
    '🤹🏽‍♂' => 'גבר עושה ג׳גלינג: גוון עור בינוני',
    '🤹🏾‍♂' => 'גבר עושה ג׳גלינג: גוון עור כהה בינוני',
    '🤹🏿‍♂' => 'גבר עושה ג׳גלינג: גוון עור כהה',
    '🤹🏻‍♀' => 'אישה עושה ג׳גלינג: גוון עור בהיר',
    '🤹🏼‍♀' => 'אישה עושה ג׳גלינג: גוון עור בהיר בינוני',
    '🤹🏽‍♀' => 'אישה עושה ג׳גלינג: גוון עור בינוני',
    '🤹🏾‍♀' => 'אישה עושה ג׳גלינג: גוון עור כהה בינוני',
    '🤹🏿‍♀' => 'אישה עושה ג׳גלינג: גוון עור כהה',
    '🧘🏻‍♂' => 'איש בתנוחת לוטוס: גוון עור בהיר',
    '🧘🏼‍♂' => 'איש בתנוחת לוטוס: גוון עור בהיר בינוני',
    '🧘🏽‍♂' => 'איש בתנוחת לוטוס: גוון עור בינוני',
    '🧘🏾‍♂' => 'איש בתנוחת לוטוס: גוון עור כהה בינוני',
    '🧘🏿‍♂' => 'איש בתנוחת לוטוס: גוון עור כהה',
    '🧘🏻‍♀' => 'אישה בתנוחת לוטוס: גוון עור בהיר',
    '🧘🏼‍♀' => 'אישה בתנוחת לוטוס: גוון עור בהיר בינוני',
    '🧘🏽‍♀' => 'אישה בתנוחת לוטוס: גוון עור בינוני',
    '🧘🏾‍♀' => 'אישה בתנוחת לוטוס: גוון עור כהה בינוני',
    '🧘🏿‍♀' => 'אישה בתנוחת לוטוס: גוון עור כהה',
    '🧑‍🦰' => 'אדם: שיער ג׳ינג׳י',
    '🧑‍🦱' => 'אדם: שיער מתולתל',
    '🧑‍🦳' => 'אדם: שיער לבן',
    '🧑‍🦲' => 'אדם: קירח',
    '👨‍🦰' => 'איש: שיער ג׳ינג׳י',
    '👨‍🦱' => 'איש: שיער מתולתל',
    '👨‍🦳' => 'איש: שיער לבן',
    '👨‍🦲' => 'איש: קירח',
    '👩‍🦰' => 'אישה: שיער ג׳ינג׳י',
    '👩‍🦱' => 'אישה: שיער מתולתל',
    '👩‍🦳' => 'אישה: שיער לבן',
    '👩‍🦲' => 'אישה: קירח',
    '🚶‍➡' => 'איש הולך: פונה ימינה',
    '🧎‍➡' => 'אדם כורע ברך: פונה ימינה',
    '🏃‍➡' => 'רץ: פונה ימינה',
    '👨‍👦' => 'משפחה: איש, בן',
    '👨‍👧' => 'משפחה: איש, בת',
    '👩‍👦' => 'משפחה: אישה, בן',
    '👩‍👧' => 'משפחה: אישה, בת',
    '😶‍🌫' => 'פרצוף בעננים',
    '😮‍💨' => 'פרצוף נושף',
    '🙂‍↕' => 'מנענע ראש מלמעלה למטה',
    '😵‍💫' => 'פרצוף עם עיני ספירלה',
    '❤‍🔥' => 'לב בלהבות',
    '❤‍🩹' => 'לב שמשתקם',
    '👁‍🗨' => 'עין בבועת דיבור',
    '🧔‍♂' => 'גבר עם זקן',
    '👱‍♂' => 'בלונדיני',
    '🧔‍♀' => 'אישה עם זקן',
    '👱‍♀' => 'בלונדינית',
    '🙍‍♂' => 'גבר מדוכדך',
    '🙍‍♀' => 'אישה מדוכדכת',
    '🙎‍♂' => 'גבר מבואס',
    '🙎‍♀' => 'אישה מבואסת',
    '🙅‍♂' => 'גבר מסמן ״לא״',
    '🙅‍♀' => 'אישה מסמנת ״לא״',
    '🙆‍♂' => 'גבר עם הידיים על הראש',
    '🙆‍♀' => 'אישה עם ידיים על הראש',
    '💁‍♂' => 'איש בדלפק מידע או מבקש טיפ',
    '💁‍♀' => 'אישה מבקשת טיפ',
    '🙋‍♂' => 'גבר מרים את היד',
    '🙋‍♀' => 'אישה מנופפת בידה',
    '🧏‍♂' => 'איש כבד שמיעה',
    '🧏‍♀' => 'אישה כבדת שמיעה',
    '🙇‍♂' => 'גבר משתחווה',
    '🙇‍♀' => 'אישה משתחווה',
    '🤦‍♂' => 'גבר מתוסכל',
    '🤦‍♀' => 'אישה מתוסכלת',
    '🤷‍♂' => 'גבר מושך בכתפיו',
    '🤷‍♀' => 'אישה מושכת בכתפיה',
    '🧑‍⚕' => 'עובד בשירותי הבריאות',
    '👨‍⚕' => 'רופא',
    '👩‍⚕' => 'רופאה',
    '🧑‍🎓' => 'סטודנט/ית',
    '👨‍🎓' => 'סטודנט',
    '👩‍🎓' => 'סטודנטית',
    '🧑‍🏫' => 'מצוות המורים',
    '👨‍🏫' => 'מורה',
    '👩‍🏫' => 'מוֹרָה',
    '🧑‍⚖' => 'שופט/ת',
    '👨‍⚖' => 'שופט',
    '👩‍⚖' => 'שופטת',
    '🧑‍🌾' => 'חקלאי/ת',
    '👨‍🌾' => 'חקלאי',
    '👩‍🌾' => 'חקלאית',
    '🧑‍🍳' => 'טבח/ית',
    '👨‍🍳' => 'טבח',
    '👩‍🍳' => 'טבחית',
    '🧑‍🔧' => 'מכונאי/ת',
    '👨‍🔧' => 'מכונאי',
    '👩‍🔧' => 'מכונאית',
    '🧑‍🏭' => 'פועל/ת',
    '👨‍🏭' => 'פועל',
    '👩‍🏭' => 'פועלת',
    '🧑‍💼' => 'עובד/ת משרד',
    '👨‍💼' => 'עובד משרד',
    '👩‍💼' => 'עובדת משרד',
    '🧑‍🔬' => 'מדען/ית',
    '👨‍🔬' => 'מדען',
    '👩‍🔬' => 'מדענית',
    '🧑‍💻' => 'טכנולוג/ית',
    '👨‍💻' => 'טכנולוג',
    '👩‍💻' => 'טכנולוגית',
    '🧑‍🎤' => 'זמר/ת',
    '👨‍🎤' => 'זמר',
    '👩‍🎤' => 'זמרת',
    '🧑‍🎨' => 'אומן/ית',
    '👨‍🎨' => 'אמן',
    '👩‍🎨' => 'אמנית',
    '🧑‍✈' => 'טייס/ת',
    '👨‍✈' => 'טייס',
    '👩‍✈' => 'טייסת',
    '🧑‍🚀' => 'אסטרונאוט/ית',
    '👨‍🚀' => 'אסטרונאוט',
    '👩‍🚀' => 'אסטרונאוטית',
    '🧑‍🚒' => 'לוחם/ת אש',
    '👨‍🚒' => 'לוחם אש',
    '👩‍🚒' => 'לוחמת אש',
    '👮‍♂' => 'קצין משטרה',
    '👮‍♀' => 'קצינת משטרה',
    '🕵‍♂' => 'חוקר פרטי',
    '🕵‍♀' => 'חוקרת פרטית',
    '💂‍♂' => 'מאבטח',
    '💂‍♀' => 'שומרת',
    '👷‍♂' => 'בנאי',
    '👷‍♀' => 'פועלת בניין',
    '👳‍♂' => 'גבר עם טורבן',
    '👳‍♀' => 'אישה עם טורבן',
    '🤵‍♂' => 'גבר בטוקסידו',
    '🤵‍♀' => 'אישה בטוקסידו',
    '👰‍♂' => 'איש עם הינומה',
    '👰‍♀' => 'אישה עם הינומה',
    '👩‍🍼' => 'אישה מניקה תינוק',
    '👨‍🍼' => 'איש מניק תינוק',
    '🧑‍🍼' => 'הנקה של תינוק',
    '🧑‍🎄' => 'קלאוס',
    '🦸‍♂' => 'סופרמן',
    '🦸‍♀' => 'סופרוומן',
    '🦹‍♂' => 'רשע בעל כוחות על',
    '🦹‍♀' => 'מרשעת על',
    '🧙‍♂' => 'קוסם עם זקן',
    '🧙‍♀' => 'קוסמת',
    '🧚‍♂' => 'פיה בן',
    '🧚‍♀' => 'פיה בת',
    '🧛‍♂' => 'ערפד בן',
    '🧛‍♀' => 'ערפדית',
    '🧜‍♂' => 'בן ים',
    '🧜‍♀' => 'בת הים',
    '🧝‍♂' => 'אלף בן',
    '🧝‍♀' => 'אלפית',
    '🧞‍♂' => 'דמון',
    '🧞‍♀' => 'שדה',
    '🧟‍♂' => 'זומבי גבר',
    '🧟‍♀' => 'זומבי אישה',
    '💆‍♂' => 'גבר מקבל עיסוי פנים',
    '💆‍♀' => 'אישה מקבלת עיסוי פנים',
    '💇‍♂' => 'גבר מסתפר',
    '💇‍♀' => 'אישה מסתפרת',
    '🚶‍♂' => 'גבר הולך',
    '🚶‍♀' => 'אישה הולכת',
    '🧍‍♂' => 'איש עומד',
    '🧍‍♀' => 'אישה עומדת',
    '🧎‍♂' => 'איש כורע ברך',
    '🧎‍♀' => 'אישה כורעת ברך',
    '🧑‍🦯' => 'אדם עם מקל נחייה',
    '👨‍🦯' => 'איש עם מקל נחייה',
    '👩‍🦯' => 'אישה עם מקל נחייה',
    '🧑‍🦼' => 'אדם בכסא גלגלים ממונע',
    '👨‍🦼' => 'איש בכסא גלגלים ממונע',
    '👩‍🦼' => 'אישה בכסא גלגלים ממונע',
    '🧑‍🦽' => 'אדם בכסא גלגלים ידני',
    '👨‍🦽' => 'איש בכסא גלגלים ידני',
    '👩‍🦽' => 'אישה בכסא גלגלים ידני',
    '🏃‍♂' => 'גבר רץ',
    '🏃‍♀' => 'אישה רצה',
    '🧑‍🩰' => 'רקדן בלט',
    '👯‍♂' => 'גברים עם אוזני ארנב רוקדים',
    '👯‍♀' => 'נשים עם אוזני ארנב',
    '🧖‍♂' => 'גבר בסאונה',
    '🧖‍♀' => 'אישה בסאונה',
    '🧗‍♂' => 'איש מטפס',
    '🧗‍♀' => 'אישה מטפסת',
    '🏌‍♂' => 'גבר משחק גולף',
    '🏌‍♀' => 'אישה משחקת גולף',
    '🏄‍♂' => 'גבר גולש',
    '🏄‍♀' => 'אישה גולשת',
    '🚣‍♂' => 'גבר חותר בסירה',
    '🚣‍♀' => 'אישה חותרת בסירה',
    '🏊‍♂' => 'גבר שוחה',
    '🏊‍♀' => 'אישה שוחה',
    '⛹‍♂' => 'גבר מקפיץ כדור',
    '⛹‍♀' => 'אישה מקפיצה כדור',
    '🏋‍♂' => 'גבר מרים משקולות',
    '🏋‍♀' => 'אישה מרימה משקולות',
    '🚴‍♂' => 'גבר רוכב על אופניים',
    '🚴‍♀' => 'אישה רוכבת על אופניים',
    '🚵‍♂' => 'גבר רוכב על אופני הרים',
    '🚵‍♀' => 'אישה רוכבת על אופני הרים',
    '🤸‍♂' => 'גבר מבצע גלגלון',
    '🤸‍♀' => 'אישה מבצעת גלגלון',
    '🤼‍♂' => 'גברים מתאבקים',
    '🤼‍♀' => 'נשים מתאבקות',
    '🤽‍♂' => 'גבר משחק כדור-מים',
    '🤽‍♀' => 'אישה משחקת כדור-מים',
    '🤾‍♂' => 'גבר משחק כדוריד',
    '🤾‍♀' => 'אישה משחקת כדור יד',
    '🤹‍♂' => 'גבר עושה ג׳גלינג',
    '🤹‍♀' => 'אישה עושה ג׳גלינג',
    '🧘‍♂' => 'איש בתנוחת לוטוס',
    '🧘‍♀' => 'אישה בתנוחת לוטוס',
    '🧑‍🧒' => 'משפחה: הורה, ילד',
    '🐕‍🦺' => 'כלב שירות',
    '🐈‍⬛' => 'חתול שחור',
    '🐻‍❄' => 'דוב קוטב',
    '🐦‍⬛' => 'ציפור שחורה',
    '🐦‍🔥' => 'עוף החול',
    '🍋‍🟩' => 'ליים',
    '🍄‍🟫' => 'פטרייה חומה',
    '⛓‍💥' => 'שרשרת שבורה',
    '🏳‍🌈' => 'דגל בצבעי הקשת',
    '🏳‍⚧' => 'דגל טרנסג׳נדר',
    '🏴‍☠' => 'דגל פירטים',
    '👋🏻' => 'יד מנופפת: גוון עור בהיר',
    '👋🏼' => 'יד מנופפת: גוון עור בהיר בינוני',
    '👋🏽' => 'יד מנופפת: גוון עור בינוני',
    '👋🏾' => 'יד מנופפת: גוון עור כהה בינוני',
    '👋🏿' => 'יד מנופפת: גוון עור כהה',
    '🤚🏻' => 'גב יד פרוש: גוון עור בהיר',
    '🤚🏼' => 'גב יד פרוש: גוון עור בהיר בינוני',
    '🤚🏽' => 'גב יד פרוש: גוון עור בינוני',
    '🤚🏾' => 'גב יד פרוש: גוון עור כהה בינוני',
    '🤚🏿' => 'גב יד פרוש: גוון עור כהה',
    '🖐🏻' => 'כף יד פתוחה מורמת: גוון עור בהיר',
    '🖐🏼' => 'כף יד פתוחה מורמת: גוון עור בהיר בינוני',
    '🖐🏽' => 'כף יד פתוחה מורמת: גוון עור בינוני',
    '🖐🏾' => 'כף יד פתוחה מורמת: גוון עור כהה בינוני',
    '🖐🏿' => 'כף יד פתוחה מורמת: גוון עור כהה',
    '✋🏻' => 'כף יד מורמת: גוון עור בהיר',
    '✋🏼' => 'כף יד מורמת: גוון עור בהיר בינוני',
    '✋🏽' => 'כף יד מורמת: גוון עור בינוני',
    '✋🏾' => 'כף יד מורמת: גוון עור כהה בינוני',
    '✋🏿' => 'כף יד מורמת: גוון עור כהה',
    '🖖🏻' => 'הצדעה וולקנית: גוון עור בהיר',
    '🖖🏼' => 'הצדעה וולקנית: גוון עור בהיר בינוני',
    '🖖🏽' => 'הצדעה וולקנית: גוון עור בינוני',
    '🖖🏾' => 'הצדעה וולקנית: גוון עור כהה בינוני',
    '🖖🏿' => 'הצדעה וולקנית: גוון עור כהה',
    '🫱🏻' => 'יד פונה ימינה: גוון עור בהיר',
    '🫱🏼' => 'יד פונה ימינה: גוון עור בהיר בינוני',
    '🫱🏽' => 'יד פונה ימינה: גוון עור בינוני',
    '🫱🏾' => 'יד פונה ימינה: גוון עור כהה בינוני',
    '🫱🏿' => 'יד פונה ימינה: גוון עור כהה',
    '🫲🏻' => 'יד פונה שמאלה: גוון עור בהיר',
    '🫲🏼' => 'יד פונה שמאלה: גוון עור בהיר בינוני',
    '🫲🏽' => 'יד פונה שמאלה: גוון עור בינוני',
    '🫲🏾' => 'יד פונה שמאלה: גוון עור כהה בינוני',
    '🫲🏿' => 'יד פונה שמאלה: גוון עור כהה',
    '🫳🏻' => 'כף יד פונה למטה: גוון עור בהיר',
    '🫳🏼' => 'כף יד פונה למטה: גוון עור בהיר בינוני',
    '🫳🏽' => 'כף יד פונה למטה: גוון עור בינוני',
    '🫳🏾' => 'כף יד פונה למטה: גוון עור כהה בינוני',
    '🫳🏿' => 'כף יד פונה למטה: גוון עור כהה',
    '🫴🏻' => 'כף יד פונה למעלה: גוון עור בהיר',
    '🫴🏼' => 'כף יד פונה למעלה: גוון עור בהיר בינוני',
    '🫴🏽' => 'כף יד פונה למעלה: גוון עור בינוני',
    '🫴🏾' => 'כף יד פונה למעלה: גוון עור כהה בינוני',
    '🫴🏿' => 'כף יד פונה למעלה: גוון עור כהה',
    '🫷🏻' => 'יד דוחפת שמאלה: גוון עור בהיר',
    '🫷🏼' => 'יד דוחפת שמאלה: גוון עור בהיר בינוני',
    '🫷🏽' => 'יד דוחפת שמאלה: גוון עור בינוני',
    '🫷🏾' => 'יד דוחפת שמאלה: גוון עור כהה בינוני',
    '🫷🏿' => 'יד דוחפת שמאלה: גוון עור כהה',
    '🫸🏻' => 'יד דוחפת ימינה: גוון עור בהיר',
    '🫸🏼' => 'יד דוחפת ימינה: גוון עור בהיר בינוני',
    '🫸🏽' => 'יד דוחפת ימינה: גוון עור בינוני',
    '🫸🏾' => 'יד דוחפת ימינה: גוון עור כהה בינוני',
    '🫸🏿' => 'יד דוחפת ימינה: גוון עור כהה',
    '👌🏻' => 'יד מסמנת שהכל בסדר: גוון עור בהיר',
    '👌🏼' => 'יד מסמנת שהכל בסדר: גוון עור בהיר בינוני',
    '👌🏽' => 'יד מסמנת שהכל בסדר: גוון עור בינוני',
    '👌🏾' => 'יד מסמנת שהכל בסדר: גוון עור כהה בינוני',
    '👌🏿' => 'יד מסמנת שהכל בסדר: גוון עור כהה',
    '🤌🏻' => 'יד מסמנת רק רגע: גוון עור בהיר',
    '🤌🏼' => 'יד מסמנת רק רגע: גוון עור בהיר בינוני',
    '🤌🏽' => 'יד מסמנת רק רגע: גוון עור בינוני',
    '🤌🏾' => 'יד מסמנת רק רגע: גוון עור כהה בינוני',
    '🤌🏿' => 'יד מסמנת רק רגע: גוון עור כהה',
    '🤏🏻' => 'יד צובטת: גוון עור בהיר',
    '🤏🏼' => 'יד צובטת: גוון עור בהיר בינוני',
    '🤏🏽' => 'יד צובטת: גוון עור בינוני',
    '🤏🏾' => 'יד צובטת: גוון עור כהה בינוני',
    '🤏🏿' => 'יד צובטת: גוון עור כהה',
    '✌🏻' => 'אצבעות מסמנות ניצחון: גוון עור בהיר',
    '✌🏼' => 'אצבעות מסמנות ניצחון: גוון עור בהיר בינוני',
    '✌🏽' => 'אצבעות מסמנות ניצחון: גוון עור בינוני',
    '✌🏾' => 'אצבעות מסמנות ניצחון: גוון עור כהה בינוני',
    '✌🏿' => 'אצבעות מסמנות ניצחון: גוון עור כהה',
    '🤞🏻' => 'יד מחזיקה אצבעות: גוון עור בהיר',
    '🤞🏼' => 'יד מחזיקה אצבעות: גוון עור בהיר בינוני',
    '🤞🏽' => 'יד מחזיקה אצבעות: גוון עור בינוני',
    '🤞🏾' => 'יד מחזיקה אצבעות: גוון עור כהה בינוני',
    '🤞🏿' => 'יד מחזיקה אצבעות: גוון עור כהה',
    '🫰🏻' => 'קליק באצבעות: גוון עור בהיר',
    '🫰🏼' => 'קליק באצבעות: גוון עור בהיר בינוני',
    '🫰🏽' => 'קליק באצבעות: גוון עור בינוני',
    '🫰🏾' => 'קליק באצבעות: גוון עור כהה בינוני',
    '🫰🏿' => 'קליק באצבעות: גוון עור כהה',
    '🤟🏻' => 'בוהן, אצבע וזרת מורמות: גוון עור בהיר',
    '🤟🏼' => 'בוהן, אצבע וזרת מורמות: גוון עור בהיר בינוני',
    '🤟🏽' => 'בוהן, אצבע וזרת מורמות: גוון עור בינוני',
    '🤟🏾' => 'בוהן, אצבע וזרת מורמות: גוון עור כהה בינוני',
    '🤟🏿' => 'בוהן, אצבע וזרת מורמות: גוון עור כהה',
    '🤘🏻' => 'יד מסמנת קרניים: גוון עור בהיר',
    '🤘🏼' => 'יד מסמנת קרניים: גוון עור בהיר בינוני',
    '🤘🏽' => 'יד מסמנת קרניים: גוון עור בינוני',
    '🤘🏾' => 'יד מסמנת קרניים: גוון עור כהה בינוני',
    '🤘🏿' => 'יד מסמנת קרניים: גוון עור כהה',
    '🤙🏻' => 'יד מסמנת ’תתקשר אליי’: גוון עור בהיר',
    '🤙🏼' => 'יד מסמנת ’תתקשר אליי’: גוון עור בהיר בינוני',
    '🤙🏽' => 'יד מסמנת ’תתקשר אליי’: גוון עור בינוני',
    '🤙🏾' => 'יד מסמנת ’תתקשר אליי’: גוון עור כהה בינוני',
    '🤙🏿' => 'יד מסמנת ’תתקשר אליי’: גוון עור כהה',
    '👈🏻' => 'גב יד מצביעה שמאלה: גוון עור בהיר',
    '👈🏼' => 'גב יד מצביעה שמאלה: גוון עור בהיר בינוני',
    '👈🏽' => 'גב יד מצביעה שמאלה: גוון עור בינוני',
    '👈🏾' => 'גב יד מצביעה שמאלה: גוון עור כהה בינוני',
    '👈🏿' => 'גב יד מצביעה שמאלה: גוון עור כהה',
    '👉🏻' => 'גב יד מצביעה ימינה: גוון עור בהיר',
    '👉🏼' => 'גב יד מצביעה ימינה: גוון עור בהיר בינוני',
    '👉🏽' => 'גב יד מצביעה ימינה: גוון עור בינוני',
    '👉🏾' => 'גב יד מצביעה ימינה: גוון עור כהה בינוני',
    '👉🏿' => 'גב יד מצביעה ימינה: גוון עור כהה',
    '👆🏻' => 'גב יד מצביעה למעלה: גוון עור בהיר',
    '👆🏼' => 'גב יד מצביעה למעלה: גוון עור בהיר בינוני',
    '👆🏽' => 'גב יד מצביעה למעלה: גוון עור בינוני',
    '👆🏾' => 'גב יד מצביעה למעלה: גוון עור כהה בינוני',
    '👆🏿' => 'גב יד מצביעה למעלה: גוון עור כהה',
    '🖕🏻' => 'אצבע משולשת: גוון עור בהיר',
    '🖕🏼' => 'אצבע משולשת: גוון עור בהיר בינוני',
    '🖕🏽' => 'אצבע משולשת: גוון עור בינוני',
    '🖕🏾' => 'אצבע משולשת: גוון עור כהה בינוני',
    '🖕🏿' => 'אצבע משולשת: גוון עור כהה',
    '👇🏻' => 'גב יד מצביעה למטה: גוון עור בהיר',
    '👇🏼' => 'גב יד מצביעה למטה: גוון עור בהיר בינוני',
    '👇🏽' => 'גב יד מצביעה למטה: גוון עור בינוני',
    '👇🏾' => 'גב יד מצביעה למטה: גוון עור כהה בינוני',
    '👇🏿' => 'גב יד מצביעה למטה: גוון עור כהה',
    '☝🏻' => 'יד מצביעה למעלה: גוון עור בהיר',
    '☝🏼' => 'יד מצביעה למעלה: גוון עור בהיר בינוני',
    '☝🏽' => 'יד מצביעה למעלה: גוון עור בינוני',
    '☝🏾' => 'יד מצביעה למעלה: גוון עור כהה בינוני',
    '☝🏿' => 'יד מצביעה למעלה: גוון עור כהה',
    '🫵🏻' => 'אצבע מצביעה: גוון עור בהיר',
    '🫵🏼' => 'אצבע מצביעה: גוון עור בהיר בינוני',
    '🫵🏽' => 'אצבע מצביעה: גוון עור בינוני',
    '🫵🏾' => 'אצבע מצביעה: גוון עור כהה בינוני',
    '🫵🏿' => 'אצבע מצביעה: גוון עור כהה',
    '👍🏻' => 'אגודל למעלה: גוון עור בהיר',
    '👍🏼' => 'אגודל למעלה: גוון עור בהיר בינוני',
    '👍🏽' => 'אגודל למעלה: גוון עור בינוני',
    '👍🏾' => 'אגודל למעלה: גוון עור כהה בינוני',
    '👍🏿' => 'אגודל למעלה: גוון עור כהה',
    '👎🏻' => 'אגודל למטה: גוון עור בהיר',
    '👎🏼' => 'אגודל למטה: גוון עור בהיר בינוני',
    '👎🏽' => 'אגודל למטה: גוון עור בינוני',
    '👎🏾' => 'אגודל למטה: גוון עור כהה בינוני',
    '👎🏿' => 'אגודל למטה: גוון עור כהה',
    '✊🏻' => 'אגרוף מורם: גוון עור בהיר',
    '✊🏼' => 'אגרוף מורם: גוון עור בהיר בינוני',
    '✊🏽' => 'אגרוף מורם: גוון עור בינוני',
    '✊🏾' => 'אגרוף מורם: גוון עור כהה בינוני',
    '✊🏿' => 'אגרוף מורם: גוון עור כהה',
    '👊🏻' => 'מכת אגרוף: גוון עור בהיר',
    '👊🏼' => 'מכת אגרוף: גוון עור בהיר בינוני',
    '👊🏽' => 'מכת אגרוף: גוון עור בינוני',
    '👊🏾' => 'מכת אגרוף: גוון עור כהה בינוני',
    '👊🏿' => 'מכת אגרוף: גוון עור כהה',
    '🤛🏻' => 'יד קמוצה שמאלה: גוון עור בהיר',
    '🤛🏼' => 'יד קמוצה שמאלה: גוון עור בהיר בינוני',
    '🤛🏽' => 'יד קמוצה שמאלה: גוון עור בינוני',
    '🤛🏾' => 'יד קמוצה שמאלה: גוון עור כהה בינוני',
    '🤛🏿' => 'יד קמוצה שמאלה: גוון עור כהה',
    '🤜🏻' => 'יד קמוצה ימינה: גוון עור בהיר',
    '🤜🏼' => 'יד קמוצה ימינה: גוון עור בהיר בינוני',
    '🤜🏽' => 'יד קמוצה ימינה: גוון עור בינוני',
    '🤜🏾' => 'יד קמוצה ימינה: גוון עור כהה בינוני',
    '🤜🏿' => 'יד קמוצה ימינה: גוון עור כהה',
    '👏🏻' => 'מחיאות כפיים: גוון עור בהיר',
    '👏🏼' => 'מחיאות כפיים: גוון עור בהיר בינוני',
    '👏🏽' => 'מחיאות כפיים: גוון עור בינוני',
    '👏🏾' => 'מחיאות כפיים: גוון עור כהה בינוני',
    '👏🏿' => 'מחיאות כפיים: גוון עור כהה',
    '🙌🏻' => 'כפות ידיים מורמות: גוון עור בהיר',
    '🙌🏼' => 'כפות ידיים מורמות: גוון עור בהיר בינוני',
    '🙌🏽' => 'כפות ידיים מורמות: גוון עור בינוני',
    '🙌🏾' => 'כפות ידיים מורמות: גוון עור כהה בינוני',
    '🙌🏿' => 'כפות ידיים מורמות: גוון עור כהה',
    '🫶🏻' => 'סימן לב עם הידיים: גוון עור בהיר',
    '🫶🏼' => 'סימן לב עם הידיים: גוון עור בהיר בינוני',
    '🫶🏽' => 'סימן לב עם הידיים: גוון עור בינוני',
    '🫶🏾' => 'סימן לב עם הידיים: גוון עור כהה בינוני',
    '🫶🏿' => 'סימן לב עם הידיים: גוון עור כהה',
    '👐🏻' => 'כפות ידיים פתוחות: גוון עור בהיר',
    '👐🏼' => 'כפות ידיים פתוחות: גוון עור בהיר בינוני',
    '👐🏽' => 'כפות ידיים פתוחות: גוון עור בינוני',
    '👐🏾' => 'כפות ידיים פתוחות: גוון עור כהה בינוני',
    '👐🏿' => 'כפות ידיים פתוחות: גוון עור כהה',
    '🤲🏻' => 'כפות ידיים מוצמדות ופונות כלפי מעלה: גוון עור בהיר',
    '🤲🏼' => 'כפות ידיים מוצמדות ופונות כלפי מעלה: גוון עור בהיר בינוני',
    '🤲🏽' => 'כפות ידיים מוצמדות ופונות כלפי מעלה: גוון עור בינוני',
    '🤲🏾' => 'כפות ידיים מוצמדות ופונות כלפי מעלה: גוון עור כהה בינוני',
    '🤲🏿' => 'כפות ידיים מוצמדות ופונות כלפי מעלה: גוון עור כהה',
    '🤝🏻' => 'לחיצת יד: גוון עור בהיר',
    '🤝🏼' => 'לחיצת יד: גוון עור בהיר בינוני',
    '🤝🏽' => 'לחיצת יד: גוון עור בינוני',
    '🤝🏾' => 'לחיצת יד: גוון עור כהה בינוני',
    '🤝🏿' => 'לחיצת יד: גוון עור כהה',
    '🙏🏻' => 'כפות ידיים מוצמדות: גוון עור בהיר',
    '🙏🏼' => 'כפות ידיים מוצמדות: גוון עור בהיר בינוני',
    '🙏🏽' => 'כפות ידיים מוצמדות: גוון עור בינוני',
    '🙏🏾' => 'כפות ידיים מוצמדות: גוון עור כהה בינוני',
    '🙏🏿' => 'כפות ידיים מוצמדות: גוון עור כהה',
    '✍🏻' => 'יד כותבת: גוון עור בהיר',
    '✍🏼' => 'יד כותבת: גוון עור בהיר בינוני',
    '✍🏽' => 'יד כותבת: גוון עור בינוני',
    '✍🏾' => 'יד כותבת: גוון עור כהה בינוני',
    '✍🏿' => 'יד כותבת: גוון עור כהה',
    '💅🏻' => 'מריחת לק: גוון עור בהיר',
    '💅🏼' => 'מריחת לק: גוון עור בהיר בינוני',
    '💅🏽' => 'מריחת לק: גוון עור בינוני',
    '💅🏾' => 'מריחת לק: גוון עור כהה בינוני',
    '💅🏿' => 'מריחת לק: גוון עור כהה',
    '🤳🏻' => 'יד מצלמת סלפי: גוון עור בהיר',
    '🤳🏼' => 'יד מצלמת סלפי: גוון עור בהיר בינוני',
    '🤳🏽' => 'יד מצלמת סלפי: גוון עור בינוני',
    '🤳🏾' => 'יד מצלמת סלפי: גוון עור כהה בינוני',
    '🤳🏿' => 'יד מצלמת סלפי: גוון עור כהה',
    '💪🏻' => 'יד עושה שריר: גוון עור בהיר',
    '💪🏼' => 'יד עושה שריר: גוון עור בהיר בינוני',
    '💪🏽' => 'יד עושה שריר: גוון עור בינוני',
    '💪🏾' => 'יד עושה שריר: גוון עור כהה בינוני',
    '💪🏿' => 'יד עושה שריר: גוון עור כהה',
    '🦵🏻' => 'רגל: גוון עור בהיר',
    '🦵🏼' => 'רגל: גוון עור בהיר בינוני',
    '🦵🏽' => 'רגל: גוון עור בינוני',
    '🦵🏾' => 'רגל: גוון עור כהה בינוני',
    '🦵🏿' => 'רגל: גוון עור כהה',
    '🦶🏻' => 'כף רגל: גוון עור בהיר',
    '🦶🏼' => 'כף רגל: גוון עור בהיר בינוני',
    '🦶🏽' => 'כף רגל: גוון עור בינוני',
    '🦶🏾' => 'כף רגל: גוון עור כהה בינוני',
    '🦶🏿' => 'כף רגל: גוון עור כהה',
    '👂🏻' => 'אוזן: גוון עור בהיר',
    '👂🏼' => 'אוזן: גוון עור בהיר בינוני',
    '👂🏽' => 'אוזן: גוון עור בינוני',
    '👂🏾' => 'אוזן: גוון עור כהה בינוני',
    '👂🏿' => 'אוזן: גוון עור כהה',
    '🦻🏻' => 'אוזן עם מכשיר שמיעה: גוון עור בהיר',
    '🦻🏼' => 'אוזן עם מכשיר שמיעה: גוון עור בהיר בינוני',
    '🦻🏽' => 'אוזן עם מכשיר שמיעה: גוון עור בינוני',
    '🦻🏾' => 'אוזן עם מכשיר שמיעה: גוון עור כהה בינוני',
    '🦻🏿' => 'אוזן עם מכשיר שמיעה: גוון עור כהה',
    '👃🏻' => 'אף: גוון עור בהיר',
    '👃🏼' => 'אף: גוון עור בהיר בינוני',
    '👃🏽' => 'אף: גוון עור בינוני',
    '👃🏾' => 'אף: גוון עור כהה בינוני',
    '👃🏿' => 'אף: גוון עור כהה',
    '👶🏻' => 'תינוק: גוון עור בהיר',
    '👶🏼' => 'תינוק: גוון עור בהיר בינוני',
    '👶🏽' => 'תינוק: גוון עור בינוני',
    '👶🏾' => 'תינוק: גוון עור כהה בינוני',
    '👶🏿' => 'תינוק: גוון עור כהה',
    '🧒🏻' => 'ילד: גוון עור בהיר',
    '🧒🏼' => 'ילד: גוון עור בהיר בינוני',
    '🧒🏽' => 'ילד: גוון עור בינוני',
    '🧒🏾' => 'ילד: גוון עור כהה בינוני',
    '🧒🏿' => 'ילד: גוון עור כהה',
    '👦🏻' => 'בן: גוון עור בהיר',
    '👦🏼' => 'בן: גוון עור בהיר בינוני',
    '👦🏽' => 'בן: גוון עור בינוני',
    '👦🏾' => 'בן: גוון עור כהה בינוני',
    '👦🏿' => 'בן: גוון עור כהה',
    '👧🏻' => 'בת: גוון עור בהיר',
    '👧🏼' => 'בת: גוון עור בהיר בינוני',
    '👧🏽' => 'בת: גוון עור בינוני',
    '👧🏾' => 'בת: גוון עור כהה בינוני',
    '👧🏿' => 'בת: גוון עור כהה',
    '🧑🏻' => 'אדם: גוון עור בהיר',
    '🧑🏼' => 'אדם: גוון עור בהיר בינוני',
    '🧑🏽' => 'אדם: גוון עור בינוני',
    '🧑🏾' => 'אדם: גוון עור כהה בינוני',
    '🧑🏿' => 'אדם: גוון עור כהה',
    '👱🏻' => 'אדם עם שיער בלונדיני: גוון עור בהיר',
    '👱🏼' => 'אדם עם שיער בלונדיני: גוון עור בהיר בינוני',
    '👱🏽' => 'אדם עם שיער בלונדיני: גוון עור בינוני',
    '👱🏾' => 'אדם עם שיער בלונדיני: גוון עור כהה בינוני',
    '👱🏿' => 'אדם עם שיער בלונדיני: גוון עור כהה',
    '👨🏻' => 'איש: גוון עור בהיר',
    '👨🏼' => 'איש: גוון עור בהיר בינוני',
    '👨🏽' => 'איש: גוון עור בינוני',
    '👨🏾' => 'איש: גוון עור כהה בינוני',
    '👨🏿' => 'איש: גוון עור כהה',
    '🧔🏻' => 'אדם מזוקן: גוון עור בהיר',
    '🧔🏼' => 'אדם מזוקן: גוון עור בהיר בינוני',
    '🧔🏽' => 'אדם מזוקן: גוון עור בינוני',
    '🧔🏾' => 'אדם מזוקן: גוון עור כהה בינוני',
    '🧔🏿' => 'אדם מזוקן: גוון עור כהה',
    '👩🏻' => 'אישה: גוון עור בהיר',
    '👩🏼' => 'אישה: גוון עור בהיר בינוני',
    '👩🏽' => 'אישה: גוון עור בינוני',
    '👩🏾' => 'אישה: גוון עור כהה בינוני',
    '👩🏿' => 'אישה: גוון עור כהה',
    '🧓🏻' => 'איש מבוגר: גוון עור בהיר',
    '🧓🏼' => 'איש מבוגר: גוון עור בהיר בינוני',
    '🧓🏽' => 'איש מבוגר: גוון עור בינוני',
    '🧓🏾' => 'איש מבוגר: גוון עור כהה בינוני',
    '🧓🏿' => 'איש מבוגר: גוון עור כהה',
    '👴🏻' => 'איש זקן: גוון עור בהיר',
    '👴🏼' => 'איש זקן: גוון עור בהיר בינוני',
    '👴🏽' => 'איש זקן: גוון עור בינוני',
    '👴🏾' => 'איש זקן: גוון עור כהה בינוני',
    '👴🏿' => 'איש זקן: גוון עור כהה',
    '👵🏻' => 'אישה זקנה: גוון עור בהיר',
    '👵🏼' => 'אישה זקנה: גוון עור בהיר בינוני',
    '👵🏽' => 'אישה זקנה: גוון עור בינוני',
    '👵🏾' => 'אישה זקנה: גוון עור כהה בינוני',
    '👵🏿' => 'אישה זקנה: גוון עור כהה',
    '🙍🏻' => 'אישה לא מרוצה: גוון עור בהיר',
    '🙍🏼' => 'אישה לא מרוצה: גוון עור בהיר בינוני',
    '🙍🏽' => 'אישה לא מרוצה: גוון עור בינוני',
    '🙍🏾' => 'אישה לא מרוצה: גוון עור כהה בינוני',
    '🙍🏿' => 'אישה לא מרוצה: גוון עור כהה',
    '🙎🏻' => 'אישה זועפת: גוון עור בהיר',
    '🙎🏼' => 'אישה זועפת: גוון עור בהיר בינוני',
    '🙎🏽' => 'אישה זועפת: גוון עור בינוני',
    '🙎🏾' => 'אישה זועפת: גוון עור כהה בינוני',
    '🙎🏿' => 'אישה זועפת: גוון עור כהה',
    '🙅🏻' => 'אישה מסמנת ״לא בסדר״: גוון עור בהיר',
    '🙅🏼' => 'אישה מסמנת ״לא בסדר״: גוון עור בהיר בינוני',
    '🙅🏽' => 'אישה מסמנת ״לא בסדר״: גוון עור בינוני',
    '🙅🏾' => 'אישה מסמנת ״לא בסדר״: גוון עור כהה בינוני',
    '🙅🏿' => 'אישה מסמנת ״לא בסדר״: גוון עור כהה',
    '🙆🏻' => 'אישה עם הידיים על הראש: גוון עור בהיר',
    '🙆🏼' => 'אישה עם הידיים על הראש: גוון עור בהיר בינוני',
    '🙆🏽' => 'אישה עם הידיים על הראש: גוון עור בינוני',
    '🙆🏾' => 'אישה עם הידיים על הראש: גוון עור כהה בינוני',
    '🙆🏿' => 'אישה עם הידיים על הראש: גוון עור כהה',
    '💁🏻' => 'אדם בדלפק מידע או מבקש טיפ: גוון עור בהיר',
    '💁🏼' => 'אדם בדלפק מידע או מבקש טיפ: גוון עור בהיר בינוני',
    '💁🏽' => 'אדם בדלפק מידע או מבקש טיפ: גוון עור בינוני',
    '💁🏾' => 'אדם בדלפק מידע או מבקש טיפ: גוון עור כהה בינוני',
    '💁🏿' => 'אדם בדלפק מידע או מבקש טיפ: גוון עור כהה',
    '🙋🏻' => 'אישה מרימה את היד: גוון עור בהיר',
    '🙋🏼' => 'אישה מרימה את היד: גוון עור בהיר בינוני',
    '🙋🏽' => 'אישה מרימה את היד: גוון עור בינוני',
    '🙋🏾' => 'אישה מרימה את היד: גוון עור כהה בינוני',
    '🙋🏿' => 'אישה מרימה את היד: גוון עור כהה',
    '🧏🏻' => 'כבד שמיעה: גוון עור בהיר',
    '🧏🏼' => 'כבד שמיעה: גוון עור בהיר בינוני',
    '🧏🏽' => 'כבד שמיעה: גוון עור בינוני',
    '🧏🏾' => 'כבד שמיעה: גוון עור כהה בינוני',
    '🧏🏿' => 'כבד שמיעה: גוון עור כהה',
    '🙇🏻' => 'אדם משתחווה: גוון עור בהיר',
    '🙇🏼' => 'אדם משתחווה: גוון עור בהיר בינוני',
    '🙇🏽' => 'אדם משתחווה: גוון עור בינוני',
    '🙇🏾' => 'אדם משתחווה: גוון עור כהה בינוני',
    '🙇🏿' => 'אדם משתחווה: גוון עור כהה',
    '🤦🏻' => 'אישה עם יד על הפנים: גוון עור בהיר',
    '🤦🏼' => 'אישה עם יד על הפנים: גוון עור בהיר בינוני',
    '🤦🏽' => 'אישה עם יד על הפנים: גוון עור בינוני',
    '🤦🏾' => 'אישה עם יד על הפנים: גוון עור כהה בינוני',
    '🤦🏿' => 'אישה עם יד על הפנים: גוון עור כהה',
    '🤷🏻' => 'מישהי מושכת בכתפיה: גוון עור בהיר',
    '🤷🏼' => 'מישהי מושכת בכתפיה: גוון עור בהיר בינוני',
    '🤷🏽' => 'מישהי מושכת בכתפיה: גוון עור בינוני',
    '🤷🏾' => 'מישהי מושכת בכתפיה: גוון עור כהה בינוני',
    '🤷🏿' => 'מישהי מושכת בכתפיה: גוון עור כהה',
    '👮🏻' => 'שוטר: גוון עור בהיר',
    '👮🏼' => 'שוטר: גוון עור בהיר בינוני',
    '👮🏽' => 'שוטר: גוון עור בינוני',
    '👮🏾' => 'שוטר: גוון עור כהה בינוני',
    '👮🏿' => 'שוטר: גוון עור כהה',
    '🕵🏻' => 'בלש: גוון עור בהיר',
    '🕵🏼' => 'בלש: גוון עור בהיר בינוני',
    '🕵🏽' => 'בלש: גוון עור בינוני',
    '🕵🏾' => 'בלש: גוון עור כהה בינוני',
    '🕵🏿' => 'בלש: גוון עור כהה',
    '💂🏻' => 'שומר: גוון עור בהיר',
    '💂🏼' => 'שומר: גוון עור בהיר בינוני',
    '💂🏽' => 'שומר: גוון עור בינוני',
    '💂🏾' => 'שומר: גוון עור כהה בינוני',
    '💂🏿' => 'שומר: גוון עור כהה',
    '🥷🏻' => 'נינג׳ה: גוון עור בהיר',
    '🥷🏼' => 'נינג׳ה: גוון עור בהיר בינוני',
    '🥷🏽' => 'נינג׳ה: גוון עור בינוני',
    '🥷🏾' => 'נינג׳ה: גוון עור כהה בינוני',
    '🥷🏿' => 'נינג׳ה: גוון עור כהה',
    '👷🏻' => 'פועל בניין: גוון עור בהיר',
    '👷🏼' => 'פועל בניין: גוון עור בהיר בינוני',
    '👷🏽' => 'פועל בניין: גוון עור בינוני',
    '👷🏾' => 'פועל בניין: גוון עור כהה בינוני',
    '👷🏿' => 'פועל בניין: גוון עור כהה',
    '🫅🏻' => 'פרצוף עם כתר: גוון עור בהיר',
    '🫅🏼' => 'פרצוף עם כתר: גוון עור בהיר בינוני',
    '🫅🏽' => 'פרצוף עם כתר: גוון עור בינוני',
    '🫅🏾' => 'פרצוף עם כתר: גוון עור כהה בינוני',
    '🫅🏿' => 'פרצוף עם כתר: גוון עור כהה',
    '🤴🏻' => 'נסיך עם כתר: גוון עור בהיר',
    '🤴🏼' => 'נסיך עם כתר: גוון עור בהיר בינוני',
    '🤴🏽' => 'נסיך עם כתר: גוון עור בינוני',
    '🤴🏾' => 'נסיך עם כתר: גוון עור כהה בינוני',
    '🤴🏿' => 'נסיך עם כתר: גוון עור כהה',
    '👸🏻' => 'נסיכה: גוון עור בהיר',
    '👸🏼' => 'נסיכה: גוון עור בהיר בינוני',
    '👸🏽' => 'נסיכה: גוון עור בינוני',
    '👸🏾' => 'נסיכה: גוון עור כהה בינוני',
    '👸🏿' => 'נסיכה: גוון עור כהה',
    '👳🏻' => 'אדם עם טורבן: גוון עור בהיר',
    '👳🏼' => 'אדם עם טורבן: גוון עור בהיר בינוני',
    '👳🏽' => 'אדם עם טורבן: גוון עור בינוני',
    '👳🏾' => 'אדם עם טורבן: גוון עור כהה בינוני',
    '👳🏿' => 'אדם עם טורבן: גוון עור כהה',
    '👲🏻' => 'אדם עם כובע סיני: גוון עור בהיר',
    '👲🏼' => 'אדם עם כובע סיני: גוון עור בהיר בינוני',
    '👲🏽' => 'אדם עם כובע סיני: גוון עור בינוני',
    '👲🏾' => 'אדם עם כובע סיני: גוון עור כהה בינוני',
    '👲🏿' => 'אדם עם כובע סיני: גוון עור כהה',
    '🧕🏻' => 'אישה עם רעלה: גוון עור בהיר',
    '🧕🏼' => 'אישה עם רעלה: גוון עור בהיר בינוני',
    '🧕🏽' => 'אישה עם רעלה: גוון עור בינוני',
    '🧕🏾' => 'אישה עם רעלה: גוון עור כהה בינוני',
    '🧕🏿' => 'אישה עם רעלה: גוון עור כהה',
    '🤵🏻' => 'איש בטוקסידו: גוון עור בהיר',
    '🤵🏼' => 'איש בטוקסידו: גוון עור בהיר בינוני',
    '🤵🏽' => 'איש בטוקסידו: גוון עור בינוני',
    '🤵🏾' => 'איש בטוקסידו: גוון עור כהה בינוני',
    '🤵🏿' => 'איש בטוקסידו: גוון עור כהה',
    '👰🏻' => 'כלה עם הינומה: גוון עור בהיר',
    '👰🏼' => 'כלה עם הינומה: גוון עור בהיר בינוני',
    '👰🏽' => 'כלה עם הינומה: גוון עור בינוני',
    '👰🏾' => 'כלה עם הינומה: גוון עור כהה בינוני',
    '👰🏿' => 'כלה עם הינומה: גוון עור כהה',
    '🤰🏻' => 'אישה בהיריון: גוון עור בהיר',
    '🤰🏼' => 'אישה בהיריון: גוון עור בהיר בינוני',
    '🤰🏽' => 'אישה בהיריון: גוון עור בינוני',
    '🤰🏾' => 'אישה בהיריון: גוון עור כהה בינוני',
    '🤰🏿' => 'אישה בהיריון: גוון עור כהה',
    '🫃🏻' => 'איש עם בטן היריון: גוון עור בהיר',
    '🫃🏼' => 'איש עם בטן היריון: גוון עור בהיר בינוני',
    '🫃🏽' => 'איש עם בטן היריון: גוון עור בינוני',
    '🫃🏾' => 'איש עם בטן היריון: גוון עור כהה בינוני',
    '🫃🏿' => 'איש עם בטן היריון: גוון עור כהה',
    '🫄🏻' => 'בהריון: גוון עור בהיר',
    '🫄🏼' => 'בהריון: גוון עור בהיר בינוני',
    '🫄🏽' => 'בהריון: גוון עור בינוני',
    '🫄🏾' => 'בהריון: גוון עור כהה בינוני',
    '🫄🏿' => 'בהריון: גוון עור כהה',
    '🤱🏻' => 'אישה מניקה: גוון עור בהיר',
    '🤱🏼' => 'אישה מניקה: גוון עור בהיר בינוני',
    '🤱🏽' => 'אישה מניקה: גוון עור בינוני',
    '🤱🏾' => 'אישה מניקה: גוון עור כהה בינוני',
    '🤱🏿' => 'אישה מניקה: גוון עור כהה',
    '👼🏻' => 'מלאך תינוק: גוון עור בהיר',
    '👼🏼' => 'מלאך תינוק: גוון עור בהיר בינוני',
    '👼🏽' => 'מלאך תינוק: גוון עור בינוני',
    '👼🏾' => 'מלאך תינוק: גוון עור כהה בינוני',
    '👼🏿' => 'מלאך תינוק: גוון עור כהה',
    '🎅🏻' => 'סנטה קלאוס: גוון עור בהיר',
    '🎅🏼' => 'סנטה קלאוס: גוון עור בהיר בינוני',
    '🎅🏽' => 'סנטה קלאוס: גוון עור בינוני',
    '🎅🏾' => 'סנטה קלאוס: גוון עור כהה בינוני',
    '🎅🏿' => 'סנטה קלאוס: גוון עור כהה',
    '🤶🏻' => 'גב׳ סנטה: גוון עור בהיר',
    '🤶🏼' => 'גב׳ סנטה: גוון עור בהיר בינוני',
    '🤶🏽' => 'גב׳ סנטה: גוון עור בינוני',
    '🤶🏾' => 'גב׳ סנטה: גוון עור כהה בינוני',
    '🤶🏿' => 'גב׳ סנטה: גוון עור כהה',
    '🦸🏻' => 'גיבור על: גוון עור בהיר',
    '🦸🏼' => 'גיבור על: גוון עור בהיר בינוני',
    '🦸🏽' => 'גיבור על: גוון עור בינוני',
    '🦸🏾' => 'גיבור על: גוון עור כהה בינוני',
    '🦸🏿' => 'גיבור על: גוון עור כהה',
    '🦹🏻' => 'נבל על: גוון עור בהיר',
    '🦹🏼' => 'נבל על: גוון עור בהיר בינוני',
    '🦹🏽' => 'נבל על: גוון עור בינוני',
    '🦹🏾' => 'נבל על: גוון עור כהה בינוני',
    '🦹🏿' => 'נבל על: גוון עור כהה',
    '🧙🏻' => 'קוסם: גוון עור בהיר',
    '🧙🏼' => 'קוסם: גוון עור בהיר בינוני',
    '🧙🏽' => 'קוסם: גוון עור בינוני',
    '🧙🏾' => 'קוסם: גוון עור כהה בינוני',
    '🧙🏿' => 'קוסם: גוון עור כהה',
    '🧚🏻' => 'פיה: גוון עור בהיר',
    '🧚🏼' => 'פיה: גוון עור בהיר בינוני',
    '🧚🏽' => 'פיה: גוון עור בינוני',
    '🧚🏾' => 'פיה: גוון עור כהה בינוני',
    '🧚🏿' => 'פיה: גוון עור כהה',
    '🧛🏻' => 'ערפד: גוון עור בהיר',
    '🧛🏼' => 'ערפד: גוון עור בהיר בינוני',
    '🧛🏽' => 'ערפד: גוון עור בינוני',
    '🧛🏾' => 'ערפד: גוון עור כהה בינוני',
    '🧛🏿' => 'ערפד: גוון עור כהה',
    '🧜🏻' => 'בתולת ים: גוון עור בהיר',
    '🧜🏼' => 'בתולת ים: גוון עור בהיר בינוני',
    '🧜🏽' => 'בתולת ים: גוון עור בינוני',
    '🧜🏾' => 'בתולת ים: גוון עור כהה בינוני',
    '🧜🏿' => 'בתולת ים: גוון עור כהה',
    '🧝🏻' => 'אלף: גוון עור בהיר',
    '🧝🏼' => 'אלף: גוון עור בהיר בינוני',
    '🧝🏽' => 'אלף: גוון עור בינוני',
    '🧝🏾' => 'אלף: גוון עור כהה בינוני',
    '🧝🏿' => 'אלף: גוון עור כהה',
    '💆🏻' => 'עיסוי פנים: גוון עור בהיר',
    '💆🏼' => 'עיסוי פנים: גוון עור בהיר בינוני',
    '💆🏽' => 'עיסוי פנים: גוון עור בינוני',
    '💆🏾' => 'עיסוי פנים: גוון עור כהה בינוני',
    '💆🏿' => 'עיסוי פנים: גוון עור כהה',
    '💇🏻' => 'תספורת: גוון עור בהיר',
    '💇🏼' => 'תספורת: גוון עור בהיר בינוני',
    '💇🏽' => 'תספורת: גוון עור בינוני',
    '💇🏾' => 'תספורת: גוון עור כהה בינוני',
    '💇🏿' => 'תספורת: גוון עור כהה',
    '🚶🏻' => 'איש הולך: גוון עור בהיר',
    '🚶🏼' => 'איש הולך: גוון עור בהיר בינוני',
    '🚶🏽' => 'איש הולך: גוון עור בינוני',
    '🚶🏾' => 'איש הולך: גוון עור כהה בינוני',
    '🚶🏿' => 'איש הולך: גוון עור כהה',
    '🧍🏻' => 'אדם עומד: גוון עור בהיר',
    '🧍🏼' => 'אדם עומד: גוון עור בהיר בינוני',
    '🧍🏽' => 'אדם עומד: גוון עור בינוני',
    '🧍🏾' => 'אדם עומד: גוון עור כהה בינוני',
    '🧍🏿' => 'אדם עומד: גוון עור כהה',
    '🧎🏻' => 'אדם כורע ברך: גוון עור בהיר',
    '🧎🏼' => 'אדם כורע ברך: גוון עור בהיר בינוני',
    '🧎🏽' => 'אדם כורע ברך: גוון עור בינוני',
    '🧎🏾' => 'אדם כורע ברך: גוון עור כהה בינוני',
    '🧎🏿' => 'אדם כורע ברך: גוון עור כהה',
    '🏃🏻' => 'רץ: גוון עור בהיר',
    '🏃🏼' => 'רץ: גוון עור בהיר בינוני',
    '🏃🏽' => 'רץ: גוון עור בינוני',
    '🏃🏾' => 'רץ: גוון עור כהה בינוני',
    '🏃🏿' => 'רץ: גוון עור כהה',
    '💃🏻' => 'רקדנית: גוון עור בהיר',
    '💃🏼' => 'רקדנית: גוון עור בהיר בינוני',
    '💃🏽' => 'רקדנית: גוון עור בינוני',
    '💃🏾' => 'רקדנית: גוון עור כהה בינוני',
    '💃🏿' => 'רקדנית: גוון עור כהה',
    '🕺🏻' => 'איש רוקד: גוון עור בהיר',
    '🕺🏼' => 'איש רוקד: גוון עור בהיר בינוני',
    '🕺🏽' => 'איש רוקד: גוון עור בינוני',
    '🕺🏾' => 'איש רוקד: גוון עור כהה בינוני',
    '🕺🏿' => 'איש רוקד: גוון עור כהה',
    '🕴🏻' => 'אדם בחליפת עסקים מרחף: גוון עור בהיר',
    '🕴🏼' => 'אדם בחליפת עסקים מרחף: גוון עור בהיר בינוני',
    '🕴🏽' => 'אדם בחליפת עסקים מרחף: גוון עור בינוני',
    '🕴🏾' => 'אדם בחליפת עסקים מרחף: גוון עור כהה בינוני',
    '🕴🏿' => 'אדם בחליפת עסקים מרחף: גוון עור כהה',
    '👯🏻' => 'נשים עם אוזני ארנב רוקדות: גוון עור בהיר',
    '👯🏼' => 'נשים עם אוזני ארנב רוקדות: גוון עור בהיר בינוני',
    '👯🏽' => 'נשים עם אוזני ארנב רוקדות: גוון עור בינוני',
    '👯🏾' => 'נשים עם אוזני ארנב רוקדות: גוון עור כהה בינוני',
    '👯🏿' => 'נשים עם אוזני ארנב רוקדות: גוון עור כהה',
    '🧖🏻' => 'מישהי בסאונה: גוון עור בהיר',
    '🧖🏼' => 'מישהי בסאונה: גוון עור בהיר בינוני',
    '🧖🏽' => 'מישהי בסאונה: גוון עור בינוני',
    '🧖🏾' => 'מישהי בסאונה: גוון עור כהה בינוני',
    '🧖🏿' => 'מישהי בסאונה: גוון עור כהה',
    '🧗🏻' => 'מישהו מטפס: גוון עור בהיר',
    '🧗🏼' => 'מישהו מטפס: גוון עור בהיר בינוני',
    '🧗🏽' => 'מישהו מטפס: גוון עור בינוני',
    '🧗🏾' => 'מישהו מטפס: גוון עור כהה בינוני',
    '🧗🏿' => 'מישהו מטפס: גוון עור כהה',
    '🏇🏻' => 'מירוצי סוסים: גוון עור בהיר',
    '🏇🏼' => 'מירוצי סוסים: גוון עור בהיר בינוני',
    '🏇🏽' => 'מירוצי סוסים: גוון עור בינוני',
    '🏇🏾' => 'מירוצי סוסים: גוון עור כהה בינוני',
    '🏇🏿' => 'מירוצי סוסים: גוון עור כהה',
    '🏂🏻' => 'גולש סנובורד: גוון עור בהיר',
    '🏂🏼' => 'גולש סנובורד: גוון עור בהיר בינוני',
    '🏂🏽' => 'גולש סנובורד: גוון עור בינוני',
    '🏂🏾' => 'גולש סנובורד: גוון עור כהה בינוני',
    '🏂🏿' => 'גולש סנובורד: גוון עור כהה',
    '🏌🏻' => 'שחקן גולף: גוון עור בהיר',
    '🏌🏼' => 'שחקן גולף: גוון עור בהיר בינוני',
    '🏌🏽' => 'שחקן גולף: גוון עור בינוני',
    '🏌🏾' => 'שחקן גולף: גוון עור כהה בינוני',
    '🏌🏿' => 'שחקן גולף: גוון עור כהה',
    '🏄🏻' => 'גולש גלים: גוון עור בהיר',
    '🏄🏼' => 'גולש גלים: גוון עור בהיר בינוני',
    '🏄🏽' => 'גולש גלים: גוון עור בינוני',
    '🏄🏾' => 'גולש גלים: גוון עור כהה בינוני',
    '🏄🏿' => 'גולש גלים: גוון עור כהה',
    '🚣🏻' => 'סירת משוטים: גוון עור בהיר',
    '🚣🏼' => 'סירת משוטים: גוון עור בהיר בינוני',
    '🚣🏽' => 'סירת משוטים: גוון עור בינוני',
    '🚣🏾' => 'סירת משוטים: גוון עור כהה בינוני',
    '🚣🏿' => 'סירת משוטים: גוון עור כהה',
    '🏊🏻' => 'שחיין: גוון עור בהיר',
    '🏊🏼' => 'שחיין: גוון עור בהיר בינוני',
    '🏊🏽' => 'שחיין: גוון עור בינוני',
    '🏊🏾' => 'שחיין: גוון עור כהה בינוני',
    '🏊🏿' => 'שחיין: גוון עור כהה',
    '⛹🏻' => 'הקפצת כדור: גוון עור בהיר',
    '⛹🏼' => 'הקפצת כדור: גוון עור בהיר בינוני',
    '⛹🏽' => 'הקפצת כדור: גוון עור בינוני',
    '⛹🏾' => 'הקפצת כדור: גוון עור כהה בינוני',
    '⛹🏿' => 'הקפצת כדור: גוון עור כהה',
    '🏋🏻' => 'מרים משקולות: גוון עור בהיר',
    '🏋🏼' => 'מרים משקולות: גוון עור בהיר בינוני',
    '🏋🏽' => 'מרים משקולות: גוון עור בינוני',
    '🏋🏾' => 'מרים משקולות: גוון עור כהה בינוני',
    '🏋🏿' => 'מרים משקולות: גוון עור כהה',
    '🚴🏻' => 'רוכב אופניים: גוון עור בהיר',
    '🚴🏼' => 'רוכב אופניים: גוון עור בהיר בינוני',
    '🚴🏽' => 'רוכב אופניים: גוון עור בינוני',
    '🚴🏾' => 'רוכב אופניים: גוון עור כהה בינוני',
    '🚴🏿' => 'רוכב אופניים: גוון עור כהה',
    '🚵🏻' => 'רוכב אופני הרים: גוון עור בהיר',
    '🚵🏼' => 'רוכב אופני הרים: גוון עור בהיר בינוני',
    '🚵🏽' => 'רוכב אופני הרים: גוון עור בינוני',
    '🚵🏾' => 'רוכב אופני הרים: גוון עור כהה בינוני',
    '🚵🏿' => 'רוכב אופני הרים: גוון עור כהה',
    '🤸🏻' => 'גלגלון: גוון עור בהיר',
    '🤸🏼' => 'גלגלון: גוון עור בהיר בינוני',
    '🤸🏽' => 'גלגלון: גוון עור בינוני',
    '🤸🏾' => 'גלגלון: גוון עור כהה בינוני',
    '🤸🏿' => 'גלגלון: גוון עור כהה',
    '🤼🏻' => 'מתאבקים: גוון עור בהיר',
    '🤼🏼' => 'מתאבקים: גוון עור בהיר בינוני',
    '🤼🏽' => 'מתאבקים: גוון עור בינוני',
    '🤼🏾' => 'מתאבקים: גוון עור כהה בינוני',
    '🤼🏿' => 'מתאבקים: גוון עור כהה',
    '🤽🏻' => 'כדורמים: גוון עור בהיר',
    '🤽🏼' => 'כדורמים: גוון עור בהיר בינוני',
    '🤽🏽' => 'כדורמים: גוון עור בינוני',
    '🤽🏾' => 'כדורמים: גוון עור כהה בינוני',
    '🤽🏿' => 'כדורמים: גוון עור כהה',
    '🤾🏻' => 'כדוריד: גוון עור בהיר',
    '🤾🏼' => 'כדוריד: גוון עור בהיר בינוני',
    '🤾🏽' => 'כדוריד: גוון עור בינוני',
    '🤾🏾' => 'כדוריד: גוון עור כהה בינוני',
    '🤾🏿' => 'כדוריד: גוון עור כהה',
    '🤹🏻' => 'להטוטן: גוון עור בהיר',
    '🤹🏼' => 'להטוטן: גוון עור בהיר בינוני',
    '🤹🏽' => 'להטוטן: גוון עור בינוני',
    '🤹🏾' => 'להטוטן: גוון עור כהה בינוני',
    '🤹🏿' => 'להטוטן: גוון עור כהה',
    '🧘🏻' => 'מישהי בתנוחת לוטוס: גוון עור בהיר',
    '🧘🏼' => 'מישהי בתנוחת לוטוס: גוון עור בהיר בינוני',
    '🧘🏽' => 'מישהי בתנוחת לוטוס: גוון עור בינוני',
    '🧘🏾' => 'מישהי בתנוחת לוטוס: גוון עור כהה בינוני',
    '🧘🏿' => 'מישהי בתנוחת לוטוס: גוון עור כהה',
    '🛀🏻' => 'אדם באמבטיה: גוון עור בהיר',
    '🛀🏼' => 'אדם באמבטיה: גוון עור בהיר בינוני',
    '🛀🏽' => 'אדם באמבטיה: גוון עור בינוני',
    '🛀🏾' => 'אדם באמבטיה: גוון עור כהה בינוני',
    '🛀🏿' => 'אדם באמבטיה: גוון עור כהה',
    '🛌🏻' => 'אדם במיטה: גוון עור בהיר',
    '🛌🏼' => 'אדם במיטה: גוון עור בהיר בינוני',
    '🛌🏽' => 'אדם במיטה: גוון עור בינוני',
    '🛌🏾' => 'אדם במיטה: גוון עור כהה בינוני',
    '🛌🏿' => 'אדם במיטה: גוון עור כהה',
    '👭🏻' => 'שתי נשים מחזיקות ידיים: גוון עור בהיר',
    '👭🏼' => 'שתי נשים מחזיקות ידיים: גוון עור בהיר בינוני',
    '👭🏽' => 'שתי נשים מחזיקות ידיים: גוון עור בינוני',
    '👭🏾' => 'שתי נשים מחזיקות ידיים: גוון עור כהה בינוני',
    '👭🏿' => 'שתי נשים מחזיקות ידיים: גוון עור כהה',
    '👫🏻' => 'איש ואישה מחזיקים ידיים: גוון עור בהיר',
    '👫🏼' => 'איש ואישה מחזיקים ידיים: גוון עור בהיר בינוני',
    '👫🏽' => 'איש ואישה מחזיקים ידיים: גוון עור בינוני',
    '👫🏾' => 'איש ואישה מחזיקים ידיים: גוון עור כהה בינוני',
    '👫🏿' => 'איש ואישה מחזיקים ידיים: גוון עור כהה',
    '👬🏻' => 'שני גברים מחזיקים ידיים: גוון עור בהיר',
    '👬🏼' => 'שני גברים מחזיקים ידיים: גוון עור בהיר בינוני',
    '👬🏽' => 'שני גברים מחזיקים ידיים: גוון עור בינוני',
    '👬🏾' => 'שני גברים מחזיקים ידיים: גוון עור כהה בינוני',
    '👬🏿' => 'שני גברים מחזיקים ידיים: גוון עור כהה',
    '💏🏻' => 'נשיקה: גוון עור בהיר',
    '💏🏼' => 'נשיקה: גוון עור בהיר בינוני',
    '💏🏽' => 'נשיקה: גוון עור בינוני',
    '💏🏾' => 'נשיקה: גוון עור כהה בינוני',
    '💏🏿' => 'נשיקה: גוון עור כהה',
    '💑🏻' => 'זוג עם לב: גוון עור בהיר',
    '💑🏼' => 'זוג עם לב: גוון עור בהיר בינוני',
    '💑🏽' => 'זוג עם לב: גוון עור בינוני',
    '💑🏾' => 'זוג עם לב: גוון עור כהה בינוני',
    '💑🏿' => 'זוג עם לב: גוון עור כהה',
    '🇦🇨' => 'דגל: האי אסנשן',
    '🇦🇩' => 'דגל: אנדורה',
    '🇦🇪' => 'דגל: איחוד האמירויות הערביות',
    '🇦🇫' => 'דגל: אפגניסטן',
    '🇦🇬' => 'דגל: אנטיגואה וברבודה',
    '🇦🇮' => 'דגל: אנגווילה',
    '🇦🇱' => 'דגל: אלבניה',
    '🇦🇲' => 'דגל: ארמניה',
    '🇦🇴' => 'דגל: אנגולה',
    '🇦🇶' => 'דגל: אנטארקטיקה',
    '🇦🇷' => 'דגל: ארגנטינה',
    '🇦🇸' => 'דגל: סמואה האמריקנית',
    '🇦🇹' => 'דגל: אוסטריה',
    '🇦🇺' => 'דגל: אוסטרליה',
    '🇦🇼' => 'דגל: ארובה',
    '🇦🇽' => 'דגל: איי אולנד',
    '🇦🇿' => 'דגל: אזרבייג׳ן',
    '🇧🇦' => 'דגל: בוסניה והרצגובינה',
    '🇧🇧' => 'דגל: ברבדוס',
    '🇧🇩' => 'דגל: בנגלדש',
    '🇧🇪' => 'דגל: בלגיה',
    '🇧🇫' => 'דגל: בורקינה פאסו',
    '🇧🇬' => 'דגל: בולגריה',
    '🇧🇭' => 'דגל: בחריין',
    '🇧🇮' => 'דגל: בורונדי',
    '🇧🇯' => 'דגל: בנין',
    '🇧🇱' => 'דגל: סנט ברתולומיאו',
    '🇧🇲' => 'דגל: ברמודה',
    '🇧🇳' => 'דגל: ברוניי',
    '🇧🇴' => 'דגל: בוליביה',
    '🇧🇶' => 'דגל: האיים הקריביים ההולנדיים',
    '🇧🇷' => 'דגל: ברזיל',
    '🇧🇸' => 'דגל: איי בהאמה',
    '🇧🇹' => 'דגל: בהוטן',
    '🇧🇻' => 'דגל: האי בובה',
    '🇧🇼' => 'דגל: בוטסואנה',
    '🇧🇾' => 'דגל: בלארוס',
    '🇧🇿' => 'דגל: בליז',
    '🇨🇦' => 'דגל: קנדה',
    '🇨🇨' => 'דגל: איי קוקוס (קילינג)',
    '🇨🇩' => 'דגל: קונגו - קינשאסה',
    '🇨🇫' => 'דגל: הרפובליקה המרכז-אפריקאית',
    '🇨🇬' => 'דגל: קונגו - ברזאויל',
    '🇨🇭' => 'דגל: שווייץ',
    '🇨🇮' => 'דגל: חוף השנהב',
    '🇨🇰' => 'דגל: איי קוק',
    '🇨🇱' => 'דגל: צ׳ילה',
    '🇨🇲' => 'דגל: קמרון',
    '🇨🇳' => 'דגל: סין',
    '🇨🇴' => 'דגל: קולומביה',
    '🇨🇵' => 'דגל: האי קליפרטון',
    '🇨🇶' => 'דגל: סרק',
    '🇨🇷' => 'דגל: קוסטה ריקה',
    '🇨🇺' => 'דגל: קובה',
    '🇨🇻' => 'דגל: כף ורדה',
    '🇨🇼' => 'דגל: קוראסאו',
    '🇨🇽' => 'דגל: אי חג המולד',
    '🇨🇾' => 'דגל: קפריסין',
    '🇨🇿' => 'דגל: צ׳כיה',
    '🇩🇪' => 'דגל: גרמניה',
    '🇩🇬' => 'דגל: דייגו גרסיה',
    '🇩🇯' => 'דגל: ג׳יבוטי',
    '🇩🇰' => 'דגל: דנמרק',
    '🇩🇲' => 'דגל: דומיניקה',
    '🇩🇴' => 'דגל: הרפובליקה הדומיניקנית',
    '🇩🇿' => 'דגל: אלג׳יריה',
    '🇪🇦' => 'דגל: סאוטה ומלייה',
    '🇪🇨' => 'דגל: אקוודור',
    '🇪🇪' => 'דגל: אסטוניה',
    '🇪🇬' => 'דגל: מצרים',
    '🇪🇭' => 'דגל: סהרה המערבית',
    '🇪🇷' => 'דגל: אריתריאה',
    '🇪🇸' => 'דגל: ספרד',
    '🇪🇹' => 'דגל: אתיופיה',
    '🇪🇺' => 'דגל: האיחוד האירופי',
    '🇫🇮' => 'דגל: פינלנד',
    '🇫🇯' => 'דגל: פיג׳י',
    '🇫🇰' => 'דגל: איי פוקלנד',
    '🇫🇲' => 'דגל: מיקרונזיה',
    '🇫🇴' => 'דגל: איי פארו',
    '🇫🇷' => 'דגל: צרפת',
    '🇬🇦' => 'דגל: גבון',
    '🇬🇧' => 'דגל: בריטניה',
    '🇬🇩' => 'דגל: גרנדה',
    '🇬🇪' => 'דגל: גאורגיה',
    '🇬🇫' => 'דגל: גיאנה הצרפתית',
    '🇬🇬' => 'דגל: גרנזי',
    '🇬🇭' => 'דגל: גאנה',
    '🇬🇮' => 'דגל: גיברלטר',
    '🇬🇱' => 'דגל: גרינלנד',
    '🇬🇲' => 'דגל: גמביה',
    '🇬🇳' => 'דגל: גינאה',
    '🇬🇵' => 'דגל: גוואדלופ',
    '🇬🇶' => 'דגל: גינאה המשוונית',
    '🇬🇷' => 'דגל: יוון',
    '🇬🇸' => 'דגל: ג׳ורג׳יה הדרומית ואיי סנדוויץ׳ הדרומיים',
    '🇬🇹' => 'דגל: גואטמלה',
    '🇬🇺' => 'דגל: גואם',
    '🇬🇼' => 'דגל: גינאה-ביסאו',
    '🇬🇾' => 'דגל: גיאנה',
    '🇭🇰' => 'דגל: הונג קונג (אזור מנהלי מיוחד של סין)',
    '🇭🇲' => 'דגל: איי הרד ומקדונלד',
    '🇭🇳' => 'דגל: הונדורס',
    '🇭🇷' => 'דגל: קרואטיה',
    '🇭🇹' => 'דגל: האיטי',
    '🇭🇺' => 'דגל: הונגריה',
    '🇮🇨' => 'דגל: האיים הקנריים',
    '🇮🇩' => 'דגל: אינדונזיה',
    '🇮🇪' => 'דגל: אירלנד',
    '🇮🇱' => 'דגל: ישראל',
    '🇮🇲' => 'דגל: האי מאן',
    '🇮🇳' => 'דגל: הודו',
    '🇮🇴' => 'דגל: הטריטוריה הבריטית באוקיינוס ההודי',
    '🇮🇶' => 'דגל: עיראק',
    '🇮🇷' => 'דגל: איראן',
    '🇮🇸' => 'דגל: איסלנד',
    '🇮🇹' => 'דגל: איטליה',
    '🇯🇪' => 'דגל: ג׳רזי',
    '🇯🇲' => 'דגל: ג׳מייקה',
    '🇯🇴' => 'דגל: ירדן',
    '🇯🇵' => 'דגל: יפן',
    '🇰🇪' => 'דגל: קניה',
    '🇰🇬' => 'דגל: קירגיזסטן',
    '🇰🇭' => 'דגל: קמבודיה',
    '🇰🇮' => 'דגל: קיריבאטי',
    '🇰🇲' => 'דגל: קומורו',
    '🇰🇳' => 'דגל: סנט קיטס ונוויס',
    '🇰🇵' => 'דגל: קוריאה הצפונית',
    '🇰🇷' => 'דגל: קוריאה הדרומית',
    '🇰🇼' => 'דגל: כווית',
    '🇰🇾' => 'דגל: איי קיימן',
    '🇰🇿' => 'דגל: קזחסטן',
    '🇱🇦' => 'דגל: לאוס',
    '🇱🇧' => 'דגל: לבנון',
    '🇱🇨' => 'דגל: סנט לוסיה',
    '🇱🇮' => 'דגל: ליכטנשטיין',
    '🇱🇰' => 'דגל: סרי לנקה',
    '🇱🇷' => 'דגל: ליבריה',
    '🇱🇸' => 'דגל: לסוטו',
    '🇱🇹' => 'דגל: ליטא',
    '🇱🇺' => 'דגל: לוקסמבורג',
    '🇱🇻' => 'דגל: לטביה',
    '🇱🇾' => 'דגל: לוב',
    '🇲🇦' => 'דגל: מרוקו',
    '🇲🇨' => 'דגל: מונקו',
    '🇲🇩' => 'דגל: מולדובה',
    '🇲🇪' => 'דגל: מונטנגרו',
    '🇲🇫' => 'דגל: סן מרטן',
    '🇲🇬' => 'דגל: מדגסקר',
    '🇲🇭' => 'דגל: איי מרשל',
    '🇲🇰' => 'דגל: מקדוניה הצפונית',
    '🇲🇱' => 'דגל: מאלי',
    '🇲🇲' => 'דגל: מיאנמר (בורמה)',
    '🇲🇳' => 'דגל: מונגוליה',
    '🇲🇴' => 'דגל: מקאו (אזור מנהלי מיוחד של סין)',
    '🇲🇵' => 'דגל: איי מריאנה הצפוניים',
    '🇲🇶' => 'דגל: מרטיניק',
    '🇲🇷' => 'דגל: מאוריטניה',
    '🇲🇸' => 'דגל: מונסראט',
    '🇲🇹' => 'דגל: מלטה',
    '🇲🇺' => 'דגל: מאוריציוס',
    '🇲🇻' => 'דגל: האיים המלדיביים',
    '🇲🇼' => 'דגל: מלאווי',
    '🇲🇽' => 'דגל: מקסיקו',
    '🇲🇾' => 'דגל: מלזיה',
    '🇲🇿' => 'דגל: מוזמביק',
    '🇳🇦' => 'דגל: נמיביה',
    '🇳🇨' => 'דגל: קלדוניה החדשה',
    '🇳🇪' => 'דגל: ניז׳ר',
    '🇳🇫' => 'דגל: האי נורפוק',
    '🇳🇬' => 'דגל: ניגריה',
    '🇳🇮' => 'דגל: ניקרגואה',
    '🇳🇱' => 'דגל: הולנד',
    '🇳🇴' => 'דגל: נורווגיה',
    '🇳🇵' => 'דגל: נפאל',
    '🇳🇷' => 'דגל: נאורו',
    '🇳🇺' => 'דגל: ניווה',
    '🇳🇿' => 'דגל: ניו זילנד',
    '🇴🇲' => 'דגל: עומאן',
    '🇵🇦' => 'דגל: פנמה',
    '🇵🇪' => 'דגל: פרו',
    '🇵🇫' => 'דגל: פולינזיה הצרפתית',
    '🇵🇬' => 'דגל: פפואה גינאה החדשה',
    '🇵🇭' => 'דגל: הפיליפינים',
    '🇵🇰' => 'דגל: פקיסטן',
    '🇵🇱' => 'דגל: פולין',
    '🇵🇲' => 'דגל: סנט פייר ומיקלון',
    '🇵🇳' => 'דגל: איי פיטקרן',
    '🇵🇷' => 'דגל: פוארטו ריקו',
    '🇵🇸' => 'דגל: השטחים הפלסטיניים',
    '🇵🇹' => 'דגל: פורטוגל',
    '🇵🇼' => 'דגל: פלאו',
    '🇵🇾' => 'דגל: פרגוואי',
    '🇶🇦' => 'דגל: קטאר',
    '🇷🇪' => 'דגל: ראוניון',
    '🇷🇴' => 'דגל: רומניה',
    '🇷🇸' => 'דגל: סרביה',
    '🇷🇺' => 'דגל: רוסיה',
    '🇷🇼' => 'דגל: רואנדה',
    '🇸🇦' => 'דגל: ערב הסעודית',
    '🇸🇧' => 'דגל: איי שלמה',
    '🇸🇨' => 'דגל: איי סיישל',
    '🇸🇩' => 'דגל: סודן',
    '🇸🇪' => 'דגל: שוודיה',
    '🇸🇬' => 'דגל: סינגפור',
    '🇸🇭' => 'דגל: סנט הלנה',
    '🇸🇮' => 'דגל: סלובניה',
    '🇸🇯' => 'דגל: סבאלברד ויאן מאיין',
    '🇸🇰' => 'דגל: סלובקיה',
    '🇸🇱' => 'דגל: סיירה לאון',
    '🇸🇲' => 'דגל: סן מרינו',
    '🇸🇳' => 'דגל: סנגל',
    '🇸🇴' => 'דגל: סומליה',
    '🇸🇷' => 'דגל: סורינאם',
    '🇸🇸' => 'דגל: דרום סודן',
    '🇸🇹' => 'דגל: סאו טומה ופרינסיפה',
    '🇸🇻' => 'דגל: אל סלבדור',
    '🇸🇽' => 'דגל: סנט מארטן',
    '🇸🇾' => 'דגל: סוריה',
    '🇸🇿' => 'דגל: אסוואטיני',
    '🇹🇦' => 'דגל: טריסטן דה קונה',
    '🇹🇨' => 'דגל: איי טרקס וקייקוס',
    '🇹🇩' => 'דגל: צ׳אד',
    '🇹🇫' => 'דגל: הטריטוריות הדרומיות של צרפת',
    '🇹🇬' => 'דגל: טוגו',
    '🇹🇭' => 'דגל: תאילנד',
    '🇹🇯' => 'דגל: טג׳יקיסטן',
    '🇹🇰' => 'דגל: טוקלאו',
    '🇹🇱' => 'דגל: טימור-לסטה',
    '🇹🇲' => 'דגל: טורקמניסטן',
    '🇹🇳' => 'דגל: תוניסיה',
    '🇹🇴' => 'דגל: טונגה',
    '🇹🇷' => 'דגל: טורקיה',
    '🇹🇹' => 'דגל: טרינידד וטובגו',
    '🇹🇻' => 'דגל: טובאלו',
    '🇹🇼' => 'דגל: טייוואן',
    '🇹🇿' => 'דגל: טנזניה',
    '🇺🇦' => 'דגל: אוקראינה',
    '🇺🇬' => 'דגל: אוגנדה',
    '🇺🇲' => 'דגל: האיים המרוחקים הקטנים של ארה״ב',
    '🇺🇳' => 'דגל: האומות המאוחדות',
    '🇺🇸' => 'דגל: ארצות הברית',
    '🇺🇾' => 'דגל: אורוגוואי',
    '🇺🇿' => 'דגל: אוזבקיסטן',
    '🇻🇦' => 'דגל: הוותיקן',
    '🇻🇨' => 'דגל: סנט וינסנט והגרנדינים',
    '🇻🇪' => 'דגל: ונצואלה',
    '🇻🇬' => 'דגל: איי הבתולה הבריטיים',
    '🇻🇮' => 'דגל: איי הבתולה של ארצות הברית',
    '🇻🇳' => 'דגל: וייטנאם',
    '🇻🇺' => 'דגל: ונואטו',
    '🇼🇫' => 'דגל: איי ווליס ופוטונה',
    '🇼🇸' => 'דגל: סמואה',
    '🇽🇰' => 'דגל: קוסובו',
    '🇾🇪' => 'דגל: תימן',
    '🇾🇹' => 'דגל: מאיוט',
    '🇿🇦' => 'דגל: דרום אפריקה',
    '🇿🇲' => 'דגל: זמביה',
    '🇿🇼' => 'דגל: זימבבואה',
    '🔟' => 'מקש: 10',
    '🏻' => 'גוון עור בהיר',
    '🏼' => 'גוון עור בהיר בינוני',
    '🏽' => 'גוון עור בינוני',
    '🏾' => 'גוון עור כהה בינוני',
    '🏿' => 'גוון עור כהה',
    '😀' => 'חיוך רחב',
    '😃' => 'פרצוף עם חיוך רחב ועיניים גדולות',
    '😄' => 'פרצוף מחייך עם פה פתוח ועיניים מחייכות',
    '😁' => 'פרצוף זורח עם עיניים מחייכות',
    '😆' => 'פרצוף מחייך בפה פתוח ועיניים עצומות',
    '😅' => 'פרצוף מחייך עם טיפת זיעה',
    '🤣' => 'מתגלגל על הרצפה מרוב צחוק',
    '😂' => 'פרצוף עם דמעות שמחה',
    '🙂' => 'פרצוף עם חיוך קטן',
    '🙃' => 'פרצוף הפוך',
    '🫠' => 'פרצוף נמס',
    '😉' => 'פרצוף קורץ',
    '😊' => 'פרצוף מחייך עם עיניים מחייכות',
    '😇' => 'פרצוף מחייך עם הילת מלאך',
    '🥰' => 'פרצוף מחייך עם לבבות',
    '😍' => 'פרצוף מחייך עם עיני לבבות',
    '🤩' => 'פרצוף עם עיני כוכבים',
    '😘' => 'פרצוף מפריח נשיקה',
    '😗' => 'פרצוף מנשק',
    '☺' => 'פרצוף מחייך',
    '😚' => 'פרצוף מנשק עם עיניים סגורות',
    '😙' => 'פרצוף מנשק עם עיניים מחייכות',
    '🥲' => 'פרצוף מחייך עם דמעה',
    '😋' => 'פרצוף של הנאה מאוכל טעים',
    '😛' => 'פרצוף מוציא לשון',
    '😜' => 'פרצוף מוציא לשון וקורץ',
    '🤪' => 'פרצוף משוגע',
    '😝' => 'פרצוף מוציא לשון ועוצם עיניים בחוזקה',
    '🤑' => 'פרצוף עם סימני דולר בעיניים ובלשון',
    '🤗' => 'פרצוף מחבק',
    '🤭' => 'פרצוף עם יד על הפה',
    '🫢' => 'פרצוף עם יד על הפה ועיניים פעורות',
    '🫣' => 'פרצוף מציץ עם יד על העיניים',
    '🤫' => 'פרצוף עושה סימן לשקט',
    '🤔' => 'פרצוף חושב',
    '🫡' => 'פרצוף מצדיע',
    '🤐' => 'פרצוף עם פה סגור ברוכסן',
    '🤨' => 'פרצוף עם גבות מורמות',
    '😐' => 'פרצוף חסר הבעה',
    '😑' => 'פרצוף חסר הבעה ועיניים סגורות',
    '😶' => 'פרצוף ללא פה',
    '🫥' => 'פרצוף עם קו מקווקו',
    '😏' => 'פרצוף זחוח',
    '😒' => 'פרצוף לא מתרשם',
    '🙄' => 'פרצוף מגלגל עיניים',
    '😬' => 'פרצוף חושף שיניים',
    '🤥' => 'פרצוף עם אף פינוקיו',
    '🫨' => 'פרצוף רועד',
    '😌' => 'פרצוף של אנחת רווחה',
    '😔' => 'פרצוף מהורהר',
    '😪' => 'פרצוף ישנוני',
    '🤤' => 'פרצוף מזיל ריר',
    '😴' => 'פרצוף ישן',
    '🫩' => 'פרצוף עם שקיות מתחת לעיניים',
    '😷' => 'פרצוף עם מסיכת מנתח',
    '🤒' => 'פרצוף עם מדחום',
    '🤕' => 'פרצוף עם תחבושת ראש',
    '🤢' => 'פרצוף סובל מבחילה',
    '🤮' => 'פרצוף מקיא',
    '🤧' => 'פרצוף מקנח אף',
    '🥵' => 'מת מחום',
    '🥶' => 'למות מקור',
    '🥴' => 'שיכור',
    '😵' => 'פרצוף עם סחרחורת',
    '🤯' => 'ראש מתפוצץ',
    '🤠' => 'פרצוף עם כובע בוקרים',
    '🥳' => 'חגיגה',
    '🥸' => 'פרצוף עם תחפושת',
    '😎' => 'פרצוף מחייך עם משקפי שמש',
    '🤓' => 'פרצוף של חנון',
    '🧐' => 'פרצוף עם מונוקל',
    '😕' => 'פרצוף מבולבל',
    '🫤' => 'פרצוף מעקם את הפה',
    '😟' => 'פרצוף מודאג',
    '🙁' => 'פרצוף עם מבט עצוב',
    '☹' => 'פרצוף עצוב',
    '😮' => 'פרצוף עם פה פתוח',
    '😯' => 'פרצוף מופתע',
    '😲' => 'פרצוף נדהם',
    '😳' => 'פרצוף נדהם וסמוק',
    '🫪' => 'פרצוף מעוות',
    '🥺' => 'מתחנן',
    '🥹' => 'פרצוף עם דמעות',
    '😦' => 'פרצוף עצוב עם פה פתוח',
    '😧' => 'פרצוף מיוסר',
    '😨' => 'פרצוף מפוחד',
    '😰' => 'פרצוף מפחד עם זיעה קרה',
    '😥' => 'פרצוף מאוכזב עם דמעה',
    '😢' => 'פרצוף בוכה',
    '😭' => 'פרצוף בוכה בקול',
    '😱' => 'פרצוף צורח בפחד',
    '😖' => 'פרצוף מתוסכל',
    '😣' => 'פרצוף סובל',
    '😞' => 'פרצוף מאוכזב',
    '😓' => 'פרצוף עם זיעה קרה',
    '😩' => 'פרצוף מותש',
    '😫' => 'פרצוף עייף',
    '🥱' => 'פרצוף מפהק',
    '😤' => 'פרצוף עם קיטור יוצא מהאף',
    '😡' => 'פרצוף זועף',
    '😠' => 'פרצוף כועס',
    '🤬' => 'פרצוף עם סמלים על הפה',
    '😈' => 'פרצוף מחייך עם קרניים',
    '👿' => 'פרצוף כועס עם קרניים',
    '💀' => 'גולגולת',
    '☠' => 'סמל פיראטים',
    '💩' => 'גוש קקי',
    '🤡' => 'פרצוף ליצן',
    '👹' => 'מפלצת',
    '👺' => 'גובלין',
    '👻' => 'רוח רפאים',
    '👽' => 'חייזר',
    '👾' => 'מפלצת חייזרית',
    '🤖' => 'רובוט',
    '😺' => 'חתול מחייך',
    '😸' => 'חתול מחייך עם עיניים מחייכות',
    '😹' => 'חתול עם דמעות שמחה',
    '😻' => 'חתול מחייך עם עיניים בצורת לב',
    '😼' => 'חתול עם חיוך עקום',
    '😽' => 'חתול מנשק',
    '🙀' => 'חתול פוחד',
    '😿' => 'חתול בוכה',
    '😾' => 'חתול זועף',
    '🙈' => 'לא ראיתי',
    '🙉' => 'לא שמעתי',
    '🙊' => 'לא דיברתי',
    '💌' => 'מכתב אהבה',
    '💘' => 'לב עם חץ',
    '💝' => 'לב עם סרט מתנה',
    '💖' => 'לב מנצנץ',
    '💗' => 'לב גדל',
    '💓' => 'לב פועם',
    '💞' => 'לבבות נעים במעגל',
    '💕' => 'שני לבבות',
    '💟' => 'לב בריבוע ורוד',
    '❣' => 'סימן קריאה בצורת לב',
    '💔' => 'לב שבור',
    '❤' => 'לב אדום',
    '🩷' => 'לב ורוד',
    '🧡' => 'לב כתום',
    '💛' => 'לב צהוב',
    '💚' => 'לב ירוק',
    '💙' => 'לב כחול',
    '🩵' => 'לב תכלת',
    '💜' => 'לב סגול',
    '🤎' => 'לב חום',
    '🖤' => 'לב שחור',
    '🩶' => 'לב אפור',
    '🤍' => 'לב לבן',
    '💋' => 'סימן נשיקה',
    '💯' => 'ציון 100',
    '💢' => 'סמל כעס',
    '🫯' => 'ענן קרב',
    '💥' => 'פיצוץ',
    '💫' => 'כוכב נע במעגל',
    '💦' => 'טיפות זיעה',
    '💨' => 'ענן בתנועה מהירה',
    '🕳' => 'חור',
    '💬' => 'בועת דיבור',
    '🗨' => 'בועת דיבור משמאל',
    '🗯' => 'בועת דיבור כועס מימין',
    '💭' => 'בועת מחשבה',
    '💤' => 'סימן נחירה',
    '👋' => 'יד מנופפת',
    '🤚' => 'גב יד פרוש',
    '🖐' => 'כף יד פתוחה מורמת',
    '✋' => 'כף יד מורמת',
    '🖖' => 'הצדעה וולקנית',
    '🫱' => 'יד פונה ימינה',
    '🫲' => 'יד פונה שמאלה',
    '🫳' => 'כף יד פונה למטה',
    '🫴' => 'כף יד פונה למעלה',
    '🫷' => 'יד דוחפת שמאלה',
    '🫸' => 'יד דוחפת ימינה',
    '👌' => 'יד מסמנת שהכל בסדר',
    '🤌' => 'יד מסמנת רק רגע',
    '🤏' => 'יד צובטת',
    '✌' => 'אצבעות מסמנות ניצחון',
    '🤞' => 'יד מחזיקה אצבעות',
    '🫰' => 'קליק באצבעות',
    '🤟' => 'בוהן, אצבע וזרת מורמות',
    '🤘' => 'יד מסמנת קרניים',
    '🤙' => 'יד מסמנת ’תתקשר אליי’',
    '👈' => 'גב יד מצביעה שמאלה',
    '👉' => 'גב יד מצביעה ימינה',
    '👆' => 'גב יד מצביעה למעלה',
    '🖕' => 'אצבע משולשת',
    '👇' => 'גב יד מצביעה למטה',
    '☝' => 'יד מצביעה למעלה',
    '🫵' => 'אצבע מצביעה',
    '👍' => 'אגודל למעלה',
    '👎' => 'אגודל למטה',
    '✊' => 'אגרוף מורם',
    '👊' => 'מכת אגרוף',
    '🤛' => 'יד קמוצה שמאלה',
    '🤜' => 'יד קמוצה ימינה',
    '👏' => 'מחיאות כפיים',
    '🙌' => 'כפות ידיים מורמות',
    '🫶' => 'סימן לב עם הידיים',
    '👐' => 'כפות ידיים פתוחות',
    '🤲' => 'כפות ידיים מוצמדות ופונות כלפי מעלה',
    '🤝' => 'לחיצת יד',
    '🙏' => 'כפות ידיים מוצמדות',
    '✍' => 'יד כותבת',
    '💅' => 'מריחת לק',
    '🤳' => 'יד מצלמת סלפי',
    '💪' => 'יד עושה שריר',
    '🦾' => 'זרוע מכנית',
    '🦿' => 'רגל מכנית',
    '🦵' => 'רגל',
    '🦶' => 'כף רגל',
    '👂' => 'אוזן',
    '🦻' => 'אוזן עם מכשיר שמיעה',
    '👃' => 'אף',
    '🧠' => 'מוח',
    '🫀' => 'לב',
    '🫁' => 'ריאות',
    '🦷' => 'שן',
    '🦴' => 'עצם',
    '👀' => 'עיניים',
    '👁' => 'עין',
    '👅' => 'לשון',
    '👄' => 'פה',
    '🫦' => 'לנשוך שפתיים',
    '👶' => 'תינוק',
    '🧒' => 'ילד',
    '👦' => 'בן',
    '👧' => 'בת',
    '🧑' => 'אדם',
    '👱' => 'אדם עם שיער בלונדיני',
    '👨' => 'איש',
    '🧔' => 'אדם מזוקן',
    '👩' => 'אישה',
    '🧓' => 'איש מבוגר',
    '👴' => 'איש זקן',
    '👵' => 'אישה זקנה',
    '🙍' => 'אישה לא מרוצה',
    '🙎' => 'אישה זועפת',
    '🙅' => 'אישה מסמנת ״לא בסדר״',
    '🙆' => 'אישה עם הידיים על הראש',
    '💁' => 'אדם בדלפק מידע או מבקש טיפ',
    '🙋' => 'אישה מרימה את היד',
    '🧏' => 'כבד שמיעה',
    '🙇' => 'אדם משתחווה',
    '🤦' => 'אישה עם יד על הפנים',
    '🤷' => 'מישהי מושכת בכתפיה',
    '👮' => 'שוטר',
    '🕵' => 'בלש',
    '💂' => 'שומר',
    '🥷' => 'נינג׳ה',
    '👷' => 'פועל בניין',
    '🫅' => 'פרצוף עם כתר',
    '🤴' => 'נסיך עם כתר',
    '👸' => 'נסיכה',
    '👳' => 'אדם עם טורבן',
    '👲' => 'אדם עם כובע סיני',
    '🧕' => 'אישה עם רעלה',
    '🤵' => 'איש בטוקסידו',
    '👰' => 'כלה עם הינומה',
    '🤰' => 'אישה בהיריון',
    '🫃' => 'איש עם בטן היריון',
    '🫄' => 'בהריון',
    '🤱' => 'אישה מניקה',
    '👼' => 'מלאך תינוק',
    '🎅' => 'סנטה קלאוס',
    '🤶' => 'גב׳ סנטה',
    '🦸' => 'גיבור על',
    '🦹' => 'נבל על',
    '🧙' => 'קוסם',
    '🧚' => 'פיה',
    '🧛' => 'ערפד',
    '🧜' => 'בתולת ים',
    '🧝' => 'אלף',
    '🧞' => 'שד',
    '🧟' => 'זומבי',
    '🧌' => 'טרול',
    '🫈' => 'יצור שעיר',
    '💆' => 'עיסוי פנים',
    '💇' => 'תספורת',
    '🚶' => 'איש הולך',
    '🧍' => 'אדם עומד',
    '🧎' => 'אדם כורע ברך',
    '🏃' => 'רץ',
    '💃' => 'רקדנית',
    '🕺' => 'איש רוקד',
    '🕴' => 'אדם בחליפת עסקים מרחף',
    '👯' => 'נשים עם אוזני ארנב רוקדות',
    '🧖' => 'מישהי בסאונה',
    '🧗' => 'מישהו מטפס',
    '🤺' => 'סייף',
    '🏇' => 'מירוצי סוסים',
    '⛷' => 'גולש סקי',
    '🏂' => 'גולש סנובורד',
    '🏌' => 'שחקן גולף',
    '🏄' => 'גולש גלים',
    '🚣' => 'סירת משוטים',
    '🏊' => 'שחיין',
    '⛹' => 'הקפצת כדור',
    '🏋' => 'מרים משקולות',
    '🚴' => 'רוכב אופניים',
    '🚵' => 'רוכב אופני הרים',
    '🤸' => 'גלגלון',
    '🤼' => 'מתאבקים',
    '🤽' => 'כדורמים',
    '🤾' => 'כדוריד',
    '🤹' => 'להטוטן',
    '🧘' => 'מישהי בתנוחת לוטוס',
    '🛀' => 'אדם באמבטיה',
    '🛌' => 'אדם במיטה',
    '👭' => 'שתי נשים מחזיקות ידיים',
    '👫' => 'איש ואישה מחזיקים ידיים',
    '👬' => 'שני גברים מחזיקים ידיים',
    '💏' => 'נשיקה',
    '💑' => 'זוג עם לב',
    '🗣' => 'צללית ראש מדבר',
    '👤' => 'צללית ראש וחזה',
    '👥' => 'שתי צלליות ראש וחזה',
    '🫂' => 'אנשים מתחבקים',
    '👪' => 'משפחה',
    '👣' => 'טביעות רגל',
    '🫆' => 'טביעת אצבע',
    '🦰' => 'שיער ג׳ינג׳י',
    '🦱' => 'שיער מתולתל',
    '🦳' => 'שיער לבן',
    '🦲' => 'קירח',
    '🐵' => 'פני קוף',
    '🐒' => 'קוף',
    '🦍' => 'גורילה',
    '🦧' => 'אורנגאוטן',
    '🐶' => 'פני כלב',
    '🐕' => 'כלב',
    '🦮' => 'כלב נחייה',
    '🐩' => 'פודל',
    '🐺' => 'זאב',
    '🦊' => 'שועל',
    '🦝' => 'רקון',
    '🐱' => 'פני חתול',
    '🐈' => 'חתול',
    '🦁' => 'אריה',
    '🐯' => 'פני טיגריס',
    '🐅' => 'טיגריס',
    '🐆' => 'נמר',
    '🐴' => 'פני סוס',
    '🫎' => 'אייל קורא',
    '🫏' => 'חמור',
    '🐎' => 'סוס',
    '🦄' => 'חד קרן',
    '🦓' => 'זברה',
    '🦌' => 'אייל',
    '🦬' => 'ביזון',
    '🐮' => 'פני פרה',
    '🐂' => 'שור',
    '🐃' => 'תאו המים',
    '🐄' => 'פרה',
    '🐷' => 'פני חזיר',
    '🐖' => 'חזיר',
    '🐗' => 'חזיר בר',
    '🐽' => 'אף חזיר',
    '🐏' => 'אַיִל',
    '🐑' => 'כבשה',
    '🐐' => 'תיש',
    '🐪' => 'גמל',
    '🐫' => 'גמל דו-דבשתי',
    '🦙' => 'למה',
    '🦒' => 'ג׳ירף',
    '🐘' => 'פיל',
    '🦣' => 'ממותה',
    '🦏' => 'קרנף',
    '🦛' => 'היפופוטם',
    '🐭' => 'פני עכבר',
    '🐁' => 'עכבר',
    '🐀' => 'חולדה',
    '🐹' => 'אוגר',
    '🐰' => 'פני ארנב',
    '🐇' => 'ארנב',
    '🐿' => 'סנאי',
    '🦫' => 'בונה',
    '🦔' => 'קיפוד',
    '🦇' => 'עטלף',
    '🐻' => 'דוב',
    '🐨' => 'קואלה',
    '🐼' => 'פנדה',
    '🦥' => 'עצלן',
    '🦦' => 'לוטרה',
    '🦨' => 'בואש',
    '🦘' => 'קנגורו',
    '🦡' => 'גירית',
    '🐾' => 'טביעות רגל של חיה',
    '🦃' => 'תרנגול הודו',
    '🐔' => 'תרנגולת',
    '🐓' => 'תרנגול',
    '🐣' => 'אפרוח בוקע',
    '🐤' => 'אפרוח',
    '🐥' => 'אפרוח מלפנים',
    '🐦' => 'ציפור',
    '🐧' => 'פינגווין',
    '🕊' => 'יונה',
    '🦅' => 'נשר',
    '🦆' => 'ברווז',
    '🦢' => 'ברבור',
    '🦉' => 'ינשוף',
    '🦤' => 'ציפור דודו',
    '🪶' => 'נוצה',
    '🦩' => 'פלמינגו',
    '🦚' => 'טווס',
    '🦜' => 'תוכי',
    '🪽' => 'כנף',
    '🪿' => 'אווז',
    '🐸' => 'פני צפרדע',
    '🐊' => 'תנין',
    '🐢' => 'צב',
    '🦎' => 'לטאה',
    '🐍' => 'נחש',
    '🐲' => 'פני דרקון',
    '🐉' => 'דרקון',
    '🦕' => 'סרופוד',
    '🦖' => 'טי-רקס',
    '🐳' => 'לווייתן מתיז סילון מים',
    '🐋' => 'לוויתן',
    '🐬' => 'דולפין',
    '🫍' => 'אורקה',
    '🦭' => 'כלב ים',
    '🐟' => 'דג',
    '🐠' => 'דג טרופי',
    '🐡' => 'אבו נפחא',
    '🦈' => 'כריש',
    '🐙' => 'תמנון',
    '🐚' => 'צדף מסולסל',
    '🪸' => 'אלמוג',
    '🪼' => 'מדוזה',
    '🦀' => 'סרטן',
    '🦞' => 'לובסטר',
    '🦐' => 'שרימפ',
    '🦑' => 'דיונון',
    '🦪' => 'צדפה',
    '🐌' => 'חלזון',
    '🦋' => 'פרפר',
    '🐛' => 'זחל',
    '🐜' => 'נמלה',
    '🐝' => 'דבורה',
    '🪲' => 'חיפושית',
    '🐞' => 'פרת משה רבנו',
    '🦗' => 'צרצר',
    '🪳' => 'תיקן',
    '🕷' => 'עכביש',
    '🕸' => 'קורי עכביש',
    '🦂' => 'עקרב',
    '🦟' => 'יתוש',
    '🪰' => 'זבוב',
    '🪱' => 'תולעת',
    '🦠' => 'מיקרוב',
    '💐' => 'זר פרחים',
    '🌸' => 'פריחת דובדבן',
    '💮' => 'פרח לבן',
    '🪷' => 'לוטוס',
    '🏵' => 'פרח צהוב',
    '🌹' => 'ורד',
    '🥀' => 'פרח נובל',
    '🌺' => 'היביסקוס',
    '🌻' => 'חמניה',
    '🌼' => 'פריחה',
    '🌷' => 'צבעוני',
    '🪻' => 'יקינתון',
    '🌱' => 'נבט',
    '🪴' => 'צמח בעציץ',
    '🌲' => 'עץ ירוק-עד',
    '🌳' => 'עץ נשיר',
    '🌴' => 'עץ דקל',
    '🌵' => 'קקטוס',
    '🌾' => 'שיבולי אורז',
    '🌿' => 'צמח תבלין',
    '☘' => 'תלתן',
    '🍀' => 'תלתן ארבעה עלים',
    '🍁' => 'עלה מייפל',
    '🍂' => 'עלי שלכת',
    '🍃' => 'עלה עף ברוח',
    '🪹' => 'קן ריק',
    '🪺' => 'קן עם ביצים',
    '🍄' => 'פטריה',
    '🪾' => 'עץ בלי עלים',
    '🍇' => 'ענבים',
    '🍈' => 'מלון',
    '🍉' => 'אבטיח',
    '🍊' => 'קלמנטינה',
    '🍋' => 'לימון',
    '🍌' => 'בננה',
    '🍍' => 'אננס',
    '🥭' => 'מנגו',
    '🍎' => 'תפוח אדום',
    '🍏' => 'תפוח ירוק',
    '🍐' => 'אגס',
    '🍑' => 'אפרסק',
    '🍒' => 'דובדבנים',
    '🍓' => 'תות שדה',
    '🫐' => 'אוכמניות',
    '🥝' => 'קיווי',
    '🍅' => 'עגבנייה',
    '🫒' => 'זית',
    '🥥' => 'קוקוס',
    '🥑' => 'אבוקדו',
    '🍆' => 'חציל',
    '🥔' => 'תפוח אדמה',
    '🥕' => 'גזר',
    '🌽' => 'קלח תירס',
    '🌶' => 'פלפל חריף',
    '🫑' => 'פלפל אדום',
    '🥒' => 'מלפפון',
    '🥬' => 'עלים ירוקים',
    '🥦' => 'ברוקולי',
    '🧄' => 'שום',
    '🧅' => 'בצל',
    '🥜' => 'בוטנים',
    '🫘' => 'שעועית',
    '🌰' => 'ערמון',
    '🫚' => 'שורש ג׳ינג׳ר',
    '🫛' => 'אפונה',
    '🫜' => 'ירק שורש',
    '🍞' => 'לחם',
    '🥐' => 'קרואסון',
    '🥖' => 'באגט',
    '🫓' => 'פיתה',
    '🥨' => 'בייגלה',
    '🥯' => 'בייגל',
    '🥞' => 'פנקייקס',
    '🧇' => 'וופל',
    '🧀' => 'חריץ גבינה',
    '🍖' => 'בשר על עצם',
    '🍗' => 'שוק',
    '🥩' => 'נתח בשר',
    '🥓' => 'בייקון',
    '🍔' => 'המבורגר',
    '🍟' => 'צ׳יפס',
    '🍕' => 'פיצה',
    '🌭' => 'נקניקייה בלחמניה',
    '🥪' => 'סנדביץ׳',
    '🌮' => 'טאקו',
    '🌯' => 'בוריטו',
    '🫔' => 'טמלה',
    '🥙' => 'פיתה עם פלאפל',
    '🧆' => 'פלאפל',
    '🥚' => 'ביצה',
    '🍳' => 'בישול',
    '🥘' => 'תבשיל קדרה',
    '🍲' => 'סיר אוכל',
    '🫕' => 'פונדו',
    '🥣' => 'קערה עם כף',
    '🥗' => 'סלט ירקות',
    '🍿' => 'פופקורן',
    '🧈' => 'חמאה',
    '🧂' => 'מלח',
    '🥫' => 'שימורים',
    '🍱' => 'חמגשית עם אוכל',
    '🍘' => 'פריכית אורז',
    '🍙' => 'כדור אורז',
    '🍚' => 'אורז מבושל',
    '🍛' => 'אורז קארי',
    '🍜' => 'קערה מהבילה',
    '🍝' => 'ספגטי',
    '🍠' => 'בטטה צלויה',
    '🍢' => 'שיפוד',
    '🍣' => 'סושי',
    '🍤' => 'שרימפ מטוגן',
    '🍥' => 'עוגיית אורז עם עיטור',
    '🥮' => 'עוגת ירח סינית',
    '🍡' => 'שיפוד כופתאות',
    '🥟' => 'דים-סאם',
    '🥠' => 'עוגיית מזל',
    '🥡' => 'קופסת משלוח',
    '🍦' => 'גלידה בגביע',
    '🍧' => 'קערית ברד',
    '🍨' => 'גלידה',
    '🍩' => 'סופגניה',
    '🍪' => 'עוגיה',
    '🎂' => 'עוגת יום הולדת',
    '🍰' => 'פרוסת עוגה',
    '🧁' => 'קפקייק',
    '🥧' => 'פשטידה',
    '🍫' => 'חפיסת שוקולד',
    '🍬' => 'סוכריה',
    '🍭' => 'סוכריה על מקל',
    '🍮' => 'פודינג',
    '🍯' => 'צנצנת דבש',
    '🍼' => 'בקבוק של תינוק',
    '🥛' => 'כוס חלב',
    '☕' => 'משקה חם',
    '🫖' => 'קנקן תה',
    '🍵' => 'ספל תה בלי ידית',
    '🍶' => 'סאקה',
    '🍾' => 'בקבוק שמפניה עם פקק עף',
    '🍷' => 'כוס יין',
    '🍸' => 'כוס קוקטייל',
    '🍹' => 'קוקטייל טרופי',
    '🍺' => 'כוס בירה',
    '🍻' => 'השקת כוסות בירה',
    '🥂' => 'השקת כוסות לחיים',
    '🥃' => 'כוס ויסקי',
    '🫗' => 'מוזגים משקה',
    '🥤' => 'כוס עם קש',
    '🧋' => 'באבל טי',
    '🧃' => 'קופסת מיץ',
    '🧉' => 'מאטה',
    '🧊' => 'קוביית קרח',
    '🥢' => 'מקלות אכילה',
    '🍽' => 'סכין ומזלג עם צלחת',
    '🍴' => 'סכין ומזלג',
    '🥄' => 'כפית',
    '🔪' => 'סכין מטבח',
    '🫙' => 'צנצנת',
    '🏺' => 'כד עתיק',
    '🌍' => 'גלובוס עם אירופה ואפריקה',
    '🌎' => 'גלובוס עם אמריקה',
    '🌏' => 'גלובוס עם אסיה ואוסטרליה',
    '🌐' => 'גלובוס עם קווי אורך ורוחב',
    '🗺' => 'מפת העולם',
    '🗾' => 'מפת יפן',
    '🧭' => 'מצפן',
    '🏔' => 'הר עם פסגה מושלגת',
    '⛰' => 'הר',
    '🛘' => 'מפולת',
    '🌋' => 'הר געש',
    '🗻' => 'הר פוג׳י',
    '🏕' => 'מחנאות',
    '🏖' => 'חוף עם שמשיה',
    '🏜' => 'מדבר',
    '🏝' => 'אי בודד',
    '🏞' => 'שמורת טבע',
    '🏟' => 'איצטדיון',
    '🏛' => 'מבנה קלאסי',
    '🏗' => 'עבודות בניין',
    '🧱' => 'לבנה',
    '🪨' => 'סלע',
    '🪵' => 'בול עץ',
    '🛖' => 'בקתה',
    '🏘' => 'בתים',
    '🏚' => 'בית מוזנח',
    '🏠' => 'בית',
    '🏡' => 'בית עם גינה',
    '🏢' => 'בניין משרדים',
    '🏣' => 'בית דואר ביפן',
    '🏤' => 'בית דואר',
    '🏥' => 'בית חולים',
    '🏦' => 'בנק',
    '🏨' => 'בית מלון',
    '🏩' => 'מלון אהבה',
    '🏪' => 'חנות נוחות',
    '🏫' => 'בית ספר',
    '🏬' => 'כלבו',
    '🏭' => 'מפעל',
    '🏯' => 'טירה יפנית',
    '🏰' => 'טירה',
    '💒' => 'חתונה',
    '🗼' => 'מגדל טוקיו',
    '🗽' => 'פסל החירות',
    '⛪' => 'כנסייה',
    '🕌' => 'מסגד',
    '🛕' => 'מקדש הינדי',
    '🕍' => 'בית כנסת',
    '⛩' => 'מקדש שינטו',
    '🕋' => 'כעבה',
    '⛲' => 'מזרקה',
    '⛺' => 'אוהל',
    '🌁' => 'מזג אוויר ערפילי',
    '🌃' => 'לילה עם כוכבים',
    '🏙' => 'נוף עירוני',
    '🌄' => 'זריחה בהרים',
    '🌅' => 'זריחה',
    '🌆' => 'נוף עירוני בשעת בין-ערביים',
    '🌇' => 'שקיעה',
    '🌉' => 'גשר בלילה',
    '♨' => 'מעיינות חמים',
    '🎠' => 'סוס בקרוסלה',
    '🛝' => 'מגלשה',
    '🎡' => 'גלגל ענק',
    '🎢' => 'רכבת הרים',
    '💈' => 'עמוד מספרה',
    '🎪' => 'אוהל קרקס',
    '🚂' => 'קטר',
    '🚃' => 'קרון רכבת',
    '🚄' => 'רכבת מהירה',
    '🚅' => 'רכבת מהירה עם חרטום בצורת קליע',
    '🚆' => 'רכבת',
    '🚇' => 'רכבת תחתית',
    '🚈' => 'רכבת קלה',
    '🚉' => 'תחנה',
    '🚊' => 'חשמלית',
    '🚝' => 'רכבת עילית',
    '🚞' => 'רכבת בהרים',
    '🚋' => 'קרון חשמלית',
    '🚌' => 'אוטובוס',
    '🚍' => 'אוטובוס מלפנים',
    '🚎' => 'אוטובוס חשמלי',
    '🚐' => 'מיניבוס',
    '🚑' => 'אמבולנס',
    '🚒' => 'כבאית',
    '🚓' => 'ניידת משטרה',
    '🚔' => 'ניידת משטרה מלפנים',
    '🚕' => 'מונית',
    '🚖' => 'מונית מלפנים',
    '🚗' => 'מכונית',
    '🚘' => 'מכונית מלפנים',
    '🚙' => 'ג׳יפ',
    '🛻' => 'טנדר',
    '🚚' => 'משאית',
    '🚛' => 'משאית מפרקית',
    '🚜' => 'טרקטור',
    '🏎' => 'מכונית מירוץ',
    '🏍' => 'אופנוע',
    '🛵' => 'קטנוע',
    '🦽' => 'כסא גלגלים ידני',
    '🦼' => 'כסא גלגלים ממונע',
    '🛺' => 'ריקשה ממונעת',
    '🚲' => 'אופניים',
    '🛴' => 'קורקינט',
    '🛹' => 'סקייטבורד',
    '🛼' => 'גלגיליות',
    '🚏' => 'תחנת אוטובוס',
    '🛣' => 'כביש מהיר',
    '🛤' => 'מסילת רכבת',
    '🛢' => 'חבית נפט',
    '⛽' => 'משאבת דלק',
    '🛞' => 'גלגל',
    '🚨' => 'פנס של ניידת משטרה',
    '🚥' => 'רמזור אופקי',
    '🚦' => 'רמזור אנכי',
    '🛑' => 'תמרור עצור',
    '🚧' => 'מחסום עבודות בכביש',
    '⚓' => 'עוגן',
    '🛟' => 'גלגל הצלה',
    '⛵' => 'סירת מפרש',
    '🛶' => 'קאנו',
    '🚤' => 'סירת מירוץ',
    '🛳' => 'ספינת נוסעים',
    '⛴' => 'מעבורת',
    '🛥' => 'סירת מנוע',
    '🚢' => 'ספינה',
    '✈' => 'מטוס',
    '🛩' => 'מטוס קטן',
    '🛫' => 'מטוס ממריא',
    '🛬' => 'מטוס נוחת',
    '🪂' => 'מצנח',
    '💺' => 'מושב',
    '🚁' => 'מסוק',
    '🚟' => 'רכבל',
    '🚠' => 'קרון רכבל',
    '🚡' => 'קרון רכבל קטן',
    '🛰' => 'לוויין',
    '🚀' => 'טיל',
    '🛸' => 'צלחת מעופפת',
    '🛎' => 'פעמון קבלה',
    '🧳' => 'מזוודה',
    '⌛' => 'שעון חול',
    '⏳' => 'חול זורם בשעון חול',
    '⌚' => 'שעון יד',
    '⏰' => 'שעון מעורר',
    '⏱' => 'שעון עצר',
    '⏲' => 'טיימר',
    '🕰' => 'שעון דקורטיבי',
    '🕛' => 'שתיים-עשרה',
    '🕧' => 'שתיים-עשרה וחצי',
    '🕐' => 'אחת',
    '🕜' => 'אחת וחצי',
    '🕑' => 'שתיים',
    '🕝' => 'שתיים וחצי',
    '🕒' => 'שלוש',
    '🕞' => 'שלוש וחצי',
    '🕓' => 'ארבע',
    '🕟' => 'ארבע וחצי',
    '🕔' => 'חמש',
    '🕠' => 'חמש וחצי',
    '🕕' => 'שש',
    '🕡' => 'שש וחצי',
    '🕖' => 'שבע',
    '🕢' => 'שבע וחצי',
    '🕗' => 'שמונה',
    '🕣' => 'שמונה וחצי',
    '🕘' => 'תשע',
    '🕤' => 'תשע וחצי',
    '🕙' => 'עשר',
    '🕥' => 'עשר וחצי',
    '🕚' => 'אחת-עשרה',
    '🕦' => 'אחת-עשרה וחצי',
    '🌑' => 'ירח חדש',
    '🌒' => 'סהר ירח מתמלא',
    '🌓' => 'חצי ירח מתמלא',
    '🌔' => 'ירח כמעט מלא',
    '🌕' => 'ירח מלא',
    '🌖' => 'ירח מתחיל להתרוקן',
    '🌗' => 'חצי ירח מתרוקן',
    '🌘' => 'סהר ירח מתרוקן',
    '🌙' => 'סהר',
    '🌚' => 'פני ירח חדש',
    '🌛' => 'פני סהר מתמלא',
    '🌜' => 'פני סהר מתרוקן',
    '🌡' => 'מדחום',
    '☀' => 'שמש',
    '🌝' => 'פני ירח מלא',
    '🌞' => 'פני שמש',
    '🪐' => 'כוכב לכת עם טבעות',
    '⭐' => 'כוכב',
    '🌟' => 'כוכב זוהר',
    '🌠' => 'כוכב שביט',
    '🌌' => 'שביל החלב',
    '☁' => 'ענן',
    '⛅' => 'שמש מאחורי ענן',
    '⛈' => 'ענן עם ברק וגשם',
    '🌤' => 'שמש מאחורי ענן קטן',
    '🌥' => 'שמש מאחורי ענן גדול',
    '🌦' => 'שמש מאחורי ענן עם גשם',
    '🌧' => 'ענן עם גשם',
    '🌨' => 'ענן עם שלג',
    '🌩' => 'ענן עם ברק',
    '🌪' => 'טורנדו',
    '🌫' => 'ערפל',
    '🌬' => 'פני רוח נושבת',
    '🌀' => 'הוריקן',
    '🌈' => 'קשת בענן',
    '🌂' => 'מטריה סגורה',
    '☂' => 'מטריה',
    '☔' => 'מטריה עם טיפות גשם',
    '⛱' => 'שמשיה',
    '⚡' => 'ברק',
    '❄' => 'פתית שלג',
    '☃' => 'איש שלג',
    '⛄' => 'איש שלג בלי שלג',
    '☄' => 'שביט',
    '🔥' => 'אש',
    '💧' => 'טיפה',
    '🌊' => 'גל',
    '🎃' => 'מנורת דלעת',
    '🎄' => 'עץ אשוח מקושט',
    '🎆' => 'זיקוקים',
    '🎇' => 'זיקוק על מקל',
    '🧨' => 'זיקוקין די נור',
    '✨' => 'נצנוץ',
    '🎈' => 'בלון',
    '🎉' => 'פצצת קונפטי',
    '🎊' => 'כדור קונפטי',
    '🎋' => 'קישוט חג יפני',
    '🎍' => 'קישוט אצטרובלים',
    '🎎' => 'בובות יפניות',
    '🎏' => 'דגלים בצורת דגי קוי',
    '🎐' => 'פעמון רוח',
    '🎑' => 'טקס ירח',
    '🧧' => 'מעטפה אדומה',
    '🎀' => 'סרט מתנה',
    '🎁' => 'קופסת מתנה',
    '🎗' => 'סרט הזדהות',
    '🎟' => 'כרטיס כניסה',
    '🎫' => 'כרטיס',
    '🎖' => 'מדליה צבאית',
    '🏆' => 'גביע',
    '🏅' => 'מדליית ספורט',
    '🥇' => 'מדליית זהב',
    '🥈' => 'מדליית כסף',
    '🥉' => 'מדליית ארד',
    '⚽' => 'כדורגל',
    '⚾' => 'כדור בסיס',
    '🥎' => 'סופטבול',
    '🏀' => 'כדור סל',
    '🏐' => 'כדורעף',
    '🏈' => 'פוטבול אמריקאי',
    '🏉' => 'כדור רוגבי',
    '🎾' => 'כדור טניס',
    '🥏' => 'פריזבי',
    '🎳' => 'כדור באולינג',
    '🏏' => 'קריקט',
    '🏑' => 'הוקי שדה',
    '🏒' => 'מקל ודיסקית של הוקי קרח',
    '🥍' => 'לקרוס',
    '🏓' => 'פינג פונג',
    '🏸' => 'בדמינטון',
    '🥊' => 'כפפת אגרוף',
    '🥋' => 'חליפת אומנויות לחימה',
    '🥅' => 'שער כדורגל',
    '⛳' => 'דגל גולף',
    '⛸' => 'נעל החלקה על קרח',
    '🎣' => 'חכת דיג',
    '🤿' => 'מסיכת צלילה',
    '🎽' => 'חולצת ריצה',
    '🎿' => 'מגלשי סקי',
    '🛷' => 'מִזְחֶלֶת',
    '🥌' => 'אבן קרלינג',
    '🎯' => 'פגיעה בול',
    '🪀' => 'יו-יו',
    '🪁' => 'עפיפון',
    '🔫' => 'אקדח מים',
    '🎱' => 'כדור ביליארד',
    '🔮' => 'כדור בדולח',
    '🪄' => 'שרביט קסמים',
    '🎮' => 'משחק וידאו',
    '🕹' => 'ג׳ויסטיק',
    '🎰' => 'מכונת מזל',
    '🎲' => 'קוביית משחק',
    '🧩' => 'חלק בפאזל',
    '🧸' => 'דובי',
    '🪅' => 'פיניאטה',
    '🪩' => 'כדור מראה',
    '🪆' => 'בבושקה',
    '♠' => 'קלף עלה',
    '♥' => 'קלף לב',
    '♦' => 'קלף יהלום',
    '♣' => 'קלף תלתן',
    '♟' => 'פיון בשחמט',
    '🃏' => 'ג׳וקר',
    '🀄' => 'דרקון אדום מה-ג׳ונג',
    '🎴' => 'קלפי פרחים',
    '🎭' => 'אמנויות הבמה',
    '🖼' => 'מסגרת עם תמונה',
    '🎨' => 'פלטת צבעים',
    '🧵' => 'חוט',
    '🪡' => 'מחט',
    '🧶' => 'צמר',
    '🪢' => 'קשר',
    '👓' => 'משקפיים',
    '🕶' => 'משקפי שמש',
    '🥽' => 'משקפי שחייה',
    '🥼' => 'חלוק מעבדה',
    '🦺' => 'אפוד בטיחות',
    '👔' => 'חולצה עם עניבה',
    '👕' => 'חולצת טי',
    '👖' => 'מכנסי ג׳ינס',
    '🧣' => 'צעיף',
    '🧤' => 'כפפות',
    '🧥' => 'מעיל',
    '🧦' => 'גרביים',
    '👗' => 'שמלה',
    '👘' => 'קימונו',
    '🥻' => 'סארי',
    '🩱' => 'בגד ים שלם',
    '🩲' => 'תחתונים',
    '🩳' => 'מכנסיים קצרים',
    '👙' => 'ביקיני',
    '👚' => 'חולצת אישה',
    '🪭' => 'מניפת יד מתקפלת',
    '👛' => 'ארנק',
    '👜' => 'תיק יד',
    '👝' => 'תיק ערב',
    '🛍' => 'שקיות קניות',
    '🎒' => 'ילקוט',
    '🩴' => 'כפכפי אצבע',
    '👞' => 'נעל של גבר',
    '👟' => 'נעל ריצה',
    '🥾' => 'נעלי הליכה',
    '🥿' => 'נעל שטוחה',
    '👠' => 'נעל עקב גבוה',
    '👡' => 'סנדל של אישה',
    '🩰' => 'נעלי בלט',
    '👢' => 'מגף של אישה',
    '🪮' => 'מסרק שיער',
    '👑' => 'כתר',
    '👒' => 'כובע של אישה',
    '🎩' => 'מגבעת צילינדר',
    '🎓' => 'כובע סיום לימודים',
    '🧢' => 'כובע מצחייה',
    '🪖' => 'קסדה צבאית',
    '⛑' => 'קסדה עם צלב לבן',
    '📿' => 'מחרוזת תפילה',
    '💄' => 'שפתון',
    '💍' => 'טבעת',
    '💎' => 'יהלום',
    '🔇' => 'רמקול מושתק',
    '🔈' => 'ווליום נמוך',
    '🔉' => 'ווליום בינוני',
    '🔊' => 'ווליום חזק',
    '📢' => 'מגפון',
    '📣' => 'מגפון בלי ידית',
    '📯' => 'קרן דואר',
    '🔔' => 'פעמון',
    '🔕' => 'פעמון מושתק',
    '🎼' => 'מפתח סול',
    '🎵' => 'תו מוזיקלי',
    '🎶' => 'תווים מוזיקליים',
    '🎙' => 'מיקרופון אולפן',
    '🎚' => 'מחוון עוצמת קול',
    '🎛' => 'כפתורי עוצמת קול',
    '🎤' => 'מיקרופון',
    '🎧' => 'אוזניה',
    '📻' => 'רדיו',
    '🎷' => 'סקסופון',
    '🎺' => 'חצוצרה',
    '🪊' => 'טרומבון',
    '🪗' => 'אקורדיון',
    '🎸' => 'גיטרה',
    '🎹' => 'קלידים',
    '🎻' => 'כינור',
    '🪕' => 'בנג׳ו',
    '🥁' => 'תוף',
    '🪘' => 'תוף גבוה',
    '🪇' => 'מאראקס',
    '🪈' => 'חליל',
    '🪉' => 'נבל',
    '📱' => 'טלפון נייד',
    '📲' => 'טלפון נייד עם חץ',
    '☎' => 'טלפון רגיל',
    '📞' => 'שפופרת טלפון',
    '📟' => 'איתורית',
    '📠' => 'מכשיר פקס',
    '🔋' => 'סוללה',
    '🪫' => 'סוללה נמוכה',
    '🔌' => 'תקע חשמלי',
    '💻' => 'מחשב נייד',
    '🖥' => 'מחשב שולחני',
    '🖨' => 'מדפסת',
    '⌨' => 'מקלדת',
    '🖱' => 'עכבר למחשב',
    '🖲' => 'גלגלת עכבר',
    '💽' => 'דיסק',
    '💾' => 'דיסקט',
    '💿' => 'דיסק אופטי',
    '📀' => 'dvd',
    '🧮' => 'חשבונייה',
    '🎥' => 'מצלמת קולנוע',
    '🎞' => 'פילם',
    '📽' => 'מקרן קולנוע',
    '🎬' => 'קלאפר',
    '📺' => 'טלוויזיה',
    '📷' => 'מצלמה',
    '📸' => 'מצלמה עם פלאש',
    '📹' => 'מצלמת וידאו',
    '📼' => 'קלטת וידאו',
    '🔍' => 'זכוכית מגדלת נוטה שמאלה',
    '🔎' => 'זכוכית מגדלת נוטה ימינה',
    '🕯' => 'נר',
    '💡' => 'נורה',
    '🔦' => 'פנס',
    '🏮' => 'פנס נייר אדום',
    '🪔' => 'מנורת דייה',
    '📔' => 'מחברת עם כריכה מעוטרת',
    '📕' => 'ספר סגור',
    '📖' => 'ספר פתוח',
    '📗' => 'ספר ירוק',
    '📘' => 'ספר כחול',
    '📙' => 'ספר כתום',
    '📚' => 'ספרים',
    '📓' => 'מחברת',
    '📒' => 'יומן',
    '📃' => 'דף עם קצה מגולגל',
    '📜' => 'מגילה',
    '📄' => 'דף עם הפנים כלפי מעלה',
    '📰' => 'עיתון',
    '🗞' => 'עיתון מגולגל',
    '📑' => 'תוויות סימניה',
    '🔖' => 'סימנייה',
    '🏷' => 'תווית',
    '🪙' => 'מטבע',
    '💰' => 'שק כסף',
    '🪎' => 'תיבת אוצר',
    '💴' => 'שטר ין',
    '💵' => 'שטר דולר',
    '💶' => 'שטר אירו',
    '💷' => 'שטר לירה שטרלינג',
    '💸' => 'כסף עם כנפיים',
    '💳' => 'כרטיס אשראי',
    '🧾' => 'קבלה',
    '💹' => 'גרף עולה עם סימן ין',
    '✉' => 'מעטפה',
    '📧' => 'אימייל',
    '📨' => 'מעטפה נכנסת',
    '📩' => 'מעטפה עם חץ',
    '📤' => 'מגש דואר יוצא',
    '📥' => 'מגש דואר נכנס',
    '📦' => 'חבילה',
    '📫' => 'תיבת דואר סגורה עם דגלון למעלה',
    '📪' => 'תיבת דואר סגורה עם דגלון למטה',
    '📬' => 'תיבת דואר פתוחה עם דגלון למעלה',
    '📭' => 'תיבת דואר פתוחה עם דגלון למטה',
    '📮' => 'תיבת דואר',
    '🗳' => 'קלפי עם פתק הצבעה',
    '✏' => 'עיפרון',
    '✒' => 'עט ציפורן שחור',
    '🖋' => 'עט נובע',
    '🖊' => 'עט',
    '🖌' => 'מכחול',
    '🖍' => 'צבע פנדה',
    '📝' => 'פתק תזכורת',
    '💼' => 'תיק מסמכים',
    '📁' => 'תיקיית מסמכים',
    '📂' => 'תיקיית מסמכים פתוחה',
    '🗂' => 'כרטסת עם חוצצים',
    '📅' => 'לוח שנה',
    '📆' => 'לוח שנה לתלישת דפים',
    '🗒' => 'פנקס עם ספירלה',
    '🗓' => 'לוח שנה עם ספירלה',
    '📇' => 'כרטסת',
    '📈' => 'גרף עולה',
    '📉' => 'גרף יורד',
    '📊' => 'תרשים עמודות',
    '📋' => 'לוח כתיבה',
    '📌' => 'נעץ',
    '📍' => 'סיכה',
    '📎' => 'אטב נייר',
    '🖇' => 'אטבי נייר מחוברים',
    '📏' => 'סרגל',
    '📐' => 'סרגל משולש',
    '✂' => 'מספריים',
    '🗃' => 'קופסת תיוק כרטיסיות',
    '🗄' => 'מגירות מסמכים',
    '🗑' => 'סל ניירות',
    '🔒' => 'מנעול',
    '🔓' => 'מנעול פתוח',
    '🔏' => 'מנעול עם עט',
    '🔐' => 'מנעול סגור עם מפתח',
    '🔑' => 'מפתח',
    '🗝' => 'מפתח ישן',
    '🔨' => 'פטיש',
    '🪓' => 'גרזן',
    '⛏' => 'מכוש',
    '⚒' => 'פטיש ומכוש',
    '🛠' => 'פטיש ומפתח ברגים',
    '🗡' => 'פגיון',
    '⚔' => 'חרבות מוצלבות',
    '💣' => 'פצצה',
    '🪃' => 'בומרנג',
    '🏹' => 'חץ וקשת',
    '🛡' => 'מגן',
    '🪚' => 'מסור',
    '🔧' => 'מפתח ברגים',
    '🪛' => 'מברג',
    '🔩' => 'בורג ואום',
    '⚙' => 'גלגל שיניים',
    '🗜' => 'מלחציים',
    '⚖' => 'מאזניים',
    '🦯' => 'מקל נחייה',
    '🔗' => 'חוליות משולבות',
    '⛓' => 'שרשראות',
    '🪝' => 'קרס',
    '🧰' => 'ארגז כלים',
    '🧲' => 'מגנט',
    '🪜' => 'סולם',
    '🪏' => 'מעדר',
    '⚗' => 'מבחנת כימיה',
    '🧪' => 'מבחנה',
    '🧫' => 'צלחת פטרי',
    '🧬' => 'די אנ איי',
    '🔬' => 'מיקרוסקופ',
    '🔭' => 'טלסקופ',
    '📡' => 'צלחת לוויין',
    '💉' => 'מזרק',
    '🩸' => 'טיפת דם',
    '💊' => 'כדור',
    '🩹' => 'פלסטר',
    '🩼' => 'קביים',
    '🩺' => 'סטתוסקופ',
    '🩻' => 'רנטגן',
    '🚪' => 'דלת',
    '🛗' => 'מעלית',
    '🪞' => 'מראה',
    '🪟' => 'חלון',
    '🛏' => 'מיטה',
    '🛋' => 'ספה ומנורה',
    '🪑' => 'כיסא',
    '🚽' => 'אסלה',
    '🪠' => 'פומפה',
    '🚿' => 'מקלחת',
    '🛁' => 'אמבטיה',
    '🪤' => 'מלכודת עכברים',
    '🪒' => 'סכין גילוח',
    '🧴' => 'קרם לחות',
    '🧷' => 'סיכת ביטחון',
    '🧹' => 'מטאטא',
    '🧺' => 'סל',
    '🧻' => 'גליל נייר',
    '🪣' => 'דלי',
    '🧼' => 'סבון',
    '🫧' => 'בועות',
    '🪥' => 'מברשת שיניים',
    '🧽' => 'ספוג',
    '🧯' => 'מטף אש',
    '🛒' => 'עגלת קניות',
    '🚬' => 'סיגריה דולקת',
    '⚰' => 'ארון קבורה',
    '🪦' => 'מצבה',
    '⚱' => 'כד אפר',
    '🧿' => 'קמע',
    '🪬' => 'חמסה',
    '🗿' => 'פסל מאיי הפסחא',
    '🪧' => 'כרזה',
    '🪪' => 'תעודת זהות',
    '🏧' => 'שלט כספומט',
    '🚮' => 'שלט פסולת לפח',
    '🚰' => 'שלט מי שתייה',
    '♿' => 'שלט לנכים בלבד',
    '🚹' => 'שלט שירותי גברים',
    '🚺' => 'שלט שירותי נשים',
    '🚻' => 'שלט שירותים',
    '🚼' => 'סמל של תינוק',
    '🚾' => 'שלט WC',
    '🛂' => 'שלט עמדת דרכונים',
    '🛃' => 'שלט עמדת מכס',
    '🛄' => 'שלט איסוף כבודה',
    '🛅' => 'שלט אחסון כבודה',
    '⚠' => 'שלט אזהרה',
    '🚸' => 'ילדים חוצים',
    '⛔' => 'אין כניסה',
    '🚫' => 'אסור',
    '🚳' => 'אין כניסה לאופניים',
    '🚭' => 'אסור לעשן',
    '🚯' => 'אין להשליך פסולת',
    '🚱' => 'אין לשתות את המים',
    '🚷' => 'אין כניסה להולכי רגל',
    '📵' => 'אין להשתמש במכשירים ניידים',
    '🔞' => 'מגיל שמונה-עשרה בלבד',
    '☢' => 'רדיואקטיבי',
    '☣' => 'סכנה ביולוגית',
    '⬆' => 'חץ למעלה',
    '↗' => 'חץ למעלה וימינה',
    '➡' => 'חץ ימינה',
    '↘' => 'חץ למטה וימינה',
    '⬇' => 'חץ למטה',
    '↙' => 'חץ למטה ושמאלה',
    '⬅' => 'חץ שמאלה',
    '↖' => 'חץ למעלה ושמאלה',
    '↕' => 'חץ מעלה ומטה',
    '↔' => 'חץ שמאלה וימינה',
    '↩' => 'חץ ימינה מתעקל שמאלה',
    '↪' => 'חץ שמאלה מתעקל ימינה',
    '⤴' => 'חץ ימינה מתעקל מעלה',
    '⤵' => 'חץ ימינה מתעקל מטה',
    '🔃' => 'חצים אנכיים מתעקלים בכיוון השעון',
    '🔄' => 'לחצן חצים נגד כיוון השעון',
    '🔙' => 'חץ אחורה',
    '🔚' => 'חץ לסוף',
    '🔛' => 'חץ פועל!',
    '🔜' => 'חץ בקרוב',
    '🔝' => 'חץ מעלה',
    '🛐' => 'בית תפילה',
    '⚛' => 'סמל האטום',
    '🕉' => 'אום',
    '✡' => 'מגן דוד',
    '☸' => 'גלגל הדהרמה',
    '☯' => 'יין-יאנג',
    '✝' => 'צלב',
    '☦' => 'צלב אורתודוכסי',
    '☪' => 'כוכב וסהר',
    '☮' => 'סמל השלום',
    '🕎' => 'חנוכיה',
    '🔯' => 'מגן דוד עם נקודה באמצע',
    '🪯' => 'סמל סיקי',
    '♈' => 'מזל טלה',
    '♉' => 'מזל שור',
    '♊' => 'מזל תאומים',
    '♋' => 'מזל סרטן',
    '♌' => 'מזל אריה',
    '♍' => 'מזל בתולה',
    '♎' => 'מזל מאזניים',
    '♏' => 'מזל עקרב',
    '♐' => 'מזל קשת',
    '♑' => 'מזל גדי',
    '♒' => 'מזל דלי',
    '♓' => 'מזל דגים',
    '⛎' => 'נושא הנחש',
    '🔀' => 'סמל השמעה אקראית',
    '🔁' => 'סמל השמעה חוזרת',
    '🔂' => 'סמל חזרה על שיר אחד',
    '▶' => 'לחצן השמעה',
    '⏩' => 'לחצן הרצה קדימה',
    '⏭' => 'לחצן מעבר לשיר הבא',
    '⏯' => 'לחצן הפעלה/השהייה',
    '◀' => 'לחצן השמעה לאחור',
    '⏪' => 'לחצן הרצה לאחור',
    '⏮' => 'לחצן מעבר לשיר הקודם',
    '🔼' => 'לחצן מעלה',
    '⏫' => 'לחצן מעלה במהירות',
    '🔽' => 'לחצן מטה',
    '⏬' => 'לחצן מטה במהירות',
    '⏸' => 'לחצן השהייה',
    '⏹' => 'לחצן עצירה',
    '⏺' => 'לחצן הקלטה',
    '⏏' => 'לחצן הוצאה',
    '🎦' => 'קולנוע',
    '🔅' => 'לחצן עמעום תאורה',
    '🔆' => 'כפתור הגברת עוצמת תאורה',
    '📶' => 'סמל עצמת קליטה',
    '🛜' => 'אלחוטי',
    '📳' => 'מצב רטט',
    '📴' => 'נייד כבוי',
    '♀' => 'סמל אישה',
    '♂' => 'סמל גבר',
    '⚧' => 'סמל לטרנסג׳נדר',
    '✖' => 'סימן כפל',
    '➕' => 'סימן חיבור',
    '➖' => 'סימן חיסור',
    '➗' => 'סימן חילוק',
    '🟰' => 'סימן שווה עבה',
    '♾' => 'אינסוף',
    '‼' => 'סימן קריאה כפול',
    '⁉' => 'סימן שאלה וסימן קריאה',
    '❓' => 'סימן שאלה אדום',
    '❔' => 'סימן שאלה לבן',
    '❕' => 'סימן קריאה לבן',
    '❗' => 'סימן קריאה אדום',
    '〰' => 'קו גלי',
    '💱' => 'המרת מטבעות',
    '💲' => 'סימן דולר',
    '⚕' => 'סמל הרפואה',
    '♻' => 'סמל מיחזור',
    '⚜' => 'שושן צחור',
    '🔱' => 'סמל קילשון',
    '📛' => 'תג שם',
    '🔰' => 'סמל יפני לרמת מתחילים',
    '⭕' => 'עיגול אדום חלול',
    '✅' => 'סימן אישור',
    '☑' => 'סימן אישור בתוך משבצת',
    '✔' => 'סימן אישור ירוק',
    '❌' => 'איקס אדום',
    '❎' => 'סימן איקס',
    '➰' => 'לולאה',
    '➿' => 'לולאה כפולה',
    '〽' => 'סמל יפני מתחום המוזיקה',
    '✳' => 'כוכבית עם שמונה פינות',
    '✴' => 'כוכב עם שמונה פינות',
    '❇' => 'נוצץ',
    '™' => 'סימן מסחרי',
    '🫟' => 'כתם',
    '🔠' => 'לחצן אותיות גדולות',
    '🔡' => 'לחצן אותיות קטנות',
    '🔢' => 'לחצן מספרים',
    '🔣' => 'לחצן סמלים',
    '🔤' => 'לחצן אותיות לטיניות',
    '🅰' => 'לחצן A (סוג דם)',
    '🆎' => 'לחצן AB (סוג דם)',
    '🅱' => 'לחצן B (סוג דם)',
    '🆑' => 'לחצן CL',
    '🆒' => 'לחצן cool',
    '🆓' => 'לחצן free',
    'ℹ' => 'סמל מידע',
    '🆔' => 'לחצן ID',
    'Ⓜ' => 'm בעיגול',
    '🆕' => 'לחצן NEW',
    '🆖' => 'לחצן NG',
    '🅾' => 'לחצן O (סוג דם)',
    '🆗' => 'לחצן OK',
    '🅿' => 'לחצן P',
    '🆘' => 'לחצן SOS',
    '🆙' => 'לחצן up!',
    '🆚' => 'לחצן VS',
    '🈁' => 'לחצן ״כאן״ ביפנית',
    '🈂' => 'לחצן ״דמי שירות״ ביפנית',
    '🈷' => 'לחצן ״כמות חודשית״ ביפנית',
    '🈶' => 'לחצן ״לא בחינם״ ביפנית',
    '🈯' => 'לחצן ״מקום שמור״ ביפנית',
    '🉐' => 'לחצן ״דיל״ ביפנית',
    '🈹' => 'לחצן ״הנחה״ ביפנית',
    '🈚' => 'לחצן ״חינם״ ביפנית',
    '🈲' => 'לחצן ״אסור״ ביפנית',
    '🉑' => 'לחצן ״מותר״ ביפנית',
    '🈸' => 'לחצן ״הגשת בקשה״ ביפנית',
    '🈴' => 'לחצן ״ציון עובר״ ביפנית',
    '🈳' => 'לחצן ״יש מקום״ ביפנית',
    '㊗' => 'לחצן ״בשעה טובה״ ביפנית',
    '㊙' => 'לחצן ״סוד״ ביפנית',
    '🈺' => 'לחצן ״פתוח״ ביפנית',
    '🈵' => 'לחצן ״אין מקום״ ביפנית',
    '🔴' => 'עיגול אדום',
    '🟠' => 'עיגול כתום',
    '🟡' => 'עיגול צהוב',
    '🟢' => 'עיגול ירוק',
    '🔵' => 'עיגול כחול',
    '🟣' => 'עיגול סגול',
    '🟤' => 'עיגול חום',
    '⚫' => 'עיגול שחור',
    '⚪' => 'עיגול לבן',
    '🟥' => 'ריבוע אדום',
    '🟧' => 'ריבוע כתום',
    '🟨' => 'ריבוע צהוב',
    '🟩' => 'ריבוע ירוק',
    '🟦' => 'ריבוע כחול',
    '🟪' => 'ריבוע סגול',
    '🟫' => 'ריבוע חום',
    '⬛' => 'ריבוע גדול שחור',
    '⬜' => 'ריבוע גדול לבן',
    '◼' => 'ריבוע שחור בינוני',
    '◻' => 'ריבוע לבן בינוני',
    '◾' => 'ריבוע בינוני-קטן שחור',
    '◽' => 'ריבוע בינוני-קטן לבן',
    '▪' => 'ריבוע שחור קטן',
    '▫' => 'ריבוע לבן קטן',
    '🔶' => 'מעוין כתום גדול',
    '🔷' => 'מעוין כחול גדול',
    '🔸' => 'מעוין כתום קטן',
    '🔹' => 'מעוין כחול קטן',
    '🔺' => 'משולש אדום כלפי מעלה',
    '🔻' => 'משולש אדום כלפי מטה',
    '💠' => 'מעוין כחול עם נקודה',
    '🔘' => 'לחצן רדיו',
    '🔳' => 'לחצן ריבוע לבן',
    '🔲' => 'לחצן ריבוע שחור',
    '🏁' => 'דגל מירוצים',
    '🚩' => 'דגל משולש אדום',
    '🎌' => 'דגלים מוצלבים',
    '🏴' => 'דגל שחור',
    '🏳' => 'דגל לבן',
];
