<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'Mfeano: onipa, onipa, wedeε ani a εda so, ne wedeε ani a εda so kakra',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'Mfeano: onipa, onipa, wedeε ani a εda so, ne wedeε ani a εda hᴐ kakra',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'Mfeano: onipa, onipa, wedeε ani a εda so, ne wedeε ani tuntum kakra',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'Mfeano: onipa, onipa, wedeε ani a εda so, ne wedeε ani tuntum',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'Mfeano: onipa, onipa, wedeε ani a εda so kakra, ne wedeε ani a εda so',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'Mfeano: onipa, onipa, wedeε ani a εda so kakra, ne wedeε ani a εda hᴐ kakra',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'Mfeano: onipa, onipa, wedeε ani a εda so kakra, ne wedeε ani tuntum kakra',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'Mfeano: onipa, onipa, wedeε ani a εda so kakra, ne wedeε ani tuntum',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'Mfeano: onipa, onipa, wedeε ani a εda hᴐ kakra, ne wedeε ani a εda so',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'Mfeano: onipa, onipa, wedeε ani a εda hᴐ kakra, ne wedeε ani a εda so kakra',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'Mfeano: onipa, onipa, wedeε ani a εda hᴐ kakra, ne wedeε ani tuntum kakra',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'Mfeano: onipa, onipa, wedeε ani a εda hᴐ kakra, ne wedeε ani tuntum',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'Mfeano: onipa, onipa, wedeε ani tuntum kakra, ne wedeε ani a εda so',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'Mfeano: onipa, onipa, wedeε ani tuntum kakra, ne wedeε ani a εda so kakra',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'Mfeano: onipa, onipa, wedeε ani tuntum kakra, ne wedeε ani a εda hᴐ kakra',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'Mfeano: onipa, onipa, wedeε ani tuntum kakra, ne wedeε ani tuntum',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'Mfeano: onipa, onipa, wedeε ani tuntum, ne wedeε ani a εda so',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'Mfeano: onipa, onipa, wedeε ani tuntum, ne wedeε ani a εda so kakra',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'Mfeano: onipa, onipa, wedeε ani tuntum, ne wedeε ani a εda hᴐ kakra',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'Mfeano: onipa, onipa, wedeε ani tuntum, ne wedeε ani tuntum kakra',
    '👨🏻‍❤‍💋‍👨🏻' => 'Mfeano: ɔbarima, ɔbarima, ne wedeε ani a εda so',
    '👨🏻‍❤‍💋‍👨🏼' => 'Mfeano: ɔbarima, ɔbarima, wedeε ani a εda so, ne wedeε ani a εda so kakra',
    '👨🏻‍❤‍💋‍👨🏽' => 'Mfeano: ɔbarima, ɔbarima, wedeε ani a εda so, ne wedeε ani a εda hᴐ kakra',
    '👨🏻‍❤‍💋‍👨🏾' => 'Mfeano: ɔbarima, ɔbarima, wedeε ani a εda so, ne wedeε ani tuntum kakra',
    '👨🏻‍❤‍💋‍👨🏿' => 'Mfeano: ɔbarima, ɔbarima, wedeε ani a εda so, ne wedeε ani tuntum',
    '👨🏼‍❤‍💋‍👨🏻' => 'Mfeano: ɔbarima, ɔbarima, wedeε ani a εda so kakra, ne wedeε ani a εda so',
    '👨🏼‍❤‍💋‍👨🏼' => 'Mfeano: ɔbarima, ɔbarima, ne wedeε ani a εda so kakra',
    '👨🏼‍❤‍💋‍👨🏽' => 'Mfeano: ɔbarima, ɔbarima, wedeε ani a εda so kakra, ne wedeε ani a εda hᴐ kakra',
    '👨🏼‍❤‍💋‍👨🏾' => 'Mfeano: ɔbarima, ɔbarima, wedeε ani a εda so kakra, ne wedeε ani tuntum kakra',
    '👨🏼‍❤‍💋‍👨🏿' => 'Mfeano: ɔbarima, ɔbarima, wedeε ani a εda so kakra, ne wedeε ani tuntum',
    '👨🏽‍❤‍💋‍👨🏻' => 'Mfeano: ɔbarima, ɔbarima, wedeε ani a εda hᴐ kakra, ne wedeε ani a εda so',
    '👨🏽‍❤‍💋‍👨🏼' => 'Mfeano: ɔbarima, ɔbarima, wedeε ani a εda hᴐ kakra, ne wedeε ani a εda so kakra',
    '👨🏽‍❤‍💋‍👨🏽' => 'Mfeano: ɔbarima, ɔbarima, ne wedeε ani a εda hᴐ kakra',
    '👨🏽‍❤‍💋‍👨🏾' => 'Mfeano: ɔbarima, ɔbarima, wedeε ani a εda hᴐ kakra, ne wedeε ani tuntum kakra',
    '👨🏽‍❤‍💋‍👨🏿' => 'Mfeano: ɔbarima, ɔbarima, wedeε ani a εda hᴐ kakra, ne wedeε ani tuntum',
    '👨🏾‍❤‍💋‍👨🏻' => 'Mfeano: ɔbarima, ɔbarima, wedeε ani tuntum kakra, ne wedeε ani a εda so',
    '👨🏾‍❤‍💋‍👨🏼' => 'Mfeano: ɔbarima, ɔbarima, wedeε ani tuntum kakra, ne wedeε ani a εda so kakra',
    '👨🏾‍❤‍💋‍👨🏽' => 'Mfeano: ɔbarima, ɔbarima, wedeε ani tuntum kakra, ne wedeε ani a εda hᴐ kakra',
    '👨🏾‍❤‍💋‍👨🏾' => 'Mfeano: ɔbarima, ɔbarima, ne wedeε ani tuntum kakra',
    '👨🏾‍❤‍💋‍👨🏿' => 'Mfeano: ɔbarima, ɔbarima, wedeε ani tuntum kakra, ne wedeε ani tuntum',
    '👨🏿‍❤‍💋‍👨🏻' => 'Mfeano: ɔbarima, ɔbarima, wedeε ani tuntum, ne wedeε ani a εda so',
    '👨🏿‍❤‍💋‍👨🏼' => 'Mfeano: ɔbarima, ɔbarima, wedeε ani tuntum, ne wedeε ani a εda so kakra',
    '👨🏿‍❤‍💋‍👨🏽' => 'Mfeano: ɔbarima, ɔbarima, wedeε ani tuntum, ne wedeε ani a εda hᴐ kakra',
    '👨🏿‍❤‍💋‍👨🏾' => 'Mfeano: ɔbarima, ɔbarima, wedeε ani tuntum, ne wedeε ani tuntum kakra',
    '👨🏿‍❤‍💋‍👨🏿' => 'Mfeano: ɔbarima, ɔbarima, ne wedeε ani tuntum',
    '👩🏻‍❤‍💋‍👨🏻' => 'Mfeano: maame, ɔbarima, ne wedeε ani a εda so',
    '👩🏻‍❤‍💋‍👨🏼' => 'Mfeano: maame, ɔbarima, wedeε ani a εda so, ne wedeε ani a εda so kakra',
    '👩🏻‍❤‍💋‍👨🏽' => 'Mfeano: maame, ɔbarima, wedeε ani a εda so, ne wedeε ani a εda hᴐ kakra',
    '👩🏻‍❤‍💋‍👨🏾' => 'Mfeano: maame, ɔbarima, wedeε ani a εda so, ne wedeε ani tuntum kakra',
    '👩🏻‍❤‍💋‍👨🏿' => 'Mfeano: maame, ɔbarima, wedeε ani a εda so, ne wedeε ani tuntum',
    '👩🏼‍❤‍💋‍👨🏻' => 'Mfeano: maame, ɔbarima, wedeε ani a εda so kakra, ne wedeε ani a εda so',
    '👩🏼‍❤‍💋‍👨🏼' => 'Mfeano: maame, ɔbarima, ne wedeε ani a εda so kakra',
    '👩🏼‍❤‍💋‍👨🏽' => 'Mfeano: maame, ɔbarima, wedeε ani a εda so kakra, ne wedeε ani a εda hᴐ kakra',
    '👩🏼‍❤‍💋‍👨🏾' => 'Mfeano: maame, ɔbarima, wedeε ani a εda so kakra, ne wedeε ani tuntum kakra',
    '👩🏼‍❤‍💋‍👨🏿' => 'Mfeano: maame, ɔbarima, wedeε ani a εda so kakra, ne wedeε ani tuntum',
    '👩🏽‍❤‍💋‍👨🏻' => 'Mfeano: maame, ɔbarima, wedeε ani a εda hᴐ kakra, ne wedeε ani a εda so',
    '👩🏽‍❤‍💋‍👨🏼' => 'Mfeano: maame, ɔbarima, wedeε ani a εda hᴐ kakra, ne wedeε ani a εda so kakra',
    '👩🏽‍❤‍💋‍👨🏽' => 'Mfeano: maame, ɔbarima, ne wedeε ani a εda hᴐ kakra',
    '👩🏽‍❤‍💋‍👨🏾' => 'Mfeano: maame, ɔbarima, wedeε ani a εda hᴐ kakra, ne wedeε ani tuntum kakra',
    '👩🏽‍❤‍💋‍👨🏿' => 'Mfeano: maame, ɔbarima, wedeε ani a εda hᴐ kakra, ne wedeε ani tuntum',
    '👩🏾‍❤‍💋‍👨🏻' => 'Mfeano: maame, ɔbarima, wedeε ani tuntum kakra, ne wedeε ani a εda so',
    '👩🏾‍❤‍💋‍👨🏼' => 'Mfeano: maame, ɔbarima, wedeε ani tuntum kakra, ne wedeε ani a εda so kakra',
    '👩🏾‍❤‍💋‍👨🏽' => 'Mfeano: maame, ɔbarima, wedeε ani tuntum kakra, ne wedeε ani a εda hᴐ kakra',
    '👩🏾‍❤‍💋‍👨🏾' => 'Mfeano: maame, ɔbarima, ne wedeε ani tuntum kakra',
    '👩🏾‍❤‍💋‍👨🏿' => 'Mfeano: maame, ɔbarima, wedeε ani tuntum kakra, ne wedeε ani tuntum',
    '👩🏿‍❤‍💋‍👨🏻' => 'Mfeano: maame, ɔbarima, wedeε ani tuntum, ne wedeε ani a εda so',
    '👩🏿‍❤‍💋‍👨🏼' => 'Mfeano: maame, ɔbarima, wedeε ani tuntum, ne wedeε ani a εda so kakra',
    '👩🏿‍❤‍💋‍👨🏽' => 'Mfeano: maame, ɔbarima, wedeε ani tuntum, ne wedeε ani a εda hᴐ kakra',
    '👩🏿‍❤‍💋‍👨🏾' => 'Mfeano: maame, ɔbarima, wedeε ani tuntum, ne wedeε ani tuntum kakra',
    '👩🏿‍❤‍💋‍👨🏿' => 'Mfeano: maame, ɔbarima, ne wedeε ani tuntum',
    '👩🏻‍❤‍💋‍👩🏻' => 'Mfeano: maame, maame, ne wedeε ani a εda so',
    '👩🏻‍❤‍💋‍👩🏼' => 'Mfeano: maame, maame, wedeε ani a εda so, ne wedeε ani a εda so kakra',
    '👩🏻‍❤‍💋‍👩🏽' => 'Mfeano: maame, maame, wedeε ani a εda so, ne wedeε ani a εda hᴐ kakra',
    '👩🏻‍❤‍💋‍👩🏾' => 'Mfeano: maame, maame, wedeε ani a εda so, ne wedeε ani tuntum kakra',
    '👩🏻‍❤‍💋‍👩🏿' => 'Mfeano: maame, maame, wedeε ani a εda so, ne wedeε ani tuntum',
    '👩🏼‍❤‍💋‍👩🏻' => 'Mfeano: maame, maame, wedeε ani a εda so kakra, ne wedeε ani a εda so',
    '👩🏼‍❤‍💋‍👩🏼' => 'Mfeano: maame, maame, ne wedeε ani a εda so kakra',
    '👩🏼‍❤‍💋‍👩🏽' => 'Mfeano: maame, maame, wedeε ani a εda so kakra, ne wedeε ani a εda hᴐ kakra',
    '👩🏼‍❤‍💋‍👩🏾' => 'Mfeano: maame, maame, wedeε ani a εda so kakra, ne wedeε ani tuntum kakra',
    '👩🏼‍❤‍💋‍👩🏿' => 'Mfeano: maame, maame, wedeε ani a εda so kakra, ne wedeε ani tuntum',
    '👩🏽‍❤‍💋‍👩🏻' => 'Mfeano: maame, maame, wedeε ani a εda hᴐ kakra, ne wedeε ani a εda so',
    '👩🏽‍❤‍💋‍👩🏼' => 'Mfeano: maame, maame, wedeε ani a εda hᴐ kakra, ne wedeε ani a εda so kakra',
    '👩🏽‍❤‍💋‍👩🏽' => 'Mfeano: maame, maame, ne wedeε ani a εda hᴐ kakra',
    '👩🏽‍❤‍💋‍👩🏾' => 'Mfeano: maame, maame, wedeε ani a εda hᴐ kakra, ne wedeε ani tuntum kakra',
    '👩🏽‍❤‍💋‍👩🏿' => 'Mfeano: maame, maame, wedeε ani a εda hᴐ kakra, ne wedeε ani tuntum',
    '👩🏾‍❤‍💋‍👩🏻' => 'Mfeano: maame, maame, wedeε ani tuntum kakra, ne wedeε ani a εda so',
    '👩🏾‍❤‍💋‍👩🏼' => 'Mfeano: maame, maame, wedeε ani tuntum kakra, ne wedeε ani a εda so kakra',
    '👩🏾‍❤‍💋‍👩🏽' => 'Mfeano: maame, maame, wedeε ani tuntum kakra, ne wedeε ani a εda hᴐ kakra',
    '👩🏾‍❤‍💋‍👩🏾' => 'Mfeano: maame, maame, ne wedeε ani tuntum kakra',
    '👩🏾‍❤‍💋‍👩🏿' => 'Mfeano: maame, maame, wedeε ani tuntum kakra, ne wedeε ani tuntum',
    '👩🏿‍❤‍💋‍👩🏻' => 'Mfeano: maame, maame, wedeε ani tuntum, ne wedeε ani a εda so',
    '👩🏿‍❤‍💋‍👩🏼' => 'Mfeano: maame, maame, wedeε ani tuntum, ne wedeε ani a εda so kakra',
    '👩🏿‍❤‍💋‍👩🏽' => 'Mfeano: maame, maame, wedeε ani tuntum, ne wedeε ani a εda hᴐ kakra',
    '👩🏿‍❤‍💋‍👩🏾' => 'Mfeano: maame, maame, wedeε ani tuntum, ne wedeε ani tuntum kakra',
    '👩🏿‍❤‍💋‍👩🏿' => 'Mfeano: maame, maame, ne wedeε ani tuntum',
    '🧑🏻‍🫯‍🧑🏼' => 'Nkurɔfoɔ retentam: wedeε ani a εda so ne wedeε ani a εda so kakra',
    '🧑🏻‍🫯‍🧑🏽' => 'Nkurɔfoɔ retentam: wedeε ani a εda so ne wedeε ani a εda hᴐ kakra',
    '🧑🏻‍🫯‍🧑🏾' => 'Nkurɔfoɔ retentam: wedeε ani a εda so ne wedeε ani tuntum kakra',
    '🧑🏻‍🫯‍🧑🏿' => 'Nkurɔfoɔ retentam: wedeε ani a εda so ne wedeε ani tuntum',
    '🧑🏼‍🫯‍🧑🏻' => 'Nkurɔfoɔ retentam: wedeε ani a εda so kakra ne wedeε ani a εda so',
    '🧑🏼‍🫯‍🧑🏽' => 'Nkurɔfoɔ retentam: wedeε ani a εda so kakra ne wedeε ani a εda hᴐ kakra',
    '🧑🏼‍🫯‍🧑🏾' => 'Nkurɔfoɔ retentam: wedeε ani a εda so kakra ne wedeε ani tuntum kakra',
    '🧑🏼‍🫯‍🧑🏿' => 'Nkurɔfoɔ retentam: wedeε ani a εda so kakra ne wedeε ani tuntum',
    '🧑🏽‍🫯‍🧑🏻' => 'Nkurɔfoɔ retentam: wedeε ani a εda hᴐ kakra ne wedeε ani a εda so',
    '🧑🏽‍🫯‍🧑🏼' => 'Nkurɔfoɔ retentam: wedeε ani a εda hᴐ kakra ne wedeε ani a εda so kakra',
    '🧑🏽‍🫯‍🧑🏾' => 'Nkurɔfoɔ retentam: wedeε ani a εda hᴐ kakra ne wedeε ani tuntum kakra',
    '🧑🏽‍🫯‍🧑🏿' => 'Nkurɔfoɔ retentam: wedeε ani a εda hᴐ kakra ne wedeε ani tuntum',
    '🧑🏾‍🫯‍🧑🏻' => 'Nkurɔfoɔ retentam: wedeε ani tuntum kakra ne wedeε ani a εda so',
    '🧑🏾‍🫯‍🧑🏼' => 'Nkurɔfoɔ retentam: wedeε ani tuntum kakra ne wedeε ani a εda so kakra',
    '🧑🏾‍🫯‍🧑🏽' => 'Nkurɔfoɔ retentam: wedeε ani tuntum kakra ne wedeε ani a εda hᴐ kakra',
    '🧑🏾‍🫯‍🧑🏿' => 'Nkurɔfoɔ retentam: wedeε ani tuntum kakra ne wedeε ani tuntum',
    '🧑🏿‍🫯‍🧑🏻' => 'Nkurɔfoɔ retentam: wedeε ani tuntum ne wedeε ani a εda so',
    '🧑🏿‍🫯‍🧑🏼' => 'Nkurɔfoɔ retentam: wedeε ani tuntum ne wedeε ani a εda so kakra',
    '🧑🏿‍🫯‍🧑🏽' => 'Nkurɔfoɔ retentam: wedeε ani tuntum ne wedeε ani a εda hᴐ kakra',
    '🧑🏿‍🫯‍🧑🏾' => 'Nkurɔfoɔ retentam: wedeε ani tuntum ne wedeε ani tuntum kakra',
    '🧑🏻‍❤‍🧑🏼' => 'Awarefoɔ ne akoma: onipa, onipa, wedeε ani a εda so, ne wedeε ani a εda so kakra',
    '🧑🏻‍❤‍🧑🏽' => 'Awarefoɔ ne akoma: onipa, onipa, wedeε ani a εda so, ne wedeε ani a εda hᴐ kakra',
    '🧑🏻‍❤‍🧑🏾' => 'Awarefoɔ ne akoma: onipa, onipa, wedeε ani a εda so, ne wedeε ani tuntum kakra',
    '🧑🏻‍❤‍🧑🏿' => 'Awarefoɔ ne akoma: onipa, onipa, wedeε ani a εda so, ne wedeε ani tuntum',
    '🧑🏼‍❤‍🧑🏻' => 'Awarefoɔ ne akoma: onipa, onipa, wedeε ani a εda so kakra, ne wedeε ani a εda so',
    '🧑🏼‍❤‍🧑🏽' => 'Awarefoɔ ne akoma: onipa, onipa, wedeε ani a εda so kakra, ne wedeε ani a εda hᴐ kakra',
    '🧑🏼‍❤‍🧑🏾' => 'Awarefoɔ ne akoma: onipa, onipa, wedeε ani a εda so kakra, ne wedeε ani tuntum kakra',
    '🧑🏼‍❤‍🧑🏿' => 'Awarefoɔ ne akoma: onipa, onipa, wedeε ani a εda so kakra, ne wedeε ani tuntum',
    '🧑🏽‍❤‍🧑🏻' => 'Awarefoɔ ne akoma: onipa, onipa, wedeε ani a εda hᴐ kakra, ne wedeε ani a εda so',
    '🧑🏽‍❤‍🧑🏼' => 'Awarefoɔ ne akoma: onipa, onipa, wedeε ani a εda hᴐ kakra, ne wedeε ani a εda so kakra',
    '🧑🏽‍❤‍🧑🏾' => 'Awarefoɔ ne akoma: onipa, onipa, wedeε ani a εda hᴐ kakra, ne wedeε ani tuntum kakra',
    '🧑🏽‍❤‍🧑🏿' => 'Awarefoɔ ne akoma: onipa, onipa, wedeε ani a εda hᴐ kakra, ne wedeε ani tuntum',
    '🧑🏾‍❤‍🧑🏻' => 'Awarefoɔ ne akoma: onipa, onipa, wedeε ani tuntum kakra, ne wedeε ani a εda so',
    '🧑🏾‍❤‍🧑🏼' => 'Awarefoɔ ne akoma: onipa, onipa, wedeε ani tuntum kakra, ne wedeε ani a εda so kakra',
    '🧑🏾‍❤‍🧑🏽' => 'Awarefoɔ ne akoma: onipa, onipa, wedeε ani tuntum kakra, ne wedeε ani a εda hᴐ kakra',
    '🧑🏾‍❤‍🧑🏿' => 'Awarefoɔ ne akoma: onipa, onipa, wedeε ani tuntum kakra, ne wedeε ani tuntum',
    '🧑🏿‍❤‍🧑🏻' => 'Awarefoɔ ne akoma: onipa, onipa, wedeε ani tuntum, ne wedeε ani a εda so',
    '🧑🏿‍❤‍🧑🏼' => 'Awarefoɔ ne akoma: onipa, onipa, wedeε ani tuntum, ne wedeε ani a εda so kakra',
    '🧑🏿‍❤‍🧑🏽' => 'Awarefoɔ ne akoma: onipa, onipa, wedeε ani tuntum, ne wedeε ani a εda hᴐ kakra',
    '🧑🏿‍❤‍🧑🏾' => 'Awarefoɔ ne akoma: onipa, onipa, wedeε ani tuntum, ne wedeε ani tuntum kakra',
    '🧑🏻‍🐰‍🧑🏼' => 'Nkurɔfoɔ wɔ adanko aso: wedeε ani a εda so ne wedeε ani a εda so kakra',
    '🧑🏻‍🐰‍🧑🏽' => 'Nkurɔfoɔ wɔ adanko aso: wedeε ani a εda so ne wedeε ani a εda hᴐ kakra',
    '🧑🏻‍🐰‍🧑🏾' => 'Nkurɔfoɔ wɔ adanko aso: wedeε ani a εda so ne wedeε ani tuntum kakra',
    '🧑🏻‍🐰‍🧑🏿' => 'Nkurɔfoɔ wɔ adanko aso: wedeε ani a εda so ne wedeε ani tuntum',
    '🧑🏼‍🐰‍🧑🏻' => 'Nkurɔfoɔ wɔ adanko aso: wedeε ani a εda so kakra ne wedeε ani a εda so',
    '🧑🏼‍🐰‍🧑🏽' => 'Nkurɔfoɔ wɔ adanko aso: wedeε ani a εda so kakra ne wedeε ani a εda hᴐ kakra',
    '🧑🏼‍🐰‍🧑🏾' => 'Nkurɔfoɔ wɔ adanko aso: wedeε ani a εda so kakra ne wedeε ani tuntum kakra',
    '🧑🏼‍🐰‍🧑🏿' => 'Nkurɔfoɔ wɔ adanko aso: wedeε ani a εda so kakra ne wedeε ani tuntum',
    '🧑🏽‍🐰‍🧑🏻' => 'Nkurɔfoɔ wɔ adanko aso: wedeε ani a εda hᴐ kakra ne wedeε ani a εda so',
    '🧑🏽‍🐰‍🧑🏼' => 'Nkurɔfoɔ wɔ adanko aso: wedeε ani a εda hᴐ kakra ne wedeε ani a εda so kakra',
    '🧑🏽‍🐰‍🧑🏾' => 'Nkurɔfoɔ wɔ adanko aso: wedeε ani a εda hᴐ kakra ne wedeε ani tuntum kakra',
    '🧑🏽‍🐰‍🧑🏿' => 'Nkurɔfoɔ wɔ adanko aso: wedeε ani a εda hᴐ kakra ne wedeε ani tuntum',
    '🧑🏾‍🐰‍🧑🏻' => 'Nkurɔfoɔ wɔ adanko aso: wedeε ani tuntum kakra ne wedeε ani a εda so',
    '🧑🏾‍🐰‍🧑🏼' => 'Nkurɔfoɔ wɔ adanko aso: wedeε ani tuntum kakra ne wedeε ani a εda so kakra',
    '🧑🏾‍🐰‍🧑🏽' => 'Nkurɔfoɔ wɔ adanko aso: wedeε ani tuntum kakra ne wedeε ani a εda hᴐ kakra',
    '🧑🏾‍🐰‍🧑🏿' => 'Nkurɔfoɔ wɔ adanko aso: wedeε ani tuntum kakra ne wedeε ani tuntum',
    '🧑🏿‍🐰‍🧑🏻' => 'Nkurɔfoɔ wɔ adanko aso: wedeε ani tuntum ne wedeε ani a εda so',
    '🧑🏿‍🐰‍🧑🏼' => 'Nkurɔfoɔ wɔ adanko aso: wedeε ani tuntum ne wedeε ani a εda so kakra',
    '🧑🏿‍🐰‍🧑🏽' => 'Nkurɔfoɔ wɔ adanko aso: wedeε ani tuntum ne wedeε ani a εda hᴐ kakra',
    '🧑🏿‍🐰‍🧑🏾' => 'Nkurɔfoɔ wɔ adanko aso: wedeε ani tuntum ne wedeε ani tuntum kakra',
    '👨🏻‍🫯‍👨🏼' => 'Mmarima retentam: wedeε ani a εda so ne wedeε ani a εda so kakra',
    '👨🏻‍🫯‍👨🏽' => 'Mmarima retentam: wedeε ani a εda so ne wedeε ani a εda hᴐ kakra',
    '👨🏻‍🫯‍👨🏾' => 'Mmarima retentam: wedeε ani a εda so ne wedeε ani tuntum kakra',
    '👨🏻‍🫯‍👨🏿' => 'Mmarima retentam: wedeε ani a εda so ne wedeε ani tuntum',
    '👨🏼‍🫯‍👨🏻' => 'Mmarima retentam: wedeε ani a εda so kakra ne wedeε ani a εda so',
    '👨🏼‍🫯‍👨🏽' => 'Mmarima retentam: wedeε ani a εda so kakra ne wedeε ani a εda hᴐ kakra',
    '👨🏼‍🫯‍👨🏾' => 'Mmarima retentam: wedeε ani a εda so kakra ne wedeε ani tuntum kakra',
    '👨🏼‍🫯‍👨🏿' => 'Mmarima retentam: wedeε ani a εda so kakra ne wedeε ani tuntum',
    '👨🏽‍🫯‍👨🏻' => 'Mmarima retentam: wedeε ani a εda hᴐ kakra ne wedeε ani a εda so',
    '👨🏽‍🫯‍👨🏼' => 'Mmarima retentam: wedeε ani a εda hᴐ kakra ne wedeε ani a εda so kakra',
    '👨🏽‍🫯‍👨🏾' => 'Mmarima retentam: wedeε ani a εda hᴐ kakra ne wedeε ani tuntum kakra',
    '👨🏽‍🫯‍👨🏿' => 'Mmarima retentam: wedeε ani a εda hᴐ kakra ne wedeε ani tuntum',
    '👨🏾‍🫯‍👨🏻' => 'Mmarima retentam: wedeε ani tuntum kakra ne wedeε ani a εda so',
    '👨🏾‍🫯‍👨🏼' => 'Mmarima retentam: wedeε ani tuntum kakra ne wedeε ani a εda so kakra',
    '👨🏾‍🫯‍👨🏽' => 'Mmarima retentam: wedeε ani tuntum kakra ne wedeε ani a εda hᴐ kakra',
    '👨🏾‍🫯‍👨🏿' => 'Mmarima retentam: wedeε ani tuntum kakra ne wedeε ani tuntum',
    '👨🏿‍🫯‍👨🏻' => 'Mmarima retentam: wedeε ani tuntum ne wedeε ani a εda so',
    '👨🏿‍🫯‍👨🏼' => 'Mmarima retentam: wedeε ani tuntum ne wedeε ani a εda so kakra',
    '👨🏿‍🫯‍👨🏽' => 'Mmarima retentam: wedeε ani tuntum ne wedeε ani a εda hᴐ kakra',
    '👨🏿‍🫯‍👨🏾' => 'Mmarima retentam: wedeε ani tuntum ne wedeε ani tuntum kakra',
    '👨🏻‍❤‍👨🏻' => 'Awarefoɔ ne akoma: ɔbarima, ɔbarima, ne wedeε ani a εda so',
    '👨🏻‍❤‍👨🏼' => 'Awarefoɔ ne akoma: ɔbarima, ɔbarima, wedeε ani a εda so, ne wedeε ani a εda so kakra',
    '👨🏻‍❤‍👨🏽' => 'Awarefoɔ ne akoma: ɔbarima, ɔbarima, wedeε ani a εda so, ne wedeε ani a εda hᴐ kakra',
    '👨🏻‍❤‍👨🏾' => 'Awarefoɔ ne akoma: ɔbarima, ɔbarima, wedeε ani a εda so, ne wedeε ani tuntum kakra',
    '👨🏻‍❤‍👨🏿' => 'Awarefoɔ ne akoma: ɔbarima, ɔbarima, wedeε ani a εda so, ne wedeε ani tuntum',
    '👨🏼‍❤‍👨🏻' => 'Awarefoɔ ne akoma: ɔbarima, ɔbarima, wedeε ani a εda so kakra, ne wedeε ani a εda so',
    '👨🏼‍❤‍👨🏼' => 'Awarefoɔ ne akoma: ɔbarima, ɔbarima, ne wedeε ani a εda so kakra',
    '👨🏼‍❤‍👨🏽' => 'Awarefoɔ ne akoma: ɔbarima, ɔbarima, wedeε ani a εda so kakra, ne wedeε ani a εda hᴐ kakra',
    '👨🏼‍❤‍👨🏾' => 'Awarefoɔ ne akoma: ɔbarima, ɔbarima, wedeε ani a εda so kakra, ne wedeε ani tuntum kakra',
    '👨🏼‍❤‍👨🏿' => 'Awarefoɔ ne akoma: ɔbarima, ɔbarima, wedeε ani a εda so kakra, ne wedeε ani tuntum',
    '👨🏽‍❤‍👨🏻' => 'Awarefoɔ ne akoma: ɔbarima, ɔbarima, wedeε ani a εda hᴐ kakra, ne wedeε ani a εda so',
    '👨🏽‍❤‍👨🏼' => 'Awarefoɔ ne akoma: ɔbarima, ɔbarima, wedeε ani a εda hᴐ kakra, ne wedeε ani a εda so kakra',
    '👨🏽‍❤‍👨🏽' => 'Awarefoɔ ne akoma: ɔbarima, ɔbarima, ne wedeε ani a εda hᴐ kakra',
    '👨🏽‍❤‍👨🏾' => 'Awarefoɔ ne akoma: ɔbarima, ɔbarima, wedeε ani a εda hᴐ kakra, ne wedeε ani tuntum kakra',
    '👨🏽‍❤‍👨🏿' => 'Awarefoɔ ne akoma: ɔbarima, ɔbarima, wedeε ani a εda hᴐ kakra, ne wedeε ani tuntum',
    '👨🏾‍❤‍👨🏻' => 'Awarefoɔ ne akoma: ɔbarima, ɔbarima, wedeε ani tuntum kakra, ne wedeε ani a εda so',
    '👨🏾‍❤‍👨🏼' => 'Awarefoɔ ne akoma: ɔbarima, ɔbarima, wedeε ani tuntum kakra, ne wedeε ani a εda so kakra',
    '👨🏾‍❤‍👨🏽' => 'Awarefoɔ ne akoma: ɔbarima, ɔbarima, wedeε ani tuntum kakra, ne wedeε ani a εda hᴐ kakra',
    '👨🏾‍❤‍👨🏾' => 'Awarefoɔ ne akoma: ɔbarima, ɔbarima, ne wedeε ani tuntum kakra',
    '👨🏾‍❤‍👨🏿' => 'Awarefoɔ ne akoma: ɔbarima, ɔbarima, wedeε ani tuntum kakra, ne wedeε ani tuntum',
    '👨🏿‍❤‍👨🏻' => 'Awarefoɔ ne akoma: ɔbarima, ɔbarima, wedeε ani tuntum, ne wedeε ani a εda so',
    '👨🏿‍❤‍👨🏼' => 'Awarefoɔ ne akoma: ɔbarima, ɔbarima, wedeε ani tuntum, ne wedeε ani a εda so kakra',
    '👨🏿‍❤‍👨🏽' => 'Awarefoɔ ne akoma: ɔbarima, ɔbarima, wedeε ani tuntum, ne wedeε ani a εda hᴐ kakra',
    '👨🏿‍❤‍👨🏾' => 'Awarefoɔ ne akoma: ɔbarima, ɔbarima, wedeε ani tuntum, ne wedeε ani tuntum kakra',
    '👨🏿‍❤‍👨🏿' => 'Awarefoɔ ne akoma: ɔbarima, ɔbarima, ne wedeε ani tuntum',
    '👨🏻‍🐰‍👨🏼' => 'Mmarima a wɔwɔ adanko aso: wedeε ani a εda so ne wedeε ani a εda so kakra',
    '👨🏻‍🐰‍👨🏽' => 'Mmarima a wɔwɔ adanko aso: wedeε ani a εda so ne wedeε ani a εda hᴐ kakra',
    '👨🏻‍🐰‍👨🏾' => 'Mmarima a wɔwɔ adanko aso: wedeε ani a εda so ne wedeε ani tuntum kakra',
    '👨🏻‍🐰‍👨🏿' => 'Mmarima a wɔwɔ adanko aso: wedeε ani a εda so ne wedeε ani tuntum',
    '👨🏼‍🐰‍👨🏻' => 'Mmarima a wɔwɔ adanko aso: wedeε ani a εda so kakra ne wedeε ani a εda so',
    '👨🏼‍🐰‍👨🏽' => 'Mmarima a wɔwɔ adanko aso: wedeε ani a εda so kakra ne wedeε ani a εda hᴐ kakra',
    '👨🏼‍🐰‍👨🏾' => 'Mmarima a wɔwɔ adanko aso: wedeε ani a εda so kakra ne wedeε ani tuntum kakra',
    '👨🏼‍🐰‍👨🏿' => 'Mmarima a wɔwɔ adanko aso: wedeε ani a εda so kakra ne wedeε ani tuntum',
    '👨🏽‍🐰‍👨🏻' => 'Mmarima a wɔwɔ adanko aso: wedeε ani a εda hᴐ kakra ne wedeε ani a εda so',
    '👨🏽‍🐰‍👨🏼' => 'Mmarima a wɔwɔ adanko aso: wedeε ani a εda hᴐ kakra ne wedeε ani a εda so kakra',
    '👨🏽‍🐰‍👨🏾' => 'Mmarima a wɔwɔ adanko aso: wedeε ani a εda hᴐ kakra ne wedeε ani tuntum kakra',
    '👨🏽‍🐰‍👨🏿' => 'Mmarima a wɔwɔ adanko aso: wedeε ani a εda hᴐ kakra ne wedeε ani tuntum',
    '👨🏾‍🐰‍👨🏻' => 'Mmarima a wɔwɔ adanko aso: wedeε ani tuntum kakra ne wedeε ani a εda so',
    '👨🏾‍🐰‍👨🏼' => 'Mmarima a wɔwɔ adanko aso: wedeε ani tuntum kakra ne wedeε ani a εda so kakra',
    '👨🏾‍🐰‍👨🏽' => 'Mmarima a wɔwɔ adanko aso: wedeε ani tuntum kakra ne wedeε ani a εda hᴐ kakra',
    '👨🏾‍🐰‍👨🏿' => 'Mmarima a wɔwɔ adanko aso: wedeε ani tuntum kakra ne wedeε ani tuntum',
    '👨🏿‍🐰‍👨🏻' => 'Mmarima a wɔwɔ adanko aso: wedeε ani tuntum ne wedeε ani a εda so',
    '👨🏿‍🐰‍👨🏼' => 'Mmarima a wɔwɔ adanko aso: wedeε ani tuntum ne wedeε ani a εda so kakra',
    '👨🏿‍🐰‍👨🏽' => 'Mmarima a wɔwɔ adanko aso: wedeε ani tuntum ne wedeε ani a εda hᴐ kakra',
    '👨🏿‍🐰‍👨🏾' => 'Mmarima a wɔwɔ adanko aso: wedeε ani tuntum ne wedeε ani tuntum kakra',
    '👩🏻‍🫯‍👩🏼' => 'Mmaa retentam: wedeε ani a εda so ne wedeε ani a εda so kakra',
    '👩🏻‍🫯‍👩🏽' => 'Mmaa retentam: wedeε ani a εda so ne wedeε ani a εda hᴐ kakra',
    '👩🏻‍🫯‍👩🏾' => 'Mmaa retentam: wedeε ani a εda so ne wedeε ani tuntum kakra',
    '👩🏻‍🫯‍👩🏿' => 'Mmaa retentam: wedeε ani a εda so ne wedeε ani tuntum',
    '👩🏼‍🫯‍👩🏻' => 'Mmaa retentam: wedeε ani a εda so kakra ne wedeε ani a εda so',
    '👩🏼‍🫯‍👩🏽' => 'Mmaa retentam: wedeε ani a εda so kakra ne wedeε ani a εda hᴐ kakra',
    '👩🏼‍🫯‍👩🏾' => 'Mmaa retentam: wedeε ani a εda so kakra ne wedeε ani tuntum kakra',
    '👩🏼‍🫯‍👩🏿' => 'Mmaa retentam: wedeε ani a εda so kakra ne wedeε ani tuntum',
    '👩🏽‍🫯‍👩🏻' => 'Mmaa retentam: wedeε ani a εda hᴐ kakra ne wedeε ani a εda so',
    '👩🏽‍🫯‍👩🏼' => 'Mmaa retentam: wedeε ani a εda hᴐ kakra ne wedeε ani a εda so kakra',
    '👩🏽‍🫯‍👩🏾' => 'Mmaa retentam: wedeε ani a εda hᴐ kakra ne wedeε ani tuntum kakra',
    '👩🏽‍🫯‍👩🏿' => 'Mmaa retentam: wedeε ani a εda hᴐ kakra ne wedeε ani tuntum',
    '👩🏾‍🫯‍👩🏻' => 'Mmaa retentam: wedeε ani tuntum kakra ne wedeε ani a εda so',
    '👩🏾‍🫯‍👩🏼' => 'Mmaa retentam: wedeε ani tuntum kakra ne wedeε ani a εda so kakra',
    '👩🏾‍🫯‍👩🏽' => 'Mmaa retentam: wedeε ani tuntum kakra ne wedeε ani a εda hᴐ kakra',
    '👩🏾‍🫯‍👩🏿' => 'Mmaa retentam: wedeε ani tuntum kakra ne wedeε ani tuntum',
    '👩🏿‍🫯‍👩🏻' => 'Mmaa retentam: wedeε ani tuntum ne wedeε ani a εda so',
    '👩🏿‍🫯‍👩🏼' => 'Mmaa retentam: wedeε ani tuntum ne wedeε ani a εda so kakra',
    '👩🏿‍🫯‍👩🏽' => 'Mmaa retentam: wedeε ani tuntum ne wedeε ani a εda hᴐ kakra',
    '👩🏿‍🫯‍👩🏾' => 'Mmaa retentam: wedeε ani tuntum ne wedeε ani tuntum kakra',
    '👩🏻‍❤‍👨🏻' => 'Awarefoɔ ne akoma: maame, ɔbarima, ne wedeε ani a εda so',
    '👩🏻‍❤‍👨🏼' => 'Awarefoɔ ne akoma: maame, ɔbarima, wedeε ani a εda so, ne wedeε ani a εda so kakra',
    '👩🏻‍❤‍👨🏽' => 'Awarefoɔ ne akoma: maame, ɔbarima, wedeε ani a εda so, ne wedeε ani a εda hᴐ kakra',
    '👩🏻‍❤‍👨🏾' => 'Awarefoɔ ne akoma: maame, ɔbarima, wedeε ani a εda so, ne wedeε ani tuntum kakra',
    '👩🏻‍❤‍👨🏿' => 'Awarefoɔ ne akoma: maame, ɔbarima, wedeε ani a εda so, ne wedeε ani tuntum',
    '👩🏼‍❤‍👨🏻' => 'Awarefoɔ ne akoma: maame, ɔbarima, wedeε ani a εda so kakra, ne wedeε ani a εda so',
    '👩🏼‍❤‍👨🏼' => 'Awarefoɔ ne akoma: maame, ɔbarima, ne wedeε ani a εda so kakra',
    '👩🏼‍❤‍👨🏽' => 'Awarefoɔ ne akoma: maame, ɔbarima, wedeε ani a εda so kakra, ne wedeε ani a εda hᴐ kakra',
    '👩🏼‍❤‍👨🏾' => 'Awarefoɔ ne akoma: maame, ɔbarima, wedeε ani a εda so kakra, ne wedeε ani tuntum kakra',
    '👩🏼‍❤‍👨🏿' => 'Awarefoɔ ne akoma: maame, ɔbarima, wedeε ani a εda so kakra, ne wedeε ani tuntum',
    '👩🏽‍❤‍👨🏻' => 'Awarefoɔ ne akoma: maame, ɔbarima, wedeε ani a εda hᴐ kakra, ne wedeε ani a εda so',
    '👩🏽‍❤‍👨🏼' => 'Awarefoɔ ne akoma: maame, ɔbarima, wedeε ani a εda hᴐ kakra, ne wedeε ani a εda so kakra',
    '👩🏽‍❤‍👨🏽' => 'Awarefoɔ ne akoma: maame, ɔbarima, ne wedeε ani a εda hᴐ kakra',
    '👩🏽‍❤‍👨🏾' => 'Awarefoɔ ne akoma: maame, ɔbarima, wedeε ani a εda hᴐ kakra, ne wedeε ani tuntum kakra',
    '👩🏽‍❤‍👨🏿' => 'Awarefoɔ ne akoma: maame, ɔbarima, wedeε ani a εda hᴐ kakra, ne wedeε ani tuntum',
    '👩🏾‍❤‍👨🏻' => 'Awarefoɔ ne akoma: maame, ɔbarima, wedeε ani tuntum kakra, ne wedeε ani a εda so',
    '👩🏾‍❤‍👨🏼' => 'Awarefoɔ ne akoma: maame, ɔbarima, wedeε ani tuntum kakra, ne wedeε ani a εda so kakra',
    '👩🏾‍❤‍👨🏽' => 'Awarefoɔ ne akoma: maame, ɔbarima, wedeε ani tuntum kakra, ne wedeε ani a εda hᴐ kakra',
    '👩🏾‍❤‍👨🏾' => 'Awarefoɔ ne akoma: maame, ɔbarima, ne wedeε ani tuntum kakra',
    '👩🏾‍❤‍👨🏿' => 'Awarefoɔ ne akoma: maame, ɔbarima, wedeε ani tuntum kakra, ne wedeε ani tuntum',
    '👩🏿‍❤‍👨🏻' => 'Awarefoɔ ne akoma: maame, ɔbarima, wedeε ani tuntum, ne wedeε ani a εda so',
    '👩🏿‍❤‍👨🏼' => 'Awarefoɔ ne akoma: maame, ɔbarima, wedeε ani tuntum, ne wedeε ani a εda so kakra',
    '👩🏿‍❤‍👨🏽' => 'Awarefoɔ ne akoma: maame, ɔbarima, wedeε ani tuntum, ne wedeε ani a εda hᴐ kakra',
    '👩🏿‍❤‍👨🏾' => 'Awarefoɔ ne akoma: maame, ɔbarima, wedeε ani tuntum, ne wedeε ani tuntum kakra',
    '👩🏿‍❤‍👨🏿' => 'Awarefoɔ ne akoma: maame, ɔbarima, ne wedeε ani tuntum',
    '👩🏻‍❤‍👩🏻' => 'Awarefoɔ ne akoma: maame, maame, ne wedeε ani a εda so',
    '👩🏻‍❤‍👩🏼' => 'Awarefoɔ ne akoma: maame, maame, wedeε ani a εda so, ne wedeε ani a εda so kakra',
    '👩🏻‍❤‍👩🏽' => 'Awarefoɔ ne akoma: maame, maame, wedeε ani a εda so, ne wedeε ani a εda hᴐ kakra',
    '👩🏻‍❤‍👩🏾' => 'Awarefoɔ ne akoma: maame, maame, wedeε ani a εda so, ne wedeε ani tuntum kakra',
    '👩🏻‍❤‍👩🏿' => 'Awarefoɔ ne akoma: maame, maame, wedeε ani a εda so, ne wedeε ani tuntum',
    '👩🏼‍❤‍👩🏻' => 'Awarefoɔ ne akoma: maame, maame, wedeε ani a εda so kakra, ne wedeε ani a εda so',
    '👩🏼‍❤‍👩🏼' => 'Awarefoɔ ne akoma: maame, maame, ne wedeε ani a εda so kakra',
    '👩🏼‍❤‍👩🏽' => 'Awarefoɔ ne akoma: maame, maame, wedeε ani a εda so kakra, ne wedeε ani a εda hᴐ kakra',
    '👩🏼‍❤‍👩🏾' => 'Awarefoɔ ne akoma: maame, maame, wedeε ani a εda so kakra, ne wedeε ani tuntum kakra',
    '👩🏼‍❤‍👩🏿' => 'Awarefoɔ ne akoma: maame, maame, wedeε ani a εda so kakra, ne wedeε ani tuntum',
    '👩🏽‍❤‍👩🏻' => 'Awarefoɔ ne akoma: maame, maame, wedeε ani a εda hᴐ kakra, ne wedeε ani a εda so',
    '👩🏽‍❤‍👩🏼' => 'Awarefoɔ ne akoma: maame, maame, wedeε ani a εda hᴐ kakra, ne wedeε ani a εda so kakra',
    '👩🏽‍❤‍👩🏽' => 'Awarefoɔ ne akoma: maame, maame, ne wedeε ani a εda hᴐ kakra',
    '👩🏽‍❤‍👩🏾' => 'Awarefoɔ ne akoma: maame, maame, wedeε ani a εda hᴐ kakra, ne wedeε ani tuntum kakra',
    '👩🏽‍❤‍👩🏿' => 'Awarefoɔ ne akoma: maame, maame, wedeε ani a εda hᴐ kakra, ne wedeε ani tuntum',
    '👩🏾‍❤‍👩🏻' => 'Awarefoɔ ne akoma: maame, maame, wedeε ani tuntum kakra, ne wedeε ani a εda so',
    '👩🏾‍❤‍👩🏼' => 'Awarefoɔ ne akoma: maame, maame, wedeε ani tuntum kakra, ne wedeε ani a εda so kakra',
    '👩🏾‍❤‍👩🏽' => 'Awarefoɔ ne akoma: maame, maame, wedeε ani tuntum kakra, ne wedeε ani a εda hᴐ kakra',
    '👩🏾‍❤‍👩🏾' => 'Awarefoɔ ne akoma: maame, maame, ne wedeε ani tuntum kakra',
    '👩🏾‍❤‍👩🏿' => 'Awarefoɔ ne akoma: maame, maame, wedeε ani tuntum kakra, ne wedeε ani tuntum',
    '👩🏿‍❤‍👩🏻' => 'Awarefoɔ ne akoma: maame, maame, wedeε ani tuntum, ne wedeε ani a εda so',
    '👩🏿‍❤‍👩🏼' => 'Awarefoɔ ne akoma: maame, maame, wedeε ani tuntum, ne wedeε ani a εda so kakra',
    '👩🏿‍❤‍👩🏽' => 'Awarefoɔ ne akoma: maame, maame, wedeε ani tuntum, ne wedeε ani a εda hᴐ kakra',
    '👩🏿‍❤‍👩🏾' => 'Awarefoɔ ne akoma: maame, maame, wedeε ani tuntum, ne wedeε ani tuntum kakra',
    '👩🏿‍❤‍👩🏿' => 'Awarefoɔ ne akoma: maame, maame, ne wedeε ani tuntum',
    '👩🏻‍🐰‍👩🏼' => 'Mmaa a wɔwɔ adanko aso: wedeε ani a εda so ne wedeε ani a εda so kakra',
    '👩🏻‍🐰‍👩🏽' => 'Mmaa a wɔwɔ adanko aso: wedeε ani a εda so ne wedeε ani a εda hᴐ kakra',
    '👩🏻‍🐰‍👩🏾' => 'Mmaa a wɔwɔ adanko aso: wedeε ani a εda so ne wedeε ani tuntum kakra',
    '👩🏻‍🐰‍👩🏿' => 'Mmaa a wɔwɔ adanko aso: wedeε ani a εda so ne wedeε ani tuntum',
    '👩🏼‍🐰‍👩🏻' => 'Mmaa a wɔwɔ adanko aso: wedeε ani a εda so kakra ne wedeε ani a εda so',
    '👩🏼‍🐰‍👩🏽' => 'Mmaa a wɔwɔ adanko aso: wedeε ani a εda so kakra ne wedeε ani a εda hᴐ kakra',
    '👩🏼‍🐰‍👩🏾' => 'Mmaa a wɔwɔ adanko aso: wedeε ani a εda so kakra ne wedeε ani tuntum kakra',
    '👩🏼‍🐰‍👩🏿' => 'Mmaa a wɔwɔ adanko aso: wedeε ani a εda so kakra ne wedeε ani tuntum',
    '👩🏽‍🐰‍👩🏻' => 'Mmaa a wɔwɔ adanko aso: wedeε ani a εda hᴐ kakra ne wedeε ani a εda so',
    '👩🏽‍🐰‍👩🏼' => 'Mmaa a wɔwɔ adanko aso: wedeε ani a εda hᴐ kakra ne wedeε ani a εda so kakra',
    '👩🏽‍🐰‍👩🏾' => 'Mmaa a wɔwɔ adanko aso: wedeε ani a εda hᴐ kakra ne wedeε ani tuntum kakra',
    '👩🏽‍🐰‍👩🏿' => 'Mmaa a wɔwɔ adanko aso: wedeε ani a εda hᴐ kakra ne wedeε ani tuntum',
    '👩🏾‍🐰‍👩🏻' => 'Mmaa a wɔwɔ adanko aso: wedeε ani tuntum kakra ne wedeε ani a εda so',
    '👩🏾‍🐰‍👩🏼' => 'Mmaa a wɔwɔ adanko aso: wedeε ani tuntum kakra ne wedeε ani a εda so kakra',
    '👩🏾‍🐰‍👩🏽' => 'Mmaa a wɔwɔ adanko aso: wedeε ani tuntum kakra ne wedeε ani a εda hᴐ kakra',
    '👩🏾‍🐰‍👩🏿' => 'Mmaa a wɔwɔ adanko aso: wedeε ani tuntum kakra ne wedeε ani tuntum',
    '👩🏿‍🐰‍👩🏻' => 'Mmaa a wɔwɔ adanko aso: wedeε ani tuntum ne wedeε ani a εda so',
    '👩🏿‍🐰‍👩🏼' => 'Mmaa a wɔwɔ adanko aso: wedeε ani tuntum ne wedeε ani a εda so kakra',
    '👩🏿‍🐰‍👩🏽' => 'Mmaa a wɔwɔ adanko aso: wedeε ani tuntum ne wedeε ani a εda hᴐ kakra',
    '👩🏿‍🐰‍👩🏾' => 'Mmaa a wɔwɔ adanko aso: wedeε ani tuntum ne wedeε ani tuntum kakra',
    '🧑🏻‍🤝‍🧑🏻' => 'Nkurɔfoɔ asɔ nsam: wedeε ani a εda so',
    '🧑🏻‍🤝‍🧑🏼' => 'Nkurɔfoɔ asɔ nsam: wedeε ani a εda so ne wedeε ani a εda so kakra',
    '🧑🏻‍🤝‍🧑🏽' => 'Nkurɔfoɔ asɔ nsam: wedeε ani a εda so ne wedeε ani a εda hᴐ kakra',
    '🧑🏻‍🤝‍🧑🏾' => 'Nkurɔfoɔ asɔ nsam: wedeε ani a εda so ne wedeε ani tuntum kakra',
    '🧑🏻‍🤝‍🧑🏿' => 'Nkurɔfoɔ asɔ nsam: wedeε ani a εda so ne wedeε ani tuntum',
    '🧑🏼‍🤝‍🧑🏻' => 'Nkurɔfoɔ asɔ nsam: wedeε ani a εda so kakra ne wedeε ani a εda so',
    '🧑🏼‍🤝‍🧑🏼' => 'Nkurɔfoɔ asɔ nsam: wedeε ani a εda so kakra',
    '🧑🏼‍🤝‍🧑🏽' => 'Nkurɔfoɔ asɔ nsam: wedeε ani a εda so kakra ne wedeε ani a εda hᴐ kakra',
    '🧑🏼‍🤝‍🧑🏾' => 'Nkurɔfoɔ asɔ nsam: wedeε ani a εda so kakra ne wedeε ani tuntum kakra',
    '🧑🏼‍🤝‍🧑🏿' => 'Nkurɔfoɔ asɔ nsam: wedeε ani a εda so kakra ne wedeε ani tuntum',
    '🧑🏽‍🤝‍🧑🏻' => 'Nkurɔfoɔ asɔ nsam: wedeε ani a εda hᴐ kakra ne wedeε ani a εda so',
    '🧑🏽‍🤝‍🧑🏼' => 'Nkurɔfoɔ asɔ nsam: wedeε ani a εda hᴐ kakra ne wedeε ani a εda so kakra',
    '🧑🏽‍🤝‍🧑🏽' => 'Nkurɔfoɔ asɔ nsam: wedeε ani a εda hᴐ kakra',
    '🧑🏽‍🤝‍🧑🏾' => 'Nkurɔfoɔ asɔ nsam: wedeε ani a εda hᴐ kakra ne wedeε ani tuntum kakra',
    '🧑🏽‍🤝‍🧑🏿' => 'Nkurɔfoɔ asɔ nsam: wedeε ani a εda hᴐ kakra ne wedeε ani tuntum',
    '🧑🏾‍🤝‍🧑🏻' => 'Nkurɔfoɔ asɔ nsam: wedeε ani tuntum kakra ne wedeε ani a εda so',
    '🧑🏾‍🤝‍🧑🏼' => 'Nkurɔfoɔ asɔ nsam: wedeε ani tuntum kakra ne wedeε ani a εda so kakra',
    '🧑🏾‍🤝‍🧑🏽' => 'Nkurɔfoɔ asɔ nsam: wedeε ani tuntum kakra ne wedeε ani a εda hᴐ kakra',
    '🧑🏾‍🤝‍🧑🏾' => 'Nkurɔfoɔ asɔ nsam: wedeε ani tuntum kakra',
    '🧑🏾‍🤝‍🧑🏿' => 'Nkurɔfoɔ asɔ nsam: wedeε ani tuntum kakra ne wedeε ani tuntum',
    '🧑🏿‍🤝‍🧑🏻' => 'Nkurɔfoɔ asɔ nsam: wedeε ani tuntum ne wedeε ani a εda so',
    '🧑🏿‍🤝‍🧑🏼' => 'Nkurɔfoɔ asɔ nsam: wedeε ani tuntum ne wedeε ani a εda so kakra',
    '🧑🏿‍🤝‍🧑🏽' => 'Nkurɔfoɔ asɔ nsam: wedeε ani tuntum ne wedeε ani a εda hᴐ kakra',
    '🧑🏿‍🤝‍🧑🏾' => 'Nkurɔfoɔ asɔ nsam: wedeε ani tuntum ne wedeε ani tuntum kakra',
    '🧑🏿‍🤝‍🧑🏿' => 'Nkurɔfoɔ asɔ nsam: wedeε ani tuntum',
    '👩🏻‍🤝‍👩🏼' => 'Mmaa asɔ nsam: wedeε ani a εda so ne wedeε ani a εda so kakra',
    '👩🏻‍🤝‍👩🏽' => 'Mmaa asɔ nsam: wedeε ani a εda so ne wedeε ani a εda hᴐ kakra',
    '👩🏻‍🤝‍👩🏾' => 'Mmaa asɔ nsam: wedeε ani a εda so ne wedeε ani tuntum kakra',
    '👩🏻‍🤝‍👩🏿' => 'Mmaa asɔ nsam: wedeε ani a εda so ne wedeε ani tuntum',
    '👩🏼‍🤝‍👩🏻' => 'Mmaa asɔ nsam: wedeε ani a εda so kakra ne wedeε ani a εda so',
    '👩🏼‍🤝‍👩🏽' => 'Mmaa asɔ nsam: wedeε ani a εda so kakra ne wedeε ani a εda hᴐ kakra',
    '👩🏼‍🤝‍👩🏾' => 'Mmaa asɔ nsam: wedeε ani a εda so kakra ne wedeε ani tuntum kakra',
    '👩🏼‍🤝‍👩🏿' => 'Mmaa asɔ nsam: wedeε ani a εda so kakra ne wedeε ani tuntum',
    '👩🏽‍🤝‍👩🏻' => 'Mmaa asɔ nsam: wedeε ani a εda hᴐ kakra ne wedeε ani a εda so',
    '👩🏽‍🤝‍👩🏼' => 'Mmaa asɔ nsam: wedeε ani a εda hᴐ kakra ne wedeε ani a εda so kakra',
    '👩🏽‍🤝‍👩🏾' => 'Mmaa asɔ nsam: wedeε ani a εda hᴐ kakra ne wedeε ani tuntum kakra',
    '👩🏽‍🤝‍👩🏿' => 'Mmaa asɔ nsam: wedeε ani a εda hᴐ kakra ne wedeε ani tuntum',
    '👩🏾‍🤝‍👩🏻' => 'Mmaa asɔ nsam: wedeε ani tuntum kakra ne wedeε ani a εda so',
    '👩🏾‍🤝‍👩🏼' => 'Mmaa asɔ nsam: wedeε ani tuntum kakra ne wedeε ani a εda so kakra',
    '👩🏾‍🤝‍👩🏽' => 'Mmaa asɔ nsam: wedeε ani tuntum kakra ne wedeε ani a εda hᴐ kakra',
    '👩🏾‍🤝‍👩🏿' => 'Mmaa asɔ nsam: wedeε ani tuntum kakra ne wedeε ani tuntum',
    '👩🏿‍🤝‍👩🏻' => 'Mmaa asɔ nsam: wedeε ani tuntum ne wedeε ani a εda so',
    '👩🏿‍🤝‍👩🏼' => 'Mmaa asɔ nsam: wedeε ani tuntum ne wedeε ani a εda so kakra',
    '👩🏿‍🤝‍👩🏽' => 'Mmaa asɔ nsam: wedeε ani tuntum ne wedeε ani a εda hᴐ kakra',
    '👩🏿‍🤝‍👩🏾' => 'Mmaa asɔ nsam: wedeε ani tuntum ne wedeε ani tuntum kakra',
    '👩🏻‍🤝‍👨🏼' => 'Ɔbaa ne barima asɔ nsam: wedeε ani a εda so ne wedeε ani a εda so kakra',
    '👩🏻‍🤝‍👨🏽' => 'Ɔbaa ne barima asɔ nsam: wedeε ani a εda so ne wedeε ani a εda hᴐ kakra',
    '👩🏻‍🤝‍👨🏾' => 'Ɔbaa ne barima asɔ nsam: wedeε ani a εda so ne wedeε ani tuntum kakra',
    '👩🏻‍🤝‍👨🏿' => 'Ɔbaa ne barima asɔ nsam: wedeε ani a εda so ne wedeε ani tuntum',
    '👩🏼‍🤝‍👨🏻' => 'Ɔbaa ne barima asɔ nsam: wedeε ani a εda so kakra ne wedeε ani a εda so',
    '👩🏼‍🤝‍👨🏽' => 'Ɔbaa ne barima asɔ nsam: wedeε ani a εda so kakra ne wedeε ani a εda hᴐ kakra',
    '👩🏼‍🤝‍👨🏾' => 'Ɔbaa ne barima asɔ nsam: wedeε ani a εda so kakra ne wedeε ani tuntum kakra',
    '👩🏼‍🤝‍👨🏿' => 'Ɔbaa ne barima asɔ nsam: wedeε ani a εda so kakra ne wedeε ani tuntum',
    '👩🏽‍🤝‍👨🏻' => 'Ɔbaa ne barima asɔ nsam: wedeε ani a εda hᴐ kakra ne wedeε ani a εda so',
    '👩🏽‍🤝‍👨🏼' => 'Ɔbaa ne barima asɔ nsam: wedeε ani a εda hᴐ kakra ne wedeε ani a εda so kakra',
    '👩🏽‍🤝‍👨🏾' => 'Ɔbaa ne barima asɔ nsam: wedeε ani a εda hᴐ kakra ne wedeε ani tuntum kakra',
    '👩🏽‍🤝‍👨🏿' => 'Ɔbaa ne barima asɔ nsam: wedeε ani a εda hᴐ kakra ne wedeε ani tuntum',
    '👩🏾‍🤝‍👨🏻' => 'Ɔbaa ne barima asɔ nsam: wedeε ani tuntum kakra ne wedeε ani a εda so',
    '👩🏾‍🤝‍👨🏼' => 'Ɔbaa ne barima asɔ nsam: wedeε ani tuntum kakra ne wedeε ani a εda so kakra',
    '👩🏾‍🤝‍👨🏽' => 'Ɔbaa ne barima asɔ nsam: wedeε ani tuntum kakra ne wedeε ani a εda hᴐ kakra',
    '👩🏾‍🤝‍👨🏿' => 'Ɔbaa ne barima asɔ nsam: wedeε ani tuntum kakra ne wedeε ani tuntum',
    '👩🏿‍🤝‍👨🏻' => 'Ɔbaa ne barima asɔ nsam: wedeε ani tuntum ne wedeε ani a εda so',
    '👩🏿‍🤝‍👨🏼' => 'Ɔbaa ne barima asɔ nsam: wedeε ani tuntum ne wedeε ani a εda so kakra',
    '👩🏿‍🤝‍👨🏽' => 'Ɔbaa ne barima asɔ nsam: wedeε ani tuntum ne wedeε ani a εda hᴐ kakra',
    '👩🏿‍🤝‍👨🏾' => 'Ɔbaa ne barima asɔ nsam: wedeε ani tuntum ne wedeε ani tuntum kakra',
    '👨🏻‍🤝‍👨🏼' => 'Mmarima asɔ nsam: wedeε ani a εda so ne wedeε ani a εda so kakra',
    '👨🏻‍🤝‍👨🏽' => 'Mmarima asɔ nsam: wedeε ani a εda so ne wedeε ani a εda hᴐ kakra',
    '👨🏻‍🤝‍👨🏾' => 'Mmarima asɔ nsam: wedeε ani a εda so ne wedeε ani tuntum kakra',
    '👨🏻‍🤝‍👨🏿' => 'Mmarima asɔ nsam: wedeε ani a εda so ne wedeε ani tuntum',
    '👨🏼‍🤝‍👨🏻' => 'Mmarima asɔ nsam: wedeε ani a εda so kakra ne wedeε ani a εda so',
    '👨🏼‍🤝‍👨🏽' => 'Mmarima asɔ nsam: wedeε ani a εda so kakra ne wedeε ani a εda hᴐ kakra',
    '👨🏼‍🤝‍👨🏾' => 'Mmarima asɔ nsam: wedeε ani a εda so kakra ne wedeε ani tuntum kakra',
    '👨🏼‍🤝‍👨🏿' => 'Mmarima asɔ nsam: wedeε ani a εda so kakra ne wedeε ani tuntum',
    '👨🏽‍🤝‍👨🏻' => 'Mmarima asɔ nsam: wedeε ani a εda hᴐ kakra ne wedeε ani a εda so',
    '👨🏽‍🤝‍👨🏼' => 'Mmarima asɔ nsam: wedeε ani a εda hᴐ kakra ne wedeε ani a εda so kakra',
    '👨🏽‍🤝‍👨🏾' => 'Mmarima asɔ nsam: wedeε ani a εda hᴐ kakra ne wedeε ani tuntum kakra',
    '👨🏽‍🤝‍👨🏿' => 'Mmarima asɔ nsam: wedeε ani a εda hᴐ kakra ne wedeε ani tuntum',
    '👨🏾‍🤝‍👨🏻' => 'Mmarima asɔ nsam: wedeε ani tuntum kakra ne wedeε ani a εda so',
    '👨🏾‍🤝‍👨🏼' => 'Mmarima asɔ nsam: wedeε ani tuntum kakra ne wedeε ani a εda so kakra',
    '👨🏾‍🤝‍👨🏽' => 'Mmarima asɔ nsam: wedeε ani tuntum kakra ne wedeε ani a εda hᴐ kakra',
    '👨🏾‍🤝‍👨🏿' => 'Mmarima asɔ nsam: wedeε ani tuntum kakra ne wedeε ani tuntum',
    '👨🏿‍🤝‍👨🏻' => 'Mmarima asɔ nsam: wedeε ani tuntum ne wedeε ani a εda so',
    '👨🏿‍🤝‍👨🏼' => 'Mmarima asɔ nsam: wedeε ani tuntum ne wedeε ani a εda so kakra',
    '👨🏿‍🤝‍👨🏽' => 'Mmarima asɔ nsam: wedeε ani tuntum ne wedeε ani a εda hᴐ kakra',
    '👨🏿‍🤝‍👨🏾' => 'Mmarima asɔ nsam: wedeε ani tuntum ne wedeε ani tuntum kakra',
    '👩‍❤‍💋‍👨' => 'Mfeano: maame ne ɔbarima',
    '👨‍❤‍💋‍👨' => 'Mfeano: ɔbarima ne ɔbarima',
    '👩‍❤‍💋‍👩' => 'Mfeano: maame ne maame',
    '👨‍👩‍👧‍👦' => 'Abusua: ɔbarima, maame, ɔbaa, ne barima',
    '👨‍👩‍👦‍👦' => 'Abusua: ɔbarima, maame, barima, ne barima',
    '👨‍👩‍👧‍👧' => 'Abusua: ɔbarima, maame, ɔbaa, ne ɔbaa',
    '👨‍👨‍👧‍👦' => 'Abusua: ɔbarima, ɔbarima, ɔbaa, ne barima',
    '👨‍👨‍👦‍👦' => 'Abusua: ɔbarima, ɔbarima, barima, ne barima',
    '👨‍👨‍👧‍👧' => 'Abusua: ɔbarima, ɔbarima, ɔbaa, ne ɔbaa',
    '👩‍👩‍👧‍👦' => 'Abusua: maame, maame, ɔbaa, ne barima',
    '👩‍👩‍👦‍👦' => 'Abusua: maame, maame, barima, ne barima',
    '👩‍👩‍👧‍👧' => 'Abusua: maame, maame, ɔbaa, ne ɔbaa',
    '🧑‍🧑‍🧒‍🧒' => 'Abusua: panin, panin, akwadaa, akwadaa',
    '🚶🏻‍♀‍➡' => 'Ɔbaa renante: wedeε ani a εda so ne rehwɛ nifa',
    '🚶🏼‍♀‍➡' => 'Ɔbaa renante: wedeε ani a εda so kakra ne rehwɛ nifa',
    '🚶🏽‍♀‍➡' => 'Ɔbaa renante: wedeε ani a εda hᴐ kakra ne rehwɛ nifa',
    '🚶🏾‍♀‍➡' => 'Ɔbaa renante: wedeε ani tuntum kakra ne rehwɛ nifa',
    '🚶🏿‍♀‍➡' => 'Ɔbaa renante: wedeε ani tuntum ne rehwɛ nifa',
    '🚶🏻‍♂‍➡' => 'Barima renante: wedeε ani a εda so ne rehwɛ nifa',
    '🚶🏼‍♂‍➡' => 'Barima renante: wedeε ani a εda so kakra ne rehwɛ nifa',
    '🚶🏽‍♂‍➡' => 'Barima renante: wedeε ani a εda hᴐ kakra ne rehwɛ nifa',
    '🚶🏾‍♂‍➡' => 'Barima renante: wedeε ani tuntum kakra ne rehwɛ nifa',
    '🚶🏿‍♂‍➡' => 'Barima renante: wedeε ani tuntum ne rehwɛ nifa',
    '🧎🏻‍♀‍➡' => 'Ɔbaa abu nkotodwe: wedeε ani a εda so ne rehwɛ nifa',
    '🧎🏼‍♀‍➡' => 'Ɔbaa abu nkotodwe: wedeε ani a εda so kakra ne rehwɛ nifa',
    '🧎🏽‍♀‍➡' => 'Ɔbaa abu nkotodwe: wedeε ani a εda hᴐ kakra ne rehwɛ nifa',
    '🧎🏾‍♀‍➡' => 'Ɔbaa abu nkotodwe: wedeε ani tuntum kakra ne rehwɛ nifa',
    '🧎🏿‍♀‍➡' => 'Ɔbaa abu nkotodwe: wedeε ani tuntum ne rehwɛ nifa',
    '🧎🏻‍♂‍➡' => 'Barima abu nkotodwe: wedeε ani a εda so ne rehwɛ nifa',
    '🧎🏼‍♂‍➡' => 'Barima abu nkotodwe: wedeε ani a εda so kakra ne rehwɛ nifa',
    '🧎🏽‍♂‍➡' => 'Barima abu nkotodwe: wedeε ani a εda hᴐ kakra ne rehwɛ nifa',
    '🧎🏾‍♂‍➡' => 'Barima abu nkotodwe: wedeε ani tuntum kakra ne rehwɛ nifa',
    '🧎🏿‍♂‍➡' => 'Barima abu nkotodwe: wedeε ani tuntum ne rehwɛ nifa',
    '🧑🏻‍🦯‍➡' => 'Obi kura abaa fitaa: wedeε ani a εda so ne rehwɛ nifa',
    '🧑🏼‍🦯‍➡' => 'Obi kura abaa fitaa: wedeε ani a εda so kakra ne rehwɛ nifa',
    '🧑🏽‍🦯‍➡' => 'Obi kura abaa fitaa: wedeε ani a εda hᴐ kakra ne rehwɛ nifa',
    '🧑🏾‍🦯‍➡' => 'Obi kura abaa fitaa: wedeε ani tuntum kakra ne rehwɛ nifa',
    '🧑🏿‍🦯‍➡' => 'Obi kura abaa fitaa: wedeε ani tuntum ne rehwɛ nifa',
    '👨🏻‍🦯‍➡' => 'Barima kura abaa fitaa: wedeε ani a εda so ne rehwɛ nifa',
    '👨🏼‍🦯‍➡' => 'Barima kura abaa fitaa: wedeε ani a εda so kakra ne rehwɛ nifa',
    '👨🏽‍🦯‍➡' => 'Barima kura abaa fitaa: wedeε ani a εda hᴐ kakra ne rehwɛ nifa',
    '👨🏾‍🦯‍➡' => 'Barima kura abaa fitaa: wedeε ani tuntum kakra ne rehwɛ nifa',
    '👨🏿‍🦯‍➡' => 'Barima kura abaa fitaa: wedeε ani tuntum ne rehwɛ nifa',
    '👩🏻‍🦯‍➡' => 'Ɔbaa kura abaa fitaa: wedeε ani a εda so ne rehwɛ nifa',
    '👩🏼‍🦯‍➡' => 'Ɔbaa kura abaa fitaa: wedeε ani a εda so kakra ne rehwɛ nifa',
    '👩🏽‍🦯‍➡' => 'Ɔbaa kura abaa fitaa: wedeε ani a εda hᴐ kakra ne rehwɛ nifa',
    '👩🏾‍🦯‍➡' => 'Ɔbaa kura abaa fitaa: wedeε ani tuntum kakra ne rehwɛ nifa',
    '👩🏿‍🦯‍➡' => 'Ɔbaa kura abaa fitaa: wedeε ani tuntum ne rehwɛ nifa',
    '🧑🏻‍🦼‍➡' => 'Obi te moto hwiikyɛɛ mu: wedeε ani a εda so ne rehwɛ nifa',
    '🧑🏼‍🦼‍➡' => 'Obi te moto hwiikyɛɛ mu: wedeε ani a εda so kakra ne rehwɛ nifa',
    '🧑🏽‍🦼‍➡' => 'Obi te moto hwiikyɛɛ mu: wedeε ani a εda hᴐ kakra ne rehwɛ nifa',
    '🧑🏾‍🦼‍➡' => 'Obi te moto hwiikyɛɛ mu: wedeε ani tuntum kakra ne rehwɛ nifa',
    '🧑🏿‍🦼‍➡' => 'Obi te moto hwiikyɛɛ mu: wedeε ani tuntum ne rehwɛ nifa',
    '👨🏻‍🦼‍➡' => 'Barima te moto hwiikyɛɛ mu: wedeε ani a εda so ne rehwɛ nifa',
    '👨🏼‍🦼‍➡' => 'Barima te moto hwiikyɛɛ mu: wedeε ani a εda so kakra ne rehwɛ nifa',
    '👨🏽‍🦼‍➡' => 'Barima te moto hwiikyɛɛ mu: wedeε ani a εda hᴐ kakra ne rehwɛ nifa',
    '👨🏾‍🦼‍➡' => 'Barima te moto hwiikyɛɛ mu: wedeε ani tuntum kakra ne rehwɛ nifa',
    '👨🏿‍🦼‍➡' => 'Barima te moto hwiikyɛɛ mu: wedeε ani tuntum ne rehwɛ nifa',
    '👩🏻‍🦼‍➡' => 'Ɔbaa te moto hwiikyɛɛ mu: wedeε ani a εda so ne rehwɛ nifa',
    '👩🏼‍🦼‍➡' => 'Ɔbaa te moto hwiikyɛɛ mu: wedeε ani a εda so kakra ne rehwɛ nifa',
    '👩🏽‍🦼‍➡' => 'Ɔbaa te moto hwiikyɛɛ mu: wedeε ani a εda hᴐ kakra ne rehwɛ nifa',
    '👩🏾‍🦼‍➡' => 'Ɔbaa te moto hwiikyɛɛ mu: wedeε ani tuntum kakra ne rehwɛ nifa',
    '👩🏿‍🦼‍➡' => 'Ɔbaa te moto hwiikyɛɛ mu: wedeε ani tuntum ne rehwɛ nifa',
    '🧑🏻‍🦽‍➡' => 'Obi te manuaa hwiikyɛɛ mu: wedeε ani a εda so ne rehwɛ nifa',
    '🧑🏼‍🦽‍➡' => 'Obi te manuaa hwiikyɛɛ mu: wedeε ani a εda so kakra ne rehwɛ nifa',
    '🧑🏽‍🦽‍➡' => 'Obi te manuaa hwiikyɛɛ mu: wedeε ani a εda hᴐ kakra ne rehwɛ nifa',
    '🧑🏾‍🦽‍➡' => 'Obi te manuaa hwiikyɛɛ mu: wedeε ani tuntum kakra ne rehwɛ nifa',
    '🧑🏿‍🦽‍➡' => 'Obi te manuaa hwiikyɛɛ mu: wedeε ani tuntum ne rehwɛ nifa',
    '👨🏻‍🦽‍➡' => 'Barima te manuaa hwiikyɛɛ mu: wedeε ani a εda so ne rehwɛ nifa',
    '👨🏼‍🦽‍➡' => 'Barima te manuaa hwiikyɛɛ mu: wedeε ani a εda so kakra ne rehwɛ nifa',
    '👨🏽‍🦽‍➡' => 'Barima te manuaa hwiikyɛɛ mu: wedeε ani a εda hᴐ kakra ne rehwɛ nifa',
    '👨🏾‍🦽‍➡' => 'Barima te manuaa hwiikyɛɛ mu: wedeε ani tuntum kakra ne rehwɛ nifa',
    '👨🏿‍🦽‍➡' => 'Barima te manuaa hwiikyɛɛ mu: wedeε ani tuntum ne rehwɛ nifa',
    '👩🏻‍🦽‍➡' => 'Ɔbaa te manuaa hwiikyɛɛ mu: wedeε ani a εda so ne rehwɛ nifa',
    '👩🏼‍🦽‍➡' => 'Ɔbaa te manuaa hwiikyɛɛ mu: wedeε ani a εda so kakra ne rehwɛ nifa',
    '👩🏽‍🦽‍➡' => 'Ɔbaa te manuaa hwiikyɛɛ mu: wedeε ani a εda hᴐ kakra ne rehwɛ nifa',
    '👩🏾‍🦽‍➡' => 'Ɔbaa te manuaa hwiikyɛɛ mu: wedeε ani tuntum kakra ne rehwɛ nifa',
    '👩🏿‍🦽‍➡' => 'Ɔbaa te manuaa hwiikyɛɛ mu: wedeε ani tuntum ne rehwɛ nifa',
    '🏃🏻‍♀‍➡' => 'Ɔbaa retu mmirika: wedeε ani a εda so ne rehwɛ nifa',
    '🏃🏼‍♀‍➡' => 'Ɔbaa retu mmirika: wedeε ani a εda so kakra ne rehwɛ nifa',
    '🏃🏽‍♀‍➡' => 'Ɔbaa retu mmirika: wedeε ani a εda hᴐ kakra ne rehwɛ nifa',
    '🏃🏾‍♀‍➡' => 'Ɔbaa retu mmirika: wedeε ani tuntum kakra ne rehwɛ nifa',
    '🏃🏿‍♀‍➡' => 'Ɔbaa retu mmirika: wedeε ani tuntum ne rehwɛ nifa',
    '🏃🏻‍♂‍➡' => 'Barima retu mmirika: wedeε ani a εda so ne rehwɛ nifa',
    '🏃🏼‍♂‍➡' => 'Barima retu mmirika: wedeε ani a εda so kakra ne rehwɛ nifa',
    '🏃🏽‍♂‍➡' => 'Barima retu mmirika: wedeε ani a εda hᴐ kakra ne rehwɛ nifa',
    '🏃🏾‍♂‍➡' => 'Barima retu mmirika: wedeε ani tuntum kakra ne rehwɛ nifa',
    '🏃🏿‍♂‍➡' => 'Barima retu mmirika: wedeε ani tuntum ne rehwɛ nifa',
    '🫱🏻‍🫲🏼' => 'nsamkyea: wedeε ani a εda so ne wedeε ani a εda so kakra',
    '🫱🏻‍🫲🏽' => 'nsamkyea: wedeε ani a εda so ne wedeε ani a εda hᴐ kakra',
    '🫱🏻‍🫲🏾' => 'nsamkyea: wedeε ani a εda so ne wedeε ani tuntum kakra',
    '🫱🏻‍🫲🏿' => 'nsamkyea: wedeε ani a εda so ne wedeε ani tuntum',
    '🫱🏼‍🫲🏻' => 'nsamkyea: wedeε ani a εda so kakra ne wedeε ani a εda so',
    '🫱🏼‍🫲🏽' => 'nsamkyea: wedeε ani a εda so kakra ne wedeε ani a εda hᴐ kakra',
    '🫱🏼‍🫲🏾' => 'nsamkyea: wedeε ani a εda so kakra ne wedeε ani tuntum kakra',
    '🫱🏼‍🫲🏿' => 'nsamkyea: wedeε ani a εda so kakra ne wedeε ani tuntum',
    '🫱🏽‍🫲🏻' => 'nsamkyea: wedeε ani a εda hᴐ kakra ne wedeε ani a εda so',
    '🫱🏽‍🫲🏼' => 'nsamkyea: wedeε ani a εda hᴐ kakra ne wedeε ani a εda so kakra',
    '🫱🏽‍🫲🏾' => 'nsamkyea: wedeε ani a εda hᴐ kakra ne wedeε ani tuntum kakra',
    '🫱🏽‍🫲🏿' => 'nsamkyea: wedeε ani a εda hᴐ kakra ne wedeε ani tuntum',
    '🫱🏾‍🫲🏻' => 'nsamkyea: wedeε ani tuntum kakra ne wedeε ani a εda so',
    '🫱🏾‍🫲🏼' => 'nsamkyea: wedeε ani tuntum kakra ne wedeε ani a εda so kakra',
    '🫱🏾‍🫲🏽' => 'nsamkyea: wedeε ani tuntum kakra ne wedeε ani a εda hᴐ kakra',
    '🫱🏾‍🫲🏿' => 'nsamkyea: wedeε ani tuntum kakra ne wedeε ani tuntum',
    '🫱🏿‍🫲🏻' => 'nsamkyea: wedeε ani tuntum ne wedeε ani a εda so',
    '🫱🏿‍🫲🏼' => 'nsamkyea: wedeε ani tuntum ne wedeε ani a εda so kakra',
    '🫱🏿‍🫲🏽' => 'nsamkyea: wedeε ani tuntum ne wedeε ani a εda hᴐ kakra',
    '🫱🏿‍🫲🏾' => 'nsamkyea: wedeε ani tuntum ne wedeε ani tuntum kakra',
    '🚶‍♀‍➡' => 'Ɔbaa renante: rehwɛ nifa',
    '🚶‍♂‍➡' => 'Barima renante: rehwɛ nifa',
    '🧎‍♀‍➡' => 'Ɔbaa abu nkotodwe: rehwɛ nifa',
    '🧎‍♂‍➡' => 'Barima abu nkotodwe: rehwɛ nifa',
    '🧑‍🦯‍➡' => 'Obi kura abaa fitaa: rehwɛ nifa',
    '👨‍🦯‍➡' => 'Barima kura abaa fitaa: rehwɛ nifa',
    '👩‍🦯‍➡' => 'Ɔbaa kura abaa fitaa: rehwɛ nifa',
    '🧑‍🦼‍➡' => 'Obi te moto hwiikyɛɛ mu: rehwɛ nifa',
    '👨‍🦼‍➡' => 'Barima te moto hwiikyɛɛ mu: rehwɛ nifa',
    '👩‍🦼‍➡' => 'Ɔbaa te moto hwiikyɛɛ mu: rehwɛ nifa',
    '🧑‍🦽‍➡' => 'Obi te manuaa hwiikyɛɛ mu: rehwɛ nifa',
    '👨‍🦽‍➡' => 'Barima te manuaa hwiikyɛɛ mu: rehwɛ nifa',
    '👩‍🦽‍➡' => 'Ɔbaa te manuaa hwiikyɛɛ mu: rehwɛ nifa',
    '🏃‍♀‍➡' => 'Ɔbaa retu mmirika: rehwɛ nifa',
    '🏃‍♂‍➡' => 'Barima retu mmirika: rehwɛ nifa',
    '👩‍❤‍👨' => 'Awarefoɔ ne akoma: maame ne ɔbarima',
    '👨‍❤‍👨' => 'Awarefoɔ ne akoma: ɔbarima ne ɔbarima',
    '👩‍❤‍👩' => 'Awarefoɔ ne akoma: maame ne maame',
    '👨‍👩‍👦' => 'Abusua: ɔbarima, maame, ne barima',
    '👨‍👩‍👧' => 'Abusua: ɔbarima, maame, ne ɔbaa',
    '👨‍👨‍👦' => 'Abusua: ɔbarima, ɔbarima, ne barima',
    '👨‍👨‍👧' => 'Abusua: ɔbarima, ɔbarima, ne ɔbaa',
    '👩‍👩‍👦' => 'Abusua: maame, maame, ne barima',
    '👩‍👩‍👧' => 'Abusua: maame, maame, ne ɔbaa',
    '👨‍👦‍👦' => 'Abusua: ɔbarima, barima, ne barima',
    '👨‍👧‍👦' => 'Abusua: ɔbarima, ɔbaa, ne barima',
    '👨‍👧‍👧' => 'Abusua: ɔbarima, ɔbaa, ne ɔbaa',
    '👩‍👦‍👦' => 'Abusua: maame, barima, ne barima',
    '👩‍👧‍👦' => 'Abusua: maame, ɔbaa, ne barima',
    '👩‍👧‍👧' => 'Abusua: maame, ɔbaa, ne ɔbaa',
    '🧑‍🤝‍🧑' => 'Nkurɔfoɔ asɔ nsam',
    '🧑‍🧑‍🧒' => 'Abusua: panin, panin, akwadaa',
    '🧑‍🧒‍🧒' => 'Abusua: panin, akwadaa, akwadaa',
    '🧑🏻‍🦰' => 'onipa: wedeε ani a εda so ne nwi kͻkͻͻ',
    '🧑🏼‍🦰' => 'onipa: wedeε ani a εda so kakra ne nwi kͻkͻͻ',
    '🧑🏽‍🦰' => 'onipa: wedeε ani a εda hᴐ kakra ne nwi kͻkͻͻ',
    '🧑🏾‍🦰' => 'onipa: wedeε ani tuntum kakra ne nwi kͻkͻͻ',
    '🧑🏿‍🦰' => 'onipa: wedeε ani tuntum ne nwi kͻkͻͻ',
    '🧑🏻‍🦱' => 'onipa: wedeε ani a εda so ne enwi a akyinkyim',
    '🧑🏼‍🦱' => 'onipa: wedeε ani a εda so kakra ne enwi a akyinkyim',
    '🧑🏽‍🦱' => 'onipa: wedeε ani a εda hᴐ kakra ne enwi a akyinkyim',
    '🧑🏾‍🦱' => 'onipa: wedeε ani tuntum kakra ne enwi a akyinkyim',
    '🧑🏿‍🦱' => 'onipa: wedeε ani tuntum ne enwi a akyinkyim',
    '🧑🏻‍🦳' => 'onipa: wedeε ani a εda so ne nwi fitaa',
    '🧑🏼‍🦳' => 'onipa: wedeε ani a εda so kakra ne nwi fitaa',
    '🧑🏽‍🦳' => 'onipa: wedeε ani a εda hᴐ kakra ne nwi fitaa',
    '🧑🏾‍🦳' => 'onipa: wedeε ani tuntum kakra ne nwi fitaa',
    '🧑🏿‍🦳' => 'onipa: wedeε ani tuntum ne nwi fitaa',
    '🧑🏻‍🦲' => 'onipa: wedeε ani a εda so ne tipa',
    '🧑🏼‍🦲' => 'onipa: wedeε ani a εda so kakra ne tipa',
    '🧑🏽‍🦲' => 'onipa: wedeε ani a εda hᴐ kakra ne tipa',
    '🧑🏾‍🦲' => 'onipa: wedeε ani tuntum kakra ne tipa',
    '🧑🏿‍🦲' => 'onipa: wedeε ani tuntum ne tipa',
    '🧑🏻‍🩰' => 'balee safoᴐ: wedeε ani a εda so',
    '🧑🏼‍🩰' => 'balee safoᴐ: wedeε ani a εda so kakra',
    '🧑🏽‍🩰' => 'balee safoᴐ: wedeε ani a εda hᴐ kakra',
    '🧑🏾‍🩰' => 'balee safoᴐ: wedeε ani tuntum kakra',
    '🧑🏿‍🩰' => 'balee safoᴐ: wedeε ani tuntum',
    '🧔🏻‍♂' => 'barima: wedeε ani a εda so ne abodwesɛ',
    '🧔🏼‍♂' => 'barima: wedeε ani a εda so kakra ne abodwesɛ',
    '🧔🏽‍♂' => 'barima: wedeε ani a εda hᴐ kakra ne abodwesɛ',
    '🧔🏾‍♂' => 'barima: wedeε ani tuntum kakra ne abodwesɛ',
    '🧔🏿‍♂' => 'barima: wedeε ani tuntum ne abodwesɛ',
    '👱🏻‍♂' => 'barima: wedeε ani a εda so ne nwii kɔkɔɔ',
    '👱🏼‍♂' => 'barima: wedeε ani a εda so kakra ne nwii kɔkɔɔ',
    '👱🏽‍♂' => 'barima: wedeε ani a εda hᴐ kakra ne nwii kɔkɔɔ',
    '👱🏾‍♂' => 'barima: wedeε ani tuntum kakra ne nwii kɔkɔɔ',
    '👱🏿‍♂' => 'barima: wedeε ani tuntum ne nwii kɔkɔɔ',
    '👨🏻‍🦰' => 'ɔbarima: wedeε ani a εda so ne nwi kͻkͻͻ',
    '👨🏼‍🦰' => 'ɔbarima: wedeε ani a εda so kakra ne nwi kͻkͻͻ',
    '👨🏽‍🦰' => 'ɔbarima: wedeε ani a εda hᴐ kakra ne nwi kͻkͻͻ',
    '👨🏾‍🦰' => 'ɔbarima: wedeε ani tuntum kakra ne nwi kͻkͻͻ',
    '👨🏿‍🦰' => 'ɔbarima: wedeε ani tuntum ne nwi kͻkͻͻ',
    '👨🏻‍🦱' => 'ɔbarima: wedeε ani a εda so ne enwi a akyinkyim',
    '👨🏼‍🦱' => 'ɔbarima: wedeε ani a εda so kakra ne enwi a akyinkyim',
    '👨🏽‍🦱' => 'ɔbarima: wedeε ani a εda hᴐ kakra ne enwi a akyinkyim',
    '👨🏾‍🦱' => 'ɔbarima: wedeε ani tuntum kakra ne enwi a akyinkyim',
    '👨🏿‍🦱' => 'ɔbarima: wedeε ani tuntum ne enwi a akyinkyim',
    '👨🏻‍🦳' => 'ɔbarima: wedeε ani a εda so ne nwi fitaa',
    '👨🏼‍🦳' => 'ɔbarima: wedeε ani a εda so kakra ne nwi fitaa',
    '👨🏽‍🦳' => 'ɔbarima: wedeε ani a εda hᴐ kakra ne nwi fitaa',
    '👨🏾‍🦳' => 'ɔbarima: wedeε ani tuntum kakra ne nwi fitaa',
    '👨🏿‍🦳' => 'ɔbarima: wedeε ani tuntum ne nwi fitaa',
    '👨🏻‍🦲' => 'ɔbarima: wedeε ani a εda so ne tipa',
    '👨🏼‍🦲' => 'ɔbarima: wedeε ani a εda so kakra ne tipa',
    '👨🏽‍🦲' => 'ɔbarima: wedeε ani a εda hᴐ kakra ne tipa',
    '👨🏾‍🦲' => 'ɔbarima: wedeε ani tuntum kakra ne tipa',
    '👨🏿‍🦲' => 'ɔbarima: wedeε ani tuntum ne tipa',
    '🧔🏻‍♀' => 'ɔbaa: wedeε ani a εda so ne abodwesɛ',
    '🧔🏼‍♀' => 'ɔbaa: wedeε ani a εda so kakra ne abodwesɛ',
    '🧔🏽‍♀' => 'ɔbaa: wedeε ani a εda hᴐ kakra ne abodwesɛ',
    '🧔🏾‍♀' => 'ɔbaa: wedeε ani tuntum kakra ne abodwesɛ',
    '🧔🏿‍♀' => 'ɔbaa: wedeε ani tuntum ne abodwesɛ',
    '👱🏻‍♀' => 'ɔbaa: wedeε ani a εda so ne nwii kɔkɔɔ',
    '👱🏼‍♀' => 'ɔbaa: wedeε ani a εda so kakra ne nwii kɔkɔɔ',
    '👱🏽‍♀' => 'ɔbaa: wedeε ani a εda hᴐ kakra ne nwii kɔkɔɔ',
    '👱🏾‍♀' => 'ɔbaa: wedeε ani tuntum kakra ne nwii kɔkɔɔ',
    '👱🏿‍♀' => 'ɔbaa: wedeε ani tuntum ne nwii kɔkɔɔ',
    '👩🏻‍🦰' => 'maame: wedeε ani a εda so ne nwi kͻkͻͻ',
    '👩🏼‍🦰' => 'maame: wedeε ani a εda so kakra ne nwi kͻkͻͻ',
    '👩🏽‍🦰' => 'maame: wedeε ani a εda hᴐ kakra ne nwi kͻkͻͻ',
    '👩🏾‍🦰' => 'maame: wedeε ani tuntum kakra ne nwi kͻkͻͻ',
    '👩🏿‍🦰' => 'maame: wedeε ani tuntum ne nwi kͻkͻͻ',
    '👩🏻‍🦱' => 'maame: wedeε ani a εda so ne enwi a akyinkyim',
    '👩🏼‍🦱' => 'maame: wedeε ani a εda so kakra ne enwi a akyinkyim',
    '👩🏽‍🦱' => 'maame: wedeε ani a εda hᴐ kakra ne enwi a akyinkyim',
    '👩🏾‍🦱' => 'maame: wedeε ani tuntum kakra ne enwi a akyinkyim',
    '👩🏿‍🦱' => 'maame: wedeε ani tuntum ne enwi a akyinkyim',
    '👩🏻‍🦳' => 'maame: wedeε ani a εda so ne nwi fitaa',
    '👩🏼‍🦳' => 'maame: wedeε ani a εda so kakra ne nwi fitaa',
    '👩🏽‍🦳' => 'maame: wedeε ani a εda hᴐ kakra ne nwi fitaa',
    '👩🏾‍🦳' => 'maame: wedeε ani tuntum kakra ne nwi fitaa',
    '👩🏿‍🦳' => 'maame: wedeε ani tuntum ne nwi fitaa',
    '👩🏻‍🦲' => 'maame: wedeε ani a εda so ne tipa',
    '👩🏼‍🦲' => 'maame: wedeε ani a εda so kakra ne tipa',
    '👩🏽‍🦲' => 'maame: wedeε ani a εda hᴐ kakra ne tipa',
    '👩🏾‍🦲' => 'maame: wedeε ani tuntum kakra ne tipa',
    '👩🏿‍🦲' => 'maame: wedeε ani tuntum ne tipa',
    '🙍🏻‍♂' => 'barima remuna: wedeε ani a εda so',
    '🙍🏼‍♂' => 'barima remuna: wedeε ani a εda so kakra',
    '🙍🏽‍♂' => 'barima remuna: wedeε ani a εda hᴐ kakra',
    '🙍🏾‍♂' => 'barima remuna: wedeε ani tuntum kakra',
    '🙍🏿‍♂' => 'barima remuna: wedeε ani tuntum',
    '🙍🏻‍♀' => 'ɔbaa remuna: wedeε ani a εda so',
    '🙍🏼‍♀' => 'ɔbaa remuna: wedeε ani a εda so kakra',
    '🙍🏽‍♀' => 'ɔbaa remuna: wedeε ani a εda hᴐ kakra',
    '🙍🏾‍♀' => 'ɔbaa remuna: wedeε ani tuntum kakra',
    '🙍🏿‍♀' => 'ɔbaa remuna: wedeε ani tuntum',
    '🙎🏻‍♂' => 'barima pɔɔtine: wedeε ani a εda so',
    '🙎🏼‍♂' => 'barima pɔɔtine: wedeε ani a εda so kakra',
    '🙎🏽‍♂' => 'barima pɔɔtine: wedeε ani a εda hᴐ kakra',
    '🙎🏾‍♂' => 'barima pɔɔtine: wedeε ani tuntum kakra',
    '🙎🏿‍♂' => 'barima pɔɔtine: wedeε ani tuntum',
    '🙎🏻‍♀' => 'ɔbaa pɔɔtine: wedeε ani a εda so',
    '🙎🏼‍♀' => 'ɔbaa pɔɔtine: wedeε ani a εda so kakra',
    '🙎🏽‍♀' => 'ɔbaa pɔɔtine: wedeε ani a εda hᴐ kakra',
    '🙎🏾‍♀' => 'ɔbaa pɔɔtine: wedeε ani tuntum kakra',
    '🙎🏿‍♀' => 'ɔbaa pɔɔtine: wedeε ani tuntum',
    '🙅🏻‍♂' => 'barima reyɛ DAABI nsɛnkyerɛnne: wedeε ani a εda so',
    '🙅🏼‍♂' => 'barima reyɛ DAABI nsɛnkyerɛnne: wedeε ani a εda so kakra',
    '🙅🏽‍♂' => 'barima reyɛ DAABI nsɛnkyerɛnne: wedeε ani a εda hᴐ kakra',
    '🙅🏾‍♂' => 'barima reyɛ DAABI nsɛnkyerɛnne: wedeε ani tuntum kakra',
    '🙅🏿‍♂' => 'barima reyɛ DAABI nsɛnkyerɛnne: wedeε ani tuntum',
    '🙅🏻‍♀' => 'ɔbaa reyɛ DAABI nsɛnkyerɛnne: wedeε ani a εda so',
    '🙅🏼‍♀' => 'ɔbaa reyɛ DAABI nsɛnkyerɛnne: wedeε ani a εda so kakra',
    '🙅🏽‍♀' => 'ɔbaa reyɛ DAABI nsɛnkyerɛnne: wedeε ani a εda hᴐ kakra',
    '🙅🏾‍♀' => 'ɔbaa reyɛ DAABI nsɛnkyerɛnne: wedeε ani tuntum kakra',
    '🙅🏿‍♀' => 'ɔbaa reyɛ DAABI nsɛnkyerɛnne: wedeε ani tuntum',
    '🙆🏻‍♂' => 'barima reyɛ OK nsɛnkyerɛnne: wedeε ani a εda so',
    '🙆🏼‍♂' => 'barima reyɛ OK nsɛnkyerɛnne: wedeε ani a εda so kakra',
    '🙆🏽‍♂' => 'barima reyɛ OK nsɛnkyerɛnne: wedeε ani a εda hᴐ kakra',
    '🙆🏾‍♂' => 'barima reyɛ OK nsɛnkyerɛnne: wedeε ani tuntum kakra',
    '🙆🏿‍♂' => 'barima reyɛ OK nsɛnkyerɛnne: wedeε ani tuntum',
    '🙆🏻‍♀' => 'ɔbaa reyɛ OK nsɛnkyerɛnne: wedeε ani a εda so',
    '🙆🏼‍♀' => 'ɔbaa reyɛ OK nsɛnkyerɛnne: wedeε ani a εda so kakra',
    '🙆🏽‍♀' => 'ɔbaa reyɛ OK nsɛnkyerɛnne: wedeε ani a εda hᴐ kakra',
    '🙆🏾‍♀' => 'ɔbaa reyɛ OK nsɛnkyerɛnne: wedeε ani tuntum kakra',
    '🙆🏿‍♀' => 'ɔbaa reyɛ OK nsɛnkyerɛnne: wedeε ani tuntum',
    '💁🏻‍♂' => 'barima tiipi nsa: wedeε ani a εda so',
    '💁🏼‍♂' => 'barima tiipi nsa: wedeε ani a εda so kakra',
    '💁🏽‍♂' => 'barima tiipi nsa: wedeε ani a εda hᴐ kakra',
    '💁🏾‍♂' => 'barima tiipi nsa: wedeε ani tuntum kakra',
    '💁🏿‍♂' => 'barima tiipi nsa: wedeε ani tuntum',
    '💁🏻‍♀' => 'ɔbaa tiipi nsa: wedeε ani a εda so',
    '💁🏼‍♀' => 'ɔbaa tiipi nsa: wedeε ani a εda so kakra',
    '💁🏽‍♀' => 'ɔbaa tiipi nsa: wedeε ani a εda hᴐ kakra',
    '💁🏾‍♀' => 'ɔbaa tiipi nsa: wedeε ani tuntum kakra',
    '💁🏿‍♀' => 'ɔbaa tiipi nsa: wedeε ani tuntum',
    '🙋🏻‍♂' => 'barima repagya nsa: wedeε ani a εda so',
    '🙋🏼‍♂' => 'barima repagya nsa: wedeε ani a εda so kakra',
    '🙋🏽‍♂' => 'barima repagya nsa: wedeε ani a εda hᴐ kakra',
    '🙋🏾‍♂' => 'barima repagya nsa: wedeε ani tuntum kakra',
    '🙋🏿‍♂' => 'barima repagya nsa: wedeε ani tuntum',
    '🙋🏻‍♀' => 'ɔbaa repagya ne nsa: wedeε ani a εda so',
    '🙋🏼‍♀' => 'ɔbaa repagya ne nsa: wedeε ani a εda so kakra',
    '🙋🏽‍♀' => 'ɔbaa repagya ne nsa: wedeε ani a εda hᴐ kakra',
    '🙋🏾‍♀' => 'ɔbaa repagya ne nsa: wedeε ani tuntum kakra',
    '🙋🏿‍♀' => 'ɔbaa repagya ne nsa: wedeε ani tuntum',
    '🧏🏻‍♂' => 'mum barima: wedeε ani a εda so',
    '🧏🏼‍♂' => 'mum barima: wedeε ani a εda so kakra',
    '🧏🏽‍♂' => 'mum barima: wedeε ani a εda hᴐ kakra',
    '🧏🏾‍♂' => 'mum barima: wedeε ani tuntum kakra',
    '🧏🏿‍♂' => 'mum barima: wedeε ani tuntum',
    '🧏🏻‍♀' => 'ɔbaa mum: wedeε ani a εda so',
    '🧏🏼‍♀' => 'ɔbaa mum: wedeε ani a εda so kakra',
    '🧏🏽‍♀' => 'ɔbaa mum: wedeε ani a εda hᴐ kakra',
    '🧏🏾‍♀' => 'ɔbaa mum: wedeε ani tuntum kakra',
    '🧏🏿‍♀' => 'ɔbaa mum: wedeε ani tuntum',
    '🙇🏻‍♂' => 'barima rebɔ ne mu ase: wedeε ani a εda so',
    '🙇🏼‍♂' => 'barima rebɔ ne mu ase: wedeε ani a εda so kakra',
    '🙇🏽‍♂' => 'barima rebɔ ne mu ase: wedeε ani a εda hᴐ kakra',
    '🙇🏾‍♂' => 'barima rebɔ ne mu ase: wedeε ani tuntum kakra',
    '🙇🏿‍♂' => 'barima rebɔ ne mu ase: wedeε ani tuntum',
    '🙇🏻‍♀' => 'ɔbaa rebɔ ne mu ase: wedeε ani a εda so',
    '🙇🏼‍♀' => 'ɔbaa rebɔ ne mu ase: wedeε ani a εda so kakra',
    '🙇🏽‍♀' => 'ɔbaa rebɔ ne mu ase: wedeε ani a εda hᴐ kakra',
    '🙇🏾‍♀' => 'ɔbaa rebɔ ne mu ase: wedeε ani tuntum kakra',
    '🙇🏿‍♀' => 'ɔbaa rebɔ ne mu ase: wedeε ani tuntum',
    '🤦🏻‍♂' => 'barima de ne nsam ato n’anim: wedeε ani a εda so',
    '🤦🏼‍♂' => 'barima de ne nsam ato n’anim: wedeε ani a εda so kakra',
    '🤦🏽‍♂' => 'barima de ne nsam ato n’anim: wedeε ani a εda hᴐ kakra',
    '🤦🏾‍♂' => 'barima de ne nsam ato n’anim: wedeε ani tuntum kakra',
    '🤦🏿‍♂' => 'barima de ne nsam ato n’anim: wedeε ani tuntum',
    '🤦🏻‍♀' => 'ɔbaa de ne nsa rebɔ n’anim: wedeε ani a εda so',
    '🤦🏼‍♀' => 'ɔbaa de ne nsa rebɔ n’anim: wedeε ani a εda so kakra',
    '🤦🏽‍♀' => 'ɔbaa de ne nsa rebɔ n’anim: wedeε ani a εda hᴐ kakra',
    '🤦🏾‍♀' => 'ɔbaa de ne nsa rebɔ n’anim: wedeε ani tuntum kakra',
    '🤦🏿‍♀' => 'ɔbaa de ne nsa rebɔ n’anim: wedeε ani tuntum',
    '🤷🏻‍♂' => 'barima repagya ne mmati: wedeε ani a εda so',
    '🤷🏼‍♂' => 'barima repagya ne mmati: wedeε ani a εda so kakra',
    '🤷🏽‍♂' => 'barima repagya ne mmati: wedeε ani a εda hᴐ kakra',
    '🤷🏾‍♂' => 'barima repagya ne mmati: wedeε ani tuntum kakra',
    '🤷🏿‍♂' => 'barima repagya ne mmati: wedeε ani tuntum',
    '🤷🏻‍♀' => 'ɔbaa repagya ne mmati: wedeε ani a εda so',
    '🤷🏼‍♀' => 'ɔbaa repagya ne mmati: wedeε ani a εda so kakra',
    '🤷🏽‍♀' => 'ɔbaa repagya ne mmati: wedeε ani a εda hᴐ kakra',
    '🤷🏾‍♀' => 'ɔbaa repagya ne mmati: wedeε ani tuntum kakra',
    '🤷🏿‍♀' => 'ɔbaa repagya ne mmati: wedeε ani tuntum',
    '🧑🏻‍⚕' => 'apomuden dwumayɛfoɔ: wedeε ani a εda so',
    '🧑🏼‍⚕' => 'apomuden dwumayɛfoɔ: wedeε ani a εda so kakra',
    '🧑🏽‍⚕' => 'apomuden dwumayɛfoɔ: wedeε ani a εda hᴐ kakra',
    '🧑🏾‍⚕' => 'apomuden dwumayɛfoɔ: wedeε ani tuntum kakra',
    '🧑🏿‍⚕' => 'apomuden dwumayɛfoɔ: wedeε ani tuntum',
    '👨🏻‍⚕' => 'apomuden dwumayɛfoɔ barima: wedeε ani a εda so',
    '👨🏼‍⚕' => 'apomuden dwumayɛfoɔ barima: wedeε ani a εda so kakra',
    '👨🏽‍⚕' => 'apomuden dwumayɛfoɔ barima: wedeε ani a εda hᴐ kakra',
    '👨🏾‍⚕' => 'apomuden dwumayɛfoɔ barima: wedeε ani tuntum kakra',
    '👨🏿‍⚕' => 'apomuden dwumayɛfoɔ barima: wedeε ani tuntum',
    '👩🏻‍⚕' => 'apomuden dwumayɛfoɔ ɔbaa: wedeε ani a εda so',
    '👩🏼‍⚕' => 'apomuden dwumayɛfoɔ ɔbaa: wedeε ani a εda so kakra',
    '👩🏽‍⚕' => 'apomuden dwumayɛfoɔ ɔbaa: wedeε ani a εda hᴐ kakra',
    '👩🏾‍⚕' => 'apomuden dwumayɛfoɔ ɔbaa: wedeε ani tuntum kakra',
    '👩🏿‍⚕' => 'apomuden dwumayɛfoɔ ɔbaa: wedeε ani tuntum',
    '🧑🏻‍🎓' => 'sukuuni: wedeε ani a εda so',
    '🧑🏼‍🎓' => 'sukuuni: wedeε ani a εda so kakra',
    '🧑🏽‍🎓' => 'sukuuni: wedeε ani a εda hᴐ kakra',
    '🧑🏾‍🎓' => 'sukuuni: wedeε ani tuntum kakra',
    '🧑🏿‍🎓' => 'sukuuni: wedeε ani tuntum',
    '👨🏻‍🎓' => 'sukuuni barima: wedeε ani a εda so',
    '👨🏼‍🎓' => 'sukuuni barima: wedeε ani a εda so kakra',
    '👨🏽‍🎓' => 'sukuuni barima: wedeε ani a εda hᴐ kakra',
    '👨🏾‍🎓' => 'sukuuni barima: wedeε ani tuntum kakra',
    '👨🏿‍🎓' => 'sukuuni barima: wedeε ani tuntum',
    '👩🏻‍🎓' => 'sukuuni baa: wedeε ani a εda so',
    '👩🏼‍🎓' => 'sukuuni baa: wedeε ani a εda so kakra',
    '👩🏽‍🎓' => 'sukuuni baa: wedeε ani a εda hᴐ kakra',
    '👩🏾‍🎓' => 'sukuuni baa: wedeε ani tuntum kakra',
    '👩🏿‍🎓' => 'sukuuni baa: wedeε ani tuntum',
    '🧑🏻‍🏫' => 'tikya: wedeε ani a εda so',
    '🧑🏼‍🏫' => 'tikya: wedeε ani a εda so kakra',
    '🧑🏽‍🏫' => 'tikya: wedeε ani a εda hᴐ kakra',
    '🧑🏾‍🏫' => 'tikya: wedeε ani tuntum kakra',
    '🧑🏿‍🏫' => 'tikya: wedeε ani tuntum',
    '👨🏻‍🏫' => 'tikyani barima: wedeε ani a εda so',
    '👨🏼‍🏫' => 'tikyani barima: wedeε ani a εda so kakra',
    '👨🏽‍🏫' => 'tikyani barima: wedeε ani a εda hᴐ kakra',
    '👨🏾‍🏫' => 'tikyani barima: wedeε ani tuntum kakra',
    '👨🏿‍🏫' => 'tikyani barima: wedeε ani tuntum',
    '👩🏻‍🏫' => 'tikyani baa: wedeε ani a εda so',
    '👩🏼‍🏫' => 'tikyani baa: wedeε ani a εda so kakra',
    '👩🏽‍🏫' => 'tikyani baa: wedeε ani a εda hᴐ kakra',
    '👩🏾‍🏫' => 'tikyani baa: wedeε ani tuntum kakra',
    '👩🏿‍🏫' => 'tikyani baa: wedeε ani tuntum',
    '🧑🏻‍⚖' => 'gyaagye: wedeε ani a εda so',
    '🧑🏼‍⚖' => 'gyaagye: wedeε ani a εda so kakra',
    '🧑🏽‍⚖' => 'gyaagye: wedeε ani a εda hᴐ kakra',
    '🧑🏾‍⚖' => 'gyaagye: wedeε ani tuntum kakra',
    '🧑🏿‍⚖' => 'gyaagye: wedeε ani tuntum',
    '👨🏻‍⚖' => 'Barima gyaagye: wedeε ani a εda so',
    '👨🏼‍⚖' => 'Barima gyaagye: wedeε ani a εda so kakra',
    '👨🏽‍⚖' => 'Barima gyaagye: wedeε ani a εda hᴐ kakra',
    '👨🏾‍⚖' => 'Barima gyaagye: wedeε ani tuntum kakra',
    '👨🏿‍⚖' => 'Barima gyaagye: wedeε ani tuntum',
    '👩🏻‍⚖' => 'ɔbaa gyaagye: wedeε ani a εda so',
    '👩🏼‍⚖' => 'ɔbaa gyaagye: wedeε ani a εda so kakra',
    '👩🏽‍⚖' => 'ɔbaa gyaagye: wedeε ani a εda hᴐ kakra',
    '👩🏾‍⚖' => 'ɔbaa gyaagye: wedeε ani tuntum kakra',
    '👩🏿‍⚖' => 'ɔbaa gyaagye: wedeε ani tuntum',
    '🧑🏻‍🌾' => 'Okuani: wedeε ani a εda so',
    '🧑🏼‍🌾' => 'Okuani: wedeε ani a εda so kakra',
    '🧑🏽‍🌾' => 'Okuani: wedeε ani a εda hᴐ kakra',
    '🧑🏾‍🌾' => 'Okuani: wedeε ani tuntum kakra',
    '🧑🏿‍🌾' => 'Okuani: wedeε ani tuntum',
    '👨🏻‍🌾' => 'Okuani barima: wedeε ani a εda so',
    '👨🏼‍🌾' => 'Okuani barima: wedeε ani a εda so kakra',
    '👨🏽‍🌾' => 'Okuani barima: wedeε ani a εda hᴐ kakra',
    '👨🏾‍🌾' => 'Okuani barima: wedeε ani tuntum kakra',
    '👨🏿‍🌾' => 'Okuani barima: wedeε ani tuntum',
    '👩🏻‍🌾' => 'Okuani baa: wedeε ani a εda so',
    '👩🏼‍🌾' => 'Okuani baa: wedeε ani a εda so kakra',
    '👩🏽‍🌾' => 'Okuani baa: wedeε ani a εda hᴐ kakra',
    '👩🏾‍🌾' => 'Okuani baa: wedeε ani tuntum kakra',
    '👩🏿‍🌾' => 'Okuani baa: wedeε ani tuntum',
    '🧑🏻‍🍳' => 'kuk: wedeε ani a εda so',
    '🧑🏼‍🍳' => 'kuk: wedeε ani a εda so kakra',
    '🧑🏽‍🍳' => 'kuk: wedeε ani a εda hᴐ kakra',
    '🧑🏾‍🍳' => 'kuk: wedeε ani tuntum kakra',
    '🧑🏿‍🍳' => 'kuk: wedeε ani tuntum',
    '👨🏻‍🍳' => 'Barima kuk: wedeε ani a εda so',
    '👨🏼‍🍳' => 'Barima kuk: wedeε ani a εda so kakra',
    '👨🏽‍🍳' => 'Barima kuk: wedeε ani a εda hᴐ kakra',
    '👨🏾‍🍳' => 'Barima kuk: wedeε ani tuntum kakra',
    '👨🏿‍🍳' => 'Barima kuk: wedeε ani tuntum',
    '👩🏻‍🍳' => 'Ɔbaa kuk: wedeε ani a εda so',
    '👩🏼‍🍳' => 'Ɔbaa kuk: wedeε ani a εda so kakra',
    '👩🏽‍🍳' => 'Ɔbaa kuk: wedeε ani a εda hᴐ kakra',
    '👩🏾‍🍳' => 'Ɔbaa kuk: wedeε ani tuntum kakra',
    '👩🏿‍🍳' => 'Ɔbaa kuk: wedeε ani tuntum',
    '🧑🏻‍🔧' => 'Mɛkanike: wedeε ani a εda so',
    '🧑🏼‍🔧' => 'Mɛkanike: wedeε ani a εda so kakra',
    '🧑🏽‍🔧' => 'Mɛkanike: wedeε ani a εda hᴐ kakra',
    '🧑🏾‍🔧' => 'Mɛkanike: wedeε ani tuntum kakra',
    '🧑🏿‍🔧' => 'Mɛkanike: wedeε ani tuntum',
    '👨🏻‍🔧' => 'Barima mɛkanike: wedeε ani a εda so',
    '👨🏼‍🔧' => 'Barima mɛkanike: wedeε ani a εda so kakra',
    '👨🏽‍🔧' => 'Barima mɛkanike: wedeε ani a εda hᴐ kakra',
    '👨🏾‍🔧' => 'Barima mɛkanike: wedeε ani tuntum kakra',
    '👨🏿‍🔧' => 'Barima mɛkanike: wedeε ani tuntum',
    '👩🏻‍🔧' => 'Ɔbaa mɛkanike: wedeε ani a εda so',
    '👩🏼‍🔧' => 'Ɔbaa mɛkanike: wedeε ani a εda so kakra',
    '👩🏽‍🔧' => 'Ɔbaa mɛkanike: wedeε ani a εda hᴐ kakra',
    '👩🏾‍🔧' => 'Ɔbaa mɛkanike: wedeε ani tuntum kakra',
    '👩🏿‍🔧' => 'Ɔbaa mɛkanike: wedeε ani tuntum',
    '🧑🏻‍🏭' => 'Faktre dwumayɛni: wedeε ani a εda so',
    '🧑🏼‍🏭' => 'Faktre dwumayɛni: wedeε ani a εda so kakra',
    '🧑🏽‍🏭' => 'Faktre dwumayɛni: wedeε ani a εda hᴐ kakra',
    '🧑🏾‍🏭' => 'Faktre dwumayɛni: wedeε ani tuntum kakra',
    '🧑🏿‍🏭' => 'Faktre dwumayɛni: wedeε ani tuntum',
    '👨🏻‍🏭' => 'Faktre dwumayɛni barima: wedeε ani a εda so',
    '👨🏼‍🏭' => 'Faktre dwumayɛni barima: wedeε ani a εda so kakra',
    '👨🏽‍🏭' => 'Faktre dwumayɛni barima: wedeε ani a εda hᴐ kakra',
    '👨🏾‍🏭' => 'Faktre dwumayɛni barima: wedeε ani tuntum kakra',
    '👨🏿‍🏭' => 'Faktre dwumayɛni barima: wedeε ani tuntum',
    '👩🏻‍🏭' => 'Faktre dwumayɛni baa: wedeε ani a εda so',
    '👩🏼‍🏭' => 'Faktre dwumayɛni baa: wedeε ani a εda so kakra',
    '👩🏽‍🏭' => 'Faktre dwumayɛni baa: wedeε ani a εda hᴐ kakra',
    '👩🏾‍🏭' => 'Faktre dwumayɛni baa: wedeε ani tuntum kakra',
    '👩🏿‍🏭' => 'Faktre dwumayɛni baa: wedeε ani tuntum',
    '🧑🏻‍💼' => 'ɔfese dwumayɛni: wedeε ani a εda so',
    '🧑🏼‍💼' => 'ɔfese dwumayɛni: wedeε ani a εda so kakra',
    '🧑🏽‍💼' => 'ɔfese dwumayɛni: wedeε ani a εda hᴐ kakra',
    '🧑🏾‍💼' => 'ɔfese dwumayɛni: wedeε ani tuntum kakra',
    '🧑🏿‍💼' => 'ɔfese dwumayɛni: wedeε ani tuntum',
    '👨🏻‍💼' => 'ɔfese dwumayɛni barima: wedeε ani a εda so',
    '👨🏼‍💼' => 'ɔfese dwumayɛni barima: wedeε ani a εda so kakra',
    '👨🏽‍💼' => 'ɔfese dwumayɛni barima: wedeε ani a εda hᴐ kakra',
    '👨🏾‍💼' => 'ɔfese dwumayɛni barima: wedeε ani tuntum kakra',
    '👨🏿‍💼' => 'ɔfese dwumayɛni barima: wedeε ani tuntum',
    '👩🏻‍💼' => 'Ɔfese dwumayɛni baa: wedeε ani a εda so',
    '👩🏼‍💼' => 'Ɔfese dwumayɛni baa: wedeε ani a εda so kakra',
    '👩🏽‍💼' => 'Ɔfese dwumayɛni baa: wedeε ani a εda hᴐ kakra',
    '👩🏾‍💼' => 'Ɔfese dwumayɛni baa: wedeε ani tuntum kakra',
    '👩🏿‍💼' => 'Ɔfese dwumayɛni baa: wedeε ani tuntum',
    '🧑🏻‍🔬' => 'Seantise: wedeε ani a εda so',
    '🧑🏼‍🔬' => 'Seantise: wedeε ani a εda so kakra',
    '🧑🏽‍🔬' => 'Seantise: wedeε ani a εda hᴐ kakra',
    '🧑🏾‍🔬' => 'Seantise: wedeε ani tuntum kakra',
    '🧑🏿‍🔬' => 'Seantise: wedeε ani tuntum',
    '👨🏻‍🔬' => 'Seantise barima: wedeε ani a εda so',
    '👨🏼‍🔬' => 'Seantise barima: wedeε ani a εda so kakra',
    '👨🏽‍🔬' => 'Seantise barima: wedeε ani a εda hᴐ kakra',
    '👨🏾‍🔬' => 'Seantise barima: wedeε ani tuntum kakra',
    '👨🏿‍🔬' => 'Seantise barima: wedeε ani tuntum',
    '👩🏻‍🔬' => 'Seantise ɔbaa: wedeε ani a εda so',
    '👩🏼‍🔬' => 'Seantise ɔbaa: wedeε ani a εda so kakra',
    '👩🏽‍🔬' => 'Seantise ɔbaa: wedeε ani a εda hᴐ kakra',
    '👩🏾‍🔬' => 'Seantise ɔbaa: wedeε ani tuntum kakra',
    '👩🏿‍🔬' => 'Seantise ɔbaa: wedeε ani tuntum',
    '🧑🏻‍💻' => 'tɛknologiste: wedeε ani a εda so',
    '🧑🏼‍💻' => 'tɛknologiste: wedeε ani a εda so kakra',
    '🧑🏽‍💻' => 'tɛknologiste: wedeε ani a εda hᴐ kakra',
    '🧑🏾‍💻' => 'tɛknologiste: wedeε ani tuntum kakra',
    '🧑🏿‍💻' => 'tɛknologiste: wedeε ani tuntum',
    '👨🏻‍💻' => 'Tɛknologiste barima: wedeε ani a εda so',
    '👨🏼‍💻' => 'Tɛknologiste barima: wedeε ani a εda so kakra',
    '👨🏽‍💻' => 'Tɛknologiste barima: wedeε ani a εda hᴐ kakra',
    '👨🏾‍💻' => 'Tɛknologiste barima: wedeε ani tuntum kakra',
    '👨🏿‍💻' => 'Tɛknologiste barima: wedeε ani tuntum',
    '👩🏻‍💻' => 'Tɛknologiste ɔbaa: wedeε ani a εda so',
    '👩🏼‍💻' => 'Tɛknologiste ɔbaa: wedeε ani a εda so kakra',
    '👩🏽‍💻' => 'Tɛknologiste ɔbaa: wedeε ani a εda hᴐ kakra',
    '👩🏾‍💻' => 'Tɛknologiste ɔbaa: wedeε ani tuntum kakra',
    '👩🏿‍💻' => 'Tɛknologiste ɔbaa: wedeε ani tuntum',
    '🧑🏻‍🎤' => 'Nnwomtoni: wedeε ani a εda so',
    '🧑🏼‍🎤' => 'Nnwomtoni: wedeε ani a εda so kakra',
    '🧑🏽‍🎤' => 'Nnwomtoni: wedeε ani a εda hᴐ kakra',
    '🧑🏾‍🎤' => 'Nnwomtoni: wedeε ani tuntum kakra',
    '🧑🏿‍🎤' => 'Nnwomtoni: wedeε ani tuntum',
    '👨🏻‍🎤' => 'Nnwomtoni barima: wedeε ani a εda so',
    '👨🏼‍🎤' => 'Nnwomtoni barima: wedeε ani a εda so kakra',
    '👨🏽‍🎤' => 'Nnwomtoni barima: wedeε ani a εda hᴐ kakra',
    '👨🏾‍🎤' => 'Nnwomtoni barima: wedeε ani tuntum kakra',
    '👨🏿‍🎤' => 'Nnwomtoni barima: wedeε ani tuntum',
    '👩🏻‍🎤' => 'Nnwomtoni baa: wedeε ani a εda so',
    '👩🏼‍🎤' => 'Nnwomtoni baa: wedeε ani a εda so kakra',
    '👩🏽‍🎤' => 'Nnwomtoni baa: wedeε ani a εda hᴐ kakra',
    '👩🏾‍🎤' => 'Nnwomtoni baa: wedeε ani tuntum kakra',
    '👩🏿‍🎤' => 'Nnwomtoni baa: wedeε ani tuntum',
    '🧑🏻‍🎨' => 'Aatise: wedeε ani a εda so',
    '🧑🏼‍🎨' => 'Aatise: wedeε ani a εda so kakra',
    '🧑🏽‍🎨' => 'Aatise: wedeε ani a εda hᴐ kakra',
    '🧑🏾‍🎨' => 'Aatise: wedeε ani tuntum kakra',
    '🧑🏿‍🎨' => 'Aatise: wedeε ani tuntum',
    '👨🏻‍🎨' => 'Aatise barima: wedeε ani a εda so',
    '👨🏼‍🎨' => 'Aatise barima: wedeε ani a εda so kakra',
    '👨🏽‍🎨' => 'Aatise barima: wedeε ani a εda hᴐ kakra',
    '👨🏾‍🎨' => 'Aatise barima: wedeε ani tuntum kakra',
    '👨🏿‍🎨' => 'Aatise barima: wedeε ani tuntum',
    '👩🏻‍🎨' => 'Aatise ɔbaa: wedeε ani a εda so',
    '👩🏼‍🎨' => 'Aatise ɔbaa: wedeε ani a εda so kakra',
    '👩🏽‍🎨' => 'Aatise ɔbaa: wedeε ani a εda hᴐ kakra',
    '👩🏾‍🎨' => 'Aatise ɔbaa: wedeε ani tuntum kakra',
    '👩🏿‍🎨' => 'Aatise ɔbaa: wedeε ani tuntum',
    '🧑🏻‍✈' => 'Pailɔt: wedeε ani a εda so',
    '🧑🏼‍✈' => 'Pailɔt: wedeε ani a εda so kakra',
    '🧑🏽‍✈' => 'Pailɔt: wedeε ani a εda hᴐ kakra',
    '🧑🏾‍✈' => 'Pailɔt: wedeε ani tuntum kakra',
    '🧑🏿‍✈' => 'Pailɔt: wedeε ani tuntum',
    '👨🏻‍✈' => 'Barima pailɔt: wedeε ani a εda so',
    '👨🏼‍✈' => 'Barima pailɔt: wedeε ani a εda so kakra',
    '👨🏽‍✈' => 'Barima pailɔt: wedeε ani a εda hᴐ kakra',
    '👨🏾‍✈' => 'Barima pailɔt: wedeε ani tuntum kakra',
    '👨🏿‍✈' => 'Barima pailɔt: wedeε ani tuntum',
    '👩🏻‍✈' => 'Pailɔt ɔbaa: wedeε ani a εda so',
    '👩🏼‍✈' => 'Pailɔt ɔbaa: wedeε ani a εda so kakra',
    '👩🏽‍✈' => 'Pailɔt ɔbaa: wedeε ani a εda hᴐ kakra',
    '👩🏾‍✈' => 'Pailɔt ɔbaa: wedeε ani tuntum kakra',
    '👩🏿‍✈' => 'Pailɔt ɔbaa: wedeε ani tuntum',
    '🧑🏻‍🚀' => 'Astrɔnɔt: wedeε ani a εda so',
    '🧑🏼‍🚀' => 'Astrɔnɔt: wedeε ani a εda so kakra',
    '🧑🏽‍🚀' => 'Astrɔnɔt: wedeε ani a εda hᴐ kakra',
    '🧑🏾‍🚀' => 'Astrɔnɔt: wedeε ani tuntum kakra',
    '🧑🏿‍🚀' => 'Astrɔnɔt: wedeε ani tuntum',
    '👨🏻‍🚀' => 'Astrɔnɔt barima: wedeε ani a εda so',
    '👨🏼‍🚀' => 'Astrɔnɔt barima: wedeε ani a εda so kakra',
    '👨🏽‍🚀' => 'Astrɔnɔt barima: wedeε ani a εda hᴐ kakra',
    '👨🏾‍🚀' => 'Astrɔnɔt barima: wedeε ani tuntum kakra',
    '👨🏿‍🚀' => 'Astrɔnɔt barima: wedeε ani tuntum',
    '👩🏻‍🚀' => 'Astrɔnɔto ɔbaa: wedeε ani a εda so',
    '👩🏼‍🚀' => 'Astrɔnɔto ɔbaa: wedeε ani a εda so kakra',
    '👩🏽‍🚀' => 'Astrɔnɔto ɔbaa: wedeε ani a εda hᴐ kakra',
    '👩🏾‍🚀' => 'Astrɔnɔto ɔbaa: wedeε ani tuntum kakra',
    '👩🏿‍🚀' => 'Astrɔnɔto ɔbaa: wedeε ani tuntum',
    '🧑🏻‍🚒' => 'Gyadumfoɔ: wedeε ani a εda so',
    '🧑🏼‍🚒' => 'Gyadumfoɔ: wedeε ani a εda so kakra',
    '🧑🏽‍🚒' => 'Gyadumfoɔ: wedeε ani a εda hᴐ kakra',
    '🧑🏾‍🚒' => 'Gyadumfoɔ: wedeε ani tuntum kakra',
    '🧑🏿‍🚒' => 'Gyadumfoɔ: wedeε ani tuntum',
    '👨🏻‍🚒' => 'Barima gyadumfoɔ: wedeε ani a εda so',
    '👨🏼‍🚒' => 'Barima gyadumfoɔ: wedeε ani a εda so kakra',
    '👨🏽‍🚒' => 'Barima gyadumfoɔ: wedeε ani a εda hᴐ kakra',
    '👨🏾‍🚒' => 'Barima gyadumfoɔ: wedeε ani tuntum kakra',
    '👨🏿‍🚒' => 'Barima gyadumfoɔ: wedeε ani tuntum',
    '👩🏻‍🚒' => 'Ɔbaa gyadumfoɔ: wedeε ani a εda so',
    '👩🏼‍🚒' => 'Ɔbaa gyadumfoɔ: wedeε ani a εda so kakra',
    '👩🏽‍🚒' => 'Ɔbaa gyadumfoɔ: wedeε ani a εda hᴐ kakra',
    '👩🏾‍🚒' => 'Ɔbaa gyadumfoɔ: wedeε ani tuntum kakra',
    '👩🏿‍🚒' => 'Ɔbaa gyadumfoɔ: wedeε ani tuntum',
    '👮🏻‍♂' => 'Polisi ɔfesa barima: wedeε ani a εda so',
    '👮🏼‍♂' => 'Polisi ɔfesa barima: wedeε ani a εda so kakra',
    '👮🏽‍♂' => 'Polisi ɔfesa barima: wedeε ani a εda hᴐ kakra',
    '👮🏾‍♂' => 'Polisi ɔfesa barima: wedeε ani tuntum kakra',
    '👮🏿‍♂' => 'Polisi ɔfesa barima: wedeε ani tuntum',
    '👮🏻‍♀' => 'Polisi ɔfesa ɔbaa: wedeε ani a εda so',
    '👮🏼‍♀' => 'Polisi ɔfesa ɔbaa: wedeε ani a εda so kakra',
    '👮🏽‍♀' => 'Polisi ɔfesa ɔbaa: wedeε ani a εda hᴐ kakra',
    '👮🏾‍♀' => 'Polisi ɔfesa ɔbaa: wedeε ani tuntum kakra',
    '👮🏿‍♀' => 'Polisi ɔfesa ɔbaa: wedeε ani tuntum',
    '🕵🏻‍♂' => 'Detɛketifo barima: wedeε ani a εda so',
    '🕵🏼‍♂' => 'Detɛketifo barima: wedeε ani a εda so kakra',
    '🕵🏽‍♂' => 'Detɛketifo barima: wedeε ani a εda hᴐ kakra',
    '🕵🏾‍♂' => 'Detɛketifo barima: wedeε ani tuntum kakra',
    '🕵🏿‍♂' => 'Detɛketifo barima: wedeε ani tuntum',
    '🕵🏻‍♀' => 'Detɛketifo ɔbaa: wedeε ani a εda so',
    '🕵🏼‍♀' => 'Detɛketifo ɔbaa: wedeε ani a εda so kakra',
    '🕵🏽‍♀' => 'Detɛketifo ɔbaa: wedeε ani a εda hᴐ kakra',
    '🕵🏾‍♀' => 'Detɛketifo ɔbaa: wedeε ani tuntum kakra',
    '🕵🏿‍♀' => 'Detɛketifo ɔbaa: wedeε ani tuntum',
    '💂🏻‍♂' => 'Barima banbɔfo: wedeε ani a εda so',
    '💂🏼‍♂' => 'Barima banbɔfo: wedeε ani a εda so kakra',
    '💂🏽‍♂' => 'Barima banbɔfo: wedeε ani a εda hᴐ kakra',
    '💂🏾‍♂' => 'Barima banbɔfo: wedeε ani tuntum kakra',
    '💂🏿‍♂' => 'Barima banbɔfo: wedeε ani tuntum',
    '💂🏻‍♀' => 'Ɔbaa banbɔfo: wedeε ani a εda so',
    '💂🏼‍♀' => 'Ɔbaa banbɔfo: wedeε ani a εda so kakra',
    '💂🏽‍♀' => 'Ɔbaa banbɔfo: wedeε ani a εda hᴐ kakra',
    '💂🏾‍♀' => 'Ɔbaa banbɔfo: wedeε ani tuntum kakra',
    '💂🏿‍♀' => 'Ɔbaa banbɔfo: wedeε ani tuntum',
    '👷🏻‍♂' => 'Adansie dwumayɛni barima: wedeε ani a εda so',
    '👷🏼‍♂' => 'Adansie dwumayɛni barima: wedeε ani a εda so kakra',
    '👷🏽‍♂' => 'Adansie dwumayɛni barima: wedeε ani a εda hᴐ kakra',
    '👷🏾‍♂' => 'Adansie dwumayɛni barima: wedeε ani tuntum kakra',
    '👷🏿‍♂' => 'Adansie dwumayɛni barima: wedeε ani tuntum',
    '👷🏻‍♀' => 'Adansie dwumayɛni baa: wedeε ani a εda so',
    '👷🏼‍♀' => 'Adansie dwumayɛni baa: wedeε ani a εda so kakra',
    '👷🏽‍♀' => 'Adansie dwumayɛni baa: wedeε ani a εda hᴐ kakra',
    '👷🏾‍♀' => 'Adansie dwumayɛni baa: wedeε ani tuntum kakra',
    '👷🏿‍♀' => 'Adansie dwumayɛni baa: wedeε ani tuntum',
    '👳🏻‍♂' => 'Barima hyɛ tɛɛban: wedeε ani a εda so',
    '👳🏼‍♂' => 'Barima hyɛ tɛɛban: wedeε ani a εda so kakra',
    '👳🏽‍♂' => 'Barima hyɛ tɛɛban: wedeε ani a εda hᴐ kakra',
    '👳🏾‍♂' => 'Barima hyɛ tɛɛban: wedeε ani tuntum kakra',
    '👳🏿‍♂' => 'Barima hyɛ tɛɛban: wedeε ani tuntum',
    '👳🏻‍♀' => 'ɔbaa a ɔhyɛ tɛɛban: wedeε ani a εda so',
    '👳🏼‍♀' => 'ɔbaa a ɔhyɛ tɛɛban: wedeε ani a εda so kakra',
    '👳🏽‍♀' => 'ɔbaa a ɔhyɛ tɛɛban: wedeε ani a εda hᴐ kakra',
    '👳🏾‍♀' => 'ɔbaa a ɔhyɛ tɛɛban: wedeε ani tuntum kakra',
    '👳🏿‍♀' => 'ɔbaa a ɔhyɛ tɛɛban: wedeε ani tuntum',
    '🤵🏻‍♂' => 'Barima a ɔhyɛ tɔseedo: wedeε ani a εda so',
    '🤵🏼‍♂' => 'Barima a ɔhyɛ tɔseedo: wedeε ani a εda so kakra',
    '🤵🏽‍♂' => 'Barima a ɔhyɛ tɔseedo: wedeε ani a εda hᴐ kakra',
    '🤵🏾‍♂' => 'Barima a ɔhyɛ tɔseedo: wedeε ani tuntum kakra',
    '🤵🏿‍♂' => 'Barima a ɔhyɛ tɔseedo: wedeε ani tuntum',
    '🤵🏻‍♀' => 'Ɔbaa a ɔhyɛ tɔseedo: wedeε ani a εda so',
    '🤵🏼‍♀' => 'Ɔbaa a ɔhyɛ tɔseedo: wedeε ani a εda so kakra',
    '🤵🏽‍♀' => 'Ɔbaa a ɔhyɛ tɔseedo: wedeε ani a εda hᴐ kakra',
    '🤵🏾‍♀' => 'Ɔbaa a ɔhyɛ tɔseedo: wedeε ani tuntum kakra',
    '🤵🏿‍♀' => 'Ɔbaa a ɔhyɛ tɔseedo: wedeε ani tuntum',
    '👰🏻‍♂' => 'Barima ne veil: wedeε ani a εda so',
    '👰🏼‍♂' => 'Barima ne veil: wedeε ani a εda so kakra',
    '👰🏽‍♂' => 'Barima ne veil: wedeε ani a εda hᴐ kakra',
    '👰🏾‍♂' => 'Barima ne veil: wedeε ani tuntum kakra',
    '👰🏿‍♂' => 'Barima ne veil: wedeε ani tuntum',
    '👰🏻‍♀' => 'Ɔbaa ne veil: wedeε ani a εda so',
    '👰🏼‍♀' => 'Ɔbaa ne veil: wedeε ani a εda so kakra',
    '👰🏽‍♀' => 'Ɔbaa ne veil: wedeε ani a εda hᴐ kakra',
    '👰🏾‍♀' => 'Ɔbaa ne veil: wedeε ani tuntum kakra',
    '👰🏿‍♀' => 'Ɔbaa ne veil: wedeε ani tuntum',
    '👩🏻‍🍼' => 'Ɔbaa rema akwadaa aduane: wedeε ani a εda so',
    '👩🏼‍🍼' => 'Ɔbaa rema akwadaa aduane: wedeε ani a εda so kakra',
    '👩🏽‍🍼' => 'Ɔbaa rema akwadaa aduane: wedeε ani a εda hᴐ kakra',
    '👩🏾‍🍼' => 'Ɔbaa rema akwadaa aduane: wedeε ani tuntum kakra',
    '👩🏿‍🍼' => 'Ɔbaa rema akwadaa aduane: wedeε ani tuntum',
    '👨🏻‍🍼' => 'Barima rema akwadaa aduane: wedeε ani a εda so',
    '👨🏼‍🍼' => 'Barima rema akwadaa aduane: wedeε ani a εda so kakra',
    '👨🏽‍🍼' => 'Barima rema akwadaa aduane: wedeε ani a εda hᴐ kakra',
    '👨🏾‍🍼' => 'Barima rema akwadaa aduane: wedeε ani tuntum kakra',
    '👨🏿‍🍼' => 'Barima rema akwadaa aduane: wedeε ani tuntum',
    '🧑🏻‍🍼' => 'obi rema akwadaa nufoɔ: wedeε ani a εda so',
    '🧑🏼‍🍼' => 'obi rema akwadaa nufoɔ: wedeε ani a εda so kakra',
    '🧑🏽‍🍼' => 'obi rema akwadaa nufoɔ: wedeε ani a εda hᴐ kakra',
    '🧑🏾‍🍼' => 'obi rema akwadaa nufoɔ: wedeε ani tuntum kakra',
    '🧑🏿‍🍼' => 'obi rema akwadaa nufoɔ: wedeε ani tuntum',
    '🧑🏻‍🎄' => 'Mx Klauso: wedeε ani a εda so',
    '🧑🏼‍🎄' => 'Mx Klauso: wedeε ani a εda so kakra',
    '🧑🏽‍🎄' => 'Mx Klauso: wedeε ani a εda hᴐ kakra',
    '🧑🏾‍🎄' => 'Mx Klauso: wedeε ani tuntum kakra',
    '🧑🏿‍🎄' => 'Mx Klauso: wedeε ani tuntum',
    '🦸🏻‍♂' => 'Supahero barima: wedeε ani a εda so',
    '🦸🏼‍♂' => 'Supahero barima: wedeε ani a εda so kakra',
    '🦸🏽‍♂' => 'Supahero barima: wedeε ani a εda hᴐ kakra',
    '🦸🏾‍♂' => 'Supahero barima: wedeε ani tuntum kakra',
    '🦸🏿‍♂' => 'Supahero barima: wedeε ani tuntum',
    '🦸🏻‍♀' => 'Supahero ɔbaa: wedeε ani a εda so',
    '🦸🏼‍♀' => 'Supahero ɔbaa: wedeε ani a εda so kakra',
    '🦸🏽‍♀' => 'Supahero ɔbaa: wedeε ani a εda hᴐ kakra',
    '🦸🏾‍♀' => 'Supahero ɔbaa: wedeε ani tuntum kakra',
    '🦸🏿‍♀' => 'Supahero ɔbaa: wedeε ani tuntum',
    '🦹🏻‍♂' => 'Supaviliane barima: wedeε ani a εda so',
    '🦹🏼‍♂' => 'Supaviliane barima: wedeε ani a εda so kakra',
    '🦹🏽‍♂' => 'Supaviliane barima: wedeε ani a εda hᴐ kakra',
    '🦹🏾‍♂' => 'Supaviliane barima: wedeε ani tuntum kakra',
    '🦹🏿‍♂' => 'Supaviliane barima: wedeε ani tuntum',
    '🦹🏻‍♀' => 'Supaviliane ɔbaa: wedeε ani a εda so',
    '🦹🏼‍♀' => 'Supaviliane ɔbaa: wedeε ani a εda so kakra',
    '🦹🏽‍♀' => 'Supaviliane ɔbaa: wedeε ani a εda hᴐ kakra',
    '🦹🏾‍♀' => 'Supaviliane ɔbaa: wedeε ani tuntum kakra',
    '🦹🏿‍♀' => 'Supaviliane ɔbaa: wedeε ani tuntum',
    '🧙🏻‍♂' => 'barima nknyaayifoͻ: wedeε ani a εda so',
    '🧙🏼‍♂' => 'barima nknyaayifoͻ: wedeε ani a εda so kakra',
    '🧙🏽‍♂' => 'barima nknyaayifoͻ: wedeε ani a εda hᴐ kakra',
    '🧙🏾‍♂' => 'barima nknyaayifoͻ: wedeε ani tuntum kakra',
    '🧙🏿‍♂' => 'barima nknyaayifoͻ: wedeε ani tuntum',
    '🧙🏻‍♀' => 'ͻbaa nkonyaayifoͻ: wedeε ani a εda so',
    '🧙🏼‍♀' => 'ͻbaa nkonyaayifoͻ: wedeε ani a εda so kakra',
    '🧙🏽‍♀' => 'ͻbaa nkonyaayifoͻ: wedeε ani a εda hᴐ kakra',
    '🧙🏾‍♀' => 'ͻbaa nkonyaayifoͻ: wedeε ani tuntum kakra',
    '🧙🏿‍♀' => 'ͻbaa nkonyaayifoͻ: wedeε ani tuntum',
    '🧚🏻‍♂' => 'Fɛɛre barima: wedeε ani a εda so',
    '🧚🏼‍♂' => 'Fɛɛre barima: wedeε ani a εda so kakra',
    '🧚🏽‍♂' => 'Fɛɛre barima: wedeε ani a εda hᴐ kakra',
    '🧚🏾‍♂' => 'Fɛɛre barima: wedeε ani tuntum kakra',
    '🧚🏿‍♂' => 'Fɛɛre barima: wedeε ani tuntum',
    '🧚🏻‍♀' => 'Ɔbaa fɛɛre: wedeε ani a εda so',
    '🧚🏼‍♀' => 'Ɔbaa fɛɛre: wedeε ani a εda so kakra',
    '🧚🏽‍♀' => 'Ɔbaa fɛɛre: wedeε ani a εda hᴐ kakra',
    '🧚🏾‍♀' => 'Ɔbaa fɛɛre: wedeε ani tuntum kakra',
    '🧚🏿‍♀' => 'Ɔbaa fɛɛre: wedeε ani tuntum',
    '🧛🏻‍♂' => 'Barima vampaya: wedeε ani a εda so',
    '🧛🏼‍♂' => 'Barima vampaya: wedeε ani a εda so kakra',
    '🧛🏽‍♂' => 'Barima vampaya: wedeε ani a εda hᴐ kakra',
    '🧛🏾‍♂' => 'Barima vampaya: wedeε ani tuntum kakra',
    '🧛🏿‍♂' => 'Barima vampaya: wedeε ani tuntum',
    '🧛🏻‍♀' => 'Ɔbaa vampaya: wedeε ani a εda so',
    '🧛🏼‍♀' => 'Ɔbaa vampaya: wedeε ani a εda so kakra',
    '🧛🏽‍♀' => 'Ɔbaa vampaya: wedeε ani a εda hᴐ kakra',
    '🧛🏾‍♀' => 'Ɔbaa vampaya: wedeε ani tuntum kakra',
    '🧛🏿‍♀' => 'Ɔbaa vampaya: wedeε ani tuntum',
    '🧜🏻‍♂' => 'Mɛɛbarima: wedeε ani a εda so',
    '🧜🏼‍♂' => 'Mɛɛbarima: wedeε ani a εda so kakra',
    '🧜🏽‍♂' => 'Mɛɛbarima: wedeε ani a εda hᴐ kakra',
    '🧜🏾‍♂' => 'Mɛɛbarima: wedeε ani tuntum kakra',
    '🧜🏿‍♂' => 'Mɛɛbarima: wedeε ani tuntum',
    '🧜🏻‍♀' => 'Mɛɛmeede: wedeε ani a εda so',
    '🧜🏼‍♀' => 'Mɛɛmeede: wedeε ani a εda so kakra',
    '🧜🏽‍♀' => 'Mɛɛmeede: wedeε ani a εda hᴐ kakra',
    '🧜🏾‍♀' => 'Mɛɛmeede: wedeε ani tuntum kakra',
    '🧜🏿‍♀' => 'Mɛɛmeede: wedeε ani tuntum',
    '🧝🏻‍♂' => 'Ɛlefo barima: wedeε ani a εda so',
    '🧝🏼‍♂' => 'Ɛlefo barima: wedeε ani a εda so kakra',
    '🧝🏽‍♂' => 'Ɛlefo barima: wedeε ani a εda hᴐ kakra',
    '🧝🏾‍♂' => 'Ɛlefo barima: wedeε ani tuntum kakra',
    '🧝🏿‍♂' => 'Ɛlefo barima: wedeε ani tuntum',
    '🧝🏻‍♀' => 'Ɛlefo ɔbaa: wedeε ani a εda so',
    '🧝🏼‍♀' => 'Ɛlefo ɔbaa: wedeε ani a εda so kakra',
    '🧝🏽‍♀' => 'Ɛlefo ɔbaa: wedeε ani a εda hᴐ kakra',
    '🧝🏾‍♀' => 'Ɛlefo ɔbaa: wedeε ani tuntum kakra',
    '🧝🏿‍♀' => 'Ɛlefo ɔbaa: wedeε ani tuntum',
    '💆🏻‍♂' => 'Barima renya amiamia: wedeε ani a εda so',
    '💆🏼‍♂' => 'Barima renya amiamia: wedeε ani a εda so kakra',
    '💆🏽‍♂' => 'Barima renya amiamia: wedeε ani a εda hᴐ kakra',
    '💆🏾‍♂' => 'Barima renya amiamia: wedeε ani tuntum kakra',
    '💆🏿‍♂' => 'Barima renya amiamia: wedeε ani tuntum',
    '💆🏻‍♀' => 'Ɔbaa renya amiamia: wedeε ani a εda so',
    '💆🏼‍♀' => 'Ɔbaa renya amiamia: wedeε ani a εda so kakra',
    '💆🏽‍♀' => 'Ɔbaa renya amiamia: wedeε ani a εda hᴐ kakra',
    '💆🏾‍♀' => 'Ɔbaa renya amiamia: wedeε ani tuntum kakra',
    '💆🏿‍♀' => 'Ɔbaa renya amiamia: wedeε ani tuntum',
    '💇🏻‍♂' => 'Wɔretwa barima nwii: wedeε ani a εda so',
    '💇🏼‍♂' => 'Wɔretwa barima nwii: wedeε ani a εda so kakra',
    '💇🏽‍♂' => 'Wɔretwa barima nwii: wedeε ani a εda hᴐ kakra',
    '💇🏾‍♂' => 'Wɔretwa barima nwii: wedeε ani tuntum kakra',
    '💇🏿‍♂' => 'Wɔretwa barima nwii: wedeε ani tuntum',
    '💇🏻‍♀' => 'Wɔretwa ɔbaa nwii: wedeε ani a εda so',
    '💇🏼‍♀' => 'Wɔretwa ɔbaa nwii: wedeε ani a εda so kakra',
    '💇🏽‍♀' => 'Wɔretwa ɔbaa nwii: wedeε ani a εda hᴐ kakra',
    '💇🏾‍♀' => 'Wɔretwa ɔbaa nwii: wedeε ani tuntum kakra',
    '💇🏿‍♀' => 'Wɔretwa ɔbaa nwii: wedeε ani tuntum',
    '🚶🏻‍♂' => 'Barima renante: wedeε ani a εda so',
    '🚶🏼‍♂' => 'Barima renante: wedeε ani a εda so kakra',
    '🚶🏽‍♂' => 'Barima renante: wedeε ani a εda hᴐ kakra',
    '🚶🏾‍♂' => 'Barima renante: wedeε ani tuntum kakra',
    '🚶🏿‍♂' => 'Barima renante: wedeε ani tuntum',
    '🚶🏻‍♀' => 'Ɔbaa renante: wedeε ani a εda so',
    '🚶🏼‍♀' => 'Ɔbaa renante: wedeε ani a εda so kakra',
    '🚶🏽‍♀' => 'Ɔbaa renante: wedeε ani a εda hᴐ kakra',
    '🚶🏾‍♀' => 'Ɔbaa renante: wedeε ani tuntum kakra',
    '🚶🏿‍♀' => 'Ɔbaa renante: wedeε ani tuntum',
    '🚶🏻‍➡' => 'Onipa renante: wedeε ani a εda so ne rehwɛ nifa',
    '🚶🏼‍➡' => 'Onipa renante: wedeε ani a εda so kakra ne rehwɛ nifa',
    '🚶🏽‍➡' => 'Onipa renante: wedeε ani a εda hᴐ kakra ne rehwɛ nifa',
    '🚶🏾‍➡' => 'Onipa renante: wedeε ani tuntum kakra ne rehwɛ nifa',
    '🚶🏿‍➡' => 'Onipa renante: wedeε ani tuntum ne rehwɛ nifa',
    '🧍🏻‍♂' => 'Barima gyina hɔ: wedeε ani a εda so',
    '🧍🏼‍♂' => 'Barima gyina hɔ: wedeε ani a εda so kakra',
    '🧍🏽‍♂' => 'Barima gyina hɔ: wedeε ani a εda hᴐ kakra',
    '🧍🏾‍♂' => 'Barima gyina hɔ: wedeε ani tuntum kakra',
    '🧍🏿‍♂' => 'Barima gyina hɔ: wedeε ani tuntum',
    '🧍🏻‍♀' => 'Ɔbaa regyina hɔ: wedeε ani a εda so',
    '🧍🏼‍♀' => 'Ɔbaa regyina hɔ: wedeε ani a εda so kakra',
    '🧍🏽‍♀' => 'Ɔbaa regyina hɔ: wedeε ani a εda hᴐ kakra',
    '🧍🏾‍♀' => 'Ɔbaa regyina hɔ: wedeε ani tuntum kakra',
    '🧍🏿‍♀' => 'Ɔbaa regyina hɔ: wedeε ani tuntum',
    '🧎🏻‍♂' => 'Barima abu nkotodwe: wedeε ani a εda so',
    '🧎🏼‍♂' => 'Barima abu nkotodwe: wedeε ani a εda so kakra',
    '🧎🏽‍♂' => 'Barima abu nkotodwe: wedeε ani a εda hᴐ kakra',
    '🧎🏾‍♂' => 'Barima abu nkotodwe: wedeε ani tuntum kakra',
    '🧎🏿‍♂' => 'Barima abu nkotodwe: wedeε ani tuntum',
    '🧎🏻‍♀' => 'Ɔbaa abu nkotodwe: wedeε ani a εda so',
    '🧎🏼‍♀' => 'Ɔbaa abu nkotodwe: wedeε ani a εda so kakra',
    '🧎🏽‍♀' => 'Ɔbaa abu nkotodwe: wedeε ani a εda hᴐ kakra',
    '🧎🏾‍♀' => 'Ɔbaa abu nkotodwe: wedeε ani tuntum kakra',
    '🧎🏿‍♀' => 'Ɔbaa abu nkotodwe: wedeε ani tuntum',
    '🧎🏻‍➡' => 'Obi abu nkotodwe: wedeε ani a εda so ne rehwɛ nifa',
    '🧎🏼‍➡' => 'Obi abu nkotodwe: wedeε ani a εda so kakra ne rehwɛ nifa',
    '🧎🏽‍➡' => 'Obi abu nkotodwe: wedeε ani a εda hᴐ kakra ne rehwɛ nifa',
    '🧎🏾‍➡' => 'Obi abu nkotodwe: wedeε ani tuntum kakra ne rehwɛ nifa',
    '🧎🏿‍➡' => 'Obi abu nkotodwe: wedeε ani tuntum ne rehwɛ nifa',
    '🧑🏻‍🦯' => 'Obi kura abaa fitaa: wedeε ani a εda so',
    '🧑🏼‍🦯' => 'Obi kura abaa fitaa: wedeε ani a εda so kakra',
    '🧑🏽‍🦯' => 'Obi kura abaa fitaa: wedeε ani a εda hᴐ kakra',
    '🧑🏾‍🦯' => 'Obi kura abaa fitaa: wedeε ani tuntum kakra',
    '🧑🏿‍🦯' => 'Obi kura abaa fitaa: wedeε ani tuntum',
    '👨🏻‍🦯' => 'Barima kura abaa fitaa: wedeε ani a εda so',
    '👨🏼‍🦯' => 'Barima kura abaa fitaa: wedeε ani a εda so kakra',
    '👨🏽‍🦯' => 'Barima kura abaa fitaa: wedeε ani a εda hᴐ kakra',
    '👨🏾‍🦯' => 'Barima kura abaa fitaa: wedeε ani tuntum kakra',
    '👨🏿‍🦯' => 'Barima kura abaa fitaa: wedeε ani tuntum',
    '👩🏻‍🦯' => 'Ɔbaa kura abaa fitaa: wedeε ani a εda so',
    '👩🏼‍🦯' => 'Ɔbaa kura abaa fitaa: wedeε ani a εda so kakra',
    '👩🏽‍🦯' => 'Ɔbaa kura abaa fitaa: wedeε ani a εda hᴐ kakra',
    '👩🏾‍🦯' => 'Ɔbaa kura abaa fitaa: wedeε ani tuntum kakra',
    '👩🏿‍🦯' => 'Ɔbaa kura abaa fitaa: wedeε ani tuntum',
    '🧑🏻‍🦼' => 'Obi te moto hwiikyɛɛ mu: wedeε ani a εda so',
    '🧑🏼‍🦼' => 'Obi te moto hwiikyɛɛ mu: wedeε ani a εda so kakra',
    '🧑🏽‍🦼' => 'Obi te moto hwiikyɛɛ mu: wedeε ani a εda hᴐ kakra',
    '🧑🏾‍🦼' => 'Obi te moto hwiikyɛɛ mu: wedeε ani tuntum kakra',
    '🧑🏿‍🦼' => 'Obi te moto hwiikyɛɛ mu: wedeε ani tuntum',
    '👨🏻‍🦼' => 'Barima te moto hwiikyɛɛ mu: wedeε ani a εda so',
    '👨🏼‍🦼' => 'Barima te moto hwiikyɛɛ mu: wedeε ani a εda so kakra',
    '👨🏽‍🦼' => 'Barima te moto hwiikyɛɛ mu: wedeε ani a εda hᴐ kakra',
    '👨🏾‍🦼' => 'Barima te moto hwiikyɛɛ mu: wedeε ani tuntum kakra',
    '👨🏿‍🦼' => 'Barima te moto hwiikyɛɛ mu: wedeε ani tuntum',
    '👩🏻‍🦼' => 'Ɔbaa te moto hwiikyɛɛ mu: wedeε ani a εda so',
    '👩🏼‍🦼' => 'Ɔbaa te moto hwiikyɛɛ mu: wedeε ani a εda so kakra',
    '👩🏽‍🦼' => 'Ɔbaa te moto hwiikyɛɛ mu: wedeε ani a εda hᴐ kakra',
    '👩🏾‍🦼' => 'Ɔbaa te moto hwiikyɛɛ mu: wedeε ani tuntum kakra',
    '👩🏿‍🦼' => 'Ɔbaa te moto hwiikyɛɛ mu: wedeε ani tuntum',
    '🧑🏻‍🦽' => 'Obi te manuaa hwiikyɛɛ mu: wedeε ani a εda so',
    '🧑🏼‍🦽' => 'Obi te manuaa hwiikyɛɛ mu: wedeε ani a εda so kakra',
    '🧑🏽‍🦽' => 'Obi te manuaa hwiikyɛɛ mu: wedeε ani a εda hᴐ kakra',
    '🧑🏾‍🦽' => 'Obi te manuaa hwiikyɛɛ mu: wedeε ani tuntum kakra',
    '🧑🏿‍🦽' => 'Obi te manuaa hwiikyɛɛ mu: wedeε ani tuntum',
    '👨🏻‍🦽' => 'Barima te manuaa hwiikyɛɛ mu: wedeε ani a εda so',
    '👨🏼‍🦽' => 'Barima te manuaa hwiikyɛɛ mu: wedeε ani a εda so kakra',
    '👨🏽‍🦽' => 'Barima te manuaa hwiikyɛɛ mu: wedeε ani a εda hᴐ kakra',
    '👨🏾‍🦽' => 'Barima te manuaa hwiikyɛɛ mu: wedeε ani tuntum kakra',
    '👨🏿‍🦽' => 'Barima te manuaa hwiikyɛɛ mu: wedeε ani tuntum',
    '👩🏻‍🦽' => 'Ɔbaa te manuaa hwiikyɛɛ mu: wedeε ani a εda so',
    '👩🏼‍🦽' => 'Ɔbaa te manuaa hwiikyɛɛ mu: wedeε ani a εda so kakra',
    '👩🏽‍🦽' => 'Ɔbaa te manuaa hwiikyɛɛ mu: wedeε ani a εda hᴐ kakra',
    '👩🏾‍🦽' => 'Ɔbaa te manuaa hwiikyɛɛ mu: wedeε ani tuntum kakra',
    '👩🏿‍🦽' => 'Ɔbaa te manuaa hwiikyɛɛ mu: wedeε ani tuntum',
    '🏃🏻‍♂' => 'Barima retu mmirika: wedeε ani a εda so',
    '🏃🏼‍♂' => 'Barima retu mmirika: wedeε ani a εda so kakra',
    '🏃🏽‍♂' => 'Barima retu mmirika: wedeε ani a εda hᴐ kakra',
    '🏃🏾‍♂' => 'Barima retu mmirika: wedeε ani tuntum kakra',
    '🏃🏿‍♂' => 'Barima retu mmirika: wedeε ani tuntum',
    '🏃🏻‍♀' => 'Ɔbaa retu mmirika: wedeε ani a εda so',
    '🏃🏼‍♀' => 'Ɔbaa retu mmirika: wedeε ani a εda so kakra',
    '🏃🏽‍♀' => 'Ɔbaa retu mmirika: wedeε ani a εda hᴐ kakra',
    '🏃🏾‍♀' => 'Ɔbaa retu mmirika: wedeε ani tuntum kakra',
    '🏃🏿‍♀' => 'Ɔbaa retu mmirika: wedeε ani tuntum',
    '🏃🏻‍➡' => 'Obi retu mmirika: wedeε ani a εda so ne rehwɛ nifa',
    '🏃🏼‍➡' => 'Obi retu mmirika: wedeε ani a εda so kakra ne rehwɛ nifa',
    '🏃🏽‍➡' => 'Obi retu mmirika: wedeε ani a εda hᴐ kakra ne rehwɛ nifa',
    '🏃🏾‍➡' => 'Obi retu mmirika: wedeε ani tuntum kakra ne rehwɛ nifa',
    '🏃🏿‍➡' => 'Obi retu mmirika: wedeε ani tuntum ne rehwɛ nifa',
    '👯🏻‍♀' => 'Mmaa a wɔwɔ adanko aso: wedeε ani a εda so',
    '👯🏼‍♀' => 'Mmaa a wɔwɔ adanko aso: wedeε ani a εda so kakra',
    '👯🏽‍♀' => 'Mmaa a wɔwɔ adanko aso: wedeε ani a εda hᴐ kakra',
    '👯🏾‍♀' => 'Mmaa a wɔwɔ adanko aso: wedeε ani tuntum kakra',
    '👯🏿‍♀' => 'Mmaa a wɔwɔ adanko aso: wedeε ani tuntum',
    '👯🏻‍♂' => 'Mmarima a wɔwɔ adanko aso: wedeε ani a εda so',
    '👯🏼‍♂' => 'Mmarima a wɔwɔ adanko aso: wedeε ani a εda so kakra',
    '👯🏽‍♂' => 'Mmarima a wɔwɔ adanko aso: wedeε ani a εda hᴐ kakra',
    '👯🏾‍♂' => 'Mmarima a wɔwɔ adanko aso: wedeε ani tuntum kakra',
    '👯🏿‍♂' => 'Mmarima a wɔwɔ adanko aso: wedeε ani tuntum',
    '🧖🏻‍♂' => 'Barima wɔ ɛhyew dan mu: wedeε ani a εda so',
    '🧖🏼‍♂' => 'Barima wɔ ɛhyew dan mu: wedeε ani a εda so kakra',
    '🧖🏽‍♂' => 'Barima wɔ ɛhyew dan mu: wedeε ani a εda hᴐ kakra',
    '🧖🏾‍♂' => 'Barima wɔ ɛhyew dan mu: wedeε ani tuntum kakra',
    '🧖🏿‍♂' => 'Barima wɔ ɛhyew dan mu: wedeε ani tuntum',
    '🧖🏻‍♀' => 'Ɔbaa wɔ ɛhyew dan mu: wedeε ani a εda so',
    '🧖🏼‍♀' => 'Ɔbaa wɔ ɛhyew dan mu: wedeε ani a εda so kakra',
    '🧖🏽‍♀' => 'Ɔbaa wɔ ɛhyew dan mu: wedeε ani a εda hᴐ kakra',
    '🧖🏾‍♀' => 'Ɔbaa wɔ ɛhyew dan mu: wedeε ani tuntum kakra',
    '🧖🏿‍♀' => 'Ɔbaa wɔ ɛhyew dan mu: wedeε ani tuntum',
    '🧗🏻‍♂' => 'Barima reforo: wedeε ani a εda so',
    '🧗🏼‍♂' => 'Barima reforo: wedeε ani a εda so kakra',
    '🧗🏽‍♂' => 'Barima reforo: wedeε ani a εda hᴐ kakra',
    '🧗🏾‍♂' => 'Barima reforo: wedeε ani tuntum kakra',
    '🧗🏿‍♂' => 'Barima reforo: wedeε ani tuntum',
    '🧗🏻‍♀' => 'Ɔbaa reforo: wedeε ani a εda so',
    '🧗🏼‍♀' => 'Ɔbaa reforo: wedeε ani a εda so kakra',
    '🧗🏽‍♀' => 'Ɔbaa reforo: wedeε ani a εda hᴐ kakra',
    '🧗🏾‍♀' => 'Ɔbaa reforo: wedeε ani tuntum kakra',
    '🧗🏿‍♀' => 'Ɔbaa reforo: wedeε ani tuntum',
    '🏌🏻‍♂' => 'Barima regɔɔfo: wedeε ani a εda so',
    '🏌🏼‍♂' => 'Barima regɔɔfo: wedeε ani a εda so kakra',
    '🏌🏽‍♂' => 'Barima regɔɔfo: wedeε ani a εda hᴐ kakra',
    '🏌🏾‍♂' => 'Barima regɔɔfo: wedeε ani tuntum kakra',
    '🏌🏿‍♂' => 'Barima regɔɔfo: wedeε ani tuntum',
    '🏌🏻‍♀' => 'Ɔbaa regɔɔfo: wedeε ani a εda so',
    '🏌🏼‍♀' => 'Ɔbaa regɔɔfo: wedeε ani a εda so kakra',
    '🏌🏽‍♀' => 'Ɔbaa regɔɔfo: wedeε ani a εda hᴐ kakra',
    '🏌🏾‍♀' => 'Ɔbaa regɔɔfo: wedeε ani tuntum kakra',
    '🏌🏿‍♀' => 'Ɔbaa regɔɔfo: wedeε ani tuntum',
    '🏄🏻‍♂' => 'Barima resɔɔfo: wedeε ani a εda so',
    '🏄🏼‍♂' => 'Barima resɔɔfo: wedeε ani a εda so kakra',
    '🏄🏽‍♂' => 'Barima resɔɔfo: wedeε ani a εda hᴐ kakra',
    '🏄🏾‍♂' => 'Barima resɔɔfo: wedeε ani tuntum kakra',
    '🏄🏿‍♂' => 'Barima resɔɔfo: wedeε ani tuntum',
    '🏄🏻‍♀' => 'Ɔbaa resɔɔfo: wedeε ani a εda so',
    '🏄🏼‍♀' => 'Ɔbaa resɔɔfo: wedeε ani a εda so kakra',
    '🏄🏽‍♀' => 'Ɔbaa resɔɔfo: wedeε ani a εda hᴐ kakra',
    '🏄🏾‍♀' => 'Ɔbaa resɔɔfo: wedeε ani tuntum kakra',
    '🏄🏿‍♀' => 'Ɔbaa resɔɔfo: wedeε ani tuntum',
    '🚣🏻‍♂' => 'Barima reka kodoɔ: wedeε ani a εda so',
    '🚣🏼‍♂' => 'Barima reka kodoɔ: wedeε ani a εda so kakra',
    '🚣🏽‍♂' => 'Barima reka kodoɔ: wedeε ani a εda hᴐ kakra',
    '🚣🏾‍♂' => 'Barima reka kodoɔ: wedeε ani tuntum kakra',
    '🚣🏿‍♂' => 'Barima reka kodoɔ: wedeε ani tuntum',
    '🚣🏻‍♀' => 'Ɔbaa reka kodoɔ: wedeε ani a εda so',
    '🚣🏼‍♀' => 'Ɔbaa reka kodoɔ: wedeε ani a εda so kakra',
    '🚣🏽‍♀' => 'Ɔbaa reka kodoɔ: wedeε ani a εda hᴐ kakra',
    '🚣🏾‍♀' => 'Ɔbaa reka kodoɔ: wedeε ani tuntum kakra',
    '🚣🏿‍♀' => 'Ɔbaa reka kodoɔ: wedeε ani tuntum',
    '🏊🏻‍♂' => 'Barima reboro nsuo: wedeε ani a εda so',
    '🏊🏼‍♂' => 'Barima reboro nsuo: wedeε ani a εda so kakra',
    '🏊🏽‍♂' => 'Barima reboro nsuo: wedeε ani a εda hᴐ kakra',
    '🏊🏾‍♂' => 'Barima reboro nsuo: wedeε ani tuntum kakra',
    '🏊🏿‍♂' => 'Barima reboro nsuo: wedeε ani tuntum',
    '🏊🏻‍♀' => 'Ɔbaa reboro nsuo: wedeε ani a εda so',
    '🏊🏼‍♀' => 'Ɔbaa reboro nsuo: wedeε ani a εda so kakra',
    '🏊🏽‍♀' => 'Ɔbaa reboro nsuo: wedeε ani a εda hᴐ kakra',
    '🏊🏾‍♀' => 'Ɔbaa reboro nsuo: wedeε ani tuntum kakra',
    '🏊🏿‍♀' => 'Ɔbaa reboro nsuo: wedeε ani tuntum',
    '⛹🏻‍♂' => 'Barima rebɔ bɔɔlo: wedeε ani a εda so',
    '⛹🏼‍♂' => 'Barima rebɔ bɔɔlo: wedeε ani a εda so kakra',
    '⛹🏽‍♂' => 'Barima rebɔ bɔɔlo: wedeε ani a εda hᴐ kakra',
    '⛹🏾‍♂' => 'Barima rebɔ bɔɔlo: wedeε ani tuntum kakra',
    '⛹🏿‍♂' => 'Barima rebɔ bɔɔlo: wedeε ani tuntum',
    '⛹🏻‍♀' => 'Ɔbaa rebɔ bɔɔlo: wedeε ani a εda so',
    '⛹🏼‍♀' => 'Ɔbaa rebɔ bɔɔlo: wedeε ani a εda so kakra',
    '⛹🏽‍♀' => 'Ɔbaa rebɔ bɔɔlo: wedeε ani a εda hᴐ kakra',
    '⛹🏾‍♀' => 'Ɔbaa rebɔ bɔɔlo: wedeε ani tuntum kakra',
    '⛹🏿‍♀' => 'Ɔbaa rebɔ bɔɔlo: wedeε ani tuntum',
    '🏋🏻‍♂' => 'Barima repagya nnadeɛ: wedeε ani a εda so',
    '🏋🏼‍♂' => 'Barima repagya nnadeɛ: wedeε ani a εda so kakra',
    '🏋🏽‍♂' => 'Barima repagya nnadeɛ: wedeε ani a εda hᴐ kakra',
    '🏋🏾‍♂' => 'Barima repagya nnadeɛ: wedeε ani tuntum kakra',
    '🏋🏿‍♂' => 'Barima repagya nnadeɛ: wedeε ani tuntum',
    '🏋🏻‍♀' => 'Ɔbaa repagya nnadeɛ: wedeε ani a εda so',
    '🏋🏼‍♀' => 'Ɔbaa repagya nnadeɛ: wedeε ani a εda so kakra',
    '🏋🏽‍♀' => 'Ɔbaa repagya nnadeɛ: wedeε ani a εda hᴐ kakra',
    '🏋🏾‍♀' => 'Ɔbaa repagya nnadeɛ: wedeε ani tuntum kakra',
    '🏋🏿‍♀' => 'Ɔbaa repagya nnadeɛ: wedeε ani tuntum',
    '🚴🏻‍♂' => 'Barima retwi sakre: wedeε ani a εda so',
    '🚴🏼‍♂' => 'Barima retwi sakre: wedeε ani a εda so kakra',
    '🚴🏽‍♂' => 'Barima retwi sakre: wedeε ani a εda hᴐ kakra',
    '🚴🏾‍♂' => 'Barima retwi sakre: wedeε ani tuntum kakra',
    '🚴🏿‍♂' => 'Barima retwi sakre: wedeε ani tuntum',
    '🚴🏻‍♀' => 'Ɔbaa retwi sakre: wedeε ani a εda so',
    '🚴🏼‍♀' => 'Ɔbaa retwi sakre: wedeε ani a εda so kakra',
    '🚴🏽‍♀' => 'Ɔbaa retwi sakre: wedeε ani a εda hᴐ kakra',
    '🚴🏾‍♀' => 'Ɔbaa retwi sakre: wedeε ani tuntum kakra',
    '🚴🏿‍♀' => 'Ɔbaa retwi sakre: wedeε ani tuntum',
    '🚵🏻‍♂' => 'Barima a ɔtwi sakre wɔ bepɔ so: wedeε ani a εda so',
    '🚵🏼‍♂' => 'Barima a ɔtwi sakre wɔ bepɔ so: wedeε ani a εda so kakra',
    '🚵🏽‍♂' => 'Barima a ɔtwi sakre wɔ bepɔ so: wedeε ani a εda hᴐ kakra',
    '🚵🏾‍♂' => 'Barima a ɔtwi sakre wɔ bepɔ so: wedeε ani tuntum kakra',
    '🚵🏿‍♂' => 'Barima a ɔtwi sakre wɔ bepɔ so: wedeε ani tuntum',
    '🚵🏻‍♀' => 'Ɔbaa retwi sakre wɔ bepɔ so: wedeε ani a εda so',
    '🚵🏼‍♀' => 'Ɔbaa retwi sakre wɔ bepɔ so: wedeε ani a εda so kakra',
    '🚵🏽‍♀' => 'Ɔbaa retwi sakre wɔ bepɔ so: wedeε ani a εda hᴐ kakra',
    '🚵🏾‍♀' => 'Ɔbaa retwi sakre wɔ bepɔ so: wedeε ani tuntum kakra',
    '🚵🏿‍♀' => 'Ɔbaa retwi sakre wɔ bepɔ so: wedeε ani tuntum',
    '🤸🏻‍♂' => 'Batima retwi kaate: wedeε ani a εda so',
    '🤸🏼‍♂' => 'Batima retwi kaate: wedeε ani a εda so kakra',
    '🤸🏽‍♂' => 'Batima retwi kaate: wedeε ani a εda hᴐ kakra',
    '🤸🏾‍♂' => 'Batima retwi kaate: wedeε ani tuntum kakra',
    '🤸🏿‍♂' => 'Batima retwi kaate: wedeε ani tuntum',
    '🤸🏻‍♀' => 'Ɔbaa retwi kaate: wedeε ani a εda so',
    '🤸🏼‍♀' => 'Ɔbaa retwi kaate: wedeε ani a εda so kakra',
    '🤸🏽‍♀' => 'Ɔbaa retwi kaate: wedeε ani a εda hᴐ kakra',
    '🤸🏾‍♀' => 'Ɔbaa retwi kaate: wedeε ani tuntum kakra',
    '🤸🏿‍♀' => 'Ɔbaa retwi kaate: wedeε ani tuntum',
    '🤼🏻‍♀' => 'Mmaa retentam: wedeε ani a εda so',
    '🤼🏼‍♀' => 'Mmaa retentam: wedeε ani a εda so kakra',
    '🤼🏽‍♀' => 'Mmaa retentam: wedeε ani a εda hᴐ kakra',
    '🤼🏾‍♀' => 'Mmaa retentam: wedeε ani tuntum kakra',
    '🤼🏿‍♀' => 'Mmaa retentam: wedeε ani tuntum',
    '🤼🏻‍♂' => 'Mmarima retentam: wedeε ani a εda so',
    '🤼🏼‍♂' => 'Mmarima retentam: wedeε ani a εda so kakra',
    '🤼🏽‍♂' => 'Mmarima retentam: wedeε ani a εda hᴐ kakra',
    '🤼🏾‍♂' => 'Mmarima retentam: wedeε ani tuntum kakra',
    '🤼🏿‍♂' => 'Mmarima retentam: wedeε ani tuntum',
    '🤽🏻‍♂' => 'Barima rebɔ polo nsuo: wedeε ani a εda so',
    '🤽🏼‍♂' => 'Barima rebɔ polo nsuo: wedeε ani a εda so kakra',
    '🤽🏽‍♂' => 'Barima rebɔ polo nsuo: wedeε ani a εda hᴐ kakra',
    '🤽🏾‍♂' => 'Barima rebɔ polo nsuo: wedeε ani tuntum kakra',
    '🤽🏿‍♂' => 'Barima rebɔ polo nsuo: wedeε ani tuntum',
    '🤽🏻‍♀' => 'Ɔbaa rebɔ polo nsuo: wedeε ani a εda so',
    '🤽🏼‍♀' => 'Ɔbaa rebɔ polo nsuo: wedeε ani a εda so kakra',
    '🤽🏽‍♀' => 'Ɔbaa rebɔ polo nsuo: wedeε ani a εda hᴐ kakra',
    '🤽🏾‍♀' => 'Ɔbaa rebɔ polo nsuo: wedeε ani tuntum kakra',
    '🤽🏿‍♀' => 'Ɔbaa rebɔ polo nsuo: wedeε ani tuntum',
    '🤾🏻‍♂' => 'Barima rebɔ nsabɔɔlo: wedeε ani a εda so',
    '🤾🏼‍♂' => 'Barima rebɔ nsabɔɔlo: wedeε ani a εda so kakra',
    '🤾🏽‍♂' => 'Barima rebɔ nsabɔɔlo: wedeε ani a εda hᴐ kakra',
    '🤾🏾‍♂' => 'Barima rebɔ nsabɔɔlo: wedeε ani tuntum kakra',
    '🤾🏿‍♂' => 'Barima rebɔ nsabɔɔlo: wedeε ani tuntum',
    '🤾🏻‍♀' => 'Ɔbaa rebɔ nsabɔɔlo: wedeε ani a εda so',
    '🤾🏼‍♀' => 'Ɔbaa rebɔ nsabɔɔlo: wedeε ani a εda so kakra',
    '🤾🏽‍♀' => 'Ɔbaa rebɔ nsabɔɔlo: wedeε ani a εda hᴐ kakra',
    '🤾🏾‍♀' => 'Ɔbaa rebɔ nsabɔɔlo: wedeε ani tuntum kakra',
    '🤾🏿‍♀' => 'Ɔbaa rebɔ nsabɔɔlo: wedeε ani tuntum',
    '🤹🏻‍♂' => 'Barima retoto bɔɔlo: wedeε ani a εda so',
    '🤹🏼‍♂' => 'Barima retoto bɔɔlo: wedeε ani a εda so kakra',
    '🤹🏽‍♂' => 'Barima retoto bɔɔlo: wedeε ani a εda hᴐ kakra',
    '🤹🏾‍♂' => 'Barima retoto bɔɔlo: wedeε ani tuntum kakra',
    '🤹🏿‍♂' => 'Barima retoto bɔɔlo: wedeε ani tuntum',
    '🤹🏻‍♀' => 'Ɔbaa retoto bɔɔlo: wedeε ani a εda so',
    '🤹🏼‍♀' => 'Ɔbaa retoto bɔɔlo: wedeε ani a εda so kakra',
    '🤹🏽‍♀' => 'Ɔbaa retoto bɔɔlo: wedeε ani a εda hᴐ kakra',
    '🤹🏾‍♀' => 'Ɔbaa retoto bɔɔlo: wedeε ani tuntum kakra',
    '🤹🏿‍♀' => 'Ɔbaa retoto bɔɔlo: wedeε ani tuntum',
    '🧘🏻‍♂' => 'Barima ayɛ lɔtusu posihyen: wedeε ani a εda so',
    '🧘🏼‍♂' => 'Barima ayɛ lɔtusu posihyen: wedeε ani a εda so kakra',
    '🧘🏽‍♂' => 'Barima ayɛ lɔtusu posihyen: wedeε ani a εda hᴐ kakra',
    '🧘🏾‍♂' => 'Barima ayɛ lɔtusu posihyen: wedeε ani tuntum kakra',
    '🧘🏿‍♂' => 'Barima ayɛ lɔtusu posihyen: wedeε ani tuntum',
    '🧘🏻‍♀' => 'Ɔbaa ayɛ lɔtusu posihyen: wedeε ani a εda so',
    '🧘🏼‍♀' => 'Ɔbaa ayɛ lɔtusu posihyen: wedeε ani a εda so kakra',
    '🧘🏽‍♀' => 'Ɔbaa ayɛ lɔtusu posihyen: wedeε ani a εda hᴐ kakra',
    '🧘🏾‍♀' => 'Ɔbaa ayɛ lɔtusu posihyen: wedeε ani tuntum kakra',
    '🧘🏿‍♀' => 'Ɔbaa ayɛ lɔtusu posihyen: wedeε ani tuntum',
    '🧑‍🦰' => 'onipa: nwi kͻkͻͻ',
    '🧑‍🦱' => 'onipa: enwi a akyinkyim',
    '🧑‍🦳' => 'onipa: nwi fitaa',
    '🧑‍🦲' => 'onipa: tipa',
    '👨‍🦰' => 'ɔbarima: nwi kͻkͻͻ',
    '👨‍🦱' => 'ɔbarima: enwi a akyinkyim',
    '👨‍🦳' => 'ɔbarima: nwi fitaa',
    '👨‍🦲' => 'ɔbarima: tipa',
    '👩‍🦰' => 'maame: nwi kͻkͻͻ',
    '👩‍🦱' => 'maame: enwi a akyinkyim',
    '👩‍🦳' => 'maame: nwi fitaa',
    '👩‍🦲' => 'maame: tipa',
    '🚶‍➡' => 'Onipa renante: rehwɛ nifa',
    '🧎‍➡' => 'Obi abu nkotodwe: rehwɛ nifa',
    '🏃‍➡' => 'Obi retu mmirika: rehwɛ nifa',
    '👨‍👦' => 'Abusua: ɔbarima ne barima',
    '👨‍👧' => 'Abusua: ɔbarima ne ɔbaa',
    '👩‍👦' => 'Abusua: maame ne barima',
    '👩‍👧' => 'Abusua: maame ne ɔbaa',
    '😶‍🌫' => 'anim wɔ mununkum mu',
    '😮‍💨' => 'anim ahomeguo',
    '🙂‍↕' => 'ti woso kɔ vɛɛtikaa',
    '😵‍💫' => 'anim ne ani ntwaho',
    '❤‍🔥' => 'akoma da gya mu',
    '❤‍🩹' => 'akoma a wɔatare',
    '👁‍🗨' => 'ani wɔ kasa bɔbuu mu',
    '🧔‍♂' => 'barima: abodwesɛ',
    '👱‍♂' => 'barima: nwii kɔkɔɔ',
    '🧔‍♀' => 'ɔbaa: abodwesɛ',
    '👱‍♀' => 'ɔbaa: nwii kɔkɔɔ',
    '🙍‍♂' => 'barima remuna',
    '🙍‍♀' => 'ɔbaa remuna',
    '🙎‍♂' => 'barima pɔɔtine',
    '🙎‍♀' => 'ɔbaa pɔɔtine',
    '🙅‍♂' => 'barima reyɛ DAABI nsɛnkyerɛnne',
    '🙅‍♀' => 'ɔbaa reyɛ DAABI nsɛnkyerɛnne',
    '🙆‍♂' => 'barima reyɛ OK nsɛnkyerɛnne',
    '🙆‍♀' => 'ɔbaa reyɛ OK nsɛnkyerɛnne',
    '💁‍♂' => 'barima tiipi nsa',
    '💁‍♀' => 'ɔbaa tiipi nsa',
    '🙋‍♂' => 'barima repagya nsa',
    '🙋‍♀' => 'ɔbaa repagya ne nsa',
    '🧏‍♂' => 'mum barima',
    '🧏‍♀' => 'ɔbaa mum',
    '🙇‍♂' => 'barima rebɔ ne mu ase',
    '🙇‍♀' => 'ɔbaa rebɔ ne mu ase',
    '🤦‍♂' => 'barima de ne nsam ato n’anim',
    '🤦‍♀' => 'ɔbaa de ne nsa rebɔ n’anim',
    '🤷‍♂' => 'barima repagya ne mmati',
    '🤷‍♀' => 'ɔbaa repagya ne mmati',
    '🧑‍⚕' => 'apomuden dwumayɛfoɔ',
    '👨‍⚕' => 'apomuden dwumayɛfoɔ barima',
    '👩‍⚕' => 'apomuden dwumayɛfoɔ ɔbaa',
    '🧑‍🎓' => 'sukuuni',
    '👨‍🎓' => 'sukuuni barima',
    '👩‍🎓' => 'sukuuni baa',
    '🧑‍🏫' => 'tikya',
    '👨‍🏫' => 'tikyani barima',
    '👩‍🏫' => 'tikyani baa',
    '🧑‍⚖' => 'gyaagye',
    '👨‍⚖' => 'Barima gyaagye',
    '👩‍⚖' => 'ɔbaa gyaagye',
    '🧑‍🌾' => 'Okuani',
    '👨‍🌾' => 'Okuani barima',
    '👩‍🌾' => 'Okuani baa',
    '🧑‍🍳' => 'kuk',
    '👨‍🍳' => 'Barima kuk',
    '👩‍🍳' => 'Ɔbaa kuk',
    '🧑‍🔧' => 'Mɛkanike',
    '👨‍🔧' => 'Barima mɛkanike',
    '👩‍🔧' => 'Ɔbaa mɛkanike',
    '🧑‍🏭' => 'Faktre dwumayɛni',
    '👨‍🏭' => 'Faktre dwumayɛni barima',
    '👩‍🏭' => 'Faktre dwumayɛni baa',
    '🧑‍💼' => 'ɔfese dwumayɛni',
    '👨‍💼' => 'ɔfese dwumayɛni barima',
    '👩‍💼' => 'Ɔfese dwumayɛni baa',
    '🧑‍🔬' => 'Seantise',
    '👨‍🔬' => 'Seantise barima',
    '👩‍🔬' => 'Seantise ɔbaa',
    '🧑‍💻' => 'tɛknologiste',
    '👨‍💻' => 'Tɛknologiste barima',
    '👩‍💻' => 'Tɛknologiste ɔbaa',
    '🧑‍🎤' => 'Nnwomtoni',
    '👨‍🎤' => 'Nnwomtoni barima',
    '👩‍🎤' => 'Nnwomtoni baa',
    '🧑‍🎨' => 'Aatise',
    '👨‍🎨' => 'Aatise barima',
    '👩‍🎨' => 'Aatise ɔbaa',
    '🧑‍✈' => 'Pailɔt',
    '👨‍✈' => 'Barima pailɔt',
    '👩‍✈' => 'Pailɔt ɔbaa',
    '🧑‍🚀' => 'Astrɔnɔt',
    '👨‍🚀' => 'Astrɔnɔt barima',
    '👩‍🚀' => 'Astrɔnɔto ɔbaa',
    '🧑‍🚒' => 'Gyadumfoɔ',
    '👨‍🚒' => 'Barima gyadumfoɔ',
    '👩‍🚒' => 'Ɔbaa gyadumfoɔ',
    '👮‍♂' => 'Polisi ɔfesa barima',
    '👮‍♀' => 'Polisi ɔfesa ɔbaa',
    '🕵‍♂' => 'Detɛketifo barima',
    '🕵‍♀' => 'Detɛketifo ɔbaa',
    '💂‍♂' => 'Barima banbɔfo',
    '💂‍♀' => 'Ɔbaa banbɔfo',
    '👷‍♂' => 'Adansie dwumayɛni barima',
    '👷‍♀' => 'Adansie dwumayɛni baa',
    '👳‍♂' => 'Barima hyɛ tɛɛban',
    '👳‍♀' => 'ɔbaa a ɔhyɛ tɛɛban',
    '🤵‍♂' => 'Barima a ɔhyɛ tɔseedo',
    '🤵‍♀' => 'Ɔbaa a ɔhyɛ tɔseedo',
    '👰‍♂' => 'Barima ne veil',
    '👰‍♀' => 'Ɔbaa ne veil',
    '👩‍🍼' => 'Ɔbaa rema akwadaa aduane',
    '👨‍🍼' => 'Barima rema akwadaa aduane',
    '🧑‍🍼' => 'obi rema akwadaa nufoɔ',
    '🧑‍🎄' => 'Mx Klauso',
    '🦸‍♂' => 'Supahero barima',
    '🦸‍♀' => 'Supahero ɔbaa',
    '🦹‍♂' => 'Supaviliane barima',
    '🦹‍♀' => 'Supaviliane ɔbaa',
    '🧙‍♂' => 'barima nknyaayifoͻ',
    '🧙‍♀' => 'ͻbaa nkonyaayifoͻ',
    '🧚‍♂' => 'Fɛɛre barima',
    '🧚‍♀' => 'Ɔbaa fɛɛre',
    '🧛‍♂' => 'Barima vampaya',
    '🧛‍♀' => 'Ɔbaa vampaya',
    '🧜‍♂' => 'Mɛɛbarima',
    '🧜‍♀' => 'Mɛɛmeede',
    '🧝‍♂' => 'Ɛlefo barima',
    '🧝‍♀' => 'Ɛlefo ɔbaa',
    '🧞‍♂' => 'Barima gyeeni',
    '🧞‍♀' => 'Ɔbaa gyeeni',
    '🧟‍♂' => 'Barima sɔmbi',
    '🧟‍♀' => 'Ɔbaa simbi',
    '💆‍♂' => 'Barima renya amiamia',
    '💆‍♀' => 'Ɔbaa renya amiamia',
    '💇‍♂' => 'Wɔretwa barima nwii',
    '💇‍♀' => 'Wɔretwa ɔbaa nwii',
    '🚶‍♂' => 'Barima renante',
    '🚶‍♀' => 'Ɔbaa renante',
    '🧍‍♂' => 'Barima gyina hɔ',
    '🧍‍♀' => 'Ɔbaa regyina hɔ',
    '🧎‍♂' => 'Barima abu nkotodwe',
    '🧎‍♀' => 'Ɔbaa abu nkotodwe',
    '🧑‍🦯' => 'Obi kura abaa fitaa',
    '👨‍🦯' => 'Barima kura abaa fitaa',
    '👩‍🦯' => 'Ɔbaa kura abaa fitaa',
    '🧑‍🦼' => 'Obi te moto hwiikyɛɛ mu',
    '👨‍🦼' => 'Barima te moto hwiikyɛɛ mu',
    '👩‍🦼' => 'Ɔbaa te moto hwiikyɛɛ mu',
    '🧑‍🦽' => 'Obi te manuaa hwiikyɛɛ mu',
    '👨‍🦽' => 'Barima te manuaa hwiikyɛɛ mu',
    '👩‍🦽' => 'Ɔbaa te manuaa hwiikyɛɛ mu',
    '🏃‍♂' => 'Barima retu mmirika',
    '🏃‍♀' => 'Ɔbaa retu mmirika',
    '🧑‍🩰' => 'balee safoᴐ',
    '👯‍♂' => 'Mmarima a wɔwɔ adanko aso',
    '👯‍♀' => 'Mmaa a wɔwɔ adanko aso',
    '🧖‍♂' => 'Barima wɔ ɛhyew dan mu',
    '🧖‍♀' => 'Ɔbaa wɔ ɛhyew dan mu',
    '🧗‍♂' => 'Barima reforo',
    '🧗‍♀' => 'Ɔbaa reforo',
    '🏌‍♂' => 'Barima regɔɔfo',
    '🏌‍♀' => 'Ɔbaa regɔɔfo',
    '🏄‍♂' => 'Barima resɔɔfo',
    '🏄‍♀' => 'Ɔbaa resɔɔfo',
    '🚣‍♂' => 'Barima reka kodoɔ',
    '🚣‍♀' => 'Ɔbaa reka kodoɔ',
    '🏊‍♂' => 'Barima reboro nsuo',
    '🏊‍♀' => 'Ɔbaa reboro nsuo',
    '⛹‍♂' => 'Barima rebɔ bɔɔlo',
    '⛹‍♀' => 'Ɔbaa rebɔ bɔɔlo',
    '🏋‍♂' => 'Barima repagya nnadeɛ',
    '🏋‍♀' => 'Ɔbaa repagya nnadeɛ',
    '🚴‍♂' => 'Barima retwi sakre',
    '🚴‍♀' => 'Ɔbaa retwi sakre',
    '🚵‍♂' => 'Barima a ɔtwi sakre wɔ bepɔ so',
    '🚵‍♀' => 'Ɔbaa retwi sakre wɔ bepɔ so',
    '🤸‍♂' => 'Batima retwi kaate',
    '🤸‍♀' => 'Ɔbaa retwi kaate',
    '🤼‍♂' => 'Mmarima retentam',
    '🤼‍♀' => 'Mmaa retentam',
    '🤽‍♂' => 'Barima rebɔ polo nsuo',
    '🤽‍♀' => 'Ɔbaa rebɔ polo nsuo',
    '🤾‍♂' => 'Barima rebɔ nsabɔɔlo',
    '🤾‍♀' => 'Ɔbaa rebɔ nsabɔɔlo',
    '🤹‍♂' => 'Barima retoto bɔɔlo',
    '🤹‍♀' => 'Ɔbaa retoto bɔɔlo',
    '🧘‍♂' => 'Barima ayɛ lɔtusu posihyen',
    '🧘‍♀' => 'Ɔbaa ayɛ lɔtusu posihyen',
    '🧑‍🧒' => 'Abusua: panin, akwadaa',
    '🐕‍🦺' => 'kraman dwumayɛni',
    '🐈‍⬛' => 'ͻkra tuntum',
    '🐻‍❄' => 'pola sisire',
    '🐦‍⬛' => 'anomaa tuntum',
    '🐦‍🔥' => 'feenise',
    '🍋‍🟩' => 'ankama',
    '🍄‍🟫' => 'mmire dodoe',
    '⛓‍💥' => 'nkyerewa a abubu',
    '🏳‍🌈' => 'nyankontͻn frankaa',
    '🏳‍⚧' => 'transgender frankaa',
    '🏴‍☠' => 'ɛpo so korͻmfoͻ frankaa',
    '👋🏻' => 'nsa a ɛrehim: wedeε ani a εda so',
    '👋🏼' => 'nsa a ɛrehim: wedeε ani a εda so kakra',
    '👋🏽' => 'nsa a ɛrehim: wedeε ani a εda hᴐ kakra',
    '👋🏾' => 'nsa a ɛrehim: wedeε ani tuntum kakra',
    '👋🏿' => 'nsa a ɛrehim: wedeε ani tuntum',
    '🤚🏻' => 'nsa akyi a apagya: wedeε ani a εda so',
    '🤚🏼' => 'nsa akyi a apagya: wedeε ani a εda so kakra',
    '🤚🏽' => 'nsa akyi a apagya: wedeε ani a εda hᴐ kakra',
    '🤚🏾' => 'nsa akyi a apagya: wedeε ani tuntum kakra',
    '🤚🏿' => 'nsa akyi a apagya: wedeε ani tuntum',
    '🖐🏻' => 'nsa ne nsateaa a abue: wedeε ani a εda so',
    '🖐🏼' => 'nsa ne nsateaa a abue: wedeε ani a εda so kakra',
    '🖐🏽' => 'nsa ne nsateaa a abue: wedeε ani a εda hᴐ kakra',
    '🖐🏾' => 'nsa ne nsateaa a abue: wedeε ani tuntum kakra',
    '🖐🏿' => 'nsa ne nsateaa a abue: wedeε ani tuntum',
    '✋🏻' => 'nsa a apagya: wedeε ani a εda so',
    '✋🏼' => 'nsa a apagya: wedeε ani a εda so kakra',
    '✋🏽' => 'nsa a apagya: wedeε ani a εda hᴐ kakra',
    '✋🏾' => 'nsa a apagya: wedeε ani tuntum kakra',
    '✋🏿' => 'nsa a apagya: wedeε ani tuntum',
    '🖖🏻' => 'vulcan nkyea: wedeε ani a εda so',
    '🖖🏼' => 'vulcan nkyea: wedeε ani a εda so kakra',
    '🖖🏽' => 'vulcan nkyea: wedeε ani a εda hᴐ kakra',
    '🖖🏾' => 'vulcan nkyea: wedeε ani tuntum kakra',
    '🖖🏿' => 'vulcan nkyea: wedeε ani tuntum',
    '🫱🏻' => 'nsa nifa: wedeε ani a εda so',
    '🫱🏼' => 'nsa nifa: wedeε ani a εda so kakra',
    '🫱🏽' => 'nsa nifa: wedeε ani a εda hᴐ kakra',
    '🫱🏾' => 'nsa nifa: wedeε ani tuntum kakra',
    '🫱🏿' => 'nsa nifa: wedeε ani tuntum',
    '🫲🏻' => 'nsa benkum: wedeε ani a εda so',
    '🫲🏼' => 'nsa benkum: wedeε ani a εda so kakra',
    '🫲🏽' => 'nsa benkum: wedeε ani a εda hᴐ kakra',
    '🫲🏾' => 'nsa benkum: wedeε ani tuntum kakra',
    '🫲🏿' => 'nsa benkum: wedeε ani tuntum',
    '🫳🏻' => 'nsam hwɛ fam: wedeε ani a εda so',
    '🫳🏼' => 'nsam hwɛ fam: wedeε ani a εda so kakra',
    '🫳🏽' => 'nsam hwɛ fam: wedeε ani a εda hᴐ kakra',
    '🫳🏾' => 'nsam hwɛ fam: wedeε ani tuntum kakra',
    '🫳🏿' => 'nsam hwɛ fam: wedeε ani tuntum',
    '🫴🏻' => 'nsam a ɛhwɛ soro: wedeε ani a εda so',
    '🫴🏼' => 'nsam a ɛhwɛ soro: wedeε ani a εda so kakra',
    '🫴🏽' => 'nsam a ɛhwɛ soro: wedeε ani a εda hᴐ kakra',
    '🫴🏾' => 'nsam a ɛhwɛ soro: wedeε ani tuntum kakra',
    '🫴🏿' => 'nsam a ɛhwɛ soro: wedeε ani tuntum',
    '🫷🏻' => 'nsa repia kɔ benkum: wedeε ani a εda so',
    '🫷🏼' => 'nsa repia kɔ benkum: wedeε ani a εda so kakra',
    '🫷🏽' => 'nsa repia kɔ benkum: wedeε ani a εda hᴐ kakra',
    '🫷🏾' => 'nsa repia kɔ benkum: wedeε ani tuntum kakra',
    '🫷🏿' => 'nsa repia kɔ benkum: wedeε ani tuntum',
    '🫸🏻' => 'nsa repia kɔ nifa: wedeε ani a εda so',
    '🫸🏼' => 'nsa repia kɔ nifa: wedeε ani a εda so kakra',
    '🫸🏽' => 'nsa repia kɔ nifa: wedeε ani a εda hᴐ kakra',
    '🫸🏾' => 'nsa repia kɔ nifa: wedeε ani tuntum kakra',
    '🫸🏿' => 'nsa repia kɔ nifa: wedeε ani tuntum',
    '👌🏻' => 'OK nsa: wedeε ani a εda so',
    '👌🏼' => 'OK nsa: wedeε ani a εda so kakra',
    '👌🏽' => 'OK nsa: wedeε ani a εda hᴐ kakra',
    '👌🏾' => 'OK nsa: wedeε ani tuntum kakra',
    '👌🏿' => 'OK nsa: wedeε ani tuntum',
    '🤌🏻' => 'nsateaa a amia: wedeε ani a εda so',
    '🤌🏼' => 'nsateaa a amia: wedeε ani a εda so kakra',
    '🤌🏽' => 'nsateaa a amia: wedeε ani a εda hᴐ kakra',
    '🤌🏾' => 'nsateaa a amia: wedeε ani tuntum kakra',
    '🤌🏿' => 'nsateaa a amia: wedeε ani tuntum',
    '🤏🏻' => 'nsa a amia: wedeε ani a εda so',
    '🤏🏼' => 'nsa a amia: wedeε ani a εda so kakra',
    '🤏🏽' => 'nsa a amia: wedeε ani a εda hᴐ kakra',
    '🤏🏾' => 'nsa a amia: wedeε ani tuntum kakra',
    '🤏🏿' => 'nsa a amia: wedeε ani tuntum',
    '✌🏻' => 'nkonimdie nsa: wedeε ani a εda so',
    '✌🏼' => 'nkonimdie nsa: wedeε ani a εda so kakra',
    '✌🏽' => 'nkonimdie nsa: wedeε ani a εda hᴐ kakra',
    '✌🏾' => 'nkonimdie nsa: wedeε ani tuntum kakra',
    '✌🏿' => 'nkonimdie nsa: wedeε ani tuntum',
    '🤞🏻' => 'nsateaa a wɔde abankyere ho: wedeε ani a εda so',
    '🤞🏼' => 'nsateaa a wɔde abankyere ho: wedeε ani a εda so kakra',
    '🤞🏽' => 'nsateaa a wɔde abankyere ho: wedeε ani a εda hᴐ kakra',
    '🤞🏾' => 'nsateaa a wɔde abankyere ho: wedeε ani tuntum kakra',
    '🤞🏿' => 'nsateaa a wɔde abankyere ho: wedeε ani tuntum',
    '🫰🏻' => 'nsa a wɔde akyerɛkyerɛkwan nsateaa ne kokuromotie abɔ mu: wedeε ani a εda so',
    '🫰🏼' => 'nsa a wɔde akyerɛkyerɛkwan nsateaa ne kokuromotie abɔ mu: wedeε ani a εda so kakra',
    '🫰🏽' => 'nsa a wɔde akyerɛkyerɛkwan nsateaa ne kokuromotie abɔ mu: wedeε ani a εda hᴐ kakra',
    '🫰🏾' => 'nsa a wɔde akyerɛkyerɛkwan nsateaa ne kokuromotie abɔ mu: wedeε ani tuntum kakra',
    '🫰🏿' => 'nsa a wɔde akyerɛkyerɛkwan nsateaa ne kokuromotie abɔ mu: wedeε ani tuntum',
    '🤟🏻' => 'ɔdɔ-wo sɛnkyerɛnne: wedeε ani a εda so',
    '🤟🏼' => 'ɔdɔ-wo sɛnkyerɛnne: wedeε ani a εda so kakra',
    '🤟🏽' => 'ɔdɔ-wo sɛnkyerɛnne: wedeε ani a εda hᴐ kakra',
    '🤟🏾' => 'ɔdɔ-wo sɛnkyerɛnne: wedeε ani tuntum kakra',
    '🤟🏿' => 'ɔdɔ-wo sɛnkyerɛnne: wedeε ani tuntum',
    '🤘🏻' => 'mmɛn no ho sɛnkyerɛnne: wedeε ani a εda so',
    '🤘🏼' => 'mmɛn no ho sɛnkyerɛnne: wedeε ani a εda so kakra',
    '🤘🏽' => 'mmɛn no ho sɛnkyerɛnne: wedeε ani a εda hᴐ kakra',
    '🤘🏾' => 'mmɛn no ho sɛnkyerɛnne: wedeε ani tuntum kakra',
    '🤘🏿' => 'mmɛn no ho sɛnkyerɛnne: wedeε ani tuntum',
    '🤙🏻' => 'frɛ me nsa: wedeε ani a εda so',
    '🤙🏼' => 'frɛ me nsa: wedeε ani a εda so kakra',
    '🤙🏽' => 'frɛ me nsa: wedeε ani a εda hᴐ kakra',
    '🤙🏾' => 'frɛ me nsa: wedeε ani tuntum kakra',
    '🤙🏿' => 'frɛ me nsa: wedeε ani tuntum',
    '👈🏻' => 'nsaakyi indɛse a ɛkyerɛ benkum so: wedeε ani a εda so',
    '👈🏼' => 'nsaakyi indɛse a ɛkyerɛ benkum so: wedeε ani a εda so kakra',
    '👈🏽' => 'nsaakyi indɛse a ɛkyerɛ benkum so: wedeε ani a εda hᴐ kakra',
    '👈🏾' => 'nsaakyi indɛse a ɛkyerɛ benkum so: wedeε ani tuntum kakra',
    '👈🏿' => 'nsaakyi indɛse a ɛkyerɛ benkum so: wedeε ani tuntum',
    '👉🏻' => 'nsaakyi indɛse a ɛkyerɛ nifa so: wedeε ani a εda so',
    '👉🏼' => 'nsaakyi indɛse a ɛkyerɛ nifa so: wedeε ani a εda so kakra',
    '👉🏽' => 'nsaakyi indɛse a ɛkyerɛ nifa so: wedeε ani a εda hᴐ kakra',
    '👉🏾' => 'nsaakyi indɛse a ɛkyerɛ nifa so: wedeε ani tuntum kakra',
    '👉🏿' => 'nsaakyi indɛse a ɛkyerɛ nifa so: wedeε ani tuntum',
    '👆🏻' => 'nsaakyi indɛse a ɛkyerɛ soro so: wedeε ani a εda so',
    '👆🏼' => 'nsaakyi indɛse a ɛkyerɛ soro so: wedeε ani a εda so kakra',
    '👆🏽' => 'nsaakyi indɛse a ɛkyerɛ soro so: wedeε ani a εda hᴐ kakra',
    '👆🏾' => 'nsaakyi indɛse a ɛkyerɛ soro so: wedeε ani tuntum kakra',
    '👆🏿' => 'nsaakyi indɛse a ɛkyerɛ soro so: wedeε ani tuntum',
    '🖕🏻' => 'mfinimfini nsateaa: wedeε ani a εda so',
    '🖕🏼' => 'mfinimfini nsateaa: wedeε ani a εda so kakra',
    '🖕🏽' => 'mfinimfini nsateaa: wedeε ani a εda hᴐ kakra',
    '🖕🏾' => 'mfinimfini nsateaa: wedeε ani tuntum kakra',
    '🖕🏿' => 'mfinimfini nsateaa: wedeε ani tuntum',
    '👇🏻' => 'nsaakyi indɛse rekyerɛ fam: wedeε ani a εda so',
    '👇🏼' => 'nsaakyi indɛse rekyerɛ fam: wedeε ani a εda so kakra',
    '👇🏽' => 'nsaakyi indɛse rekyerɛ fam: wedeε ani a εda hᴐ kakra',
    '👇🏾' => 'nsaakyi indɛse rekyerɛ fam: wedeε ani tuntum kakra',
    '👇🏿' => 'nsaakyi indɛse rekyerɛ fam: wedeε ani tuntum',
    '☝🏻' => 'indɛse rekyerɛ soro: wedeε ani a εda so',
    '☝🏼' => 'indɛse rekyerɛ soro: wedeε ani a εda so kakra',
    '☝🏽' => 'indɛse rekyerɛ soro: wedeε ani a εda hᴐ kakra',
    '☝🏾' => 'indɛse rekyerɛ soro: wedeε ani tuntum kakra',
    '☝🏿' => 'indɛse rekyerɛ soro: wedeε ani tuntum',
    '🫵🏻' => 'indɛse rekyerɛ ɔhwɛfoɔ no so: wedeε ani a εda so',
    '🫵🏼' => 'indɛse rekyerɛ ɔhwɛfoɔ no so: wedeε ani a εda so kakra',
    '🫵🏽' => 'indɛse rekyerɛ ɔhwɛfoɔ no so: wedeε ani a εda hᴐ kakra',
    '🫵🏾' => 'indɛse rekyerɛ ɔhwɛfoɔ no so: wedeε ani tuntum kakra',
    '🫵🏿' => 'indɛse rekyerɛ ɔhwɛfoɔ no so: wedeε ani tuntum',
    '👍🏻' => 'kokuromotie a ɛkɔ soro: wedeε ani a εda so',
    '👍🏼' => 'kokuromotie a ɛkɔ soro: wedeε ani a εda so kakra',
    '👍🏽' => 'kokuromotie a ɛkɔ soro: wedeε ani a εda hᴐ kakra',
    '👍🏾' => 'kokuromotie a ɛkɔ soro: wedeε ani tuntum kakra',
    '👍🏿' => 'kokuromotie a ɛkɔ soro: wedeε ani tuntum',
    '👎🏻' => 'kokuromotie a ɛkɔ fam: wedeε ani a εda so',
    '👎🏼' => 'kokuromotie a ɛkɔ fam: wedeε ani a εda so kakra',
    '👎🏽' => 'kokuromotie a ɛkɔ fam: wedeε ani a εda hᴐ kakra',
    '👎🏾' => 'kokuromotie a ɛkɔ fam: wedeε ani tuntum kakra',
    '👎🏿' => 'kokuromotie a ɛkɔ fam: wedeε ani tuntum',
    '✊🏻' => 'twɛdeɛ a apagya: wedeε ani a εda so',
    '✊🏼' => 'twɛdeɛ a apagya: wedeε ani a εda so kakra',
    '✊🏽' => 'twɛdeɛ a apagya: wedeε ani a εda hᴐ kakra',
    '✊🏾' => 'twɛdeɛ a apagya: wedeε ani tuntum kakra',
    '✊🏿' => 'twɛdeɛ a apagya: wedeε ani tuntum',
    '👊🏻' => 'twɛdeɛ a ɛreba: wedeε ani a εda so',
    '👊🏼' => 'twɛdeɛ a ɛreba: wedeε ani a εda so kakra',
    '👊🏽' => 'twɛdeɛ a ɛreba: wedeε ani a εda hᴐ kakra',
    '👊🏾' => 'twɛdeɛ a ɛreba: wedeε ani tuntum kakra',
    '👊🏿' => 'twɛdeɛ a ɛreba: wedeε ani tuntum',
    '🤛🏻' => 'twɛdeɛ a ɛhwɛ benkum: wedeε ani a εda so',
    '🤛🏼' => 'twɛdeɛ a ɛhwɛ benkum: wedeε ani a εda so kakra',
    '🤛🏽' => 'twɛdeɛ a ɛhwɛ benkum: wedeε ani a εda hᴐ kakra',
    '🤛🏾' => 'twɛdeɛ a ɛhwɛ benkum: wedeε ani tuntum kakra',
    '🤛🏿' => 'twɛdeɛ a ɛhwɛ benkum: wedeε ani tuntum',
    '🤜🏻' => 'twɛdeɛ a ɛhwɛ nifa: wedeε ani a εda so',
    '🤜🏼' => 'twɛdeɛ a ɛhwɛ nifa: wedeε ani a εda so kakra',
    '🤜🏽' => 'twɛdeɛ a ɛhwɛ nifa: wedeε ani a εda hᴐ kakra',
    '🤜🏾' => 'twɛdeɛ a ɛhwɛ nifa: wedeε ani tuntum kakra',
    '🤜🏿' => 'twɛdeɛ a ɛhwɛ nifa: wedeε ani tuntum',
    '👏🏻' => 'nsa a ɛrebom: wedeε ani a εda so',
    '👏🏼' => 'nsa a ɛrebom: wedeε ani a εda so kakra',
    '👏🏽' => 'nsa a ɛrebom: wedeε ani a εda hᴐ kakra',
    '👏🏾' => 'nsa a ɛrebom: wedeε ani tuntum kakra',
    '👏🏿' => 'nsa a ɛrebom: wedeε ani tuntum',
    '🙌🏻' => 'nsa a ɛrepagya: wedeε ani a εda so',
    '🙌🏼' => 'nsa a ɛrepagya: wedeε ani a εda so kakra',
    '🙌🏽' => 'nsa a ɛrepagya: wedeε ani a εda hᴐ kakra',
    '🙌🏾' => 'nsa a ɛrepagya: wedeε ani tuntum kakra',
    '🙌🏿' => 'nsa a ɛrepagya: wedeε ani tuntum',
    '🫶🏻' => 'akoma nsa: wedeε ani a εda so',
    '🫶🏼' => 'akoma nsa: wedeε ani a εda so kakra',
    '🫶🏽' => 'akoma nsa: wedeε ani a εda hᴐ kakra',
    '🫶🏾' => 'akoma nsa: wedeε ani tuntum kakra',
    '🫶🏿' => 'akoma nsa: wedeε ani tuntum',
    '👐🏻' => 'nsa a abue: wedeε ani a εda so',
    '👐🏼' => 'nsa a abue: wedeε ani a εda so kakra',
    '👐🏽' => 'nsa a abue: wedeε ani a εda hᴐ kakra',
    '👐🏾' => 'nsa a abue: wedeε ani tuntum kakra',
    '👐🏿' => 'nsa a abue: wedeε ani tuntum',
    '🤲🏻' => 'nsateaa a ɛkɔ soro bom: wedeε ani a εda so',
    '🤲🏼' => 'nsateaa a ɛkɔ soro bom: wedeε ani a εda so kakra',
    '🤲🏽' => 'nsateaa a ɛkɔ soro bom: wedeε ani a εda hᴐ kakra',
    '🤲🏾' => 'nsateaa a ɛkɔ soro bom: wedeε ani tuntum kakra',
    '🤲🏿' => 'nsateaa a ɛkɔ soro bom: wedeε ani tuntum',
    '🤝🏻' => 'nsamkyea: wedeε ani a εda so',
    '🤝🏼' => 'nsamkyea: wedeε ani a εda so kakra',
    '🤝🏽' => 'nsamkyea: wedeε ani a εda hᴐ kakra',
    '🤝🏾' => 'nsamkyea: wedeε ani tuntum kakra',
    '🤝🏿' => 'nsamkyea: wedeε ani tuntum',
    '🙏🏻' => 'nsa a aka abom: wedeε ani a εda so',
    '🙏🏼' => 'nsa a aka abom: wedeε ani a εda so kakra',
    '🙏🏽' => 'nsa a aka abom: wedeε ani a εda hᴐ kakra',
    '🙏🏾' => 'nsa a aka abom: wedeε ani tuntum kakra',
    '🙏🏿' => 'nsa a aka abom: wedeε ani tuntum',
    '✍🏻' => 'nsa a wɔde twerɛ nsɛm: wedeε ani a εda so',
    '✍🏼' => 'nsa a wɔde twerɛ nsɛm: wedeε ani a εda so kakra',
    '✍🏽' => 'nsa a wɔde twerɛ nsɛm: wedeε ani a εda hᴐ kakra',
    '✍🏾' => 'nsa a wɔde twerɛ nsɛm: wedeε ani tuntum kakra',
    '✍🏿' => 'nsa a wɔde twerɛ nsɛm: wedeε ani tuntum',
    '💅🏻' => 'mmɔwerɛ pɔlihye: wedeε ani a εda so',
    '💅🏼' => 'mmɔwerɛ pɔlihye: wedeε ani a εda so kakra',
    '💅🏽' => 'mmɔwerɛ pɔlihye: wedeε ani a εda hᴐ kakra',
    '💅🏾' => 'mmɔwerɛ pɔlihye: wedeε ani tuntum kakra',
    '💅🏿' => 'mmɔwerɛ pɔlihye: wedeε ani tuntum',
    '🤳🏻' => 'selfie: wedeε ani a εda so',
    '🤳🏼' => 'selfie: wedeε ani a εda so kakra',
    '🤳🏽' => 'selfie: wedeε ani a εda hᴐ kakra',
    '🤳🏾' => 'selfie: wedeε ani tuntum kakra',
    '🤳🏿' => 'selfie: wedeε ani tuntum',
    '💪🏻' => 'baasɛpse a aflɛse: wedeε ani a εda so',
    '💪🏼' => 'baasɛpse a aflɛse: wedeε ani a εda so kakra',
    '💪🏽' => 'baasɛpse a aflɛse: wedeε ani a εda hᴐ kakra',
    '💪🏾' => 'baasɛpse a aflɛse: wedeε ani tuntum kakra',
    '💪🏿' => 'baasɛpse a aflɛse: wedeε ani tuntum',
    '🦵🏻' => 'nan: wedeε ani a εda so',
    '🦵🏼' => 'nan: wedeε ani a εda so kakra',
    '🦵🏽' => 'nan: wedeε ani a εda hᴐ kakra',
    '🦵🏾' => 'nan: wedeε ani tuntum kakra',
    '🦵🏿' => 'nan: wedeε ani tuntum',
    '🦶🏻' => 'nan ase: wedeε ani a εda so',
    '🦶🏼' => 'nan ase: wedeε ani a εda so kakra',
    '🦶🏽' => 'nan ase: wedeε ani a εda hᴐ kakra',
    '🦶🏾' => 'nan ase: wedeε ani tuntum kakra',
    '🦶🏿' => 'nan ase: wedeε ani tuntum',
    '👂🏻' => 'aso: wedeε ani a εda so',
    '👂🏼' => 'aso: wedeε ani a εda so kakra',
    '👂🏽' => 'aso: wedeε ani a εda hᴐ kakra',
    '👂🏾' => 'aso: wedeε ani tuntum kakra',
    '👂🏿' => 'aso: wedeε ani tuntum',
    '🦻🏻' => 'aso ne otie eede: wedeε ani a εda so',
    '🦻🏼' => 'aso ne otie eede: wedeε ani a εda so kakra',
    '🦻🏽' => 'aso ne otie eede: wedeε ani a εda hᴐ kakra',
    '🦻🏾' => 'aso ne otie eede: wedeε ani tuntum kakra',
    '🦻🏿' => 'aso ne otie eede: wedeε ani tuntum',
    '👃🏻' => 'hwene: wedeε ani a εda so',
    '👃🏼' => 'hwene: wedeε ani a εda so kakra',
    '👃🏽' => 'hwene: wedeε ani a εda hᴐ kakra',
    '👃🏾' => 'hwene: wedeε ani tuntum kakra',
    '👃🏿' => 'hwene: wedeε ani tuntum',
    '👶🏻' => 'abɔfra: wedeε ani a εda so',
    '👶🏼' => 'abɔfra: wedeε ani a εda so kakra',
    '👶🏽' => 'abɔfra: wedeε ani a εda hᴐ kakra',
    '👶🏾' => 'abɔfra: wedeε ani tuntum kakra',
    '👶🏿' => 'abɔfra: wedeε ani tuntum',
    '🧒🏻' => 'akwadaa: wedeε ani a εda so',
    '🧒🏼' => 'akwadaa: wedeε ani a εda so kakra',
    '🧒🏽' => 'akwadaa: wedeε ani a εda hᴐ kakra',
    '🧒🏾' => 'akwadaa: wedeε ani tuntum kakra',
    '🧒🏿' => 'akwadaa: wedeε ani tuntum',
    '👦🏻' => 'barima: wedeε ani a εda so',
    '👦🏼' => 'barima: wedeε ani a εda so kakra',
    '👦🏽' => 'barima: wedeε ani a εda hᴐ kakra',
    '👦🏾' => 'barima: wedeε ani tuntum kakra',
    '👦🏿' => 'barima: wedeε ani tuntum',
    '👧🏻' => 'ɔbaa: wedeε ani a εda so',
    '👧🏼' => 'ɔbaa: wedeε ani a εda so kakra',
    '👧🏽' => 'ɔbaa: wedeε ani a εda hᴐ kakra',
    '👧🏾' => 'ɔbaa: wedeε ani tuntum kakra',
    '👧🏿' => 'ɔbaa: wedeε ani tuntum',
    '🧑🏻' => 'onipa: wedeε ani a εda so',
    '🧑🏼' => 'onipa: wedeε ani a εda so kakra',
    '🧑🏽' => 'onipa: wedeε ani a εda hᴐ kakra',
    '🧑🏾' => 'onipa: wedeε ani tuntum kakra',
    '🧑🏿' => 'onipa: wedeε ani tuntum',
    '👱🏻' => 'onipa: wedeε ani a εda so ne nwii kɔkɔɔ',
    '👱🏼' => 'onipa: wedeε ani a εda so kakra ne nwii kɔkɔɔ',
    '👱🏽' => 'onipa: wedeε ani a εda hᴐ kakra ne nwii kɔkɔɔ',
    '👱🏾' => 'onipa: wedeε ani tuntum kakra ne nwii kɔkɔɔ',
    '👱🏿' => 'onipa: wedeε ani tuntum ne nwii kɔkɔɔ',
    '👨🏻' => 'ɔbarima: wedeε ani a εda so',
    '👨🏼' => 'ɔbarima: wedeε ani a εda so kakra',
    '👨🏽' => 'ɔbarima: wedeε ani a εda hᴐ kakra',
    '👨🏾' => 'ɔbarima: wedeε ani tuntum kakra',
    '👨🏿' => 'ɔbarima: wedeε ani tuntum',
    '🧔🏻' => 'onipa: wedeε ani a εda so ne abodwesɛ',
    '🧔🏼' => 'onipa: wedeε ani a εda so kakra ne abodwesɛ',
    '🧔🏽' => 'onipa: wedeε ani a εda hᴐ kakra ne abodwesɛ',
    '🧔🏾' => 'onipa: wedeε ani tuntum kakra ne abodwesɛ',
    '🧔🏿' => 'onipa: wedeε ani tuntum ne abodwesɛ',
    '👩🏻' => 'maame: wedeε ani a εda so',
    '👩🏼' => 'maame: wedeε ani a εda so kakra',
    '👩🏽' => 'maame: wedeε ani a εda hᴐ kakra',
    '👩🏾' => 'maame: wedeε ani tuntum kakra',
    '👩🏿' => 'maame: wedeε ani tuntum',
    '🧓🏻' => 'Onipa a wanyini: wedeε ani a εda so',
    '🧓🏼' => 'Onipa a wanyini: wedeε ani a εda so kakra',
    '🧓🏽' => 'Onipa a wanyini: wedeε ani a εda hᴐ kakra',
    '🧓🏾' => 'Onipa a wanyini: wedeε ani tuntum kakra',
    '🧓🏿' => 'Onipa a wanyini: wedeε ani tuntum',
    '👴🏻' => 'akwakora: wedeε ani a εda so',
    '👴🏼' => 'akwakora: wedeε ani a εda so kakra',
    '👴🏽' => 'akwakora: wedeε ani a εda hᴐ kakra',
    '👴🏾' => 'akwakora: wedeε ani tuntum kakra',
    '👴🏿' => 'akwakora: wedeε ani tuntum',
    '👵🏻' => 'abrewa: wedeε ani a εda so',
    '👵🏼' => 'abrewa: wedeε ani a εda so kakra',
    '👵🏽' => 'abrewa: wedeε ani a εda hᴐ kakra',
    '👵🏾' => 'abrewa: wedeε ani tuntum kakra',
    '👵🏿' => 'abrewa: wedeε ani tuntum',
    '🙍🏻' => 'onipa a wamuna: wedeε ani a εda so',
    '🙍🏼' => 'onipa a wamuna: wedeε ani a εda so kakra',
    '🙍🏽' => 'onipa a wamuna: wedeε ani a εda hᴐ kakra',
    '🙍🏾' => 'onipa a wamuna: wedeε ani tuntum kakra',
    '🙍🏿' => 'onipa a wamuna: wedeε ani tuntum',
    '🙎🏻' => 'onipa pɔɔtine: wedeε ani a εda so',
    '🙎🏼' => 'onipa pɔɔtine: wedeε ani a εda so kakra',
    '🙎🏽' => 'onipa pɔɔtine: wedeε ani a εda hᴐ kakra',
    '🙎🏾' => 'onipa pɔɔtine: wedeε ani tuntum kakra',
    '🙎🏿' => 'onipa pɔɔtine: wedeε ani tuntum',
    '🙅🏻' => 'onipa reyɛ DAABI nsɛnkyerɛnne: wedeε ani a εda so',
    '🙅🏼' => 'onipa reyɛ DAABI nsɛnkyerɛnne: wedeε ani a εda so kakra',
    '🙅🏽' => 'onipa reyɛ DAABI nsɛnkyerɛnne: wedeε ani a εda hᴐ kakra',
    '🙅🏾' => 'onipa reyɛ DAABI nsɛnkyerɛnne: wedeε ani tuntum kakra',
    '🙅🏿' => 'onipa reyɛ DAABI nsɛnkyerɛnne: wedeε ani tuntum',
    '🙆🏻' => 'onipa reyɛ OK nsɛnkyerɛnne: wedeε ani a εda so',
    '🙆🏼' => 'onipa reyɛ OK nsɛnkyerɛnne: wedeε ani a εda so kakra',
    '🙆🏽' => 'onipa reyɛ OK nsɛnkyerɛnne: wedeε ani a εda hᴐ kakra',
    '🙆🏾' => 'onipa reyɛ OK nsɛnkyerɛnne: wedeε ani tuntum kakra',
    '🙆🏿' => 'onipa reyɛ OK nsɛnkyerɛnne: wedeε ani tuntum',
    '💁🏻' => 'onipa tiipi nsa: wedeε ani a εda so',
    '💁🏼' => 'onipa tiipi nsa: wedeε ani a εda so kakra',
    '💁🏽' => 'onipa tiipi nsa: wedeε ani a εda hᴐ kakra',
    '💁🏾' => 'onipa tiipi nsa: wedeε ani tuntum kakra',
    '💁🏿' => 'onipa tiipi nsa: wedeε ani tuntum',
    '🙋🏻' => 'onipa repagya nsa: wedeε ani a εda so',
    '🙋🏼' => 'onipa repagya nsa: wedeε ani a εda so kakra',
    '🙋🏽' => 'onipa repagya nsa: wedeε ani a εda hᴐ kakra',
    '🙋🏾' => 'onipa repagya nsa: wedeε ani tuntum kakra',
    '🙋🏿' => 'onipa repagya nsa: wedeε ani tuntum',
    '🧏🏻' => 'ɛmum: wedeε ani a εda so',
    '🧏🏼' => 'ɛmum: wedeε ani a εda so kakra',
    '🧏🏽' => 'ɛmum: wedeε ani a εda hᴐ kakra',
    '🧏🏾' => 'ɛmum: wedeε ani tuntum kakra',
    '🧏🏿' => 'ɛmum: wedeε ani tuntum',
    '🙇🏻' => 'onipa rebɔ ne mu ase: wedeε ani a εda so',
    '🙇🏼' => 'onipa rebɔ ne mu ase: wedeε ani a εda so kakra',
    '🙇🏽' => 'onipa rebɔ ne mu ase: wedeε ani a εda hᴐ kakra',
    '🙇🏾' => 'onipa rebɔ ne mu ase: wedeε ani tuntum kakra',
    '🙇🏿' => 'onipa rebɔ ne mu ase: wedeε ani tuntum',
    '🤦🏻' => 'onipa de ne nsam ato n’anim: wedeε ani a εda so',
    '🤦🏼' => 'onipa de ne nsam ato n’anim: wedeε ani a εda so kakra',
    '🤦🏽' => 'onipa de ne nsam ato n’anim: wedeε ani a εda hᴐ kakra',
    '🤦🏾' => 'onipa de ne nsam ato n’anim: wedeε ani tuntum kakra',
    '🤦🏿' => 'onipa de ne nsam ato n’anim: wedeε ani tuntum',
    '🤷🏻' => 'onipa repagya ne mmati: wedeε ani a εda so',
    '🤷🏼' => 'onipa repagya ne mmati: wedeε ani a εda so kakra',
    '🤷🏽' => 'onipa repagya ne mmati: wedeε ani a εda hᴐ kakra',
    '🤷🏾' => 'onipa repagya ne mmati: wedeε ani tuntum kakra',
    '🤷🏿' => 'onipa repagya ne mmati: wedeε ani tuntum',
    '👮🏻' => 'Polisi ɔfesa: wedeε ani a εda so',
    '👮🏼' => 'Polisi ɔfesa: wedeε ani a εda so kakra',
    '👮🏽' => 'Polisi ɔfesa: wedeε ani a εda hᴐ kakra',
    '👮🏾' => 'Polisi ɔfesa: wedeε ani tuntum kakra',
    '👮🏿' => 'Polisi ɔfesa: wedeε ani tuntum',
    '🕵🏻' => 'detɛketifo: wedeε ani a εda so',
    '🕵🏼' => 'detɛketifo: wedeε ani a εda so kakra',
    '🕵🏽' => 'detɛketifo: wedeε ani a εda hᴐ kakra',
    '🕵🏾' => 'detɛketifo: wedeε ani tuntum kakra',
    '🕵🏿' => 'detɛketifo: wedeε ani tuntum',
    '💂🏻' => 'Banbɔfo: wedeε ani a εda so',
    '💂🏼' => 'Banbɔfo: wedeε ani a εda so kakra',
    '💂🏽' => 'Banbɔfo: wedeε ani a εda hᴐ kakra',
    '💂🏾' => 'Banbɔfo: wedeε ani tuntum kakra',
    '💂🏿' => 'Banbɔfo: wedeε ani tuntum',
    '🥷🏻' => 'Ningya: wedeε ani a εda so',
    '🥷🏼' => 'Ningya: wedeε ani a εda so kakra',
    '🥷🏽' => 'Ningya: wedeε ani a εda hᴐ kakra',
    '🥷🏾' => 'Ningya: wedeε ani tuntum kakra',
    '🥷🏿' => 'Ningya: wedeε ani tuntum',
    '👷🏻' => 'Adansie dwumayɛni: wedeε ani a εda so',
    '👷🏼' => 'Adansie dwumayɛni: wedeε ani a εda so kakra',
    '👷🏽' => 'Adansie dwumayɛni: wedeε ani a εda hᴐ kakra',
    '👷🏾' => 'Adansie dwumayɛni: wedeε ani tuntum kakra',
    '👷🏿' => 'Adansie dwumayɛni: wedeε ani tuntum',
    '🫅🏻' => 'Obi a ɔhyɛ ahenkyɛ: wedeε ani a εda so',
    '🫅🏼' => 'Obi a ɔhyɛ ahenkyɛ: wedeε ani a εda so kakra',
    '🫅🏽' => 'Obi a ɔhyɛ ahenkyɛ: wedeε ani a εda hᴐ kakra',
    '🫅🏾' => 'Obi a ɔhyɛ ahenkyɛ: wedeε ani tuntum kakra',
    '🫅🏿' => 'Obi a ɔhyɛ ahenkyɛ: wedeε ani tuntum',
    '🤴🏻' => 'Prense: wedeε ani a εda so',
    '🤴🏼' => 'Prense: wedeε ani a εda so kakra',
    '🤴🏽' => 'Prense: wedeε ani a εda hᴐ kakra',
    '🤴🏾' => 'Prense: wedeε ani tuntum kakra',
    '🤴🏿' => 'Prense: wedeε ani tuntum',
    '👸🏻' => 'prensɛse: wedeε ani a εda so',
    '👸🏼' => 'prensɛse: wedeε ani a εda so kakra',
    '👸🏽' => 'prensɛse: wedeε ani a εda hᴐ kakra',
    '👸🏾' => 'prensɛse: wedeε ani tuntum kakra',
    '👸🏿' => 'prensɛse: wedeε ani tuntum',
    '👳🏻' => 'Obi hyɛ tɛɛban: wedeε ani a εda so',
    '👳🏼' => 'Obi hyɛ tɛɛban: wedeε ani a εda so kakra',
    '👳🏽' => 'Obi hyɛ tɛɛban: wedeε ani a εda hᴐ kakra',
    '👳🏾' => 'Obi hyɛ tɛɛban: wedeε ani tuntum kakra',
    '👳🏿' => 'Obi hyɛ tɛɛban: wedeε ani tuntum',
    '👲🏻' => 'Obi a ɔhyɛ skɔɔlekap: wedeε ani a εda so',
    '👲🏼' => 'Obi a ɔhyɛ skɔɔlekap: wedeε ani a εda so kakra',
    '👲🏽' => 'Obi a ɔhyɛ skɔɔlekap: wedeε ani a εda hᴐ kakra',
    '👲🏾' => 'Obi a ɔhyɛ skɔɔlekap: wedeε ani tuntum kakra',
    '👲🏿' => 'Obi a ɔhyɛ skɔɔlekap: wedeε ani tuntum',
    '🧕🏻' => 'Ɔbaa wabɔ duku: wedeε ani a εda so',
    '🧕🏼' => 'Ɔbaa wabɔ duku: wedeε ani a εda so kakra',
    '🧕🏽' => 'Ɔbaa wabɔ duku: wedeε ani a εda hᴐ kakra',
    '🧕🏾' => 'Ɔbaa wabɔ duku: wedeε ani tuntum kakra',
    '🧕🏿' => 'Ɔbaa wabɔ duku: wedeε ani tuntum',
    '🤵🏻' => 'Obi a ɔhyɛ tɔseedo: wedeε ani a εda so',
    '🤵🏼' => 'Obi a ɔhyɛ tɔseedo: wedeε ani a εda so kakra',
    '🤵🏽' => 'Obi a ɔhyɛ tɔseedo: wedeε ani a εda hᴐ kakra',
    '🤵🏾' => 'Obi a ɔhyɛ tɔseedo: wedeε ani tuntum kakra',
    '🤵🏿' => 'Obi a ɔhyɛ tɔseedo: wedeε ani tuntum',
    '👰🏻' => 'Obi ne veil: wedeε ani a εda so',
    '👰🏼' => 'Obi ne veil: wedeε ani a εda so kakra',
    '👰🏽' => 'Obi ne veil: wedeε ani a εda hᴐ kakra',
    '👰🏾' => 'Obi ne veil: wedeε ani tuntum kakra',
    '👰🏿' => 'Obi ne veil: wedeε ani tuntum',
    '🤰🏻' => 'Ɔbaa a ɔnyem: wedeε ani a εda so',
    '🤰🏼' => 'Ɔbaa a ɔnyem: wedeε ani a εda so kakra',
    '🤰🏽' => 'Ɔbaa a ɔnyem: wedeε ani a εda hᴐ kakra',
    '🤰🏾' => 'Ɔbaa a ɔnyem: wedeε ani tuntum kakra',
    '🤰🏿' => 'Ɔbaa a ɔnyem: wedeε ani tuntum',
    '🫃🏻' => 'Barima a ɔnyem: wedeε ani a εda so',
    '🫃🏼' => 'Barima a ɔnyem: wedeε ani a εda so kakra',
    '🫃🏽' => 'Barima a ɔnyem: wedeε ani a εda hᴐ kakra',
    '🫃🏾' => 'Barima a ɔnyem: wedeε ani tuntum kakra',
    '🫃🏿' => 'Barima a ɔnyem: wedeε ani tuntum',
    '🫄🏻' => 'Obi a ɔnyem: wedeε ani a εda so',
    '🫄🏼' => 'Obi a ɔnyem: wedeε ani a εda so kakra',
    '🫄🏽' => 'Obi a ɔnyem: wedeε ani a εda hᴐ kakra',
    '🫄🏾' => 'Obi a ɔnyem: wedeε ani tuntum kakra',
    '🫄🏿' => 'Obi a ɔnyem: wedeε ani tuntum',
    '🤱🏻' => 'nufuoɔma: wedeε ani a εda so',
    '🤱🏼' => 'nufuoɔma: wedeε ani a εda so kakra',
    '🤱🏽' => 'nufuoɔma: wedeε ani a εda hᴐ kakra',
    '🤱🏾' => 'nufuoɔma: wedeε ani tuntum kakra',
    '🤱🏿' => 'nufuoɔma: wedeε ani tuntum',
    '👼🏻' => 'Ɔbɔfoɔ akwadaa: wedeε ani a εda so',
    '👼🏼' => 'Ɔbɔfoɔ akwadaa: wedeε ani a εda so kakra',
    '👼🏽' => 'Ɔbɔfoɔ akwadaa: wedeε ani a εda hᴐ kakra',
    '👼🏾' => 'Ɔbɔfoɔ akwadaa: wedeε ani tuntum kakra',
    '👼🏿' => 'Ɔbɔfoɔ akwadaa: wedeε ani tuntum',
    '🎅🏻' => 'Santa Klauso: wedeε ani a εda so',
    '🎅🏼' => 'Santa Klauso: wedeε ani a εda so kakra',
    '🎅🏽' => 'Santa Klauso: wedeε ani a εda hᴐ kakra',
    '🎅🏾' => 'Santa Klauso: wedeε ani tuntum kakra',
    '🎅🏿' => 'Santa Klauso: wedeε ani tuntum',
    '🤶🏻' => 'Mrs. Klauso: wedeε ani a εda so',
    '🤶🏼' => 'Mrs. Klauso: wedeε ani a εda so kakra',
    '🤶🏽' => 'Mrs. Klauso: wedeε ani a εda hᴐ kakra',
    '🤶🏾' => 'Mrs. Klauso: wedeε ani tuntum kakra',
    '🤶🏿' => 'Mrs. Klauso: wedeε ani tuntum',
    '🦸🏻' => 'Supahero: wedeε ani a εda so',
    '🦸🏼' => 'Supahero: wedeε ani a εda so kakra',
    '🦸🏽' => 'Supahero: wedeε ani a εda hᴐ kakra',
    '🦸🏾' => 'Supahero: wedeε ani tuntum kakra',
    '🦸🏿' => 'Supahero: wedeε ani tuntum',
    '🦹🏻' => 'Supaviliane: wedeε ani a εda so',
    '🦹🏼' => 'Supaviliane: wedeε ani a εda so kakra',
    '🦹🏽' => 'Supaviliane: wedeε ani a εda hᴐ kakra',
    '🦹🏾' => 'Supaviliane: wedeε ani tuntum kakra',
    '🦹🏿' => 'Supaviliane: wedeε ani tuntum',
    '🧙🏻' => 'nkonyaayifoͻ: wedeε ani a εda so',
    '🧙🏼' => 'nkonyaayifoͻ: wedeε ani a εda so kakra',
    '🧙🏽' => 'nkonyaayifoͻ: wedeε ani a εda hᴐ kakra',
    '🧙🏾' => 'nkonyaayifoͻ: wedeε ani tuntum kakra',
    '🧙🏿' => 'nkonyaayifoͻ: wedeε ani tuntum',
    '🧚🏻' => 'Fɛɛre: wedeε ani a εda so',
    '🧚🏼' => 'Fɛɛre: wedeε ani a εda so kakra',
    '🧚🏽' => 'Fɛɛre: wedeε ani a εda hᴐ kakra',
    '🧚🏾' => 'Fɛɛre: wedeε ani tuntum kakra',
    '🧚🏿' => 'Fɛɛre: wedeε ani tuntum',
    '🧛🏻' => 'Vampaya: wedeε ani a εda so',
    '🧛🏼' => 'Vampaya: wedeε ani a εda so kakra',
    '🧛🏽' => 'Vampaya: wedeε ani a εda hᴐ kakra',
    '🧛🏾' => 'Vampaya: wedeε ani tuntum kakra',
    '🧛🏿' => 'Vampaya: wedeε ani tuntum',
    '🧜🏻' => 'Mɛɛnipa: wedeε ani a εda so',
    '🧜🏼' => 'Mɛɛnipa: wedeε ani a εda so kakra',
    '🧜🏽' => 'Mɛɛnipa: wedeε ani a εda hᴐ kakra',
    '🧜🏾' => 'Mɛɛnipa: wedeε ani tuntum kakra',
    '🧜🏿' => 'Mɛɛnipa: wedeε ani tuntum',
    '🧝🏻' => 'ɛlefo: wedeε ani a εda so',
    '🧝🏼' => 'ɛlefo: wedeε ani a εda so kakra',
    '🧝🏽' => 'ɛlefo: wedeε ani a εda hᴐ kakra',
    '🧝🏾' => 'ɛlefo: wedeε ani tuntum kakra',
    '🧝🏿' => 'ɛlefo: wedeε ani tuntum',
    '💆🏻' => 'Onipa renya amiamia: wedeε ani a εda so',
    '💆🏼' => 'Onipa renya amiamia: wedeε ani a εda so kakra',
    '💆🏽' => 'Onipa renya amiamia: wedeε ani a εda hᴐ kakra',
    '💆🏾' => 'Onipa renya amiamia: wedeε ani tuntum kakra',
    '💆🏿' => 'Onipa renya amiamia: wedeε ani tuntum',
    '💇🏻' => 'Wɔretwa obi nwii: wedeε ani a εda so',
    '💇🏼' => 'Wɔretwa obi nwii: wedeε ani a εda so kakra',
    '💇🏽' => 'Wɔretwa obi nwii: wedeε ani a εda hᴐ kakra',
    '💇🏾' => 'Wɔretwa obi nwii: wedeε ani tuntum kakra',
    '💇🏿' => 'Wɔretwa obi nwii: wedeε ani tuntum',
    '🚶🏻' => 'Onipa renante: wedeε ani a εda so',
    '🚶🏼' => 'Onipa renante: wedeε ani a εda so kakra',
    '🚶🏽' => 'Onipa renante: wedeε ani a εda hᴐ kakra',
    '🚶🏾' => 'Onipa renante: wedeε ani tuntum kakra',
    '🚶🏿' => 'Onipa renante: wedeε ani tuntum',
    '🧍🏻' => 'Onipa gyina hɔ: wedeε ani a εda so',
    '🧍🏼' => 'Onipa gyina hɔ: wedeε ani a εda so kakra',
    '🧍🏽' => 'Onipa gyina hɔ: wedeε ani a εda hᴐ kakra',
    '🧍🏾' => 'Onipa gyina hɔ: wedeε ani tuntum kakra',
    '🧍🏿' => 'Onipa gyina hɔ: wedeε ani tuntum',
    '🧎🏻' => 'Obi abu nkotodwe: wedeε ani a εda so',
    '🧎🏼' => 'Obi abu nkotodwe: wedeε ani a εda so kakra',
    '🧎🏽' => 'Obi abu nkotodwe: wedeε ani a εda hᴐ kakra',
    '🧎🏾' => 'Obi abu nkotodwe: wedeε ani tuntum kakra',
    '🧎🏿' => 'Obi abu nkotodwe: wedeε ani tuntum',
    '🏃🏻' => 'Obi retu mmirika: wedeε ani a εda so',
    '🏃🏼' => 'Obi retu mmirika: wedeε ani a εda so kakra',
    '🏃🏽' => 'Obi retu mmirika: wedeε ani a εda hᴐ kakra',
    '🏃🏾' => 'Obi retu mmirika: wedeε ani tuntum kakra',
    '🏃🏿' => 'Obi retu mmirika: wedeε ani tuntum',
    '💃🏻' => 'Ɔbaa resa: wedeε ani a εda so',
    '💃🏼' => 'Ɔbaa resa: wedeε ani a εda so kakra',
    '💃🏽' => 'Ɔbaa resa: wedeε ani a εda hᴐ kakra',
    '💃🏾' => 'Ɔbaa resa: wedeε ani tuntum kakra',
    '💃🏿' => 'Ɔbaa resa: wedeε ani tuntum',
    '🕺🏻' => 'Barima resa: wedeε ani a εda so',
    '🕺🏼' => 'Barima resa: wedeε ani a εda so kakra',
    '🕺🏽' => 'Barima resa: wedeε ani a εda hᴐ kakra',
    '🕺🏾' => 'Barima resa: wedeε ani tuntum kakra',
    '🕺🏿' => 'Barima resa: wedeε ani tuntum',
    '🕴🏻' => 'Obi hyɛ suutu retu kɔ soro: wedeε ani a εda so',
    '🕴🏼' => 'Obi hyɛ suutu retu kɔ soro: wedeε ani a εda so kakra',
    '🕴🏽' => 'Obi hyɛ suutu retu kɔ soro: wedeε ani a εda hᴐ kakra',
    '🕴🏾' => 'Obi hyɛ suutu retu kɔ soro: wedeε ani tuntum kakra',
    '🕴🏿' => 'Obi hyɛ suutu retu kɔ soro: wedeε ani tuntum',
    '👯🏻' => 'Nkurɔfoɔ wɔ adanko aso: wedeε ani a εda so',
    '👯🏼' => 'Nkurɔfoɔ wɔ adanko aso: wedeε ani a εda so kakra',
    '👯🏽' => 'Nkurɔfoɔ wɔ adanko aso: wedeε ani a εda hᴐ kakra',
    '👯🏾' => 'Nkurɔfoɔ wɔ adanko aso: wedeε ani tuntum kakra',
    '👯🏿' => 'Nkurɔfoɔ wɔ adanko aso: wedeε ani tuntum',
    '🧖🏻' => 'Obi wɔ ɛhyew dan mu: wedeε ani a εda so',
    '🧖🏼' => 'Obi wɔ ɛhyew dan mu: wedeε ani a εda so kakra',
    '🧖🏽' => 'Obi wɔ ɛhyew dan mu: wedeε ani a εda hᴐ kakra',
    '🧖🏾' => 'Obi wɔ ɛhyew dan mu: wedeε ani tuntum kakra',
    '🧖🏿' => 'Obi wɔ ɛhyew dan mu: wedeε ani tuntum',
    '🧗🏻' => 'Obi reforo: wedeε ani a εda so',
    '🧗🏼' => 'Obi reforo: wedeε ani a εda so kakra',
    '🧗🏽' => 'Obi reforo: wedeε ani a εda hᴐ kakra',
    '🧗🏾' => 'Obi reforo: wedeε ani tuntum kakra',
    '🧗🏿' => 'Obi reforo: wedeε ani tuntum',
    '🏇🏻' => 'Pɔnko akansie: wedeε ani a εda so',
    '🏇🏼' => 'Pɔnko akansie: wedeε ani a εda so kakra',
    '🏇🏽' => 'Pɔnko akansie: wedeε ani a εda hᴐ kakra',
    '🏇🏾' => 'Pɔnko akansie: wedeε ani tuntum kakra',
    '🏇🏿' => 'Pɔnko akansie: wedeε ani tuntum',
    '🏂🏻' => 'Sonoobɔda: wedeε ani a εda so',
    '🏂🏼' => 'Sonoobɔda: wedeε ani a εda so kakra',
    '🏂🏽' => 'Sonoobɔda: wedeε ani a εda hᴐ kakra',
    '🏂🏾' => 'Sonoobɔda: wedeε ani tuntum kakra',
    '🏂🏿' => 'Sonoobɔda: wedeε ani tuntum',
    '🏌🏻' => 'Obi regɔɔfo: wedeε ani a εda so',
    '🏌🏼' => 'Obi regɔɔfo: wedeε ani a εda so kakra',
    '🏌🏽' => 'Obi regɔɔfo: wedeε ani a εda hᴐ kakra',
    '🏌🏾' => 'Obi regɔɔfo: wedeε ani tuntum kakra',
    '🏌🏿' => 'Obi regɔɔfo: wedeε ani tuntum',
    '🏄🏻' => 'obi resεεfe: wedeε ani a εda so',
    '🏄🏼' => 'obi resεεfe: wedeε ani a εda so kakra',
    '🏄🏽' => 'obi resεεfe: wedeε ani a εda hᴐ kakra',
    '🏄🏾' => 'obi resεεfe: wedeε ani tuntum kakra',
    '🏄🏿' => 'obi resεεfe: wedeε ani tuntum',
    '🚣🏻' => 'Obi reka kodoɔ: wedeε ani a εda so',
    '🚣🏼' => 'Obi reka kodoɔ: wedeε ani a εda so kakra',
    '🚣🏽' => 'Obi reka kodoɔ: wedeε ani a εda hᴐ kakra',
    '🚣🏾' => 'Obi reka kodoɔ: wedeε ani tuntum kakra',
    '🚣🏿' => 'Obi reka kodoɔ: wedeε ani tuntum',
    '🏊🏻' => 'Obi reboro nsuo: wedeε ani a εda so',
    '🏊🏼' => 'Obi reboro nsuo: wedeε ani a εda so kakra',
    '🏊🏽' => 'Obi reboro nsuo: wedeε ani a εda hᴐ kakra',
    '🏊🏾' => 'Obi reboro nsuo: wedeε ani tuntum kakra',
    '🏊🏿' => 'Obi reboro nsuo: wedeε ani tuntum',
    '⛹🏻' => 'Obi rebɔ bɔɔlo: wedeε ani a εda so',
    '⛹🏼' => 'Obi rebɔ bɔɔlo: wedeε ani a εda so kakra',
    '⛹🏽' => 'Obi rebɔ bɔɔlo: wedeε ani a εda hᴐ kakra',
    '⛹🏾' => 'Obi rebɔ bɔɔlo: wedeε ani tuntum kakra',
    '⛹🏿' => 'Obi rebɔ bɔɔlo: wedeε ani tuntum',
    '🏋🏻' => 'Obi repagya nnadeɛ: wedeε ani a εda so',
    '🏋🏼' => 'Obi repagya nnadeɛ: wedeε ani a εda so kakra',
    '🏋🏽' => 'Obi repagya nnadeɛ: wedeε ani a εda hᴐ kakra',
    '🏋🏾' => 'Obi repagya nnadeɛ: wedeε ani tuntum kakra',
    '🏋🏿' => 'Obi repagya nnadeɛ: wedeε ani tuntum',
    '🚴🏻' => 'Obi retwi sakre: wedeε ani a εda so',
    '🚴🏼' => 'Obi retwi sakre: wedeε ani a εda so kakra',
    '🚴🏽' => 'Obi retwi sakre: wedeε ani a εda hᴐ kakra',
    '🚴🏾' => 'Obi retwi sakre: wedeε ani tuntum kakra',
    '🚴🏿' => 'Obi retwi sakre: wedeε ani tuntum',
    '🚵🏻' => 'Obi retwi sakre wɔ bepɔ so: wedeε ani a εda so',
    '🚵🏼' => 'Obi retwi sakre wɔ bepɔ so: wedeε ani a εda so kakra',
    '🚵🏽' => 'Obi retwi sakre wɔ bepɔ so: wedeε ani a εda hᴐ kakra',
    '🚵🏾' => 'Obi retwi sakre wɔ bepɔ so: wedeε ani tuntum kakra',
    '🚵🏿' => 'Obi retwi sakre wɔ bepɔ so: wedeε ani tuntum',
    '🤸🏻' => 'Obi retwi kaate: wedeε ani a εda so',
    '🤸🏼' => 'Obi retwi kaate: wedeε ani a εda so kakra',
    '🤸🏽' => 'Obi retwi kaate: wedeε ani a εda hᴐ kakra',
    '🤸🏾' => 'Obi retwi kaate: wedeε ani tuntum kakra',
    '🤸🏿' => 'Obi retwi kaate: wedeε ani tuntum',
    '🤼🏻' => 'Nkurɔfoɔ retentam: wedeε ani a εda so',
    '🤼🏼' => 'Nkurɔfoɔ retentam: wedeε ani a εda so kakra',
    '🤼🏽' => 'Nkurɔfoɔ retentam: wedeε ani a εda hᴐ kakra',
    '🤼🏾' => 'Nkurɔfoɔ retentam: wedeε ani tuntum kakra',
    '🤼🏿' => 'Nkurɔfoɔ retentam: wedeε ani tuntum',
    '🤽🏻' => 'Obi rebɔ polo nsuo: wedeε ani a εda so',
    '🤽🏼' => 'Obi rebɔ polo nsuo: wedeε ani a εda so kakra',
    '🤽🏽' => 'Obi rebɔ polo nsuo: wedeε ani a εda hᴐ kakra',
    '🤽🏾' => 'Obi rebɔ polo nsuo: wedeε ani tuntum kakra',
    '🤽🏿' => 'Obi rebɔ polo nsuo: wedeε ani tuntum',
    '🤾🏻' => 'Obi rebɔ nsabɔɔlo: wedeε ani a εda so',
    '🤾🏼' => 'Obi rebɔ nsabɔɔlo: wedeε ani a εda so kakra',
    '🤾🏽' => 'Obi rebɔ nsabɔɔlo: wedeε ani a εda hᴐ kakra',
    '🤾🏾' => 'Obi rebɔ nsabɔɔlo: wedeε ani tuntum kakra',
    '🤾🏿' => 'Obi rebɔ nsabɔɔlo: wedeε ani tuntum',
    '🤹🏻' => 'Obi retoto bɔɔlo: wedeε ani a εda so',
    '🤹🏼' => 'Obi retoto bɔɔlo: wedeε ani a εda so kakra',
    '🤹🏽' => 'Obi retoto bɔɔlo: wedeε ani a εda hᴐ kakra',
    '🤹🏾' => 'Obi retoto bɔɔlo: wedeε ani tuntum kakra',
    '🤹🏿' => 'Obi retoto bɔɔlo: wedeε ani tuntum',
    '🧘🏻' => 'Obi ayɛ lɔtusu posihyen: wedeε ani a εda so',
    '🧘🏼' => 'Obi ayɛ lɔtusu posihyen: wedeε ani a εda so kakra',
    '🧘🏽' => 'Obi ayɛ lɔtusu posihyen: wedeε ani a εda hᴐ kakra',
    '🧘🏾' => 'Obi ayɛ lɔtusu posihyen: wedeε ani tuntum kakra',
    '🧘🏿' => 'Obi ayɛ lɔtusu posihyen: wedeε ani tuntum',
    '🛀🏻' => 'Obi redware: wedeε ani a εda so',
    '🛀🏼' => 'Obi redware: wedeε ani a εda so kakra',
    '🛀🏽' => 'Obi redware: wedeε ani a εda hᴐ kakra',
    '🛀🏾' => 'Obi redware: wedeε ani tuntum kakra',
    '🛀🏿' => 'Obi redware: wedeε ani tuntum',
    '🛌🏻' => 'Onipa da mpa mu: wedeε ani a εda so',
    '🛌🏼' => 'Onipa da mpa mu: wedeε ani a εda so kakra',
    '🛌🏽' => 'Onipa da mpa mu: wedeε ani a εda hᴐ kakra',
    '🛌🏾' => 'Onipa da mpa mu: wedeε ani tuntum kakra',
    '🛌🏿' => 'Onipa da mpa mu: wedeε ani tuntum',
    '👭🏻' => 'Mmaa asɔ nsam: wedeε ani a εda so',
    '👭🏼' => 'Mmaa asɔ nsam: wedeε ani a εda so kakra',
    '👭🏽' => 'Mmaa asɔ nsam: wedeε ani a εda hᴐ kakra',
    '👭🏾' => 'Mmaa asɔ nsam: wedeε ani tuntum kakra',
    '👭🏿' => 'Mmaa asɔ nsam: wedeε ani tuntum',
    '👫🏻' => 'Ɔbaa ne barima asɔ nsam: wedeε ani a εda so',
    '👫🏼' => 'Ɔbaa ne barima asɔ nsam: wedeε ani a εda so kakra',
    '👫🏽' => 'Ɔbaa ne barima asɔ nsam: wedeε ani a εda hᴐ kakra',
    '👫🏾' => 'Ɔbaa ne barima asɔ nsam: wedeε ani tuntum kakra',
    '👫🏿' => 'Ɔbaa ne barima asɔ nsam: wedeε ani tuntum',
    '👬🏻' => 'Mmarima asɔ nsam: wedeε ani a εda so',
    '👬🏼' => 'Mmarima asɔ nsam: wedeε ani a εda so kakra',
    '👬🏽' => 'Mmarima asɔ nsam: wedeε ani a εda hᴐ kakra',
    '👬🏾' => 'Mmarima asɔ nsam: wedeε ani tuntum kakra',
    '👬🏿' => 'Mmarima asɔ nsam: wedeε ani tuntum',
    '💏🏻' => 'Mfeano: wedeε ani a εda so',
    '💏🏼' => 'Mfeano: wedeε ani a εda so kakra',
    '💏🏽' => 'Mfeano: wedeε ani a εda hᴐ kakra',
    '💏🏾' => 'Mfeano: wedeε ani tuntum kakra',
    '💏🏿' => 'Mfeano: wedeε ani tuntum',
    '💑🏻' => 'Awarefoɔ ne akoma: wedeε ani a εda so',
    '💑🏼' => 'Awarefoɔ ne akoma: wedeε ani a εda so kakra',
    '💑🏽' => 'Awarefoɔ ne akoma: wedeε ani a εda hᴐ kakra',
    '💑🏾' => 'Awarefoɔ ne akoma: wedeε ani tuntum kakra',
    '💑🏿' => 'Awarefoɔ ne akoma: wedeε ani tuntum',
    '🔟' => 'kiikape: 10',
    '🏻' => 'wedeε ani a εda so',
    '🏼' => 'wedeε ani a εda so kakra',
    '🏽' => 'wedeε ani a εda hᴐ kakra',
    '🏾' => 'wedeε ani tuntum kakra',
    '🏿' => 'wedeε ani tuntum',
    '😀' => 'anim a ԑresere',
    '😃' => 'anim a ɛseresere a na’ni yɛ akɛseɛ',
    '😄' => 'sereɛ anim ne aniwa a ɛsere',
    '😁' => 'serewee anim ne ani a ɛresere',
    '😆' => 'anim a ԑrehwԑ adeԑ fee',
    '😅' => 'anweneanwene anim a mfifire wom',
    '🤣' => 'remunimuni fam resere',
    '😂' => 'ani ne aniye nisuo',
    '🙂' => 'anim a ɛresere kakraa bi',
    '🙃' => 'anim a asi ase',
    '🫠' => 'anim a ɛrenane',
    '😉' => 'anim ne ani a ɛkata ntɛm',
    '😊' => 'serewee anim ne serewee ani',
    '😇' => 'serewee anim ne halo',
    '🥰' => 'sereɛ anim ne akoma',
    '😍' => 'sereɛ anim ne akoma ani',
    '🤩' => 'setaa-straake',
    '😘' => 'anim rehu mfeano',
    '😗' => 'mfeano anim',
    '☺' => 'serewee anim',
    '😚' => 'mfeano anim ne aniwa a akata',
    '😙' => 'mfeano anim ne sereɛ ani',
    '🥲' => 'serewee anim ne nisuo',
    '😋' => 'anim kɔn adɔ aduane',
    '😛' => 'anim ne tɛkrɛma',
    '😜' => 'winkee anim ne tɛkrɛma',
    '🤪' => 'zani anim',
    '😝' => 'anim a amia ne tɛkrɛma',
    '🤑' => 'sika-ano anim',
    '🤗' => 'serewee anim ne nsa a emu abue',
    '🤭' => 'anim ne nsa a akata ano',
    '🫢' => 'anim ne ani a abue ne nsa a akata ano',
    '🫣' => 'anim ne ani a ɛtetɛ',
    '🤫' => 'ka ano tom anim',
    '🤔' => 'redwene anim',
    '🫡' => 'kuruse anim',
    '🤐' => 'ziipa-ano anim',
    '🤨' => 'anim ne aniakyi nwii a apagya',
    '😐' => 'neetraa anim',
    '😑' => 'anim a atenka biara nni mu',
    '😶' => 'anim a ɛnni ano',
    '🫥' => 'nsensaneɛ mmubueɛ anim',
    '😏' => 'sedeɛ anim',
    '😒' => 'anim a ɛnyɛ anigye',
    '🙄' => 'anim ne ani a ɛretware',
    '😬' => 'grɛmaasin anim',
    '🤥' => 'atorɔ anim',
    '🫨' => 'anim a ɛrewoso',
    '😌' => 'ahotɔ anim',
    '😔' => 'awerɛhodie anim',
    '😪' => 'anikum anim',
    '🤤' => 'anosuo anim',
    '😴' => 'nna anim',
    '🫩' => 'anim a baage wɔ n’ani ase',
    '😷' => 'anim ne mɛdikaa nkatanim',
    '🤒' => 'anim ne tɛmɔmita',
    '🤕' => 'anim ne ti baanegye',
    '🤢' => 'abofono anim',
    '🤮' => 'anim a ɛrefe',
    '🤧' => 'hwansie anim',
    '🥵' => 'hyew anim',
    '🥶' => 'anim nwununwunu',
    '🥴' => 'woosi anim',
    '😵' => 'anim ne ani a wɔatwam',
    '🤯' => 'ti a apae',
    '🤠' => 'kaawboe kyɛ anim',
    '🥳' => 'paati anim',
    '🥸' => 'disgaase anim',
    '😎' => 'serewee anim ne sanglasese',
    '🤓' => 'nɛɛde anim',
    '🧐' => 'anim ne monokeele',
    '😕' => 'anim a ɛyɛ basaa',
    '🫤' => 'anim ne ano a akyea',
    '😟' => 'anim basaa',
    '🙁' => 'anim a amuna kakraa bi',
    '☹' => 'anim a amuna',
    '😮' => 'anim ne ano a abue',
    '😯' => 'ahodwiri anim',
    '😲' => 'nwanwa anim',
    '😳' => 'flɔhye anim',
    '🫪' => 'anim a asɛe',
    '🥺' => 'akyɛwpa anim',
    '🥹' => 'anim a ɛretwe nisuo san',
    '😦' => 'anim a amuna ne ano a abue',
    '😧' => 'yeaa anim',
    '😨' => 'suro anim',
    '😰' => 'anim basaa ne mfifire',
    '😥' => 'awerɛhoɔ nanso ahotɔ anim',
    '😢' => 'esu anim',
    '😭' => 'su denden anim',
    '😱' => 'anim teɛteɛm wɔ ehu mu',
    '😖' => 'basaa anim',
    '😣' => 'nkoden anim',
    '😞' => 'huammɔ anim',
    '😓' => 'awerɛhoɔ anim ne mfifire',
    '😩' => 'anim a abrɛ',
    '😫' => 'brɛ anim',
    '🥱' => 'heram anim',
    '😤' => 'anim a wusie firi hwenem pue',
    '😡' => 'kokopae anim',
    '😠' => 'abufuo anim',
    '🤬' => 'anim a ɛwɔ simboo',
    '😈' => 'anim a ɛresere ne mmɛn',
    '👿' => 'abufuo anim ne mmɛn',
    '💀' => 'tikora',
    '☠' => 'tikora ne nnompe a wɔtwam',
    '💩' => 'agyanan boa',
    '🤡' => 'klaawo anim',
    '👹' => 'ɔɔga',
    '👺' => 'gɔɔbeline',
    '👻' => 'saman',
    '👽' => 'aaliene',
    '👾' => 'aaliene sasabonsam',
    '🤖' => 'robɔto',
    '😺' => 'ɔkra resere',
    '😸' => 'ɔkra ne ani a ɛresere',
    '😹' => 'ɔkra a ɔde anigyeɛ nisuo resu',
    '😻' => 'ɔkra a ɔresere a n’ani yɛ akoma',
    '😼' => 'ɔkra ne sereɛ a akyim',
    '😽' => 'ɔkra a ɔrefe ano',
    '🙀' => 'ɔkra a wabrɛ',
    '😿' => 'ɔkra a ɔresu',
    '😾' => 'ɔkra a wadwa',
    '🙈' => 'nhwɛ-bɔne-biara adoe',
    '🙉' => 'ntie-bɔne-biara adoe',
    '🙊' => 'nka-bɔne-biara adoe',
    '💌' => 'ͻdͻ krataa',
    '💘' => 'akoma a agyan hyɛ mu',
    '💝' => 'akoma ne ribine',
    '💖' => 'akoma a ɛtete gya',
    '💗' => 'akoma a ɛrenyini',
    '💓' => 'akoma a ɛrebɔ',
    '💞' => 'akoma a ɛretware',
    '💕' => 'akoma mmienu',
    '💟' => 'akoma dɛkorahyen',
    '❣' => 'akoma nteamu',
    '💔' => 'akoma a abubu',
    '❤' => 'akoma kɔkɔɔ',
    '🩷' => 'akoma pinke',
    '🧡' => 'ankaa akoma',
    '💛' => 'akoma akokɔsradeɛ',
    '💚' => 'akoma ahabanmono',
    '💙' => 'akoma bruu',
    '🩵' => 'akoma bruu kakraa',
    '💜' => 'akoma pɛɛpoo',
    '🤎' => 'akoma dodoe',
    '🖤' => 'akoma tuntum',
    '🩶' => 'akoma nsonso',
    '🤍' => 'akoma fitaa',
    '💋' => 'anofeɛ agyinahyɛdeɛ',
    '💯' => 'pɔnse ɔha',
    '💢' => 'abufuo agyinahyɛdeɛ',
    '🫯' => 'ᴐko klawdo',
    '💥' => 'kɔɔlihyen',
    '💫' => 'anisobirie',
    '💦' => 'mfifire',
    '💨' => 'dahyeen awee',
    '🕳' => 'tokuro',
    '💬' => 'kasa baaloo',
    '🗨' => 'benkum kasa bɔbuu',
    '🗯' => 'nifa abufuo bɔbuu',
    '💭' => 'adwene baaluu',
    '💤' => 'ZZZ',
    '👋' => 'nsa a ɛrehim',
    '🤚' => 'nsa akyi a apagya',
    '🖐' => 'nsa ne nsateaa a abue',
    '✋' => 'nsa a apagya',
    '🖖' => 'vulcan nkyea',
    '🫱' => 'nsa nifa',
    '🫲' => 'nsa benkum',
    '🫳' => 'nsam hwɛ fam',
    '🫴' => 'nsam a ɛhwɛ soro',
    '🫷' => 'nsa repia kɔ benkum',
    '🫸' => 'nsa repia kɔ nifa',
    '👌' => 'OK nsa',
    '🤌' => 'nsateaa a amia',
    '🤏' => 'nsa a amia',
    '✌' => 'nkonimdie nsa',
    '🤞' => 'nsateaa a wɔde abankyere ho',
    '🫰' => 'nsa a wɔde akyerɛkyerɛkwan nsateaa ne kokuromotie abɔ mu',
    '🤟' => 'ɔdɔ-wo sɛnkyerɛnne',
    '🤘' => 'mmɛn no ho sɛnkyerɛnne',
    '🤙' => 'frɛ me nsa',
    '👈' => 'nsaakyi indɛse a ɛkyerɛ benkum so',
    '👉' => 'nsaakyi indɛse a ɛkyerɛ nifa so',
    '👆' => 'nsaakyi indɛse a ɛkyerɛ soro so',
    '🖕' => 'mfinimfini nsateaa',
    '👇' => 'nsaakyi indɛse rekyerɛ fam',
    '☝' => 'indɛse rekyerɛ soro',
    '🫵' => 'indɛse rekyerɛ ɔhwɛfoɔ no so',
    '👍' => 'kokuromotie a ɛkɔ soro',
    '👎' => 'kokuromotie a ɛkɔ fam',
    '✊' => 'twɛdeɛ a apagya',
    '👊' => 'twɛdeɛ a ɛreba',
    '🤛' => 'twɛdeɛ a ɛhwɛ benkum',
    '🤜' => 'twɛdeɛ a ɛhwɛ nifa',
    '👏' => 'nsa a ɛrebom',
    '🙌' => 'nsa a ɛrepagya',
    '🫶' => 'akoma nsa',
    '👐' => 'nsa a abue',
    '🤲' => 'nsateaa a ɛkɔ soro bom',
    '🤝' => 'nsamkyea',
    '🙏' => 'nsa a aka abom',
    '✍' => 'nsa a wɔde twerɛ nsɛm',
    '💅' => 'mmɔwerɛ pɔlihye',
    '🤳' => 'selfie',
    '💪' => 'baasɛpse a aflɛse',
    '🦾' => 'dadeɛ abasa a ɛkɔba',
    '🦿' => 'dadeɛ nan a ɛkɔba',
    '🦵' => 'nan',
    '🦶' => 'nan ase',
    '👂' => 'aso',
    '🦻' => 'aso ne otie eede',
    '👃' => 'hwene',
    '🧠' => 'adwene',
    '🫀' => 'aduyɛ akoma',
    '🫁' => 'ahrawa',
    '🦷' => 'ɛse',
    '🦴' => 'dompe',
    '👀' => 'ani',
    '👁' => 'aniwa',
    '👅' => 'tɛkrɛma',
    '👄' => 'ano',
    '🫦' => 'ano a obi reka',
    '👶' => 'abɔfra',
    '🧒' => 'akwadaa',
    '👦' => 'barima',
    '👧' => 'ɔbaa',
    '🧑' => 'onipa',
    '👱' => 'onipa: nwii kɔkɔɔ',
    '👨' => 'ɔbarima',
    '🧔' => 'onipa: abodwesɛ',
    '👩' => 'maame',
    '🧓' => 'Onipa a wanyini',
    '👴' => 'akwakora',
    '👵' => 'abrewa',
    '🙍' => 'onipa a wamuna',
    '🙎' => 'onipa pɔɔtine',
    '🙅' => 'onipa reyɛ DAABI nsɛnkyerɛnne',
    '🙆' => 'onipa reyɛ OK nsɛnkyerɛnne',
    '💁' => 'onipa tiipi nsa',
    '🙋' => 'onipa repagya nsa',
    '🧏' => 'ɛmum',
    '🙇' => 'onipa rebɔ ne mu ase',
    '🤦' => 'onipa de ne nsam ato n’anim',
    '🤷' => 'onipa repagya ne mmati',
    '👮' => 'Polisi ɔfesa',
    '🕵' => 'detɛketifo',
    '💂' => 'Banbɔfo',
    '🥷' => 'Ningya',
    '👷' => 'Adansie dwumayɛni',
    '🫅' => 'Obi a ɔhyɛ ahenkyɛ',
    '🤴' => 'Prense',
    '👸' => 'prensɛse',
    '👳' => 'Obi hyɛ tɛɛban',
    '👲' => 'Obi a ɔhyɛ skɔɔlekap',
    '🧕' => 'Ɔbaa wabɔ duku',
    '🤵' => 'Obi a ɔhyɛ tɔseedo',
    '👰' => 'Obi ne veil',
    '🤰' => 'Ɔbaa a ɔnyem',
    '🫃' => 'Barima a ɔnyem',
    '🫄' => 'Obi a ɔnyem',
    '🤱' => 'nufuoɔma',
    '👼' => 'Ɔbɔfoɔ akwadaa',
    '🎅' => 'Santa Klauso',
    '🤶' => 'Mrs. Klauso',
    '🦸' => 'Supahero',
    '🦹' => 'Supaviliane',
    '🧙' => 'nkonyaayifoͻ',
    '🧚' => 'Fɛɛre',
    '🧛' => 'Vampaya',
    '🧜' => 'Mɛɛnipa',
    '🧝' => 'ɛlefo',
    '🧞' => 'gyeeni',
    '🧟' => 'Sɔmbi',
    '🧌' => 'Trol',
    '🫈' => 'abᴐdeε a enwi wᴐ ne ho',
    '💆' => 'Onipa renya amiamia',
    '💇' => 'Wɔretwa obi nwii',
    '🚶' => 'Onipa renante',
    '🧍' => 'Onipa gyina hɔ',
    '🧎' => 'Obi abu nkotodwe',
    '🏃' => 'Obi retu mmirika',
    '💃' => 'Ɔbaa resa',
    '🕺' => 'Barima resa',
    '🕴' => 'Obi hyɛ suutu retu kɔ soro',
    '👯' => 'Nkurɔfoɔ wɔ adanko aso',
    '🧖' => 'Obi wɔ ɛhyew dan mu',
    '🧗' => 'Obi reforo',
    '🤺' => 'Obi refɛnse',
    '🏇' => 'Pɔnko akansie',
    '⛷' => 'Skiya',
    '🏂' => 'Sonoobɔda',
    '🏌' => 'Obi regɔɔfo',
    '🏄' => 'obi resεεfe',
    '🚣' => 'Obi reka kodoɔ',
    '🏊' => 'Obi reboro nsuo',
    '⛹' => 'Obi rebɔ bɔɔlo',
    '🏋' => 'Obi repagya nnadeɛ',
    '🚴' => 'Obi retwi sakre',
    '🚵' => 'Obi retwi sakre wɔ bepɔ so',
    '🤸' => 'Obi retwi kaate',
    '🤼' => 'Nkurɔfoɔ retentam',
    '🤽' => 'Obi rebɔ polo nsuo',
    '🤾' => 'Obi rebɔ nsabɔɔlo',
    '🤹' => 'Obi retoto bɔɔlo',
    '🧘' => 'Obi ayɛ lɔtusu posihyen',
    '🛀' => 'Obi redware',
    '🛌' => 'Onipa da mpa mu',
    '👭' => 'Mmaa asɔ nsam',
    '👫' => 'Ɔbaa ne barima asɔ nsam',
    '👬' => 'Mmarima asɔ nsam',
    '💏' => 'Mfeano',
    '💑' => 'Awarefoɔ ne akoma',
    '🗣' => 'Kasa ti',
    '👤' => 'Baasete wɔ sunsum mu',
    '👥' => 'Baasete ahodoɔ wɔ sunsum mu',
    '🫂' => 'Nkurɔfoɔ rebam',
    '👪' => 'Abusua',
    '👣' => 'Ananmɔn',
    '🫆' => 'Fingaperente',
    '🦰' => 'nwi kͻkͻͻ',
    '🦱' => 'enwi a akyinkyim',
    '🦳' => 'nwi fitaa',
    '🦲' => 'tipa',
    '🐵' => 'adoe anim',
    '🐒' => 'adoe',
    '🦍' => 'kontronfi',
    '🦧' => 'kwakuo',
    '🐶' => 'kraman anim',
    '🐕' => 'kraman',
    '🦮' => 'kraman banbͻfoͻ',
    '🐩' => 'puudel',
    '🐺' => 'kankane',
    '🦊' => 'sakraman',
    '🦝' => 'rakun',
    '🐱' => 'ͻkra anim',
    '🐈' => 'ͻkra',
    '🦁' => 'gyata',
    '🐯' => 'sebͻ anim',
    '🐅' => 'sebͻ',
    '🐆' => 'Leopaade',
    '🐴' => 'pͻnkͻ anim',
    '🫎' => 'Muuse',
    '🫏' => 'afrumu',
    '🐎' => 'pͻnkͻ',
    '🦄' => 'yunikɔn',
    '🦓' => 'zɛbra',
    '🦌' => 'wansane',
    '🦬' => 'baesin',
    '🐮' => 'nantwie anim',
    '🐂' => 'ox',
    '🐃' => 'nsuo mu ɛkoͻ',
    '🐄' => 'nantwie',
    '🐷' => 'prako anim',
    '🐖' => 'prako',
    '🐗' => 'kɔkɔte',
    '🐽' => 'prako hwene',
    '🐏' => 'odwannini',
    '🐑' => 'odwanbedeɛ',
    '🐐' => 'apͻnkye',
    '🐪' => 'yoma',
    '🐫' => 'akyakya-mmienu yoma',
    '🦙' => 'llaama',
    '🦒' => 'gyirafo',
    '🐘' => 'ͻsono',
    '🦣' => 'mamɔto',
    '🦏' => 'rainoserɔso',
    '🦛' => 'susono',
    '🐭' => 'akura anim',
    '🐁' => 'akura',
    '🐀' => 'kusie',
    '🐹' => 'hamsta',
    '🐰' => 'adanko anim',
    '🐇' => 'adanko',
    '🐿' => 'opuro',
    '🦫' => 'beeva',
    '🦔' => 'apɛsɛ',
    '🦇' => 'apan',
    '🐻' => 'sisire',
    '🐨' => 'koala',
    '🐼' => 'panda',
    '🦥' => 'sloolɔt',
    '🦦' => 'ɔta',
    '🦨' => 'skanke',
    '🦘' => 'kangaroo',
    '🦡' => 'bagya',
    '🐾' => 'pɔɔw perente',
    '🦃' => 'Kokrokoko',
    '🐔' => 'akokͻ',
    '🐓' => 'akokɔnini',
    '🐣' => 'akokɔba firi kosua mu',
    '🐤' => 'akokɔba ketewa',
    '🐥' => 'akokɔba a ɔhwɛ anim',
    '🐦' => 'anomaa',
    '🐧' => 'pɛngwiene',
    '🕊' => 'aborͻnoma',
    '🦅' => 'kͻdeɛ',
    '🦆' => 'dabodabo',
    '🦢' => 'sowaan',
    '🦉' => 'patuo',
    '🦤' => 'dodo',
    '🪶' => 'takra',
    '🦩' => 'flamingo',
    '🦚' => 'peekɔk',
    '🦜' => 'ako',
    '🪽' => 'ataban',
    '🪿' => 'goose',
    '🐸' => 'apͻtrͻ',
    '🐊' => 'dɛnkyɛm',
    '🐢' => 'Akyekyedeɛ',
    '🦎' => 'koterɛ',
    '🐍' => 'ͻwͻ',
    '🐲' => 'ɔtweaseɛ anim',
    '🐉' => 'Ɔtweaseɛ',
    '🦕' => 'sauropɔd',
    '🦖' => 'T-Rex',
    '🐳' => 'sepuutin bonsu',
    '🐋' => 'bonsu',
    '🐬' => 'Dɔɔfin',
    '🫍' => 'bonsu kεse',
    '🦭' => 'Siili',
    '🐟' => 'nsunam',
    '🐠' => 'Trɔpikaa apataa',
    '🐡' => 'Bolooapataa',
    '🦈' => 'Aboodede',
    '🐙' => 'Ɔkotopɔso',
    '🐚' => 'Ntwaho konkora',
    '🪸' => 'Kɔraa',
    '🪼' => 'Gyɛliapataa',
    '🦀' => 'Kɔtɔ',
    '🦞' => 'Lɔboseta',
    '🦐' => 'mɔnko',
    '🦑' => 'Sekwede',
    '🦪' => 'Ɔeseta',
    '🐌' => 'nwa',
    '🦋' => 'afrafrantͻ',
    '🐛' => 'Bɔɔgo',
    '🐜' => 'kakapɛ',
    '🐝' => 'nwowa',
    '🪲' => 'biitil',
    '🐞' => 'ledi biitil',
    '🦗' => 'aketekyere',
    '🪳' => 'tɛfrɛ',
    '🕷' => 'ananse',
    '🕸' => 'ananse ntentan',
    '🦂' => 'nyanyankyerɛ',
    '🦟' => 'Ntontom',
    '🪰' => 'Atuboa',
    '🪱' => 'Sonsono',
    '🦠' => 'maikrobe',
    '💐' => 'Bukee',
    '🌸' => 'Hyɛri apae',
    '💮' => 'Nhwiren fitaa',
    '🪷' => 'lɔtus',
    '🏵' => 'rosete',
    '🌹' => 'rose',
    '🥀' => 'Nhwiren a atwentwam',
    '🌺' => 'Hibiskɔso',
    '🌻' => 'Sɔnflawa',
    '🌼' => 'Apae',
    '🌷' => 'Tulipo',
    '🪻' => 'haisinte',
    '🌱' => 'Afifideɛ',
    '🪴' => 'pɔɔtɛd dua',
    '🌲' => 'Frɔmfrɔm daa dua',
    '🌳' => 'desidiɔso dua',
    '🌴' => 'Kube dua',
    '🌵' => 'Kaktus',
    '🌾' => 'Ɛmo hyeefo',
    '🌿' => 'Ahabanduro',
    '☘' => 'Hyamrɔk',
    '🍀' => 'nhaban nan klova',
    '🍁' => 'Meepoo ahaban',
    '🍂' => 'Ahaban a atɔ fam',
    '🍃' => 'nhaban nam mframa mu',
    '🪹' => 'Ɛbuo a hwee nni mu',
    '🪺' => 'Ɛbuo ne nkosua',
    '🍄' => 'mmire',
    '🪾' => 'ɛnni nhaban dua',
    '🍇' => 'bobeaba',
    '🍈' => 'Mɛlɔn',
    '🍉' => 'wͻtamɛlͻn',
    '🍊' => 'Tangaree',
    '🍋' => 'ankaa twadeɛ',
    '🍌' => 'kwadu',
    '🍍' => 'abrͻbɛ',
    '🥭' => 'amango',
    '🍎' => 'aprɛ kͻkͻͻ',
    '🍏' => 'Aprɛ ahabanmono',
    '🍐' => 'paya',
    '🍑' => 'Piikye',
    '🍒' => 'kyεrisi',
    '🍓' => 'Setrɔbɛɛrii',
    '🫐' => 'bruubɛɛrii',
    '🥝' => 'kiwi aduaba',
    '🍅' => 'ntoosi',
    '🫒' => 'ngo',
    '🥥' => 'kube',
    '🥑' => 'avokado',
    '🍆' => 'nyadeewa',
    '🥔' => 'aborɔdwoma',
    '🥕' => 'karroto',
    '🌽' => 'aburoo bɛtim',
    '🌶' => 'mako hyew',
    '🫑' => 'bɛɛl mako',
    '🥒' => 'kokumba',
    '🥬' => 'nhabanmono',
    '🥦' => 'brokoli',
    '🧄' => 'galeke',
    '🧅' => 'gyeene',
    '🥜' => 'nkateε',
    '🫘' => 'adua',
    '🌰' => 'kyɛstenɔt',
    '🫚' => 'akekaduru nhini',
    '🫛' => 'adua pɔd',
    '🫜' => 'nhini atosodeɛ',
    '🍞' => 'paanoo',
    '🥐' => 'krɔsaa',
    '🥖' => 'bagɛte paanoo',
    '🫓' => 'paanootratra',
    '🥨' => 'prɛtsɛl',
    '🥯' => 'bagele',
    '🥞' => 'pankeeki',
    '🧇' => 'waafuu',
    '🧀' => 'kyiisi wɛɛge',
    '🍖' => 'nam wɔ dompe ho',
    '🍗' => 'akokɔ nan',
    '🥩' => 'ɛnam a wɔatwa',
    '🥓' => 'beekin',
    '🍔' => 'hambɔga',
    '🍟' => 'frɛnkye fraise',
    '🍕' => 'pizza',
    '🌭' => 'hɔt dɔg',
    '🥪' => 'kyibom',
    '🌮' => 'tako',
    '🌯' => 'bɔrito',
    '🫔' => 'tamale',
    '🥙' => 'paanootratra a wɔahyɛm',
    '🧆' => 'falafele',
    '🥚' => 'kosua',
    '🍳' => 'aduanenoa',
    '🥘' => 'aduane gu kyɛnsee tiatia mu',
    '🍲' => 'kukuom aduane',
    '🫕' => 'fɔndue',
    '🥣' => 'kyɛnsee ne atere',
    '🥗' => 'ahahan salad',
    '🍿' => 'pɔpkɔɔno',
    '🧈' => 'bɔta',
    '🧂' => 'nkyene',
    '🥫' => 'konkom aduane',
    '🍱' => 'bɛnto adaka',
    '🍘' => 'ɛmo kraka',
    '🍙' => 'ɛmotuo',
    '🍚' => 'ɛmo a wɔanoa',
    '🍛' => 'kɛri ɛmo',
    '🍜' => 'kyɛnsee a ɛrehuru',
    '🍝' => 'talia',
    '🍠' => 'abrodwoma a wɔatoto',
    '🍢' => 'oden',
    '🍣' => 'suhyi',
    '🍤' => 'mɔnko a wɔakye',
    '🍥' => 'apataa keeki ne ntwaho',
    '🥮' => 'bosome keeki',
    '🍡' => 'dango',
    '🥟' => 'dɔmpiline',
    '🥠' => 'yiedie kooki',
    '🥡' => 'fakɔfie adaka',
    '🍦' => 'aese kirim mmerɛmmerɛ',
    '🍧' => 'aese a wɔawerɛwerɛ',
    '🍨' => 'aese kirim',
    '🍩' => 'doonɔto',
    '🍪' => 'kooki',
    '🎂' => 'awoda keeki',
    '🍰' => 'keekitiatia',
    '🧁' => 'kuruwakeeki',
    '🥧' => 'pae',
    '🍫' => 'kyokolɛɛte baa',
    '🍬' => 'kandi',
    '🍭' => 'lɔlipɔɔpo',
    '🍮' => 'kastaade',
    '🍯' => 'ɛwoɔ kukuo',
    '🍼' => 'abͻfra toa',
    '🥛' => 'nufusuo tɔmmɛ baako',
    '☕' => 'anonneɛ a ɛyɛ hye',
    '🫖' => 'tii kukuo',
    '🍵' => 'tii kuruwa a ɛni nsa',
    '🍶' => 'sake',
    '🍾' => 'toa ne ntuano a ɛrepae',
    '🍷' => 'bobesa tɔmmɛ',
    '🍸' => 'kɔkteele tɔmmɛ',
    '🍹' => 'trɔpikaa nsa',
    '🍺' => 'bia kuruwa',
    '🍻' => 'bai nkuruwa a agye geengaan',
    '🥂' => 'tɔmmɛ a agye geengaan',
    '🥃' => 'tumbler tɔmmɛ',
    '🫗' => 'rehwie nsuo',
    '🥤' => 'Kuruwa ne setrɔɔ',
    '🧋' => 'bɔbuu tee',
    '🧃' => 'adɔkɔdɔkɔdeɛ adaka',
    '🧉' => 'yɔnkoɔ',
    '🧊' => 'nsuboɔ',
    '🥢' => 'adidimmaa',
    '🍽' => 'fɔk ne sekan ne prɛɛte',
    '🍴' => 'fɔk ne sekan',
    '🥄' => 'atere',
    '🔪' => 'gyaade sekan',
    '🫙' => 'gyaa',
    '🏺' => 'amfɔra',
    '🌍' => 'globe a ɛrekyerɛ Yuropu-Afrika',
    '🌎' => 'globe a ɛrekyerɛ Amerika',
    '🌏' => 'globe a ɛrekyerɛ Asia-Ɔstrelia',
    '🌐' => 'globe ne mɛridianse',
    '🗺' => 'wiase maapͻ',
    '🗾' => 'Gyapan maapɔ',
    '🧭' => 'kɔmpase',
    '🏔' => 'bepͻ a asukɔtwea akata so',
    '⛰' => 'bepͻ',
    '🛘' => 'asasehwie',
    '🌋' => 'ogya bepɔ',
    '🗻' => 'bepͻ fuji',
    '🏕' => 'nwuram nna',
    '🏖' => 'mpoano a kyiniiɛ wɔ hɔ',
    '🏜' => 'ɛserɛ so',
    '🏝' => 'ɛserɛ so supɔ',
    '🏞' => 'ɔman agoprama',
    '🏟' => 'Prama',
    '🏛' => 'tete dan',
    '🏗' => 'ɛdansie',
    '🧱' => 'bereke',
    '🪨' => 'ɛboͻ',
    '🪵' => 'dua',
    '🛖' => 'apata',
    '🏘' => 'adan',
    '🏚' => 'ɛdan a aseɛ',
    '🏠' => 'ɛdan',
    '🏡' => 'ɛdan a turo wͻ mu',
    '🏢' => 'ͻfese dan',
    '🏣' => 'Gyapanese nkratoɔbea',
    '🏤' => 'nkratoɔbea',
    '🏥' => 'ayaresabea',
    '🏦' => 'sikakorabea',
    '🏨' => 'ahͻhogyebea',
    '🏩' => 'ɔdɔ ahɔhogyebea',
    '🏪' => 'ahotɔ sotɔɔ',
    '🏫' => 'sukuu',
    '🏬' => 'Nneɛma nyinaa sotɔɔ',
    '🏭' => 'mfididwumabea',
    '🏯' => 'Gyapanfoɔ abankɛseɛ',
    '🏰' => 'abankɛseɛ',
    '💒' => 'ayeforͻ',
    '🗼' => 'Tokyo abantenten',
    '🗽' => 'fawohodie ohoni',
    '⛪' => 'asͻredan',
    '🕌' => 'masalakyi',
    '🛕' => 'hindu asͻredan',
    '🕍' => 'mpaebͻfie',
    '⛩' => 'shinto abosomfie',
    '🕋' => 'kaaba',
    '⛲' => 'asubura',
    '⛺' => 'ntomadan',
    '🌁' => 'kusukusu',
    '🌃' => 'anadwo a nsoromma wͻ hͻ',
    '🏙' => 'kurokɛseɛtebea',
    '🌄' => 'owia apue wͻ mmepͻ so',
    '🌅' => 'owia apue',
    '🌆' => 'anadwo kurokɛseɛtebea',
    '🌇' => 'awiatɔeɛ',
    '🌉' => 'ɛtwene anadwo mu',
    '♨' => 'nsutene a ɛyɛ hye',
    '🎠' => 'karosɛɛle pɔnkɔ',
    '🛝' => 'agodiebea selaide',
    '🎡' => 'fɛɛrise hweeli',
    '🎢' => 'rola koseta',
    '💈' => 'baaba abaa',
    '🎪' => 'sɛɛkus apata',
    '🚂' => 'lokomotifo',
    '🚃' => 'ketekekwan kar',
    '🚄' => 'keteke a ɛde mmirika kɛse kɔ',
    '🚅' => 'aboba keteke',
    '🚆' => 'keteke',
    '🚇' => 'mɛtro',
    '🚈' => 'kanea keteke',
    '🚉' => 'ahyɛn gyinabea',
    '🚊' => 'tram',
    '🚝' => 'kwanbaako',
    '🚞' => 'bepͻ ho keteke kwan',
    '🚋' => 'tram kaa',
    '🚌' => 'bͻͻso',
    '🚍' => 'bͻͻso a ɛreba',
    '🚎' => 'trɔlibɔs',
    '🚐' => 'bͻͻso ketewa',
    '🚑' => 'ambulanse',
    '🚒' => 'egya ɛngyen',
    '🚓' => 'polisi kaa',
    '🚔' => 'polisi kaa a ɛreba',
    '🚕' => 'taksi',
    '🚖' => 'taksi a ɛreba',
    '🚗' => 'kaa a ɛkɔ',
    '🚘' => 'kaa a ɛkɔ a ɛreba',
    '🚙' => 'sopɔɔso dwumadie kaa',
    '🛻' => 'kɔfa trɔko',
    '🚚' => 'adema trɔko',
    '🚛' => 'lɔre kɛseɛ',
    '🚜' => 'traketa',
    '🏎' => 'akansie kaa',
    '🏍' => 'motosakre',
    '🛵' => 'moto skuta',
    '🦽' => 'manuaa hwiikyɛɛ',
    '🦼' => 'hwiikyɛɛ a wɔde moto ayɛ',
    '🛺' => 'okada',
    '🚲' => 'sakre',
    '🛴' => 'kik skuta',
    '🛹' => 'seketebɔɔdo',
    '🛼' => 'rola sekeete',
    '🚏' => 'bɔs agyinaeɛ',
    '🛣' => 'motokwan',
    '🛤' => 'keteke kwan',
    '🛢' => 'fango akurɛ',
    '⛽' => 'fango pɔmpo',
    '🛞' => 'hweeli',
    '🚨' => 'polisi kaa kanea',
    '🚥' => 'kar kanea a ɛda fam',
    '🚦' => 'kaa kanea a ɛgyina hɔ',
    '🛑' => 'gyae sɛnkyerɛnne',
    '🚧' => 'adansie',
    '⚓' => 'sɛkyɛ',
    '🛟' => 'kawa bɔe',
    '⛵' => 'seelekodoɔ',
    '🛶' => 'kodoɔ',
    '🚤' => 'mmirikatuokodoɔ',
    '🛳' => 'akwantufoɔ suhyɛn',
    '⛴' => 'atwareɛ',
    '🛥' => 'moto kodoɔ',
    '🚢' => 'suhyɛn',
    '✈' => 'wiemhyɛn',
    '🛩' => 'wiemhyɛn ketewa',
    '🛫' => 'wiemhyɛn nkɔeɛ',
    '🛬' => 'wiemhyɛn mmaeɛ',
    '🪂' => 'parashuto',
    '💺' => 'adwa',
    '🚁' => 'hɛlikɔpta',
    '🚟' => 'keteke kwan a wɔde asɛn hɔ',
    '🚠' => 'bepɔ keebuukwan',
    '🚡' => 'wiem tramkwan',
    '🛰' => 'saetelaite',
    '🚀' => 'rɔkɛte',
    '🛸' => 'sɔɔsa a ɛretu',
    '🛎' => 'bɛɛlhɔpo dɔn',
    '🧳' => 'ɔkwantuni baage',
    '⌛' => 'dɔnhwereglaase awie',
    '⏳' => 'dɔnhwereglaase nwieeɛ',
    '⌚' => 'wͻͻkye',
    '⏰' => 'dede klɔko',
    '⏱' => 'gyaewɔɔkye',
    '⏲' => 'berɛkan klɔko',
    '🕰' => 'mantelepiisi klɔko',
    '🕛' => 'prɛmtoberɛ',
    '🕧' => 'dummienu mpaemu',
    '🕐' => 'dɔnko',
    '🕜' => 'dɔnko mpaemu',
    '🕑' => 'nnɔn mmienu',
    '🕝' => 'nnɔn mmienu mpaemu',
    '🕒' => 'nnɔn mmiɛnsa',
    '🕞' => 'nnɔn mmiɛnsa mpaemu',
    '🕓' => 'nnɔn nnan',
    '🕟' => 'nnɔn nnan mpaemu',
    '🕔' => 'nnɔn num',
    '🕠' => 'nnɔn num mpaemu',
    '🕕' => 'nnɔn nsia',
    '🕡' => 'nnɔn nsia mpaemu',
    '🕖' => 'nnɔn nson',
    '🕢' => 'nnɔn nson mpaemu',
    '🕗' => 'nnɔn nwɔtwe',
    '🕣' => 'nnɔn nwɔtwe mpaemu',
    '🕘' => 'nnɔn nkron',
    '🕤' => 'nnɔn nkron mpaemu',
    '🕙' => 'nnɔn du',
    '🕥' => 'nnɔn du mpaemu',
    '🕚' => 'nnɔn du baako',
    '🕦' => 'nnɔn du baako mpaemu',
    '🌑' => 'ɔsram foforɔ',
    '🌒' => 'waasin krɛsɛnte ɔsram',
    '🌓' => 'kɔta a ɛdi kan ɔsram',
    '🌔' => 'waasin gibiso ɔsram',
    '🌕' => 'ɔsram mua',
    '🌖' => 'waanin gibiso ɔsram',
    '🌗' => 'akyire kɔta ɔsram',
    '🌘' => 'waanin krɛsɛnte ɔsram',
    '🌙' => 'krɛsɛnte ɔsram',
    '🌚' => 'ɔsram foforɔ anim',
    '🌛' => 'kɔta a ɛdi kan ɔsram anim',
    '🌜' => 'akyire kɔta ɔsram anim',
    '🌡' => 'tɛmomita',
    '☀' => 'owia',
    '🌝' => 'ɔsram mua anim',
    '🌞' => 'owia ne anim',
    '🪐' => 'okyinsroma a ɛwɔ kawa',
    '⭐' => 'nsoroma',
    '🌟' => 'nsoroma a ɛrehyerɛn',
    '🌠' => 'nsoroma a ɛretu',
    '🌌' => 'milki nsoromma',
    '☁' => 'mununkum',
    '⛅' => 'owia a ɛwɔ mununkum akyi',
    '⛈' => 'munumkum ne agradaa ne osuo',
    '🌤' => 'owia a ɛwɔ mununkum ketewa akyi',
    '🌥' => 'owia a ɛwɔ mununkum kɛseɛ akyi',
    '🌦' => 'owia a ɛwɔ osuo munumkum akyi',
    '🌧' => 'munumkum ne osuo',
    '🌨' => 'munumkum ne sukyerɛma',
    '🌩' => 'munumkum ne ayerɛmo',
    '🌪' => 'ahum',
    '🌫' => 'ɛbɔ',
    '🌬' => 'mframa anim',
    '🌀' => 'saeklono',
    '🌈' => 'nyankontɔn',
    '🌂' => 'kyiniiɛ a ɛmu ato',
    '☂' => 'kyiniiɛ',
    '☔' => 'kyiniiɛ a osuo ato agu so',
    '⛱' => 'kyiniiɛ a ɛda fam',
    '⚡' => 'vɔɔtege a ɛwɔ soro',
    '❄' => 'sukyerɛmaaba',
    '☃' => 'sukyerɛmapapa',
    '⛄' => 'sukyerɛmapapa a ɔnni sukyerɛma',
    '☄' => 'kɔmɛt',
    '🔥' => 'ogya',
    '💧' => 'nsuoko',
    '🌊' => 'Ɛpo asorɔkye',
    '🎃' => 'jack-o-kanea',
    '🎄' => 'Buronyadua',
    '🎆' => 'nͻkaatotoͻ',
    '🎇' => 'deԑ ԑpa gya',
    '🧨' => 'gyawuo',
    '✨' => 'gyaeteԑ',
    '🎈' => 'baaluu',
    '🎉' => 'deԑ wͻpae wͻ apontoͻ ase',
    '🎊' => 'confretti bͻͻlo',
    '🎋' => 'tanabata dua',
    '🎍' => 'pine nsiesie',
    '🎎' => 'Gyapanfoͻ mmaduaba',
    '🎏' => 'koinobori',
    '🎐' => 'nkonyaadeԑ',
    '🎑' => 'ͻsranehwԑ apontoͻ',
    '🧧' => 'ԑmflԑpo kͻkͻͻ',
    '🎀' => 'ribͻn',
    '🎁' => 'akyԑdeԑ a wͻakyekyere ho',
    '🎗' => 'nkaeԑ ribͻn',
    '🎟' => 'admihyin tikiti',
    '🎫' => 'tikiti',
    '🎖' => 'asraafoͻ mԑdaa',
    '🏆' => 'kuruwa',
    '🏅' => 'agokansie mԑdaa',
    '🥇' => 'deԑ ͻdii kan mԑdaa',
    '🥈' => 'deԑ ͻtͻ so mmienu mԑdaa',
    '🥉' => 'Deԑ ͻtͻ so mmiԑnsa mԑdaa',
    '⚽' => 'futbͻͻlo',
    '⚾' => 'basebͻͻlo',
    '🥎' => 'softball',
    '🏀' => 'basketball',
    '🏐' => 'volleyball',
    '🏈' => 'amԑrikafoͻ futbͻͻlo',
    '🏉' => 'rugbi futbͻͻlo',
    '🎾' => 'tԑnese',
    '🥏' => 'apaawa a wͻto',
    '🎳' => 'boolin',
    '🏏' => 'krekԑte agodie',
    '🏑' => 'prama so hͻki',
    '🏒' => 'aese hͻki',
    '🥍' => 'lakrosu',
    '🏓' => 'ping pong',
    '🏸' => 'badmintin',
    '🥊' => 'akuturukubͻ glͻͻvo',
    '🥋' => 'mahyaa aate atadeԑ',
    '🥅' => 'goo atena',
    '⛳' => 'frankaa wͻ tokuro mu',
    '⛸' => 'aese sikeeti',
    '🎣' => 'nsunamyie dua',
    '🤿' => 'osuboro nkataanim',
    '🎽' => 'mmirikatuo atadeԑ',
    '🎿' => 'skii',
    '🛷' => 'sled',
    '🥌' => 'ͻboͻ a akyinkyim',
    '🎯' => 'buusei',
    '🪀' => 'yo-yo',
    '🪁' => 'kaete',
    '🔫' => 'nsuo tuo',
    '🎱' => 'puu 8 bͻͻlo',
    '🔮' => 'krestaa bͻͻlo',
    '🪄' => 'nkonyaa akadeԑ',
    '🎮' => 'video agorͻ',
    '🕹' => 'joystick',
    '🎰' => 'alot afidie',
    '🎲' => 'agodie aba',
    '🧩' => 'abisaa',
    '🧸' => 'tԑdibԑԑ',
    '🪅' => 'pinyaata',
    '🪩' => 'ahwehwԑ bͻͻlo',
    '🪆' => 'mmaduaba',
    '♠' => 'spaa',
    '♥' => 'akoma deԑ',
    '♦' => 'kaloo deԑ',
    '♣' => 'kuren deԑ',
    '♟' => 'dame',
    '🃏' => 'gyoka',
    '🀄' => 'mahyͻn dragͻn kͻkͻͻ',
    '🎴' => 'flawa agodie kaade',
    '🎭' => 'reyԑ aate',
    '🖼' => 'mfoni a ԑda ada mu',
    '🎨' => 'aateni palete',
    '🧵' => 'ahoma',
    '🪡' => 'adepam paneԑ',
    '🧶' => 'anwenehoma',
    '🪢' => 'ԑpͻ',
    '👓' => 'nhwehwԑniwa',
    '🕶' => 'awia ahwehwԑniwa',
    '🥽' => 'gͻgoro',
    '🥼' => 'laabo ataadeԑ',
    '🦺' => 'ahwԑyie vest',
    '👔' => 'kͻnmuahoma',
    '👕' => 'Tiihyɛɛte',
    '👖' => 'gyinse',
    '🧣' => 'duku',
    '🧤' => 'glͻͻvo',
    '🧥' => 'kootu',
    '🧦' => 'sͻkoso',
    '👗' => 'ataadeɛ',
    '👘' => 'kimono',
    '🥻' => 'sari',
    '🩱' => 'nsuboro atadeɛ',
    '🩲' => 'pieto',
    '🩳' => 'nika',
    '👙' => 'bikini',
    '👚' => 'mmaa ntadeɛ',
    '🪭' => 'nsa papa a wotumi bobͻ',
    '👛' => 'pɛɛse',
    '👜' => 'nsa baage',
    '👝' => 'klͻͻkye baage',
    '🛍' => 'dwadie baage',
    '🎒' => 'baage a yɛde bͻ akyi',
    '🩴' => 'tͻn sannase',
    '👞' => 'barima hyuu',
    '👟' => 'mmirikatuo hyuu',
    '🥾' => 'bepͻ mpaboa',
    '🥿' => 'hyuu tratra',
    '👠' => 'hyuu a ɛwͻ soro',
    '👡' => 'ͻbaa mpaboa',
    '🩰' => 'balee hyuu',
    '👢' => 'ͻbaa buutu',
    '🪮' => 'afe',
    '👑' => 'ahenkyɛ',
    '👒' => 'ͻbaa kyɛ',
    '🎩' => 'soro kyɛ',
    '🎓' => 'sukuuwie kyɛ',
    '🧢' => 'ɛkyɛ a wͻatwerɛ anim',
    '🪖' => 'asrafoͻ hɛɛmɛte',
    '⛑' => 'ͻgyefoͻ dwumayɛni hɛɛmɛte',
    '📿' => 'mpaeɛ ahwenneɛ',
    '💄' => 'lipsteke',
    '💍' => 'kawa',
    '💎' => 'gyɛm boͻ',
    '🔇' => 'spiika a wͻamua ano',
    '🔈' => 'spiika ano wͻ fam',
    '🔉' => 'spiika anoden yɛ hͻ-ne-hͻ',
    '🔊' => 'spiika anoden wͻ soro',
    '📢' => 'spiika a ano yɛ den',
    '📣' => 'mɛgafon',
    '📯' => 'posͻfese abɛn',
    '🔔' => 'dͻn',
    '🔕' => 'dͻn a wͻasan mu',
    '🎼' => 'nnwoma mu aba',
    '🎵' => 'nnwom nootu',
    '🎶' => 'nnwom nootu ahodoͻ',
    '🎙' => 'studio maekrofon',
    '🎚' => 'gyinabea sesafoͻ',
    '🎛' => 'deɛ wͻde di so',
    '🎤' => 'akasamu',
    '🎧' => 'hɛdfon',
    '📻' => 'radio',
    '🎷' => 'saksofon',
    '🎺' => 'totorobɛnto',
    '🪊' => 'trombone',
    '🪗' => 'akͻͻdion',
    '🎸' => 'gitae',
    '🎹' => 'nnwom kiibͻͻdo',
    '🎻' => 'violin',
    '🪕' => 'bandwo',
    '🥁' => 'twene',
    '🪘' => 'twene tentene',
    '🪇' => 'malakas',
    '🪈' => 'abɛn',
    '🪉' => 'haapo',
    '📱' => 'mobaa fon',
    '📲' => 'mobaa fon a akyerɛkyerɛkwan da so',
    '☎' => 'tɛlefon',
    '📞' => 'tɛlefon nsa',
    '📟' => 'pegya',
    '📠' => 'faase afidie',
    '🔋' => 'batere',
    '🪫' => 'batere kͻ fam',
    '🔌' => 'elɛtreke plͻgo',
    '💻' => 'laptͻp',
    '🖥' => 'pono so kͻmputa',
    '🖨' => 'printa',
    '⌨' => 'kiibɔd',
    '🖱' => 'kɔmputa mawoso',
    '🖲' => 'trakebɔɔlo',
    '💽' => 'kɔmputa disike',
    '💾' => 'flɔpi disike',
    '💿' => 'ɔptikaa disike',
    '📀' => 'dvd',
    '🧮' => 'abakus',
    '🎥' => 'sini kamera',
    '🎞' => 'sini mfonini',
    '📽' => 'sini progyɛkta',
    '🎬' => 'klapa bɔɔdo',
    '📺' => 'tɛlɛbihyɛn',
    '📷' => 'kamɛra',
    '📸' => 'kamera ne yerɛwyerɛw',
    '📹' => 'video kamera',
    '📼' => 'videokaasɛte',
    '🔍' => 'maginifayine glaase a wɔadane kɔ benkum',
    '🔎' => 'maginifayine glaase a wɔadane kɔ nifa',
    '🕯' => 'kyɛnere',
    '💡' => 'kanea bͻͻbo',
    '🔦' => 'tͻͻkye',
    '🏮' => 'krataa bobo kͻkͻͻ',
    '🪔' => 'diya kanea',
    '📔' => 'nwoma a aduradeɛ adura ho',
    '📕' => 'nwoma a emu ato',
    '📖' => 'bue nwoma mu',
    '📗' => 'nwoma grin',
    '📘' => 'nwoma bluu',
    '📙' => 'nwoma a ɛwͻ ankaa ahosuo',
    '📚' => 'nwoma ahodoͻ',
    '📓' => 'nwoma',
    '📒' => 'lɛgya',
    '📃' => 'kratafa a abobͻ',
    '📜' => 'bobͻ',
    '📄' => 'kratafa a ɛrehwɛ soro',
    '📰' => 'dawubͻ krataa',
    '🗞' => 'dawubͻ krataa a wͻabobͻ',
    '📑' => 'bukmake taabo',
    '🔖' => 'bukmake',
    '🏷' => 'ahyɛnsodeɛ',
    '🪙' => 'kͻin',
    '💰' => 'sika bͻtͻ',
    '🪎' => 'agudiε adaka',
    '💴' => 'yen sika krataa',
    '💵' => 'dͻla sika krataa',
    '💶' => 'yuro sikakorabea krataa',
    '💷' => 'pͻn sika krataa',
    '💸' => 'sika a ԑwͻ ntaban',
    '💳' => 'adefiri kaade',
    '🧾' => 'resiiti',
    '💹' => 'pono no rekͻ anim wͻ yen ho',
    '✉' => 'ԑmflԑpo',
    '📧' => 'emeel',
    '📨' => 'ԑmflԑpo a ԑreba',
    '📩' => 'ԑmflԑpo a akyerԑkyerԑ kwan wͻ ho',
    '📤' => 'nkrakͻ adaka',
    '📥' => 'nkraba adaka',
    '📦' => 'Amanedeԑ',
    '📫' => 'meel adaka a wͻato mu na wͻapagya frankaa wͻ so',
    '📪' => 'meel adaka a wͻatom na wͻde frankaa akͻ fam',
    '📬' => 'bue meel adaka a wͻapagya frankaa',
    '📭' => 'bue meel adaka a wͻama frankaa akͻ fam',
    '📮' => 'amanedeɛ adaka',
    '🗳' => 'abatoͻ adaka a aba wom',
    '✏' => 'pԑnsere',
    '✒' => 'ano tuntum',
    '🖋' => 'fanten pԑn',
    '🖊' => 'pԑn',
    '🖌' => 'kwa ho borͻͻso',
    '🖍' => 'krayon',
    '📝' => 'mɛmo',
    '💼' => 'baage',
    '📁' => 'faale folda',
    '📂' => 'faale folda a abue',
    '🗂' => 'kaade indɛse nkyekyɛmu',
    '📅' => 'kalͻɛnda',
    '📆' => 'sunsuan kalɛnda no mu',
    '🗒' => 'atwerɛsɛm nwoma a ɛyɛ spiral',
    '🗓' => 'Kalԑnna a ɛyɛ spiral',
    '📇' => 'kaade indɛse',
    '📈' => 'pono no rekͻ anim',
    '📉' => 'pono a ɛso rete',
    '📊' => 'baa pono',
    '📋' => 'klipbͻdo',
    '📌' => 'nyɛeɛ paneɛ',
    '📍' => 'pin kurukuruwa',
    '📎' => 'krataa klip',
    '🖇' => 'krataa klip a abom',
    '📏' => 'rula',
    '📐' => 'rula ahinasa',
    '✂' => 'apasoͻ',
    '🗃' => 'kaade faale adaka',
    '🗄' => 'faale adakawa',
    '🗑' => 'bͻͻla adeɛ',
    '🔒' => 'mu ato',
    '🔓' => 'abue',
    '🔏' => 'de pen atom',
    '🔐' => 'de safoa atom',
    '🔑' => 'safoa',
    '🗝' => 'safoa dada',
    '🔨' => 'hama',
    '🪓' => 'akuma',
    '⛏' => 'pinkase',
    '⚒' => 'hama ne pinkase',
    '🛠' => 'hama ne spaana',
    '🗡' => 'sekamma',
    '⚔' => 'akosekan',
    '💣' => 'topaeԑ',
    '🪃' => 'mmumfasoͻ',
    '🏹' => 'agyan',
    '🛡' => 'akokyԑm',
    '🪚' => 'kapentafoͻ sradaa',
    '🔧' => 'spaana',
    '🪛' => 'skrudriva',
    '🔩' => 'nat ne boot',
    '⚙' => 'adwuma afadeԑ',
    '🗜' => 'fam',
    '⚖' => 'ferenkyem susudua',
    '🦯' => 'poma fitaa',
    '🔗' => 'lenke',
    '⛓' => 'nkyerewa',
    '🪝' => 'huuku',
    '🧰' => 'akadeԑ adaka',
    '🧲' => 'tweboͻ',
    '🪜' => 'atwedeɛ',
    '🪏' => 'sofi',
    '⚗' => 'alɛmbeke',
    '🧪' => 'sͻhwɛ',
    '🧫' => 'petri aduane',
    '🧬' => 'dna',
    '🔬' => 'maekroskopu',
    '🔭' => 'teliskopu',
    '📡' => 'antena',
    '💉' => 'paneԑ',
    '🩸' => 'mogya ko',
    '💊' => 'perese',
    '🩹' => 'mfamyɛ bandegyi',
    '🩼' => 'krͻͻkye',
    '🩺' => 'stetoskopu',
    '🩻' => 'x-ray',
    '🚪' => 'pono',
    '🛗' => 'atwedeԑ',
    '🪞' => 'ahwehwɛ',
    '🪟' => 'mpoma',
    '🛏' => 'mpa',
    '🛋' => 'akonnwa kԑseԑ ne kanea',
    '🪑' => 'akonnwa',
    '🚽' => 'agyanan',
    '🪠' => 'plͻnga',
    '🚿' => 'dware',
    '🛁' => 'adwareɛ',
    '🪤' => 'akurafidie',
    '🪒' => 'shaving stick',
    '🧴' => 'sradeԑ toa',
    '🧷' => 'ahwԑyie pin',
    '🧹' => 'praeԑ',
    '🧺' => 'kԑntԑn',
    '🧻' => 'agyanan krataa',
    '🪣' => 'bokiti',
    '🧼' => 'samina',
    '🫧' => 'ahuro',
    '🪥' => 'apͻͻse brͻhye',
    '🧽' => 'sapͻ',
    '🧯' => 'dumgya',
    '🛒' => 'dwadie adaka',
    '🚬' => 'sigarɛte',
    '⚰' => 'fundaka',
    '🪦' => 'nnasoboͻ',
    '⚱' => 'ayiyͻ kukuo',
    '🧿' => 'nazar amulet',
    '🪬' => 'hamsa',
    '🗿' => 'moai',
    '🪧' => 'plakaade',
    '🪪' => 'adida kaade',
    '🏧' => 'ATM nsԑkyerԑnne',
    '🚮' => 'nwura a ԑwͻ bin nsԑnkyerԑnne mu',
    '🚰' => 'pͻͻtabͻl nsuo',
    '♿' => 'mmubuafoͻ akonwa nsԑnkyerԑnne',
    '🚹' => 'mmarima dan',
    '🚺' => 'mmaa dan',
    '🚻' => 'homedan',
    '🚼' => 'abͻfra ahyɛnsodeɛ',
    '🚾' => 'wͻta klosɛte',
    '🛂' => 'pasepͻͻto sowhɛ',
    '🛃' => 'kͻstͻmfoͻ',
    '🛄' => 'bagegi gyeɛ',
    '🛅' => 'benkum lagegi',
    '⚠' => 'kͻkͻbͻ',
    '🚸' => 'mmͻfra retwamu',
    '⛔' => 'nwuramu nni hɔ',
    '🚫' => 'si ho kwan',
    '🚳' => 'sakre mma ha',
    '🚭' => 'nnom sigaret wo ha',
    '🚯' => 'nto nwura ngu ha',
    '🚱' => 'nsuo a yɛnnom',
    '🚷' => 'wɔn a wɔnam fam mfa ha',
    '📵' => 'mfa fon nni dwuma wɔ ha',
    '🔞' => 'deɛ ɔnnuruu du nwɔtwe mma ha',
    '☢' => 'radeoaketifo',
    '☣' => 'bayohasaade',
    '⬆' => 'soro akyerԑkyerԑkwan',
    '↗' => 'soro-nifa akyerɛkyerɛkwan',
    '➡' => 'nifa so akyerԑkyerԑkwan',
    '↘' => 'fam-nifa akyerɛkyerɛkwan',
    '⬇' => 'fam akyerԑkyerԑkwan',
    '↙' => 'fam-benkum akkyerɛkyerɛkwan',
    '⬅' => 'benkum akyerԑkyerԑkwan',
    '↖' => 'soro-benkum akyerԑkyerԑkwan',
    '↕' => 'soro-fam akyerɛkyerɛkwan',
    '↔' => 'benkum-nifa akyerԑkyerԑkwan',
    '↩' => 'nifa akyerԑkyerԑkwan akoa hwɛ benkum',
    '↪' => 'benkum akyerԑkyerԑkwan a akoa hwɛ nifa',
    '⤴' => 'nifa akyerԑkyerԑkwan a akoa hwɛ soro',
    '⤵' => 'nifa akyerԑkyerԑkwan akoa hwɛ fam',
    '🔃' => 'klɔkwaise tenten mu akyerɛkyerɛkwan',
    '🔄' => 'kɔntaklɔkwaise akyerɛkyerɛkwan bɔtom',
    '🔙' => 'AKYIRE akyerԑkyerԑkwan',
    '🔚' => 'akyerɛkyerɛkwan AWIEEƐ',
    '🔛' => 'SO! akyerɛkyerɛkwan',
    '🔜' => 'SOON akyerԑkyerԑkwan',
    '🔝' => 'ƐSORO akyerԑkyerԑkwan',
    '🛐' => 'beaeɛ a ͻsom',
    '⚛' => 'aatͻm agyinahyɛdeɛ',
    '🕉' => 'om',
    '✡' => 'Dawid nsoromma',
    '☸' => 'dharma ntwahonan',
    '☯' => 'yin yang',
    '✝' => 'latin asɛnnua',
    '☦' => 'ɔtɔdɔso asɛnnua',
    '☪' => 'nsoroma ne krɛsɛnte',
    '☮' => 'asomdwoeɛ ahyɛnsodeɛ',
    '🕎' => 'menora',
    '🔯' => 'nsoroma ano nsia a dɔɔto wom',
    '🪯' => 'khanda',
    '♈' => 'Aries',
    '♉' => 'Taurus',
    '♊' => 'Gemini',
    '♋' => 'Cancer',
    '♌' => 'leo',
    '♍' => 'Virgo',
    '♎' => 'Libra',
    '♏' => 'Scorpio',
    '♐' => 'Sagittarius',
    '♑' => 'Capricorn',
    '♒' => 'Aquarius',
    '♓' => 'Pisces',
    '⛎' => 'Ophiuchus',
    '🔀' => 'nnwom fra bɔtom',
    '🔁' => 'si so bɔtom',
    '🔂' => 'si korɔ so bɔtom',
    '▶' => 'bɔ bɔtom',
    '⏩' => 'ntɛm-anim bɔtom',
    '⏭' => 'nnwom a ɛdi hɔ bɔtom',
    '⏯' => 'bɔ anaa gyina bɔtom',
    '◀' => 'kɔ akyi bɔtom',
    '⏪' => 'ntɛm akyi bɔtom',
    '⏮' => 'akyi nnwom bɔtom',
    '🔼' => 'soro bɔtom',
    '⏫' => 'ntɛm soro bɔtom',
    '🔽' => 'fam bɔtom',
    '⏬' => 'ntɛm fam bɔtom',
    '⏸' => 'gyina bɔtom',
    '⏹' => 'gyae bɔtom',
    '⏺' => 'kyere bɔtom',
    '⏏' => 'yi bɔtom',
    '🎦' => 'sini',
    '🔅' => 'kusuu bɔtom',
    '🔆' => 'bɔtom hyɛɛn',
    '📶' => 'antena mmaa',
    '🛜' => 'ɛnni ahoma',
    '📳' => 'awosoɔ berɛ',
    '📴' => 'mobaa fon dum',
    '♀' => 'ͻbaa nsɛnkyerɛnne',
    '♂' => 'ͻbarima nsɛnkyerɛnne',
    '⚧' => 'transgɛnda simboo',
    '✖' => 'mɔɔtiplae',
    '➕' => 'plas',
    '➖' => 'te firi mu',
    '➗' => 'kyɛ mu',
    '🟰' => 'pɛpɛɛpɛ sɛnkyerɛnne a ɛyɛ duru',
    '♾' => 'ɛnni awieeɛ',
    '‼' => 'nteamudeɛ mmienu',
    '⁉' => 'nteamudeɛ asɛmmisa nsɛnkyerɛne',
    '❓' => 'asɛmmisa nsɛnkyerɛne kɔkɔɔ',
    '❔' => 'asɛmmisa nsɛnkyerɛne fitaa',
    '❕' => 'nteamudeɛ fitaa',
    '❗' => 'nteamudeɛ kɔkɔɔ',
    '〰' => 'weevi daahye',
    '💱' => 'sika sesa',
    '💲' => 'dɔla ahyɛnsodeɛ duruduru',
    '⚕' => 'ayarehwɛ ahyɛnsodeɛ',
    '♻' => 'resaekiline ahyɛnsodeɛ',
    '⚜' => 'fleur-de-lis',
    '🔱' => 'traidɛnte ahyɛnsodeɛ',
    '📛' => 'edin baagye',
    '🔰' => 'Gyapanfoɔ ahyɛnsodeɛ ma deɛ ɔrefiri aseɛ',
    '⭕' => 'kanko kɔkɔɔ a tokuro da mu',
    '✅' => 'kyɛɛki ahyɛnsodeɛ bɔtom',
    '☑' => 'kyɛɛki adaka ne kyɛɛki',
    '✔' => 'kyɛɛki ahyɛnsodeɛ',
    '❌' => 'krɔɔs ahyɛnsodeɛ',
    '❎' => 'krɔss ahyɛnsodeɛ bɔtom',
    '➰' => 'kɛɛli luupu',
    '➿' => 'kɛɛli luupu mmienu',
    '〽' => 'ɔfa nsesaeɛ ahyɛnsodeɛ',
    '✳' => 'ɛpɔ nwɔtwe astɛriske',
    '✴' => 'ano nwɔtwe nsoroma',
    '❇' => 'yerɛwyerɛw',
    '™' => 'adwadie ahyɛnsodeɛ',
    '🫟' => 'to pete',
    '🔠' => 'input laatin atwerɛdeɛ akɛseɛ',
    '🔡' => 'input laatin atwerɛdeɛ nketewa',
    '🔢' => 'input nͻma',
    '🔣' => 'input ahyɛnsodeɛ',
    '🔤' => 'input laatin ntwerɛdeɛ',
    '🅰' => 'A bͻtom (mogya su)',
    '🆎' => 'AB bͻtom (mogya su)',
    '🅱' => 'B bͻtom (mogya su)',
    '🆑' => 'CL bͻtom',
    '🆒' => 'COOL bͻtom',
    '🆓' => 'FREE bͻtom',
    'ℹ' => 'asɛm',
    '🆔' => 'ID bͻtom',
    'Ⓜ' => 'M a ɛhyɛ kanko mu',
    '🆕' => 'NEW bͻtom',
    '🆖' => 'NG bͻtom',
    '🅾' => 'O bͻtom (mogya su)',
    '🆗' => 'OK bͻtom',
    '🅿' => 'P bͻtom',
    '🆘' => 'SOS bͻtom',
    '🆙' => 'UP! bͻtom',
    '🆚' => 'VS bͻtom',
    '🈁' => 'Gyapanfoɔ “ɛha” bɔtom',
    '🈂' => 'Gyapanfoɔ “dwumadie ka” bɔtom',
    '🈷' => 'Gyapanfoɔ “bosome sika” bɔtom',
    '🈶' => 'Gyapanfoɔ “ɛnyɛ kwa” bɔtom',
    '🈯' => 'Gyapanfoɔ “wɔakora so” bɔtom',
    '🉐' => 'Gyapanfoɔ “di ano” bɔtom',
    '🈹' => 'Gyapanfoɔ “ntesoɔ” bɔtom',
    '🈚' => 'Gyapanfoɔ “wontua hwee” bɔtom',
    '🈲' => 'Gyapanfoɔ “wɔabara” bɔtom',
    '🉑' => 'Gyapanfoɔ “wɔgye tom” bɔtom',
    '🈸' => 'Gyapanfoɔ “apilikeehyen” bɔtom',
    '🈴' => 'Gyapanfoɔ “nkonimdie aba” bɔtom',
    '🈳' => 'Gyapanfoɔ “kwan da hɔ” bɔtom',
    '㊗' => 'Gyapanfoɔ “ayekoo” bɔtom',
    '㊙' => 'Gyapanfoɔ “ahintasɛm” bɔtom',
    '🈺' => 'Gyapanfoɔ “adwuma apue” bɔtom',
    '🈵' => 'Gyapanfoɔ “kwan nni hɔ” bɔtom',
    '🔴' => 'kanko kͻkͻͻ',
    '🟠' => 'ankaahono kanko',
    '🟡' => 'akokͻsradeɛ kanko',
    '🟢' => 'ahabammono kanko',
    '🔵' => 'bibire kanko',
    '🟣' => 'beredum kanko',
    '🟤' => 'dodoeɛ kanko',
    '⚫' => 'kanko tuntum',
    '⚪' => 'kanko fitaa',
    '🟥' => 'sokwɛɛ kͻkͻͻ',
    '🟧' => 'sokwɛɛ ankaahono',
    '🟨' => 'sokwɛɛ akokͻsradeɛ',
    '🟩' => 'sokwɛɛ ahabammono',
    '🟦' => 'sokwɛɛ bibire',
    '🟪' => 'sokwɛɛ beredum',
    '🟫' => 'sokwɛɛ dodoeɛ',
    '⬛' => 'sokwɛɛ tuntum kɛseɛ',
    '⬜' => 'sokwɛɛ fitaa kɛseɛ',
    '◼' => 'sokwɛɛ hͻ-ne-hͻ tuntum',
    '◻' => 'sokwɛɛ hͻ-ne-hͻ fitaa',
    '◾' => 'sokwɛɛ tuntum keteea kakra',
    '◽' => 'sokwɛɛ fitaa ketewa kakra',
    '▪' => 'sokwɛɛ tuntum ketewa',
    '▫' => 'sokwɛɛ fitaa ketewa',
    '🔶' => 'denkyemboͻ ankaa kɛseɛ',
    '🔷' => 'denkyemboͻ bibire kɛseɛ',
    '🔸' => 'denkyemboͻ ankaahono ketewa',
    '🔹' => 'denkyemboͻ bibire ketewa',
    '🔺' => 'ahinasa kͻkͻͻ kyerɛ soro',
    '🔻' => 'ahinasa kͻkͻͻ kyerɛ fam',
    '💠' => 'denkyemboͻ a dͻͻto wͻ mu',
    '🔘' => 'kasafidie bͻtom',
    '🔳' => 'fitaa sokwɛɛ bͻtom',
    '🔲' => 'tuntum sokwɛɛ bͻtom',
    '🏁' => 'damedame frankaa',
    '🚩' => 'ahiniasa frankaa',
    '🎌' => 'frankaa a yεasensan mu',
    '🏴' => 'frankaa tuntum',
    '🏳' => 'frankaa fitaa',
];
