<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'poljubac: odrasla osoba, odrasla osoba, svijetla koža i srednje svijetla koža',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'poljubac: odrasla osoba, odrasla osoba, svijetla koža i ni svijetla ni tamna koža',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'poljubac: odrasla osoba, odrasla osoba, svijetla koža i srednje tamna koža',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'poljubac: odrasla osoba, odrasla osoba, svijetla koža i tamna koža',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'poljubac: odrasla osoba, odrasla osoba, srednje svijetla koža i svijetla koža',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'poljubac: odrasla osoba, odrasla osoba, srednje svijetla koža i ni svijetla ni tamna koža',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'poljubac: odrasla osoba, odrasla osoba, srednje svijetla koža i srednje tamna koža',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'poljubac: odrasla osoba, odrasla osoba, srednje svijetla koža i tamna koža',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'poljubac: odrasla osoba, odrasla osoba, ni svijetla ni tamna koža i svijetla koža',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'poljubac: odrasla osoba, odrasla osoba, ni svijetla ni tamna koža i srednje svijetla koža',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'poljubac: odrasla osoba, odrasla osoba, ni svijetla ni tamna koža i srednje tamna koža',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'poljubac: odrasla osoba, odrasla osoba, ni svijetla ni tamna koža i tamna koža',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'poljubac: odrasla osoba, odrasla osoba, srednje tamna koža i svijetla koža',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'poljubac: odrasla osoba, odrasla osoba, srednje tamna koža i srednje svijetla koža',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'poljubac: odrasla osoba, odrasla osoba, srednje tamna koža i ni svijetla ni tamna koža',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'poljubac: odrasla osoba, odrasla osoba, srednje tamna koža i tamna koža',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'poljubac: odrasla osoba, odrasla osoba, tamna koža i svijetla koža',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'poljubac: odrasla osoba, odrasla osoba, tamna koža i srednje svijetla koža',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'poljubac: odrasla osoba, odrasla osoba, tamna koža i ni svijetla ni tamna koža',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'poljubac: odrasla osoba, odrasla osoba, tamna koža i srednje tamna koža',
    '👨🏻‍❤‍💋‍👨🏻' => 'poljubac: muškarac, muškarac i svijetla koža',
    '👨🏻‍❤‍💋‍👨🏼' => 'poljubac: muškarac, muškarac, svijetla koža i srednje svijetla koža',
    '👨🏻‍❤‍💋‍👨🏽' => 'poljubac: muškarac, muškarac, svijetla koža i ni svijetla ni tamna koža',
    '👨🏻‍❤‍💋‍👨🏾' => 'poljubac: muškarac, muškarac, svijetla koža i srednje tamna koža',
    '👨🏻‍❤‍💋‍👨🏿' => 'poljubac: muškarac, muškarac, svijetla koža i tamna koža',
    '👨🏼‍❤‍💋‍👨🏻' => 'poljubac: muškarac, muškarac, srednje svijetla koža i svijetla koža',
    '👨🏼‍❤‍💋‍👨🏼' => 'poljubac: muškarac, muškarac i srednje svijetla koža',
    '👨🏼‍❤‍💋‍👨🏽' => 'poljubac: muškarac, muškarac, srednje svijetla koža i ni svijetla ni tamna koža',
    '👨🏼‍❤‍💋‍👨🏾' => 'poljubac: muškarac, muškarac, srednje svijetla koža i srednje tamna koža',
    '👨🏼‍❤‍💋‍👨🏿' => 'poljubac: muškarac, muškarac, srednje svijetla koža i tamna koža',
    '👨🏽‍❤‍💋‍👨🏻' => 'poljubac: muškarac, muškarac, ni svijetla ni tamna koža i svijetla koža',
    '👨🏽‍❤‍💋‍👨🏼' => 'poljubac: muškarac, muškarac, ni svijetla ni tamna koža i srednje svijetla koža',
    '👨🏽‍❤‍💋‍👨🏽' => 'poljubac: muškarac, muškarac i ni svijetla ni tamna koža',
    '👨🏽‍❤‍💋‍👨🏾' => 'poljubac: muškarac, muškarac, ni svijetla ni tamna koža i srednje tamna koža',
    '👨🏽‍❤‍💋‍👨🏿' => 'poljubac: muškarac, muškarac, ni svijetla ni tamna koža i tamna koža',
    '👨🏾‍❤‍💋‍👨🏻' => 'poljubac: muškarac, muškarac, srednje tamna koža i svijetla koža',
    '👨🏾‍❤‍💋‍👨🏼' => 'poljubac: muškarac, muškarac, srednje tamna koža i srednje svijetla koža',
    '👨🏾‍❤‍💋‍👨🏽' => 'poljubac: muškarac, muškarac, srednje tamna koža i ni svijetla ni tamna koža',
    '👨🏾‍❤‍💋‍👨🏾' => 'poljubac: muškarac, muškarac i srednje tamna koža',
    '👨🏾‍❤‍💋‍👨🏿' => 'poljubac: muškarac, muškarac, srednje tamna koža i tamna koža',
    '👨🏿‍❤‍💋‍👨🏻' => 'poljubac: muškarac, muškarac, tamna koža i svijetla koža',
    '👨🏿‍❤‍💋‍👨🏼' => 'poljubac: muškarac, muškarac, tamna koža i srednje svijetla koža',
    '👨🏿‍❤‍💋‍👨🏽' => 'poljubac: muškarac, muškarac, tamna koža i ni svijetla ni tamna koža',
    '👨🏿‍❤‍💋‍👨🏾' => 'poljubac: muškarac, muškarac, tamna koža i srednje tamna koža',
    '👨🏿‍❤‍💋‍👨🏿' => 'poljubac: muškarac, muškarac i tamna koža',
    '👩🏻‍❤‍💋‍👨🏻' => 'poljubac: žena, muškarac i svijetla koža',
    '👩🏻‍❤‍💋‍👨🏼' => 'poljubac: žena, muškarac, svijetla koža i srednje svijetla koža',
    '👩🏻‍❤‍💋‍👨🏽' => 'poljubac: žena, muškarac, svijetla koža i ni svijetla ni tamna koža',
    '👩🏻‍❤‍💋‍👨🏾' => 'poljubac: žena, muškarac, svijetla koža i srednje tamna koža',
    '👩🏻‍❤‍💋‍👨🏿' => 'poljubac: žena, muškarac, svijetla koža i tamna koža',
    '👩🏼‍❤‍💋‍👨🏻' => 'poljubac: žena, muškarac, srednje svijetla koža i svijetla koža',
    '👩🏼‍❤‍💋‍👨🏼' => 'poljubac: žena, muškarac i srednje svijetla koža',
    '👩🏼‍❤‍💋‍👨🏽' => 'poljubac: žena, muškarac, srednje svijetla koža i ni svijetla ni tamna koža',
    '👩🏼‍❤‍💋‍👨🏾' => 'poljubac: žena, muškarac, srednje svijetla koža i srednje tamna koža',
    '👩🏼‍❤‍💋‍👨🏿' => 'poljubac: žena, muškarac, srednje svijetla koža i tamna koža',
    '👩🏽‍❤‍💋‍👨🏻' => 'poljubac: žena, muškarac, ni svijetla ni tamna koža i svijetla koža',
    '👩🏽‍❤‍💋‍👨🏼' => 'poljubac: žena, muškarac, ni svijetla ni tamna koža i srednje svijetla koža',
    '👩🏽‍❤‍💋‍👨🏽' => 'poljubac: žena, muškarac i ni svijetla ni tamna koža',
    '👩🏽‍❤‍💋‍👨🏾' => 'poljubac: žena, muškarac, ni svijetla ni tamna koža i srednje tamna koža',
    '👩🏽‍❤‍💋‍👨🏿' => 'poljubac: žena, muškarac, ni svijetla ni tamna koža i tamna koža',
    '👩🏾‍❤‍💋‍👨🏻' => 'poljubac: žena, muškarac, srednje tamna koža i svijetla koža',
    '👩🏾‍❤‍💋‍👨🏼' => 'poljubac: žena, muškarac, srednje tamna koža i srednje svijetla koža',
    '👩🏾‍❤‍💋‍👨🏽' => 'poljubac: žena, muškarac, srednje tamna koža i ni svijetla ni tamna koža',
    '👩🏾‍❤‍💋‍👨🏾' => 'poljubac: žena, muškarac i srednje tamna koža',
    '👩🏾‍❤‍💋‍👨🏿' => 'poljubac: žena, muškarac, srednje tamna koža i tamna koža',
    '👩🏿‍❤‍💋‍👨🏻' => 'poljubac: žena, muškarac, tamna koža i svijetla koža',
    '👩🏿‍❤‍💋‍👨🏼' => 'poljubac: žena, muškarac, tamna koža i srednje svijetla koža',
    '👩🏿‍❤‍💋‍👨🏽' => 'poljubac: žena, muškarac, tamna koža i ni svijetla ni tamna koža',
    '👩🏿‍❤‍💋‍👨🏾' => 'poljubac: žena, muškarac, tamna koža i srednje tamna koža',
    '👩🏿‍❤‍💋‍👨🏿' => 'poljubac: žena, muškarac i tamna koža',
    '👩🏻‍❤‍💋‍👩🏻' => 'poljubac: žena, žena i svijetla koža',
    '👩🏻‍❤‍💋‍👩🏼' => 'poljubac: žena, žena, svijetla koža i srednje svijetla koža',
    '👩🏻‍❤‍💋‍👩🏽' => 'poljubac: žena, žena, svijetla koža i ni svijetla ni tamna koža',
    '👩🏻‍❤‍💋‍👩🏾' => 'poljubac: žena, žena, svijetla koža i srednje tamna koža',
    '👩🏻‍❤‍💋‍👩🏿' => 'poljubac: žena, žena, svijetla koža i tamna koža',
    '👩🏼‍❤‍💋‍👩🏻' => 'poljubac: žena, žena, srednje svijetla koža i svijetla koža',
    '👩🏼‍❤‍💋‍👩🏼' => 'poljubac: žena, žena i srednje svijetla koža',
    '👩🏼‍❤‍💋‍👩🏽' => 'poljubac: žena, žena, srednje svijetla koža i ni svijetla ni tamna koža',
    '👩🏼‍❤‍💋‍👩🏾' => 'poljubac: žena, žena, srednje svijetla koža i srednje tamna koža',
    '👩🏼‍❤‍💋‍👩🏿' => 'poljubac: žena, žena, srednje svijetla koža i tamna koža',
    '👩🏽‍❤‍💋‍👩🏻' => 'poljubac: žena, žena, ni svijetla ni tamna koža i svijetla koža',
    '👩🏽‍❤‍💋‍👩🏼' => 'poljubac: žena, žena, ni svijetla ni tamna koža i srednje svijetla koža',
    '👩🏽‍❤‍💋‍👩🏽' => 'poljubac: žena, žena i ni svijetla ni tamna koža',
    '👩🏽‍❤‍💋‍👩🏾' => 'poljubac: žena, žena, ni svijetla ni tamna koža i srednje tamna koža',
    '👩🏽‍❤‍💋‍👩🏿' => 'poljubac: žena, žena, ni svijetla ni tamna koža i tamna koža',
    '👩🏾‍❤‍💋‍👩🏻' => 'poljubac: žena, žena, srednje tamna koža i svijetla koža',
    '👩🏾‍❤‍💋‍👩🏼' => 'poljubac: žena, žena, srednje tamna koža i srednje svijetla koža',
    '👩🏾‍❤‍💋‍👩🏽' => 'poljubac: žena, žena, srednje tamna koža i ni svijetla ni tamna koža',
    '👩🏾‍❤‍💋‍👩🏾' => 'poljubac: žena, žena i srednje tamna koža',
    '👩🏾‍❤‍💋‍👩🏿' => 'poljubac: žena, žena, srednje tamna koža i tamna koža',
    '👩🏿‍❤‍💋‍👩🏻' => 'poljubac: žena, žena, tamna koža i svijetla koža',
    '👩🏿‍❤‍💋‍👩🏼' => 'poljubac: žena, žena, tamna koža i srednje svijetla koža',
    '👩🏿‍❤‍💋‍👩🏽' => 'poljubac: žena, žena, tamna koža i ni svijetla ni tamna koža',
    '👩🏿‍❤‍💋‍👩🏾' => 'poljubac: žena, žena, tamna koža i srednje tamna koža',
    '👩🏿‍❤‍💋‍👩🏿' => 'poljubac: žena, žena i tamna koža',
    '🧑🏻‍🫯‍🧑🏼' => 'rvanje: svijetla koža i srednje svijetla koža',
    '🧑🏻‍🫯‍🧑🏽' => 'rvanje: svijetla koža i ni svijetla ni tamna koža',
    '🧑🏻‍🫯‍🧑🏾' => 'rvanje: svijetla koža i srednje tamna koža',
    '🧑🏻‍🫯‍🧑🏿' => 'rvanje: svijetla koža i tamna koža',
    '🧑🏼‍🫯‍🧑🏻' => 'rvanje: srednje svijetla koža i svijetla koža',
    '🧑🏼‍🫯‍🧑🏽' => 'rvanje: srednje svijetla koža i ni svijetla ni tamna koža',
    '🧑🏼‍🫯‍🧑🏾' => 'rvanje: srednje svijetla koža i srednje tamna koža',
    '🧑🏼‍🫯‍🧑🏿' => 'rvanje: srednje svijetla koža i tamna koža',
    '🧑🏽‍🫯‍🧑🏻' => 'rvanje: ni svijetla ni tamna koža i svijetla koža',
    '🧑🏽‍🫯‍🧑🏼' => 'rvanje: ni svijetla ni tamna koža i srednje svijetla koža',
    '🧑🏽‍🫯‍🧑🏾' => 'rvanje: ni svijetla ni tamna koža i srednje tamna koža',
    '🧑🏽‍🫯‍🧑🏿' => 'rvanje: ni svijetla ni tamna koža i tamna koža',
    '🧑🏾‍🫯‍🧑🏻' => 'rvanje: srednje tamna koža i svijetla koža',
    '🧑🏾‍🫯‍🧑🏼' => 'rvanje: srednje tamna koža i srednje svijetla koža',
    '🧑🏾‍🫯‍🧑🏽' => 'rvanje: srednje tamna koža i ni svijetla ni tamna koža',
    '🧑🏾‍🫯‍🧑🏿' => 'rvanje: srednje tamna koža i tamna koža',
    '🧑🏿‍🫯‍🧑🏻' => 'rvanje: tamna koža i svijetla koža',
    '🧑🏿‍🫯‍🧑🏼' => 'rvanje: tamna koža i srednje svijetla koža',
    '🧑🏿‍🫯‍🧑🏽' => 'rvanje: tamna koža i ni svijetla ni tamna koža',
    '🧑🏿‍🫯‍🧑🏾' => 'rvanje: tamna koža i srednje tamna koža',
    '🧑🏻‍❤‍🧑🏼' => 'par sa srcem: odrasla osoba, odrasla osoba, svijetla koža i srednje svijetla koža',
    '🧑🏻‍❤‍🧑🏽' => 'par sa srcem: odrasla osoba, odrasla osoba, svijetla koža i ni svijetla ni tamna koža',
    '🧑🏻‍❤‍🧑🏾' => 'par sa srcem: odrasla osoba, odrasla osoba, svijetla koža i srednje tamna koža',
    '🧑🏻‍❤‍🧑🏿' => 'par sa srcem: odrasla osoba, odrasla osoba, svijetla koža i tamna koža',
    '🧑🏼‍❤‍🧑🏻' => 'par sa srcem: odrasla osoba, odrasla osoba, srednje svijetla koža i svijetla koža',
    '🧑🏼‍❤‍🧑🏽' => 'par sa srcem: odrasla osoba, odrasla osoba, srednje svijetla koža i ni svijetla ni tamna koža',
    '🧑🏼‍❤‍🧑🏾' => 'par sa srcem: odrasla osoba, odrasla osoba, srednje svijetla koža i srednje tamna koža',
    '🧑🏼‍❤‍🧑🏿' => 'par sa srcem: odrasla osoba, odrasla osoba, srednje svijetla koža i tamna koža',
    '🧑🏽‍❤‍🧑🏻' => 'par sa srcem: odrasla osoba, odrasla osoba, ni svijetla ni tamna koža i svijetla koža',
    '🧑🏽‍❤‍🧑🏼' => 'par sa srcem: odrasla osoba, odrasla osoba, ni svijetla ni tamna koža i srednje svijetla koža',
    '🧑🏽‍❤‍🧑🏾' => 'par sa srcem: odrasla osoba, odrasla osoba, ni svijetla ni tamna koža i srednje tamna koža',
    '🧑🏽‍❤‍🧑🏿' => 'par sa srcem: odrasla osoba, odrasla osoba, ni svijetla ni tamna koža i tamna koža',
    '🧑🏾‍❤‍🧑🏻' => 'par sa srcem: odrasla osoba, odrasla osoba, srednje tamna koža i svijetla koža',
    '🧑🏾‍❤‍🧑🏼' => 'par sa srcem: odrasla osoba, odrasla osoba, srednje tamna koža i srednje svijetla koža',
    '🧑🏾‍❤‍🧑🏽' => 'par sa srcem: odrasla osoba, odrasla osoba, srednje tamna koža i ni svijetla ni tamna koža',
    '🧑🏾‍❤‍🧑🏿' => 'par sa srcem: odrasla osoba, odrasla osoba, srednje tamna koža i tamna koža',
    '🧑🏿‍❤‍🧑🏻' => 'par sa srcem: odrasla osoba, odrasla osoba, tamna koža i svijetla koža',
    '🧑🏿‍❤‍🧑🏼' => 'par sa srcem: odrasla osoba, odrasla osoba, tamna koža i srednje svijetla koža',
    '🧑🏿‍❤‍🧑🏽' => 'par sa srcem: odrasla osoba, odrasla osoba, tamna koža i ni svijetla ni tamna koža',
    '🧑🏿‍❤‍🧑🏾' => 'par sa srcem: odrasla osoba, odrasla osoba, tamna koža i srednje tamna koža',
    '🧑🏻‍🐰‍🧑🏼' => 'osobe u provodu: svijetla koža i srednje svijetla koža',
    '🧑🏻‍🐰‍🧑🏽' => 'osobe u provodu: svijetla koža i ni svijetla ni tamna koža',
    '🧑🏻‍🐰‍🧑🏾' => 'osobe u provodu: svijetla koža i srednje tamna koža',
    '🧑🏻‍🐰‍🧑🏿' => 'osobe u provodu: svijetla koža i tamna koža',
    '🧑🏼‍🐰‍🧑🏻' => 'osobe u provodu: srednje svijetla koža i svijetla koža',
    '🧑🏼‍🐰‍🧑🏽' => 'osobe u provodu: srednje svijetla koža i ni svijetla ni tamna koža',
    '🧑🏼‍🐰‍🧑🏾' => 'osobe u provodu: srednje svijetla koža i srednje tamna koža',
    '🧑🏼‍🐰‍🧑🏿' => 'osobe u provodu: srednje svijetla koža i tamna koža',
    '🧑🏽‍🐰‍🧑🏻' => 'osobe u provodu: ni svijetla ni tamna koža i svijetla koža',
    '🧑🏽‍🐰‍🧑🏼' => 'osobe u provodu: ni svijetla ni tamna koža i srednje svijetla koža',
    '🧑🏽‍🐰‍🧑🏾' => 'osobe u provodu: ni svijetla ni tamna koža i srednje tamna koža',
    '🧑🏽‍🐰‍🧑🏿' => 'osobe u provodu: ni svijetla ni tamna koža i tamna koža',
    '🧑🏾‍🐰‍🧑🏻' => 'osobe u provodu: srednje tamna koža i svijetla koža',
    '🧑🏾‍🐰‍🧑🏼' => 'osobe u provodu: srednje tamna koža i srednje svijetla koža',
    '🧑🏾‍🐰‍🧑🏽' => 'osobe u provodu: srednje tamna koža i ni svijetla ni tamna koža',
    '🧑🏾‍🐰‍🧑🏿' => 'osobe u provodu: srednje tamna koža i tamna koža',
    '🧑🏿‍🐰‍🧑🏻' => 'osobe u provodu: tamna koža i svijetla koža',
    '🧑🏿‍🐰‍🧑🏼' => 'osobe u provodu: tamna koža i srednje svijetla koža',
    '🧑🏿‍🐰‍🧑🏽' => 'osobe u provodu: tamna koža i ni svijetla ni tamna koža',
    '🧑🏿‍🐰‍🧑🏾' => 'osobe u provodu: tamna koža i srednje tamna koža',
    '👨🏻‍🫯‍👨🏼' => 'rvači: svijetla koža i srednje svijetla koža',
    '👨🏻‍🫯‍👨🏽' => 'rvači: svijetla koža i ni svijetla ni tamna koža',
    '👨🏻‍🫯‍👨🏾' => 'rvači: svijetla koža i srednje tamna koža',
    '👨🏻‍🫯‍👨🏿' => 'rvači: svijetla koža i tamna koža',
    '👨🏼‍🫯‍👨🏻' => 'rvači: srednje svijetla koža i svijetla koža',
    '👨🏼‍🫯‍👨🏽' => 'rvači: srednje svijetla koža i ni svijetla ni tamna koža',
    '👨🏼‍🫯‍👨🏾' => 'rvači: srednje svijetla koža i srednje tamna koža',
    '👨🏼‍🫯‍👨🏿' => 'rvači: srednje svijetla koža i tamna koža',
    '👨🏽‍🫯‍👨🏻' => 'rvači: ni svijetla ni tamna koža i svijetla koža',
    '👨🏽‍🫯‍👨🏼' => 'rvači: ni svijetla ni tamna koža i srednje svijetla koža',
    '👨🏽‍🫯‍👨🏾' => 'rvači: ni svijetla ni tamna koža i srednje tamna koža',
    '👨🏽‍🫯‍👨🏿' => 'rvači: ni svijetla ni tamna koža i tamna koža',
    '👨🏾‍🫯‍👨🏻' => 'rvači: srednje tamna koža i svijetla koža',
    '👨🏾‍🫯‍👨🏼' => 'rvači: srednje tamna koža i srednje svijetla koža',
    '👨🏾‍🫯‍👨🏽' => 'rvači: srednje tamna koža i ni svijetla ni tamna koža',
    '👨🏾‍🫯‍👨🏿' => 'rvači: srednje tamna koža i tamna koža',
    '👨🏿‍🫯‍👨🏻' => 'rvači: tamna koža i svijetla koža',
    '👨🏿‍🫯‍👨🏼' => 'rvači: tamna koža i srednje svijetla koža',
    '👨🏿‍🫯‍👨🏽' => 'rvači: tamna koža i ni svijetla ni tamna koža',
    '👨🏿‍🫯‍👨🏾' => 'rvači: tamna koža i srednje tamna koža',
    '👨🏻‍❤‍👨🏻' => 'par sa srcem: muškarac, muškarac i svijetla koža',
    '👨🏻‍❤‍👨🏼' => 'par sa srcem: muškarac, muškarac, svijetla koža i srednje svijetla koža',
    '👨🏻‍❤‍👨🏽' => 'par sa srcem: muškarac, muškarac, svijetla koža i ni svijetla ni tamna koža',
    '👨🏻‍❤‍👨🏾' => 'par sa srcem: muškarac, muškarac, svijetla koža i srednje tamna koža',
    '👨🏻‍❤‍👨🏿' => 'par sa srcem: muškarac, muškarac, svijetla koža i tamna koža',
    '👨🏼‍❤‍👨🏻' => 'par sa srcem: muškarac, muškarac, srednje svijetla koža i svijetla koža',
    '👨🏼‍❤‍👨🏼' => 'par sa srcem: muškarac, muškarac i srednje svijetla koža',
    '👨🏼‍❤‍👨🏽' => 'par sa srcem: muškarac, muškarac, srednje svijetla koža i ni svijetla ni tamna koža',
    '👨🏼‍❤‍👨🏾' => 'par sa srcem: muškarac, muškarac, srednje svijetla koža i srednje tamna koža',
    '👨🏼‍❤‍👨🏿' => 'par sa srcem: muškarac, muškarac, srednje svijetla koža i tamna koža',
    '👨🏽‍❤‍👨🏻' => 'par sa srcem: muškarac, muškarac, ni svijetla ni tamna koža i svijetla koža',
    '👨🏽‍❤‍👨🏼' => 'par sa srcem: muškarac, muškarac, ni svijetla ni tamna koža i srednje svijetla koža',
    '👨🏽‍❤‍👨🏽' => 'par sa srcem: muškarac, muškarac i ni svijetla ni tamna koža',
    '👨🏽‍❤‍👨🏾' => 'par sa srcem: muškarac, muškarac, ni svijetla ni tamna koža i srednje tamna koža',
    '👨🏽‍❤‍👨🏿' => 'par sa srcem: muškarac, muškarac, ni svijetla ni tamna koža i tamna koža',
    '👨🏾‍❤‍👨🏻' => 'par sa srcem: muškarac, muškarac, srednje tamna koža i svijetla koža',
    '👨🏾‍❤‍👨🏼' => 'par sa srcem: muškarac, muškarac, srednje tamna koža i srednje svijetla koža',
    '👨🏾‍❤‍👨🏽' => 'par sa srcem: muškarac, muškarac, srednje tamna koža i ni svijetla ni tamna koža',
    '👨🏾‍❤‍👨🏾' => 'par sa srcem: muškarac, muškarac i srednje tamna koža',
    '👨🏾‍❤‍👨🏿' => 'par sa srcem: muškarac, muškarac, srednje tamna koža i tamna koža',
    '👨🏿‍❤‍👨🏻' => 'par sa srcem: muškarac, muškarac, tamna koža i svijetla koža',
    '👨🏿‍❤‍👨🏼' => 'par sa srcem: muškarac, muškarac, tamna koža i srednje svijetla koža',
    '👨🏿‍❤‍👨🏽' => 'par sa srcem: muškarac, muškarac, tamna koža i ni svijetla ni tamna koža',
    '👨🏿‍❤‍👨🏾' => 'par sa srcem: muškarac, muškarac, tamna koža i srednje tamna koža',
    '👨🏿‍❤‍👨🏿' => 'par sa srcem: muškarac, muškarac i tamna koža',
    '👨🏻‍🐰‍👨🏼' => 'muškarci u provodu: svijetla koža i srednje svijetla koža',
    '👨🏻‍🐰‍👨🏽' => 'muškarci u provodu: svijetla koža i ni svijetla ni tamna koža',
    '👨🏻‍🐰‍👨🏾' => 'muškarci u provodu: svijetla koža i srednje tamna koža',
    '👨🏻‍🐰‍👨🏿' => 'muškarci u provodu: svijetla koža i tamna koža',
    '👨🏼‍🐰‍👨🏻' => 'muškarci u provodu: srednje svijetla koža i svijetla koža',
    '👨🏼‍🐰‍👨🏽' => 'muškarci u provodu: srednje svijetla koža i ni svijetla ni tamna koža',
    '👨🏼‍🐰‍👨🏾' => 'muškarci u provodu: srednje svijetla koža i srednje tamna koža',
    '👨🏼‍🐰‍👨🏿' => 'muškarci u provodu: srednje svijetla koža i tamna koža',
    '👨🏽‍🐰‍👨🏻' => 'muškarci u provodu: ni svijetla ni tamna koža i svijetla koža',
    '👨🏽‍🐰‍👨🏼' => 'muškarci u provodu: ni svijetla ni tamna koža i srednje svijetla koža',
    '👨🏽‍🐰‍👨🏾' => 'muškarci u provodu: ni svijetla ni tamna koža i srednje tamna koža',
    '👨🏽‍🐰‍👨🏿' => 'muškarci u provodu: ni svijetla ni tamna koža i tamna koža',
    '👨🏾‍🐰‍👨🏻' => 'muškarci u provodu: srednje tamna koža i svijetla koža',
    '👨🏾‍🐰‍👨🏼' => 'muškarci u provodu: srednje tamna koža i srednje svijetla koža',
    '👨🏾‍🐰‍👨🏽' => 'muškarci u provodu: srednje tamna koža i ni svijetla ni tamna koža',
    '👨🏾‍🐰‍👨🏿' => 'muškarci u provodu: srednje tamna koža i tamna koža',
    '👨🏿‍🐰‍👨🏻' => 'muškarci u provodu: tamna koža i svijetla koža',
    '👨🏿‍🐰‍👨🏼' => 'muškarci u provodu: tamna koža i srednje svijetla koža',
    '👨🏿‍🐰‍👨🏽' => 'muškarci u provodu: tamna koža i ni svijetla ni tamna koža',
    '👨🏿‍🐰‍👨🏾' => 'muškarci u provodu: tamna koža i srednje tamna koža',
    '👩🏻‍🫯‍👩🏼' => 'rvačice: svijetla koža i srednje svijetla koža',
    '👩🏻‍🫯‍👩🏽' => 'rvačice: svijetla koža i ni svijetla ni tamna koža',
    '👩🏻‍🫯‍👩🏾' => 'rvačice: svijetla koža i srednje tamna koža',
    '👩🏻‍🫯‍👩🏿' => 'rvačice: svijetla koža i tamna koža',
    '👩🏼‍🫯‍👩🏻' => 'rvačice: srednje svijetla koža i svijetla koža',
    '👩🏼‍🫯‍👩🏽' => 'rvačice: srednje svijetla koža i ni svijetla ni tamna koža',
    '👩🏼‍🫯‍👩🏾' => 'rvačice: srednje svijetla koža i srednje tamna koža',
    '👩🏼‍🫯‍👩🏿' => 'rvačice: srednje svijetla koža i tamna koža',
    '👩🏽‍🫯‍👩🏻' => 'rvačice: ni svijetla ni tamna koža i svijetla koža',
    '👩🏽‍🫯‍👩🏼' => 'rvačice: ni svijetla ni tamna koža i srednje svijetla koža',
    '👩🏽‍🫯‍👩🏾' => 'rvačice: ni svijetla ni tamna koža i srednje tamna koža',
    '👩🏽‍🫯‍👩🏿' => 'rvačice: ni svijetla ni tamna koža i tamna koža',
    '👩🏾‍🫯‍👩🏻' => 'rvačice: srednje tamna koža i svijetla koža',
    '👩🏾‍🫯‍👩🏼' => 'rvačice: srednje tamna koža i srednje svijetla koža',
    '👩🏾‍🫯‍👩🏽' => 'rvačice: srednje tamna koža i ni svijetla ni tamna koža',
    '👩🏾‍🫯‍👩🏿' => 'rvačice: srednje tamna koža i tamna koža',
    '👩🏿‍🫯‍👩🏻' => 'rvačice: tamna koža i svijetla koža',
    '👩🏿‍🫯‍👩🏼' => 'rvačice: tamna koža i srednje svijetla koža',
    '👩🏿‍🫯‍👩🏽' => 'rvačice: tamna koža i ni svijetla ni tamna koža',
    '👩🏿‍🫯‍👩🏾' => 'rvačice: tamna koža i srednje tamna koža',
    '👩🏻‍❤‍👨🏻' => 'par sa srcem: žena, muškarac i svijetla koža',
    '👩🏻‍❤‍👨🏼' => 'par sa srcem: žena, muškarac, svijetla koža i srednje svijetla koža',
    '👩🏻‍❤‍👨🏽' => 'par sa srcem: žena, muškarac, svijetla koža i ni svijetla ni tamna koža',
    '👩🏻‍❤‍👨🏾' => 'par sa srcem: žena, muškarac, svijetla koža i srednje tamna koža',
    '👩🏻‍❤‍👨🏿' => 'par sa srcem: žena, muškarac, svijetla koža i tamna koža',
    '👩🏼‍❤‍👨🏻' => 'par sa srcem: žena, muškarac, srednje svijetla koža i svijetla koža',
    '👩🏼‍❤‍👨🏼' => 'par sa srcem: žena, muškarac i srednje svijetla koža',
    '👩🏼‍❤‍👨🏽' => 'par sa srcem: žena, muškarac, srednje svijetla koža i ni svijetla ni tamna koža',
    '👩🏼‍❤‍👨🏾' => 'par sa srcem: žena, muškarac, srednje svijetla koža i srednje tamna koža',
    '👩🏼‍❤‍👨🏿' => 'par sa srcem: žena, muškarac, srednje svijetla koža i tamna koža',
    '👩🏽‍❤‍👨🏻' => 'par sa srcem: žena, muškarac, ni svijetla ni tamna koža i svijetla koža',
    '👩🏽‍❤‍👨🏼' => 'par sa srcem: žena, muškarac, ni svijetla ni tamna koža i srednje svijetla koža',
    '👩🏽‍❤‍👨🏽' => 'par sa srcem: žena, muškarac i ni svijetla ni tamna koža',
    '👩🏽‍❤‍👨🏾' => 'par sa srcem: žena, muškarac, ni svijetla ni tamna koža i srednje tamna koža',
    '👩🏽‍❤‍👨🏿' => 'par sa srcem: žena, muškarac, ni svijetla ni tamna koža i tamna koža',
    '👩🏾‍❤‍👨🏻' => 'par sa srcem: žena, muškarac, srednje tamna koža i svijetla koža',
    '👩🏾‍❤‍👨🏼' => 'par sa srcem: žena, muškarac, srednje tamna koža i srednje svijetla koža',
    '👩🏾‍❤‍👨🏽' => 'par sa srcem: žena, muškarac, srednje tamna koža i ni svijetla ni tamna koža',
    '👩🏾‍❤‍👨🏾' => 'par sa srcem: žena, muškarac i srednje tamna koža',
    '👩🏾‍❤‍👨🏿' => 'par sa srcem: žena, muškarac, srednje tamna koža i tamna koža',
    '👩🏿‍❤‍👨🏻' => 'par sa srcem: žena, muškarac, tamna koža i svijetla koža',
    '👩🏿‍❤‍👨🏼' => 'par sa srcem: žena, muškarac, tamna koža i srednje svijetla koža',
    '👩🏿‍❤‍👨🏽' => 'par sa srcem: žena, muškarac, tamna koža i ni svijetla ni tamna koža',
    '👩🏿‍❤‍👨🏾' => 'par sa srcem: žena, muškarac, tamna koža i srednje tamna koža',
    '👩🏿‍❤‍👨🏿' => 'par sa srcem: žena, muškarac i tamna koža',
    '👩🏻‍❤‍👩🏻' => 'par sa srcem: žena, žena i svijetla koža',
    '👩🏻‍❤‍👩🏼' => 'par sa srcem: žena, žena, svijetla koža i srednje svijetla koža',
    '👩🏻‍❤‍👩🏽' => 'par sa srcem: žena, žena, svijetla koža i ni svijetla ni tamna koža',
    '👩🏻‍❤‍👩🏾' => 'par sa srcem: žena, žena, svijetla koža i srednje tamna koža',
    '👩🏻‍❤‍👩🏿' => 'par sa srcem: žena, žena, svijetla koža i tamna koža',
    '👩🏼‍❤‍👩🏻' => 'par sa srcem: žena, žena, srednje svijetla koža i svijetla koža',
    '👩🏼‍❤‍👩🏼' => 'par sa srcem: žena, žena i srednje svijetla koža',
    '👩🏼‍❤‍👩🏽' => 'par sa srcem: žena, žena, srednje svijetla koža i ni svijetla ni tamna koža',
    '👩🏼‍❤‍👩🏾' => 'par sa srcem: žena, žena, srednje svijetla koža i srednje tamna koža',
    '👩🏼‍❤‍👩🏿' => 'par sa srcem: žena, žena, srednje svijetla koža i tamna koža',
    '👩🏽‍❤‍👩🏻' => 'par sa srcem: žena, žena, ni svijetla ni tamna koža i svijetla koža',
    '👩🏽‍❤‍👩🏼' => 'par sa srcem: žena, žena, ni svijetla ni tamna koža i srednje svijetla koža',
    '👩🏽‍❤‍👩🏽' => 'par sa srcem: žena, žena i ni svijetla ni tamna koža',
    '👩🏽‍❤‍👩🏾' => 'par sa srcem: žena, žena, ni svijetla ni tamna koža i srednje tamna koža',
    '👩🏽‍❤‍👩🏿' => 'par sa srcem: žena, žena, ni svijetla ni tamna koža i tamna koža',
    '👩🏾‍❤‍👩🏻' => 'par sa srcem: žena, žena, srednje tamna koža i svijetla koža',
    '👩🏾‍❤‍👩🏼' => 'par sa srcem: žena, žena, srednje tamna koža i srednje svijetla koža',
    '👩🏾‍❤‍👩🏽' => 'par sa srcem: žena, žena, srednje tamna koža i ni svijetla ni tamna koža',
    '👩🏾‍❤‍👩🏾' => 'par sa srcem: žena, žena i srednje tamna koža',
    '👩🏾‍❤‍👩🏿' => 'par sa srcem: žena, žena, srednje tamna koža i tamna koža',
    '👩🏿‍❤‍👩🏻' => 'par sa srcem: žena, žena, tamna koža i svijetla koža',
    '👩🏿‍❤‍👩🏼' => 'par sa srcem: žena, žena, tamna koža i srednje svijetla koža',
    '👩🏿‍❤‍👩🏽' => 'par sa srcem: žena, žena, tamna koža i ni svijetla ni tamna koža',
    '👩🏿‍❤‍👩🏾' => 'par sa srcem: žena, žena, tamna koža i srednje tamna koža',
    '👩🏿‍❤‍👩🏿' => 'par sa srcem: žena, žena i tamna koža',
    '👩🏻‍🐰‍👩🏼' => 'žene u provodu: svijetla koža i srednje svijetla koža',
    '👩🏻‍🐰‍👩🏽' => 'žene u provodu: svijetla koža i ni svijetla ni tamna koža',
    '👩🏻‍🐰‍👩🏾' => 'žene u provodu: svijetla koža i srednje tamna koža',
    '👩🏻‍🐰‍👩🏿' => 'žene u provodu: svijetla koža i tamna koža',
    '👩🏼‍🐰‍👩🏻' => 'žene u provodu: srednje svijetla koža i svijetla koža',
    '👩🏼‍🐰‍👩🏽' => 'žene u provodu: srednje svijetla koža i ni svijetla ni tamna koža',
    '👩🏼‍🐰‍👩🏾' => 'žene u provodu: srednje svijetla koža i srednje tamna koža',
    '👩🏼‍🐰‍👩🏿' => 'žene u provodu: srednje svijetla koža i tamna koža',
    '👩🏽‍🐰‍👩🏻' => 'žene u provodu: ni svijetla ni tamna koža i svijetla koža',
    '👩🏽‍🐰‍👩🏼' => 'žene u provodu: ni svijetla ni tamna koža i srednje svijetla koža',
    '👩🏽‍🐰‍👩🏾' => 'žene u provodu: ni svijetla ni tamna koža i srednje tamna koža',
    '👩🏽‍🐰‍👩🏿' => 'žene u provodu: ni svijetla ni tamna koža i tamna koža',
    '👩🏾‍🐰‍👩🏻' => 'žene u provodu: srednje tamna koža i svijetla koža',
    '👩🏾‍🐰‍👩🏼' => 'žene u provodu: srednje tamna koža i srednje svijetla koža',
    '👩🏾‍🐰‍👩🏽' => 'žene u provodu: srednje tamna koža i ni svijetla ni tamna koža',
    '👩🏾‍🐰‍👩🏿' => 'žene u provodu: srednje tamna koža i tamna koža',
    '👩🏿‍🐰‍👩🏻' => 'žene u provodu: tamna koža i svijetla koža',
    '👩🏿‍🐰‍👩🏼' => 'žene u provodu: tamna koža i srednje svijetla koža',
    '👩🏿‍🐰‍👩🏽' => 'žene u provodu: tamna koža i ni svijetla ni tamna koža',
    '👩🏿‍🐰‍👩🏾' => 'žene u provodu: tamna koža i srednje tamna koža',
    '🧑🏻‍🤝‍🧑🏻' => 'osobe se drže za ruke: svijetla koža',
    '🧑🏻‍🤝‍🧑🏼' => 'osobe se drže za ruke: svijetla koža i srednje svijetla koža',
    '🧑🏻‍🤝‍🧑🏽' => 'osobe se drže za ruke: svijetla koža i ni svijetla ni tamna koža',
    '🧑🏻‍🤝‍🧑🏾' => 'osobe se drže za ruke: svijetla koža i srednje tamna koža',
    '🧑🏻‍🤝‍🧑🏿' => 'osobe se drže za ruke: svijetla koža i tamna koža',
    '🧑🏼‍🤝‍🧑🏻' => 'osobe se drže za ruke: srednje svijetla koža i svijetla koža',
    '🧑🏼‍🤝‍🧑🏼' => 'osobe se drže za ruke: srednje svijetla koža',
    '🧑🏼‍🤝‍🧑🏽' => 'osobe se drže za ruke: srednje svijetla koža i ni svijetla ni tamna koža',
    '🧑🏼‍🤝‍🧑🏾' => 'osobe se drže za ruke: srednje svijetla koža i srednje tamna koža',
    '🧑🏼‍🤝‍🧑🏿' => 'osobe se drže za ruke: srednje svijetla koža i tamna koža',
    '🧑🏽‍🤝‍🧑🏻' => 'osobe se drže za ruke: ni svijetla ni tamna koža i svijetla koža',
    '🧑🏽‍🤝‍🧑🏼' => 'osobe se drže za ruke: ni svijetla ni tamna koža i srednje svijetla koža',
    '🧑🏽‍🤝‍🧑🏽' => 'osobe se drže za ruke: ni svijetla ni tamna koža',
    '🧑🏽‍🤝‍🧑🏾' => 'osobe se drže za ruke: ni svijetla ni tamna koža i srednje tamna koža',
    '🧑🏽‍🤝‍🧑🏿' => 'osobe se drže za ruke: ni svijetla ni tamna koža i tamna koža',
    '🧑🏾‍🤝‍🧑🏻' => 'osobe se drže za ruke: srednje tamna koža i svijetla koža',
    '🧑🏾‍🤝‍🧑🏼' => 'osobe se drže za ruke: srednje tamna koža i srednje svijetla koža',
    '🧑🏾‍🤝‍🧑🏽' => 'osobe se drže za ruke: srednje tamna koža i ni svijetla ni tamna koža',
    '🧑🏾‍🤝‍🧑🏾' => 'osobe se drže za ruke: srednje tamna koža',
    '🧑🏾‍🤝‍🧑🏿' => 'osobe se drže za ruke: srednje tamna koža i tamna koža',
    '🧑🏿‍🤝‍🧑🏻' => 'osobe se drže za ruke: tamna koža i svijetla koža',
    '🧑🏿‍🤝‍🧑🏼' => 'osobe se drže za ruke: tamna koža i srednje svijetla koža',
    '🧑🏿‍🤝‍🧑🏽' => 'osobe se drže za ruke: tamna koža i ni svijetla ni tamna koža',
    '🧑🏿‍🤝‍🧑🏾' => 'osobe se drže za ruke: tamna koža i srednje tamna koža',
    '🧑🏿‍🤝‍🧑🏿' => 'osobe se drže za ruke: tamna koža',
    '👩🏻‍🤝‍👩🏼' => 'žene se drže za ruke: svijetla koža i srednje svijetla koža',
    '👩🏻‍🤝‍👩🏽' => 'žene se drže za ruke: svijetla koža i ni svijetla ni tamna koža',
    '👩🏻‍🤝‍👩🏾' => 'žene se drže za ruke: svijetla koža i srednje tamna koža',
    '👩🏻‍🤝‍👩🏿' => 'žene se drže za ruke: svijetla koža i tamna koža',
    '👩🏼‍🤝‍👩🏻' => 'žene se drže za ruke: srednje svijetla koža i svijetla koža',
    '👩🏼‍🤝‍👩🏽' => 'žene se drže za ruke: srednje svijetla koža i ni svijetla ni tamna koža',
    '👩🏼‍🤝‍👩🏾' => 'žene se drže za ruke: srednje svijetla koža i srednje tamna koža',
    '👩🏼‍🤝‍👩🏿' => 'žene se drže za ruke: srednje svijetla koža i tamna koža',
    '👩🏽‍🤝‍👩🏻' => 'žene se drže za ruke: ni svijetla ni tamna koža i svijetla koža',
    '👩🏽‍🤝‍👩🏼' => 'žene se drže za ruke: ni svijetla ni tamna koža i srednje svijetla koža',
    '👩🏽‍🤝‍👩🏾' => 'žene se drže za ruke: ni svijetla ni tamna koža i srednje tamna koža',
    '👩🏽‍🤝‍👩🏿' => 'žene se drže za ruke: ni svijetla ni tamna koža i tamna koža',
    '👩🏾‍🤝‍👩🏻' => 'žene se drže za ruke: srednje tamna koža i svijetla koža',
    '👩🏾‍🤝‍👩🏼' => 'žene se drže za ruke: srednje tamna koža i srednje svijetla koža',
    '👩🏾‍🤝‍👩🏽' => 'žene se drže za ruke: srednje tamna koža i ni svijetla ni tamna koža',
    '👩🏾‍🤝‍👩🏿' => 'žene se drže za ruke: srednje tamna koža i tamna koža',
    '👩🏿‍🤝‍👩🏻' => 'žene se drže za ruke: tamna koža i svijetla koža',
    '👩🏿‍🤝‍👩🏼' => 'žene se drže za ruke: tamna koža i srednje svijetla koža',
    '👩🏿‍🤝‍👩🏽' => 'žene se drže za ruke: tamna koža i ni svijetla ni tamna koža',
    '👩🏿‍🤝‍👩🏾' => 'žene se drže za ruke: tamna koža i srednje tamna koža',
    '👩🏻‍🤝‍👨🏼' => 'žena i muškarac se drže za ruke: svijetla koža i srednje svijetla koža',
    '👩🏻‍🤝‍👨🏽' => 'žena i muškarac se drže za ruke: svijetla koža i ni svijetla ni tamna koža',
    '👩🏻‍🤝‍👨🏾' => 'žena i muškarac se drže za ruke: svijetla koža i srednje tamna koža',
    '👩🏻‍🤝‍👨🏿' => 'žena i muškarac se drže za ruke: svijetla koža i tamna koža',
    '👩🏼‍🤝‍👨🏻' => 'žena i muškarac se drže za ruke: srednje svijetla koža i svijetla koža',
    '👩🏼‍🤝‍👨🏽' => 'žena i muškarac se drže za ruke: srednje svijetla koža i ni svijetla ni tamna koža',
    '👩🏼‍🤝‍👨🏾' => 'žena i muškarac se drže za ruke: srednje svijetla koža i srednje tamna koža',
    '👩🏼‍🤝‍👨🏿' => 'žena i muškarac se drže za ruke: srednje svijetla koža i tamna koža',
    '👩🏽‍🤝‍👨🏻' => 'žena i muškarac se drže za ruke: ni svijetla ni tamna koža i svijetla koža',
    '👩🏽‍🤝‍👨🏼' => 'žena i muškarac se drže za ruke: ni svijetla ni tamna koža i srednje svijetla koža',
    '👩🏽‍🤝‍👨🏾' => 'žena i muškarac se drže za ruke: ni svijetla ni tamna koža i srednje tamna koža',
    '👩🏽‍🤝‍👨🏿' => 'žena i muškarac se drže za ruke: ni svijetla ni tamna koža i tamna koža',
    '👩🏾‍🤝‍👨🏻' => 'žena i muškarac se drže za ruke: srednje tamna koža i svijetla koža',
    '👩🏾‍🤝‍👨🏼' => 'žena i muškarac se drže za ruke: srednje tamna koža i srednje svijetla koža',
    '👩🏾‍🤝‍👨🏽' => 'žena i muškarac se drže za ruke: srednje tamna koža i ni svijetla ni tamna koža',
    '👩🏾‍🤝‍👨🏿' => 'žena i muškarac se drže za ruke: srednje tamna koža i tamna koža',
    '👩🏿‍🤝‍👨🏻' => 'žena i muškarac se drže za ruke: tamna koža i svijetla koža',
    '👩🏿‍🤝‍👨🏼' => 'žena i muškarac se drže za ruke: tamna koža i srednje svijetla koža',
    '👩🏿‍🤝‍👨🏽' => 'žena i muškarac se drže za ruke: tamna koža i ni svijetla ni tamna koža',
    '👩🏿‍🤝‍👨🏾' => 'žena i muškarac se drže za ruke: tamna koža i srednje tamna koža',
    '👨🏻‍🤝‍👨🏼' => 'muškarci se drže za ruke: svijetla koža i srednje svijetla koža',
    '👨🏻‍🤝‍👨🏽' => 'muškarci se drže za ruke: svijetla koža i ni svijetla ni tamna koža',
    '👨🏻‍🤝‍👨🏾' => 'muškarci se drže za ruke: svijetla koža i srednje tamna koža',
    '👨🏻‍🤝‍👨🏿' => 'muškarci se drže za ruke: svijetla koža i tamna koža',
    '👨🏼‍🤝‍👨🏻' => 'muškarci se drže za ruke: srednje svijetla koža i svijetla koža',
    '👨🏼‍🤝‍👨🏽' => 'muškarci se drže za ruke: srednje svijetla koža i ni svijetla ni tamna koža',
    '👨🏼‍🤝‍👨🏾' => 'muškarci se drže za ruke: srednje svijetla koža i srednje tamna koža',
    '👨🏼‍🤝‍👨🏿' => 'muškarci se drže za ruke: srednje svijetla koža i tamna koža',
    '👨🏽‍🤝‍👨🏻' => 'muškarci se drže za ruke: ni svijetla ni tamna koža i svijetla koža',
    '👨🏽‍🤝‍👨🏼' => 'muškarci se drže za ruke: ni svijetla ni tamna koža i srednje svijetla koža',
    '👨🏽‍🤝‍👨🏾' => 'muškarci se drže za ruke: ni svijetla ni tamna koža i srednje tamna koža',
    '👨🏽‍🤝‍👨🏿' => 'muškarci se drže za ruke: ni svijetla ni tamna koža i tamna koža',
    '👨🏾‍🤝‍👨🏻' => 'muškarci se drže za ruke: srednje tamna koža i svijetla koža',
    '👨🏾‍🤝‍👨🏼' => 'muškarci se drže za ruke: srednje tamna koža i srednje svijetla koža',
    '👨🏾‍🤝‍👨🏽' => 'muškarci se drže za ruke: srednje tamna koža i ni svijetla ni tamna koža',
    '👨🏾‍🤝‍👨🏿' => 'muškarci se drže za ruke: srednje tamna koža i tamna koža',
    '👨🏿‍🤝‍👨🏻' => 'muškarci se drže za ruke: tamna koža i svijetla koža',
    '👨🏿‍🤝‍👨🏼' => 'muškarci se drže za ruke: tamna koža i srednje svijetla koža',
    '👨🏿‍🤝‍👨🏽' => 'muškarci se drže za ruke: tamna koža i ni svijetla ni tamna koža',
    '👨🏿‍🤝‍👨🏾' => 'muškarci se drže za ruke: tamna koža i srednje tamna koža',
    '👩‍❤‍💋‍👨' => 'poljubac: žena i muškarac',
    '👨‍❤‍💋‍👨' => 'poljubac: muškarac i muškarac',
    '👩‍❤‍💋‍👩' => 'poljubac: žena i žena',
    '👨‍👩‍👧‍👦' => 'porodica: muškarac, žena, djevojčica i dječak',
    '👨‍👩‍👦‍👦' => 'porodica: muškarac, žena, dječak i dječak',
    '👨‍👩‍👧‍👧' => 'porodica: muškarac, žena, djevojčica i djevojčica',
    '👨‍👨‍👧‍👦' => 'porodica: muškarac, muškarac, djevojčica i dječak',
    '👨‍👨‍👦‍👦' => 'porodica: muškarac, muškarac, dječak i dječak',
    '👨‍👨‍👧‍👧' => 'porodica: muškarac, muškarac, djevojčica i djevojčica',
    '👩‍👩‍👧‍👦' => 'porodica: žena, žena, djevojčica i dječak',
    '👩‍👩‍👦‍👦' => 'porodica: žena, žena, dječak i dječak',
    '👩‍👩‍👧‍👧' => 'porodica: žena, žena, djevojčica i djevojčica',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'zastava: Engleska',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'zastava: Škotska',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'zastava: Vels',
    '🧑‍🧑‍🧒‍🧒' => 'porodica: odrasla osoba, odrasla osoba, dijete, dijete',
    '🚶🏻‍♀‍➡' => 'žena hoda: svijetla koža i gleda udesno',
    '🚶🏼‍♀‍➡' => 'žena hoda: srednje svijetla koža i gleda udesno',
    '🚶🏽‍♀‍➡' => 'žena hoda: ni svijetla ni tamna koža i gleda udesno',
    '🚶🏾‍♀‍➡' => 'žena hoda: srednje tamna koža i gleda udesno',
    '🚶🏿‍♀‍➡' => 'žena hoda: tamna koža i gleda udesno',
    '🚶🏻‍♂‍➡' => 'muškarac hoda: svijetla koža i gleda udesno',
    '🚶🏼‍♂‍➡' => 'muškarac hoda: srednje svijetla koža i gleda udesno',
    '🚶🏽‍♂‍➡' => 'muškarac hoda: ni svijetla ni tamna koža i gleda udesno',
    '🚶🏾‍♂‍➡' => 'muškarac hoda: srednje tamna koža i gleda udesno',
    '🚶🏿‍♂‍➡' => 'muškarac hoda: tamna koža i gleda udesno',
    '🧎🏻‍♀‍➡' => 'žena kleči: svijetla koža i gleda udesno',
    '🧎🏼‍♀‍➡' => 'žena kleči: srednje svijetla koža i gleda udesno',
    '🧎🏽‍♀‍➡' => 'žena kleči: ni svijetla ni tamna koža i gleda udesno',
    '🧎🏾‍♀‍➡' => 'žena kleči: srednje tamna koža i gleda udesno',
    '🧎🏿‍♀‍➡' => 'žena kleči: tamna koža i gleda udesno',
    '🧎🏻‍♂‍➡' => 'čovek kleči: svijetla koža i gleda udesno',
    '🧎🏼‍♂‍➡' => 'čovek kleči: srednje svijetla koža i gleda udesno',
    '🧎🏽‍♂‍➡' => 'čovek kleči: ni svijetla ni tamna koža i gleda udesno',
    '🧎🏾‍♂‍➡' => 'čovek kleči: srednje tamna koža i gleda udesno',
    '🧎🏿‍♂‍➡' => 'čovek kleči: tamna koža i gleda udesno',
    '🧑🏻‍🦯‍➡' => 'osoba sa pomoćnim štapom: svijetla koža i gleda udesno',
    '🧑🏼‍🦯‍➡' => 'osoba sa pomoćnim štapom: srednje svijetla koža i gleda udesno',
    '🧑🏽‍🦯‍➡' => 'osoba sa pomoćnim štapom: ni svijetla ni tamna koža i gleda udesno',
    '🧑🏾‍🦯‍➡' => 'osoba sa pomoćnim štapom: srednje tamna koža i gleda udesno',
    '🧑🏿‍🦯‍➡' => 'osoba sa pomoćnim štapom: tamna koža i gleda udesno',
    '👨🏻‍🦯‍➡' => 'čovjek sa pomoćnim štapom: svijetla koža i gleda udesno',
    '👨🏼‍🦯‍➡' => 'čovjek sa pomoćnim štapom: srednje svijetla koža i gleda udesno',
    '👨🏽‍🦯‍➡' => 'čovjek sa pomoćnim štapom: ni svijetla ni tamna koža i gleda udesno',
    '👨🏾‍🦯‍➡' => 'čovjek sa pomoćnim štapom: srednje tamna koža i gleda udesno',
    '👨🏿‍🦯‍➡' => 'čovjek sa pomoćnim štapom: tamna koža i gleda udesno',
    '👩🏻‍🦯‍➡' => 'žena sa pomoćnim štapom: svijetla koža i gleda udesno',
    '👩🏼‍🦯‍➡' => 'žena sa pomoćnim štapom: srednje svijetla koža i gleda udesno',
    '👩🏽‍🦯‍➡' => 'žena sa pomoćnim štapom: ni svijetla ni tamna koža i gleda udesno',
    '👩🏾‍🦯‍➡' => 'žena sa pomoćnim štapom: srednje tamna koža i gleda udesno',
    '👩🏿‍🦯‍➡' => 'žena sa pomoćnim štapom: tamna koža i gleda udesno',
    '🧑🏻‍🦼‍➡' => 'osoba u motornim kolicima: svijetla koža i gleda udesno',
    '🧑🏼‍🦼‍➡' => 'osoba u motornim kolicima: srednje svijetla koža i gleda udesno',
    '🧑🏽‍🦼‍➡' => 'osoba u motornim kolicima: ni svijetla ni tamna koža i gleda udesno',
    '🧑🏾‍🦼‍➡' => 'osoba u motornim kolicima: srednje tamna koža i gleda udesno',
    '🧑🏿‍🦼‍➡' => 'osoba u motornim kolicima: tamna koža i gleda udesno',
    '👨🏻‍🦼‍➡' => 'čovjek u motornim kolicima: svijetla koža i gleda udesno',
    '👨🏼‍🦼‍➡' => 'čovjek u motornim kolicima: srednje svijetla koža i gleda udesno',
    '👨🏽‍🦼‍➡' => 'čovjek u motornim kolicima: ni svijetla ni tamna koža i gleda udesno',
    '👨🏾‍🦼‍➡' => 'čovjek u motornim kolicima: srednje tamna koža i gleda udesno',
    '👨🏿‍🦼‍➡' => 'čovjek u motornim kolicima: tamna koža i gleda udesno',
    '👩🏻‍🦼‍➡' => 'žena u motornim kolicima: svijetla koža i gleda udesno',
    '👩🏼‍🦼‍➡' => 'žena u motornim kolicima: srednje svijetla koža i gleda udesno',
    '👩🏽‍🦼‍➡' => 'žena u motornim kolicima: ni svijetla ni tamna koža i gleda udesno',
    '👩🏾‍🦼‍➡' => 'žena u motornim kolicima: srednje tamna koža i gleda udesno',
    '👩🏿‍🦼‍➡' => 'žena u motornim kolicima: tamna koža i gleda udesno',
    '🧑🏻‍🦽‍➡' => 'osoba u mehaničkim kolicima: svijetla koža i gleda udesno',
    '🧑🏼‍🦽‍➡' => 'osoba u mehaničkim kolicima: srednje svijetla koža i gleda udesno',
    '🧑🏽‍🦽‍➡' => 'osoba u mehaničkim kolicima: ni svijetla ni tamna koža i gleda udesno',
    '🧑🏾‍🦽‍➡' => 'osoba u mehaničkim kolicima: srednje tamna koža i gleda udesno',
    '🧑🏿‍🦽‍➡' => 'osoba u mehaničkim kolicima: tamna koža i gleda udesno',
    '👨🏻‍🦽‍➡' => 'čovjek u mehaničkim kolicima: svijetla koža i gleda udesno',
    '👨🏼‍🦽‍➡' => 'čovjek u mehaničkim kolicima: srednje svijetla koža i gleda udesno',
    '👨🏽‍🦽‍➡' => 'čovjek u mehaničkim kolicima: ni svijetla ni tamna koža i gleda udesno',
    '👨🏾‍🦽‍➡' => 'čovjek u mehaničkim kolicima: srednje tamna koža i gleda udesno',
    '👨🏿‍🦽‍➡' => 'čovjek u mehaničkim kolicima: tamna koža i gleda udesno',
    '👩🏻‍🦽‍➡' => 'žena u mehaničkim kolicima: svijetla koža i gleda udesno',
    '👩🏼‍🦽‍➡' => 'žena u mehaničkim kolicima: srednje svijetla koža i gleda udesno',
    '👩🏽‍🦽‍➡' => 'žena u mehaničkim kolicima: ni svijetla ni tamna koža i gleda udesno',
    '👩🏾‍🦽‍➡' => 'žena u mehaničkim kolicima: srednje tamna koža i gleda udesno',
    '👩🏿‍🦽‍➡' => 'žena u mehaničkim kolicima: tamna koža i gleda udesno',
    '🏃🏻‍♀‍➡' => 'žena trči: svijetla koža i gleda udesno',
    '🏃🏼‍♀‍➡' => 'žena trči: srednje svijetla koža i gleda udesno',
    '🏃🏽‍♀‍➡' => 'žena trči: ni svijetla ni tamna koža i gleda udesno',
    '🏃🏾‍♀‍➡' => 'žena trči: srednje tamna koža i gleda udesno',
    '🏃🏿‍♀‍➡' => 'žena trči: tamna koža i gleda udesno',
    '🏃🏻‍♂‍➡' => 'muškarac trči: svijetla koža i gleda udesno',
    '🏃🏼‍♂‍➡' => 'muškarac trči: srednje svijetla koža i gleda udesno',
    '🏃🏽‍♂‍➡' => 'muškarac trči: ni svijetla ni tamna koža i gleda udesno',
    '🏃🏾‍♂‍➡' => 'muškarac trči: srednje tamna koža i gleda udesno',
    '🏃🏿‍♂‍➡' => 'muškarac trči: tamna koža i gleda udesno',
    '🫱🏻‍🫲🏼' => 'rukovanje: svijetla koža i srednje svijetla koža',
    '🫱🏻‍🫲🏽' => 'rukovanje: svijetla koža i ni svijetla ni tamna koža',
    '🫱🏻‍🫲🏾' => 'rukovanje: svijetla koža i srednje tamna koža',
    '🫱🏻‍🫲🏿' => 'rukovanje: svijetla koža i tamna koža',
    '🫱🏼‍🫲🏻' => 'rukovanje: srednje svijetla koža i svijetla koža',
    '🫱🏼‍🫲🏽' => 'rukovanje: srednje svijetla koža i ni svijetla ni tamna koža',
    '🫱🏼‍🫲🏾' => 'rukovanje: srednje svijetla koža i srednje tamna koža',
    '🫱🏼‍🫲🏿' => 'rukovanje: srednje svijetla koža i tamna koža',
    '🫱🏽‍🫲🏻' => 'rukovanje: ni svijetla ni tamna koža i svijetla koža',
    '🫱🏽‍🫲🏼' => 'rukovanje: ni svijetla ni tamna koža i srednje svijetla koža',
    '🫱🏽‍🫲🏾' => 'rukovanje: ni svijetla ni tamna koža i srednje tamna koža',
    '🫱🏽‍🫲🏿' => 'rukovanje: ni svijetla ni tamna koža i tamna koža',
    '🫱🏾‍🫲🏻' => 'rukovanje: srednje tamna koža i svijetla koža',
    '🫱🏾‍🫲🏼' => 'rukovanje: srednje tamna koža i srednje svijetla koža',
    '🫱🏾‍🫲🏽' => 'rukovanje: srednje tamna koža i ni svijetla ni tamna koža',
    '🫱🏾‍🫲🏿' => 'rukovanje: srednje tamna koža i tamna koža',
    '🫱🏿‍🫲🏻' => 'rukovanje: tamna koža i svijetla koža',
    '🫱🏿‍🫲🏼' => 'rukovanje: tamna koža i srednje svijetla koža',
    '🫱🏿‍🫲🏽' => 'rukovanje: tamna koža i ni svijetla ni tamna koža',
    '🫱🏿‍🫲🏾' => 'rukovanje: tamna koža i srednje tamna koža',
    '🚶‍♀‍➡' => 'žena hoda: gleda udesno',
    '🚶‍♂‍➡' => 'muškarac hoda: gleda udesno',
    '🧎‍♀‍➡' => 'žena kleči: gleda udesno',
    '🧎‍♂‍➡' => 'čovek kleči: gleda udesno',
    '🧑‍🦯‍➡' => 'osoba sa pomoćnim štapom: gleda udesno',
    '👨‍🦯‍➡' => 'čovjek sa pomoćnim štapom: gleda udesno',
    '👩‍🦯‍➡' => 'žena sa pomoćnim štapom: gleda udesno',
    '🧑‍🦼‍➡' => 'osoba u motornim kolicima: gleda udesno',
    '👨‍🦼‍➡' => 'čovjek u motornim kolicima: gleda udesno',
    '👩‍🦼‍➡' => 'žena u motornim kolicima: gleda udesno',
    '🧑‍🦽‍➡' => 'osoba u mehaničkim kolicima: gleda udesno',
    '👨‍🦽‍➡' => 'čovjek u mehaničkim kolicima: gleda udesno',
    '👩‍🦽‍➡' => 'žena u mehaničkim kolicima: gleda udesno',
    '🏃‍♀‍➡' => 'žena trči: gleda udesno',
    '🏃‍♂‍➡' => 'muškarac trči: gleda udesno',
    '👩‍❤‍👨' => 'par sa srcem: žena i muškarac',
    '👨‍❤‍👨' => 'par sa srcem: muškarac i muškarac',
    '👩‍❤‍👩' => 'par sa srcem: žena i žena',
    '👨‍👩‍👦' => 'porodica: muškarac, žena i dječak',
    '👨‍👩‍👧' => 'porodica: muškarac, žena i djevojčica',
    '👨‍👨‍👦' => 'porodica: muškarac, muškarac i dječak',
    '👨‍👨‍👧' => 'porodica: muškarac, muškarac i djevojčica',
    '👩‍👩‍👦' => 'porodica: žena, žena i dječak',
    '👩‍👩‍👧' => 'porodica: žena, žena i djevojčica',
    '👨‍👦‍👦' => 'porodica: muškarac, dječak i dječak',
    '👨‍👧‍👦' => 'porodica: muškarac, djevojčica i dječak',
    '👨‍👧‍👧' => 'porodica: muškarac, djevojčica i djevojčica',
    '👩‍👦‍👦' => 'porodica: žena, dječak i dječak',
    '👩‍👧‍👦' => 'porodica: žena, djevojčica i dječak',
    '👩‍👧‍👧' => 'porodica: žena, djevojčica i djevojčica',
    '🧑‍🤝‍🧑' => 'osobe se drže za ruke',
    '🧑‍🧑‍🧒' => 'porodica: odrasla osoba, odrasla osoba, dijete',
    '🧑‍🧒‍🧒' => 'porodica: odrasla osoba, dijete, dijete',
    '🧑🏻‍🦰' => 'odrasla osoba: svijetla koža i crvena kosa',
    '🧑🏼‍🦰' => 'odrasla osoba: srednje svijetla koža i crvena kosa',
    '🧑🏽‍🦰' => 'odrasla osoba: ni svijetla ni tamna koža i crvena kosa',
    '🧑🏾‍🦰' => 'odrasla osoba: srednje tamna koža i crvena kosa',
    '🧑🏿‍🦰' => 'odrasla osoba: tamna koža i crvena kosa',
    '🧑🏻‍🦱' => 'odrasla osoba: svijetla koža i kovrdžava kosa',
    '🧑🏼‍🦱' => 'odrasla osoba: srednje svijetla koža i kovrdžava kosa',
    '🧑🏽‍🦱' => 'odrasla osoba: ni svijetla ni tamna koža i kovrdžava kosa',
    '🧑🏾‍🦱' => 'odrasla osoba: srednje tamna koža i kovrdžava kosa',
    '🧑🏿‍🦱' => 'odrasla osoba: tamna koža i kovrdžava kosa',
    '🧑🏻‍🦳' => 'odrasla osoba: svijetla koža i sijeda kosa',
    '🧑🏼‍🦳' => 'odrasla osoba: srednje svijetla koža i sijeda kosa',
    '🧑🏽‍🦳' => 'odrasla osoba: ni svijetla ni tamna koža i sijeda kosa',
    '🧑🏾‍🦳' => 'odrasla osoba: srednje tamna koža i sijeda kosa',
    '🧑🏿‍🦳' => 'odrasla osoba: tamna koža i sijeda kosa',
    '🧑🏻‍🦲' => 'odrasla osoba: svijetla koža i ćelav',
    '🧑🏼‍🦲' => 'odrasla osoba: srednje svijetla koža i ćelav',
    '🧑🏽‍🦲' => 'odrasla osoba: ni svijetla ni tamna koža i ćelav',
    '🧑🏾‍🦲' => 'odrasla osoba: srednje tamna koža i ćelav',
    '🧑🏿‍🦲' => 'odrasla osoba: tamna koža i ćelav',
    '🧑🏻‍🩰' => 'baletan: svijetla koža',
    '🧑🏼‍🩰' => 'baletan: srednje svijetla koža',
    '🧑🏽‍🩰' => 'baletan: ni svijetla ni tamna koža',
    '🧑🏾‍🩰' => 'baletan: srednje tamna koža',
    '🧑🏿‍🩰' => 'baletan: tamna koža',
    '🧔🏻‍♂' => 'muškarac: svijetla koža i brada',
    '🧔🏼‍♂' => 'muškarac: srednje svijetla koža i brada',
    '🧔🏽‍♂' => 'muškarac: ni svijetla ni tamna koža i brada',
    '🧔🏾‍♂' => 'muškarac: srednje tamna koža i brada',
    '🧔🏿‍♂' => 'muškarac: tamna koža i brada',
    '👱🏻‍♂' => 'plav muškarac: svijetla koža',
    '👱🏼‍♂' => 'plav muškarac: srednje svijetla koža',
    '👱🏽‍♂' => 'plav muškarac: ni svijetla ni tamna koža',
    '👱🏾‍♂' => 'plav muškarac: srednje tamna koža',
    '👱🏿‍♂' => 'plav muškarac: tamna koža',
    '👨🏻‍🦰' => 'muškarac: svijetla koža i crvena kosa',
    '👨🏼‍🦰' => 'muškarac: srednje svijetla koža i crvena kosa',
    '👨🏽‍🦰' => 'muškarac: ni svijetla ni tamna koža i crvena kosa',
    '👨🏾‍🦰' => 'muškarac: srednje tamna koža i crvena kosa',
    '👨🏿‍🦰' => 'muškarac: tamna koža i crvena kosa',
    '👨🏻‍🦱' => 'muškarac: svijetla koža i kovrdžava kosa',
    '👨🏼‍🦱' => 'muškarac: srednje svijetla koža i kovrdžava kosa',
    '👨🏽‍🦱' => 'muškarac: ni svijetla ni tamna koža i kovrdžava kosa',
    '👨🏾‍🦱' => 'muškarac: srednje tamna koža i kovrdžava kosa',
    '👨🏿‍🦱' => 'muškarac: tamna koža i kovrdžava kosa',
    '👨🏻‍🦳' => 'muškarac: svijetla koža i sijeda kosa',
    '👨🏼‍🦳' => 'muškarac: srednje svijetla koža i sijeda kosa',
    '👨🏽‍🦳' => 'muškarac: ni svijetla ni tamna koža i sijeda kosa',
    '👨🏾‍🦳' => 'muškarac: srednje tamna koža i sijeda kosa',
    '👨🏿‍🦳' => 'muškarac: tamna koža i sijeda kosa',
    '👨🏻‍🦲' => 'muškarac: svijetla koža i ćelav',
    '👨🏼‍🦲' => 'muškarac: srednje svijetla koža i ćelav',
    '👨🏽‍🦲' => 'muškarac: ni svijetla ni tamna koža i ćelav',
    '👨🏾‍🦲' => 'muškarac: srednje tamna koža i ćelav',
    '👨🏿‍🦲' => 'muškarac: tamna koža i ćelav',
    '🧔🏻‍♀' => 'žena: svijetla koža i brada',
    '🧔🏼‍♀' => 'žena: srednje svijetla koža i brada',
    '🧔🏽‍♀' => 'žena: ni svijetla ni tamna koža i brada',
    '🧔🏾‍♀' => 'žena: srednje tamna koža i brada',
    '🧔🏿‍♀' => 'žena: tamna koža i brada',
    '👱🏻‍♀' => 'plavuša: svijetla koža',
    '👱🏼‍♀' => 'plavuša: srednje svijetla koža',
    '👱🏽‍♀' => 'plavuša: ni svijetla ni tamna koža',
    '👱🏾‍♀' => 'plavuša: srednje tamna koža',
    '👱🏿‍♀' => 'plavuša: tamna koža',
    '👩🏻‍🦰' => 'žena: svijetla koža i crvena kosa',
    '👩🏼‍🦰' => 'žena: srednje svijetla koža i crvena kosa',
    '👩🏽‍🦰' => 'žena: ni svijetla ni tamna koža i crvena kosa',
    '👩🏾‍🦰' => 'žena: srednje tamna koža i crvena kosa',
    '👩🏿‍🦰' => 'žena: tamna koža i crvena kosa',
    '👩🏻‍🦱' => 'žena: svijetla koža i kovrdžava kosa',
    '👩🏼‍🦱' => 'žena: srednje svijetla koža i kovrdžava kosa',
    '👩🏽‍🦱' => 'žena: ni svijetla ni tamna koža i kovrdžava kosa',
    '👩🏾‍🦱' => 'žena: srednje tamna koža i kovrdžava kosa',
    '👩🏿‍🦱' => 'žena: tamna koža i kovrdžava kosa',
    '👩🏻‍🦳' => 'žena: svijetla koža i sijeda kosa',
    '👩🏼‍🦳' => 'žena: srednje svijetla koža i sijeda kosa',
    '👩🏽‍🦳' => 'žena: ni svijetla ni tamna koža i sijeda kosa',
    '👩🏾‍🦳' => 'žena: srednje tamna koža i sijeda kosa',
    '👩🏿‍🦳' => 'žena: tamna koža i sijeda kosa',
    '👩🏻‍🦲' => 'žena: svijetla koža i ćelav',
    '👩🏼‍🦲' => 'žena: srednje svijetla koža i ćelav',
    '👩🏽‍🦲' => 'žena: ni svijetla ni tamna koža i ćelav',
    '👩🏾‍🦲' => 'žena: srednje tamna koža i ćelav',
    '👩🏿‍🦲' => 'žena: tamna koža i ćelav',
    '🙍🏻‍♂' => 'namršten muškarac: svijetla koža',
    '🙍🏼‍♂' => 'namršten muškarac: srednje svijetla koža',
    '🙍🏽‍♂' => 'namršten muškarac: ni svijetla ni tamna koža',
    '🙍🏾‍♂' => 'namršten muškarac: srednje tamna koža',
    '🙍🏿‍♂' => 'namršten muškarac: tamna koža',
    '🙍🏻‍♀' => 'namrštena žena: svijetla koža',
    '🙍🏼‍♀' => 'namrštena žena: srednje svijetla koža',
    '🙍🏽‍♀' => 'namrštena žena: ni svijetla ni tamna koža',
    '🙍🏾‍♀' => 'namrštena žena: srednje tamna koža',
    '🙍🏿‍♀' => 'namrštena žena: tamna koža',
    '🙎🏻‍♂' => 'naduren muškarac: svijetla koža',
    '🙎🏼‍♂' => 'naduren muškarac: srednje svijetla koža',
    '🙎🏽‍♂' => 'naduren muškarac: ni svijetla ni tamna koža',
    '🙎🏾‍♂' => 'naduren muškarac: srednje tamna koža',
    '🙎🏿‍♂' => 'naduren muškarac: tamna koža',
    '🙎🏻‍♀' => 'nadurena žena: svijetla koža',
    '🙎🏼‍♀' => 'nadurena žena: srednje svijetla koža',
    '🙎🏽‍♀' => 'nadurena žena: ni svijetla ni tamna koža',
    '🙎🏾‍♀' => 'nadurena žena: srednje tamna koža',
    '🙎🏿‍♀' => 'nadurena žena: tamna koža',
    '🙅🏻‍♂' => 'muškarac pokazuje „ne“: svijetla koža',
    '🙅🏼‍♂' => 'muškarac pokazuje „ne“: srednje svijetla koža',
    '🙅🏽‍♂' => 'muškarac pokazuje „ne“: ni svijetla ni tamna koža',
    '🙅🏾‍♂' => 'muškarac pokazuje „ne“: srednje tamna koža',
    '🙅🏿‍♂' => 'muškarac pokazuje „ne“: tamna koža',
    '🙅🏻‍♀' => 'žena pokazuje „ne“: svijetla koža',
    '🙅🏼‍♀' => 'žena pokazuje „ne“: srednje svijetla koža',
    '🙅🏽‍♀' => 'žena pokazuje „ne“: ni svijetla ni tamna koža',
    '🙅🏾‍♀' => 'žena pokazuje „ne“: srednje tamna koža',
    '🙅🏿‍♀' => 'žena pokazuje „ne“: tamna koža',
    '🙆🏻‍♂' => 'muškarac pokazuje „ok“: svijetla koža',
    '🙆🏼‍♂' => 'muškarac pokazuje „ok“: srednje svijetla koža',
    '🙆🏽‍♂' => 'muškarac pokazuje „ok“: ni svijetla ni tamna koža',
    '🙆🏾‍♂' => 'muškarac pokazuje „ok“: srednje tamna koža',
    '🙆🏿‍♂' => 'muškarac pokazuje „ok“: tamna koža',
    '🙆🏻‍♀' => 'žena pokazuje „ok“: svijetla koža',
    '🙆🏼‍♀' => 'žena pokazuje „ok“: srednje svijetla koža',
    '🙆🏽‍♀' => 'žena pokazuje „ok“: ni svijetla ni tamna koža',
    '🙆🏾‍♀' => 'žena pokazuje „ok“: srednje tamna koža',
    '🙆🏿‍♀' => 'žena pokazuje „ok“: tamna koža',
    '💁🏻‍♂' => 'muškarac otkriva namjere: svijetla koža',
    '💁🏼‍♂' => 'muškarac otkriva namjere: srednje svijetla koža',
    '💁🏽‍♂' => 'muškarac otkriva namjere: ni svijetla ni tamna koža',
    '💁🏾‍♂' => 'muškarac otkriva namjere: srednje tamna koža',
    '💁🏿‍♂' => 'muškarac otkriva namjere: tamna koža',
    '💁🏻‍♀' => 'žena otkriva namjere: svijetla koža',
    '💁🏼‍♀' => 'žena otkriva namjere: srednje svijetla koža',
    '💁🏽‍♀' => 'žena otkriva namjere: ni svijetla ni tamna koža',
    '💁🏾‍♀' => 'žena otkriva namjere: srednje tamna koža',
    '💁🏿‍♀' => 'žena otkriva namjere: tamna koža',
    '🙋🏻‍♂' => 'muškarac podiže ruku: svijetla koža',
    '🙋🏼‍♂' => 'muškarac podiže ruku: srednje svijetla koža',
    '🙋🏽‍♂' => 'muškarac podiže ruku: ni svijetla ni tamna koža',
    '🙋🏾‍♂' => 'muškarac podiže ruku: srednje tamna koža',
    '🙋🏿‍♂' => 'muškarac podiže ruku: tamna koža',
    '🙋🏻‍♀' => 'žena podiže ruku: svijetla koža',
    '🙋🏼‍♀' => 'žena podiže ruku: srednje svijetla koža',
    '🙋🏽‍♀' => 'žena podiže ruku: ni svijetla ni tamna koža',
    '🙋🏾‍♀' => 'žena podiže ruku: srednje tamna koža',
    '🙋🏿‍♀' => 'žena podiže ruku: tamna koža',
    '🧏🏻‍♂' => 'gluv čovjek: svijetla koža',
    '🧏🏼‍♂' => 'gluv čovjek: srednje svijetla koža',
    '🧏🏽‍♂' => 'gluv čovjek: ni svijetla ni tamna koža',
    '🧏🏾‍♂' => 'gluv čovjek: srednje tamna koža',
    '🧏🏿‍♂' => 'gluv čovjek: tamna koža',
    '🧏🏻‍♀' => 'gluva žena: svijetla koža',
    '🧏🏼‍♀' => 'gluva žena: srednje svijetla koža',
    '🧏🏽‍♀' => 'gluva žena: ni svijetla ni tamna koža',
    '🧏🏾‍♀' => 'gluva žena: srednje tamna koža',
    '🧏🏿‍♀' => 'gluva žena: tamna koža',
    '🙇🏻‍♂' => 'muški duboki naklon: svijetla koža',
    '🙇🏼‍♂' => 'muški duboki naklon: srednje svijetla koža',
    '🙇🏽‍♂' => 'muški duboki naklon: ni svijetla ni tamna koža',
    '🙇🏾‍♂' => 'muški duboki naklon: srednje tamna koža',
    '🙇🏿‍♂' => 'muški duboki naklon: tamna koža',
    '🙇🏻‍♀' => 'ženski duboki naklon: svijetla koža',
    '🙇🏼‍♀' => 'ženski duboki naklon: srednje svijetla koža',
    '🙇🏽‍♀' => 'ženski duboki naklon: ni svijetla ni tamna koža',
    '🙇🏾‍♀' => 'ženski duboki naklon: srednje tamna koža',
    '🙇🏿‍♀' => 'ženski duboki naklon: tamna koža',
    '🤦🏻‍♂' => 'muškarac s rukom na čelu: svijetla koža',
    '🤦🏼‍♂' => 'muškarac s rukom na čelu: srednje svijetla koža',
    '🤦🏽‍♂' => 'muškarac s rukom na čelu: ni svijetla ni tamna koža',
    '🤦🏾‍♂' => 'muškarac s rukom na čelu: srednje tamna koža',
    '🤦🏿‍♂' => 'muškarac s rukom na čelu: tamna koža',
    '🤦🏻‍♀' => 'žena s rukom na čelu: svijetla koža',
    '🤦🏼‍♀' => 'žena s rukom na čelu: srednje svijetla koža',
    '🤦🏽‍♀' => 'žena s rukom na čelu: ni svijetla ni tamna koža',
    '🤦🏾‍♀' => 'žena s rukom na čelu: srednje tamna koža',
    '🤦🏿‍♀' => 'žena s rukom na čelu: tamna koža',
    '🤷🏻‍♂' => 'muškarac sliježe ramenima: svijetla koža',
    '🤷🏼‍♂' => 'muškarac sliježe ramenima: srednje svijetla koža',
    '🤷🏽‍♂' => 'muškarac sliježe ramenima: ni svijetla ni tamna koža',
    '🤷🏾‍♂' => 'muškarac sliježe ramenima: srednje tamna koža',
    '🤷🏿‍♂' => 'muškarac sliježe ramenima: tamna koža',
    '🤷🏻‍♀' => 'žena sliježe ramenima: svijetla koža',
    '🤷🏼‍♀' => 'žena sliježe ramenima: srednje svijetla koža',
    '🤷🏽‍♀' => 'žena sliježe ramenima: ni svijetla ni tamna koža',
    '🤷🏾‍♀' => 'žena sliježe ramenima: srednje tamna koža',
    '🤷🏿‍♀' => 'žena sliježe ramenima: tamna koža',
    '🧑🏻‍⚕' => 'zdravstveni radnik: svijetla koža',
    '🧑🏼‍⚕' => 'zdravstveni radnik: srednje svijetla koža',
    '🧑🏽‍⚕' => 'zdravstveni radnik: ni svijetla ni tamna koža',
    '🧑🏾‍⚕' => 'zdravstveni radnik: srednje tamna koža',
    '🧑🏿‍⚕' => 'zdravstveni radnik: tamna koža',
    '👨🏻‍⚕' => 'muškarac zdravstveni radnik: svijetla koža',
    '👨🏼‍⚕' => 'muškarac zdravstveni radnik: srednje svijetla koža',
    '👨🏽‍⚕' => 'muškarac zdravstveni radnik: ni svijetla ni tamna koža',
    '👨🏾‍⚕' => 'muškarac zdravstveni radnik: srednje tamna koža',
    '👨🏿‍⚕' => 'muškarac zdravstveni radnik: tamna koža',
    '👩🏻‍⚕' => 'zdravstvena radnica: svijetla koža',
    '👩🏼‍⚕' => 'zdravstvena radnica: srednje svijetla koža',
    '👩🏽‍⚕' => 'zdravstvena radnica: ni svijetla ni tamna koža',
    '👩🏾‍⚕' => 'zdravstvena radnica: srednje tamna koža',
    '👩🏿‍⚕' => 'zdravstvena radnica: tamna koža',
    '🧑🏻‍🎓' => 'student(kinja): svijetla koža',
    '🧑🏼‍🎓' => 'student(kinja): srednje svijetla koža',
    '🧑🏽‍🎓' => 'student(kinja): ni svijetla ni tamna koža',
    '🧑🏾‍🎓' => 'student(kinja): srednje tamna koža',
    '🧑🏿‍🎓' => 'student(kinja): tamna koža',
    '👨🏻‍🎓' => 'student: svijetla koža',
    '👨🏼‍🎓' => 'student: srednje svijetla koža',
    '👨🏽‍🎓' => 'student: ni svijetla ni tamna koža',
    '👨🏾‍🎓' => 'student: srednje tamna koža',
    '👨🏿‍🎓' => 'student: tamna koža',
    '👩🏻‍🎓' => 'studentkinja: svijetla koža',
    '👩🏼‍🎓' => 'studentkinja: srednje svijetla koža',
    '👩🏽‍🎓' => 'studentkinja: ni svijetla ni tamna koža',
    '👩🏾‍🎓' => 'studentkinja: srednje tamna koža',
    '👩🏿‍🎓' => 'studentkinja: tamna koža',
    '🧑🏻‍🏫' => 'učitelj: svijetla koža',
    '🧑🏼‍🏫' => 'učitelj: srednje svijetla koža',
    '🧑🏽‍🏫' => 'učitelj: ni svijetla ni tamna koža',
    '🧑🏾‍🏫' => 'učitelj: srednje tamna koža',
    '🧑🏿‍🏫' => 'učitelj: tamna koža',
    '👨🏻‍🏫' => 'profesor: svijetla koža',
    '👨🏼‍🏫' => 'profesor: srednje svijetla koža',
    '👨🏽‍🏫' => 'profesor: ni svijetla ni tamna koža',
    '👨🏾‍🏫' => 'profesor: srednje tamna koža',
    '👨🏿‍🏫' => 'profesor: tamna koža',
    '👩🏻‍🏫' => 'profesorka: svijetla koža',
    '👩🏼‍🏫' => 'profesorka: srednje svijetla koža',
    '👩🏽‍🏫' => 'profesorka: ni svijetla ni tamna koža',
    '👩🏾‍🏫' => 'profesorka: srednje tamna koža',
    '👩🏿‍🏫' => 'profesorka: tamna koža',
    '🧑🏻‍⚖' => 'sudija/nica: svijetla koža',
    '🧑🏼‍⚖' => 'sudija/nica: srednje svijetla koža',
    '🧑🏽‍⚖' => 'sudija/nica: ni svijetla ni tamna koža',
    '🧑🏾‍⚖' => 'sudija/nica: srednje tamna koža',
    '🧑🏿‍⚖' => 'sudija/nica: tamna koža',
    '👨🏻‍⚖' => 'muškarac sudija: svijetla koža',
    '👨🏼‍⚖' => 'muškarac sudija: srednje svijetla koža',
    '👨🏽‍⚖' => 'muškarac sudija: ni svijetla ni tamna koža',
    '👨🏾‍⚖' => 'muškarac sudija: srednje tamna koža',
    '👨🏿‍⚖' => 'muškarac sudija: tamna koža',
    '👩🏻‍⚖' => 'žena sudija: svijetla koža',
    '👩🏼‍⚖' => 'žena sudija: srednje svijetla koža',
    '👩🏽‍⚖' => 'žena sudija: ni svijetla ni tamna koža',
    '👩🏾‍⚖' => 'žena sudija: srednje tamna koža',
    '👩🏿‍⚖' => 'žena sudija: tamna koža',
    '🧑🏻‍🌾' => 'poljoprivrednik: svijetla koža',
    '🧑🏼‍🌾' => 'poljoprivrednik: srednje svijetla koža',
    '🧑🏽‍🌾' => 'poljoprivrednik: ni svijetla ni tamna koža',
    '🧑🏾‍🌾' => 'poljoprivrednik: srednje tamna koža',
    '🧑🏿‍🌾' => 'poljoprivrednik: tamna koža',
    '👨🏻‍🌾' => 'muškarac poljoprivrednik: svijetla koža',
    '👨🏼‍🌾' => 'muškarac poljoprivrednik: srednje svijetla koža',
    '👨🏽‍🌾' => 'muškarac poljoprivrednik: ni svijetla ni tamna koža',
    '👨🏾‍🌾' => 'muškarac poljoprivrednik: srednje tamna koža',
    '👨🏿‍🌾' => 'muškarac poljoprivrednik: tamna koža',
    '👩🏻‍🌾' => 'poljoprivrednica: svijetla koža',
    '👩🏼‍🌾' => 'poljoprivrednica: srednje svijetla koža',
    '👩🏽‍🌾' => 'poljoprivrednica: ni svijetla ni tamna koža',
    '👩🏾‍🌾' => 'poljoprivrednica: srednje tamna koža',
    '👩🏿‍🌾' => 'poljoprivrednica: tamna koža',
    '🧑🏻‍🍳' => 'kuvar: svijetla koža',
    '🧑🏼‍🍳' => 'kuvar: srednje svijetla koža',
    '🧑🏽‍🍳' => 'kuvar: ni svijetla ni tamna koža',
    '🧑🏾‍🍳' => 'kuvar: srednje tamna koža',
    '🧑🏿‍🍳' => 'kuvar: tamna koža',
    '👨🏻‍🍳' => 'muškarac kuvar: svijetla koža',
    '👨🏼‍🍳' => 'muškarac kuvar: srednje svijetla koža',
    '👨🏽‍🍳' => 'muškarac kuvar: ni svijetla ni tamna koža',
    '👨🏾‍🍳' => 'muškarac kuvar: srednje tamna koža',
    '👨🏿‍🍳' => 'muškarac kuvar: tamna koža',
    '👩🏻‍🍳' => 'kuvarica: svijetla koža',
    '👩🏼‍🍳' => 'kuvarica: srednje svijetla koža',
    '👩🏽‍🍳' => 'kuvarica: ni svijetla ni tamna koža',
    '👩🏾‍🍳' => 'kuvarica: srednje tamna koža',
    '👩🏿‍🍳' => 'kuvarica: tamna koža',
    '🧑🏻‍🔧' => 'mehaničar: svijetla koža',
    '🧑🏼‍🔧' => 'mehaničar: srednje svijetla koža',
    '🧑🏽‍🔧' => 'mehaničar: ni svijetla ni tamna koža',
    '🧑🏾‍🔧' => 'mehaničar: srednje tamna koža',
    '🧑🏿‍🔧' => 'mehaničar: tamna koža',
    '👨🏻‍🔧' => 'muškarac mehaničar: svijetla koža',
    '👨🏼‍🔧' => 'muškarac mehaničar: srednje svijetla koža',
    '👨🏽‍🔧' => 'muškarac mehaničar: ni svijetla ni tamna koža',
    '👨🏾‍🔧' => 'muškarac mehaničar: srednje tamna koža',
    '👨🏿‍🔧' => 'muškarac mehaničar: tamna koža',
    '👩🏻‍🔧' => 'mehaničarka: svijetla koža',
    '👩🏼‍🔧' => 'mehaničarka: srednje svijetla koža',
    '👩🏽‍🔧' => 'mehaničarka: ni svijetla ni tamna koža',
    '👩🏾‍🔧' => 'mehaničarka: srednje tamna koža',
    '👩🏿‍🔧' => 'mehaničarka: tamna koža',
    '🧑🏻‍🏭' => 'radnik u fabrici: svijetla koža',
    '🧑🏼‍🏭' => 'radnik u fabrici: srednje svijetla koža',
    '🧑🏽‍🏭' => 'radnik u fabrici: ni svijetla ni tamna koža',
    '🧑🏾‍🏭' => 'radnik u fabrici: srednje tamna koža',
    '🧑🏿‍🏭' => 'radnik u fabrici: tamna koža',
    '👨🏻‍🏭' => 'radnik: svijetla koža',
    '👨🏼‍🏭' => 'radnik: srednje svijetla koža',
    '👨🏽‍🏭' => 'radnik: ni svijetla ni tamna koža',
    '👨🏾‍🏭' => 'radnik: srednje tamna koža',
    '👨🏿‍🏭' => 'radnik: tamna koža',
    '👩🏻‍🏭' => 'radnica: svijetla koža',
    '👩🏼‍🏭' => 'radnica: srednje svijetla koža',
    '👩🏽‍🏭' => 'radnica: ni svijetla ni tamna koža',
    '👩🏾‍🏭' => 'radnica: srednje tamna koža',
    '👩🏿‍🏭' => 'radnica: tamna koža',
    '🧑🏻‍💼' => 'kancelarijski radnik: svijetla koža',
    '🧑🏼‍💼' => 'kancelarijski radnik: srednje svijetla koža',
    '🧑🏽‍💼' => 'kancelarijski radnik: ni svijetla ni tamna koža',
    '🧑🏾‍💼' => 'kancelarijski radnik: srednje tamna koža',
    '🧑🏿‍💼' => 'kancelarijski radnik: tamna koža',
    '👨🏻‍💼' => 'muškarac u kancelariji: svijetla koža',
    '👨🏼‍💼' => 'muškarac u kancelariji: srednje svijetla koža',
    '👨🏽‍💼' => 'muškarac u kancelariji: ni svijetla ni tamna koža',
    '👨🏾‍💼' => 'muškarac u kancelariji: srednje tamna koža',
    '👨🏿‍💼' => 'muškarac u kancelariji: tamna koža',
    '👩🏻‍💼' => 'žena u kancelariji: svijetla koža',
    '👩🏼‍💼' => 'žena u kancelariji: srednje svijetla koža',
    '👩🏽‍💼' => 'žena u kancelariji: ni svijetla ni tamna koža',
    '👩🏾‍💼' => 'žena u kancelariji: srednje tamna koža',
    '👩🏿‍💼' => 'žena u kancelariji: tamna koža',
    '🧑🏻‍🔬' => 'naučnik/ca: svijetla koža',
    '🧑🏼‍🔬' => 'naučnik/ca: srednje svijetla koža',
    '🧑🏽‍🔬' => 'naučnik/ca: ni svijetla ni tamna koža',
    '🧑🏾‍🔬' => 'naučnik/ca: srednje tamna koža',
    '🧑🏿‍🔬' => 'naučnik/ca: tamna koža',
    '👨🏻‍🔬' => 'naučnik: svijetla koža',
    '👨🏼‍🔬' => 'naučnik: srednje svijetla koža',
    '👨🏽‍🔬' => 'naučnik: ni svijetla ni tamna koža',
    '👨🏾‍🔬' => 'naučnik: srednje tamna koža',
    '👨🏿‍🔬' => 'naučnik: tamna koža',
    '👩🏻‍🔬' => 'naučnica: svijetla koža',
    '👩🏼‍🔬' => 'naučnica: srednje svijetla koža',
    '👩🏽‍🔬' => 'naučnica: ni svijetla ni tamna koža',
    '👩🏾‍🔬' => 'naučnica: srednje tamna koža',
    '👩🏿‍🔬' => 'naučnica: tamna koža',
    '🧑🏻‍💻' => 'tehnolog: svijetla koža',
    '🧑🏼‍💻' => 'tehnolog: srednje svijetla koža',
    '🧑🏽‍💻' => 'tehnolog: ni svijetla ni tamna koža',
    '🧑🏾‍💻' => 'tehnolog: srednje tamna koža',
    '🧑🏿‍💻' => 'tehnolog: tamna koža',
    '👨🏻‍💻' => 'muškarac tehnolog: svijetla koža',
    '👨🏼‍💻' => 'muškarac tehnolog: srednje svijetla koža',
    '👨🏽‍💻' => 'muškarac tehnolog: ni svijetla ni tamna koža',
    '👨🏾‍💻' => 'muškarac tehnolog: srednje tamna koža',
    '👨🏿‍💻' => 'muškarac tehnolog: tamna koža',
    '👩🏻‍💻' => 'žena tehnolog: svijetla koža',
    '👩🏼‍💻' => 'žena tehnolog: srednje svijetla koža',
    '👩🏽‍💻' => 'žena tehnolog: ni svijetla ni tamna koža',
    '👩🏾‍💻' => 'žena tehnolog: srednje tamna koža',
    '👩🏿‍💻' => 'žena tehnolog: tamna koža',
    '🧑🏻‍🎤' => 'pjevač: svijetla koža',
    '🧑🏼‍🎤' => 'pjevač: srednje svijetla koža',
    '🧑🏽‍🎤' => 'pjevač: ni svijetla ni tamna koža',
    '🧑🏾‍🎤' => 'pjevač: srednje tamna koža',
    '🧑🏿‍🎤' => 'pjevač: tamna koža',
    '👨🏻‍🎤' => 'muškarac pjevač: svijetla koža',
    '👨🏼‍🎤' => 'muškarac pjevač: srednje svijetla koža',
    '👨🏽‍🎤' => 'muškarac pjevač: ni svijetla ni tamna koža',
    '👨🏾‍🎤' => 'muškarac pjevač: srednje tamna koža',
    '👨🏿‍🎤' => 'muškarac pjevač: tamna koža',
    '👩🏻‍🎤' => 'pjevačica: svijetla koža',
    '👩🏼‍🎤' => 'pjevačica: srednje svijetla koža',
    '👩🏽‍🎤' => 'pjevačica: ni svijetla ni tamna koža',
    '👩🏾‍🎤' => 'pjevačica: srednje tamna koža',
    '👩🏿‍🎤' => 'pjevačica: tamna koža',
    '🧑🏻‍🎨' => 'umjetnik: svijetla koža',
    '🧑🏼‍🎨' => 'umjetnik: srednje svijetla koža',
    '🧑🏽‍🎨' => 'umjetnik: ni svijetla ni tamna koža',
    '🧑🏾‍🎨' => 'umjetnik: srednje tamna koža',
    '🧑🏿‍🎨' => 'umjetnik: tamna koža',
    '👨🏻‍🎨' => 'muškarac umjetnik: svijetla koža',
    '👨🏼‍🎨' => 'muškarac umjetnik: srednje svijetla koža',
    '👨🏽‍🎨' => 'muškarac umjetnik: ni svijetla ni tamna koža',
    '👨🏾‍🎨' => 'muškarac umjetnik: srednje tamna koža',
    '👨🏿‍🎨' => 'muškarac umjetnik: tamna koža',
    '👩🏻‍🎨' => 'umjetnica: svijetla koža',
    '👩🏼‍🎨' => 'umjetnica: srednje svijetla koža',
    '👩🏽‍🎨' => 'umjetnica: ni svijetla ni tamna koža',
    '👩🏾‍🎨' => 'umjetnica: srednje tamna koža',
    '👩🏿‍🎨' => 'umjetnica: tamna koža',
    '🧑🏻‍✈' => 'pilot(kinja): svijetla koža',
    '🧑🏼‍✈' => 'pilot(kinja): srednje svijetla koža',
    '🧑🏽‍✈' => 'pilot(kinja): ni svijetla ni tamna koža',
    '🧑🏾‍✈' => 'pilot(kinja): srednje tamna koža',
    '🧑🏿‍✈' => 'pilot(kinja): tamna koža',
    '👨🏻‍✈' => 'pilot: svijetla koža',
    '👨🏼‍✈' => 'pilot: srednje svijetla koža',
    '👨🏽‍✈' => 'pilot: ni svijetla ni tamna koža',
    '👨🏾‍✈' => 'pilot: srednje tamna koža',
    '👨🏿‍✈' => 'pilot: tamna koža',
    '👩🏻‍✈' => 'žena pilot: svijetla koža',
    '👩🏼‍✈' => 'žena pilot: srednje svijetla koža',
    '👩🏽‍✈' => 'žena pilot: ni svijetla ni tamna koža',
    '👩🏾‍✈' => 'žena pilot: srednje tamna koža',
    '👩🏿‍✈' => 'žena pilot: tamna koža',
    '🧑🏻‍🚀' => 'astronaut: svijetla koža',
    '🧑🏼‍🚀' => 'astronaut: srednje svijetla koža',
    '🧑🏽‍🚀' => 'astronaut: ni svijetla ni tamna koža',
    '🧑🏾‍🚀' => 'astronaut: srednje tamna koža',
    '🧑🏿‍🚀' => 'astronaut: tamna koža',
    '👨🏻‍🚀' => 'kosmonaut: svijetla koža',
    '👨🏼‍🚀' => 'kosmonaut: srednje svijetla koža',
    '👨🏽‍🚀' => 'kosmonaut: ni svijetla ni tamna koža',
    '👨🏾‍🚀' => 'kosmonaut: srednje tamna koža',
    '👨🏿‍🚀' => 'kosmonaut: tamna koža',
    '👩🏻‍🚀' => 'kosmonautkinja: svijetla koža',
    '👩🏼‍🚀' => 'kosmonautkinja: srednje svijetla koža',
    '👩🏽‍🚀' => 'kosmonautkinja: ni svijetla ni tamna koža',
    '👩🏾‍🚀' => 'kosmonautkinja: srednje tamna koža',
    '👩🏿‍🚀' => 'kosmonautkinja: tamna koža',
    '🧑🏻‍🚒' => 'vatrogasac / žena vatrogasac: svijetla koža',
    '🧑🏼‍🚒' => 'vatrogasac / žena vatrogasac: srednje svijetla koža',
    '🧑🏽‍🚒' => 'vatrogasac / žena vatrogasac: ni svijetla ni tamna koža',
    '🧑🏾‍🚒' => 'vatrogasac / žena vatrogasac: srednje tamna koža',
    '🧑🏿‍🚒' => 'vatrogasac / žena vatrogasac: tamna koža',
    '👨🏻‍🚒' => 'vatrogasac: svijetla koža',
    '👨🏼‍🚒' => 'vatrogasac: srednje svijetla koža',
    '👨🏽‍🚒' => 'vatrogasac: ni svijetla ni tamna koža',
    '👨🏾‍🚒' => 'vatrogasac: srednje tamna koža',
    '👨🏿‍🚒' => 'vatrogasac: tamna koža',
    '👩🏻‍🚒' => 'žena vatrogasac: svijetla koža',
    '👩🏼‍🚒' => 'žena vatrogasac: srednje svijetla koža',
    '👩🏽‍🚒' => 'žena vatrogasac: ni svijetla ni tamna koža',
    '👩🏾‍🚒' => 'žena vatrogasac: srednje tamna koža',
    '👩🏿‍🚒' => 'žena vatrogasac: tamna koža',
    '👮🏻‍♂' => 'policajac: svijetla koža',
    '👮🏼‍♂' => 'policajac: srednje svijetla koža',
    '👮🏽‍♂' => 'policajac: ni svijetla ni tamna koža',
    '👮🏾‍♂' => 'policajac: srednje tamna koža',
    '👮🏿‍♂' => 'policajac: tamna koža',
    '👮🏻‍♀' => 'policajka: svijetla koža',
    '👮🏼‍♀' => 'policajka: srednje svijetla koža',
    '👮🏽‍♀' => 'policajka: ni svijetla ni tamna koža',
    '👮🏾‍♀' => 'policajka: srednje tamna koža',
    '👮🏿‍♀' => 'policajka: tamna koža',
    '🕵🏻‍♂' => 'detektiv: svijetla koža',
    '🕵🏼‍♂' => 'detektiv: srednje svijetla koža',
    '🕵🏽‍♂' => 'detektiv: ni svijetla ni tamna koža',
    '🕵🏾‍♂' => 'detektiv: srednje tamna koža',
    '🕵🏿‍♂' => 'detektiv: tamna koža',
    '🕵🏻‍♀' => 'detektivka: svijetla koža',
    '🕵🏼‍♀' => 'detektivka: srednje svijetla koža',
    '🕵🏽‍♀' => 'detektivka: ni svijetla ni tamna koža',
    '🕵🏾‍♀' => 'detektivka: srednje tamna koža',
    '🕵🏿‍♀' => 'detektivka: tamna koža',
    '💂🏻‍♂' => 'gardista: svijetla koža',
    '💂🏼‍♂' => 'gardista: srednje svijetla koža',
    '💂🏽‍♂' => 'gardista: ni svijetla ni tamna koža',
    '💂🏾‍♂' => 'gardista: srednje tamna koža',
    '💂🏿‍♂' => 'gardista: tamna koža',
    '💂🏻‍♀' => 'gardistkinja: svijetla koža',
    '💂🏼‍♀' => 'gardistkinja: srednje svijetla koža',
    '💂🏽‍♀' => 'gardistkinja: ni svijetla ni tamna koža',
    '💂🏾‍♀' => 'gardistkinja: srednje tamna koža',
    '💂🏿‍♀' => 'gardistkinja: tamna koža',
    '👷🏻‍♂' => 'građevinar: svijetla koža',
    '👷🏼‍♂' => 'građevinar: srednje svijetla koža',
    '👷🏽‍♂' => 'građevinar: ni svijetla ni tamna koža',
    '👷🏾‍♂' => 'građevinar: srednje tamna koža',
    '👷🏿‍♂' => 'građevinar: tamna koža',
    '👷🏻‍♀' => 'građevinarka: svijetla koža',
    '👷🏼‍♀' => 'građevinarka: srednje svijetla koža',
    '👷🏽‍♀' => 'građevinarka: ni svijetla ni tamna koža',
    '👷🏾‍♀' => 'građevinarka: srednje tamna koža',
    '👷🏿‍♀' => 'građevinarka: tamna koža',
    '👳🏻‍♂' => 'čovjek sa turbanom: svijetla koža',
    '👳🏼‍♂' => 'čovjek sa turbanom: srednje svijetla koža',
    '👳🏽‍♂' => 'čovjek sa turbanom: ni svijetla ni tamna koža',
    '👳🏾‍♂' => 'čovjek sa turbanom: srednje tamna koža',
    '👳🏿‍♂' => 'čovjek sa turbanom: tamna koža',
    '👳🏻‍♀' => 'žena sa turbanom: svijetla koža',
    '👳🏼‍♀' => 'žena sa turbanom: srednje svijetla koža',
    '👳🏽‍♀' => 'žena sa turbanom: ni svijetla ni tamna koža',
    '👳🏾‍♀' => 'žena sa turbanom: srednje tamna koža',
    '👳🏿‍♀' => 'žena sa turbanom: tamna koža',
    '🤵🏻‍♂' => 'muškarac u smokingu: svijetla koža',
    '🤵🏼‍♂' => 'muškarac u smokingu: srednje svijetla koža',
    '🤵🏽‍♂' => 'muškarac u smokingu: ni svijetla ni tamna koža',
    '🤵🏾‍♂' => 'muškarac u smokingu: srednje tamna koža',
    '🤵🏿‍♂' => 'muškarac u smokingu: tamna koža',
    '🤵🏻‍♀' => 'žena u smokingu: svijetla koža',
    '🤵🏼‍♀' => 'žena u smokingu: srednje svijetla koža',
    '🤵🏽‍♀' => 'žena u smokingu: ni svijetla ni tamna koža',
    '🤵🏾‍♀' => 'žena u smokingu: srednje tamna koža',
    '🤵🏿‍♀' => 'žena u smokingu: tamna koža',
    '👰🏻‍♂' => 'muškarac sa velom: svijetla koža',
    '👰🏼‍♂' => 'muškarac sa velom: srednje svijetla koža',
    '👰🏽‍♂' => 'muškarac sa velom: ni svijetla ni tamna koža',
    '👰🏾‍♂' => 'muškarac sa velom: srednje tamna koža',
    '👰🏿‍♂' => 'muškarac sa velom: tamna koža',
    '👰🏻‍♀' => 'žena sa velom: svijetla koža',
    '👰🏼‍♀' => 'žena sa velom: srednje svijetla koža',
    '👰🏽‍♀' => 'žena sa velom: ni svijetla ni tamna koža',
    '👰🏾‍♀' => 'žena sa velom: srednje tamna koža',
    '👰🏿‍♀' => 'žena sa velom: tamna koža',
    '👩🏻‍🍼' => 'žena hrani bebu: svijetla koža',
    '👩🏼‍🍼' => 'žena hrani bebu: srednje svijetla koža',
    '👩🏽‍🍼' => 'žena hrani bebu: ni svijetla ni tamna koža',
    '👩🏾‍🍼' => 'žena hrani bebu: srednje tamna koža',
    '👩🏿‍🍼' => 'žena hrani bebu: tamna koža',
    '👨🏻‍🍼' => 'muškarac hrani bebu: svijetla koža',
    '👨🏼‍🍼' => 'muškarac hrani bebu: srednje svijetla koža',
    '👨🏽‍🍼' => 'muškarac hrani bebu: ni svijetla ni tamna koža',
    '👨🏾‍🍼' => 'muškarac hrani bebu: srednje tamna koža',
    '👨🏿‍🍼' => 'muškarac hrani bebu: tamna koža',
    '🧑🏻‍🍼' => 'osoba hrani bebu: svijetla koža',
    '🧑🏼‍🍼' => 'osoba hrani bebu: srednje svijetla koža',
    '🧑🏽‍🍼' => 'osoba hrani bebu: ni svijetla ni tamna koža',
    '🧑🏾‍🍼' => 'osoba hrani bebu: srednje tamna koža',
    '🧑🏿‍🍼' => 'osoba hrani bebu: tamna koža',
    '🧑🏻‍🎄' => 'osoba Mraz: svijetla koža',
    '🧑🏼‍🎄' => 'osoba Mraz: srednje svijetla koža',
    '🧑🏽‍🎄' => 'osoba Mraz: ni svijetla ni tamna koža',
    '🧑🏾‍🎄' => 'osoba Mraz: srednje tamna koža',
    '🧑🏿‍🎄' => 'osoba Mraz: tamna koža',
    '🦸🏻‍♂' => 'muškarac superheroj: svijetla koža',
    '🦸🏼‍♂' => 'muškarac superheroj: srednje svijetla koža',
    '🦸🏽‍♂' => 'muškarac superheroj: ni svijetla ni tamna koža',
    '🦸🏾‍♂' => 'muškarac superheroj: srednje tamna koža',
    '🦸🏿‍♂' => 'muškarac superheroj: tamna koža',
    '🦸🏻‍♀' => 'žena super heroj: svijetla koža',
    '🦸🏼‍♀' => 'žena super heroj: srednje svijetla koža',
    '🦸🏽‍♀' => 'žena super heroj: ni svijetla ni tamna koža',
    '🦸🏾‍♀' => 'žena super heroj: srednje tamna koža',
    '🦸🏿‍♀' => 'žena super heroj: tamna koža',
    '🦹🏻‍♂' => 'muškarac negativac: svijetla koža',
    '🦹🏼‍♂' => 'muškarac negativac: srednje svijetla koža',
    '🦹🏽‍♂' => 'muškarac negativac: ni svijetla ni tamna koža',
    '🦹🏾‍♂' => 'muškarac negativac: srednje tamna koža',
    '🦹🏿‍♂' => 'muškarac negativac: tamna koža',
    '🦹🏻‍♀' => 'žena negativac: svijetla koža',
    '🦹🏼‍♀' => 'žena negativac: srednje svijetla koža',
    '🦹🏽‍♀' => 'žena negativac: ni svijetla ni tamna koža',
    '🦹🏾‍♀' => 'žena negativac: srednje tamna koža',
    '🦹🏿‍♀' => 'žena negativac: tamna koža',
    '🧙🏻‍♂' => 'čarobnjak: svijetla koža',
    '🧙🏼‍♂' => 'čarobnjak: srednje svijetla koža',
    '🧙🏽‍♂' => 'čarobnjak: ni svijetla ni tamna koža',
    '🧙🏾‍♂' => 'čarobnjak: srednje tamna koža',
    '🧙🏿‍♂' => 'čarobnjak: tamna koža',
    '🧙🏻‍♀' => 'čarobnica: svijetla koža',
    '🧙🏼‍♀' => 'čarobnica: srednje svijetla koža',
    '🧙🏽‍♀' => 'čarobnica: ni svijetla ni tamna koža',
    '🧙🏾‍♀' => 'čarobnica: srednje tamna koža',
    '🧙🏿‍♀' => 'čarobnica: tamna koža',
    '🧚🏻‍♂' => 'vilenjak: svijetla koža',
    '🧚🏼‍♂' => 'vilenjak: srednje svijetla koža',
    '🧚🏽‍♂' => 'vilenjak: ni svijetla ni tamna koža',
    '🧚🏾‍♂' => 'vilenjak: srednje tamna koža',
    '🧚🏿‍♂' => 'vilenjak: tamna koža',
    '🧚🏻‍♀' => 'žena vila: svijetla koža',
    '🧚🏼‍♀' => 'žena vila: srednje svijetla koža',
    '🧚🏽‍♀' => 'žena vila: ni svijetla ni tamna koža',
    '🧚🏾‍♀' => 'žena vila: srednje tamna koža',
    '🧚🏿‍♀' => 'žena vila: tamna koža',
    '🧛🏻‍♂' => 'muški vampir: svijetla koža',
    '🧛🏼‍♂' => 'muški vampir: srednje svijetla koža',
    '🧛🏽‍♂' => 'muški vampir: ni svijetla ni tamna koža',
    '🧛🏾‍♂' => 'muški vampir: srednje tamna koža',
    '🧛🏿‍♂' => 'muški vampir: tamna koža',
    '🧛🏻‍♀' => 'ženski vampir: svijetla koža',
    '🧛🏼‍♀' => 'ženski vampir: srednje svijetla koža',
    '🧛🏽‍♀' => 'ženski vampir: ni svijetla ni tamna koža',
    '🧛🏾‍♀' => 'ženski vampir: srednje tamna koža',
    '🧛🏿‍♀' => 'ženski vampir: tamna koža',
    '🧜🏻‍♂' => 'muškarac iz mora: svijetla koža',
    '🧜🏼‍♂' => 'muškarac iz mora: srednje svijetla koža',
    '🧜🏽‍♂' => 'muškarac iz mora: ni svijetla ni tamna koža',
    '🧜🏾‍♂' => 'muškarac iz mora: srednje tamna koža',
    '🧜🏿‍♂' => 'muškarac iz mora: tamna koža',
    '🧜🏻‍♀' => 'sirena: svijetla koža',
    '🧜🏼‍♀' => 'sirena: srednje svijetla koža',
    '🧜🏽‍♀' => 'sirena: ni svijetla ni tamna koža',
    '🧜🏾‍♀' => 'sirena: srednje tamna koža',
    '🧜🏿‍♀' => 'sirena: tamna koža',
    '🧝🏻‍♂' => 'muškarac vilovnjak: svijetla koža',
    '🧝🏼‍♂' => 'muškarac vilovnjak: srednje svijetla koža',
    '🧝🏽‍♂' => 'muškarac vilovnjak: ni svijetla ni tamna koža',
    '🧝🏾‍♂' => 'muškarac vilovnjak: srednje tamna koža',
    '🧝🏿‍♂' => 'muškarac vilovnjak: tamna koža',
    '🧝🏻‍♀' => 'žena vilovnjak: svijetla koža',
    '🧝🏼‍♀' => 'žena vilovnjak: srednje svijetla koža',
    '🧝🏽‍♀' => 'žena vilovnjak: ni svijetla ni tamna koža',
    '🧝🏾‍♀' => 'žena vilovnjak: srednje tamna koža',
    '🧝🏿‍♀' => 'žena vilovnjak: tamna koža',
    '💆🏻‍♂' => 'muška masaža lica: svijetla koža',
    '💆🏼‍♂' => 'muška masaža lica: srednje svijetla koža',
    '💆🏽‍♂' => 'muška masaža lica: ni svijetla ni tamna koža',
    '💆🏾‍♂' => 'muška masaža lica: srednje tamna koža',
    '💆🏿‍♂' => 'muška masaža lica: tamna koža',
    '💆🏻‍♀' => 'ženska masaža lica: svijetla koža',
    '💆🏼‍♀' => 'ženska masaža lica: srednje svijetla koža',
    '💆🏽‍♀' => 'ženska masaža lica: ni svijetla ni tamna koža',
    '💆🏾‍♀' => 'ženska masaža lica: srednje tamna koža',
    '💆🏿‍♀' => 'ženska masaža lica: tamna koža',
    '💇🏻‍♂' => 'muško šišanje: svijetla koža',
    '💇🏼‍♂' => 'muško šišanje: srednje svijetla koža',
    '💇🏽‍♂' => 'muško šišanje: ni svijetla ni tamna koža',
    '💇🏾‍♂' => 'muško šišanje: srednje tamna koža',
    '💇🏿‍♂' => 'muško šišanje: tamna koža',
    '💇🏻‍♀' => 'žensko šišanje: svijetla koža',
    '💇🏼‍♀' => 'žensko šišanje: srednje svijetla koža',
    '💇🏽‍♀' => 'žensko šišanje: ni svijetla ni tamna koža',
    '💇🏾‍♀' => 'žensko šišanje: srednje tamna koža',
    '💇🏿‍♀' => 'žensko šišanje: tamna koža',
    '🚶🏻‍♂' => 'muškarac hoda: svijetla koža',
    '🚶🏼‍♂' => 'muškarac hoda: srednje svijetla koža',
    '🚶🏽‍♂' => 'muškarac hoda: ni svijetla ni tamna koža',
    '🚶🏾‍♂' => 'muškarac hoda: srednje tamna koža',
    '🚶🏿‍♂' => 'muškarac hoda: tamna koža',
    '🚶🏻‍♀' => 'žena hoda: svijetla koža',
    '🚶🏼‍♀' => 'žena hoda: srednje svijetla koža',
    '🚶🏽‍♀' => 'žena hoda: ni svijetla ni tamna koža',
    '🚶🏾‍♀' => 'žena hoda: srednje tamna koža',
    '🚶🏿‍♀' => 'žena hoda: tamna koža',
    '🚶🏻‍➡' => 'pješak: svijetla koža i gleda udesno',
    '🚶🏼‍➡' => 'pješak: srednje svijetla koža i gleda udesno',
    '🚶🏽‍➡' => 'pješak: ni svijetla ni tamna koža i gleda udesno',
    '🚶🏾‍➡' => 'pješak: srednje tamna koža i gleda udesno',
    '🚶🏿‍➡' => 'pješak: tamna koža i gleda udesno',
    '🧍🏻‍♂' => 'čovjek stoji: svijetla koža',
    '🧍🏼‍♂' => 'čovjek stoji: srednje svijetla koža',
    '🧍🏽‍♂' => 'čovjek stoji: ni svijetla ni tamna koža',
    '🧍🏾‍♂' => 'čovjek stoji: srednje tamna koža',
    '🧍🏿‍♂' => 'čovjek stoji: tamna koža',
    '🧍🏻‍♀' => 'žena stoji: svijetla koža',
    '🧍🏼‍♀' => 'žena stoji: srednje svijetla koža',
    '🧍🏽‍♀' => 'žena stoji: ni svijetla ni tamna koža',
    '🧍🏾‍♀' => 'žena stoji: srednje tamna koža',
    '🧍🏿‍♀' => 'žena stoji: tamna koža',
    '🧎🏻‍♂' => 'čovek kleči: svijetla koža',
    '🧎🏼‍♂' => 'čovek kleči: srednje svijetla koža',
    '🧎🏽‍♂' => 'čovek kleči: ni svijetla ni tamna koža',
    '🧎🏾‍♂' => 'čovek kleči: srednje tamna koža',
    '🧎🏿‍♂' => 'čovek kleči: tamna koža',
    '🧎🏻‍♀' => 'žena kleči: svijetla koža',
    '🧎🏼‍♀' => 'žena kleči: srednje svijetla koža',
    '🧎🏽‍♀' => 'žena kleči: ni svijetla ni tamna koža',
    '🧎🏾‍♀' => 'žena kleči: srednje tamna koža',
    '🧎🏿‍♀' => 'žena kleči: tamna koža',
    '🧎🏻‍➡' => 'osoba kleči: svijetla koža i gleda udesno',
    '🧎🏼‍➡' => 'osoba kleči: srednje svijetla koža i gleda udesno',
    '🧎🏽‍➡' => 'osoba kleči: ni svijetla ni tamna koža i gleda udesno',
    '🧎🏾‍➡' => 'osoba kleči: srednje tamna koža i gleda udesno',
    '🧎🏿‍➡' => 'osoba kleči: tamna koža i gleda udesno',
    '🧑🏻‍🦯' => 'osoba sa pomoćnim štapom: svijetla koža',
    '🧑🏼‍🦯' => 'osoba sa pomoćnim štapom: srednje svijetla koža',
    '🧑🏽‍🦯' => 'osoba sa pomoćnim štapom: ni svijetla ni tamna koža',
    '🧑🏾‍🦯' => 'osoba sa pomoćnim štapom: srednje tamna koža',
    '🧑🏿‍🦯' => 'osoba sa pomoćnim štapom: tamna koža',
    '👨🏻‍🦯' => 'čovjek sa pomoćnim štapom: svijetla koža',
    '👨🏼‍🦯' => 'čovjek sa pomoćnim štapom: srednje svijetla koža',
    '👨🏽‍🦯' => 'čovjek sa pomoćnim štapom: ni svijetla ni tamna koža',
    '👨🏾‍🦯' => 'čovjek sa pomoćnim štapom: srednje tamna koža',
    '👨🏿‍🦯' => 'čovjek sa pomoćnim štapom: tamna koža',
    '👩🏻‍🦯' => 'žena sa pomoćnim štapom: svijetla koža',
    '👩🏼‍🦯' => 'žena sa pomoćnim štapom: srednje svijetla koža',
    '👩🏽‍🦯' => 'žena sa pomoćnim štapom: ni svijetla ni tamna koža',
    '👩🏾‍🦯' => 'žena sa pomoćnim štapom: srednje tamna koža',
    '👩🏿‍🦯' => 'žena sa pomoćnim štapom: tamna koža',
    '🧑🏻‍🦼' => 'osoba u motornim kolicima: svijetla koža',
    '🧑🏼‍🦼' => 'osoba u motornim kolicima: srednje svijetla koža',
    '🧑🏽‍🦼' => 'osoba u motornim kolicima: ni svijetla ni tamna koža',
    '🧑🏾‍🦼' => 'osoba u motornim kolicima: srednje tamna koža',
    '🧑🏿‍🦼' => 'osoba u motornim kolicima: tamna koža',
    '👨🏻‍🦼' => 'čovjek u motornim kolicima: svijetla koža',
    '👨🏼‍🦼' => 'čovjek u motornim kolicima: srednje svijetla koža',
    '👨🏽‍🦼' => 'čovjek u motornim kolicima: ni svijetla ni tamna koža',
    '👨🏾‍🦼' => 'čovjek u motornim kolicima: srednje tamna koža',
    '👨🏿‍🦼' => 'čovjek u motornim kolicima: tamna koža',
    '👩🏻‍🦼' => 'žena u motornim kolicima: svijetla koža',
    '👩🏼‍🦼' => 'žena u motornim kolicima: srednje svijetla koža',
    '👩🏽‍🦼' => 'žena u motornim kolicima: ni svijetla ni tamna koža',
    '👩🏾‍🦼' => 'žena u motornim kolicima: srednje tamna koža',
    '👩🏿‍🦼' => 'žena u motornim kolicima: tamna koža',
    '🧑🏻‍🦽' => 'osoba u mehaničkim kolicima: svijetla koža',
    '🧑🏼‍🦽' => 'osoba u mehaničkim kolicima: srednje svijetla koža',
    '🧑🏽‍🦽' => 'osoba u mehaničkim kolicima: ni svijetla ni tamna koža',
    '🧑🏾‍🦽' => 'osoba u mehaničkim kolicima: srednje tamna koža',
    '🧑🏿‍🦽' => 'osoba u mehaničkim kolicima: tamna koža',
    '👨🏻‍🦽' => 'čovjek u mehaničkim kolicima: svijetla koža',
    '👨🏼‍🦽' => 'čovjek u mehaničkim kolicima: srednje svijetla koža',
    '👨🏽‍🦽' => 'čovjek u mehaničkim kolicima: ni svijetla ni tamna koža',
    '👨🏾‍🦽' => 'čovjek u mehaničkim kolicima: srednje tamna koža',
    '👨🏿‍🦽' => 'čovjek u mehaničkim kolicima: tamna koža',
    '👩🏻‍🦽' => 'žena u mehaničkim kolicima: svijetla koža',
    '👩🏼‍🦽' => 'žena u mehaničkim kolicima: srednje svijetla koža',
    '👩🏽‍🦽' => 'žena u mehaničkim kolicima: ni svijetla ni tamna koža',
    '👩🏾‍🦽' => 'žena u mehaničkim kolicima: srednje tamna koža',
    '👩🏿‍🦽' => 'žena u mehaničkim kolicima: tamna koža',
    '🏃🏻‍♂' => 'muškarac trči: svijetla koža',
    '🏃🏼‍♂' => 'muškarac trči: srednje svijetla koža',
    '🏃🏽‍♂' => 'muškarac trči: ni svijetla ni tamna koža',
    '🏃🏾‍♂' => 'muškarac trči: srednje tamna koža',
    '🏃🏿‍♂' => 'muškarac trči: tamna koža',
    '🏃🏻‍♀' => 'žena trči: svijetla koža',
    '🏃🏼‍♀' => 'žena trči: srednje svijetla koža',
    '🏃🏽‍♀' => 'žena trči: ni svijetla ni tamna koža',
    '🏃🏾‍♀' => 'žena trči: srednje tamna koža',
    '🏃🏿‍♀' => 'žena trči: tamna koža',
    '🏃🏻‍➡' => 'trkač: svijetla koža i gleda udesno',
    '🏃🏼‍➡' => 'trkač: srednje svijetla koža i gleda udesno',
    '🏃🏽‍➡' => 'trkač: ni svijetla ni tamna koža i gleda udesno',
    '🏃🏾‍➡' => 'trkač: srednje tamna koža i gleda udesno',
    '🏃🏿‍➡' => 'trkač: tamna koža i gleda udesno',
    '👯🏻‍♀' => 'žene u provodu: svijetla koža',
    '👯🏼‍♀' => 'žene u provodu: srednje svijetla koža',
    '👯🏽‍♀' => 'žene u provodu: ni svijetla ni tamna koža',
    '👯🏾‍♀' => 'žene u provodu: srednje tamna koža',
    '👯🏿‍♀' => 'žene u provodu: tamna koža',
    '👯🏻‍♂' => 'muškarci u provodu: svijetla koža',
    '👯🏼‍♂' => 'muškarci u provodu: srednje svijetla koža',
    '👯🏽‍♂' => 'muškarci u provodu: ni svijetla ni tamna koža',
    '👯🏾‍♂' => 'muškarci u provodu: srednje tamna koža',
    '👯🏿‍♂' => 'muškarci u provodu: tamna koža',
    '🧖🏻‍♂' => 'muškarac u parnom kupatilu: svijetla koža',
    '🧖🏼‍♂' => 'muškarac u parnom kupatilu: srednje svijetla koža',
    '🧖🏽‍♂' => 'muškarac u parnom kupatilu: ni svijetla ni tamna koža',
    '🧖🏾‍♂' => 'muškarac u parnom kupatilu: srednje tamna koža',
    '🧖🏿‍♂' => 'muškarac u parnom kupatilu: tamna koža',
    '🧖🏻‍♀' => 'žena u parnom kupatilu: svijetla koža',
    '🧖🏼‍♀' => 'žena u parnom kupatilu: srednje svijetla koža',
    '🧖🏽‍♀' => 'žena u parnom kupatilu: ni svijetla ni tamna koža',
    '🧖🏾‍♀' => 'žena u parnom kupatilu: srednje tamna koža',
    '🧖🏿‍♀' => 'žena u parnom kupatilu: tamna koža',
    '🧗🏻‍♂' => 'muškarac se penje: svijetla koža',
    '🧗🏼‍♂' => 'muškarac se penje: srednje svijetla koža',
    '🧗🏽‍♂' => 'muškarac se penje: ni svijetla ni tamna koža',
    '🧗🏾‍♂' => 'muškarac se penje: srednje tamna koža',
    '🧗🏿‍♂' => 'muškarac se penje: tamna koža',
    '🧗🏻‍♀' => 'žena se penje: svijetla koža',
    '🧗🏼‍♀' => 'žena se penje: srednje svijetla koža',
    '🧗🏽‍♀' => 'žena se penje: ni svijetla ni tamna koža',
    '🧗🏾‍♀' => 'žena se penje: srednje tamna koža',
    '🧗🏿‍♀' => 'žena se penje: tamna koža',
    '🏌🏻‍♂' => 'golfer: svijetla koža',
    '🏌🏼‍♂' => 'golfer: srednje svijetla koža',
    '🏌🏽‍♂' => 'golfer: ni svijetla ni tamna koža',
    '🏌🏾‍♂' => 'golfer: srednje tamna koža',
    '🏌🏿‍♂' => 'golfer: tamna koža',
    '🏌🏻‍♀' => 'golferka: svijetla koža',
    '🏌🏼‍♀' => 'golferka: srednje svijetla koža',
    '🏌🏽‍♀' => 'golferka: ni svijetla ni tamna koža',
    '🏌🏾‍♀' => 'golferka: srednje tamna koža',
    '🏌🏿‍♀' => 'golferka: tamna koža',
    '🏄🏻‍♂' => 'surfer: svijetla koža',
    '🏄🏼‍♂' => 'surfer: srednje svijetla koža',
    '🏄🏽‍♂' => 'surfer: ni svijetla ni tamna koža',
    '🏄🏾‍♂' => 'surfer: srednje tamna koža',
    '🏄🏿‍♂' => 'surfer: tamna koža',
    '🏄🏻‍♀' => 'surferka: svijetla koža',
    '🏄🏼‍♀' => 'surferka: srednje svijetla koža',
    '🏄🏽‍♀' => 'surferka: ni svijetla ni tamna koža',
    '🏄🏾‍♀' => 'surferka: srednje tamna koža',
    '🏄🏿‍♀' => 'surferka: tamna koža',
    '🚣🏻‍♂' => 'veslač: svijetla koža',
    '🚣🏼‍♂' => 'veslač: srednje svijetla koža',
    '🚣🏽‍♂' => 'veslač: ni svijetla ni tamna koža',
    '🚣🏾‍♂' => 'veslač: srednje tamna koža',
    '🚣🏿‍♂' => 'veslač: tamna koža',
    '🚣🏻‍♀' => 'veslačica: svijetla koža',
    '🚣🏼‍♀' => 'veslačica: srednje svijetla koža',
    '🚣🏽‍♀' => 'veslačica: ni svijetla ni tamna koža',
    '🚣🏾‍♀' => 'veslačica: srednje tamna koža',
    '🚣🏿‍♀' => 'veslačica: tamna koža',
    '🏊🏻‍♂' => 'plivač: svijetla koža',
    '🏊🏼‍♂' => 'plivač: srednje svijetla koža',
    '🏊🏽‍♂' => 'plivač: ni svijetla ni tamna koža',
    '🏊🏾‍♂' => 'plivač: srednje tamna koža',
    '🏊🏿‍♂' => 'plivač: tamna koža',
    '🏊🏻‍♀' => 'plivačica: svijetla koža',
    '🏊🏼‍♀' => 'plivačica: srednje svijetla koža',
    '🏊🏽‍♀' => 'plivačica: ni svijetla ni tamna koža',
    '🏊🏾‍♀' => 'plivačica: srednje tamna koža',
    '🏊🏿‍♀' => 'plivačica: tamna koža',
    '⛹🏻‍♂' => 'muškarac sa loptom: svijetla koža',
    '⛹🏼‍♂' => 'muškarac sa loptom: srednje svijetla koža',
    '⛹🏽‍♂' => 'muškarac sa loptom: ni svijetla ni tamna koža',
    '⛹🏾‍♂' => 'muškarac sa loptom: srednje tamna koža',
    '⛹🏿‍♂' => 'muškarac sa loptom: tamna koža',
    '⛹🏻‍♀' => 'žena sa loptom: svijetla koža',
    '⛹🏼‍♀' => 'žena sa loptom: srednje svijetla koža',
    '⛹🏽‍♀' => 'žena sa loptom: ni svijetla ni tamna koža',
    '⛹🏾‍♀' => 'žena sa loptom: srednje tamna koža',
    '⛹🏿‍♀' => 'žena sa loptom: tamna koža',
    '🏋🏻‍♂' => 'dizač tegova: svijetla koža',
    '🏋🏼‍♂' => 'dizač tegova: srednje svijetla koža',
    '🏋🏽‍♂' => 'dizač tegova: ni svijetla ni tamna koža',
    '🏋🏾‍♂' => 'dizač tegova: srednje tamna koža',
    '🏋🏿‍♂' => 'dizač tegova: tamna koža',
    '🏋🏻‍♀' => 'dizačica tegova: svijetla koža',
    '🏋🏼‍♀' => 'dizačica tegova: srednje svijetla koža',
    '🏋🏽‍♀' => 'dizačica tegova: ni svijetla ni tamna koža',
    '🏋🏾‍♀' => 'dizačica tegova: srednje tamna koža',
    '🏋🏿‍♀' => 'dizačica tegova: tamna koža',
    '🚴🏻‍♂' => 'biciklista: svijetla koža',
    '🚴🏼‍♂' => 'biciklista: srednje svijetla koža',
    '🚴🏽‍♂' => 'biciklista: ni svijetla ni tamna koža',
    '🚴🏾‍♂' => 'biciklista: srednje tamna koža',
    '🚴🏿‍♂' => 'biciklista: tamna koža',
    '🚴🏻‍♀' => 'biciklistkinja: svijetla koža',
    '🚴🏼‍♀' => 'biciklistkinja: srednje svijetla koža',
    '🚴🏽‍♀' => 'biciklistkinja: ni svijetla ni tamna koža',
    '🚴🏾‍♀' => 'biciklistkinja: srednje tamna koža',
    '🚴🏿‍♀' => 'biciklistkinja: tamna koža',
    '🚵🏻‍♂' => 'brdski biciklista: svijetla koža',
    '🚵🏼‍♂' => 'brdski biciklista: srednje svijetla koža',
    '🚵🏽‍♂' => 'brdski biciklista: ni svijetla ni tamna koža',
    '🚵🏾‍♂' => 'brdski biciklista: srednje tamna koža',
    '🚵🏿‍♂' => 'brdski biciklista: tamna koža',
    '🚵🏻‍♀' => 'brdska biciklistkinja: svijetla koža',
    '🚵🏼‍♀' => 'brdska biciklistkinja: srednje svijetla koža',
    '🚵🏽‍♀' => 'brdska biciklistkinja: ni svijetla ni tamna koža',
    '🚵🏾‍♀' => 'brdska biciklistkinja: srednje tamna koža',
    '🚵🏿‍♀' => 'brdska biciklistkinja: tamna koža',
    '🤸🏻‍♂' => 'gimnastičar: svijetla koža',
    '🤸🏼‍♂' => 'gimnastičar: srednje svijetla koža',
    '🤸🏽‍♂' => 'gimnastičar: ni svijetla ni tamna koža',
    '🤸🏾‍♂' => 'gimnastičar: srednje tamna koža',
    '🤸🏿‍♂' => 'gimnastičar: tamna koža',
    '🤸🏻‍♀' => 'gimnastičarka: svijetla koža',
    '🤸🏼‍♀' => 'gimnastičarka: srednje svijetla koža',
    '🤸🏽‍♀' => 'gimnastičarka: ni svijetla ni tamna koža',
    '🤸🏾‍♀' => 'gimnastičarka: srednje tamna koža',
    '🤸🏿‍♀' => 'gimnastičarka: tamna koža',
    '🤼🏻‍♀' => 'rvačice: svijetla koža',
    '🤼🏼‍♀' => 'rvačice: srednje svijetla koža',
    '🤼🏽‍♀' => 'rvačice: ni svijetla ni tamna koža',
    '🤼🏾‍♀' => 'rvačice: srednje tamna koža',
    '🤼🏿‍♀' => 'rvačice: tamna koža',
    '🤼🏻‍♂' => 'rvači: svijetla koža',
    '🤼🏼‍♂' => 'rvači: srednje svijetla koža',
    '🤼🏽‍♂' => 'rvači: ni svijetla ni tamna koža',
    '🤼🏾‍♂' => 'rvači: srednje tamna koža',
    '🤼🏿‍♂' => 'rvači: tamna koža',
    '🤽🏻‍♂' => 'vaterpolista: svijetla koža',
    '🤽🏼‍♂' => 'vaterpolista: srednje svijetla koža',
    '🤽🏽‍♂' => 'vaterpolista: ni svijetla ni tamna koža',
    '🤽🏾‍♂' => 'vaterpolista: srednje tamna koža',
    '🤽🏿‍♂' => 'vaterpolista: tamna koža',
    '🤽🏻‍♀' => 'vaterpolistkinja: svijetla koža',
    '🤽🏼‍♀' => 'vaterpolistkinja: srednje svijetla koža',
    '🤽🏽‍♀' => 'vaterpolistkinja: ni svijetla ni tamna koža',
    '🤽🏾‍♀' => 'vaterpolistkinja: srednje tamna koža',
    '🤽🏿‍♀' => 'vaterpolistkinja: tamna koža',
    '🤾🏻‍♂' => 'rukometaš: svijetla koža',
    '🤾🏼‍♂' => 'rukometaš: srednje svijetla koža',
    '🤾🏽‍♂' => 'rukometaš: ni svijetla ni tamna koža',
    '🤾🏾‍♂' => 'rukometaš: srednje tamna koža',
    '🤾🏿‍♂' => 'rukometaš: tamna koža',
    '🤾🏻‍♀' => 'rukometašica: svijetla koža',
    '🤾🏼‍♀' => 'rukometašica: srednje svijetla koža',
    '🤾🏽‍♀' => 'rukometašica: ni svijetla ni tamna koža',
    '🤾🏾‍♀' => 'rukometašica: srednje tamna koža',
    '🤾🏿‍♀' => 'rukometašica: tamna koža',
    '🤹🏻‍♂' => 'žongler: svijetla koža',
    '🤹🏼‍♂' => 'žongler: srednje svijetla koža',
    '🤹🏽‍♂' => 'žongler: ni svijetla ni tamna koža',
    '🤹🏾‍♂' => 'žongler: srednje tamna koža',
    '🤹🏿‍♂' => 'žongler: tamna koža',
    '🤹🏻‍♀' => 'žonglerka: svijetla koža',
    '🤹🏼‍♀' => 'žonglerka: srednje svijetla koža',
    '🤹🏽‍♀' => 'žonglerka: ni svijetla ni tamna koža',
    '🤹🏾‍♀' => 'žonglerka: srednje tamna koža',
    '🤹🏿‍♀' => 'žonglerka: tamna koža',
    '🧘🏻‍♂' => 'muškarac u lotos pozi: svijetla koža',
    '🧘🏼‍♂' => 'muškarac u lotos pozi: srednje svijetla koža',
    '🧘🏽‍♂' => 'muškarac u lotos pozi: ni svijetla ni tamna koža',
    '🧘🏾‍♂' => 'muškarac u lotos pozi: srednje tamna koža',
    '🧘🏿‍♂' => 'muškarac u lotos pozi: tamna koža',
    '🧘🏻‍♀' => 'žena u lotos pozi: svijetla koža',
    '🧘🏼‍♀' => 'žena u lotos pozi: srednje svijetla koža',
    '🧘🏽‍♀' => 'žena u lotos pozi: ni svijetla ni tamna koža',
    '🧘🏾‍♀' => 'žena u lotos pozi: srednje tamna koža',
    '🧘🏿‍♀' => 'žena u lotos pozi: tamna koža',
    '🧑‍🦰' => 'odrasla osoba: crvena kosa',
    '🧑‍🦱' => 'odrasla osoba: kovrdžava kosa',
    '🧑‍🦳' => 'odrasla osoba: sijeda kosa',
    '🧑‍🦲' => 'odrasla osoba: ćelav',
    '👨‍🦰' => 'muškarac: crvena kosa',
    '👨‍🦱' => 'muškarac: kovrdžava kosa',
    '👨‍🦳' => 'muškarac: sijeda kosa',
    '👨‍🦲' => 'muškarac: ćelav',
    '👩‍🦰' => 'žena: crvena kosa',
    '👩‍🦱' => 'žena: kovrdžava kosa',
    '👩‍🦳' => 'žena: sijeda kosa',
    '👩‍🦲' => 'žena: ćelav',
    '🚶‍➡' => 'pješak: gleda udesno',
    '🧎‍➡' => 'osoba kleči: gleda udesno',
    '🏃‍➡' => 'trkač: gleda udesno',
    '👨‍👦' => 'porodica: muškarac i dječak',
    '👨‍👧' => 'porodica: muškarac i djevojčica',
    '👩‍👦' => 'porodica: žena i dječak',
    '👩‍👧' => 'porodica: žena i djevojčica',
    '😶‍🌫' => 'lice u oblacima',
    '😮‍💨' => 'lice izdiše',
    '🙂‍↕' => 'glava trese vertikalno',
    '😵‍💫' => 'lice sa spiralnim očima',
    '❤‍🔥' => 'zapaljeno srce',
    '❤‍🩹' => 'srce koje zacjeljuje',
    '👁‍🗨' => 'oko u oblačiću dijaloga',
    '🧔‍♂' => 'muškarac: brada',
    '👱‍♂' => 'plav muškarac',
    '🧔‍♀' => 'žena: brada',
    '👱‍♀' => 'plavuša',
    '🙍‍♂' => 'namršten muškarac',
    '🙍‍♀' => 'namrštena žena',
    '🙎‍♂' => 'naduren muškarac',
    '🙎‍♀' => 'nadurena žena',
    '🙅‍♂' => 'muškarac pokazuje „ne“',
    '🙅‍♀' => 'žena pokazuje „ne“',
    '🙆‍♂' => 'muškarac pokazuje „ok“',
    '🙆‍♀' => 'žena pokazuje „ok“',
    '💁‍♂' => 'muškarac otkriva namjere',
    '💁‍♀' => 'žena otkriva namjere',
    '🙋‍♂' => 'muškarac podiže ruku',
    '🙋‍♀' => 'žena podiže ruku',
    '🧏‍♂' => 'gluv čovjek',
    '🧏‍♀' => 'gluva žena',
    '🙇‍♂' => 'muški duboki naklon',
    '🙇‍♀' => 'ženski duboki naklon',
    '🤦‍♂' => 'muškarac s rukom na čelu',
    '🤦‍♀' => 'žena s rukom na čelu',
    '🤷‍♂' => 'muškarac sliježe ramenima',
    '🤷‍♀' => 'žena sliježe ramenima',
    '🧑‍⚕' => 'zdravstveni radnik',
    '👨‍⚕' => 'muškarac zdravstveni radnik',
    '👩‍⚕' => 'zdravstvena radnica',
    '🧑‍🎓' => 'student(kinja)',
    '👨‍🎓' => 'student',
    '👩‍🎓' => 'studentkinja',
    '🧑‍🏫' => 'učitelj',
    '👨‍🏫' => 'profesor',
    '👩‍🏫' => 'profesorka',
    '🧑‍⚖' => 'sudija/nica',
    '👨‍⚖' => 'muškarac sudija',
    '👩‍⚖' => 'žena sudija',
    '🧑‍🌾' => 'poljoprivrednik',
    '👨‍🌾' => 'muškarac poljoprivrednik',
    '👩‍🌾' => 'poljoprivrednica',
    '🧑‍🍳' => 'kuvar',
    '👨‍🍳' => 'muškarac kuvar',
    '👩‍🍳' => 'kuvarica',
    '🧑‍🔧' => 'mehaničar',
    '👨‍🔧' => 'muškarac mehaničar',
    '👩‍🔧' => 'mehaničarka',
    '🧑‍🏭' => 'radnik u fabrici',
    '👨‍🏭' => 'radnik',
    '👩‍🏭' => 'radnica',
    '🧑‍💼' => 'kancelarijski radnik',
    '👨‍💼' => 'muškarac u kancelariji',
    '👩‍💼' => 'žena u kancelariji',
    '🧑‍🔬' => 'naučnik/ca',
    '👨‍🔬' => 'naučnik',
    '👩‍🔬' => 'naučnica',
    '🧑‍💻' => 'tehnolog',
    '👨‍💻' => 'muškarac tehnolog',
    '👩‍💻' => 'žena tehnolog',
    '🧑‍🎤' => 'pjevač',
    '👨‍🎤' => 'muškarac pjevač',
    '👩‍🎤' => 'pjevačica',
    '🧑‍🎨' => 'umjetnik',
    '👨‍🎨' => 'muškarac umjetnik',
    '👩‍🎨' => 'umjetnica',
    '🧑‍✈' => 'pilot(kinja)',
    '👨‍✈' => 'pilot',
    '👩‍✈' => 'žena pilot',
    '🧑‍🚀' => 'astronaut',
    '👨‍🚀' => 'kosmonaut',
    '👩‍🚀' => 'kosmonautkinja',
    '🧑‍🚒' => 'vatrogasac / žena vatrogasac',
    '👨‍🚒' => 'vatrogasac',
    '👩‍🚒' => 'žena vatrogasac',
    '👮‍♂' => 'policajac',
    '👮‍♀' => 'policajka',
    '🕵‍♂' => 'detektiv',
    '🕵‍♀' => 'detektivka',
    '💂‍♂' => 'gardista',
    '💂‍♀' => 'gardistkinja',
    '👷‍♂' => 'građevinar',
    '👷‍♀' => 'građevinarka',
    '👳‍♂' => 'čovjek sa turbanom',
    '👳‍♀' => 'žena sa turbanom',
    '🤵‍♂' => 'muškarac u smokingu',
    '🤵‍♀' => 'žena u smokingu',
    '👰‍♂' => 'muškarac sa velom',
    '👰‍♀' => 'žena sa velom',
    '👩‍🍼' => 'žena hrani bebu',
    '👨‍🍼' => 'muškarac hrani bebu',
    '🧑‍🍼' => 'osoba hrani bebu',
    '🧑‍🎄' => 'osoba Mraz',
    '🦸‍♂' => 'muškarac superheroj',
    '🦸‍♀' => 'žena super heroj',
    '🦹‍♂' => 'muškarac negativac',
    '🦹‍♀' => 'žena negativac',
    '🧙‍♂' => 'čarobnjak',
    '🧙‍♀' => 'čarobnica',
    '🧚‍♂' => 'vilenjak',
    '🧚‍♀' => 'žena vila',
    '🧛‍♂' => 'muški vampir',
    '🧛‍♀' => 'ženski vampir',
    '🧜‍♂' => 'muškarac iz mora',
    '🧜‍♀' => 'sirena',
    '🧝‍♂' => 'muškarac vilovnjak',
    '🧝‍♀' => 'žena vilovnjak',
    '🧞‍♂' => 'muški dobri duh',
    '🧞‍♀' => 'ženski dobri duh',
    '🧟‍♂' => 'muškarac zombi',
    '🧟‍♀' => 'žena zombi',
    '💆‍♂' => 'muška masaža lica',
    '💆‍♀' => 'ženska masaža lica',
    '💇‍♂' => 'muško šišanje',
    '💇‍♀' => 'žensko šišanje',
    '🚶‍♂' => 'muškarac hoda',
    '🚶‍♀' => 'žena hoda',
    '🧍‍♂' => 'čovjek stoji',
    '🧍‍♀' => 'žena stoji',
    '🧎‍♂' => 'čovek kleči',
    '🧎‍♀' => 'žena kleči',
    '🧑‍🦯' => 'osoba sa pomoćnim štapom',
    '👨‍🦯' => 'čovjek sa pomoćnim štapom',
    '👩‍🦯' => 'žena sa pomoćnim štapom',
    '🧑‍🦼' => 'osoba u motornim kolicima',
    '👨‍🦼' => 'čovjek u motornim kolicima',
    '👩‍🦼' => 'žena u motornim kolicima',
    '🧑‍🦽' => 'osoba u mehaničkim kolicima',
    '👨‍🦽' => 'čovjek u mehaničkim kolicima',
    '👩‍🦽' => 'žena u mehaničkim kolicima',
    '🏃‍♂' => 'muškarac trči',
    '🏃‍♀' => 'žena trči',
    '🧑‍🩰' => 'baletan',
    '👯‍♂' => 'muškarci u provodu',
    '👯‍♀' => 'žene u provodu',
    '🧖‍♂' => 'muškarac u parnom kupatilu',
    '🧖‍♀' => 'žena u parnom kupatilu',
    '🧗‍♂' => 'muškarac se penje',
    '🧗‍♀' => 'žena se penje',
    '🏌‍♂' => 'golfer',
    '🏌‍♀' => 'golferka',
    '🏄‍♂' => 'surfer',
    '🏄‍♀' => 'surferka',
    '🚣‍♂' => 'veslač',
    '🚣‍♀' => 'veslačica',
    '🏊‍♂' => 'plivač',
    '🏊‍♀' => 'plivačica',
    '⛹‍♂' => 'muškarac sa loptom',
    '⛹‍♀' => 'žena sa loptom',
    '🏋‍♂' => 'dizač tegova',
    '🏋‍♀' => 'dizačica tegova',
    '🚴‍♂' => 'biciklista',
    '🚴‍♀' => 'biciklistkinja',
    '🚵‍♂' => 'brdski biciklista',
    '🚵‍♀' => 'brdska biciklistkinja',
    '🤸‍♂' => 'gimnastičar',
    '🤸‍♀' => 'gimnastičarka',
    '🤼‍♂' => 'rvači',
    '🤼‍♀' => 'rvačice',
    '🤽‍♂' => 'vaterpolista',
    '🤽‍♀' => 'vaterpolistkinja',
    '🤾‍♂' => 'rukometaš',
    '🤾‍♀' => 'rukometašica',
    '🤹‍♂' => 'žongler',
    '🤹‍♀' => 'žonglerka',
    '🧘‍♂' => 'muškarac u lotos pozi',
    '🧘‍♀' => 'žena u lotos pozi',
    '🧑‍🧒' => 'porodica: odrasla osoba, dijete',
    '🐕‍🦺' => 'službeni pas',
    '🐈‍⬛' => 'crna mačka',
    '🐻‍❄' => 'polarni medvjed',
    '🐦‍⬛' => 'crna ptica',
    '🐦‍🔥' => 'feniks',
    '🍋‍🟩' => 'limeta',
    '🍄‍🟫' => 'smeđa pečurka',
    '⛓‍💥' => 'prekinut lanac',
    '🏳‍🌈' => 'dugina zastava',
    '🏳‍⚧' => 'transrodna zastava',
    '🏴‍☠' => 'piratska zastava',
    '👋🏻' => 'ruka koja maše: svijetla koža',
    '👋🏼' => 'ruka koja maše: srednje svijetla koža',
    '👋🏽' => 'ruka koja maše: ni svijetla ni tamna koža',
    '👋🏾' => 'ruka koja maše: srednje tamna koža',
    '👋🏿' => 'ruka koja maše: tamna koža',
    '🤚🏻' => 'podignut dlan: svijetla koža',
    '🤚🏼' => 'podignut dlan: srednje svijetla koža',
    '🤚🏽' => 'podignut dlan: ni svijetla ni tamna koža',
    '🤚🏾' => 'podignut dlan: srednje tamna koža',
    '🤚🏿' => 'podignut dlan: tamna koža',
    '🖐🏻' => 'šaka sa raširenim prstima: svijetla koža',
    '🖐🏼' => 'šaka sa raširenim prstima: srednje svijetla koža',
    '🖐🏽' => 'šaka sa raširenim prstima: ni svijetla ni tamna koža',
    '🖐🏾' => 'šaka sa raširenim prstima: srednje tamna koža',
    '🖐🏿' => 'šaka sa raširenim prstima: tamna koža',
    '✋🏻' => 'podignuta ruka: svijetla koža',
    '✋🏼' => 'podignuta ruka: srednje svijetla koža',
    '✋🏽' => 'podignuta ruka: ni svijetla ni tamna koža',
    '✋🏾' => 'podignuta ruka: srednje tamna koža',
    '✋🏿' => 'podignuta ruka: tamna koža',
    '🖖🏻' => 'vulkanski pozdrav: svijetla koža',
    '🖖🏼' => 'vulkanski pozdrav: srednje svijetla koža',
    '🖖🏽' => 'vulkanski pozdrav: ni svijetla ni tamna koža',
    '🖖🏾' => 'vulkanski pozdrav: srednje tamna koža',
    '🖖🏿' => 'vulkanski pozdrav: tamna koža',
    '🫱🏻' => 'ruka okrenuta nadesno: svijetla koža',
    '🫱🏼' => 'ruka okrenuta nadesno: srednje svijetla koža',
    '🫱🏽' => 'ruka okrenuta nadesno: ni svijetla ni tamna koža',
    '🫱🏾' => 'ruka okrenuta nadesno: srednje tamna koža',
    '🫱🏿' => 'ruka okrenuta nadesno: tamna koža',
    '🫲🏻' => 'ruka okrenuta nalevo: svijetla koža',
    '🫲🏼' => 'ruka okrenuta nalevo: srednje svijetla koža',
    '🫲🏽' => 'ruka okrenuta nalevo: ni svijetla ni tamna koža',
    '🫲🏾' => 'ruka okrenuta nalevo: srednje tamna koža',
    '🫲🏿' => 'ruka okrenuta nalevo: tamna koža',
    '🫳🏻' => 'dlan okrenut nadole: svijetla koža',
    '🫳🏼' => 'dlan okrenut nadole: srednje svijetla koža',
    '🫳🏽' => 'dlan okrenut nadole: ni svijetla ni tamna koža',
    '🫳🏾' => 'dlan okrenut nadole: srednje tamna koža',
    '🫳🏿' => 'dlan okrenut nadole: tamna koža',
    '🫴🏻' => 'dlan okrenut nagore: svijetla koža',
    '🫴🏼' => 'dlan okrenut nagore: srednje svijetla koža',
    '🫴🏽' => 'dlan okrenut nagore: ni svijetla ni tamna koža',
    '🫴🏾' => 'dlan okrenut nagore: srednje tamna koža',
    '🫴🏿' => 'dlan okrenut nagore: tamna koža',
    '🫷🏻' => 'ruka gura ulijevo: svijetla koža',
    '🫷🏼' => 'ruka gura ulijevo: srednje svijetla koža',
    '🫷🏽' => 'ruka gura ulijevo: ni svijetla ni tamna koža',
    '🫷🏾' => 'ruka gura ulijevo: srednje tamna koža',
    '🫷🏿' => 'ruka gura ulijevo: tamna koža',
    '🫸🏻' => 'ruka gura udesno: svijetla koža',
    '🫸🏼' => 'ruka gura udesno: srednje svijetla koža',
    '🫸🏽' => 'ruka gura udesno: ni svijetla ni tamna koža',
    '🫸🏾' => 'ruka gura udesno: srednje tamna koža',
    '🫸🏿' => 'ruka gura udesno: tamna koža',
    '👌🏻' => 'znak rukom „u redu“: svijetla koža',
    '👌🏼' => 'znak rukom „u redu“: srednje svijetla koža',
    '👌🏽' => 'znak rukom „u redu“: ni svijetla ni tamna koža',
    '👌🏾' => 'znak rukom „u redu“: srednje tamna koža',
    '👌🏿' => 'znak rukom „u redu“: tamna koža',
    '🤌🏻' => 'skupljeni prsti: svijetla koža',
    '🤌🏼' => 'skupljeni prsti: srednje svijetla koža',
    '🤌🏽' => 'skupljeni prsti: ni svijetla ni tamna koža',
    '🤌🏾' => 'skupljeni prsti: srednje tamna koža',
    '🤌🏿' => 'skupljeni prsti: tamna koža',
    '🤏🏻' => 'ruka štipa: svijetla koža',
    '🤏🏼' => 'ruka štipa: srednje svijetla koža',
    '🤏🏽' => 'ruka štipa: ni svijetla ni tamna koža',
    '🤏🏾' => 'ruka štipa: srednje tamna koža',
    '🤏🏿' => 'ruka štipa: tamna koža',
    '✌🏻' => 'znak pobjede: svijetla koža',
    '✌🏼' => 'znak pobjede: srednje svijetla koža',
    '✌🏽' => 'znak pobjede: ni svijetla ni tamna koža',
    '✌🏾' => 'znak pobjede: srednje tamna koža',
    '✌🏿' => 'znak pobjede: tamna koža',
    '🤞🏻' => 'prekršteni prsti: svijetla koža',
    '🤞🏼' => 'prekršteni prsti: srednje svijetla koža',
    '🤞🏽' => 'prekršteni prsti: ni svijetla ni tamna koža',
    '🤞🏾' => 'prekršteni prsti: srednje tamna koža',
    '🤞🏿' => 'prekršteni prsti: tamna koža',
    '🫰🏻' => 'ruka sa prekrštenim palcem i kažiprstom: svijetla koža',
    '🫰🏼' => 'ruka sa prekrštenim palcem i kažiprstom: srednje svijetla koža',
    '🫰🏽' => 'ruka sa prekrštenim palcem i kažiprstom: ni svijetla ni tamna koža',
    '🫰🏾' => 'ruka sa prekrštenim palcem i kažiprstom: srednje tamna koža',
    '🫰🏿' => 'ruka sa prekrštenim palcem i kažiprstom: tamna koža',
    '🤟🏻' => 'pokret volim te: svijetla koža',
    '🤟🏼' => 'pokret volim te: srednje svijetla koža',
    '🤟🏽' => 'pokret volim te: ni svijetla ni tamna koža',
    '🤟🏾' => 'pokret volim te: srednje tamna koža',
    '🤟🏿' => 'pokret volim te: tamna koža',
    '🤘🏻' => 'znak rogova: svijetla koža',
    '🤘🏼' => 'znak rogova: srednje svijetla koža',
    '🤘🏽' => 'znak rogova: ni svijetla ni tamna koža',
    '🤘🏾' => 'znak rogova: srednje tamna koža',
    '🤘🏿' => 'znak rogova: tamna koža',
    '🤙🏻' => 'znak rukom za telefon: svijetla koža',
    '🤙🏼' => 'znak rukom za telefon: srednje svijetla koža',
    '🤙🏽' => 'znak rukom za telefon: ni svijetla ni tamna koža',
    '🤙🏾' => 'znak rukom za telefon: srednje tamna koža',
    '🤙🏿' => 'znak rukom za telefon: tamna koža',
    '👈🏻' => 'kažiprst koji pokazuje ulijevo: svijetla koža',
    '👈🏼' => 'kažiprst koji pokazuje ulijevo: srednje svijetla koža',
    '👈🏽' => 'kažiprst koji pokazuje ulijevo: ni svijetla ni tamna koža',
    '👈🏾' => 'kažiprst koji pokazuje ulijevo: srednje tamna koža',
    '👈🏿' => 'kažiprst koji pokazuje ulijevo: tamna koža',
    '👉🏻' => 'kažiprst koji pokazuje udesno: svijetla koža',
    '👉🏼' => 'kažiprst koji pokazuje udesno: srednje svijetla koža',
    '👉🏽' => 'kažiprst koji pokazuje udesno: ni svijetla ni tamna koža',
    '👉🏾' => 'kažiprst koji pokazuje udesno: srednje tamna koža',
    '👉🏿' => 'kažiprst koji pokazuje udesno: tamna koža',
    '👆🏻' => 'kažiprst koji pokazuje nagore otpozadi: svijetla koža',
    '👆🏼' => 'kažiprst koji pokazuje nagore otpozadi: srednje svijetla koža',
    '👆🏽' => 'kažiprst koji pokazuje nagore otpozadi: ni svijetla ni tamna koža',
    '👆🏾' => 'kažiprst koji pokazuje nagore otpozadi: srednje tamna koža',
    '👆🏿' => 'kažiprst koji pokazuje nagore otpozadi: tamna koža',
    '🖕🏻' => 'srednji prst: svijetla koža',
    '🖕🏼' => 'srednji prst: srednje svijetla koža',
    '🖕🏽' => 'srednji prst: ni svijetla ni tamna koža',
    '🖕🏾' => 'srednji prst: srednje tamna koža',
    '🖕🏿' => 'srednji prst: tamna koža',
    '👇🏻' => 'kažiprst koji pokazuje nadolje otpozadi: svijetla koža',
    '👇🏼' => 'kažiprst koji pokazuje nadolje otpozadi: srednje svijetla koža',
    '👇🏽' => 'kažiprst koji pokazuje nadolje otpozadi: ni svijetla ni tamna koža',
    '👇🏾' => 'kažiprst koji pokazuje nadolje otpozadi: srednje tamna koža',
    '👇🏿' => 'kažiprst koji pokazuje nadolje otpozadi: tamna koža',
    '☝🏻' => 'kažiprst koji pokazuje nagore: svijetla koža',
    '☝🏼' => 'kažiprst koji pokazuje nagore: srednje svijetla koža',
    '☝🏽' => 'kažiprst koji pokazuje nagore: ni svijetla ni tamna koža',
    '☝🏾' => 'kažiprst koji pokazuje nagore: srednje tamna koža',
    '☝🏿' => 'kažiprst koji pokazuje nagore: tamna koža',
    '🫵🏻' => 'kažiprst koji pokazuje prema gledaocu: svijetla koža',
    '🫵🏼' => 'kažiprst koji pokazuje prema gledaocu: srednje svijetla koža',
    '🫵🏽' => 'kažiprst koji pokazuje prema gledaocu: ni svijetla ni tamna koža',
    '🫵🏾' => 'kažiprst koji pokazuje prema gledaocu: srednje tamna koža',
    '🫵🏿' => 'kažiprst koji pokazuje prema gledaocu: tamna koža',
    '👍🏻' => 'palac nagore: svijetla koža',
    '👍🏼' => 'palac nagore: srednje svijetla koža',
    '👍🏽' => 'palac nagore: ni svijetla ni tamna koža',
    '👍🏾' => 'palac nagore: srednje tamna koža',
    '👍🏿' => 'palac nagore: tamna koža',
    '👎🏻' => 'palac nadolje: svijetla koža',
    '👎🏼' => 'palac nadolje: srednje svijetla koža',
    '👎🏽' => 'palac nadolje: ni svijetla ni tamna koža',
    '👎🏾' => 'palac nadolje: srednje tamna koža',
    '👎🏿' => 'palac nadolje: tamna koža',
    '✊🏻' => 'pesnica: svijetla koža',
    '✊🏼' => 'pesnica: srednje svijetla koža',
    '✊🏽' => 'pesnica: ni svijetla ni tamna koža',
    '✊🏾' => 'pesnica: srednje tamna koža',
    '✊🏿' => 'pesnica: tamna koža',
    '👊🏻' => 'usmjerena pesnica: svijetla koža',
    '👊🏼' => 'usmjerena pesnica: srednje svijetla koža',
    '👊🏽' => 'usmjerena pesnica: ni svijetla ni tamna koža',
    '👊🏾' => 'usmjerena pesnica: srednje tamna koža',
    '👊🏿' => 'usmjerena pesnica: tamna koža',
    '🤛🏻' => 'pesnica ulijevo: svijetla koža',
    '🤛🏼' => 'pesnica ulijevo: srednje svijetla koža',
    '🤛🏽' => 'pesnica ulijevo: ni svijetla ni tamna koža',
    '🤛🏾' => 'pesnica ulijevo: srednje tamna koža',
    '🤛🏿' => 'pesnica ulijevo: tamna koža',
    '🤜🏻' => 'pesnica udesno: svijetla koža',
    '🤜🏼' => 'pesnica udesno: srednje svijetla koža',
    '🤜🏽' => 'pesnica udesno: ni svijetla ni tamna koža',
    '🤜🏾' => 'pesnica udesno: srednje tamna koža',
    '🤜🏿' => 'pesnica udesno: tamna koža',
    '👏🏻' => 'ruke koje tapšu: svijetla koža',
    '👏🏼' => 'ruke koje tapšu: srednje svijetla koža',
    '👏🏽' => 'ruke koje tapšu: ni svijetla ni tamna koža',
    '👏🏾' => 'ruke koje tapšu: srednje tamna koža',
    '👏🏿' => 'ruke koje tapšu: tamna koža',
    '🙌🏻' => 'podignute ruke: svijetla koža',
    '🙌🏼' => 'podignute ruke: srednje svijetla koža',
    '🙌🏽' => 'podignute ruke: ni svijetla ni tamna koža',
    '🙌🏾' => 'podignute ruke: srednje tamna koža',
    '🙌🏿' => 'podignute ruke: tamna koža',
    '🫶🏻' => 'ruke koje prave srce: svijetla koža',
    '🫶🏼' => 'ruke koje prave srce: srednje svijetla koža',
    '🫶🏽' => 'ruke koje prave srce: ni svijetla ni tamna koža',
    '🫶🏾' => 'ruke koje prave srce: srednje tamna koža',
    '🫶🏿' => 'ruke koje prave srce: tamna koža',
    '👐🏻' => 'rasklopljene šake: svijetla koža',
    '👐🏼' => 'rasklopljene šake: srednje svijetla koža',
    '👐🏽' => 'rasklopljene šake: ni svijetla ni tamna koža',
    '👐🏾' => 'rasklopljene šake: srednje tamna koža',
    '👐🏿' => 'rasklopljene šake: tamna koža',
    '🤲🏻' => 'dlanovi nagore zajedno: svijetla koža',
    '🤲🏼' => 'dlanovi nagore zajedno: srednje svijetla koža',
    '🤲🏽' => 'dlanovi nagore zajedno: ni svijetla ni tamna koža',
    '🤲🏾' => 'dlanovi nagore zajedno: srednje tamna koža',
    '🤲🏿' => 'dlanovi nagore zajedno: tamna koža',
    '🤝🏻' => 'rukovanje: svijetla koža',
    '🤝🏼' => 'rukovanje: srednje svijetla koža',
    '🤝🏽' => 'rukovanje: ni svijetla ni tamna koža',
    '🤝🏾' => 'rukovanje: srednje tamna koža',
    '🤝🏿' => 'rukovanje: tamna koža',
    '🙏🏻' => 'spojeni dlanovi: svijetla koža',
    '🙏🏼' => 'spojeni dlanovi: srednje svijetla koža',
    '🙏🏽' => 'spojeni dlanovi: ni svijetla ni tamna koža',
    '🙏🏾' => 'spojeni dlanovi: srednje tamna koža',
    '🙏🏿' => 'spojeni dlanovi: tamna koža',
    '✍🏻' => 'ruka koja piše: svijetla koža',
    '✍🏼' => 'ruka koja piše: srednje svijetla koža',
    '✍🏽' => 'ruka koja piše: ni svijetla ni tamna koža',
    '✍🏾' => 'ruka koja piše: srednje tamna koža',
    '✍🏿' => 'ruka koja piše: tamna koža',
    '💅🏻' => 'lak za nokte: svijetla koža',
    '💅🏼' => 'lak za nokte: srednje svijetla koža',
    '💅🏽' => 'lak za nokte: ni svijetla ni tamna koža',
    '💅🏾' => 'lak za nokte: srednje tamna koža',
    '💅🏿' => 'lak za nokte: tamna koža',
    '🤳🏻' => 'selfi: svijetla koža',
    '🤳🏼' => 'selfi: srednje svijetla koža',
    '🤳🏽' => 'selfi: ni svijetla ni tamna koža',
    '🤳🏾' => 'selfi: srednje tamna koža',
    '🤳🏿' => 'selfi: tamna koža',
    '💪🏻' => 'stegnuti biceps: svijetla koža',
    '💪🏼' => 'stegnuti biceps: srednje svijetla koža',
    '💪🏽' => 'stegnuti biceps: ni svijetla ni tamna koža',
    '💪🏾' => 'stegnuti biceps: srednje tamna koža',
    '💪🏿' => 'stegnuti biceps: tamna koža',
    '🦵🏻' => 'noga: svijetla koža',
    '🦵🏼' => 'noga: srednje svijetla koža',
    '🦵🏽' => 'noga: ni svijetla ni tamna koža',
    '🦵🏾' => 'noga: srednje tamna koža',
    '🦵🏿' => 'noga: tamna koža',
    '🦶🏻' => 'stopalo: svijetla koža',
    '🦶🏼' => 'stopalo: srednje svijetla koža',
    '🦶🏽' => 'stopalo: ni svijetla ni tamna koža',
    '🦶🏾' => 'stopalo: srednje tamna koža',
    '🦶🏿' => 'stopalo: tamna koža',
    '👂🏻' => 'uvo: svijetla koža',
    '👂🏼' => 'uvo: srednje svijetla koža',
    '👂🏽' => 'uvo: ni svijetla ni tamna koža',
    '👂🏾' => 'uvo: srednje tamna koža',
    '👂🏿' => 'uvo: tamna koža',
    '🦻🏻' => 'uvo sa slušnim aparatom: svijetla koža',
    '🦻🏼' => 'uvo sa slušnim aparatom: srednje svijetla koža',
    '🦻🏽' => 'uvo sa slušnim aparatom: ni svijetla ni tamna koža',
    '🦻🏾' => 'uvo sa slušnim aparatom: srednje tamna koža',
    '🦻🏿' => 'uvo sa slušnim aparatom: tamna koža',
    '👃🏻' => 'nos: svijetla koža',
    '👃🏼' => 'nos: srednje svijetla koža',
    '👃🏽' => 'nos: ni svijetla ni tamna koža',
    '👃🏾' => 'nos: srednje tamna koža',
    '👃🏿' => 'nos: tamna koža',
    '👶🏻' => 'beba: svijetla koža',
    '👶🏼' => 'beba: srednje svijetla koža',
    '👶🏽' => 'beba: ni svijetla ni tamna koža',
    '👶🏾' => 'beba: srednje tamna koža',
    '👶🏿' => 'beba: tamna koža',
    '🧒🏻' => 'dijete: svijetla koža',
    '🧒🏼' => 'dijete: srednje svijetla koža',
    '🧒🏽' => 'dijete: ni svijetla ni tamna koža',
    '🧒🏾' => 'dijete: srednje tamna koža',
    '🧒🏿' => 'dijete: tamna koža',
    '👦🏻' => 'dječak: svijetla koža',
    '👦🏼' => 'dječak: srednje svijetla koža',
    '👦🏽' => 'dječak: ni svijetla ni tamna koža',
    '👦🏾' => 'dječak: srednje tamna koža',
    '👦🏿' => 'dječak: tamna koža',
    '👧🏻' => 'djevojčica: svijetla koža',
    '👧🏼' => 'djevojčica: srednje svijetla koža',
    '👧🏽' => 'djevojčica: ni svijetla ni tamna koža',
    '👧🏾' => 'djevojčica: srednje tamna koža',
    '👧🏿' => 'djevojčica: tamna koža',
    '🧑🏻' => 'odrasla osoba: svijetla koža',
    '🧑🏼' => 'odrasla osoba: srednje svijetla koža',
    '🧑🏽' => 'odrasla osoba: ni svijetla ni tamna koža',
    '🧑🏾' => 'odrasla osoba: srednje tamna koža',
    '🧑🏿' => 'odrasla osoba: tamna koža',
    '👱🏻' => 'osoba sa plavom kosom: svijetla koža',
    '👱🏼' => 'osoba sa plavom kosom: srednje svijetla koža',
    '👱🏽' => 'osoba sa plavom kosom: ni svijetla ni tamna koža',
    '👱🏾' => 'osoba sa plavom kosom: srednje tamna koža',
    '👱🏿' => 'osoba sa plavom kosom: tamna koža',
    '👨🏻' => 'muškarac: svijetla koža',
    '👨🏼' => 'muškarac: srednje svijetla koža',
    '👨🏽' => 'muškarac: ni svijetla ni tamna koža',
    '👨🏾' => 'muškarac: srednje tamna koža',
    '👨🏿' => 'muškarac: tamna koža',
    '🧔🏻' => 'osoba sa bradom: svijetla koža',
    '🧔🏼' => 'osoba sa bradom: srednje svijetla koža',
    '🧔🏽' => 'osoba sa bradom: ni svijetla ni tamna koža',
    '🧔🏾' => 'osoba sa bradom: srednje tamna koža',
    '🧔🏿' => 'osoba sa bradom: tamna koža',
    '👩🏻' => 'žena: svijetla koža',
    '👩🏼' => 'žena: srednje svijetla koža',
    '👩🏽' => 'žena: ni svijetla ni tamna koža',
    '👩🏾' => 'žena: srednje tamna koža',
    '👩🏿' => 'žena: tamna koža',
    '🧓🏻' => 'starija odrasla osoba: svijetla koža',
    '🧓🏼' => 'starija odrasla osoba: srednje svijetla koža',
    '🧓🏽' => 'starija odrasla osoba: ni svijetla ni tamna koža',
    '🧓🏾' => 'starija odrasla osoba: srednje tamna koža',
    '🧓🏿' => 'starija odrasla osoba: tamna koža',
    '👴🏻' => 'starac: svijetla koža',
    '👴🏼' => 'starac: srednje svijetla koža',
    '👴🏽' => 'starac: ni svijetla ni tamna koža',
    '👴🏾' => 'starac: srednje tamna koža',
    '👴🏿' => 'starac: tamna koža',
    '👵🏻' => 'starica: svijetla koža',
    '👵🏼' => 'starica: srednje svijetla koža',
    '👵🏽' => 'starica: ni svijetla ni tamna koža',
    '👵🏾' => 'starica: srednje tamna koža',
    '👵🏿' => 'starica: tamna koža',
    '🙍🏻' => 'namrštena osoba: svijetla koža',
    '🙍🏼' => 'namrštena osoba: srednje svijetla koža',
    '🙍🏽' => 'namrštena osoba: ni svijetla ni tamna koža',
    '🙍🏾' => 'namrštena osoba: srednje tamna koža',
    '🙍🏿' => 'namrštena osoba: tamna koža',
    '🙎🏻' => 'nadurena osoba: svijetla koža',
    '🙎🏼' => 'nadurena osoba: srednje svijetla koža',
    '🙎🏽' => 'nadurena osoba: ni svijetla ni tamna koža',
    '🙎🏾' => 'nadurena osoba: srednje tamna koža',
    '🙎🏿' => 'nadurena osoba: tamna koža',
    '🙅🏻' => 'osoba koja pokazuje „ne“: svijetla koža',
    '🙅🏼' => 'osoba koja pokazuje „ne“: srednje svijetla koža',
    '🙅🏽' => 'osoba koja pokazuje „ne“: ni svijetla ni tamna koža',
    '🙅🏾' => 'osoba koja pokazuje „ne“: srednje tamna koža',
    '🙅🏿' => 'osoba koja pokazuje „ne“: tamna koža',
    '🙆🏻' => 'osoba koja pokazuje „u redu“: svijetla koža',
    '🙆🏼' => 'osoba koja pokazuje „u redu“: srednje svijetla koža',
    '🙆🏽' => 'osoba koja pokazuje „u redu“: ni svijetla ni tamna koža',
    '🙆🏾' => 'osoba koja pokazuje „u redu“: srednje tamna koža',
    '🙆🏿' => 'osoba koja pokazuje „u redu“: tamna koža',
    '💁🏻' => 'osoba koja daje informacije: svijetla koža',
    '💁🏼' => 'osoba koja daje informacije: srednje svijetla koža',
    '💁🏽' => 'osoba koja daje informacije: ni svijetla ni tamna koža',
    '💁🏾' => 'osoba koja daje informacije: srednje tamna koža',
    '💁🏿' => 'osoba koja daje informacije: tamna koža',
    '🙋🏻' => 'srećna osoba sa podignutom rukom: svijetla koža',
    '🙋🏼' => 'srećna osoba sa podignutom rukom: srednje svijetla koža',
    '🙋🏽' => 'srećna osoba sa podignutom rukom: ni svijetla ni tamna koža',
    '🙋🏾' => 'srećna osoba sa podignutom rukom: srednje tamna koža',
    '🙋🏿' => 'srećna osoba sa podignutom rukom: tamna koža',
    '🧏🏻' => 'gluva osoba: svijetla koža',
    '🧏🏼' => 'gluva osoba: srednje svijetla koža',
    '🧏🏽' => 'gluva osoba: ni svijetla ni tamna koža',
    '🧏🏾' => 'gluva osoba: srednje tamna koža',
    '🧏🏿' => 'gluva osoba: tamna koža',
    '🙇🏻' => 'osoba koja se klanja: svijetla koža',
    '🙇🏼' => 'osoba koja se klanja: srednje svijetla koža',
    '🙇🏽' => 'osoba koja se klanja: ni svijetla ni tamna koža',
    '🙇🏾' => 'osoba koja se klanja: srednje tamna koža',
    '🙇🏿' => 'osoba koja se klanja: tamna koža',
    '🤦🏻' => 'šaka o čelo: svijetla koža',
    '🤦🏼' => 'šaka o čelo: srednje svijetla koža',
    '🤦🏽' => 'šaka o čelo: ni svijetla ni tamna koža',
    '🤦🏾' => 'šaka o čelo: srednje tamna koža',
    '🤦🏿' => 'šaka o čelo: tamna koža',
    '🤷🏻' => 'slijeganje ramenima: svijetla koža',
    '🤷🏼' => 'slijeganje ramenima: srednje svijetla koža',
    '🤷🏽' => 'slijeganje ramenima: ni svijetla ni tamna koža',
    '🤷🏾' => 'slijeganje ramenima: srednje tamna koža',
    '🤷🏿' => 'slijeganje ramenima: tamna koža',
    '👮🏻' => 'predstavnik policije: svijetla koža',
    '👮🏼' => 'predstavnik policije: srednje svijetla koža',
    '👮🏽' => 'predstavnik policije: ni svijetla ni tamna koža',
    '👮🏾' => 'predstavnik policije: srednje tamna koža',
    '👮🏿' => 'predstavnik policije: tamna koža',
    '🕵🏻' => 'inspektor: svijetla koža',
    '🕵🏼' => 'inspektor: srednje svijetla koža',
    '🕵🏽' => 'inspektor: ni svijetla ni tamna koža',
    '🕵🏾' => 'inspektor: srednje tamna koža',
    '🕵🏿' => 'inspektor: tamna koža',
    '💂🏻' => 'čuvar: svijetla koža',
    '💂🏼' => 'čuvar: srednje svijetla koža',
    '💂🏽' => 'čuvar: ni svijetla ni tamna koža',
    '💂🏾' => 'čuvar: srednje tamna koža',
    '💂🏿' => 'čuvar: tamna koža',
    '🥷🏻' => 'nindža: svijetla koža',
    '🥷🏼' => 'nindža: srednje svijetla koža',
    '🥷🏽' => 'nindža: ni svijetla ni tamna koža',
    '🥷🏾' => 'nindža: srednje tamna koža',
    '🥷🏿' => 'nindža: tamna koža',
    '👷🏻' => 'građevinski radnik: svijetla koža',
    '👷🏼' => 'građevinski radnik: srednje svijetla koža',
    '👷🏽' => 'građevinski radnik: ni svijetla ni tamna koža',
    '👷🏾' => 'građevinski radnik: srednje tamna koža',
    '👷🏿' => 'građevinski radnik: tamna koža',
    '🫅🏻' => 'osoba sa krunom: svijetla koža',
    '🫅🏼' => 'osoba sa krunom: srednje svijetla koža',
    '🫅🏽' => 'osoba sa krunom: ni svijetla ni tamna koža',
    '🫅🏾' => 'osoba sa krunom: srednje tamna koža',
    '🫅🏿' => 'osoba sa krunom: tamna koža',
    '🤴🏻' => 'princ: svijetla koža',
    '🤴🏼' => 'princ: srednje svijetla koža',
    '🤴🏽' => 'princ: ni svijetla ni tamna koža',
    '🤴🏾' => 'princ: srednje tamna koža',
    '🤴🏿' => 'princ: tamna koža',
    '👸🏻' => 'princeza: svijetla koža',
    '👸🏼' => 'princeza: srednje svijetla koža',
    '👸🏽' => 'princeza: ni svijetla ni tamna koža',
    '👸🏾' => 'princeza: srednje tamna koža',
    '👸🏿' => 'princeza: tamna koža',
    '👳🏻' => 'osoba sa turbanom: svijetla koža',
    '👳🏼' => 'osoba sa turbanom: srednje svijetla koža',
    '👳🏽' => 'osoba sa turbanom: ni svijetla ni tamna koža',
    '👳🏾' => 'osoba sa turbanom: srednje tamna koža',
    '👳🏿' => 'osoba sa turbanom: tamna koža',
    '👲🏻' => 'čovjek sa kineskom kapom: svijetla koža',
    '👲🏼' => 'čovjek sa kineskom kapom: srednje svijetla koža',
    '👲🏽' => 'čovjek sa kineskom kapom: ni svijetla ni tamna koža',
    '👲🏾' => 'čovjek sa kineskom kapom: srednje tamna koža',
    '👲🏿' => 'čovjek sa kineskom kapom: tamna koža',
    '🧕🏻' => 'žena sa maramom na glavi: svijetla koža',
    '🧕🏼' => 'žena sa maramom na glavi: srednje svijetla koža',
    '🧕🏽' => 'žena sa maramom na glavi: ni svijetla ni tamna koža',
    '🧕🏾' => 'žena sa maramom na glavi: srednje tamna koža',
    '🧕🏿' => 'žena sa maramom na glavi: tamna koža',
    '🤵🏻' => 'čovjek u smokingu: svijetla koža',
    '🤵🏼' => 'čovjek u smokingu: srednje svijetla koža',
    '🤵🏽' => 'čovjek u smokingu: ni svijetla ni tamna koža',
    '🤵🏾' => 'čovjek u smokingu: srednje tamna koža',
    '🤵🏿' => 'čovjek u smokingu: tamna koža',
    '👰🏻' => 'nevjesta sa velom: svijetla koža',
    '👰🏼' => 'nevjesta sa velom: srednje svijetla koža',
    '👰🏽' => 'nevjesta sa velom: ni svijetla ni tamna koža',
    '👰🏾' => 'nevjesta sa velom: srednje tamna koža',
    '👰🏿' => 'nevjesta sa velom: tamna koža',
    '🤰🏻' => 'trudnica: svijetla koža',
    '🤰🏼' => 'trudnica: srednje svijetla koža',
    '🤰🏽' => 'trudnica: ni svijetla ni tamna koža',
    '🤰🏾' => 'trudnica: srednje tamna koža',
    '🤰🏿' => 'trudnica: tamna koža',
    '🫃🏻' => 'trudni muškarac: svijetla koža',
    '🫃🏼' => 'trudni muškarac: srednje svijetla koža',
    '🫃🏽' => 'trudni muškarac: ni svijetla ni tamna koža',
    '🫃🏾' => 'trudni muškarac: srednje tamna koža',
    '🫃🏿' => 'trudni muškarac: tamna koža',
    '🫄🏻' => 'trudna osoba: svijetla koža',
    '🫄🏼' => 'trudna osoba: srednje svijetla koža',
    '🫄🏽' => 'trudna osoba: ni svijetla ni tamna koža',
    '🫄🏾' => 'trudna osoba: srednje tamna koža',
    '🫄🏿' => 'trudna osoba: tamna koža',
    '🤱🏻' => 'dojenje: svijetla koža',
    '🤱🏼' => 'dojenje: srednje svijetla koža',
    '🤱🏽' => 'dojenje: ni svijetla ni tamna koža',
    '🤱🏾' => 'dojenje: srednje tamna koža',
    '🤱🏿' => 'dojenje: tamna koža',
    '👼🏻' => 'beba anđeo: svijetla koža',
    '👼🏼' => 'beba anđeo: srednje svijetla koža',
    '👼🏽' => 'beba anđeo: ni svijetla ni tamna koža',
    '👼🏾' => 'beba anđeo: srednje tamna koža',
    '👼🏿' => 'beba anđeo: tamna koža',
    '🎅🏻' => 'Djed Mraz: svijetla koža',
    '🎅🏼' => 'Djed Mraz: srednje svijetla koža',
    '🎅🏽' => 'Djed Mraz: ni svijetla ni tamna koža',
    '🎅🏾' => 'Djed Mraz: srednje tamna koža',
    '🎅🏿' => 'Djed Mraz: tamna koža',
    '🤶🏻' => 'baka Mraz: svijetla koža',
    '🤶🏼' => 'baka Mraz: srednje svijetla koža',
    '🤶🏽' => 'baka Mraz: ni svijetla ni tamna koža',
    '🤶🏾' => 'baka Mraz: srednje tamna koža',
    '🤶🏿' => 'baka Mraz: tamna koža',
    '🦸🏻' => 'superheroj: svijetla koža',
    '🦸🏼' => 'superheroj: srednje svijetla koža',
    '🦸🏽' => 'superheroj: ni svijetla ni tamna koža',
    '🦸🏾' => 'superheroj: srednje tamna koža',
    '🦸🏿' => 'superheroj: tamna koža',
    '🦹🏻' => 'negativac: svijetla koža',
    '🦹🏼' => 'negativac: srednje svijetla koža',
    '🦹🏽' => 'negativac: ni svijetla ni tamna koža',
    '🦹🏾' => 'negativac: srednje tamna koža',
    '🦹🏿' => 'negativac: tamna koža',
    '🧙🏻' => 'mag: svijetla koža',
    '🧙🏼' => 'mag: srednje svijetla koža',
    '🧙🏽' => 'mag: ni svijetla ni tamna koža',
    '🧙🏾' => 'mag: srednje tamna koža',
    '🧙🏿' => 'mag: tamna koža',
    '🧚🏻' => 'vila: svijetla koža',
    '🧚🏼' => 'vila: srednje svijetla koža',
    '🧚🏽' => 'vila: ni svijetla ni tamna koža',
    '🧚🏾' => 'vila: srednje tamna koža',
    '🧚🏿' => 'vila: tamna koža',
    '🧛🏻' => 'vampir: svijetla koža',
    '🧛🏼' => 'vampir: srednje svijetla koža',
    '🧛🏽' => 'vampir: ni svijetla ni tamna koža',
    '🧛🏾' => 'vampir: srednje tamna koža',
    '🧛🏿' => 'vampir: tamna koža',
    '🧜🏻' => 'osoba iz mora: svijetla koža',
    '🧜🏼' => 'osoba iz mora: srednje svijetla koža',
    '🧜🏽' => 'osoba iz mora: ni svijetla ni tamna koža',
    '🧜🏾' => 'osoba iz mora: srednje tamna koža',
    '🧜🏿' => 'osoba iz mora: tamna koža',
    '🧝🏻' => 'vilovnjak: svijetla koža',
    '🧝🏼' => 'vilovnjak: srednje svijetla koža',
    '🧝🏽' => 'vilovnjak: ni svijetla ni tamna koža',
    '🧝🏾' => 'vilovnjak: srednje tamna koža',
    '🧝🏿' => 'vilovnjak: tamna koža',
    '💆🏻' => 'masaža lica: svijetla koža',
    '💆🏼' => 'masaža lica: srednje svijetla koža',
    '💆🏽' => 'masaža lica: ni svijetla ni tamna koža',
    '💆🏾' => 'masaža lica: srednje tamna koža',
    '💆🏿' => 'masaža lica: tamna koža',
    '💇🏻' => 'šišanje: svijetla koža',
    '💇🏼' => 'šišanje: srednje svijetla koža',
    '💇🏽' => 'šišanje: ni svijetla ni tamna koža',
    '💇🏾' => 'šišanje: srednje tamna koža',
    '💇🏿' => 'šišanje: tamna koža',
    '🚶🏻' => 'pješak: svijetla koža',
    '🚶🏼' => 'pješak: srednje svijetla koža',
    '🚶🏽' => 'pješak: ni svijetla ni tamna koža',
    '🚶🏾' => 'pješak: srednje tamna koža',
    '🚶🏿' => 'pješak: tamna koža',
    '🧍🏻' => 'osoba stoji: svijetla koža',
    '🧍🏼' => 'osoba stoji: srednje svijetla koža',
    '🧍🏽' => 'osoba stoji: ni svijetla ni tamna koža',
    '🧍🏾' => 'osoba stoji: srednje tamna koža',
    '🧍🏿' => 'osoba stoji: tamna koža',
    '🧎🏻' => 'osoba kleči: svijetla koža',
    '🧎🏼' => 'osoba kleči: srednje svijetla koža',
    '🧎🏽' => 'osoba kleči: ni svijetla ni tamna koža',
    '🧎🏾' => 'osoba kleči: srednje tamna koža',
    '🧎🏿' => 'osoba kleči: tamna koža',
    '🏃🏻' => 'trkač: svijetla koža',
    '🏃🏼' => 'trkač: srednje svijetla koža',
    '🏃🏽' => 'trkač: ni svijetla ni tamna koža',
    '🏃🏾' => 'trkač: srednje tamna koža',
    '🏃🏿' => 'trkač: tamna koža',
    '💃🏻' => 'plesačica: svijetla koža',
    '💃🏼' => 'plesačica: srednje svijetla koža',
    '💃🏽' => 'plesačica: ni svijetla ni tamna koža',
    '💃🏾' => 'plesačica: srednje tamna koža',
    '💃🏿' => 'plesačica: tamna koža',
    '🕺🏻' => 'plesač: svijetla koža',
    '🕺🏼' => 'plesač: srednje svijetla koža',
    '🕺🏽' => 'plesač: ni svijetla ni tamna koža',
    '🕺🏾' => 'plesač: srednje tamna koža',
    '🕺🏿' => 'plesač: tamna koža',
    '🕴🏻' => 'muškarac u poslovnom odijelu koji lebdi: svijetla koža',
    '🕴🏼' => 'muškarac u poslovnom odijelu koji lebdi: srednje svijetla koža',
    '🕴🏽' => 'muškarac u poslovnom odijelu koji lebdi: ni svijetla ni tamna koža',
    '🕴🏾' => 'muškarac u poslovnom odijelu koji lebdi: srednje tamna koža',
    '🕴🏿' => 'muškarac u poslovnom odijelu koji lebdi: tamna koža',
    '👯🏻' => 'osobe u provodu: svijetla koža',
    '👯🏼' => 'osobe u provodu: srednje svijetla koža',
    '👯🏽' => 'osobe u provodu: ni svijetla ni tamna koža',
    '👯🏾' => 'osobe u provodu: srednje tamna koža',
    '👯🏿' => 'osobe u provodu: tamna koža',
    '🧖🏻' => 'osoba u parnom kupatilu: svijetla koža',
    '🧖🏼' => 'osoba u parnom kupatilu: srednje svijetla koža',
    '🧖🏽' => 'osoba u parnom kupatilu: ni svijetla ni tamna koža',
    '🧖🏾' => 'osoba u parnom kupatilu: srednje tamna koža',
    '🧖🏿' => 'osoba u parnom kupatilu: tamna koža',
    '🧗🏻' => 'penjanje: svijetla koža',
    '🧗🏼' => 'penjanje: srednje svijetla koža',
    '🧗🏽' => 'penjanje: ni svijetla ni tamna koža',
    '🧗🏾' => 'penjanje: srednje tamna koža',
    '🧗🏿' => 'penjanje: tamna koža',
    '🏇🏻' => 'trke konja: svijetla koža',
    '🏇🏼' => 'trke konja: srednje svijetla koža',
    '🏇🏽' => 'trke konja: ni svijetla ni tamna koža',
    '🏇🏾' => 'trke konja: srednje tamna koža',
    '🏇🏿' => 'trke konja: tamna koža',
    '🏂🏻' => 'vozač snouborda: svijetla koža',
    '🏂🏼' => 'vozač snouborda: srednje svijetla koža',
    '🏂🏽' => 'vozač snouborda: ni svijetla ni tamna koža',
    '🏂🏾' => 'vozač snouborda: srednje tamna koža',
    '🏂🏿' => 'vozač snouborda: tamna koža',
    '🏌🏻' => 'osoba igra golf: svijetla koža',
    '🏌🏼' => 'osoba igra golf: srednje svijetla koža',
    '🏌🏽' => 'osoba igra golf: ni svijetla ni tamna koža',
    '🏌🏾' => 'osoba igra golf: srednje tamna koža',
    '🏌🏿' => 'osoba igra golf: tamna koža',
    '🏄🏻' => 'osoba surfuje: svijetla koža',
    '🏄🏼' => 'osoba surfuje: srednje svijetla koža',
    '🏄🏽' => 'osoba surfuje: ni svijetla ni tamna koža',
    '🏄🏾' => 'osoba surfuje: srednje tamna koža',
    '🏄🏿' => 'osoba surfuje: tamna koža',
    '🚣🏻' => 'čamac na vesla: svijetla koža',
    '🚣🏼' => 'čamac na vesla: srednje svijetla koža',
    '🚣🏽' => 'čamac na vesla: ni svijetla ni tamna koža',
    '🚣🏾' => 'čamac na vesla: srednje tamna koža',
    '🚣🏿' => 'čamac na vesla: tamna koža',
    '🏊🏻' => 'osoba pliva: svijetla koža',
    '🏊🏼' => 'osoba pliva: srednje svijetla koža',
    '🏊🏽' => 'osoba pliva: ni svijetla ni tamna koža',
    '🏊🏾' => 'osoba pliva: srednje tamna koža',
    '🏊🏿' => 'osoba pliva: tamna koža',
    '⛹🏻' => 'osoba sa loptom: svijetla koža',
    '⛹🏼' => 'osoba sa loptom: srednje svijetla koža',
    '⛹🏽' => 'osoba sa loptom: ni svijetla ni tamna koža',
    '⛹🏾' => 'osoba sa loptom: srednje tamna koža',
    '⛹🏿' => 'osoba sa loptom: tamna koža',
    '🏋🏻' => 'osoba diže tegove: svijetla koža',
    '🏋🏼' => 'osoba diže tegove: srednje svijetla koža',
    '🏋🏽' => 'osoba diže tegove: ni svijetla ni tamna koža',
    '🏋🏾' => 'osoba diže tegove: srednje tamna koža',
    '🏋🏿' => 'osoba diže tegove: tamna koža',
    '🚴🏻' => 'osoba na biciklu: svijetla koža',
    '🚴🏼' => 'osoba na biciklu: srednje svijetla koža',
    '🚴🏽' => 'osoba na biciklu: ni svijetla ni tamna koža',
    '🚴🏾' => 'osoba na biciklu: srednje tamna koža',
    '🚴🏿' => 'osoba na biciklu: tamna koža',
    '🚵🏻' => 'osoba na brdskom biciklu: svijetla koža',
    '🚵🏼' => 'osoba na brdskom biciklu: srednje svijetla koža',
    '🚵🏽' => 'osoba na brdskom biciklu: ni svijetla ni tamna koža',
    '🚵🏾' => 'osoba na brdskom biciklu: srednje tamna koža',
    '🚵🏿' => 'osoba na brdskom biciklu: tamna koža',
    '🤸🏻' => 'gimnastičarska zvezda: svijetla koža',
    '🤸🏼' => 'gimnastičarska zvezda: srednje svijetla koža',
    '🤸🏽' => 'gimnastičarska zvezda: ni svijetla ni tamna koža',
    '🤸🏾' => 'gimnastičarska zvezda: srednje tamna koža',
    '🤸🏿' => 'gimnastičarska zvezda: tamna koža',
    '🤼🏻' => 'rvanje: svijetla koža',
    '🤼🏼' => 'rvanje: srednje svijetla koža',
    '🤼🏽' => 'rvanje: ni svijetla ni tamna koža',
    '🤼🏾' => 'rvanje: srednje tamna koža',
    '🤼🏿' => 'rvanje: tamna koža',
    '🤽🏻' => 'vaterpolo: svijetla koža',
    '🤽🏼' => 'vaterpolo: srednje svijetla koža',
    '🤽🏽' => 'vaterpolo: ni svijetla ni tamna koža',
    '🤽🏾' => 'vaterpolo: srednje tamna koža',
    '🤽🏿' => 'vaterpolo: tamna koža',
    '🤾🏻' => 'rukomet: svijetla koža',
    '🤾🏼' => 'rukomet: srednje svijetla koža',
    '🤾🏽' => 'rukomet: ni svijetla ni tamna koža',
    '🤾🏾' => 'rukomet: srednje tamna koža',
    '🤾🏿' => 'rukomet: tamna koža',
    '🤹🏻' => 'osoba žonglira: svijetla koža',
    '🤹🏼' => 'osoba žonglira: srednje svijetla koža',
    '🤹🏽' => 'osoba žonglira: ni svijetla ni tamna koža',
    '🤹🏾' => 'osoba žonglira: srednje tamna koža',
    '🤹🏿' => 'osoba žonglira: tamna koža',
    '🧘🏻' => 'lotos poza: svijetla koža',
    '🧘🏼' => 'lotos poza: srednje svijetla koža',
    '🧘🏽' => 'lotos poza: ni svijetla ni tamna koža',
    '🧘🏾' => 'lotos poza: srednje tamna koža',
    '🧘🏿' => 'lotos poza: tamna koža',
    '🛀🏻' => 'osoba koja se kupa: svijetla koža',
    '🛀🏼' => 'osoba koja se kupa: srednje svijetla koža',
    '🛀🏽' => 'osoba koja se kupa: ni svijetla ni tamna koža',
    '🛀🏾' => 'osoba koja se kupa: srednje tamna koža',
    '🛀🏿' => 'osoba koja se kupa: tamna koža',
    '🛌🏻' => 'osoba u krevetu: svijetla koža',
    '🛌🏼' => 'osoba u krevetu: srednje svijetla koža',
    '🛌🏽' => 'osoba u krevetu: ni svijetla ni tamna koža',
    '🛌🏾' => 'osoba u krevetu: srednje tamna koža',
    '🛌🏿' => 'osoba u krevetu: tamna koža',
    '👭🏻' => 'žene se drže za ruke: svijetla koža',
    '👭🏼' => 'žene se drže za ruke: srednje svijetla koža',
    '👭🏽' => 'žene se drže za ruke: ni svijetla ni tamna koža',
    '👭🏾' => 'žene se drže za ruke: srednje tamna koža',
    '👭🏿' => 'žene se drže za ruke: tamna koža',
    '👫🏻' => 'žena i muškarac se drže za ruke: svijetla koža',
    '👫🏼' => 'žena i muškarac se drže za ruke: srednje svijetla koža',
    '👫🏽' => 'žena i muškarac se drže za ruke: ni svijetla ni tamna koža',
    '👫🏾' => 'žena i muškarac se drže za ruke: srednje tamna koža',
    '👫🏿' => 'žena i muškarac se drže za ruke: tamna koža',
    '👬🏻' => 'muškarci se drže za ruke: svijetla koža',
    '👬🏼' => 'muškarci se drže za ruke: srednje svijetla koža',
    '👬🏽' => 'muškarci se drže za ruke: ni svijetla ni tamna koža',
    '👬🏾' => 'muškarci se drže za ruke: srednje tamna koža',
    '👬🏿' => 'muškarci se drže za ruke: tamna koža',
    '💏🏻' => 'poljubac: svijetla koža',
    '💏🏼' => 'poljubac: srednje svijetla koža',
    '💏🏽' => 'poljubac: ni svijetla ni tamna koža',
    '💏🏾' => 'poljubac: srednje tamna koža',
    '💏🏿' => 'poljubac: tamna koža',
    '💑🏻' => 'par sa srcem: svijetla koža',
    '💑🏼' => 'par sa srcem: srednje svijetla koža',
    '💑🏽' => 'par sa srcem: ni svijetla ni tamna koža',
    '💑🏾' => 'par sa srcem: srednje tamna koža',
    '💑🏿' => 'par sa srcem: tamna koža',
    '🇦🇨' => 'zastava: ostrvo Asension',
    '🇦🇩' => 'zastava: Andora',
    '🇦🇪' => 'zastava: Ujedinjeni Arapski Emirati',
    '🇦🇫' => 'zastava: Avganistan',
    '🇦🇬' => 'zastava: Antigva i Barbuda',
    '🇦🇮' => 'zastava: Angvila',
    '🇦🇱' => 'zastava: Albanija',
    '🇦🇲' => 'zastava: Jermenija',
    '🇦🇴' => 'zastava: Angola',
    '🇦🇶' => 'zastava: Antarktik',
    '🇦🇷' => 'zastava: Argentina',
    '🇦🇸' => 'zastava: Američka Samoa',
    '🇦🇹' => 'zastava: Austrija',
    '🇦🇺' => 'zastava: Australija',
    '🇦🇼' => 'zastava: Aruba',
    '🇦🇽' => 'zastava: Olandska ostrva',
    '🇦🇿' => 'zastava: Azerbejdžan',
    '🇧🇦' => 'zastava: Bosna i Hercegovina',
    '🇧🇧' => 'zastava: Barbados',
    '🇧🇩' => 'zastava: Bangladeš',
    '🇧🇪' => 'zastava: Belgija',
    '🇧🇫' => 'zastava: Burkina Faso',
    '🇧🇬' => 'zastava: Bugarska',
    '🇧🇭' => 'zastava: Bahrein',
    '🇧🇮' => 'zastava: Burundi',
    '🇧🇯' => 'zastava: Benin',
    '🇧🇱' => 'zastava: Sen Bartelemi',
    '🇧🇲' => 'zastava: Bermudi',
    '🇧🇳' => 'zastava: Bruneji',
    '🇧🇴' => 'zastava: Bolivija',
    '🇧🇶' => 'zastava: Karipska Holandija',
    '🇧🇷' => 'zastava: Brazil',
    '🇧🇸' => 'zastava: Bahami',
    '🇧🇹' => 'zastava: Butan',
    '🇧🇻' => 'zastava: ostrvo Buve',
    '🇧🇼' => 'zastava: Bocvana',
    '🇧🇾' => 'zastava: Bjelorusija',
    '🇧🇿' => 'zastava: Belize',
    '🇨🇦' => 'zastava: Kanada',
    '🇨🇨' => 'zastava: Kokosova (Kiling) ostrva',
    '🇨🇩' => 'zastava: Kongo - Kinšasa',
    '🇨🇫' => 'zastava: Centralnoafrička Republika',
    '🇨🇬' => 'zastava: Kongo - Brazavil',
    '🇨🇭' => 'zastava: Švajcarska',
    '🇨🇮' => 'zastava: Obala Slonovače (Kot d’Ivoar)',
    '🇨🇰' => 'zastava: Kukova Ostrva',
    '🇨🇱' => 'zastava: Čile',
    '🇨🇲' => 'zastava: Kamerun',
    '🇨🇳' => 'zastava: Kina',
    '🇨🇴' => 'zastava: Kolumbija',
    '🇨🇵' => 'zastava: ostrvo Kliperton',
    '🇨🇶' => 'zastava: Sark',
    '🇨🇷' => 'zastava: Kostarika',
    '🇨🇺' => 'zastava: Kuba',
    '🇨🇻' => 'zastava: Zelenortska Ostrva',
    '🇨🇼' => 'zastava: Kurasao',
    '🇨🇽' => 'zastava: Božićno Ostrvo',
    '🇨🇾' => 'zastava: Kipar',
    '🇨🇿' => 'zastava: Češka Republika',
    '🇩🇪' => 'zastava: Njemačka',
    '🇩🇬' => 'zastava: Dijego Garsija',
    '🇩🇯' => 'zastava: Džibuti',
    '🇩🇰' => 'zastava: Danska',
    '🇩🇲' => 'zastava: Dominika',
    '🇩🇴' => 'zastava: Dominikanska Republika',
    '🇩🇿' => 'zastava: Alžir',
    '🇪🇦' => 'zastava: Seuta i Melilja',
    '🇪🇨' => 'zastava: Ekvador',
    '🇪🇪' => 'zastava: Estonija',
    '🇪🇬' => 'zastava: Egipat',
    '🇪🇭' => 'zastava: Zapadna Sahara',
    '🇪🇷' => 'zastava: Eritreja',
    '🇪🇸' => 'zastava: Španija',
    '🇪🇹' => 'zastava: Etiopija',
    '🇪🇺' => 'zastava: Evropska unija',
    '🇫🇮' => 'zastava: Finska',
    '🇫🇯' => 'zastava: Fidži',
    '🇫🇰' => 'zastava: Foklandska ostrva',
    '🇫🇲' => 'zastava: Mikronezija',
    '🇫🇴' => 'zastava: Farska ostrva',
    '🇫🇷' => 'zastava: Francuska',
    '🇬🇦' => 'zastava: Gabon',
    '🇬🇧' => 'zastava: Ujedinjeno Kraljevstvo',
    '🇬🇩' => 'zastava: Grenada',
    '🇬🇪' => 'zastava: Gruzija',
    '🇬🇫' => 'zastava: Francuska Gvajana',
    '🇬🇬' => 'zastava: Gernzi',
    '🇬🇭' => 'zastava: Gana',
    '🇬🇮' => 'zastava: Gibraltar',
    '🇬🇱' => 'zastava: Grenland',
    '🇬🇲' => 'zastava: Gambija',
    '🇬🇳' => 'zastava: Gvineja',
    '🇬🇵' => 'zastava: Gvadelup',
    '🇬🇶' => 'zastava: Ekvatorijalna Gvineja',
    '🇬🇷' => 'zastava: Grčka',
    '🇬🇸' => 'zastava: Južna Džordžija i Južna Sendvička ostrva',
    '🇬🇹' => 'zastava: Gvatemala',
    '🇬🇺' => 'zastava: Gvam',
    '🇬🇼' => 'zastava: Gvineja Bisao',
    '🇬🇾' => 'zastava: Gvajana',
    '🇭🇰' => 'zastava: Hongkong (SAO Kine)',
    '🇭🇲' => 'zastava: ostrvo Herd i ostrva Makdonald',
    '🇭🇳' => 'zastava: Honduras',
    '🇭🇷' => 'zastava: Hrvatska',
    '🇭🇹' => 'zastava: Haiti',
    '🇭🇺' => 'zastava: Mađarska',
    '🇮🇨' => 'zastava: Kanarska Ostrva',
    '🇮🇩' => 'zastava: Indonezija',
    '🇮🇪' => 'zastava: Irska',
    '🇮🇱' => 'zastava: Izrael',
    '🇮🇲' => 'zastava: Ostrvo Man',
    '🇮🇳' => 'zastava: Indija',
    '🇮🇴' => 'zastava: Britanska teritorija Indijskog okeana',
    '🇮🇶' => 'zastava: Irak',
    '🇮🇷' => 'zastava: Iran',
    '🇮🇸' => 'zastava: Island',
    '🇮🇹' => 'zastava: Italija',
    '🇯🇪' => 'zastava: Džerzi',
    '🇯🇲' => 'zastava: Jamajka',
    '🇯🇴' => 'zastava: Jordan',
    '🇯🇵' => 'zastava: Japan',
    '🇰🇪' => 'zastava: Kenija',
    '🇰🇬' => 'zastava: Kirgistan',
    '🇰🇭' => 'zastava: Kambodža',
    '🇰🇮' => 'zastava: Kiribati',
    '🇰🇲' => 'zastava: Komori',
    '🇰🇳' => 'zastava: Sent Kits i Nevis',
    '🇰🇵' => 'zastava: Sjeverna Koreja',
    '🇰🇷' => 'zastava: Južna Koreja',
    '🇰🇼' => 'zastava: Kuvajt',
    '🇰🇾' => 'zastava: Kajmanska Ostrva',
    '🇰🇿' => 'zastava: Kazahstan',
    '🇱🇦' => 'zastava: Laos',
    '🇱🇧' => 'zastava: Liban',
    '🇱🇨' => 'zastava: Sveta Lucija',
    '🇱🇮' => 'zastava: Lihtenštajn',
    '🇱🇰' => 'zastava: Šri Lanka',
    '🇱🇷' => 'zastava: Liberija',
    '🇱🇸' => 'zastava: Lesoto',
    '🇱🇹' => 'zastava: Litvanija',
    '🇱🇺' => 'zastava: Luksemburg',
    '🇱🇻' => 'zastava: Letonija',
    '🇱🇾' => 'zastava: Libija',
    '🇲🇦' => 'zastava: Maroko',
    '🇲🇨' => 'zastava: Monako',
    '🇲🇩' => 'zastava: Moldavija',
    '🇲🇪' => 'zastava: Crna Gora',
    '🇲🇫' => 'zastava: Sveti Martin (Francuska)',
    '🇲🇬' => 'zastava: Madagaskar',
    '🇲🇭' => 'zastava: Maršalska Ostrva',
    '🇲🇰' => 'zastava: Sjeverna Makedonija',
    '🇲🇱' => 'zastava: Mali',
    '🇲🇲' => 'zastava: Mjanmar (Burma)',
    '🇲🇳' => 'zastava: Mongolija',
    '🇲🇴' => 'zastava: SAR Makao (Kina)',
    '🇲🇵' => 'zastava: Sjeverna Marijanska ostrva',
    '🇲🇶' => 'zastava: Martinik',
    '🇲🇷' => 'zastava: Mauritanija',
    '🇲🇸' => 'zastava: Monserat',
    '🇲🇹' => 'zastava: Malta',
    '🇲🇺' => 'zastava: Mauricijus',
    '🇲🇻' => 'zastava: Maldivi',
    '🇲🇼' => 'zastava: Malavi',
    '🇲🇽' => 'zastava: Meksiko',
    '🇲🇾' => 'zastava: Malezija',
    '🇲🇿' => 'zastava: Mozambik',
    '🇳🇦' => 'zastava: Namibija',
    '🇳🇨' => 'zastava: Nova Kaledonija',
    '🇳🇪' => 'zastava: Niger',
    '🇳🇫' => 'zastava: ostrvo Norfok',
    '🇳🇬' => 'zastava: Nigerija',
    '🇳🇮' => 'zastava: Nikaragva',
    '🇳🇱' => 'zastava: Holandija',
    '🇳🇴' => 'zastava: Norveška',
    '🇳🇵' => 'zastava: Nepal',
    '🇳🇷' => 'zastava: Nauru',
    '🇳🇺' => 'zastava: Nijue',
    '🇳🇿' => 'zastava: Novi Zeland',
    '🇴🇲' => 'zastava: Oman',
    '🇵🇦' => 'zastava: Panama',
    '🇵🇪' => 'zastava: Peru',
    '🇵🇫' => 'zastava: Francuska Polinezija',
    '🇵🇬' => 'zastava: Papua Nova Gvineja',
    '🇵🇭' => 'zastava: Filipini',
    '🇵🇰' => 'zastava: Pakistan',
    '🇵🇱' => 'zastava: Poljska',
    '🇵🇲' => 'zastava: Sen Pjer i Mikelon',
    '🇵🇳' => 'zastava: Pitkern',
    '🇵🇷' => 'zastava: Portoriko',
    '🇵🇸' => 'zastava: palestinske teritorije',
    '🇵🇹' => 'zastava: Portugalija',
    '🇵🇼' => 'zastava: Palau',
    '🇵🇾' => 'zastava: Paragvaj',
    '🇶🇦' => 'zastava: Katar',
    '🇷🇪' => 'zastava: Reunion',
    '🇷🇴' => 'zastava: Rumunija',
    '🇷🇸' => 'zastava: Srbija',
    '🇷🇺' => 'zastava: Rusija',
    '🇷🇼' => 'zastava: Ruanda',
    '🇸🇦' => 'zastava: Saudijska Arabija',
    '🇸🇧' => 'zastava: Solomonska Ostrva',
    '🇸🇨' => 'zastava: Sejšeli',
    '🇸🇩' => 'zastava: Sudan',
    '🇸🇪' => 'zastava: Švedska',
    '🇸🇬' => 'zastava: Singapur',
    '🇸🇭' => 'zastava: Sveta Jelena',
    '🇸🇮' => 'zastava: Slovenija',
    '🇸🇯' => 'zastava: Svalbard i Jan Majen',
    '🇸🇰' => 'zastava: Slovačka',
    '🇸🇱' => 'zastava: Sijera Leone',
    '🇸🇲' => 'zastava: San Marino',
    '🇸🇳' => 'zastava: Senegal',
    '🇸🇴' => 'zastava: Somalija',
    '🇸🇷' => 'zastava: Surinam',
    '🇸🇸' => 'zastava: Južni Sudan',
    '🇸🇹' => 'zastava: Sao Tome i Principe',
    '🇸🇻' => 'zastava: Salvador',
    '🇸🇽' => 'zastava: Sveti Martin (Holandija)',
    '🇸🇾' => 'zastava: Sirija',
    '🇸🇿' => 'zastava: Svazilend',
    '🇹🇦' => 'zastava: Tristan da Kunja',
    '🇹🇨' => 'zastava: Ostrva Turks i Kaikos',
    '🇹🇩' => 'zastava: Čad',
    '🇹🇫' => 'zastava: Francuske južne teritorije',
    '🇹🇬' => 'zastava: Togo',
    '🇹🇭' => 'zastava: Tajland',
    '🇹🇯' => 'zastava: Tadžikistan',
    '🇹🇰' => 'zastava: Tokelau',
    '🇹🇱' => 'zastava: Timor-Leste (Istočni Timor)',
    '🇹🇲' => 'zastava: Turkmenistan',
    '🇹🇳' => 'zastava: Tunis',
    '🇹🇴' => 'zastava: Tonga',
    '🇹🇷' => 'zastava: Turska',
    '🇹🇹' => 'zastava: Trinidad i Tobago',
    '🇹🇻' => 'zastava: Tuvalu',
    '🇹🇼' => 'zastava: Tajvan',
    '🇹🇿' => 'zastava: Tanzanija',
    '🇺🇦' => 'zastava: Ukrajina',
    '🇺🇬' => 'zastava: Uganda',
    '🇺🇲' => 'zastava: Spoljna ostrva SAD',
    '🇺🇳' => 'zastava: Ujedinjene nacije',
    '🇺🇸' => 'zastava: Sjedinjene Države',
    '🇺🇾' => 'zastava: Urugvaj',
    '🇺🇿' => 'zastava: Uzbekistan',
    '🇻🇦' => 'zastava: Vatikan',
    '🇻🇨' => 'zastava: Sveti Vinsent i Grenadini',
    '🇻🇪' => 'zastava: Venecuela',
    '🇻🇬' => 'zastava: Britanska Djevičanska ostrva',
    '🇻🇮' => 'zastava: Američka Djevičanska ostrva',
    '🇻🇳' => 'zastava: Vijetnam',
    '🇻🇺' => 'zastava: Vanuatu',
    '🇼🇫' => 'zastava: Valis i Futuna',
    '🇼🇸' => 'zastava: Samoa',
    '🇽🇰' => 'zastava: Kosovo',
    '🇾🇪' => 'zastava: Jemen',
    '🇾🇹' => 'zastava: Majot',
    '🇿🇦' => 'zastava: Južnoafrička Republika',
    '🇿🇲' => 'zastava: Zambija',
    '🇿🇼' => 'zastava: Zimbabve',
    '🔟' => 'taster: 10',
    '🏻' => 'svijetla koža',
    '🏼' => 'srednje svijetla koža',
    '🏽' => 'ni svijetla ni tamna koža',
    '🏾' => 'srednje tamna koža',
    '🏿' => 'tamna koža',
    '😀' => 'lice sa širokim osmijehom',
    '😃' => 'lice sa oduševljenim osmijehom',
    '😄' => 'lice koje se slatko smije',
    '😁' => 'lice sa kezom',
    '😆' => 'lice sa zločestim osmijehom',
    '😅' => 'lice sa nervoznim osmijehom',
    '🤣' => 'valjanje od smijeha',
    '😂' => 'lice sa suzama radosnicama',
    '🙂' => 'blago nasmijano lice',
    '🙃' => 'lice okrenuto naopako',
    '🫠' => 'lice se topi',
    '😉' => 'lice koje namiguje',
    '😊' => 'nasmijano lice sa nasmijanim očima',
    '😇' => 'nasmijano lice sa oreolom',
    '🥰' => 'smajli sa srcima',
    '😍' => 'nasmijano lice sa očima u obliku srca',
    '🤩' => 'pod srećnom zvijezdom',
    '😘' => 'lice koje šalje poljubac',
    '😗' => 'lice koje ljubi',
    '☺' => 'nasmijano lice',
    '😚' => 'lice koje ljubi sa zatvorenim očima',
    '😙' => 'lice koje ljubi sa nasmijanim očima',
    '🥲' => 'nasmijano lice sa suzom',
    '😋' => 'lice koje uživa u ukusnoj hrani',
    '😛' => 'lice koje se plazi',
    '😜' => 'lice koje se plazi i namiguje',
    '🤪' => 'ludačko lice',
    '😝' => 'lice koje se plazi sa zatvorenim očima',
    '🤑' => 'pohlepno lice',
    '🤗' => 'lice koje grli',
    '🤭' => 'lice sa rukom preko usta',
    '🫢' => 'lice otvorenih očiju sa rukom preko usta',
    '🫣' => 'gledanje kroz prste',
    '🤫' => 'ućutkujuće lice',
    '🤔' => 'lice koje razmišlja',
    '🫡' => 'lice salutira',
    '🤐' => 'lice sa zapečaćenim ustima',
    '🤨' => 'lice sa uzdignutom obrvom',
    '😐' => 'lice sa neutralnim izrazom',
    '😑' => 'bezizražajno lice',
    '😶' => 'lice bez usta',
    '🫥' => 'lice isprekidanom linijom',
    '😏' => 'lice koje se zlobno smješka',
    '😒' => 'smoreno lice',
    '🙄' => 'lice koje koluta očima',
    '😬' => 'lice sa grimasom',
    '🤥' => 'lažljivac',
    '🫨' => 'drhteće lice',
    '😌' => 'spokojno lice',
    '😔' => 'zamišljeno lice',
    '😪' => 'pospano lice',
    '🤤' => 'lice kojem ide voda na usta',
    '😴' => 'lice koje spava',
    '🫩' => 'lice sa podočnjacima',
    '😷' => 'lice sa medicinskom maskom',
    '🤒' => 'lice sa toplomjerom',
    '🤕' => 'lice sa zavojem na glavi',
    '🤢' => 'lice kojem je muka',
    '🤮' => 'lice povraća',
    '🤧' => 'lice koje kija',
    '🥵' => 'vruće lice',
    '🥶' => 'hladno lice',
    '🥴' => 'pogubljeno lice',
    '😵' => 'lice sa vrtoglavicom',
    '🤯' => 'glava eksplodira',
    '🤠' => 'lice kauboja',
    '🥳' => 'lice na žurci',
    '🥸' => 'prerušeno lice',
    '😎' => 'nasmijano lice sa naočarima za sunce',
    '🤓' => 'štrebersko lice',
    '🧐' => 'lice sa monoklom',
    '😕' => 'zbunjeno lice',
    '🫤' => 'lice sa dijagonalnim ustima',
    '😟' => 'zabrinuto lice',
    '🙁' => 'lice koje se blago mršti',
    '☹' => 'namršteno lice',
    '😮' => 'lice sa otvorenim ustima',
    '😯' => 'iznenađeno lice',
    '😲' => 'zapanjeno lice',
    '😳' => 'zajapureno lice',
    '🫪' => 'iskrivljeno lice',
    '🥺' => 'molećivo lice',
    '🥹' => 'lice zadržava suze',
    '😦' => 'začuđeno lice',
    '😧' => 'izbezumljeno lice',
    '😨' => 'uplašeno lice',
    '😰' => 'lice sa otvorenim ustima, obliveno hladnim znojem',
    '😥' => 'razočarano lice kome je laknulo',
    '😢' => 'lice koje plače',
    '😭' => 'lice koje rida',
    '😱' => 'lice koje vrišti od straha',
    '😖' => 'lice u nedoumici',
    '😣' => 'izmučeno lice',
    '😞' => 'razočarano lice',
    '😓' => 'lice obliveno hladnim znojem',
    '😩' => 'premoreno lice',
    '😫' => 'umorno lice',
    '🥱' => 'lice zijeva',
    '😤' => 'lice kome iz nosa izlazi para',
    '😡' => 'nadureno lice',
    '😠' => 'ljutito lice',
    '🤬' => 'lice sa simbolima na usnama',
    '😈' => 'nasmijano lice sa rogovima',
    '👿' => 'đavolčić',
    '💀' => 'lobanja',
    '☠' => 'lobanja sa ukrštenim kostima',
    '💩' => 'gomila kake',
    '🤡' => 'lice klovna',
    '👹' => 'čudovište',
    '👺' => 'goblin',
    '👻' => 'duh',
    '👽' => 'vanzemaljac',
    '👾' => 'vanzemaljsko čudovište',
    '🤖' => 'robotsko lice',
    '😺' => 'nasmijana mačka sa otvorenim ustima',
    '😸' => 'mačka sa širokim osmijehom i nasmijanim očima',
    '😹' => 'lice mačke sa suzama radosnicama',
    '😻' => 'nasmijana mačka sa očima u obliku srca',
    '😼' => 'mačka sa kiselim osmijehom',
    '😽' => 'mačka koja ljubi sa zatvorenim očima',
    '🙀' => 'uplašena mačka',
    '😿' => 'uplakana mačka',
    '😾' => 'nadurena mačka',
    '🙈' => 'ne vidi zlo',
    '🙉' => 'ne čuje zlo',
    '🙊' => 'ne govori zlo',
    '💌' => 'ljubavno pismo',
    '💘' => 'srce probodeno strijelom',
    '💝' => 'srce sa mašnicom',
    '💖' => 'blistavo srce',
    '💗' => 'srce koje raste',
    '💓' => 'srce koje kuca',
    '💞' => 'srca koja se okreću',
    '💕' => 'dva srca',
    '💟' => 'ukras sa srcem',
    '❣' => 'ukrasni uzvičnik u obliku velikog srca',
    '💔' => 'slomljeno srce',
    '❤' => 'crveno srce',
    '🩷' => 'roze srce',
    '🧡' => 'narandžasto srce',
    '💛' => 'žuto srce',
    '💚' => 'zeleno srce',
    '💙' => 'plavo srce',
    '🩵' => 'svijetloplavo srce',
    '💜' => 'ljubičasto srce',
    '🤎' => 'braon srce',
    '🖤' => 'crno srce',
    '🩶' => 'sivo srce',
    '🤍' => 'bijelo srce',
    '💋' => 'otisak poljupca',
    '💯' => 'sto poena',
    '💢' => 'simbol ljutnje',
    '🫯' => 'oblak tuče',
    '💥' => 'sudar',
    '💫' => 'vrtoglavica',
    '💦' => 'kapljice znoja',
    '💨' => 'bježanje',
    '🕳' => 'rupa',
    '💬' => 'oblačić za govor',
    '🗨' => 'oblačić za govor usmjeren nalijevo',
    '🗯' => 'oblačić za ljutiti govor usmjeren desno',
    '💭' => 'oblačić za misli',
    '💤' => 'spavanje',
    '👋' => 'ruka koja maše',
    '🤚' => 'podignut dlan',
    '🖐' => 'šaka sa raširenim prstima',
    '✋' => 'podignuta ruka',
    '🖖' => 'vulkanski pozdrav',
    '🫱' => 'ruka okrenuta nadesno',
    '🫲' => 'ruka okrenuta nalevo',
    '🫳' => 'dlan okrenut nadole',
    '🫴' => 'dlan okrenut nagore',
    '🫷' => 'ruka gura ulijevo',
    '🫸' => 'ruka gura udesno',
    '👌' => 'znak rukom „u redu“',
    '🤌' => 'skupljeni prsti',
    '🤏' => 'ruka štipa',
    '✌' => 'znak pobjede',
    '🤞' => 'prekršteni prsti',
    '🫰' => 'ruka sa prekrštenim palcem i kažiprstom',
    '🤟' => 'pokret volim te',
    '🤘' => 'znak rogova',
    '🤙' => 'znak rukom za telefon',
    '👈' => 'kažiprst koji pokazuje ulijevo',
    '👉' => 'kažiprst koji pokazuje udesno',
    '👆' => 'kažiprst koji pokazuje nagore otpozadi',
    '🖕' => 'srednji prst',
    '👇' => 'kažiprst koji pokazuje nadolje otpozadi',
    '☝' => 'kažiprst koji pokazuje nagore',
    '🫵' => 'kažiprst koji pokazuje prema gledaocu',
    '👍' => 'palac nagore',
    '👎' => 'palac nadolje',
    '✊' => 'pesnica',
    '👊' => 'usmjerena pesnica',
    '🤛' => 'pesnica ulijevo',
    '🤜' => 'pesnica udesno',
    '👏' => 'ruke koje tapšu',
    '🙌' => 'podignute ruke',
    '🫶' => 'ruke koje prave srce',
    '👐' => 'rasklopljene šake',
    '🤲' => 'dlanovi nagore zajedno',
    '🤝' => 'rukovanje',
    '🙏' => 'spojeni dlanovi',
    '✍' => 'ruka koja piše',
    '💅' => 'lak za nokte',
    '🤳' => 'selfi',
    '💪' => 'stegnuti biceps',
    '🦾' => 'mehanička ruka',
    '🦿' => 'mehanička noga',
    '🦵' => 'noga',
    '🦶' => 'stopalo',
    '👂' => 'uvo',
    '🦻' => 'uvo sa slušnim aparatom',
    '👃' => 'nos',
    '🧠' => 'mozak',
    '🫀' => 'anatomsko srce',
    '🫁' => 'pluća',
    '🦷' => 'zub',
    '🦴' => 'kost',
    '👀' => 'oči',
    '👁' => 'oko',
    '👅' => 'jezik',
    '👄' => 'usta',
    '🫦' => 'ugriz usne',
    '👶' => 'beba',
    '🧒' => 'dijete',
    '👦' => 'dječak',
    '👧' => 'djevojčica',
    '🧑' => 'odrasla osoba',
    '👱' => 'osoba sa plavom kosom',
    '👨' => 'muškarac',
    '🧔' => 'osoba sa bradom',
    '👩' => 'žena',
    '🧓' => 'starija odrasla osoba',
    '👴' => 'starac',
    '👵' => 'starica',
    '🙍' => 'namrštena osoba',
    '🙎' => 'nadurena osoba',
    '🙅' => 'osoba koja pokazuje „ne“',
    '🙆' => 'osoba koja pokazuje „u redu“',
    '💁' => 'osoba koja daje informacije',
    '🙋' => 'srećna osoba sa podignutom rukom',
    '🧏' => 'gluva osoba',
    '🙇' => 'osoba koja se klanja',
    '🤦' => 'šaka o čelo',
    '🤷' => 'slijeganje ramenima',
    '👮' => 'predstavnik policije',
    '🕵' => 'inspektor',
    '💂' => 'čuvar',
    '🥷' => 'nindža',
    '👷' => 'građevinski radnik',
    '🫅' => 'osoba sa krunom',
    '🤴' => 'princ',
    '👸' => 'princeza',
    '👳' => 'osoba sa turbanom',
    '👲' => 'čovjek sa kineskom kapom',
    '🧕' => 'žena sa maramom na glavi',
    '🤵' => 'čovjek u smokingu',
    '👰' => 'nevjesta sa velom',
    '🤰' => 'trudnica',
    '🫃' => 'trudni muškarac',
    '🫄' => 'trudna osoba',
    '🤱' => 'dojenje',
    '👼' => 'beba anđeo',
    '🎅' => 'Djed Mraz',
    '🤶' => 'baka Mraz',
    '🦸' => 'superheroj',
    '🦹' => 'negativac',
    '🧙' => 'mag',
    '🧚' => 'vila',
    '🧛' => 'vampir',
    '🧜' => 'osoba iz mora',
    '🧝' => 'vilovnjak',
    '🧞' => 'dobri duh',
    '🧟' => 'zombi',
    '🧌' => 'trol',
    '🫈' => 'dlakavo stvorenje',
    '💆' => 'masaža lica',
    '💇' => 'šišanje',
    '🚶' => 'pješak',
    '🧍' => 'osoba stoji',
    '🧎' => 'osoba kleči',
    '🏃' => 'trkač',
    '💃' => 'plesačica',
    '🕺' => 'plesač',
    '🕴' => 'muškarac u poslovnom odijelu koji lebdi',
    '👯' => 'osobe u provodu',
    '🧖' => 'osoba u parnom kupatilu',
    '🧗' => 'penjanje',
    '🤺' => 'mačevalac',
    '🏇' => 'trke konja',
    '⛷' => 'skijaš',
    '🏂' => 'vozač snouborda',
    '🏌' => 'osoba igra golf',
    '🏄' => 'osoba surfuje',
    '🚣' => 'čamac na vesla',
    '🏊' => 'osoba pliva',
    '⛹' => 'osoba sa loptom',
    '🏋' => 'osoba diže tegove',
    '🚴' => 'osoba na biciklu',
    '🚵' => 'osoba na brdskom biciklu',
    '🤸' => 'gimnastičarska zvezda',
    '🤼' => 'rvanje',
    '🤽' => 'vaterpolo',
    '🤾' => 'rukomet',
    '🤹' => 'osoba žonglira',
    '🧘' => 'lotos poza',
    '🛀' => 'osoba koja se kupa',
    '🛌' => 'osoba u krevetu',
    '👭' => 'žene se drže za ruke',
    '👫' => 'žena i muškarac se drže za ruke',
    '👬' => 'muškarci se drže za ruke',
    '💏' => 'poljubac',
    '💑' => 'par sa srcem',
    '🗣' => 'glava koja govori',
    '👤' => 'silueta čovjeka',
    '👥' => 'siluete ljudi',
    '🫂' => 'ljudi se grle',
    '👪' => 'porodica',
    '👣' => 'otisci stopala',
    '🫆' => 'otisak prsta',
    '🦰' => 'crvena kosa',
    '🦱' => 'kovrdžava kosa',
    '🦳' => 'sijeda kosa',
    '🦲' => 'ćelav',
    '🐵' => 'lice majmuna',
    '🐒' => 'majmun',
    '🦍' => 'gorila',
    '🦧' => 'orangutan',
    '🐶' => 'lice psa',
    '🐕' => 'pas',
    '🦮' => 'pas vodič',
    '🐩' => 'pudla',
    '🐺' => 'vuk',
    '🦊' => 'lisica',
    '🦝' => 'rakun',
    '🐱' => 'lice mačke',
    '🐈' => 'mačka',
    '🦁' => 'lav',
    '🐯' => 'lice tigra',
    '🐅' => 'tigar',
    '🐆' => 'leopard',
    '🐴' => 'lice konja',
    '🫎' => 'los',
    '🫏' => 'magarac',
    '🐎' => 'konj',
    '🦄' => 'lice jednoroga',
    '🦓' => 'zebra',
    '🦌' => 'jelen',
    '🦬' => 'bizon',
    '🐮' => 'lice krave',
    '🐂' => 'vo',
    '🐃' => 'vodeni bivo',
    '🐄' => 'krava',
    '🐷' => 'lice svinje',
    '🐖' => 'svinja',
    '🐗' => 'vepar',
    '🐽' => 'svinjska njuška',
    '🐏' => 'ovan',
    '🐑' => 'ovca',
    '🐐' => 'koza',
    '🐪' => 'kamila',
    '🐫' => 'dvogrba kamila',
    '🦙' => 'lama',
    '🦒' => 'žirafa',
    '🐘' => 'slon',
    '🦣' => 'mamut',
    '🦏' => 'nosorog',
    '🦛' => 'nilski konj',
    '🐭' => 'lice miša',
    '🐁' => 'miš',
    '🐀' => 'pacov',
    '🐹' => 'hrčak',
    '🐰' => 'lice zeca',
    '🐇' => 'zec',
    '🐿' => 'vjeverica',
    '🦫' => 'dabar',
    '🦔' => 'jež',
    '🦇' => 'šišmiš',
    '🐻' => 'medvjed',
    '🐨' => 'koala',
    '🐼' => 'panda',
    '🦥' => 'ljenjivac',
    '🦦' => 'vidra',
    '🦨' => 'tvor',
    '🦘' => 'kengur',
    '🦡' => 'jazavac',
    '🐾' => 'otisci šapa',
    '🦃' => 'ćurka',
    '🐔' => 'kokoška',
    '🐓' => 'pijevac',
    '🐣' => 'pile u jajetu',
    '🐤' => 'pile',
    '🐥' => 'pile sprijeda',
    '🐦' => 'ptica',
    '🐧' => 'pingvin',
    '🕊' => 'golubica',
    '🦅' => 'orao',
    '🦆' => 'patka',
    '🦢' => 'labud',
    '🦉' => 'sova',
    '🦤' => 'dodo',
    '🪶' => 'pero',
    '🦩' => 'flamingo',
    '🦚' => 'paun',
    '🦜' => 'papagaj',
    '🪽' => 'krilo',
    '🪿' => 'guska',
    '🐸' => 'žaba',
    '🐊' => 'krokodil',
    '🐢' => 'kornjača',
    '🦎' => 'gušter',
    '🐍' => 'zmija',
    '🐲' => 'lice zmaja',
    '🐉' => 'zmaj',
    '🦕' => 'sauropod',
    '🦖' => 'tiranosaurus reks',
    '🐳' => 'kit koji prska',
    '🐋' => 'kit',
    '🐬' => 'delfin',
    '🫍' => 'orka',
    '🦭' => 'foka',
    '🐟' => 'riba',
    '🐠' => 'tropska riba',
    '🐡' => 'naduvana riba',
    '🦈' => 'ajkula',
    '🐙' => 'oktopod',
    '🐚' => 'spiralna školjka',
    '🪸' => 'koral',
    '🪼' => 'meduza',
    '🦀' => 'kraba',
    '🦞' => 'jastog',
    '🦐' => 'račić',
    '🦑' => 'hobotnica',
    '🦪' => 'ostriga',
    '🐌' => 'puž',
    '🦋' => 'leptir',
    '🐛' => 'gusjenica',
    '🐜' => 'mrav',
    '🐝' => 'pčela',
    '🪲' => 'buba',
    '🐞' => 'bubamara',
    '🦗' => 'zrikavac',
    '🪳' => 'bubašvaba',
    '🕷' => 'pauk',
    '🕸' => 'paukova mreža',
    '🦂' => 'škorpion',
    '🦟' => 'komarac',
    '🪰' => 'muva',
    '🪱' => 'crv',
    '🦠' => 'mikrob',
    '💐' => 'buket',
    '🌸' => 'cvijet trešnje',
    '💮' => 'bijeli cvijet',
    '🪷' => 'lotus',
    '🏵' => 'rozeta',
    '🌹' => 'ruža',
    '🥀' => 'uveli cvijet',
    '🌺' => 'hibiskus',
    '🌻' => 'suncokret',
    '🌼' => 'cvijet',
    '🌷' => 'lala',
    '🪻' => 'zumbul',
    '🌱' => 'mladica',
    '🪴' => 'biljka u saksiji',
    '🌲' => 'četinar',
    '🌳' => 'listopadno drvo',
    '🌴' => 'palma',
    '🌵' => 'kaktus',
    '🌾' => 'snop riže',
    '🌿' => 'biljka',
    '☘' => 'djetelina',
    '🍀' => 'djetelina sa četiri lista',
    '🍁' => 'javorov list',
    '🍂' => 'opali list',
    '🍃' => 'list koji leprša na vjetru',
    '🪹' => 'prazno gnijezdo',
    '🪺' => 'gnijezdo s jajima',
    '🍄' => 'pečurka',
    '🪾' => 'drvo bez lišća',
    '🍇' => 'grožđe',
    '🍈' => 'dinja',
    '🍉' => 'lubenica',
    '🍊' => 'mandarina',
    '🍋' => 'limun',
    '🍌' => 'banana',
    '🍍' => 'ananas',
    '🥭' => 'mango',
    '🍎' => 'crvena jabuka',
    '🍏' => 'zelena jabuka',
    '🍐' => 'kruška',
    '🍑' => 'breskva',
    '🍒' => 'trešnje',
    '🍓' => 'jagoda',
    '🫐' => 'borovnice',
    '🥝' => 'kivi',
    '🍅' => 'paradajz',
    '🫒' => 'maslina',
    '🥥' => 'kokos',
    '🥑' => 'avokado',
    '🍆' => 'patlidžan',
    '🥔' => 'krompir',
    '🥕' => 'mrkva',
    '🌽' => 'klip kukuruza',
    '🌶' => 'ljuta papričica',
    '🫑' => 'babura',
    '🥒' => 'krastavac',
    '🥬' => 'lisnato zeleno povrće',
    '🥦' => 'brokoli',
    '🧄' => 'bijeli luk',
    '🧅' => 'crni luk',
    '🥜' => 'kikiriki',
    '🫘' => 'pasulj',
    '🌰' => 'kesten',
    '🫚' => 'korijen đumbira',
    '🫛' => 'mahuna graška',
    '🫜' => 'korjenasto povrće',
    '🍞' => 'hljeb',
    '🥐' => 'kroasan',
    '🥖' => 'baget',
    '🫓' => 'pljosnat hljeb',
    '🥨' => 'pereca',
    '🥯' => 'bejgl',
    '🥞' => 'palačinke',
    '🧇' => 'vafl',
    '🧀' => 'kriška sira',
    '🍖' => 'meso sa koskom',
    '🍗' => 'batak',
    '🥩' => 'parče mesa',
    '🥓' => 'slanina',
    '🍔' => 'hamburger',
    '🍟' => 'pomfrit',
    '🍕' => 'pica',
    '🌭' => 'hot-dog',
    '🥪' => 'sendvič',
    '🌮' => 'tako',
    '🌯' => 'burito',
    '🫔' => 'tamale',
    '🥙' => 'giros',
    '🧆' => 'falafel',
    '🥚' => 'jaje',
    '🍳' => 'jaje u tiganju',
    '🥘' => 'tiganj hrane',
    '🍲' => 'činija hrane',
    '🫕' => 'fondu',
    '🥣' => 'činija sa kašikom',
    '🥗' => 'zelena salata',
    '🍿' => 'kokice',
    '🧈' => 'puter',
    '🧂' => 'so',
    '🥫' => 'konzervirana hrana',
    '🍱' => 'kutija sa ručkom',
    '🍘' => 'kreker od riže',
    '🍙' => 'kuglica od riže',
    '🍚' => 'kuvana riža',
    '🍛' => 'riža sa karijem',
    '🍜' => 'vruća činija',
    '🍝' => 'špagete',
    '🍠' => 'pečeni slatki krompir',
    '🍢' => 'oden',
    '🍣' => 'suši',
    '🍤' => 'prženi škampi',
    '🍥' => 'riblja pljeskavica sa spiralom',
    '🥮' => 'mjesečev kolač',
    '🍡' => 'dango',
    '🥟' => 'knedla',
    '🥠' => 'kolačić sudbine',
    '🥡' => 'kutija za hranu',
    '🍦' => 'sladoled u kornetu',
    '🍧' => 'sorbe',
    '🍨' => 'sladoled',
    '🍩' => 'krofna',
    '🍪' => 'kolačić',
    '🎂' => 'rođendanska torta',
    '🍰' => 'parče torte',
    '🧁' => 'kapkejk',
    '🥧' => 'pita',
    '🍫' => 'čokoladica',
    '🍬' => 'bombona',
    '🍭' => 'lizalica',
    '🍮' => 'krempita',
    '🍯' => 'ćup sa medom',
    '🍼' => 'flašica za bebe',
    '🥛' => 'čaša mlijeka',
    '☕' => 'topli napitak',
    '🫖' => 'čajnik',
    '🍵' => 'šoljica bez drške',
    '🍶' => 'sake',
    '🍾' => 'boca iz koje izlijeće čep',
    '🍷' => 'čaša vina',
    '🍸' => 'koktel',
    '🍹' => 'tropsko piće',
    '🍺' => 'krigla piva',
    '🍻' => 'krigle piva koje se kucaju',
    '🥂' => 'čaše nazdravljaju',
    '🥃' => 'čaša za žestinu',
    '🫗' => 'sipanje tečnosti',
    '🥤' => 'čaša sa slamčicom',
    '🧋' => 'čaj sa bobicama',
    '🧃' => 'piće u tetrapaku',
    '🧉' => 'mate',
    '🧊' => 'kocka leda',
    '🥢' => 'štapići',
    '🍽' => 'viljuška i nož sa tanjirom',
    '🍴' => 'viljuška i nož',
    '🥄' => 'kašika',
    '🔪' => 'kuhinjski nož',
    '🫙' => 'tegla',
    '🏺' => 'amfora',
    '🌍' => 'globus sa Evropom i Afrikom',
    '🌎' => 'globus sa Amerikom',
    '🌏' => 'globus sa Azijom i Australijom',
    '🌐' => 'globus sa meridijanima',
    '🗺' => 'mapa svijeta',
    '🗾' => 'mapa Japana',
    '🧭' => 'kompas',
    '🏔' => 'snježni vrh planine',
    '⛰' => 'planina',
    '🛘' => 'odron',
    '🌋' => 'vulkan',
    '🗻' => 'planina fudži',
    '🏕' => 'kampovanje',
    '🏖' => 'plaža sa suncobranom',
    '🏜' => 'pustinja',
    '🏝' => 'pusto ostrvo',
    '🏞' => 'nacionalni park',
    '🏟' => 'stadion',
    '🏛' => 'antička građevina',
    '🏗' => 'gradilište',
    '🧱' => 'cigla',
    '🪨' => 'kamen',
    '🪵' => 'drvo',
    '🛖' => 'koliba',
    '🏘' => 'kuće',
    '🏚' => 'zapuštena kuća',
    '🏠' => 'kuća',
    '🏡' => 'kuća sa baštom',
    '🏢' => 'poslovna zgrada',
    '🏣' => 'japanska pošta',
    '🏤' => 'pošta',
    '🏥' => 'bolnica',
    '🏦' => 'banka',
    '🏨' => 'hotel',
    '🏩' => 'ljubavni hotel',
    '🏪' => 'prodavnica mješovite robe',
    '🏫' => 'škola',
    '🏬' => 'robna kuća',
    '🏭' => 'fabrika',
    '🏯' => 'japanski dvorac',
    '🏰' => 'dvorac',
    '💒' => 'vjenčanje',
    '🗼' => 'tokijski toranj',
    '🗽' => 'kip slobode',
    '⛪' => 'crkva',
    '🕌' => 'džamija',
    '🛕' => 'hindu hram',
    '🕍' => 'sinagoga',
    '⛩' => 'šintoistički hram',
    '🕋' => 'kaba',
    '⛲' => 'fontana',
    '⛺' => 'šator',
    '🌁' => 'maglovito',
    '🌃' => 'zvjezdana noć',
    '🏙' => 'gradski pejzaž',
    '🌄' => 'izlazak sunca iznad planina',
    '🌅' => 'izlazak sunca',
    '🌆' => 'grad u sumrak',
    '🌇' => 'zalazak sunca',
    '🌉' => 'most noću',
    '♨' => 'termalni izvori',
    '🎠' => 'konj sa vrteške',
    '🛝' => 'tobogan',
    '🎡' => 'panoramska vrteška',
    '🎢' => 'rolerkoster',
    '💈' => 'znak za berbernicu',
    '🎪' => 'cirkuski šator',
    '🚂' => 'lokomotiva',
    '🚃' => 'vagon',
    '🚄' => 'brzi voz',
    '🚅' => 'brzi voz sa zaobljenim vrhom',
    '🚆' => 'voz',
    '🚇' => 'metro',
    '🚈' => 'gradska željeznica',
    '🚉' => 'stanica',
    '🚊' => 'tramvaj',
    '🚝' => 'monorejl',
    '🚞' => 'planinska željeznica',
    '🚋' => 'vagon tramvaja',
    '🚌' => 'autobus',
    '🚍' => 'autobus sprijeda',
    '🚎' => 'trolejbus',
    '🚐' => 'minibus',
    '🚑' => 'hitna pomoć',
    '🚒' => 'vatrogasni kamion',
    '🚓' => 'policijski automobil',
    '🚔' => 'policijski automobil sprijeda',
    '🚕' => 'taksi',
    '🚖' => 'taksi spreda',
    '🚗' => 'automobil',
    '🚘' => 'automobil sprijeda',
    '🚙' => 'kamp-vozilo',
    '🛻' => 'pikap vozilo',
    '🚚' => 'teretni kamion',
    '🚛' => 'kamion sa prikolicom',
    '🚜' => 'traktor',
    '🏎' => 'trkački automobil',
    '🏍' => 'motocikl',
    '🛵' => 'skuter',
    '🦽' => 'kolica na ručni pogon',
    '🦼' => 'motorna kolica',
    '🛺' => 'auto-rikša',
    '🚲' => 'bicikl',
    '🛴' => 'trotinet',
    '🛹' => 'skejtbord',
    '🛼' => 'rolšua',
    '🚏' => 'autobuska stanica',
    '🛣' => 'auto-put',
    '🛤' => 'željeznička pruga',
    '🛢' => 'bure nafte',
    '⛽' => 'pumpa za gorivo',
    '🛞' => 'točak',
    '🚨' => 'policijska rotacija',
    '🚥' => 'horizontalni semafor',
    '🚦' => 'vertikalni semafor',
    '🛑' => 'znak stop',
    '🚧' => 'radovi u toku',
    '⚓' => 'sidro',
    '🛟' => 'pojas za spasavanje',
    '⛵' => 'jedrenjak',
    '🛶' => 'kanu',
    '🚤' => 'gliser',
    '🛳' => 'putnički brod',
    '⛴' => 'trajekt',
    '🛥' => 'jahta',
    '🚢' => 'brod',
    '✈' => 'avion',
    '🛩' => 'mali avion',
    '🛫' => 'polijetanje aviona',
    '🛬' => 'slijetanje aviona',
    '🪂' => 'padobran',
    '💺' => 'sjedište',
    '🚁' => 'helikopter',
    '🚟' => 'viseća željeznica',
    '🚠' => 'planinska žičara',
    '🚡' => 'viseći tramvaj',
    '🛰' => 'satelit',
    '🚀' => 'raketa',
    '🛸' => 'leteći tanjir',
    '🛎' => 'zvono na recepciji',
    '🧳' => 'prtljag',
    '⌛' => 'pješčani sat',
    '⏳' => 'pješčani sat sa pijeskom koji teče',
    '⌚' => 'sat',
    '⏰' => 'budilnik',
    '⏱' => 'štoperica',
    '⏲' => 'tajmer',
    '🕰' => 'stoni sat',
    '🕛' => 'dvanaest sati',
    '🕧' => 'pola jedan',
    '🕐' => 'jedan sat',
    '🕜' => 'pola dva',
    '🕑' => 'dva sata',
    '🕝' => 'pola tri',
    '🕒' => 'tri sata',
    '🕞' => 'pola četiri',
    '🕓' => 'četiri sata',
    '🕟' => 'pola pet',
    '🕔' => 'pet sati',
    '🕠' => 'pola šest',
    '🕕' => 'šest sati',
    '🕡' => 'pola sedam',
    '🕖' => 'sedam sati',
    '🕢' => 'pola osam',
    '🕗' => 'osam sati',
    '🕣' => 'pola devet',
    '🕘' => 'devet sati',
    '🕤' => 'pola deset',
    '🕙' => 'deset sati',
    '🕥' => 'pola jedanaest',
    '🕚' => 'jedanaest sati',
    '🕦' => 'pola dvanaest',
    '🌑' => 'mlad mjesec',
    '🌒' => 'mjesečev srp u porastu',
    '🌓' => 'mjesec u prvoj četvrti',
    '🌔' => 'skoro pa pun mjesec',
    '🌕' => 'pun mjesec',
    '🌖' => 'mjesec poslije punog mjeseca',
    '🌗' => 'mjesec u posljednjoj četvrti',
    '🌘' => 'mjesečev srp u opadanju',
    '🌙' => 'mjesečev srp',
    '🌚' => 'mlad mjesec sa licem',
    '🌛' => 'mjesec u prvoj četvrti sa licem',
    '🌜' => 'mjesec u posljednjoj četvrti sa licem',
    '🌡' => 'termometar',
    '☀' => 'sunce',
    '🌝' => 'pun mjesec sa licem',
    '🌞' => 'sunce sa licem',
    '🪐' => 'planeta sa prstenom',
    '⭐' => 'zvijezda',
    '🌟' => 'zvijezda koja svijetli',
    '🌠' => 'zvijezda padalica',
    '🌌' => 'mliječni put',
    '☁' => 'oblak',
    '⛅' => 'sunce iza oblaka',
    '⛈' => 'oblak sa munjom i kišom',
    '🌤' => 'sunce iza malog oblaka',
    '🌥' => 'sunce iza velikog oblaka',
    '🌦' => 'sunce iza kišnog oblaka',
    '🌧' => 'oblak sa kišom',
    '🌨' => 'oblak sa snijegom',
    '🌩' => 'oblak sa munjom',
    '🌪' => 'tornado',
    '🌫' => 'magla',
    '🌬' => 'lice vjetra',
    '🌀' => 'ciklon',
    '🌈' => 'duga',
    '🌂' => 'zatvoreni kišobran',
    '☂' => 'kišobran',
    '☔' => 'kišobran sa kapima kiše',
    '⛱' => 'suncobran na zemlji',
    '⚡' => 'visok napon',
    '❄' => 'pahulja',
    '☃' => 'snješko bijelić',
    '⛄' => 'snješko bijelić bez snijega',
    '☄' => 'kometa',
    '🔥' => 'vatra',
    '💧' => 'kapljica',
    '🌊' => 'talas',
    '🎃' => 'svjetiljka od bundeve',
    '🎄' => 'božićna jelka',
    '🎆' => 'vatromet',
    '🎇' => 'prskalica',
    '🧨' => 'petarda',
    '✨' => 'iskre',
    '🎈' => 'balon',
    '🎉' => 'konfete u tubi',
    '🎊' => 'konfete u lopti',
    '🎋' => 'drvo tanabata',
    '🎍' => 'dekoracija borovima',
    '🎎' => 'japanske lutke',
    '🎏' => 'vjetrokaz u obliku šarana',
    '🎐' => 'eolska zvona',
    '🎑' => 'ceremonija u čast mjeseca',
    '🧧' => 'crvena koverta',
    '🎀' => 'mašnica',
    '🎁' => 'upakovan poklon',
    '🎗' => 'spomen-traka',
    '🎟' => 'ulaznice',
    '🎫' => 'karta',
    '🎖' => 'orden',
    '🏆' => 'pehar',
    '🏅' => 'sportska medalja',
    '🥇' => 'zlatna medalja',
    '🥈' => 'srebrna medalja',
    '🥉' => 'bronzana medalja',
    '⚽' => 'fudbalska lopta',
    '⚾' => 'loptica za bejzbol',
    '🥎' => 'lopta za softbol',
    '🏀' => 'košarkaška lopta',
    '🏐' => 'lopta za odbojku',
    '🏈' => 'lopta za američki fudbal',
    '🏉' => 'lopta za ragbi',
    '🎾' => 'tenis',
    '🥏' => 'frizbi',
    '🎳' => 'kuglanje',
    '🏏' => 'kriket',
    '🏑' => 'hokej na travi',
    '🏒' => 'štap i pak za hokej',
    '🥍' => 'lakros',
    '🏓' => 'stoni tenis',
    '🏸' => 'badminton',
    '🥊' => 'bokserska rukavica',
    '🥋' => 'borilački kimono',
    '🥅' => 'gol',
    '⛳' => 'zastavica u rupi',
    '⛸' => 'klizaljka',
    '🎣' => 'štap za pecanje',
    '🤿' => 'maska za ronjenje',
    '🎽' => 'majica za trčanje',
    '🎿' => 'skije',
    '🛷' => 'sanke',
    '🥌' => 'kamen za karling',
    '🎯' => 'pogodak u centar',
    '🪀' => 'jojo',
    '🪁' => 'zmaj na vjetar',
    '🔫' => 'vodeni pištolj',
    '🎱' => 'bilijar',
    '🔮' => 'kristalna kugla',
    '🪄' => 'čarobni štapić',
    '🎮' => 'video igra',
    '🕹' => 'džojstik',
    '🎰' => 'slot-mašina',
    '🎲' => 'kockica za igru',
    '🧩' => 'dio slagalice',
    '🧸' => 'medvjedić',
    '🪅' => 'pinjata',
    '🪩' => 'disko kugla',
    '🪆' => 'lutka u lutki',
    '♠' => 'pik',
    '♥' => 'herc',
    '♦' => 'karo',
    '♣' => 'tref',
    '♟' => 'šahovski pješak',
    '🃏' => 'džoker',
    '🀄' => 'crveni zmaj iz madžonga',
    '🎴' => 'karte za igranje sa cvijetom',
    '🎭' => 'scenska umjetnost',
    '🖼' => 'ram sa slikom',
    '🎨' => 'slikarska paleta',
    '🧵' => 'konac',
    '🪡' => 'igla za šivenje',
    '🧶' => 'predivo',
    '🪢' => 'čvor',
    '👓' => 'naočari',
    '🕶' => 'naočari za sunce',
    '🥽' => 'zaštitne naočari',
    '🥼' => 'bijeli mantil',
    '🦺' => 'prsluk za spasavanje',
    '👔' => 'kravata',
    '👕' => 'majica',
    '👖' => 'farmerke',
    '🧣' => 'šal',
    '🧤' => 'rukavice',
    '🧥' => 'kaput',
    '🧦' => 'čarape',
    '👗' => 'haljina',
    '👘' => 'kimono',
    '🥻' => 'sari',
    '🩱' => 'jednodijelni kupaći',
    '🩲' => 'gaće',
    '🩳' => 'šorc',
    '👙' => 'bikini',
    '👚' => 'ženska odjeća',
    '🪭' => 'lepeza',
    '👛' => 'tašnica',
    '👜' => 'tašna',
    '👝' => 'neseser',
    '🛍' => 'torbe za kupovinu',
    '🎒' => 'školski ranac',
    '🩴' => 'japanka',
    '👞' => 'muška cipela',
    '👟' => 'patika',
    '🥾' => 'cipela za planinarenje',
    '🥿' => 'ravna cipela',
    '👠' => 'cipela sa štiklom',
    '👡' => 'ženska sandala',
    '🩰' => 'baletske patike',
    '👢' => 'ženska čizma',
    '🪮' => 'češljić',
    '👑' => 'kruna',
    '👒' => 'ženski šešir',
    '🎩' => 'cilindar',
    '🎓' => 'kapa za diplomce',
    '🧢' => 'kačket',
    '🪖' => 'šljem',
    '⛑' => 'kaciga sa bijelim krstom',
    '📿' => 'brojanica',
    '💄' => 'karmin',
    '💍' => 'prsten',
    '💎' => 'dragulj',
    '🔇' => 'isključen zvučnik',
    '🔈' => 'zvučnik',
    '🔉' => 'uključen zvučnik',
    '🔊' => 'pojačan zvučnik',
    '📢' => 'razglas',
    '📣' => 'megafon',
    '📯' => 'poštanska truba',
    '🔔' => 'zvono',
    '🔕' => 'precrtano zvono',
    '🎼' => 'notni zapis',
    '🎵' => 'nota',
    '🎶' => 'note',
    '🎙' => 'studijski mikrofon',
    '🎚' => 'klizač za podešavanje',
    '🎛' => 'kontrolna dugmad',
    '🎤' => 'mikrofon',
    '🎧' => 'slušalica',
    '📻' => 'radio',
    '🎷' => 'saksofon',
    '🎺' => 'truba',
    '🪊' => 'trombon',
    '🪗' => 'harmonika',
    '🎸' => 'gitara',
    '🎹' => 'klavijatura',
    '🎻' => 'violina',
    '🪕' => 'bendžo',
    '🥁' => 'doboš',
    '🪘' => 'timpan',
    '🪇' => 'maraka',
    '🪈' => 'flauta',
    '🪉' => 'harfa',
    '📱' => 'mobilni telefon',
    '📲' => 'mobilni telefon sa strelicom',
    '☎' => 'telefon',
    '📞' => 'telefonska slušalica',
    '📟' => 'pejdžer',
    '📠' => 'faks',
    '🔋' => 'baterija',
    '🪫' => 'niski nivo baterije',
    '🔌' => 'strujni utikač',
    '💻' => 'laptop računar',
    '🖥' => 'stoni računar',
    '🖨' => 'štampač',
    '⌨' => 'tastatura',
    '🖱' => 'računarski miš',
    '🖲' => 'kuglica za kretanje',
    '💽' => 'mini-disk',
    '💾' => 'disketa',
    '💿' => 'optički disk',
    '📀' => 'dvd',
    '🧮' => 'računaljka',
    '🎥' => 'filmska kamera',
    '🎞' => 'kadrovi filma',
    '📽' => 'filmski projektor',
    '🎬' => 'režiserska klapa',
    '📺' => 'televizija',
    '📷' => 'fotoaparat',
    '📸' => 'fotoaparat sa blicem',
    '📹' => 'video kamera',
    '📼' => 'video kaseta',
    '🔍' => 'lupa usmjerena nalijevo',
    '🔎' => 'lupa usmjerena nadesno',
    '🕯' => 'svijeća',
    '💡' => 'sijalica',
    '🔦' => 'baterijska lampa',
    '🏮' => 'lampion od crvenog papira',
    '🪔' => 'uljana lampa',
    '📔' => 'sveska sa ukrasnim koricama',
    '📕' => 'zatvorena knjiga',
    '📖' => 'otvorena knjiga',
    '📗' => 'zelena knjiga',
    '📘' => 'plava knjiga',
    '📙' => 'narandžasta knjiga',
    '📚' => 'knjige',
    '📓' => 'sveska',
    '📒' => 'bilježnica',
    '📃' => 'stranica sa uvijenom ivicom',
    '📜' => 'svitak',
    '📄' => 'stranica okrenuta nagore',
    '📰' => 'novine',
    '🗞' => 'umotane novine',
    '📑' => 'stranice sa bilješkama',
    '🔖' => 'obilježivač stranica u knjizi',
    '🏷' => 'oznaka',
    '🪙' => 'novčić',
    '💰' => 'vreća novca',
    '🪎' => 'kovčeg s blagom',
    '💴' => 'novčanica sa znakom jena',
    '💵' => 'novčanica sa znakom dolara',
    '💶' => 'novčanica sa znakom evra',
    '💷' => 'novčanica sa znakom funte',
    '💸' => 'novac sa krilima',
    '💳' => 'kreditna kartica',
    '🧾' => 'priznanica',
    '💹' => 'grafikon porasta sa znakom jena',
    '✉' => 'koverta',
    '📧' => 'imejl',
    '📨' => 'koverta koja stiže',
    '📩' => 'koverta sa strelicom',
    '📤' => 'pregrada sa odlaznom poštom',
    '📥' => 'pregrada sa dolaznom poštom',
    '📦' => 'paket',
    '📫' => 'zatvoreno poštansko sanduče sa podignutom zastavom',
    '📪' => 'zatvoreno poštansko sanduče sa spuštenom zastavom',
    '📬' => 'otvoreno poštansko sanduče sa podignutom zastavom',
    '📭' => 'otvoreno poštansko sanduče sa spuštenom zastavom',
    '📮' => 'poštansko sanduče',
    '🗳' => 'glasačka kutija sa listićem',
    '✏' => 'olovka',
    '✒' => 'crno pero',
    '🖋' => 'nalivpero',
    '🖊' => 'hemijska olovka',
    '🖌' => 'slikarska četkica',
    '🖍' => 'voštana bojica',
    '📝' => 'beleška',
    '💼' => 'torba',
    '📁' => 'fascikla',
    '📂' => 'otvorena fascikla',
    '🗂' => 'razdjelnici za katalog kartica',
    '📅' => 'kalendar',
    '📆' => 'kalendar sa odvojivim listovima',
    '🗒' => 'bilježnica sa spiralom',
    '🗓' => 'kalendar sa spiralom',
    '📇' => 'katalog kartica',
    '📈' => 'grafikon sa uzlaznim trendom',
    '📉' => 'grafikon sa opadajućim trendom',
    '📊' => 'trakasti grafikon',
    '📋' => 'klipbord',
    '📌' => 'pribadača',
    '📍' => 'čioda',
    '📎' => 'spajalica',
    '🖇' => 'povezane spajalice',
    '📏' => 'lenjir',
    '📐' => 'trougaoni lenjir',
    '✂' => 'makaze',
    '🗃' => 'kutija sa karticama',
    '🗄' => 'ormar za kartoteku',
    '🗑' => 'korpa za đubre',
    '🔒' => 'katanac',
    '🔓' => 'otvoren katanac',
    '🔏' => 'katanac sa nalivperom',
    '🔐' => 'zatvoren katanac sa ključem',
    '🔑' => 'ključ',
    '🗝' => 'stari ključ',
    '🔨' => 'čekić',
    '🪓' => 'sjekira',
    '⛏' => 'pijuk',
    '⚒' => 'čekić i pijuk',
    '🛠' => 'čekić i francuski ključ',
    '🗡' => 'bodež',
    '⚔' => 'ukršteni mačevi',
    '💣' => 'bomba',
    '🪃' => 'bumerang',
    '🏹' => 'luk i strijela',
    '🛡' => 'štit',
    '🪚' => 'testera',
    '🔧' => 'francuski ključ',
    '🪛' => 'šrafciger',
    '🔩' => 'navrtka i zavrtanj',
    '⚙' => 'zupčanik',
    '🗜' => 'stega',
    '⚖' => 'terazije',
    '🦯' => 'bijeli štap',
    '🔗' => 'karike',
    '⛓' => 'lanci',
    '🪝' => 'kuka',
    '🧰' => 'kutija za alat',
    '🧲' => 'magnet',
    '🪜' => 'merdevine',
    '🪏' => 'lopata',
    '⚗' => 'alembik',
    '🧪' => 'epruveta',
    '🧫' => 'petrijeva šolja',
    '🧬' => 'dnk',
    '🔬' => 'mikroskop',
    '🔭' => 'teleskop',
    '📡' => 'satelitska antena',
    '💉' => 'špric',
    '🩸' => 'kap krvi',
    '💊' => 'pilula',
    '🩹' => 'flaster',
    '🩼' => 'štaka',
    '🩺' => 'stetoskop',
    '🩻' => 'rendgenski zraci',
    '🚪' => 'vrata',
    '🛗' => 'lift',
    '🪞' => 'ogledalo',
    '🪟' => 'prozor',
    '🛏' => 'krevet',
    '🛋' => 'kauč i lampa',
    '🪑' => 'stolica',
    '🚽' => 've-ce šolja',
    '🪠' => 'otpušivač',
    '🚿' => 'tuš',
    '🛁' => 'kada',
    '🪤' => 'mišolovka',
    '🪒' => 'brijač',
    '🧴' => 'boca za losion',
    '🧷' => 'zihernadla',
    '🧹' => 'metla',
    '🧺' => 'korpa',
    '🧻' => 'rolna papira',
    '🪣' => 'kofa',
    '🧼' => 'sapun',
    '🫧' => 'mjehurići',
    '🪥' => 'četkica za zube',
    '🧽' => 'sunđer',
    '🧯' => 'protivpožarni aparat',
    '🛒' => 'kolica za kupovinu',
    '🚬' => 'cigareta',
    '⚰' => 'kovčeg',
    '🪦' => 'nadgrobni spomenik',
    '⚱' => 'posmrtna urna',
    '🧿' => 'nazar',
    '🪬' => 'hamsa',
    '🗿' => 'moai',
    '🪧' => 'plakat',
    '🪪' => 'identifikacijska karta',
    '🏧' => 'znak za bankomat',
    '🚮' => 'bacanje otpada u korpu',
    '🚰' => 'voda za piće',
    '♿' => 'simbol za invalidska kolica',
    '🚹' => 'muški toalet',
    '🚺' => 'ženski toalet',
    '🚻' => 'toalet',
    '🚼' => 'simbol za bebu',
    '🚾' => 've-ce',
    '🛂' => 'kontrola pasoša',
    '🛃' => 'carina',
    '🛄' => 'preuzimanje prtljaga',
    '🛅' => 'ostavljeni prtljag',
    '⚠' => 'upozorenje',
    '🚸' => 'prelaz za djecu',
    '⛔' => 'zabranjen ulaz',
    '🚫' => 'zabranjeno',
    '🚳' => 'zabranjeno za bicikle',
    '🚭' => 'zabranjeno pušenje',
    '🚯' => 'zabranjeno bacanje otpada',
    '🚱' => 'voda nije za piće',
    '🚷' => 'zabranjeno za pješake',
    '📵' => 'zabranjeni mobilni telefoni',
    '🔞' => 'zabranjeno za maloljetne',
    '☢' => 'radioaktivno',
    '☣' => 'opasno po život',
    '⬆' => 'strelica nagore',
    '↗' => 'strelica nagore i nadesno',
    '➡' => 'strelica nadesno',
    '↘' => 'strelica nadolje i nadesno',
    '⬇' => 'strelica nadolje',
    '↙' => 'strelica nadolje i nalijevo',
    '⬅' => 'strelica nalijevo',
    '↖' => 'strelica nagore i nalijevo',
    '↕' => 'strelica nagore i nadolje',
    '↔' => 'strelica nalijevo i nadesno',
    '↩' => 'strelica za polukružni okret udesno',
    '↪' => 'strelica za polukružni okret ulijevo',
    '⤴' => 'strelica koja skreće nagore',
    '⤵' => 'strelica koja skreće nadolje',
    '🔃' => 'strelice koje se vrte udesno',
    '🔄' => 'strelice koje se vrte ulijevo',
    '🔙' => 'strelica za povratak',
    '🔚' => 'strelica za kraj',
    '🔛' => 'strelica za uključeno',
    '🔜' => 'strelica za uskoro',
    '🔝' => 'strelica za vrh',
    '🛐' => 'vjerski objekat',
    '⚛' => 'simbol za atom',
    '🕉' => 'om',
    '✡' => 'davidova zvijezda',
    '☸' => 'darmin točak',
    '☯' => 'jin i jang',
    '✝' => 'latinski krst',
    '☦' => 'pravoslavni krst',
    '☪' => 'zvijezda i polumjesec',
    '☮' => 'simbol mira',
    '🕎' => 'menora',
    '🔯' => 'šestokraka zvijezda sa tačkom',
    '🪯' => 'kanda',
    '♈' => 'ovan u horoskopu',
    '♉' => 'bik u horoskopu',
    '♊' => 'blizanci u horoskopu',
    '♋' => 'rak u horoskopu',
    '♌' => 'lav u horoskopu',
    '♍' => 'djevica u horoskopu',
    '♎' => 'vaga u horoskopu',
    '♏' => 'škorpija u horoskopu',
    '♐' => 'strijelac u horoskopu',
    '♑' => 'jarac u horoskopu',
    '♒' => 'vodolija u horoskopu',
    '♓' => 'ribe u horoskopu',
    '⛎' => 'zmijonoša',
    '🔀' => 'dugme za nasumično puštanje',
    '🔁' => 'dugme za ponavljanje',
    '🔂' => 'dugme za ponavljanje jedne pjesme',
    '▶' => 'dugme za reprodukciju',
    '⏩' => 'dugme za premotavanje unaprijed',
    '⏭' => 'dugme za sljedeću pjesmu',
    '⏯' => 'dugme za reprodukciju ili pauzu',
    '◀' => 'dugme za reprodukciju unazad',
    '⏪' => 'dugme za premotavanje unazad',
    '⏮' => 'dugme za posljednju pjesmu',
    '🔼' => 'dugme za kretanje nagore',
    '⏫' => 'dugme za brzo kretanje nagore',
    '🔽' => 'dugme za kretanje nadolje',
    '⏬' => 'dugme za brzo kretanje nadolje',
    '⏸' => 'dugme za pauzu',
    '⏹' => 'dugme za zaustavljanje',
    '⏺' => 'dugme za snimanje',
    '⏏' => 'dugme za izbacivanje',
    '🎦' => 'bioskop',
    '🔅' => 'dugme za zatamnjivanje',
    '🔆' => 'dugme za povećavanje osvijetljenosti',
    '📶' => 'trake jačine signala',
    '🛜' => 'mobilna mreža',
    '📳' => 'režim vibracije',
    '📴' => 'isključen mobilni telefon',
    '♀' => 'ženski znak',
    '♂' => 'muški znak',
    '⚧' => 'transrodni simbol',
    '✖' => 'crni znak za množenje',
    '➕' => 'crni znak plus',
    '➖' => 'crni znak minus',
    '➗' => 'crni znak za dijeljenje',
    '🟰' => 'podebljani znak jednakosti',
    '♾' => 'beskonačnost',
    '‼' => 'dvostruki uzvičnik',
    '⁉' => 'uzvičnik i upitnik',
    '❓' => 'upitnik',
    '❔' => 'bijeli upitnik',
    '❕' => 'bijeli uzvičnik',
    '❗' => 'uzvičnik',
    '〰' => 'talasasta crta',
    '💱' => 'konverzija valuta',
    '💲' => 'crni znak za dolar',
    '⚕' => 'medicinski znak',
    '♻' => 'simbol za recikliranje',
    '⚜' => 'ljiljan',
    '🔱' => 'amblem trozupca',
    '📛' => 'značka sa imenom',
    '🔰' => 'japanski simbol za početnika',
    '⭕' => 'oks',
    '✅' => 'dugme sa znakom potvrde',
    '☑' => 'opcija sa znakom potvrde',
    '✔' => 'crni znak potvrde',
    '❌' => 'iks',
    '❎' => 'dugme sa znakom iks',
    '➰' => 'petlja',
    '➿' => 'dvostruka petlja',
    '〽' => 'znak za razdvajanje dijelova',
    '✳' => 'osmokraka zvijezda',
    '✴' => 'osmokraka zvjezdica',
    '❇' => 'iskra',
    '™' => 'žig',
    '🫟' => 'prosuto',
    '🔠' => 'unos velikih slova',
    '🔡' => 'unos malih slova',
    '🔢' => 'unos brojeva',
    '🔣' => 'unos simbola',
    '🔤' => 'unos latiničnih slova',
    '🅰' => 'dugme sa slovom a',
    '🆎' => 'dugme sa slovima a i b',
    '🅱' => 'dugme sa slovom b',
    '🆑' => 'dugme CL',
    '🆒' => 'dugme COOL',
    '🆓' => 'dugme FREE',
    'ℹ' => 'izvor informacija',
    '🆔' => 'dugme ID',
    'Ⓜ' => 'slovo m u krugu',
    '🆕' => 'dugme NEW',
    '🆖' => 'dugme NG',
    '🅾' => 'dugme o',
    '🆗' => 'dugme OK',
    '🅿' => 'znak za parking',
    '🆘' => 'S.O.S.',
    '🆙' => 'dugme UP!',
    '🆚' => 'dugme VS',
    '🈁' => 'katakana koko u kvadratu',
    '🈂' => 'katakana sa u kvadratu',
    '🈷' => 'ideograf „mjesec“ u kvadratu',
    '🈶' => 'japansko dugme „nije besplatno“',
    '🈯' => 'ideograf „prst“ u kvadratu',
    '🉐' => 'japansko dugme „bagatela“',
    '🈹' => 'japansko dugme „sniženje“',
    '🈚' => 'japansko dugme „besplatno“',
    '🈲' => 'japansko dugme „zabranjeno“',
    '🉑' => 'japansko dugme „prihvatljivo“',
    '🈸' => 'japansko dugme „primjena“',
    '🈴' => 'japansko dugme „prelazna ocena“',
    '🈳' => 'japansko dugme „prazno“',
    '㊗' => 'japansko dugme „čestitke“',
    '㊙' => 'japansko dugme „tajna“',
    '🈺' => 'japansko dugme „otvoreno“',
    '🈵' => 'japansko dugme „nema mjesta“',
    '🔴' => 'crveni krug',
    '🟠' => 'narandžast krug',
    '🟡' => 'žut krug',
    '🟢' => 'zelen krug',
    '🔵' => 'plavi krug',
    '🟣' => 'ljubičast krug',
    '🟤' => 'braon krug',
    '⚫' => 'crni krug',
    '⚪' => 'bijeli krug',
    '🟥' => 'crveni kvadrat',
    '🟧' => 'narandžasti kvadrat',
    '🟨' => 'žuti kvadrat',
    '🟩' => 'zeleni kvadrat',
    '🟦' => 'plavi kvadrat',
    '🟪' => 'ljubičasti kvadrat',
    '🟫' => 'braon kvadrat',
    '⬛' => 'veliki crni kvadrat',
    '⬜' => 'veliki bijeli kvadrat',
    '◼' => 'crni kvadrat srednje veličine',
    '◻' => 'bijeli kvadrat srednje veličine',
    '◾' => 'srednjemali crni kvadrat',
    '◽' => 'srednjemali bijeli kvadrat',
    '▪' => 'mali crni kvadrat',
    '▫' => 'mali bijeli kvadrat',
    '🔶' => 'veliki narandžasti romb',
    '🔷' => 'veliki plavi romb',
    '🔸' => 'mali narandžasti romb',
    '🔹' => 'mali plavi romb',
    '🔺' => 'crveni trougao okrenut nagore',
    '🔻' => 'crveni trougao okrenut nadolje',
    '💠' => 'romb sa tačkom',
    '🔘' => 'dugme za izbor',
    '🔳' => 'bijelo kvadratno dugme',
    '🔲' => 'crno kvadratno dugme',
    '🏁' => 'zastava za kraj trke',
    '🚩' => 'trouglasta zastava',
    '🎌' => 'ukrštene zastave',
    '🏴' => 'crna zastava',
    '🏳' => 'bijela zastava',
];
