<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'bozk: dospelý, dospelý, svetlý tón pleti, stredne svetlý tón pleti',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'bozk: dospelý, dospelý, svetlý tón pleti, stredný tón pleti',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'bozk: dospelý, dospelý, svetlý tón pleti, stredne tmavý tón pleti',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'bozk: dospelý, dospelý, svetlý tón pleti, tmavý tón pleti',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'bozk: dospelý, dospelý, stredne svetlý tón pleti, svetlý tón pleti',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'bozk: dospelý, dospelý, stredne svetlý tón pleti, stredný tón pleti',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'bozk: dospelý, dospelý, stredne svetlý tón pleti, stredne tmavý tón pleti',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'bozk: dospelý, dospelý, stredne svetlý tón pleti, tmavý tón pleti',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'bozk: dospelý, dospelý, stredný tón pleti, svetlý tón pleti',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'bozk: dospelý, dospelý, stredný tón pleti, stredne svetlý tón pleti',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'bozk: dospelý, dospelý, stredný tón pleti, stredne tmavý tón pleti',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'bozk: dospelý, dospelý, stredný tón pleti, tmavý tón pleti',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'bozk: dospelý, dospelý, stredne tmavý tón pleti, svetlý tón pleti',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'bozk: dospelý, dospelý, stredne tmavý tón pleti, stredne svetlý tón pleti',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'bozk: dospelý, dospelý, stredne tmavý tón pleti, stredný tón pleti',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'bozk: dospelý, dospelý, stredne tmavý tón pleti, tmavý tón pleti',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'bozk: dospelý, dospelý, tmavý tón pleti, svetlý tón pleti',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'bozk: dospelý, dospelý, tmavý tón pleti, stredne svetlý tón pleti',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'bozk: dospelý, dospelý, tmavý tón pleti, stredný tón pleti',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'bozk: dospelý, dospelý, tmavý tón pleti, stredne tmavý tón pleti',
    '👨🏻‍❤‍💋‍👨🏻' => 'bozk: muž, muž, svetlý tón pleti',
    '👨🏻‍❤‍💋‍👨🏼' => 'bozk: muž, muž, svetlý tón pleti, stredne svetlý tón pleti',
    '👨🏻‍❤‍💋‍👨🏽' => 'bozk: muž, muž, svetlý tón pleti, stredný tón pleti',
    '👨🏻‍❤‍💋‍👨🏾' => 'bozk: muž, muž, svetlý tón pleti, stredne tmavý tón pleti',
    '👨🏻‍❤‍💋‍👨🏿' => 'bozk: muž, muž, svetlý tón pleti, tmavý tón pleti',
    '👨🏼‍❤‍💋‍👨🏻' => 'bozk: muž, muž, stredne svetlý tón pleti, svetlý tón pleti',
    '👨🏼‍❤‍💋‍👨🏼' => 'bozk: muž, muž, stredne svetlý tón pleti',
    '👨🏼‍❤‍💋‍👨🏽' => 'bozk: muž, muž, stredne svetlý tón pleti, stredný tón pleti',
    '👨🏼‍❤‍💋‍👨🏾' => 'bozk: muž, muž, stredne svetlý tón pleti, stredne tmavý tón pleti',
    '👨🏼‍❤‍💋‍👨🏿' => 'bozk: muž, muž, stredne svetlý tón pleti, tmavý tón pleti',
    '👨🏽‍❤‍💋‍👨🏻' => 'bozk: muž, muž, stredný tón pleti, svetlý tón pleti',
    '👨🏽‍❤‍💋‍👨🏼' => 'bozk: muž, muž, stredný tón pleti, stredne svetlý tón pleti',
    '👨🏽‍❤‍💋‍👨🏽' => 'bozk: muž, muž, stredný tón pleti',
    '👨🏽‍❤‍💋‍👨🏾' => 'bozk: muž, muž, stredný tón pleti, stredne tmavý tón pleti',
    '👨🏽‍❤‍💋‍👨🏿' => 'bozk: muž, muž, stredný tón pleti, tmavý tón pleti',
    '👨🏾‍❤‍💋‍👨🏻' => 'bozk: muž, muž, stredne tmavý tón pleti, svetlý tón pleti',
    '👨🏾‍❤‍💋‍👨🏼' => 'bozk: muž, muž, stredne tmavý tón pleti, stredne svetlý tón pleti',
    '👨🏾‍❤‍💋‍👨🏽' => 'bozk: muž, muž, stredne tmavý tón pleti, stredný tón pleti',
    '👨🏾‍❤‍💋‍👨🏾' => 'bozk: muž, muž, stredne tmavý tón pleti',
    '👨🏾‍❤‍💋‍👨🏿' => 'bozk: muž, muž, stredne tmavý tón pleti, tmavý tón pleti',
    '👨🏿‍❤‍💋‍👨🏻' => 'bozk: muž, muž, tmavý tón pleti, svetlý tón pleti',
    '👨🏿‍❤‍💋‍👨🏼' => 'bozk: muž, muž, tmavý tón pleti, stredne svetlý tón pleti',
    '👨🏿‍❤‍💋‍👨🏽' => 'bozk: muž, muž, tmavý tón pleti, stredný tón pleti',
    '👨🏿‍❤‍💋‍👨🏾' => 'bozk: muž, muž, tmavý tón pleti, stredne tmavý tón pleti',
    '👨🏿‍❤‍💋‍👨🏿' => 'bozk: muž, muž, tmavý tón pleti',
    '👩🏻‍❤‍💋‍👨🏻' => 'bozk: žena, muž, svetlý tón pleti',
    '👩🏻‍❤‍💋‍👨🏼' => 'bozk: žena, muž, svetlý tón pleti, stredne svetlý tón pleti',
    '👩🏻‍❤‍💋‍👨🏽' => 'bozk: žena, muž, svetlý tón pleti, stredný tón pleti',
    '👩🏻‍❤‍💋‍👨🏾' => 'bozk: žena, muž, svetlý tón pleti, stredne tmavý tón pleti',
    '👩🏻‍❤‍💋‍👨🏿' => 'bozk: žena, muž, svetlý tón pleti, tmavý tón pleti',
    '👩🏼‍❤‍💋‍👨🏻' => 'bozk: žena, muž, stredne svetlý tón pleti, svetlý tón pleti',
    '👩🏼‍❤‍💋‍👨🏼' => 'bozk: žena, muž, stredne svetlý tón pleti',
    '👩🏼‍❤‍💋‍👨🏽' => 'bozk: žena, muž, stredne svetlý tón pleti, stredný tón pleti',
    '👩🏼‍❤‍💋‍👨🏾' => 'bozk: žena, muž, stredne svetlý tón pleti, stredne tmavý tón pleti',
    '👩🏼‍❤‍💋‍👨🏿' => 'bozk: žena, muž, stredne svetlý tón pleti, tmavý tón pleti',
    '👩🏽‍❤‍💋‍👨🏻' => 'bozk: žena, muž, stredný tón pleti, svetlý tón pleti',
    '👩🏽‍❤‍💋‍👨🏼' => 'bozk: žena, muž, stredný tón pleti, stredne svetlý tón pleti',
    '👩🏽‍❤‍💋‍👨🏽' => 'bozk: žena, muž, stredný tón pleti',
    '👩🏽‍❤‍💋‍👨🏾' => 'bozk: žena, muž, stredný tón pleti, stredne tmavý tón pleti',
    '👩🏽‍❤‍💋‍👨🏿' => 'bozk: žena, muž, stredný tón pleti, tmavý tón pleti',
    '👩🏾‍❤‍💋‍👨🏻' => 'bozk: žena, muž, stredne tmavý tón pleti, svetlý tón pleti',
    '👩🏾‍❤‍💋‍👨🏼' => 'bozk: žena, muž, stredne tmavý tón pleti, stredne svetlý tón pleti',
    '👩🏾‍❤‍💋‍👨🏽' => 'bozk: žena, muž, stredne tmavý tón pleti, stredný tón pleti',
    '👩🏾‍❤‍💋‍👨🏾' => 'bozk: žena, muž, stredne tmavý tón pleti',
    '👩🏾‍❤‍💋‍👨🏿' => 'bozk: žena, muž, stredne tmavý tón pleti, tmavý tón pleti',
    '👩🏿‍❤‍💋‍👨🏻' => 'bozk: žena, muž, tmavý tón pleti, svetlý tón pleti',
    '👩🏿‍❤‍💋‍👨🏼' => 'bozk: žena, muž, tmavý tón pleti, stredne svetlý tón pleti',
    '👩🏿‍❤‍💋‍👨🏽' => 'bozk: žena, muž, tmavý tón pleti, stredný tón pleti',
    '👩🏿‍❤‍💋‍👨🏾' => 'bozk: žena, muž, tmavý tón pleti, stredne tmavý tón pleti',
    '👩🏿‍❤‍💋‍👨🏿' => 'bozk: žena, muž, tmavý tón pleti',
    '👩🏻‍❤‍💋‍👩🏻' => 'bozk: žena, žena, svetlý tón pleti',
    '👩🏻‍❤‍💋‍👩🏼' => 'bozk: žena, žena, svetlý tón pleti, stredne svetlý tón pleti',
    '👩🏻‍❤‍💋‍👩🏽' => 'bozk: žena, žena, svetlý tón pleti, stredný tón pleti',
    '👩🏻‍❤‍💋‍👩🏾' => 'bozk: žena, žena, svetlý tón pleti, stredne tmavý tón pleti',
    '👩🏻‍❤‍💋‍👩🏿' => 'bozk: žena, žena, svetlý tón pleti, tmavý tón pleti',
    '👩🏼‍❤‍💋‍👩🏻' => 'bozk: žena, žena, stredne svetlý tón pleti, svetlý tón pleti',
    '👩🏼‍❤‍💋‍👩🏼' => 'bozk: žena, žena, stredne svetlý tón pleti',
    '👩🏼‍❤‍💋‍👩🏽' => 'bozk: žena, žena, stredne svetlý tón pleti, stredný tón pleti',
    '👩🏼‍❤‍💋‍👩🏾' => 'bozk: žena, žena, stredne svetlý tón pleti, stredne tmavý tón pleti',
    '👩🏼‍❤‍💋‍👩🏿' => 'bozk: žena, žena, stredne svetlý tón pleti, tmavý tón pleti',
    '👩🏽‍❤‍💋‍👩🏻' => 'bozk: žena, žena, stredný tón pleti, svetlý tón pleti',
    '👩🏽‍❤‍💋‍👩🏼' => 'bozk: žena, žena, stredný tón pleti, stredne svetlý tón pleti',
    '👩🏽‍❤‍💋‍👩🏽' => 'bozk: žena, žena, stredný tón pleti',
    '👩🏽‍❤‍💋‍👩🏾' => 'bozk: žena, žena, stredný tón pleti, stredne tmavý tón pleti',
    '👩🏽‍❤‍💋‍👩🏿' => 'bozk: žena, žena, stredný tón pleti, tmavý tón pleti',
    '👩🏾‍❤‍💋‍👩🏻' => 'bozk: žena, žena, stredne tmavý tón pleti, svetlý tón pleti',
    '👩🏾‍❤‍💋‍👩🏼' => 'bozk: žena, žena, stredne tmavý tón pleti, stredne svetlý tón pleti',
    '👩🏾‍❤‍💋‍👩🏽' => 'bozk: žena, žena, stredne tmavý tón pleti, stredný tón pleti',
    '👩🏾‍❤‍💋‍👩🏾' => 'bozk: žena, žena, stredne tmavý tón pleti',
    '👩🏾‍❤‍💋‍👩🏿' => 'bozk: žena, žena, stredne tmavý tón pleti, tmavý tón pleti',
    '👩🏿‍❤‍💋‍👩🏻' => 'bozk: žena, žena, tmavý tón pleti, svetlý tón pleti',
    '👩🏿‍❤‍💋‍👩🏼' => 'bozk: žena, žena, tmavý tón pleti, stredne svetlý tón pleti',
    '👩🏿‍❤‍💋‍👩🏽' => 'bozk: žena, žena, tmavý tón pleti, stredný tón pleti',
    '👩🏿‍❤‍💋‍👩🏾' => 'bozk: žena, žena, tmavý tón pleti, stredne tmavý tón pleti',
    '👩🏿‍❤‍💋‍👩🏿' => 'bozk: žena, žena, tmavý tón pleti',
    '🧑🏻‍🫯‍🧑🏼' => 'zápasiaci ľudia: svetlý tón pleti, stredne svetlý tón pleti',
    '🧑🏻‍🫯‍🧑🏽' => 'zápasiaci ľudia: svetlý tón pleti, stredný tón pleti',
    '🧑🏻‍🫯‍🧑🏾' => 'zápasiaci ľudia: svetlý tón pleti, stredne tmavý tón pleti',
    '🧑🏻‍🫯‍🧑🏿' => 'zápasiaci ľudia: svetlý tón pleti, tmavý tón pleti',
    '🧑🏼‍🫯‍🧑🏻' => 'zápasiaci ľudia: stredne svetlý tón pleti, svetlý tón pleti',
    '🧑🏼‍🫯‍🧑🏽' => 'zápasiaci ľudia: stredne svetlý tón pleti, stredný tón pleti',
    '🧑🏼‍🫯‍🧑🏾' => 'zápasiaci ľudia: stredne svetlý tón pleti, stredne tmavý tón pleti',
    '🧑🏼‍🫯‍🧑🏿' => 'zápasiaci ľudia: stredne svetlý tón pleti, tmavý tón pleti',
    '🧑🏽‍🫯‍🧑🏻' => 'zápasiaci ľudia: stredný tón pleti, svetlý tón pleti',
    '🧑🏽‍🫯‍🧑🏼' => 'zápasiaci ľudia: stredný tón pleti, stredne svetlý tón pleti',
    '🧑🏽‍🫯‍🧑🏾' => 'zápasiaci ľudia: stredný tón pleti, stredne tmavý tón pleti',
    '🧑🏽‍🫯‍🧑🏿' => 'zápasiaci ľudia: stredný tón pleti, tmavý tón pleti',
    '🧑🏾‍🫯‍🧑🏻' => 'zápasiaci ľudia: stredne tmavý tón pleti, svetlý tón pleti',
    '🧑🏾‍🫯‍🧑🏼' => 'zápasiaci ľudia: stredne tmavý tón pleti, stredne svetlý tón pleti',
    '🧑🏾‍🫯‍🧑🏽' => 'zápasiaci ľudia: stredne tmavý tón pleti, stredný tón pleti',
    '🧑🏾‍🫯‍🧑🏿' => 'zápasiaci ľudia: stredne tmavý tón pleti, tmavý tón pleti',
    '🧑🏿‍🫯‍🧑🏻' => 'zápasiaci ľudia: tmavý tón pleti, svetlý tón pleti',
    '🧑🏿‍🫯‍🧑🏼' => 'zápasiaci ľudia: tmavý tón pleti, stredne svetlý tón pleti',
    '🧑🏿‍🫯‍🧑🏽' => 'zápasiaci ľudia: tmavý tón pleti, stredný tón pleti',
    '🧑🏿‍🫯‍🧑🏾' => 'zápasiaci ľudia: tmavý tón pleti, stredne tmavý tón pleti',
    '🧑🏻‍❤‍🧑🏼' => 'pár so srdcom: dospelý, dospelý, svetlý tón pleti, stredne svetlý tón pleti',
    '🧑🏻‍❤‍🧑🏽' => 'pár so srdcom: dospelý, dospelý, svetlý tón pleti, stredný tón pleti',
    '🧑🏻‍❤‍🧑🏾' => 'pár so srdcom: dospelý, dospelý, svetlý tón pleti, stredne tmavý tón pleti',
    '🧑🏻‍❤‍🧑🏿' => 'pár so srdcom: dospelý, dospelý, svetlý tón pleti, tmavý tón pleti',
    '🧑🏼‍❤‍🧑🏻' => 'pár so srdcom: dospelý, dospelý, stredne svetlý tón pleti, svetlý tón pleti',
    '🧑🏼‍❤‍🧑🏽' => 'pár so srdcom: dospelý, dospelý, stredne svetlý tón pleti, stredný tón pleti',
    '🧑🏼‍❤‍🧑🏾' => 'pár so srdcom: dospelý, dospelý, stredne svetlý tón pleti, stredne tmavý tón pleti',
    '🧑🏼‍❤‍🧑🏿' => 'pár so srdcom: dospelý, dospelý, stredne svetlý tón pleti, tmavý tón pleti',
    '🧑🏽‍❤‍🧑🏻' => 'pár so srdcom: dospelý, dospelý, stredný tón pleti, svetlý tón pleti',
    '🧑🏽‍❤‍🧑🏼' => 'pár so srdcom: dospelý, dospelý, stredný tón pleti, stredne svetlý tón pleti',
    '🧑🏽‍❤‍🧑🏾' => 'pár so srdcom: dospelý, dospelý, stredný tón pleti, stredne tmavý tón pleti',
    '🧑🏽‍❤‍🧑🏿' => 'pár so srdcom: dospelý, dospelý, stredný tón pleti, tmavý tón pleti',
    '🧑🏾‍❤‍🧑🏻' => 'pár so srdcom: dospelý, dospelý, stredne tmavý tón pleti, svetlý tón pleti',
    '🧑🏾‍❤‍🧑🏼' => 'pár so srdcom: dospelý, dospelý, stredne tmavý tón pleti, stredne svetlý tón pleti',
    '🧑🏾‍❤‍🧑🏽' => 'pár so srdcom: dospelý, dospelý, stredne tmavý tón pleti, stredný tón pleti',
    '🧑🏾‍❤‍🧑🏿' => 'pár so srdcom: dospelý, dospelý, stredne tmavý tón pleti, tmavý tón pleti',
    '🧑🏿‍❤‍🧑🏻' => 'pár so srdcom: dospelý, dospelý, tmavý tón pleti, svetlý tón pleti',
    '🧑🏿‍❤‍🧑🏼' => 'pár so srdcom: dospelý, dospelý, tmavý tón pleti, stredne svetlý tón pleti',
    '🧑🏿‍❤‍🧑🏽' => 'pár so srdcom: dospelý, dospelý, tmavý tón pleti, stredný tón pleti',
    '🧑🏿‍❤‍🧑🏾' => 'pár so srdcom: dospelý, dospelý, tmavý tón pleti, stredne tmavý tón pleti',
    '🧑🏻‍🐰‍🧑🏼' => 'ľudia so zajačími ušami: svetlý tón pleti, stredne svetlý tón pleti',
    '🧑🏻‍🐰‍🧑🏽' => 'ľudia so zajačími ušami: svetlý tón pleti, stredný tón pleti',
    '🧑🏻‍🐰‍🧑🏾' => 'ľudia so zajačími ušami: svetlý tón pleti, stredne tmavý tón pleti',
    '🧑🏻‍🐰‍🧑🏿' => 'ľudia so zajačími ušami: svetlý tón pleti, tmavý tón pleti',
    '🧑🏼‍🐰‍🧑🏻' => 'ľudia so zajačími ušami: stredne svetlý tón pleti, svetlý tón pleti',
    '🧑🏼‍🐰‍🧑🏽' => 'ľudia so zajačími ušami: stredne svetlý tón pleti, stredný tón pleti',
    '🧑🏼‍🐰‍🧑🏾' => 'ľudia so zajačími ušami: stredne svetlý tón pleti, stredne tmavý tón pleti',
    '🧑🏼‍🐰‍🧑🏿' => 'ľudia so zajačími ušami: stredne svetlý tón pleti, tmavý tón pleti',
    '🧑🏽‍🐰‍🧑🏻' => 'ľudia so zajačími ušami: stredný tón pleti, svetlý tón pleti',
    '🧑🏽‍🐰‍🧑🏼' => 'ľudia so zajačími ušami: stredný tón pleti, stredne svetlý tón pleti',
    '🧑🏽‍🐰‍🧑🏾' => 'ľudia so zajačími ušami: stredný tón pleti, stredne tmavý tón pleti',
    '🧑🏽‍🐰‍🧑🏿' => 'ľudia so zajačími ušami: stredný tón pleti, tmavý tón pleti',
    '🧑🏾‍🐰‍🧑🏻' => 'ľudia so zajačími ušami: stredne tmavý tón pleti, svetlý tón pleti',
    '🧑🏾‍🐰‍🧑🏼' => 'ľudia so zajačími ušami: stredne tmavý tón pleti, stredne svetlý tón pleti',
    '🧑🏾‍🐰‍🧑🏽' => 'ľudia so zajačími ušami: stredne tmavý tón pleti, stredný tón pleti',
    '🧑🏾‍🐰‍🧑🏿' => 'ľudia so zajačími ušami: stredne tmavý tón pleti, tmavý tón pleti',
    '🧑🏿‍🐰‍🧑🏻' => 'ľudia so zajačími ušami: tmavý tón pleti, svetlý tón pleti',
    '🧑🏿‍🐰‍🧑🏼' => 'ľudia so zajačími ušami: tmavý tón pleti, stredne svetlý tón pleti',
    '🧑🏿‍🐰‍🧑🏽' => 'ľudia so zajačími ušami: tmavý tón pleti, stredný tón pleti',
    '🧑🏿‍🐰‍🧑🏾' => 'ľudia so zajačími ušami: tmavý tón pleti, stredne tmavý tón pleti',
    '👨🏻‍🫯‍👨🏼' => 'zápasníci: svetlý tón pleti, stredne svetlý tón pleti',
    '👨🏻‍🫯‍👨🏽' => 'zápasníci: svetlý tón pleti, stredný tón pleti',
    '👨🏻‍🫯‍👨🏾' => 'zápasníci: svetlý tón pleti, stredne tmavý tón pleti',
    '👨🏻‍🫯‍👨🏿' => 'zápasníci: svetlý tón pleti, tmavý tón pleti',
    '👨🏼‍🫯‍👨🏻' => 'zápasníci: stredne svetlý tón pleti, svetlý tón pleti',
    '👨🏼‍🫯‍👨🏽' => 'zápasníci: stredne svetlý tón pleti, stredný tón pleti',
    '👨🏼‍🫯‍👨🏾' => 'zápasníci: stredne svetlý tón pleti, stredne tmavý tón pleti',
    '👨🏼‍🫯‍👨🏿' => 'zápasníci: stredne svetlý tón pleti, tmavý tón pleti',
    '👨🏽‍🫯‍👨🏻' => 'zápasníci: stredný tón pleti, svetlý tón pleti',
    '👨🏽‍🫯‍👨🏼' => 'zápasníci: stredný tón pleti, stredne svetlý tón pleti',
    '👨🏽‍🫯‍👨🏾' => 'zápasníci: stredný tón pleti, stredne tmavý tón pleti',
    '👨🏽‍🫯‍👨🏿' => 'zápasníci: stredný tón pleti, tmavý tón pleti',
    '👨🏾‍🫯‍👨🏻' => 'zápasníci: stredne tmavý tón pleti, svetlý tón pleti',
    '👨🏾‍🫯‍👨🏼' => 'zápasníci: stredne tmavý tón pleti, stredne svetlý tón pleti',
    '👨🏾‍🫯‍👨🏽' => 'zápasníci: stredne tmavý tón pleti, stredný tón pleti',
    '👨🏾‍🫯‍👨🏿' => 'zápasníci: stredne tmavý tón pleti, tmavý tón pleti',
    '👨🏿‍🫯‍👨🏻' => 'zápasníci: tmavý tón pleti, svetlý tón pleti',
    '👨🏿‍🫯‍👨🏼' => 'zápasníci: tmavý tón pleti, stredne svetlý tón pleti',
    '👨🏿‍🫯‍👨🏽' => 'zápasníci: tmavý tón pleti, stredný tón pleti',
    '👨🏿‍🫯‍👨🏾' => 'zápasníci: tmavý tón pleti, stredne tmavý tón pleti',
    '👨🏻‍❤‍👨🏻' => 'pár so srdcom: muž, muž, svetlý tón pleti',
    '👨🏻‍❤‍👨🏼' => 'pár so srdcom: muž, muž, svetlý tón pleti, stredne svetlý tón pleti',
    '👨🏻‍❤‍👨🏽' => 'pár so srdcom: muž, muž, svetlý tón pleti, stredný tón pleti',
    '👨🏻‍❤‍👨🏾' => 'pár so srdcom: muž, muž, svetlý tón pleti, stredne tmavý tón pleti',
    '👨🏻‍❤‍👨🏿' => 'pár so srdcom: muž, muž, svetlý tón pleti, tmavý tón pleti',
    '👨🏼‍❤‍👨🏻' => 'pár so srdcom: muž, muž, stredne svetlý tón pleti, svetlý tón pleti',
    '👨🏼‍❤‍👨🏼' => 'pár so srdcom: muž, muž, stredne svetlý tón pleti',
    '👨🏼‍❤‍👨🏽' => 'pár so srdcom: muž, muž, stredne svetlý tón pleti, stredný tón pleti',
    '👨🏼‍❤‍👨🏾' => 'pár so srdcom: muž, muž, stredne svetlý tón pleti, stredne tmavý tón pleti',
    '👨🏼‍❤‍👨🏿' => 'pár so srdcom: muž, muž, stredne svetlý tón pleti, tmavý tón pleti',
    '👨🏽‍❤‍👨🏻' => 'pár so srdcom: muž, muž, stredný tón pleti, svetlý tón pleti',
    '👨🏽‍❤‍👨🏼' => 'pár so srdcom: muž, muž, stredný tón pleti, stredne svetlý tón pleti',
    '👨🏽‍❤‍👨🏽' => 'pár so srdcom: muž, muž, stredný tón pleti',
    '👨🏽‍❤‍👨🏾' => 'pár so srdcom: muž, muž, stredný tón pleti, stredne tmavý tón pleti',
    '👨🏽‍❤‍👨🏿' => 'pár so srdcom: muž, muž, stredný tón pleti, tmavý tón pleti',
    '👨🏾‍❤‍👨🏻' => 'pár so srdcom: muž, muž, stredne tmavý tón pleti, svetlý tón pleti',
    '👨🏾‍❤‍👨🏼' => 'pár so srdcom: muž, muž, stredne tmavý tón pleti, stredne svetlý tón pleti',
    '👨🏾‍❤‍👨🏽' => 'pár so srdcom: muž, muž, stredne tmavý tón pleti, stredný tón pleti',
    '👨🏾‍❤‍👨🏾' => 'pár so srdcom: muž, muž, stredne tmavý tón pleti',
    '👨🏾‍❤‍👨🏿' => 'pár so srdcom: muž, muž, stredne tmavý tón pleti, tmavý tón pleti',
    '👨🏿‍❤‍👨🏻' => 'pár so srdcom: muž, muž, tmavý tón pleti, svetlý tón pleti',
    '👨🏿‍❤‍👨🏼' => 'pár so srdcom: muž, muž, tmavý tón pleti, stredne svetlý tón pleti',
    '👨🏿‍❤‍👨🏽' => 'pár so srdcom: muž, muž, tmavý tón pleti, stredný tón pleti',
    '👨🏿‍❤‍👨🏾' => 'pár so srdcom: muž, muž, tmavý tón pleti, stredne tmavý tón pleti',
    '👨🏿‍❤‍👨🏿' => 'pár so srdcom: muž, muž, tmavý tón pleti',
    '👨🏻‍🐰‍👨🏼' => 'muži so zajačími ušami: svetlý tón pleti, stredne svetlý tón pleti',
    '👨🏻‍🐰‍👨🏽' => 'muži so zajačími ušami: svetlý tón pleti, stredný tón pleti',
    '👨🏻‍🐰‍👨🏾' => 'muži so zajačími ušami: svetlý tón pleti, stredne tmavý tón pleti',
    '👨🏻‍🐰‍👨🏿' => 'muži so zajačími ušami: svetlý tón pleti, tmavý tón pleti',
    '👨🏼‍🐰‍👨🏻' => 'muži so zajačími ušami: stredne svetlý tón pleti, svetlý tón pleti',
    '👨🏼‍🐰‍👨🏽' => 'muži so zajačími ušami: stredne svetlý tón pleti, stredný tón pleti',
    '👨🏼‍🐰‍👨🏾' => 'muži so zajačími ušami: stredne svetlý tón pleti, stredne tmavý tón pleti',
    '👨🏼‍🐰‍👨🏿' => 'muži so zajačími ušami: stredne svetlý tón pleti, tmavý tón pleti',
    '👨🏽‍🐰‍👨🏻' => 'muži so zajačími ušami: stredný tón pleti, svetlý tón pleti',
    '👨🏽‍🐰‍👨🏼' => 'muži so zajačími ušami: stredný tón pleti, stredne svetlý tón pleti',
    '👨🏽‍🐰‍👨🏾' => 'muži so zajačími ušami: stredný tón pleti, stredne tmavý tón pleti',
    '👨🏽‍🐰‍👨🏿' => 'muži so zajačími ušami: stredný tón pleti, tmavý tón pleti',
    '👨🏾‍🐰‍👨🏻' => 'muži so zajačími ušami: stredne tmavý tón pleti, svetlý tón pleti',
    '👨🏾‍🐰‍👨🏼' => 'muži so zajačími ušami: stredne tmavý tón pleti, stredne svetlý tón pleti',
    '👨🏾‍🐰‍👨🏽' => 'muži so zajačími ušami: stredne tmavý tón pleti, stredný tón pleti',
    '👨🏾‍🐰‍👨🏿' => 'muži so zajačími ušami: stredne tmavý tón pleti, tmavý tón pleti',
    '👨🏿‍🐰‍👨🏻' => 'muži so zajačími ušami: tmavý tón pleti, svetlý tón pleti',
    '👨🏿‍🐰‍👨🏼' => 'muži so zajačími ušami: tmavý tón pleti, stredne svetlý tón pleti',
    '👨🏿‍🐰‍👨🏽' => 'muži so zajačími ušami: tmavý tón pleti, stredný tón pleti',
    '👨🏿‍🐰‍👨🏾' => 'muži so zajačími ušami: tmavý tón pleti, stredne tmavý tón pleti',
    '👩🏻‍🫯‍👩🏼' => 'zápasníčky: svetlý tón pleti, stredne svetlý tón pleti',
    '👩🏻‍🫯‍👩🏽' => 'zápasníčky: svetlý tón pleti, stredný tón pleti',
    '👩🏻‍🫯‍👩🏾' => 'zápasníčky: svetlý tón pleti, stredne tmavý tón pleti',
    '👩🏻‍🫯‍👩🏿' => 'zápasníčky: svetlý tón pleti, tmavý tón pleti',
    '👩🏼‍🫯‍👩🏻' => 'zápasníčky: stredne svetlý tón pleti, svetlý tón pleti',
    '👩🏼‍🫯‍👩🏽' => 'zápasníčky: stredne svetlý tón pleti, stredný tón pleti',
    '👩🏼‍🫯‍👩🏾' => 'zápasníčky: stredne svetlý tón pleti, stredne tmavý tón pleti',
    '👩🏼‍🫯‍👩🏿' => 'zápasníčky: stredne svetlý tón pleti, tmavý tón pleti',
    '👩🏽‍🫯‍👩🏻' => 'zápasníčky: stredný tón pleti, svetlý tón pleti',
    '👩🏽‍🫯‍👩🏼' => 'zápasníčky: stredný tón pleti, stredne svetlý tón pleti',
    '👩🏽‍🫯‍👩🏾' => 'zápasníčky: stredný tón pleti, stredne tmavý tón pleti',
    '👩🏽‍🫯‍👩🏿' => 'zápasníčky: stredný tón pleti, tmavý tón pleti',
    '👩🏾‍🫯‍👩🏻' => 'zápasníčky: stredne tmavý tón pleti, svetlý tón pleti',
    '👩🏾‍🫯‍👩🏼' => 'zápasníčky: stredne tmavý tón pleti, stredne svetlý tón pleti',
    '👩🏾‍🫯‍👩🏽' => 'zápasníčky: stredne tmavý tón pleti, stredný tón pleti',
    '👩🏾‍🫯‍👩🏿' => 'zápasníčky: stredne tmavý tón pleti, tmavý tón pleti',
    '👩🏿‍🫯‍👩🏻' => 'zápasníčky: tmavý tón pleti, svetlý tón pleti',
    '👩🏿‍🫯‍👩🏼' => 'zápasníčky: tmavý tón pleti, stredne svetlý tón pleti',
    '👩🏿‍🫯‍👩🏽' => 'zápasníčky: tmavý tón pleti, stredný tón pleti',
    '👩🏿‍🫯‍👩🏾' => 'zápasníčky: tmavý tón pleti, stredne tmavý tón pleti',
    '👩🏻‍❤‍👨🏻' => 'pár so srdcom: žena, muž, svetlý tón pleti',
    '👩🏻‍❤‍👨🏼' => 'pár so srdcom: žena, muž, svetlý tón pleti, stredne svetlý tón pleti',
    '👩🏻‍❤‍👨🏽' => 'pár so srdcom: žena, muž, svetlý tón pleti, stredný tón pleti',
    '👩🏻‍❤‍👨🏾' => 'pár so srdcom: žena, muž, svetlý tón pleti, stredne tmavý tón pleti',
    '👩🏻‍❤‍👨🏿' => 'pár so srdcom: žena, muž, svetlý tón pleti, tmavý tón pleti',
    '👩🏼‍❤‍👨🏻' => 'pár so srdcom: žena, muž, stredne svetlý tón pleti, svetlý tón pleti',
    '👩🏼‍❤‍👨🏼' => 'pár so srdcom: žena, muž, stredne svetlý tón pleti',
    '👩🏼‍❤‍👨🏽' => 'pár so srdcom: žena, muž, stredne svetlý tón pleti, stredný tón pleti',
    '👩🏼‍❤‍👨🏾' => 'pár so srdcom: žena, muž, stredne svetlý tón pleti, stredne tmavý tón pleti',
    '👩🏼‍❤‍👨🏿' => 'pár so srdcom: žena, muž, stredne svetlý tón pleti, tmavý tón pleti',
    '👩🏽‍❤‍👨🏻' => 'pár so srdcom: žena, muž, stredný tón pleti, svetlý tón pleti',
    '👩🏽‍❤‍👨🏼' => 'pár so srdcom: žena, muž, stredný tón pleti, stredne svetlý tón pleti',
    '👩🏽‍❤‍👨🏽' => 'pár so srdcom: žena, muž, stredný tón pleti',
    '👩🏽‍❤‍👨🏾' => 'pár so srdcom: žena, muž, stredný tón pleti, stredne tmavý tón pleti',
    '👩🏽‍❤‍👨🏿' => 'pár so srdcom: žena, muž, stredný tón pleti, tmavý tón pleti',
    '👩🏾‍❤‍👨🏻' => 'pár so srdcom: žena, muž, stredne tmavý tón pleti, svetlý tón pleti',
    '👩🏾‍❤‍👨🏼' => 'pár so srdcom: žena, muž, stredne tmavý tón pleti, stredne svetlý tón pleti',
    '👩🏾‍❤‍👨🏽' => 'pár so srdcom: žena, muž, stredne tmavý tón pleti, stredný tón pleti',
    '👩🏾‍❤‍👨🏾' => 'pár so srdcom: žena, muž, stredne tmavý tón pleti',
    '👩🏾‍❤‍👨🏿' => 'pár so srdcom: žena, muž, stredne tmavý tón pleti, tmavý tón pleti',
    '👩🏿‍❤‍👨🏻' => 'pár so srdcom: žena, muž, tmavý tón pleti, svetlý tón pleti',
    '👩🏿‍❤‍👨🏼' => 'pár so srdcom: žena, muž, tmavý tón pleti, stredne svetlý tón pleti',
    '👩🏿‍❤‍👨🏽' => 'pár so srdcom: žena, muž, tmavý tón pleti, stredný tón pleti',
    '👩🏿‍❤‍👨🏾' => 'pár so srdcom: žena, muž, tmavý tón pleti, stredne tmavý tón pleti',
    '👩🏿‍❤‍👨🏿' => 'pár so srdcom: žena, muž, tmavý tón pleti',
    '👩🏻‍❤‍👩🏻' => 'pár so srdcom: žena, žena, svetlý tón pleti',
    '👩🏻‍❤‍👩🏼' => 'pár so srdcom: žena, žena, svetlý tón pleti, stredne svetlý tón pleti',
    '👩🏻‍❤‍👩🏽' => 'pár so srdcom: žena, žena, svetlý tón pleti, stredný tón pleti',
    '👩🏻‍❤‍👩🏾' => 'pár so srdcom: žena, žena, svetlý tón pleti, stredne tmavý tón pleti',
    '👩🏻‍❤‍👩🏿' => 'pár so srdcom: žena, žena, svetlý tón pleti, tmavý tón pleti',
    '👩🏼‍❤‍👩🏻' => 'pár so srdcom: žena, žena, stredne svetlý tón pleti, svetlý tón pleti',
    '👩🏼‍❤‍👩🏼' => 'pár so srdcom: žena, žena, stredne svetlý tón pleti',
    '👩🏼‍❤‍👩🏽' => 'pár so srdcom: žena, žena, stredne svetlý tón pleti, stredný tón pleti',
    '👩🏼‍❤‍👩🏾' => 'pár so srdcom: žena, žena, stredne svetlý tón pleti, stredne tmavý tón pleti',
    '👩🏼‍❤‍👩🏿' => 'pár so srdcom: žena, žena, stredne svetlý tón pleti, tmavý tón pleti',
    '👩🏽‍❤‍👩🏻' => 'pár so srdcom: žena, žena, stredný tón pleti, svetlý tón pleti',
    '👩🏽‍❤‍👩🏼' => 'pár so srdcom: žena, žena, stredný tón pleti, stredne svetlý tón pleti',
    '👩🏽‍❤‍👩🏽' => 'pár so srdcom: žena, žena, stredný tón pleti',
    '👩🏽‍❤‍👩🏾' => 'pár so srdcom: žena, žena, stredný tón pleti, stredne tmavý tón pleti',
    '👩🏽‍❤‍👩🏿' => 'pár so srdcom: žena, žena, stredný tón pleti, tmavý tón pleti',
    '👩🏾‍❤‍👩🏻' => 'pár so srdcom: žena, žena, stredne tmavý tón pleti, svetlý tón pleti',
    '👩🏾‍❤‍👩🏼' => 'pár so srdcom: žena, žena, stredne tmavý tón pleti, stredne svetlý tón pleti',
    '👩🏾‍❤‍👩🏽' => 'pár so srdcom: žena, žena, stredne tmavý tón pleti, stredný tón pleti',
    '👩🏾‍❤‍👩🏾' => 'pár so srdcom: žena, žena, stredne tmavý tón pleti',
    '👩🏾‍❤‍👩🏿' => 'pár so srdcom: žena, žena, stredne tmavý tón pleti, tmavý tón pleti',
    '👩🏿‍❤‍👩🏻' => 'pár so srdcom: žena, žena, tmavý tón pleti, svetlý tón pleti',
    '👩🏿‍❤‍👩🏼' => 'pár so srdcom: žena, žena, tmavý tón pleti, stredne svetlý tón pleti',
    '👩🏿‍❤‍👩🏽' => 'pár so srdcom: žena, žena, tmavý tón pleti, stredný tón pleti',
    '👩🏿‍❤‍👩🏾' => 'pár so srdcom: žena, žena, tmavý tón pleti, stredne tmavý tón pleti',
    '👩🏿‍❤‍👩🏿' => 'pár so srdcom: žena, žena, tmavý tón pleti',
    '👩🏻‍🐰‍👩🏼' => 'ženy so zajačími ušami: svetlý tón pleti, stredne svetlý tón pleti',
    '👩🏻‍🐰‍👩🏽' => 'ženy so zajačími ušami: svetlý tón pleti, stredný tón pleti',
    '👩🏻‍🐰‍👩🏾' => 'ženy so zajačími ušami: svetlý tón pleti, stredne tmavý tón pleti',
    '👩🏻‍🐰‍👩🏿' => 'ženy so zajačími ušami: svetlý tón pleti, tmavý tón pleti',
    '👩🏼‍🐰‍👩🏻' => 'ženy so zajačími ušami: stredne svetlý tón pleti, svetlý tón pleti',
    '👩🏼‍🐰‍👩🏽' => 'ženy so zajačími ušami: stredne svetlý tón pleti, stredný tón pleti',
    '👩🏼‍🐰‍👩🏾' => 'ženy so zajačími ušami: stredne svetlý tón pleti, stredne tmavý tón pleti',
    '👩🏼‍🐰‍👩🏿' => 'ženy so zajačími ušami: stredne svetlý tón pleti, tmavý tón pleti',
    '👩🏽‍🐰‍👩🏻' => 'ženy so zajačími ušami: stredný tón pleti, svetlý tón pleti',
    '👩🏽‍🐰‍👩🏼' => 'ženy so zajačími ušami: stredný tón pleti, stredne svetlý tón pleti',
    '👩🏽‍🐰‍👩🏾' => 'ženy so zajačími ušami: stredný tón pleti, stredne tmavý tón pleti',
    '👩🏽‍🐰‍👩🏿' => 'ženy so zajačími ušami: stredný tón pleti, tmavý tón pleti',
    '👩🏾‍🐰‍👩🏻' => 'ženy so zajačími ušami: stredne tmavý tón pleti, svetlý tón pleti',
    '👩🏾‍🐰‍👩🏼' => 'ženy so zajačími ušami: stredne tmavý tón pleti, stredne svetlý tón pleti',
    '👩🏾‍🐰‍👩🏽' => 'ženy so zajačími ušami: stredne tmavý tón pleti, stredný tón pleti',
    '👩🏾‍🐰‍👩🏿' => 'ženy so zajačími ušami: stredne tmavý tón pleti, tmavý tón pleti',
    '👩🏿‍🐰‍👩🏻' => 'ženy so zajačími ušami: tmavý tón pleti, svetlý tón pleti',
    '👩🏿‍🐰‍👩🏼' => 'ženy so zajačími ušami: tmavý tón pleti, stredne svetlý tón pleti',
    '👩🏿‍🐰‍👩🏽' => 'ženy so zajačími ušami: tmavý tón pleti, stredný tón pleti',
    '👩🏿‍🐰‍👩🏾' => 'ženy so zajačími ušami: tmavý tón pleti, stredne tmavý tón pleti',
    '🧑🏻‍🤝‍🧑🏻' => 'ľudia držiaci sa za ruky: svetlý tón pleti',
    '🧑🏻‍🤝‍🧑🏼' => 'ľudia držiaci sa za ruky: svetlý tón pleti, stredne svetlý tón pleti',
    '🧑🏻‍🤝‍🧑🏽' => 'ľudia držiaci sa za ruky: svetlý tón pleti, stredný tón pleti',
    '🧑🏻‍🤝‍🧑🏾' => 'ľudia držiaci sa za ruky: svetlý tón pleti, stredne tmavý tón pleti',
    '🧑🏻‍🤝‍🧑🏿' => 'ľudia držiaci sa za ruky: svetlý tón pleti, tmavý tón pleti',
    '🧑🏼‍🤝‍🧑🏻' => 'ľudia držiaci sa za ruky: stredne svetlý tón pleti, svetlý tón pleti',
    '🧑🏼‍🤝‍🧑🏼' => 'ľudia držiaci sa za ruky: stredne svetlý tón pleti',
    '🧑🏼‍🤝‍🧑🏽' => 'ľudia držiaci sa za ruky: stredne svetlý tón pleti, stredný tón pleti',
    '🧑🏼‍🤝‍🧑🏾' => 'ľudia držiaci sa za ruky: stredne svetlý tón pleti, stredne tmavý tón pleti',
    '🧑🏼‍🤝‍🧑🏿' => 'ľudia držiaci sa za ruky: stredne svetlý tón pleti, tmavý tón pleti',
    '🧑🏽‍🤝‍🧑🏻' => 'ľudia držiaci sa za ruky: stredný tón pleti, svetlý tón pleti',
    '🧑🏽‍🤝‍🧑🏼' => 'ľudia držiaci sa za ruky: stredný tón pleti, stredne svetlý tón pleti',
    '🧑🏽‍🤝‍🧑🏽' => 'ľudia držiaci sa za ruky: stredný tón pleti',
    '🧑🏽‍🤝‍🧑🏾' => 'ľudia držiaci sa za ruky: stredný tón pleti, stredne tmavý tón pleti',
    '🧑🏽‍🤝‍🧑🏿' => 'ľudia držiaci sa za ruky: stredný tón pleti, tmavý tón pleti',
    '🧑🏾‍🤝‍🧑🏻' => 'ľudia držiaci sa za ruky: stredne tmavý tón pleti, svetlý tón pleti',
    '🧑🏾‍🤝‍🧑🏼' => 'ľudia držiaci sa za ruky: stredne tmavý tón pleti, stredne svetlý tón pleti',
    '🧑🏾‍🤝‍🧑🏽' => 'ľudia držiaci sa za ruky: stredne tmavý tón pleti, stredný tón pleti',
    '🧑🏾‍🤝‍🧑🏾' => 'ľudia držiaci sa za ruky: stredne tmavý tón pleti',
    '🧑🏾‍🤝‍🧑🏿' => 'ľudia držiaci sa za ruky: stredne tmavý tón pleti, tmavý tón pleti',
    '🧑🏿‍🤝‍🧑🏻' => 'ľudia držiaci sa za ruky: tmavý tón pleti, svetlý tón pleti',
    '🧑🏿‍🤝‍🧑🏼' => 'ľudia držiaci sa za ruky: tmavý tón pleti, stredne svetlý tón pleti',
    '🧑🏿‍🤝‍🧑🏽' => 'ľudia držiaci sa za ruky: tmavý tón pleti, stredný tón pleti',
    '🧑🏿‍🤝‍🧑🏾' => 'ľudia držiaci sa za ruky: tmavý tón pleti, stredne tmavý tón pleti',
    '🧑🏿‍🤝‍🧑🏿' => 'ľudia držiaci sa za ruky: tmavý tón pleti',
    '👩🏻‍🤝‍👩🏼' => 'ženy držiace sa za ruky: svetlý tón pleti, stredne svetlý tón pleti',
    '👩🏻‍🤝‍👩🏽' => 'ženy držiace sa za ruky: svetlý tón pleti, stredný tón pleti',
    '👩🏻‍🤝‍👩🏾' => 'ženy držiace sa za ruky: svetlý tón pleti, stredne tmavý tón pleti',
    '👩🏻‍🤝‍👩🏿' => 'ženy držiace sa za ruky: svetlý tón pleti, tmavý tón pleti',
    '👩🏼‍🤝‍👩🏻' => 'ženy držiace sa za ruky: stredne svetlý tón pleti, svetlý tón pleti',
    '👩🏼‍🤝‍👩🏽' => 'ženy držiace sa za ruky: stredne svetlý tón pleti, stredný tón pleti',
    '👩🏼‍🤝‍👩🏾' => 'ženy držiace sa za ruky: stredne svetlý tón pleti, stredne tmavý tón pleti',
    '👩🏼‍🤝‍👩🏿' => 'ženy držiace sa za ruky: stredne svetlý tón pleti, tmavý tón pleti',
    '👩🏽‍🤝‍👩🏻' => 'ženy držiace sa za ruky: stredný tón pleti, svetlý tón pleti',
    '👩🏽‍🤝‍👩🏼' => 'ženy držiace sa za ruky: stredný tón pleti, stredne svetlý tón pleti',
    '👩🏽‍🤝‍👩🏾' => 'ženy držiace sa za ruky: stredný tón pleti, stredne tmavý tón pleti',
    '👩🏽‍🤝‍👩🏿' => 'ženy držiace sa za ruky: stredný tón pleti, tmavý tón pleti',
    '👩🏾‍🤝‍👩🏻' => 'ženy držiace sa za ruky: stredne tmavý tón pleti, svetlý tón pleti',
    '👩🏾‍🤝‍👩🏼' => 'ženy držiace sa za ruky: stredne tmavý tón pleti, stredne svetlý tón pleti',
    '👩🏾‍🤝‍👩🏽' => 'ženy držiace sa za ruky: stredne tmavý tón pleti, stredný tón pleti',
    '👩🏾‍🤝‍👩🏿' => 'ženy držiace sa za ruky: stredne tmavý tón pleti, tmavý tón pleti',
    '👩🏿‍🤝‍👩🏻' => 'ženy držiace sa za ruky: tmavý tón pleti, svetlý tón pleti',
    '👩🏿‍🤝‍👩🏼' => 'ženy držiace sa za ruky: tmavý tón pleti, stredne svetlý tón pleti',
    '👩🏿‍🤝‍👩🏽' => 'ženy držiace sa za ruky: tmavý tón pleti, stredný tón pleti',
    '👩🏿‍🤝‍👩🏾' => 'ženy držiace sa za ruky: tmavý tón pleti, stredne tmavý tón pleti',
    '👩🏻‍🤝‍👨🏼' => 'žena a muž držiaci sa za ruky: svetlý tón pleti, stredne svetlý tón pleti',
    '👩🏻‍🤝‍👨🏽' => 'žena a muž držiaci sa za ruky: svetlý tón pleti, stredný tón pleti',
    '👩🏻‍🤝‍👨🏾' => 'žena a muž držiaci sa za ruky: svetlý tón pleti, stredne tmavý tón pleti',
    '👩🏻‍🤝‍👨🏿' => 'žena a muž držiaci sa za ruky: svetlý tón pleti, tmavý tón pleti',
    '👩🏼‍🤝‍👨🏻' => 'žena a muž držiaci sa za ruky: stredne svetlý tón pleti, svetlý tón pleti',
    '👩🏼‍🤝‍👨🏽' => 'žena a muž držiaci sa za ruky: stredne svetlý tón pleti, stredný tón pleti',
    '👩🏼‍🤝‍👨🏾' => 'žena a muž držiaci sa za ruky: stredne svetlý tón pleti, stredne tmavý tón pleti',
    '👩🏼‍🤝‍👨🏿' => 'žena a muž držiaci sa za ruky: stredne svetlý tón pleti, tmavý tón pleti',
    '👩🏽‍🤝‍👨🏻' => 'žena a muž držiaci sa za ruky: stredný tón pleti, svetlý tón pleti',
    '👩🏽‍🤝‍👨🏼' => 'žena a muž držiaci sa za ruky: stredný tón pleti, stredne svetlý tón pleti',
    '👩🏽‍🤝‍👨🏾' => 'žena a muž držiaci sa za ruky: stredný tón pleti, stredne tmavý tón pleti',
    '👩🏽‍🤝‍👨🏿' => 'žena a muž držiaci sa za ruky: stredný tón pleti, tmavý tón pleti',
    '👩🏾‍🤝‍👨🏻' => 'žena a muž držiaci sa za ruky: stredne tmavý tón pleti, svetlý tón pleti',
    '👩🏾‍🤝‍👨🏼' => 'žena a muž držiaci sa za ruky: stredne tmavý tón pleti, stredne svetlý tón pleti',
    '👩🏾‍🤝‍👨🏽' => 'žena a muž držiaci sa za ruky: stredne tmavý tón pleti, stredný tón pleti',
    '👩🏾‍🤝‍👨🏿' => 'žena a muž držiaci sa za ruky: stredne tmavý tón pleti, tmavý tón pleti',
    '👩🏿‍🤝‍👨🏻' => 'žena a muž držiaci sa za ruky: tmavý tón pleti, svetlý tón pleti',
    '👩🏿‍🤝‍👨🏼' => 'žena a muž držiaci sa za ruky: tmavý tón pleti, stredne svetlý tón pleti',
    '👩🏿‍🤝‍👨🏽' => 'žena a muž držiaci sa za ruky: tmavý tón pleti, stredný tón pleti',
    '👩🏿‍🤝‍👨🏾' => 'žena a muž držiaci sa za ruky: tmavý tón pleti, stredne tmavý tón pleti',
    '👨🏻‍🤝‍👨🏼' => 'muži držiaci sa za ruky: svetlý tón pleti, stredne svetlý tón pleti',
    '👨🏻‍🤝‍👨🏽' => 'muži držiaci sa za ruky: svetlý tón pleti, stredný tón pleti',
    '👨🏻‍🤝‍👨🏾' => 'muži držiaci sa za ruky: svetlý tón pleti, stredne tmavý tón pleti',
    '👨🏻‍🤝‍👨🏿' => 'muži držiaci sa za ruky: svetlý tón pleti, tmavý tón pleti',
    '👨🏼‍🤝‍👨🏻' => 'muži držiaci sa za ruky: stredne svetlý tón pleti, svetlý tón pleti',
    '👨🏼‍🤝‍👨🏽' => 'muži držiaci sa za ruky: stredne svetlý tón pleti, stredný tón pleti',
    '👨🏼‍🤝‍👨🏾' => 'muži držiaci sa za ruky: stredne svetlý tón pleti, stredne tmavý tón pleti',
    '👨🏼‍🤝‍👨🏿' => 'muži držiaci sa za ruky: stredne svetlý tón pleti, tmavý tón pleti',
    '👨🏽‍🤝‍👨🏻' => 'muži držiaci sa za ruky: stredný tón pleti, svetlý tón pleti',
    '👨🏽‍🤝‍👨🏼' => 'muži držiaci sa za ruky: stredný tón pleti, stredne svetlý tón pleti',
    '👨🏽‍🤝‍👨🏾' => 'muži držiaci sa za ruky: stredný tón pleti, stredne tmavý tón pleti',
    '👨🏽‍🤝‍👨🏿' => 'muži držiaci sa za ruky: stredný tón pleti, tmavý tón pleti',
    '👨🏾‍🤝‍👨🏻' => 'muži držiaci sa za ruky: stredne tmavý tón pleti, svetlý tón pleti',
    '👨🏾‍🤝‍👨🏼' => 'muži držiaci sa za ruky: stredne tmavý tón pleti, stredne svetlý tón pleti',
    '👨🏾‍🤝‍👨🏽' => 'muži držiaci sa za ruky: stredne tmavý tón pleti, stredný tón pleti',
    '👨🏾‍🤝‍👨🏿' => 'muži držiaci sa za ruky: stredne tmavý tón pleti, tmavý tón pleti',
    '👨🏿‍🤝‍👨🏻' => 'muži držiaci sa za ruky: tmavý tón pleti, svetlý tón pleti',
    '👨🏿‍🤝‍👨🏼' => 'muži držiaci sa za ruky: tmavý tón pleti, stredne svetlý tón pleti',
    '👨🏿‍🤝‍👨🏽' => 'muži držiaci sa za ruky: tmavý tón pleti, stredný tón pleti',
    '👨🏿‍🤝‍👨🏾' => 'muži držiaci sa za ruky: tmavý tón pleti, stredne tmavý tón pleti',
    '👩‍❤‍💋‍👨' => 'bozk: žena, muž',
    '👨‍❤‍💋‍👨' => 'bozk: muž, muž',
    '👩‍❤‍💋‍👩' => 'bozk: žena, žena',
    '👨‍👩‍👧‍👦' => 'rodina: muž, žena, dievča, chlapec',
    '👨‍👩‍👦‍👦' => 'rodina: muž, žena, chlapec, chlapec',
    '👨‍👩‍👧‍👧' => 'rodina: muž, žena, dievča, dievča',
    '👨‍👨‍👧‍👦' => 'rodina: muž, muž, dievča, chlapec',
    '👨‍👨‍👦‍👦' => 'rodina: muž, muž, chlapec, chlapec',
    '👨‍👨‍👧‍👧' => 'rodina: muž, muž, dievča, dievča',
    '👩‍👩‍👧‍👦' => 'rodina: žena, žena, dievča, chlapec',
    '👩‍👩‍👦‍👦' => 'rodina: žena, žena, chlapec, chlapec',
    '👩‍👩‍👧‍👧' => 'rodina: žena, žena, dievča, dievča',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'zástava: Anglicko',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'zástava: Škótsko',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'zástava: Wales',
    '🧑‍🧑‍🧒‍🧒' => 'rodina: dospelý, dospelý, dieťa, dieťa',
    '🚶🏻‍♀‍➡' => 'chodkyňa: svetlý tón pleti, smerom doprava',
    '🚶🏼‍♀‍➡' => 'chodkyňa: stredne svetlý tón pleti, smerom doprava',
    '🚶🏽‍♀‍➡' => 'chodkyňa: stredný tón pleti, smerom doprava',
    '🚶🏾‍♀‍➡' => 'chodkyňa: stredne tmavý tón pleti, smerom doprava',
    '🚶🏿‍♀‍➡' => 'chodkyňa: tmavý tón pleti, smerom doprava',
    '🚶🏻‍♂‍➡' => 'chodec: svetlý tón pleti, smerom doprava',
    '🚶🏼‍♂‍➡' => 'chodec: stredne svetlý tón pleti, smerom doprava',
    '🚶🏽‍♂‍➡' => 'chodec: stredný tón pleti, smerom doprava',
    '🚶🏾‍♂‍➡' => 'chodec: stredne tmavý tón pleti, smerom doprava',
    '🚶🏿‍♂‍➡' => 'chodec: tmavý tón pleti, smerom doprava',
    '🧎🏻‍♀‍➡' => 'kľačiaca žena: svetlý tón pleti, smerom doprava',
    '🧎🏼‍♀‍➡' => 'kľačiaca žena: stredne svetlý tón pleti, smerom doprava',
    '🧎🏽‍♀‍➡' => 'kľačiaca žena: stredný tón pleti, smerom doprava',
    '🧎🏾‍♀‍➡' => 'kľačiaca žena: stredne tmavý tón pleti, smerom doprava',
    '🧎🏿‍♀‍➡' => 'kľačiaca žena: tmavý tón pleti, smerom doprava',
    '🧎🏻‍♂‍➡' => 'kľačiaci muž: svetlý tón pleti, smerom doprava',
    '🧎🏼‍♂‍➡' => 'kľačiaci muž: stredne svetlý tón pleti, smerom doprava',
    '🧎🏽‍♂‍➡' => 'kľačiaci muž: stredný tón pleti, smerom doprava',
    '🧎🏾‍♂‍➡' => 'kľačiaci muž: stredne tmavý tón pleti, smerom doprava',
    '🧎🏿‍♂‍➡' => 'kľačiaci muž: tmavý tón pleti, smerom doprava',
    '🧑🏻‍🦯‍➡' => 'človek s bielou palicou: svetlý tón pleti, smerom doprava',
    '🧑🏼‍🦯‍➡' => 'človek s bielou palicou: stredne svetlý tón pleti, smerom doprava',
    '🧑🏽‍🦯‍➡' => 'človek s bielou palicou: stredný tón pleti, smerom doprava',
    '🧑🏾‍🦯‍➡' => 'človek s bielou palicou: stredne tmavý tón pleti, smerom doprava',
    '🧑🏿‍🦯‍➡' => 'človek s bielou palicou: tmavý tón pleti, smerom doprava',
    '👨🏻‍🦯‍➡' => 'muž s bielou palicou: svetlý tón pleti, smerom doprava',
    '👨🏼‍🦯‍➡' => 'muž s bielou palicou: stredne svetlý tón pleti, smerom doprava',
    '👨🏽‍🦯‍➡' => 'muž s bielou palicou: stredný tón pleti, smerom doprava',
    '👨🏾‍🦯‍➡' => 'muž s bielou palicou: stredne tmavý tón pleti, smerom doprava',
    '👨🏿‍🦯‍➡' => 'muž s bielou palicou: tmavý tón pleti, smerom doprava',
    '👩🏻‍🦯‍➡' => 'žena so slepeckou palicou: svetlý tón pleti, smerom doprava',
    '👩🏼‍🦯‍➡' => 'žena so slepeckou palicou: stredne svetlý tón pleti, smerom doprava',
    '👩🏽‍🦯‍➡' => 'žena so slepeckou palicou: stredný tón pleti, smerom doprava',
    '👩🏾‍🦯‍➡' => 'žena so slepeckou palicou: stredne tmavý tón pleti, smerom doprava',
    '👩🏿‍🦯‍➡' => 'žena so slepeckou palicou: tmavý tón pleti, smerom doprava',
    '🧑🏻‍🦼‍➡' => 'človek na elektrickom invalidnom vozíku: svetlý tón pleti, smerom doprava',
    '🧑🏼‍🦼‍➡' => 'človek na elektrickom invalidnom vozíku: stredne svetlý tón pleti, smerom doprava',
    '🧑🏽‍🦼‍➡' => 'človek na elektrickom invalidnom vozíku: stredný tón pleti, smerom doprava',
    '🧑🏾‍🦼‍➡' => 'človek na elektrickom invalidnom vozíku: stredne tmavý tón pleti, smerom doprava',
    '🧑🏿‍🦼‍➡' => 'človek na elektrickom invalidnom vozíku: tmavý tón pleti, smerom doprava',
    '👨🏻‍🦼‍➡' => 'muž na elektrickom invalidnom vozíku: svetlý tón pleti, smerom doprava',
    '👨🏼‍🦼‍➡' => 'muž na elektrickom invalidnom vozíku: stredne svetlý tón pleti, smerom doprava',
    '👨🏽‍🦼‍➡' => 'muž na elektrickom invalidnom vozíku: stredný tón pleti, smerom doprava',
    '👨🏾‍🦼‍➡' => 'muž na elektrickom invalidnom vozíku: stredne tmavý tón pleti, smerom doprava',
    '👨🏿‍🦼‍➡' => 'muž na elektrickom invalidnom vozíku: tmavý tón pleti, smerom doprava',
    '👩🏻‍🦼‍➡' => 'žena na elektrickom invalidnom vozíku: svetlý tón pleti, smerom doprava',
    '👩🏼‍🦼‍➡' => 'žena na elektrickom invalidnom vozíku: stredne svetlý tón pleti, smerom doprava',
    '👩🏽‍🦼‍➡' => 'žena na elektrickom invalidnom vozíku: stredný tón pleti, smerom doprava',
    '👩🏾‍🦼‍➡' => 'žena na elektrickom invalidnom vozíku: stredne tmavý tón pleti, smerom doprava',
    '👩🏿‍🦼‍➡' => 'žena na elektrickom invalidnom vozíku: tmavý tón pleti, smerom doprava',
    '🧑🏻‍🦽‍➡' => 'človek na mechanickom invalidnom vozíku: svetlý tón pleti, smerom doprava',
    '🧑🏼‍🦽‍➡' => 'človek na mechanickom invalidnom vozíku: stredne svetlý tón pleti, smerom doprava',
    '🧑🏽‍🦽‍➡' => 'človek na mechanickom invalidnom vozíku: stredný tón pleti, smerom doprava',
    '🧑🏾‍🦽‍➡' => 'človek na mechanickom invalidnom vozíku: stredne tmavý tón pleti, smerom doprava',
    '🧑🏿‍🦽‍➡' => 'človek na mechanickom invalidnom vozíku: tmavý tón pleti, smerom doprava',
    '👨🏻‍🦽‍➡' => 'muž na mechanickom invalidnom vozíku: svetlý tón pleti, smerom doprava',
    '👨🏼‍🦽‍➡' => 'muž na mechanickom invalidnom vozíku: stredne svetlý tón pleti, smerom doprava',
    '👨🏽‍🦽‍➡' => 'muž na mechanickom invalidnom vozíku: stredný tón pleti, smerom doprava',
    '👨🏾‍🦽‍➡' => 'muž na mechanickom invalidnom vozíku: stredne tmavý tón pleti, smerom doprava',
    '👨🏿‍🦽‍➡' => 'muž na mechanickom invalidnom vozíku: tmavý tón pleti, smerom doprava',
    '👩🏻‍🦽‍➡' => 'žena na mechanickom invalidnom vozíku: svetlý tón pleti, smerom doprava',
    '👩🏼‍🦽‍➡' => 'žena na mechanickom invalidnom vozíku: stredne svetlý tón pleti, smerom doprava',
    '👩🏽‍🦽‍➡' => 'žena na mechanickom invalidnom vozíku: stredný tón pleti, smerom doprava',
    '👩🏾‍🦽‍➡' => 'žena na mechanickom invalidnom vozíku: stredne tmavý tón pleti, smerom doprava',
    '👩🏿‍🦽‍➡' => 'žena na mechanickom invalidnom vozíku: tmavý tón pleti, smerom doprava',
    '🏃🏻‍♀‍➡' => 'bežkyňa: svetlý tón pleti, smerom doprava',
    '🏃🏼‍♀‍➡' => 'bežkyňa: stredne svetlý tón pleti, smerom doprava',
    '🏃🏽‍♀‍➡' => 'bežkyňa: stredný tón pleti, smerom doprava',
    '🏃🏾‍♀‍➡' => 'bežkyňa: stredne tmavý tón pleti, smerom doprava',
    '🏃🏿‍♀‍➡' => 'bežkyňa: tmavý tón pleti, smerom doprava',
    '🏃🏻‍♂‍➡' => 'bežec: svetlý tón pleti, smerom doprava',
    '🏃🏼‍♂‍➡' => 'bežec: stredne svetlý tón pleti, smerom doprava',
    '🏃🏽‍♂‍➡' => 'bežec: stredný tón pleti, smerom doprava',
    '🏃🏾‍♂‍➡' => 'bežec: stredne tmavý tón pleti, smerom doprava',
    '🏃🏿‍♂‍➡' => 'bežec: tmavý tón pleti, smerom doprava',
    '🫱🏻‍🫲🏼' => 'potrasenie rukami: svetlý tón pleti, stredne svetlý tón pleti',
    '🫱🏻‍🫲🏽' => 'potrasenie rukami: svetlý tón pleti, stredný tón pleti',
    '🫱🏻‍🫲🏾' => 'potrasenie rukami: svetlý tón pleti, stredne tmavý tón pleti',
    '🫱🏻‍🫲🏿' => 'potrasenie rukami: svetlý tón pleti, tmavý tón pleti',
    '🫱🏼‍🫲🏻' => 'potrasenie rukami: stredne svetlý tón pleti, svetlý tón pleti',
    '🫱🏼‍🫲🏽' => 'potrasenie rukami: stredne svetlý tón pleti, stredný tón pleti',
    '🫱🏼‍🫲🏾' => 'potrasenie rukami: stredne svetlý tón pleti, stredne tmavý tón pleti',
    '🫱🏼‍🫲🏿' => 'potrasenie rukami: stredne svetlý tón pleti, tmavý tón pleti',
    '🫱🏽‍🫲🏻' => 'potrasenie rukami: stredný tón pleti, svetlý tón pleti',
    '🫱🏽‍🫲🏼' => 'potrasenie rukami: stredný tón pleti, stredne svetlý tón pleti',
    '🫱🏽‍🫲🏾' => 'potrasenie rukami: stredný tón pleti, stredne tmavý tón pleti',
    '🫱🏽‍🫲🏿' => 'potrasenie rukami: stredný tón pleti, tmavý tón pleti',
    '🫱🏾‍🫲🏻' => 'potrasenie rukami: stredne tmavý tón pleti, svetlý tón pleti',
    '🫱🏾‍🫲🏼' => 'potrasenie rukami: stredne tmavý tón pleti, stredne svetlý tón pleti',
    '🫱🏾‍🫲🏽' => 'potrasenie rukami: stredne tmavý tón pleti, stredný tón pleti',
    '🫱🏾‍🫲🏿' => 'potrasenie rukami: stredne tmavý tón pleti, tmavý tón pleti',
    '🫱🏿‍🫲🏻' => 'potrasenie rukami: tmavý tón pleti, svetlý tón pleti',
    '🫱🏿‍🫲🏼' => 'potrasenie rukami: tmavý tón pleti, stredne svetlý tón pleti',
    '🫱🏿‍🫲🏽' => 'potrasenie rukami: tmavý tón pleti, stredný tón pleti',
    '🫱🏿‍🫲🏾' => 'potrasenie rukami: tmavý tón pleti, stredne tmavý tón pleti',
    '🚶‍♀‍➡' => 'chodkyňa: smerom doprava',
    '🚶‍♂‍➡' => 'chodec: smerom doprava',
    '🧎‍♀‍➡' => 'kľačiaca žena: smerom doprava',
    '🧎‍♂‍➡' => 'kľačiaci muž: smerom doprava',
    '🧑‍🦯‍➡' => 'človek s bielou palicou: smerom doprava',
    '👨‍🦯‍➡' => 'muž s bielou palicou: smerom doprava',
    '👩‍🦯‍➡' => 'žena so slepeckou palicou: smerom doprava',
    '🧑‍🦼‍➡' => 'človek na elektrickom invalidnom vozíku: smerom doprava',
    '👨‍🦼‍➡' => 'muž na elektrickom invalidnom vozíku: smerom doprava',
    '👩‍🦼‍➡' => 'žena na elektrickom invalidnom vozíku: smerom doprava',
    '🧑‍🦽‍➡' => 'človek na mechanickom invalidnom vozíku: smerom doprava',
    '👨‍🦽‍➡' => 'muž na mechanickom invalidnom vozíku: smerom doprava',
    '👩‍🦽‍➡' => 'žena na mechanickom invalidnom vozíku: smerom doprava',
    '🏃‍♀‍➡' => 'bežkyňa: smerom doprava',
    '🏃‍♂‍➡' => 'bežec: smerom doprava',
    '👩‍❤‍👨' => 'pár so srdcom: žena, muž',
    '👨‍❤‍👨' => 'pár so srdcom: muž, muž',
    '👩‍❤‍👩' => 'pár so srdcom: žena, žena',
    '👨‍👩‍👦' => 'rodina: muž, žena, chlapec',
    '👨‍👩‍👧' => 'rodina: muž, žena, dievča',
    '👨‍👨‍👦' => 'rodina: muž, muž, chlapec',
    '👨‍👨‍👧' => 'rodina: muž, muž, dievča',
    '👩‍👩‍👦' => 'rodina: žena, žena, chlapec',
    '👩‍👩‍👧' => 'rodina: žena, žena, dievča',
    '👨‍👦‍👦' => 'rodina: muž, chlapec, chlapec',
    '👨‍👧‍👦' => 'rodina: muž, dievča, chlapec',
    '👨‍👧‍👧' => 'rodina: muž, dievča, dievča',
    '👩‍👦‍👦' => 'rodina: žena, chlapec, chlapec',
    '👩‍👧‍👦' => 'rodina: žena, dievča, chlapec',
    '👩‍👧‍👧' => 'rodina: žena, dievča, dievča',
    '🧑‍🤝‍🧑' => 'ľudia držiaci sa za ruky',
    '🧑‍🧑‍🧒' => 'rodina: dospelý, dospelý, dieťa',
    '🧑‍🧒‍🧒' => 'rodina: dospelý, dieťa, dieťa',
    '🧑🏻‍🦰' => 'dospelý: svetlý tón pleti, ryšavé vlasy',
    '🧑🏼‍🦰' => 'dospelý: stredne svetlý tón pleti, ryšavé vlasy',
    '🧑🏽‍🦰' => 'dospelý: stredný tón pleti, ryšavé vlasy',
    '🧑🏾‍🦰' => 'dospelý: stredne tmavý tón pleti, ryšavé vlasy',
    '🧑🏿‍🦰' => 'dospelý: tmavý tón pleti, ryšavé vlasy',
    '🧑🏻‍🦱' => 'dospelý: svetlý tón pleti, kučeravé vlasy',
    '🧑🏼‍🦱' => 'dospelý: stredne svetlý tón pleti, kučeravé vlasy',
    '🧑🏽‍🦱' => 'dospelý: stredný tón pleti, kučeravé vlasy',
    '🧑🏾‍🦱' => 'dospelý: stredne tmavý tón pleti, kučeravé vlasy',
    '🧑🏿‍🦱' => 'dospelý: tmavý tón pleti, kučeravé vlasy',
    '🧑🏻‍🦳' => 'dospelý: svetlý tón pleti, sivé vlasy',
    '🧑🏼‍🦳' => 'dospelý: stredne svetlý tón pleti, sivé vlasy',
    '🧑🏽‍🦳' => 'dospelý: stredný tón pleti, sivé vlasy',
    '🧑🏾‍🦳' => 'dospelý: stredne tmavý tón pleti, sivé vlasy',
    '🧑🏿‍🦳' => 'dospelý: tmavý tón pleti, sivé vlasy',
    '🧑🏻‍🦲' => 'dospelý: svetlý tón pleti, holá hlava',
    '🧑🏼‍🦲' => 'dospelý: stredne svetlý tón pleti, holá hlava',
    '🧑🏽‍🦲' => 'dospelý: stredný tón pleti, holá hlava',
    '🧑🏾‍🦲' => 'dospelý: stredne tmavý tón pleti, holá hlava',
    '🧑🏿‍🦲' => 'dospelý: tmavý tón pleti, holá hlava',
    '🧑🏻‍🩰' => 'baletka: svetlý tón pleti',
    '🧑🏼‍🩰' => 'baletka: stredne svetlý tón pleti',
    '🧑🏽‍🩰' => 'baletka: stredný tón pleti',
    '🧑🏾‍🩰' => 'baletka: stredne tmavý tón pleti',
    '🧑🏿‍🩰' => 'baletka: tmavý tón pleti',
    '🧔🏻‍♂' => 'bradatý muž: svetlý tón pleti',
    '🧔🏼‍♂' => 'bradatý muž: stredne svetlý tón pleti',
    '🧔🏽‍♂' => 'bradatý muž: stredný tón pleti',
    '🧔🏾‍♂' => 'bradatý muž: stredne tmavý tón pleti',
    '🧔🏿‍♂' => 'bradatý muž: tmavý tón pleti',
    '👱🏻‍♂' => 'blondín: svetlý tón pleti',
    '👱🏼‍♂' => 'blondín: stredne svetlý tón pleti',
    '👱🏽‍♂' => 'blondín: stredný tón pleti',
    '👱🏾‍♂' => 'blondín: stredne tmavý tón pleti',
    '👱🏿‍♂' => 'blondín: tmavý tón pleti',
    '👨🏻‍🦰' => 'muž: svetlý tón pleti, ryšavé vlasy',
    '👨🏼‍🦰' => 'muž: stredne svetlý tón pleti, ryšavé vlasy',
    '👨🏽‍🦰' => 'muž: stredný tón pleti, ryšavé vlasy',
    '👨🏾‍🦰' => 'muž: stredne tmavý tón pleti, ryšavé vlasy',
    '👨🏿‍🦰' => 'muž: tmavý tón pleti, ryšavé vlasy',
    '👨🏻‍🦱' => 'muž: svetlý tón pleti, kučeravé vlasy',
    '👨🏼‍🦱' => 'muž: stredne svetlý tón pleti, kučeravé vlasy',
    '👨🏽‍🦱' => 'muž: stredný tón pleti, kučeravé vlasy',
    '👨🏾‍🦱' => 'muž: stredne tmavý tón pleti, kučeravé vlasy',
    '👨🏿‍🦱' => 'muž: tmavý tón pleti, kučeravé vlasy',
    '👨🏻‍🦳' => 'muž: svetlý tón pleti, sivé vlasy',
    '👨🏼‍🦳' => 'muž: stredne svetlý tón pleti, sivé vlasy',
    '👨🏽‍🦳' => 'muž: stredný tón pleti, sivé vlasy',
    '👨🏾‍🦳' => 'muž: stredne tmavý tón pleti, sivé vlasy',
    '👨🏿‍🦳' => 'muž: tmavý tón pleti, sivé vlasy',
    '👨🏻‍🦲' => 'muž: svetlý tón pleti, holá hlava',
    '👨🏼‍🦲' => 'muž: stredne svetlý tón pleti, holá hlava',
    '👨🏽‍🦲' => 'muž: stredný tón pleti, holá hlava',
    '👨🏾‍🦲' => 'muž: stredne tmavý tón pleti, holá hlava',
    '👨🏿‍🦲' => 'muž: tmavý tón pleti, holá hlava',
    '🧔🏻‍♀' => 'bradatá žena: svetlý tón pleti',
    '🧔🏼‍♀' => 'bradatá žena: stredne svetlý tón pleti',
    '🧔🏽‍♀' => 'bradatá žena: stredný tón pleti',
    '🧔🏾‍♀' => 'bradatá žena: stredne tmavý tón pleti',
    '🧔🏿‍♀' => 'bradatá žena: tmavý tón pleti',
    '👱🏻‍♀' => 'blondína: svetlý tón pleti',
    '👱🏼‍♀' => 'blondína: stredne svetlý tón pleti',
    '👱🏽‍♀' => 'blondína: stredný tón pleti',
    '👱🏾‍♀' => 'blondína: stredne tmavý tón pleti',
    '👱🏿‍♀' => 'blondína: tmavý tón pleti',
    '👩🏻‍🦰' => 'žena: svetlý tón pleti, ryšavé vlasy',
    '👩🏼‍🦰' => 'žena: stredne svetlý tón pleti, ryšavé vlasy',
    '👩🏽‍🦰' => 'žena: stredný tón pleti, ryšavé vlasy',
    '👩🏾‍🦰' => 'žena: stredne tmavý tón pleti, ryšavé vlasy',
    '👩🏿‍🦰' => 'žena: tmavý tón pleti, ryšavé vlasy',
    '👩🏻‍🦱' => 'žena: svetlý tón pleti, kučeravé vlasy',
    '👩🏼‍🦱' => 'žena: stredne svetlý tón pleti, kučeravé vlasy',
    '👩🏽‍🦱' => 'žena: stredný tón pleti, kučeravé vlasy',
    '👩🏾‍🦱' => 'žena: stredne tmavý tón pleti, kučeravé vlasy',
    '👩🏿‍🦱' => 'žena: tmavý tón pleti, kučeravé vlasy',
    '👩🏻‍🦳' => 'žena: svetlý tón pleti, sivé vlasy',
    '👩🏼‍🦳' => 'žena: stredne svetlý tón pleti, sivé vlasy',
    '👩🏽‍🦳' => 'žena: stredný tón pleti, sivé vlasy',
    '👩🏾‍🦳' => 'žena: stredne tmavý tón pleti, sivé vlasy',
    '👩🏿‍🦳' => 'žena: tmavý tón pleti, sivé vlasy',
    '👩🏻‍🦲' => 'žena: svetlý tón pleti, holá hlava',
    '👩🏼‍🦲' => 'žena: stredne svetlý tón pleti, holá hlava',
    '👩🏽‍🦲' => 'žena: stredný tón pleti, holá hlava',
    '👩🏾‍🦲' => 'žena: stredne tmavý tón pleti, holá hlava',
    '👩🏿‍🦲' => 'žena: tmavý tón pleti, holá hlava',
    '🙍🏻‍♂' => 'zamračený muž: svetlý tón pleti',
    '🙍🏼‍♂' => 'zamračený muž: stredne svetlý tón pleti',
    '🙍🏽‍♂' => 'zamračený muž: stredný tón pleti',
    '🙍🏾‍♂' => 'zamračený muž: stredne tmavý tón pleti',
    '🙍🏿‍♂' => 'zamračený muž: tmavý tón pleti',
    '🙍🏻‍♀' => 'zamračená žena: svetlý tón pleti',
    '🙍🏼‍♀' => 'zamračená žena: stredne svetlý tón pleti',
    '🙍🏽‍♀' => 'zamračená žena: stredný tón pleti',
    '🙍🏾‍♀' => 'zamračená žena: stredne tmavý tón pleti',
    '🙍🏿‍♀' => 'zamračená žena: tmavý tón pleti',
    '🙎🏻‍♂' => 'podráždený muž: svetlý tón pleti',
    '🙎🏼‍♂' => 'podráždený muž: stredne svetlý tón pleti',
    '🙎🏽‍♂' => 'podráždený muž: stredný tón pleti',
    '🙎🏾‍♂' => 'podráždený muž: stredne tmavý tón pleti',
    '🙎🏿‍♂' => 'podráždený muž: tmavý tón pleti',
    '🙎🏻‍♀' => 'podráždená žena: svetlý tón pleti',
    '🙎🏼‍♀' => 'podráždená žena: stredne svetlý tón pleti',
    '🙎🏽‍♀' => 'podráždená žena: stredný tón pleti',
    '🙎🏾‍♀' => 'podráždená žena: stredne tmavý tón pleti',
    '🙎🏿‍♀' => 'podráždená žena: tmavý tón pleti',
    '🙅🏻‍♂' => 'muž s prekríženými rukami: svetlý tón pleti',
    '🙅🏼‍♂' => 'muž s prekríženými rukami: stredne svetlý tón pleti',
    '🙅🏽‍♂' => 'muž s prekríženými rukami: stredný tón pleti',
    '🙅🏾‍♂' => 'muž s prekríženými rukami: stredne tmavý tón pleti',
    '🙅🏿‍♂' => 'muž s prekríženými rukami: tmavý tón pleti',
    '🙅🏻‍♀' => 'žena s prekríženými rukami: svetlý tón pleti',
    '🙅🏼‍♀' => 'žena s prekríženými rukami: stredne svetlý tón pleti',
    '🙅🏽‍♀' => 'žena s prekríženými rukami: stredný tón pleti',
    '🙅🏾‍♀' => 'žena s prekríženými rukami: stredne tmavý tón pleti',
    '🙅🏿‍♀' => 'žena s prekríženými rukami: tmavý tón pleti',
    '🙆🏻‍♂' => 'muž s rukami nad hlavou: svetlý tón pleti',
    '🙆🏼‍♂' => 'muž s rukami nad hlavou: stredne svetlý tón pleti',
    '🙆🏽‍♂' => 'muž s rukami nad hlavou: stredný tón pleti',
    '🙆🏾‍♂' => 'muž s rukami nad hlavou: stredne tmavý tón pleti',
    '🙆🏿‍♂' => 'muž s rukami nad hlavou: tmavý tón pleti',
    '🙆🏻‍♀' => 'žena s rukami nad hlavou: svetlý tón pleti',
    '🙆🏼‍♀' => 'žena s rukami nad hlavou: stredne svetlý tón pleti',
    '🙆🏽‍♀' => 'žena s rukami nad hlavou: stredný tón pleti',
    '🙆🏾‍♀' => 'žena s rukami nad hlavou: stredne tmavý tón pleti',
    '🙆🏿‍♀' => 'žena s rukami nad hlavou: tmavý tón pleti',
    '💁🏻‍♂' => 'muž s nastavenou dlaňou: svetlý tón pleti',
    '💁🏼‍♂' => 'muž s nastavenou dlaňou: stredne svetlý tón pleti',
    '💁🏽‍♂' => 'muž s nastavenou dlaňou: stredný tón pleti',
    '💁🏾‍♂' => 'muž s nastavenou dlaňou: stredne tmavý tón pleti',
    '💁🏿‍♂' => 'muž s nastavenou dlaňou: tmavý tón pleti',
    '💁🏻‍♀' => 'žena s nastavenou dlaňou: svetlý tón pleti',
    '💁🏼‍♀' => 'žena s nastavenou dlaňou: stredne svetlý tón pleti',
    '💁🏽‍♀' => 'žena s nastavenou dlaňou: stredný tón pleti',
    '💁🏾‍♀' => 'žena s nastavenou dlaňou: stredne tmavý tón pleti',
    '💁🏿‍♀' => 'žena s nastavenou dlaňou: tmavý tón pleti',
    '🙋🏻‍♂' => 'muž so zdvihnutou rukou: svetlý tón pleti',
    '🙋🏼‍♂' => 'muž so zdvihnutou rukou: stredne svetlý tón pleti',
    '🙋🏽‍♂' => 'muž so zdvihnutou rukou: stredný tón pleti',
    '🙋🏾‍♂' => 'muž so zdvihnutou rukou: stredne tmavý tón pleti',
    '🙋🏿‍♂' => 'muž so zdvihnutou rukou: tmavý tón pleti',
    '🙋🏻‍♀' => 'žena so zdvihnutou rukou: svetlý tón pleti',
    '🙋🏼‍♀' => 'žena so zdvihnutou rukou: stredne svetlý tón pleti',
    '🙋🏽‍♀' => 'žena so zdvihnutou rukou: stredný tón pleti',
    '🙋🏾‍♀' => 'žena so zdvihnutou rukou: stredne tmavý tón pleti',
    '🙋🏿‍♀' => 'žena so zdvihnutou rukou: tmavý tón pleti',
    '🧏🏻‍♂' => 'nepočujúci muž: svetlý tón pleti',
    '🧏🏼‍♂' => 'nepočujúci muž: stredne svetlý tón pleti',
    '🧏🏽‍♂' => 'nepočujúci muž: stredný tón pleti',
    '🧏🏾‍♂' => 'nepočujúci muž: stredne tmavý tón pleti',
    '🧏🏿‍♂' => 'nepočujúci muž: tmavý tón pleti',
    '🧏🏻‍♀' => 'nepočujúca žena: svetlý tón pleti',
    '🧏🏼‍♀' => 'nepočujúca žena: stredne svetlý tón pleti',
    '🧏🏽‍♀' => 'nepočujúca žena: stredný tón pleti',
    '🧏🏾‍♀' => 'nepočujúca žena: stredne tmavý tón pleti',
    '🧏🏿‍♀' => 'nepočujúca žena: tmavý tón pleti',
    '🙇🏻‍♂' => 'klaňajúci sa muž: svetlý tón pleti',
    '🙇🏼‍♂' => 'klaňajúci sa muž: stredne svetlý tón pleti',
    '🙇🏽‍♂' => 'klaňajúci sa muž: stredný tón pleti',
    '🙇🏾‍♂' => 'klaňajúci sa muž: stredne tmavý tón pleti',
    '🙇🏿‍♂' => 'klaňajúci sa muž: tmavý tón pleti',
    '🙇🏻‍♀' => 'klaňajúca sa žena: svetlý tón pleti',
    '🙇🏼‍♀' => 'klaňajúca sa žena: stredne svetlý tón pleti',
    '🙇🏽‍♀' => 'klaňajúca sa žena: stredný tón pleti',
    '🙇🏾‍♀' => 'klaňajúca sa žena: stredne tmavý tón pleti',
    '🙇🏿‍♀' => 'klaňajúca sa žena: tmavý tón pleti',
    '🤦🏻‍♂' => 'muž chytajúci sa za hlavu: svetlý tón pleti',
    '🤦🏼‍♂' => 'muž chytajúci sa za hlavu: stredne svetlý tón pleti',
    '🤦🏽‍♂' => 'muž chytajúci sa za hlavu: stredný tón pleti',
    '🤦🏾‍♂' => 'muž chytajúci sa za hlavu: stredne tmavý tón pleti',
    '🤦🏿‍♂' => 'muž chytajúci sa za hlavu: tmavý tón pleti',
    '🤦🏻‍♀' => 'žena chytajúca sa za hlavu: svetlý tón pleti',
    '🤦🏼‍♀' => 'žena chytajúca sa za hlavu: stredne svetlý tón pleti',
    '🤦🏽‍♀' => 'žena chytajúca sa za hlavu: stredný tón pleti',
    '🤦🏾‍♀' => 'žena chytajúca sa za hlavu: stredne tmavý tón pleti',
    '🤦🏿‍♀' => 'žena chytajúca sa za hlavu: tmavý tón pleti',
    '🤷🏻‍♂' => 'muž krčiaci plecami: svetlý tón pleti',
    '🤷🏼‍♂' => 'muž krčiaci plecami: stredne svetlý tón pleti',
    '🤷🏽‍♂' => 'muž krčiaci plecami: stredný tón pleti',
    '🤷🏾‍♂' => 'muž krčiaci plecami: stredne tmavý tón pleti',
    '🤷🏿‍♂' => 'muž krčiaci plecami: tmavý tón pleti',
    '🤷🏻‍♀' => 'žena krčiaca plecami: svetlý tón pleti',
    '🤷🏼‍♀' => 'žena krčiaca plecami: stredne svetlý tón pleti',
    '🤷🏽‍♀' => 'žena krčiaca plecami: stredný tón pleti',
    '🤷🏾‍♀' => 'žena krčiaca plecami: stredne tmavý tón pleti',
    '🤷🏿‍♀' => 'žena krčiaca plecami: tmavý tón pleti',
    '🧑🏻‍⚕' => 'zdravotník: svetlý tón pleti',
    '🧑🏼‍⚕' => 'zdravotník: stredne svetlý tón pleti',
    '🧑🏽‍⚕' => 'zdravotník: stredný tón pleti',
    '🧑🏾‍⚕' => 'zdravotník: stredne tmavý tón pleti',
    '🧑🏿‍⚕' => 'zdravotník: tmavý tón pleti',
    '👨🏻‍⚕' => 'zdravotník muž: svetlý tón pleti',
    '👨🏼‍⚕' => 'zdravotník muž: stredne svetlý tón pleti',
    '👨🏽‍⚕' => 'zdravotník muž: stredný tón pleti',
    '👨🏾‍⚕' => 'zdravotník muž: stredne tmavý tón pleti',
    '👨🏿‍⚕' => 'zdravotník muž: tmavý tón pleti',
    '👩🏻‍⚕' => 'zdravotníčka: svetlý tón pleti',
    '👩🏼‍⚕' => 'zdravotníčka: stredne svetlý tón pleti',
    '👩🏽‍⚕' => 'zdravotníčka: stredný tón pleti',
    '👩🏾‍⚕' => 'zdravotníčka: stredne tmavý tón pleti',
    '👩🏿‍⚕' => 'zdravotníčka: tmavý tón pleti',
    '🧑🏻‍🎓' => 'študent: svetlý tón pleti',
    '🧑🏼‍🎓' => 'študent: stredne svetlý tón pleti',
    '🧑🏽‍🎓' => 'študent: stredný tón pleti',
    '🧑🏾‍🎓' => 'študent: stredne tmavý tón pleti',
    '🧑🏿‍🎓' => 'študent: tmavý tón pleti',
    '👨🏻‍🎓' => 'študent muž: svetlý tón pleti',
    '👨🏼‍🎓' => 'študent muž: stredne svetlý tón pleti',
    '👨🏽‍🎓' => 'študent muž: stredný tón pleti',
    '👨🏾‍🎓' => 'študent muž: stredne tmavý tón pleti',
    '👨🏿‍🎓' => 'študent muž: tmavý tón pleti',
    '👩🏻‍🎓' => 'študentka: svetlý tón pleti',
    '👩🏼‍🎓' => 'študentka: stredne svetlý tón pleti',
    '👩🏽‍🎓' => 'študentka: stredný tón pleti',
    '👩🏾‍🎓' => 'študentka: stredne tmavý tón pleti',
    '👩🏿‍🎓' => 'študentka: tmavý tón pleti',
    '🧑🏻‍🏫' => 'učiteľ: svetlý tón pleti',
    '🧑🏼‍🏫' => 'učiteľ: stredne svetlý tón pleti',
    '🧑🏽‍🏫' => 'učiteľ: stredný tón pleti',
    '🧑🏾‍🏫' => 'učiteľ: stredne tmavý tón pleti',
    '🧑🏿‍🏫' => 'učiteľ: tmavý tón pleti',
    '👨🏻‍🏫' => 'učiteľ muž: svetlý tón pleti',
    '👨🏼‍🏫' => 'učiteľ muž: stredne svetlý tón pleti',
    '👨🏽‍🏫' => 'učiteľ muž: stredný tón pleti',
    '👨🏾‍🏫' => 'učiteľ muž: stredne tmavý tón pleti',
    '👨🏿‍🏫' => 'učiteľ muž: tmavý tón pleti',
    '👩🏻‍🏫' => 'učiteľka: svetlý tón pleti',
    '👩🏼‍🏫' => 'učiteľka: stredne svetlý tón pleti',
    '👩🏽‍🏫' => 'učiteľka: stredný tón pleti',
    '👩🏾‍🏫' => 'učiteľka: stredne tmavý tón pleti',
    '👩🏿‍🏫' => 'učiteľka: tmavý tón pleti',
    '🧑🏻‍⚖' => 'sudca: svetlý tón pleti',
    '🧑🏼‍⚖' => 'sudca: stredne svetlý tón pleti',
    '🧑🏽‍⚖' => 'sudca: stredný tón pleti',
    '🧑🏾‍⚖' => 'sudca: stredne tmavý tón pleti',
    '🧑🏿‍⚖' => 'sudca: tmavý tón pleti',
    '👨🏻‍⚖' => 'sudca muž: svetlý tón pleti',
    '👨🏼‍⚖' => 'sudca muž: stredne svetlý tón pleti',
    '👨🏽‍⚖' => 'sudca muž: stredný tón pleti',
    '👨🏾‍⚖' => 'sudca muž: stredne tmavý tón pleti',
    '👨🏿‍⚖' => 'sudca muž: tmavý tón pleti',
    '👩🏻‍⚖' => 'sudkyňa: svetlý tón pleti',
    '👩🏼‍⚖' => 'sudkyňa: stredne svetlý tón pleti',
    '👩🏽‍⚖' => 'sudkyňa: stredný tón pleti',
    '👩🏾‍⚖' => 'sudkyňa: stredne tmavý tón pleti',
    '👩🏿‍⚖' => 'sudkyňa: tmavý tón pleti',
    '🧑🏻‍🌾' => 'roľník: svetlý tón pleti',
    '🧑🏼‍🌾' => 'roľník: stredne svetlý tón pleti',
    '🧑🏽‍🌾' => 'roľník: stredný tón pleti',
    '🧑🏾‍🌾' => 'roľník: stredne tmavý tón pleti',
    '🧑🏿‍🌾' => 'roľník: tmavý tón pleti',
    '👨🏻‍🌾' => 'roľník muž: svetlý tón pleti',
    '👨🏼‍🌾' => 'roľník muž: stredne svetlý tón pleti',
    '👨🏽‍🌾' => 'roľník muž: stredný tón pleti',
    '👨🏾‍🌾' => 'roľník muž: stredne tmavý tón pleti',
    '👨🏿‍🌾' => 'roľník muž: tmavý tón pleti',
    '👩🏻‍🌾' => 'roľníčka: svetlý tón pleti',
    '👩🏼‍🌾' => 'roľníčka: stredne svetlý tón pleti',
    '👩🏽‍🌾' => 'roľníčka: stredný tón pleti',
    '👩🏾‍🌾' => 'roľníčka: stredne tmavý tón pleti',
    '👩🏿‍🌾' => 'roľníčka: tmavý tón pleti',
    '🧑🏻‍🍳' => 'kuchár: svetlý tón pleti',
    '🧑🏼‍🍳' => 'kuchár: stredne svetlý tón pleti',
    '🧑🏽‍🍳' => 'kuchár: stredný tón pleti',
    '🧑🏾‍🍳' => 'kuchár: stredne tmavý tón pleti',
    '🧑🏿‍🍳' => 'kuchár: tmavý tón pleti',
    '👨🏻‍🍳' => 'kuchár muž: svetlý tón pleti',
    '👨🏼‍🍳' => 'kuchár muž: stredne svetlý tón pleti',
    '👨🏽‍🍳' => 'kuchár muž: stredný tón pleti',
    '👨🏾‍🍳' => 'kuchár muž: stredne tmavý tón pleti',
    '👨🏿‍🍳' => 'kuchár muž: tmavý tón pleti',
    '👩🏻‍🍳' => 'kuchárka: svetlý tón pleti',
    '👩🏼‍🍳' => 'kuchárka: stredne svetlý tón pleti',
    '👩🏽‍🍳' => 'kuchárka: stredný tón pleti',
    '👩🏾‍🍳' => 'kuchárka: stredne tmavý tón pleti',
    '👩🏿‍🍳' => 'kuchárka: tmavý tón pleti',
    '🧑🏻‍🔧' => 'remeselník: svetlý tón pleti',
    '🧑🏼‍🔧' => 'remeselník: stredne svetlý tón pleti',
    '🧑🏽‍🔧' => 'remeselník: stredný tón pleti',
    '🧑🏾‍🔧' => 'remeselník: stredne tmavý tón pleti',
    '🧑🏿‍🔧' => 'remeselník: tmavý tón pleti',
    '👨🏻‍🔧' => 'remeselník muž: svetlý tón pleti',
    '👨🏼‍🔧' => 'remeselník muž: stredne svetlý tón pleti',
    '👨🏽‍🔧' => 'remeselník muž: stredný tón pleti',
    '👨🏾‍🔧' => 'remeselník muž: stredne tmavý tón pleti',
    '👨🏿‍🔧' => 'remeselník muž: tmavý tón pleti',
    '👩🏻‍🔧' => 'remeselníčka: svetlý tón pleti',
    '👩🏼‍🔧' => 'remeselníčka: stredne svetlý tón pleti',
    '👩🏽‍🔧' => 'remeselníčka: stredný tón pleti',
    '👩🏾‍🔧' => 'remeselníčka: stredne tmavý tón pleti',
    '👩🏿‍🔧' => 'remeselníčka: tmavý tón pleti',
    '🧑🏻‍🏭' => 'robotník: svetlý tón pleti',
    '🧑🏼‍🏭' => 'robotník: stredne svetlý tón pleti',
    '🧑🏽‍🏭' => 'robotník: stredný tón pleti',
    '🧑🏾‍🏭' => 'robotník: stredne tmavý tón pleti',
    '🧑🏿‍🏭' => 'robotník: tmavý tón pleti',
    '👨🏻‍🏭' => 'robotník muž: svetlý tón pleti',
    '👨🏼‍🏭' => 'robotník muž: stredne svetlý tón pleti',
    '👨🏽‍🏭' => 'robotník muž: stredný tón pleti',
    '👨🏾‍🏭' => 'robotník muž: stredne tmavý tón pleti',
    '👨🏿‍🏭' => 'robotník muž: tmavý tón pleti',
    '👩🏻‍🏭' => 'robotníčka: svetlý tón pleti',
    '👩🏼‍🏭' => 'robotníčka: stredne svetlý tón pleti',
    '👩🏽‍🏭' => 'robotníčka: stredný tón pleti',
    '👩🏾‍🏭' => 'robotníčka: stredne tmavý tón pleti',
    '👩🏿‍🏭' => 'robotníčka: tmavý tón pleti',
    '🧑🏻‍💼' => 'pracovník v kancelárii: svetlý tón pleti',
    '🧑🏼‍💼' => 'pracovník v kancelárii: stredne svetlý tón pleti',
    '🧑🏽‍💼' => 'pracovník v kancelárii: stredný tón pleti',
    '🧑🏾‍💼' => 'pracovník v kancelárii: stredne tmavý tón pleti',
    '🧑🏿‍💼' => 'pracovník v kancelárii: tmavý tón pleti',
    '👨🏻‍💼' => 'pracovník v kancelárii muž: svetlý tón pleti',
    '👨🏼‍💼' => 'pracovník v kancelárii muž: stredne svetlý tón pleti',
    '👨🏽‍💼' => 'pracovník v kancelárii muž: stredný tón pleti',
    '👨🏾‍💼' => 'pracovník v kancelárii muž: stredne tmavý tón pleti',
    '👨🏿‍💼' => 'pracovník v kancelárii muž: tmavý tón pleti',
    '👩🏻‍💼' => 'pracovníčka v kancelárii: svetlý tón pleti',
    '👩🏼‍💼' => 'pracovníčka v kancelárii: stredne svetlý tón pleti',
    '👩🏽‍💼' => 'pracovníčka v kancelárii: stredný tón pleti',
    '👩🏾‍💼' => 'pracovníčka v kancelárii: stredne tmavý tón pleti',
    '👩🏿‍💼' => 'pracovníčka v kancelárii: tmavý tón pleti',
    '🧑🏻‍🔬' => 'vedec: svetlý tón pleti',
    '🧑🏼‍🔬' => 'vedec: stredne svetlý tón pleti',
    '🧑🏽‍🔬' => 'vedec: stredný tón pleti',
    '🧑🏾‍🔬' => 'vedec: stredne tmavý tón pleti',
    '🧑🏿‍🔬' => 'vedec: tmavý tón pleti',
    '👨🏻‍🔬' => 'vedec muž: svetlý tón pleti',
    '👨🏼‍🔬' => 'vedec muž: stredne svetlý tón pleti',
    '👨🏽‍🔬' => 'vedec muž: stredný tón pleti',
    '👨🏾‍🔬' => 'vedec muž: stredne tmavý tón pleti',
    '👨🏿‍🔬' => 'vedec muž: tmavý tón pleti',
    '👩🏻‍🔬' => 'vedkyňa: svetlý tón pleti',
    '👩🏼‍🔬' => 'vedkyňa: stredne svetlý tón pleti',
    '👩🏽‍🔬' => 'vedkyňa: stredný tón pleti',
    '👩🏾‍🔬' => 'vedkyňa: stredne tmavý tón pleti',
    '👩🏿‍🔬' => 'vedkyňa: tmavý tón pleti',
    '🧑🏻‍💻' => 'programátor: svetlý tón pleti',
    '🧑🏼‍💻' => 'programátor: stredne svetlý tón pleti',
    '🧑🏽‍💻' => 'programátor: stredný tón pleti',
    '🧑🏾‍💻' => 'programátor: stredne tmavý tón pleti',
    '🧑🏿‍💻' => 'programátor: tmavý tón pleti',
    '👨🏻‍💻' => 'programátor muž: svetlý tón pleti',
    '👨🏼‍💻' => 'programátor muž: stredne svetlý tón pleti',
    '👨🏽‍💻' => 'programátor muž: stredný tón pleti',
    '👨🏾‍💻' => 'programátor muž: stredne tmavý tón pleti',
    '👨🏿‍💻' => 'programátor muž: tmavý tón pleti',
    '👩🏻‍💻' => 'programátorka: svetlý tón pleti',
    '👩🏼‍💻' => 'programátorka: stredne svetlý tón pleti',
    '👩🏽‍💻' => 'programátorka: stredný tón pleti',
    '👩🏾‍💻' => 'programátorka: stredne tmavý tón pleti',
    '👩🏿‍💻' => 'programátorka: tmavý tón pleti',
    '🧑🏻‍🎤' => 'spevák: svetlý tón pleti',
    '🧑🏼‍🎤' => 'spevák: stredne svetlý tón pleti',
    '🧑🏽‍🎤' => 'spevák: stredný tón pleti',
    '🧑🏾‍🎤' => 'spevák: stredne tmavý tón pleti',
    '🧑🏿‍🎤' => 'spevák: tmavý tón pleti',
    '👨🏻‍🎤' => 'spevák muž: svetlý tón pleti',
    '👨🏼‍🎤' => 'spevák muž: stredne svetlý tón pleti',
    '👨🏽‍🎤' => 'spevák muž: stredný tón pleti',
    '👨🏾‍🎤' => 'spevák muž: stredne tmavý tón pleti',
    '👨🏿‍🎤' => 'spevák muž: tmavý tón pleti',
    '👩🏻‍🎤' => 'speváčka: svetlý tón pleti',
    '👩🏼‍🎤' => 'speváčka: stredne svetlý tón pleti',
    '👩🏽‍🎤' => 'speváčka: stredný tón pleti',
    '👩🏾‍🎤' => 'speváčka: stredne tmavý tón pleti',
    '👩🏿‍🎤' => 'speváčka: tmavý tón pleti',
    '🧑🏻‍🎨' => 'maliar: svetlý tón pleti',
    '🧑🏼‍🎨' => 'maliar: stredne svetlý tón pleti',
    '🧑🏽‍🎨' => 'maliar: stredný tón pleti',
    '🧑🏾‍🎨' => 'maliar: stredne tmavý tón pleti',
    '🧑🏿‍🎨' => 'maliar: tmavý tón pleti',
    '👨🏻‍🎨' => 'maliar muž: svetlý tón pleti',
    '👨🏼‍🎨' => 'maliar muž: stredne svetlý tón pleti',
    '👨🏽‍🎨' => 'maliar muž: stredný tón pleti',
    '👨🏾‍🎨' => 'maliar muž: stredne tmavý tón pleti',
    '👨🏿‍🎨' => 'maliar muž: tmavý tón pleti',
    '👩🏻‍🎨' => 'maliarka: svetlý tón pleti',
    '👩🏼‍🎨' => 'maliarka: stredne svetlý tón pleti',
    '👩🏽‍🎨' => 'maliarka: stredný tón pleti',
    '👩🏾‍🎨' => 'maliarka: stredne tmavý tón pleti',
    '👩🏿‍🎨' => 'maliarka: tmavý tón pleti',
    '🧑🏻‍✈' => 'pilot: svetlý tón pleti',
    '🧑🏼‍✈' => 'pilot: stredne svetlý tón pleti',
    '🧑🏽‍✈' => 'pilot: stredný tón pleti',
    '🧑🏾‍✈' => 'pilot: stredne tmavý tón pleti',
    '🧑🏿‍✈' => 'pilot: tmavý tón pleti',
    '👨🏻‍✈' => 'pilot muž: svetlý tón pleti',
    '👨🏼‍✈' => 'pilot muž: stredne svetlý tón pleti',
    '👨🏽‍✈' => 'pilot muž: stredný tón pleti',
    '👨🏾‍✈' => 'pilot muž: stredne tmavý tón pleti',
    '👨🏿‍✈' => 'pilot muž: tmavý tón pleti',
    '👩🏻‍✈' => 'pilotka: svetlý tón pleti',
    '👩🏼‍✈' => 'pilotka: stredne svetlý tón pleti',
    '👩🏽‍✈' => 'pilotka: stredný tón pleti',
    '👩🏾‍✈' => 'pilotka: stredne tmavý tón pleti',
    '👩🏿‍✈' => 'pilotka: tmavý tón pleti',
    '🧑🏻‍🚀' => 'kozmonaut: svetlý tón pleti',
    '🧑🏼‍🚀' => 'kozmonaut: stredne svetlý tón pleti',
    '🧑🏽‍🚀' => 'kozmonaut: stredný tón pleti',
    '🧑🏾‍🚀' => 'kozmonaut: stredne tmavý tón pleti',
    '🧑🏿‍🚀' => 'kozmonaut: tmavý tón pleti',
    '👨🏻‍🚀' => 'kozmonaut muž: svetlý tón pleti',
    '👨🏼‍🚀' => 'kozmonaut muž: stredne svetlý tón pleti',
    '👨🏽‍🚀' => 'kozmonaut muž: stredný tón pleti',
    '👨🏾‍🚀' => 'kozmonaut muž: stredne tmavý tón pleti',
    '👨🏿‍🚀' => 'kozmonaut muž: tmavý tón pleti',
    '👩🏻‍🚀' => 'kozmonautka: svetlý tón pleti',
    '👩🏼‍🚀' => 'kozmonautka: stredne svetlý tón pleti',
    '👩🏽‍🚀' => 'kozmonautka: stredný tón pleti',
    '👩🏾‍🚀' => 'kozmonautka: stredne tmavý tón pleti',
    '👩🏿‍🚀' => 'kozmonautka: tmavý tón pleti',
    '🧑🏻‍🚒' => 'hasič: svetlý tón pleti',
    '🧑🏼‍🚒' => 'hasič: stredne svetlý tón pleti',
    '🧑🏽‍🚒' => 'hasič: stredný tón pleti',
    '🧑🏾‍🚒' => 'hasič: stredne tmavý tón pleti',
    '🧑🏿‍🚒' => 'hasič: tmavý tón pleti',
    '👨🏻‍🚒' => 'hasič muž: svetlý tón pleti',
    '👨🏼‍🚒' => 'hasič muž: stredne svetlý tón pleti',
    '👨🏽‍🚒' => 'hasič muž: stredný tón pleti',
    '👨🏾‍🚒' => 'hasič muž: stredne tmavý tón pleti',
    '👨🏿‍🚒' => 'hasič muž: tmavý tón pleti',
    '👩🏻‍🚒' => 'hasička: svetlý tón pleti',
    '👩🏼‍🚒' => 'hasička: stredne svetlý tón pleti',
    '👩🏽‍🚒' => 'hasička: stredný tón pleti',
    '👩🏾‍🚒' => 'hasička: stredne tmavý tón pleti',
    '👩🏿‍🚒' => 'hasička: tmavý tón pleti',
    '👮🏻‍♂' => 'policajt muž: svetlý tón pleti',
    '👮🏼‍♂' => 'policajt muž: stredne svetlý tón pleti',
    '👮🏽‍♂' => 'policajt muž: stredný tón pleti',
    '👮🏾‍♂' => 'policajt muž: stredne tmavý tón pleti',
    '👮🏿‍♂' => 'policajt muž: tmavý tón pleti',
    '👮🏻‍♀' => 'policajtka: svetlý tón pleti',
    '👮🏼‍♀' => 'policajtka: stredne svetlý tón pleti',
    '👮🏽‍♀' => 'policajtka: stredný tón pleti',
    '👮🏾‍♀' => 'policajtka: stredne tmavý tón pleti',
    '👮🏿‍♀' => 'policajtka: tmavý tón pleti',
    '🕵🏻‍♂' => 'detektív muž: svetlý tón pleti',
    '🕵🏼‍♂' => 'detektív muž: stredne svetlý tón pleti',
    '🕵🏽‍♂' => 'detektív muž: stredný tón pleti',
    '🕵🏾‍♂' => 'detektív muž: stredne tmavý tón pleti',
    '🕵🏿‍♂' => 'detektív muž: tmavý tón pleti',
    '🕵🏻‍♀' => 'detektívka: svetlý tón pleti',
    '🕵🏼‍♀' => 'detektívka: stredne svetlý tón pleti',
    '🕵🏽‍♀' => 'detektívka: stredný tón pleti',
    '🕵🏾‍♀' => 'detektívka: stredne tmavý tón pleti',
    '🕵🏿‍♀' => 'detektívka: tmavý tón pleti',
    '💂🏻‍♂' => 'strážca: svetlý tón pleti',
    '💂🏼‍♂' => 'strážca: stredne svetlý tón pleti',
    '💂🏽‍♂' => 'strážca: stredný tón pleti',
    '💂🏾‍♂' => 'strážca: stredne tmavý tón pleti',
    '💂🏿‍♂' => 'strážca: tmavý tón pleti',
    '💂🏻‍♀' => 'strážkyňa: svetlý tón pleti',
    '💂🏼‍♀' => 'strážkyňa: stredne svetlý tón pleti',
    '💂🏽‍♀' => 'strážkyňa: stredný tón pleti',
    '💂🏾‍♀' => 'strážkyňa: stredne tmavý tón pleti',
    '💂🏿‍♀' => 'strážkyňa: tmavý tón pleti',
    '👷🏻‍♂' => 'stavbár: svetlý tón pleti',
    '👷🏼‍♂' => 'stavbár: stredne svetlý tón pleti',
    '👷🏽‍♂' => 'stavbár: stredný tón pleti',
    '👷🏾‍♂' => 'stavbár: stredne tmavý tón pleti',
    '👷🏿‍♂' => 'stavbár: tmavý tón pleti',
    '👷🏻‍♀' => 'stavbárka: svetlý tón pleti',
    '👷🏼‍♀' => 'stavbárka: stredne svetlý tón pleti',
    '👷🏽‍♀' => 'stavbárka: stredný tón pleti',
    '👷🏾‍♀' => 'stavbárka: stredne tmavý tón pleti',
    '👷🏿‍♀' => 'stavbárka: tmavý tón pleti',
    '👳🏻‍♂' => 'muž s turbanom: svetlý tón pleti',
    '👳🏼‍♂' => 'muž s turbanom: stredne svetlý tón pleti',
    '👳🏽‍♂' => 'muž s turbanom: stredný tón pleti',
    '👳🏾‍♂' => 'muž s turbanom: stredne tmavý tón pleti',
    '👳🏿‍♂' => 'muž s turbanom: tmavý tón pleti',
    '👳🏻‍♀' => 'žena s turbanom: svetlý tón pleti',
    '👳🏼‍♀' => 'žena s turbanom: stredne svetlý tón pleti',
    '👳🏽‍♀' => 'žena s turbanom: stredný tón pleti',
    '👳🏾‍♀' => 'žena s turbanom: stredne tmavý tón pleti',
    '👳🏿‍♀' => 'žena s turbanom: tmavý tón pleti',
    '🤵🏻‍♂' => 'muž v smokingu: svetlý tón pleti',
    '🤵🏼‍♂' => 'muž v smokingu: stredne svetlý tón pleti',
    '🤵🏽‍♂' => 'muž v smokingu: stredný tón pleti',
    '🤵🏾‍♂' => 'muž v smokingu: stredne tmavý tón pleti',
    '🤵🏿‍♂' => 'muž v smokingu: tmavý tón pleti',
    '🤵🏻‍♀' => 'žena v smokingu: svetlý tón pleti',
    '🤵🏼‍♀' => 'žena v smokingu: stredne svetlý tón pleti',
    '🤵🏽‍♀' => 'žena v smokingu: stredný tón pleti',
    '🤵🏾‍♀' => 'žena v smokingu: stredne tmavý tón pleti',
    '🤵🏿‍♀' => 'žena v smokingu: tmavý tón pleti',
    '👰🏻‍♂' => 'muž so závojom: svetlý tón pleti',
    '👰🏼‍♂' => 'muž so závojom: stredne svetlý tón pleti',
    '👰🏽‍♂' => 'muž so závojom: stredný tón pleti',
    '👰🏾‍♂' => 'muž so závojom: stredne tmavý tón pleti',
    '👰🏿‍♂' => 'muž so závojom: tmavý tón pleti',
    '👰🏻‍♀' => 'žena so závojom: svetlý tón pleti',
    '👰🏼‍♀' => 'žena so závojom: stredne svetlý tón pleti',
    '👰🏽‍♀' => 'žena so závojom: stredný tón pleti',
    '👰🏾‍♀' => 'žena so závojom: stredne tmavý tón pleti',
    '👰🏿‍♀' => 'žena so závojom: tmavý tón pleti',
    '👩🏻‍🍼' => 'žena kŕmiaca bábätko: svetlý tón pleti',
    '👩🏼‍🍼' => 'žena kŕmiaca bábätko: stredne svetlý tón pleti',
    '👩🏽‍🍼' => 'žena kŕmiaca bábätko: stredný tón pleti',
    '👩🏾‍🍼' => 'žena kŕmiaca bábätko: stredne tmavý tón pleti',
    '👩🏿‍🍼' => 'žena kŕmiaca bábätko: tmavý tón pleti',
    '👨🏻‍🍼' => 'muž kŕmiaci bábätko: svetlý tón pleti',
    '👨🏼‍🍼' => 'muž kŕmiaci bábätko: stredne svetlý tón pleti',
    '👨🏽‍🍼' => 'muž kŕmiaci bábätko: stredný tón pleti',
    '👨🏾‍🍼' => 'muž kŕmiaci bábätko: stredne tmavý tón pleti',
    '👨🏿‍🍼' => 'muž kŕmiaci bábätko: tmavý tón pleti',
    '🧑🏻‍🍼' => 'človek kŕmiaci bábätko: svetlý tón pleti',
    '🧑🏼‍🍼' => 'človek kŕmiaci bábätko: stredne svetlý tón pleti',
    '🧑🏽‍🍼' => 'človek kŕmiaci bábätko: stredný tón pleti',
    '🧑🏾‍🍼' => 'človek kŕmiaci bábätko: stredne tmavý tón pleti',
    '🧑🏿‍🍼' => 'človek kŕmiaci bábätko: tmavý tón pleti',
    '🧑🏻‍🎄' => 'Mx Santa: svetlý tón pleti',
    '🧑🏼‍🎄' => 'Mx Santa: stredne svetlý tón pleti',
    '🧑🏽‍🎄' => 'Mx Santa: stredný tón pleti',
    '🧑🏾‍🎄' => 'Mx Santa: stredne tmavý tón pleti',
    '🧑🏿‍🎄' => 'Mx Santa: tmavý tón pleti',
    '🦸🏻‍♂' => 'supermuž: svetlý tón pleti',
    '🦸🏼‍♂' => 'supermuž: stredne svetlý tón pleti',
    '🦸🏽‍♂' => 'supermuž: stredný tón pleti',
    '🦸🏾‍♂' => 'supermuž: stredne tmavý tón pleti',
    '🦸🏿‍♂' => 'supermuž: tmavý tón pleti',
    '🦸🏻‍♀' => 'superžena: svetlý tón pleti',
    '🦸🏼‍♀' => 'superžena: stredne svetlý tón pleti',
    '🦸🏽‍♀' => 'superžena: stredný tón pleti',
    '🦸🏾‍♀' => 'superžena: stredne tmavý tón pleti',
    '🦸🏿‍♀' => 'superžena: tmavý tón pleti',
    '🦹🏻‍♂' => 'superdarebák: svetlý tón pleti',
    '🦹🏼‍♂' => 'superdarebák: stredne svetlý tón pleti',
    '🦹🏽‍♂' => 'superdarebák: stredný tón pleti',
    '🦹🏾‍♂' => 'superdarebák: stredne tmavý tón pleti',
    '🦹🏿‍♂' => 'superdarebák: tmavý tón pleti',
    '🦹🏻‍♀' => 'superdarebáčka: svetlý tón pleti',
    '🦹🏼‍♀' => 'superdarebáčka: stredne svetlý tón pleti',
    '🦹🏽‍♀' => 'superdarebáčka: stredný tón pleti',
    '🦹🏾‍♀' => 'superdarebáčka: stredne tmavý tón pleti',
    '🦹🏿‍♀' => 'superdarebáčka: tmavý tón pleti',
    '🧙🏻‍♂' => 'čarodejník: svetlý tón pleti',
    '🧙🏼‍♂' => 'čarodejník: stredne svetlý tón pleti',
    '🧙🏽‍♂' => 'čarodejník: stredný tón pleti',
    '🧙🏾‍♂' => 'čarodejník: stredne tmavý tón pleti',
    '🧙🏿‍♂' => 'čarodejník: tmavý tón pleti',
    '🧙🏻‍♀' => 'čarodejníčka: svetlý tón pleti',
    '🧙🏼‍♀' => 'čarodejníčka: stredne svetlý tón pleti',
    '🧙🏽‍♀' => 'čarodejníčka: stredný tón pleti',
    '🧙🏾‍♀' => 'čarodejníčka: stredne tmavý tón pleti',
    '🧙🏿‍♀' => 'čarodejníčka: tmavý tón pleti',
    '🧚🏻‍♂' => 'škriatok: svetlý tón pleti',
    '🧚🏼‍♂' => 'škriatok: stredne svetlý tón pleti',
    '🧚🏽‍♂' => 'škriatok: stredný tón pleti',
    '🧚🏾‍♂' => 'škriatok: stredne tmavý tón pleti',
    '🧚🏿‍♂' => 'škriatok: tmavý tón pleti',
    '🧚🏻‍♀' => 'víla: svetlý tón pleti',
    '🧚🏼‍♀' => 'víla: stredne svetlý tón pleti',
    '🧚🏽‍♀' => 'víla: stredný tón pleti',
    '🧚🏾‍♀' => 'víla: stredne tmavý tón pleti',
    '🧚🏿‍♀' => 'víla: tmavý tón pleti',
    '🧛🏻‍♂' => 'upír: svetlý tón pleti',
    '🧛🏼‍♂' => 'upír: stredne svetlý tón pleti',
    '🧛🏽‍♂' => 'upír: stredný tón pleti',
    '🧛🏾‍♂' => 'upír: stredne tmavý tón pleti',
    '🧛🏿‍♂' => 'upír: tmavý tón pleti',
    '🧛🏻‍♀' => 'upírka: svetlý tón pleti',
    '🧛🏼‍♀' => 'upírka: stredne svetlý tón pleti',
    '🧛🏽‍♀' => 'upírka: stredný tón pleti',
    '🧛🏾‍♀' => 'upírka: stredne tmavý tón pleti',
    '🧛🏿‍♀' => 'upírka: tmavý tón pleti',
    '🧜🏻‍♂' => 'morský muž: svetlý tón pleti',
    '🧜🏼‍♂' => 'morský muž: stredne svetlý tón pleti',
    '🧜🏽‍♂' => 'morský muž: stredný tón pleti',
    '🧜🏾‍♂' => 'morský muž: stredne tmavý tón pleti',
    '🧜🏿‍♂' => 'morský muž: tmavý tón pleti',
    '🧜🏻‍♀' => 'morská panna: svetlý tón pleti',
    '🧜🏼‍♀' => 'morská panna: stredne svetlý tón pleti',
    '🧜🏽‍♀' => 'morská panna: stredný tón pleti',
    '🧜🏾‍♀' => 'morská panna: stredne tmavý tón pleti',
    '🧜🏿‍♀' => 'morská panna: tmavý tón pleti',
    '🧝🏻‍♂' => 'elf: svetlý tón pleti',
    '🧝🏼‍♂' => 'elf: stredne svetlý tón pleti',
    '🧝🏽‍♂' => 'elf: stredný tón pleti',
    '🧝🏾‍♂' => 'elf: stredne tmavý tón pleti',
    '🧝🏿‍♂' => 'elf: tmavý tón pleti',
    '🧝🏻‍♀' => 'elfka: svetlý tón pleti',
    '🧝🏼‍♀' => 'elfka: stredne svetlý tón pleti',
    '🧝🏽‍♀' => 'elfka: stredný tón pleti',
    '🧝🏾‍♀' => 'elfka: stredne tmavý tón pleti',
    '🧝🏿‍♀' => 'elfka: tmavý tón pleti',
    '💆🏻‍♂' => 'muž dostáva masáž tváre: svetlý tón pleti',
    '💆🏼‍♂' => 'muž dostáva masáž tváre: stredne svetlý tón pleti',
    '💆🏽‍♂' => 'muž dostáva masáž tváre: stredný tón pleti',
    '💆🏾‍♂' => 'muž dostáva masáž tváre: stredne tmavý tón pleti',
    '💆🏿‍♂' => 'muž dostáva masáž tváre: tmavý tón pleti',
    '💆🏻‍♀' => 'žena dostáva masáž tváre: svetlý tón pleti',
    '💆🏼‍♀' => 'žena dostáva masáž tváre: stredne svetlý tón pleti',
    '💆🏽‍♀' => 'žena dostáva masáž tváre: stredný tón pleti',
    '💆🏾‍♀' => 'žena dostáva masáž tváre: stredne tmavý tón pleti',
    '💆🏿‍♀' => 'žena dostáva masáž tváre: tmavý tón pleti',
    '💇🏻‍♂' => 'muž u kaderníka: svetlý tón pleti',
    '💇🏼‍♂' => 'muž u kaderníka: stredne svetlý tón pleti',
    '💇🏽‍♂' => 'muž u kaderníka: stredný tón pleti',
    '💇🏾‍♂' => 'muž u kaderníka: stredne tmavý tón pleti',
    '💇🏿‍♂' => 'muž u kaderníka: tmavý tón pleti',
    '💇🏻‍♀' => 'žena u kaderníka: svetlý tón pleti',
    '💇🏼‍♀' => 'žena u kaderníka: stredne svetlý tón pleti',
    '💇🏽‍♀' => 'žena u kaderníka: stredný tón pleti',
    '💇🏾‍♀' => 'žena u kaderníka: stredne tmavý tón pleti',
    '💇🏿‍♀' => 'žena u kaderníka: tmavý tón pleti',
    '🚶🏻‍♂' => 'chodec: svetlý tón pleti',
    '🚶🏼‍♂' => 'chodec: stredne svetlý tón pleti',
    '🚶🏽‍♂' => 'chodec: stredný tón pleti',
    '🚶🏾‍♂' => 'chodec: stredne tmavý tón pleti',
    '🚶🏿‍♂' => 'chodec: tmavý tón pleti',
    '🚶🏻‍♀' => 'chodkyňa: svetlý tón pleti',
    '🚶🏼‍♀' => 'chodkyňa: stredne svetlý tón pleti',
    '🚶🏽‍♀' => 'chodkyňa: stredný tón pleti',
    '🚶🏾‍♀' => 'chodkyňa: stredne tmavý tón pleti',
    '🚶🏿‍♀' => 'chodkyňa: tmavý tón pleti',
    '🚶🏻‍➡' => 'chodiaci človek: svetlý tón pleti, smerom doprava',
    '🚶🏼‍➡' => 'chodiaci človek: stredne svetlý tón pleti, smerom doprava',
    '🚶🏽‍➡' => 'chodiaci človek: stredný tón pleti, smerom doprava',
    '🚶🏾‍➡' => 'chodiaci človek: stredne tmavý tón pleti, smerom doprava',
    '🚶🏿‍➡' => 'chodiaci človek: tmavý tón pleti, smerom doprava',
    '🧍🏻‍♂' => 'stojaci muž: svetlý tón pleti',
    '🧍🏼‍♂' => 'stojaci muž: stredne svetlý tón pleti',
    '🧍🏽‍♂' => 'stojaci muž: stredný tón pleti',
    '🧍🏾‍♂' => 'stojaci muž: stredne tmavý tón pleti',
    '🧍🏿‍♂' => 'stojaci muž: tmavý tón pleti',
    '🧍🏻‍♀' => 'stojaca žena: svetlý tón pleti',
    '🧍🏼‍♀' => 'stojaca žena: stredne svetlý tón pleti',
    '🧍🏽‍♀' => 'stojaca žena: stredný tón pleti',
    '🧍🏾‍♀' => 'stojaca žena: stredne tmavý tón pleti',
    '🧍🏿‍♀' => 'stojaca žena: tmavý tón pleti',
    '🧎🏻‍♂' => 'kľačiaci muž: svetlý tón pleti',
    '🧎🏼‍♂' => 'kľačiaci muž: stredne svetlý tón pleti',
    '🧎🏽‍♂' => 'kľačiaci muž: stredný tón pleti',
    '🧎🏾‍♂' => 'kľačiaci muž: stredne tmavý tón pleti',
    '🧎🏿‍♂' => 'kľačiaci muž: tmavý tón pleti',
    '🧎🏻‍♀' => 'kľačiaca žena: svetlý tón pleti',
    '🧎🏼‍♀' => 'kľačiaca žena: stredne svetlý tón pleti',
    '🧎🏽‍♀' => 'kľačiaca žena: stredný tón pleti',
    '🧎🏾‍♀' => 'kľačiaca žena: stredne tmavý tón pleti',
    '🧎🏿‍♀' => 'kľačiaca žena: tmavý tón pleti',
    '🧎🏻‍➡' => 'kľačiaci človek: svetlý tón pleti, smerom doprava',
    '🧎🏼‍➡' => 'kľačiaci človek: stredne svetlý tón pleti, smerom doprava',
    '🧎🏽‍➡' => 'kľačiaci človek: stredný tón pleti, smerom doprava',
    '🧎🏾‍➡' => 'kľačiaci človek: stredne tmavý tón pleti, smerom doprava',
    '🧎🏿‍➡' => 'kľačiaci človek: tmavý tón pleti, smerom doprava',
    '🧑🏻‍🦯' => 'človek s bielou palicou: svetlý tón pleti',
    '🧑🏼‍🦯' => 'človek s bielou palicou: stredne svetlý tón pleti',
    '🧑🏽‍🦯' => 'človek s bielou palicou: stredný tón pleti',
    '🧑🏾‍🦯' => 'človek s bielou palicou: stredne tmavý tón pleti',
    '🧑🏿‍🦯' => 'človek s bielou palicou: tmavý tón pleti',
    '👨🏻‍🦯' => 'muž s bielou palicou: svetlý tón pleti',
    '👨🏼‍🦯' => 'muž s bielou palicou: stredne svetlý tón pleti',
    '👨🏽‍🦯' => 'muž s bielou palicou: stredný tón pleti',
    '👨🏾‍🦯' => 'muž s bielou palicou: stredne tmavý tón pleti',
    '👨🏿‍🦯' => 'muž s bielou palicou: tmavý tón pleti',
    '👩🏻‍🦯' => 'žena so slepeckou palicou: svetlý tón pleti',
    '👩🏼‍🦯' => 'žena so slepeckou palicou: stredne svetlý tón pleti',
    '👩🏽‍🦯' => 'žena so slepeckou palicou: stredný tón pleti',
    '👩🏾‍🦯' => 'žena so slepeckou palicou: stredne tmavý tón pleti',
    '👩🏿‍🦯' => 'žena so slepeckou palicou: tmavý tón pleti',
    '🧑🏻‍🦼' => 'človek na elektrickom invalidnom vozíku: svetlý tón pleti',
    '🧑🏼‍🦼' => 'človek na elektrickom invalidnom vozíku: stredne svetlý tón pleti',
    '🧑🏽‍🦼' => 'človek na elektrickom invalidnom vozíku: stredný tón pleti',
    '🧑🏾‍🦼' => 'človek na elektrickom invalidnom vozíku: stredne tmavý tón pleti',
    '🧑🏿‍🦼' => 'človek na elektrickom invalidnom vozíku: tmavý tón pleti',
    '👨🏻‍🦼' => 'muž na elektrickom invalidnom vozíku: svetlý tón pleti',
    '👨🏼‍🦼' => 'muž na elektrickom invalidnom vozíku: stredne svetlý tón pleti',
    '👨🏽‍🦼' => 'muž na elektrickom invalidnom vozíku: stredný tón pleti',
    '👨🏾‍🦼' => 'muž na elektrickom invalidnom vozíku: stredne tmavý tón pleti',
    '👨🏿‍🦼' => 'muž na elektrickom invalidnom vozíku: tmavý tón pleti',
    '👩🏻‍🦼' => 'žena na elektrickom invalidnom vozíku: svetlý tón pleti',
    '👩🏼‍🦼' => 'žena na elektrickom invalidnom vozíku: stredne svetlý tón pleti',
    '👩🏽‍🦼' => 'žena na elektrickom invalidnom vozíku: stredný tón pleti',
    '👩🏾‍🦼' => 'žena na elektrickom invalidnom vozíku: stredne tmavý tón pleti',
    '👩🏿‍🦼' => 'žena na elektrickom invalidnom vozíku: tmavý tón pleti',
    '🧑🏻‍🦽' => 'človek na mechanickom invalidnom vozíku: svetlý tón pleti',
    '🧑🏼‍🦽' => 'človek na mechanickom invalidnom vozíku: stredne svetlý tón pleti',
    '🧑🏽‍🦽' => 'človek na mechanickom invalidnom vozíku: stredný tón pleti',
    '🧑🏾‍🦽' => 'človek na mechanickom invalidnom vozíku: stredne tmavý tón pleti',
    '🧑🏿‍🦽' => 'človek na mechanickom invalidnom vozíku: tmavý tón pleti',
    '👨🏻‍🦽' => 'muž na mechanickom invalidnom vozíku: svetlý tón pleti',
    '👨🏼‍🦽' => 'muž na mechanickom invalidnom vozíku: stredne svetlý tón pleti',
    '👨🏽‍🦽' => 'muž na mechanickom invalidnom vozíku: stredný tón pleti',
    '👨🏾‍🦽' => 'muž na mechanickom invalidnom vozíku: stredne tmavý tón pleti',
    '👨🏿‍🦽' => 'muž na mechanickom invalidnom vozíku: tmavý tón pleti',
    '👩🏻‍🦽' => 'žena na mechanickom invalidnom vozíku: svetlý tón pleti',
    '👩🏼‍🦽' => 'žena na mechanickom invalidnom vozíku: stredne svetlý tón pleti',
    '👩🏽‍🦽' => 'žena na mechanickom invalidnom vozíku: stredný tón pleti',
    '👩🏾‍🦽' => 'žena na mechanickom invalidnom vozíku: stredne tmavý tón pleti',
    '👩🏿‍🦽' => 'žena na mechanickom invalidnom vozíku: tmavý tón pleti',
    '🏃🏻‍♂' => 'bežec: svetlý tón pleti',
    '🏃🏼‍♂' => 'bežec: stredne svetlý tón pleti',
    '🏃🏽‍♂' => 'bežec: stredný tón pleti',
    '🏃🏾‍♂' => 'bežec: stredne tmavý tón pleti',
    '🏃🏿‍♂' => 'bežec: tmavý tón pleti',
    '🏃🏻‍♀' => 'bežkyňa: svetlý tón pleti',
    '🏃🏼‍♀' => 'bežkyňa: stredne svetlý tón pleti',
    '🏃🏽‍♀' => 'bežkyňa: stredný tón pleti',
    '🏃🏾‍♀' => 'bežkyňa: stredne tmavý tón pleti',
    '🏃🏿‍♀' => 'bežkyňa: tmavý tón pleti',
    '🏃🏻‍➡' => 'bežiaci človek: svetlý tón pleti, smerom doprava',
    '🏃🏼‍➡' => 'bežiaci človek: stredne svetlý tón pleti, smerom doprava',
    '🏃🏽‍➡' => 'bežiaci človek: stredný tón pleti, smerom doprava',
    '🏃🏾‍➡' => 'bežiaci človek: stredne tmavý tón pleti, smerom doprava',
    '🏃🏿‍➡' => 'bežiaci človek: tmavý tón pleti, smerom doprava',
    '👯🏻‍♀' => 'ženy so zajačími ušami: svetlý tón pleti',
    '👯🏼‍♀' => 'ženy so zajačími ušami: stredne svetlý tón pleti',
    '👯🏽‍♀' => 'ženy so zajačími ušami: stredný tón pleti',
    '👯🏾‍♀' => 'ženy so zajačími ušami: stredne tmavý tón pleti',
    '👯🏿‍♀' => 'ženy so zajačími ušami: tmavý tón pleti',
    '👯🏻‍♂' => 'muži so zajačími ušami: svetlý tón pleti',
    '👯🏼‍♂' => 'muži so zajačími ušami: stredne svetlý tón pleti',
    '👯🏽‍♂' => 'muži so zajačími ušami: stredný tón pleti',
    '👯🏾‍♂' => 'muži so zajačími ušami: stredne tmavý tón pleti',
    '👯🏿‍♂' => 'muži so zajačími ušami: tmavý tón pleti',
    '🧖🏻‍♂' => 'muž v pare: svetlý tón pleti',
    '🧖🏼‍♂' => 'muž v pare: stredne svetlý tón pleti',
    '🧖🏽‍♂' => 'muž v pare: stredný tón pleti',
    '🧖🏾‍♂' => 'muž v pare: stredne tmavý tón pleti',
    '🧖🏿‍♂' => 'muž v pare: tmavý tón pleti',
    '🧖🏻‍♀' => 'žena v pare: svetlý tón pleti',
    '🧖🏼‍♀' => 'žena v pare: stredne svetlý tón pleti',
    '🧖🏽‍♀' => 'žena v pare: stredný tón pleti',
    '🧖🏾‍♀' => 'žena v pare: stredne tmavý tón pleti',
    '🧖🏿‍♀' => 'žena v pare: tmavý tón pleti',
    '🧗🏻‍♂' => 'lezec: svetlý tón pleti',
    '🧗🏼‍♂' => 'lezec: stredne svetlý tón pleti',
    '🧗🏽‍♂' => 'lezec: stredný tón pleti',
    '🧗🏾‍♂' => 'lezec: stredne tmavý tón pleti',
    '🧗🏿‍♂' => 'lezec: tmavý tón pleti',
    '🧗🏻‍♀' => 'lezkyňa: svetlý tón pleti',
    '🧗🏼‍♀' => 'lezkyňa: stredne svetlý tón pleti',
    '🧗🏽‍♀' => 'lezkyňa: stredný tón pleti',
    '🧗🏾‍♀' => 'lezkyňa: stredne tmavý tón pleti',
    '🧗🏿‍♀' => 'lezkyňa: tmavý tón pleti',
    '🏌🏻‍♂' => 'golfista: svetlý tón pleti',
    '🏌🏼‍♂' => 'golfista: stredne svetlý tón pleti',
    '🏌🏽‍♂' => 'golfista: stredný tón pleti',
    '🏌🏾‍♂' => 'golfista: stredne tmavý tón pleti',
    '🏌🏿‍♂' => 'golfista: tmavý tón pleti',
    '🏌🏻‍♀' => 'golfistka: svetlý tón pleti',
    '🏌🏼‍♀' => 'golfistka: stredne svetlý tón pleti',
    '🏌🏽‍♀' => 'golfistka: stredný tón pleti',
    '🏌🏾‍♀' => 'golfistka: stredne tmavý tón pleti',
    '🏌🏿‍♀' => 'golfistka: tmavý tón pleti',
    '🏄🏻‍♂' => 'surfista: svetlý tón pleti',
    '🏄🏼‍♂' => 'surfista: stredne svetlý tón pleti',
    '🏄🏽‍♂' => 'surfista: stredný tón pleti',
    '🏄🏾‍♂' => 'surfista: stredne tmavý tón pleti',
    '🏄🏿‍♂' => 'surfista: tmavý tón pleti',
    '🏄🏻‍♀' => 'surfistka: svetlý tón pleti',
    '🏄🏼‍♀' => 'surfistka: stredne svetlý tón pleti',
    '🏄🏽‍♀' => 'surfistka: stredný tón pleti',
    '🏄🏾‍♀' => 'surfistka: stredne tmavý tón pleti',
    '🏄🏿‍♀' => 'surfistka: tmavý tón pleti',
    '🚣🏻‍♂' => 'veslár: svetlý tón pleti',
    '🚣🏼‍♂' => 'veslár: stredne svetlý tón pleti',
    '🚣🏽‍♂' => 'veslár: stredný tón pleti',
    '🚣🏾‍♂' => 'veslár: stredne tmavý tón pleti',
    '🚣🏿‍♂' => 'veslár: tmavý tón pleti',
    '🚣🏻‍♀' => 'veslárka: svetlý tón pleti',
    '🚣🏼‍♀' => 'veslárka: stredne svetlý tón pleti',
    '🚣🏽‍♀' => 'veslárka: stredný tón pleti',
    '🚣🏾‍♀' => 'veslárka: stredne tmavý tón pleti',
    '🚣🏿‍♀' => 'veslárka: tmavý tón pleti',
    '🏊🏻‍♂' => 'plavec: svetlý tón pleti',
    '🏊🏼‍♂' => 'plavec: stredne svetlý tón pleti',
    '🏊🏽‍♂' => 'plavec: stredný tón pleti',
    '🏊🏾‍♂' => 'plavec: stredne tmavý tón pleti',
    '🏊🏿‍♂' => 'plavec: tmavý tón pleti',
    '🏊🏻‍♀' => 'plavkyňa: svetlý tón pleti',
    '🏊🏼‍♀' => 'plavkyňa: stredne svetlý tón pleti',
    '🏊🏽‍♀' => 'plavkyňa: stredný tón pleti',
    '🏊🏾‍♀' => 'plavkyňa: stredne tmavý tón pleti',
    '🏊🏿‍♀' => 'plavkyňa: tmavý tón pleti',
    '⛹🏻‍♂' => 'muž s loptou: svetlý tón pleti',
    '⛹🏼‍♂' => 'muž s loptou: stredne svetlý tón pleti',
    '⛹🏽‍♂' => 'muž s loptou: stredný tón pleti',
    '⛹🏾‍♂' => 'muž s loptou: stredne tmavý tón pleti',
    '⛹🏿‍♂' => 'muž s loptou: tmavý tón pleti',
    '⛹🏻‍♀' => 'žena s loptou: svetlý tón pleti',
    '⛹🏼‍♀' => 'žena s loptou: stredne svetlý tón pleti',
    '⛹🏽‍♀' => 'žena s loptou: stredný tón pleti',
    '⛹🏾‍♀' => 'žena s loptou: stredne tmavý tón pleti',
    '⛹🏿‍♀' => 'žena s loptou: tmavý tón pleti',
    '🏋🏻‍♂' => 'vzpierač: svetlý tón pleti',
    '🏋🏼‍♂' => 'vzpierač: stredne svetlý tón pleti',
    '🏋🏽‍♂' => 'vzpierač: stredný tón pleti',
    '🏋🏾‍♂' => 'vzpierač: stredne tmavý tón pleti',
    '🏋🏿‍♂' => 'vzpierač: tmavý tón pleti',
    '🏋🏻‍♀' => 'vzpieračka: svetlý tón pleti',
    '🏋🏼‍♀' => 'vzpieračka: stredne svetlý tón pleti',
    '🏋🏽‍♀' => 'vzpieračka: stredný tón pleti',
    '🏋🏾‍♀' => 'vzpieračka: stredne tmavý tón pleti',
    '🏋🏿‍♀' => 'vzpieračka: tmavý tón pleti',
    '🚴🏻‍♂' => 'cyklista: svetlý tón pleti',
    '🚴🏼‍♂' => 'cyklista: stredne svetlý tón pleti',
    '🚴🏽‍♂' => 'cyklista: stredný tón pleti',
    '🚴🏾‍♂' => 'cyklista: stredne tmavý tón pleti',
    '🚴🏿‍♂' => 'cyklista: tmavý tón pleti',
    '🚴🏻‍♀' => 'cyklistka: svetlý tón pleti',
    '🚴🏼‍♀' => 'cyklistka: stredne svetlý tón pleti',
    '🚴🏽‍♀' => 'cyklistka: stredný tón pleti',
    '🚴🏾‍♀' => 'cyklistka: stredne tmavý tón pleti',
    '🚴🏿‍♀' => 'cyklistka: tmavý tón pleti',
    '🚵🏻‍♂' => 'horský cyklista: svetlý tón pleti',
    '🚵🏼‍♂' => 'horský cyklista: stredne svetlý tón pleti',
    '🚵🏽‍♂' => 'horský cyklista: stredný tón pleti',
    '🚵🏾‍♂' => 'horský cyklista: stredne tmavý tón pleti',
    '🚵🏿‍♂' => 'horský cyklista: tmavý tón pleti',
    '🚵🏻‍♀' => 'horská cyklistka: svetlý tón pleti',
    '🚵🏼‍♀' => 'horská cyklistka: stredne svetlý tón pleti',
    '🚵🏽‍♀' => 'horská cyklistka: stredný tón pleti',
    '🚵🏾‍♀' => 'horská cyklistka: stredne tmavý tón pleti',
    '🚵🏿‍♀' => 'horská cyklistka: tmavý tón pleti',
    '🤸🏻‍♂' => 'muž robí hviezdu: svetlý tón pleti',
    '🤸🏼‍♂' => 'muž robí hviezdu: stredne svetlý tón pleti',
    '🤸🏽‍♂' => 'muž robí hviezdu: stredný tón pleti',
    '🤸🏾‍♂' => 'muž robí hviezdu: stredne tmavý tón pleti',
    '🤸🏿‍♂' => 'muž robí hviezdu: tmavý tón pleti',
    '🤸🏻‍♀' => 'žena robí hviezdu: svetlý tón pleti',
    '🤸🏼‍♀' => 'žena robí hviezdu: stredne svetlý tón pleti',
    '🤸🏽‍♀' => 'žena robí hviezdu: stredný tón pleti',
    '🤸🏾‍♀' => 'žena robí hviezdu: stredne tmavý tón pleti',
    '🤸🏿‍♀' => 'žena robí hviezdu: tmavý tón pleti',
    '🤼🏻‍♀' => 'zápasníčky: svetlý tón pleti',
    '🤼🏼‍♀' => 'zápasníčky: stredne svetlý tón pleti',
    '🤼🏽‍♀' => 'zápasníčky: stredný tón pleti',
    '🤼🏾‍♀' => 'zápasníčky: stredne tmavý tón pleti',
    '🤼🏿‍♀' => 'zápasníčky: tmavý tón pleti',
    '🤼🏻‍♂' => 'zápasníci: svetlý tón pleti',
    '🤼🏼‍♂' => 'zápasníci: stredne svetlý tón pleti',
    '🤼🏽‍♂' => 'zápasníci: stredný tón pleti',
    '🤼🏾‍♂' => 'zápasníci: stredne tmavý tón pleti',
    '🤼🏿‍♂' => 'zápasníci: tmavý tón pleti',
    '🤽🏻‍♂' => 'pólista: svetlý tón pleti',
    '🤽🏼‍♂' => 'pólista: stredne svetlý tón pleti',
    '🤽🏽‍♂' => 'pólista: stredný tón pleti',
    '🤽🏾‍♂' => 'pólista: stredne tmavý tón pleti',
    '🤽🏿‍♂' => 'pólista: tmavý tón pleti',
    '🤽🏻‍♀' => 'pólistka: svetlý tón pleti',
    '🤽🏼‍♀' => 'pólistka: stredne svetlý tón pleti',
    '🤽🏽‍♀' => 'pólistka: stredný tón pleti',
    '🤽🏾‍♀' => 'pólistka: stredne tmavý tón pleti',
    '🤽🏿‍♀' => 'pólistka: tmavý tón pleti',
    '🤾🏻‍♂' => 'hádzanár: svetlý tón pleti',
    '🤾🏼‍♂' => 'hádzanár: stredne svetlý tón pleti',
    '🤾🏽‍♂' => 'hádzanár: stredný tón pleti',
    '🤾🏾‍♂' => 'hádzanár: stredne tmavý tón pleti',
    '🤾🏿‍♂' => 'hádzanár: tmavý tón pleti',
    '🤾🏻‍♀' => 'hádzanárka: svetlý tón pleti',
    '🤾🏼‍♀' => 'hádzanárka: stredne svetlý tón pleti',
    '🤾🏽‍♀' => 'hádzanárka: stredný tón pleti',
    '🤾🏾‍♀' => 'hádzanárka: stredne tmavý tón pleti',
    '🤾🏿‍♀' => 'hádzanárka: tmavý tón pleti',
    '🤹🏻‍♂' => 'žonglér: svetlý tón pleti',
    '🤹🏼‍♂' => 'žonglér: stredne svetlý tón pleti',
    '🤹🏽‍♂' => 'žonglér: stredný tón pleti',
    '🤹🏾‍♂' => 'žonglér: stredne tmavý tón pleti',
    '🤹🏿‍♂' => 'žonglér: tmavý tón pleti',
    '🤹🏻‍♀' => 'žonglérka: svetlý tón pleti',
    '🤹🏼‍♀' => 'žonglérka: stredne svetlý tón pleti',
    '🤹🏽‍♀' => 'žonglérka: stredný tón pleti',
    '🤹🏾‍♀' => 'žonglérka: stredne tmavý tón pleti',
    '🤹🏿‍♀' => 'žonglérka: tmavý tón pleti',
    '🧘🏻‍♂' => 'muž v lotosovom sede: svetlý tón pleti',
    '🧘🏼‍♂' => 'muž v lotosovom sede: stredne svetlý tón pleti',
    '🧘🏽‍♂' => 'muž v lotosovom sede: stredný tón pleti',
    '🧘🏾‍♂' => 'muž v lotosovom sede: stredne tmavý tón pleti',
    '🧘🏿‍♂' => 'muž v lotosovom sede: tmavý tón pleti',
    '🧘🏻‍♀' => 'žena v lotosovom sede: svetlý tón pleti',
    '🧘🏼‍♀' => 'žena v lotosovom sede: stredne svetlý tón pleti',
    '🧘🏽‍♀' => 'žena v lotosovom sede: stredný tón pleti',
    '🧘🏾‍♀' => 'žena v lotosovom sede: stredne tmavý tón pleti',
    '🧘🏿‍♀' => 'žena v lotosovom sede: tmavý tón pleti',
    '🧑‍🦰' => 'dospelý: ryšavé vlasy',
    '🧑‍🦱' => 'dospelý: kučeravé vlasy',
    '🧑‍🦳' => 'dospelý: sivé vlasy',
    '🧑‍🦲' => 'dospelý: holá hlava',
    '👨‍🦰' => 'muž: ryšavé vlasy',
    '👨‍🦱' => 'muž: kučeravé vlasy',
    '👨‍🦳' => 'muž: sivé vlasy',
    '👨‍🦲' => 'muž: holá hlava',
    '👩‍🦰' => 'žena: ryšavé vlasy',
    '👩‍🦱' => 'žena: kučeravé vlasy',
    '👩‍🦳' => 'žena: sivé vlasy',
    '👩‍🦲' => 'žena: holá hlava',
    '🚶‍➡' => 'chodiaci človek: smerom doprava',
    '🧎‍➡' => 'kľačiaci človek: smerom doprava',
    '🏃‍➡' => 'bežiaci človek: smerom doprava',
    '👨‍👦' => 'rodina: muž, chlapec',
    '👨‍👧' => 'rodina: muž, dievča',
    '👩‍👦' => 'rodina: žena, chlapec',
    '👩‍👧' => 'rodina: žena, dievča',
    '😶‍🌫' => 'tvár v oblakoch',
    '😮‍💨' => 'vydychujúca tvár',
    '🙂‍↕' => 'prikyvujúca hlava',
    '😵‍💫' => 'tvár so špirálovými očami',
    '❤‍🔥' => 'horiace srdce',
    '❤‍🩹' => 'srdce s obväzom',
    '👁‍🗨' => 'oko v bubline',
    '🧔‍♂' => 'bradatý muž',
    '👱‍♂' => 'blondín',
    '🧔‍♀' => 'bradatá žena',
    '👱‍♀' => 'blondína',
    '🙍‍♂' => 'zamračený muž',
    '🙍‍♀' => 'zamračená žena',
    '🙎‍♂' => 'podráždený muž',
    '🙎‍♀' => 'podráždená žena',
    '🙅‍♂' => 'muž s prekríženými rukami',
    '🙅‍♀' => 'žena s prekríženými rukami',
    '🙆‍♂' => 'muž s rukami nad hlavou',
    '🙆‍♀' => 'žena s rukami nad hlavou',
    '💁‍♂' => 'muž s nastavenou dlaňou',
    '💁‍♀' => 'žena s nastavenou dlaňou',
    '🙋‍♂' => 'muž so zdvihnutou rukou',
    '🙋‍♀' => 'žena so zdvihnutou rukou',
    '🧏‍♂' => 'nepočujúci muž',
    '🧏‍♀' => 'nepočujúca žena',
    '🙇‍♂' => 'klaňajúci sa muž',
    '🙇‍♀' => 'klaňajúca sa žena',
    '🤦‍♂' => 'muž chytajúci sa za hlavu',
    '🤦‍♀' => 'žena chytajúca sa za hlavu',
    '🤷‍♂' => 'muž krčiaci plecami',
    '🤷‍♀' => 'žena krčiaca plecami',
    '🧑‍⚕' => 'zdravotník',
    '👨‍⚕' => 'zdravotník muž',
    '👩‍⚕' => 'zdravotníčka',
    '🧑‍🎓' => 'študent',
    '👨‍🎓' => 'študent muž',
    '👩‍🎓' => 'študentka',
    '🧑‍🏫' => 'učiteľ',
    '👨‍🏫' => 'učiteľ muž',
    '👩‍🏫' => 'učiteľka',
    '🧑‍⚖' => 'sudca',
    '👨‍⚖' => 'sudca muž',
    '👩‍⚖' => 'sudkyňa',
    '🧑‍🌾' => 'roľník',
    '👨‍🌾' => 'roľník muž',
    '👩‍🌾' => 'roľníčka',
    '🧑‍🍳' => 'kuchár',
    '👨‍🍳' => 'kuchár muž',
    '👩‍🍳' => 'kuchárka',
    '🧑‍🔧' => 'remeselník',
    '👨‍🔧' => 'remeselník muž',
    '👩‍🔧' => 'remeselníčka',
    '🧑‍🏭' => 'robotník',
    '👨‍🏭' => 'robotník muž',
    '👩‍🏭' => 'robotníčka',
    '🧑‍💼' => 'pracovník v kancelárii',
    '👨‍💼' => 'pracovník v kancelárii muž',
    '👩‍💼' => 'pracovníčka v kancelárii',
    '🧑‍🔬' => 'vedec',
    '👨‍🔬' => 'vedec muž',
    '👩‍🔬' => 'vedkyňa',
    '🧑‍💻' => 'programátor',
    '👨‍💻' => 'programátor muž',
    '👩‍💻' => 'programátorka',
    '🧑‍🎤' => 'spevák',
    '👨‍🎤' => 'spevák muž',
    '👩‍🎤' => 'speváčka',
    '🧑‍🎨' => 'maliar',
    '👨‍🎨' => 'maliar muž',
    '👩‍🎨' => 'maliarka',
    '🧑‍✈' => 'pilot',
    '👨‍✈' => 'pilot muž',
    '👩‍✈' => 'pilotka',
    '🧑‍🚀' => 'kozmonaut',
    '👨‍🚀' => 'kozmonaut muž',
    '👩‍🚀' => 'kozmonautka',
    '🧑‍🚒' => 'hasič',
    '👨‍🚒' => 'hasič muž',
    '👩‍🚒' => 'hasička',
    '👮‍♂' => 'policajt muž',
    '👮‍♀' => 'policajtka',
    '🕵‍♂' => 'detektív muž',
    '🕵‍♀' => 'detektívka',
    '💂‍♂' => 'strážca',
    '💂‍♀' => 'strážkyňa',
    '👷‍♂' => 'stavbár',
    '👷‍♀' => 'stavbárka',
    '👳‍♂' => 'muž s turbanom',
    '👳‍♀' => 'žena s turbanom',
    '🤵‍♂' => 'muž v smokingu',
    '🤵‍♀' => 'žena v smokingu',
    '👰‍♂' => 'muž so závojom',
    '👰‍♀' => 'žena so závojom',
    '👩‍🍼' => 'žena kŕmiaca bábätko',
    '👨‍🍼' => 'muž kŕmiaci bábätko',
    '🧑‍🍼' => 'človek kŕmiaci bábätko',
    '🧑‍🎄' => 'Mx Santa',
    '🦸‍♂' => 'supermuž',
    '🦸‍♀' => 'superžena',
    '🦹‍♂' => 'superdarebák',
    '🦹‍♀' => 'superdarebáčka',
    '🧙‍♂' => 'čarodejník',
    '🧙‍♀' => 'čarodejníčka',
    '🧚‍♂' => 'škriatok',
    '🧚‍♀' => 'víla',
    '🧛‍♂' => 'upír',
    '🧛‍♀' => 'upírka',
    '🧜‍♂' => 'morský muž',
    '🧜‍♀' => 'morská panna',
    '🧝‍♂' => 'elf',
    '🧝‍♀' => 'elfka',
    '🧞‍♂' => 'mužský džin',
    '🧞‍♀' => 'ženský džin',
    '🧟‍♂' => 'mužská zombia',
    '🧟‍♀' => 'ženská zombia',
    '💆‍♂' => 'muž dostáva masáž tváre',
    '💆‍♀' => 'žena dostáva masáž tváre',
    '💇‍♂' => 'muž u kaderníka',
    '💇‍♀' => 'žena u kaderníka',
    '🚶‍♂' => 'chodec',
    '🚶‍♀' => 'chodkyňa',
    '🧍‍♂' => 'stojaci muž',
    '🧍‍♀' => 'stojaca žena',
    '🧎‍♂' => 'kľačiaci muž',
    '🧎‍♀' => 'kľačiaca žena',
    '🧑‍🦯' => 'človek s bielou palicou',
    '👨‍🦯' => 'muž s bielou palicou',
    '👩‍🦯' => 'žena so slepeckou palicou',
    '🧑‍🦼' => 'človek na elektrickom invalidnom vozíku',
    '👨‍🦼' => 'muž na elektrickom invalidnom vozíku',
    '👩‍🦼' => 'žena na elektrickom invalidnom vozíku',
    '🧑‍🦽' => 'človek na mechanickom invalidnom vozíku',
    '👨‍🦽' => 'muž na mechanickom invalidnom vozíku',
    '👩‍🦽' => 'žena na mechanickom invalidnom vozíku',
    '🏃‍♂' => 'bežec',
    '🏃‍♀' => 'bežkyňa',
    '🧑‍🩰' => 'baletka',
    '👯‍♂' => 'muži so zajačími ušami',
    '👯‍♀' => 'ženy so zajačími ušami',
    '🧖‍♂' => 'muž v pare',
    '🧖‍♀' => 'žena v pare',
    '🧗‍♂' => 'lezec',
    '🧗‍♀' => 'lezkyňa',
    '🏌‍♂' => 'golfista',
    '🏌‍♀' => 'golfistka',
    '🏄‍♂' => 'surfista',
    '🏄‍♀' => 'surfistka',
    '🚣‍♂' => 'veslár',
    '🚣‍♀' => 'veslárka',
    '🏊‍♂' => 'plavec',
    '🏊‍♀' => 'plavkyňa',
    '⛹‍♂' => 'muž s loptou',
    '⛹‍♀' => 'žena s loptou',
    '🏋‍♂' => 'vzpierač',
    '🏋‍♀' => 'vzpieračka',
    '🚴‍♂' => 'cyklista',
    '🚴‍♀' => 'cyklistka',
    '🚵‍♂' => 'horský cyklista',
    '🚵‍♀' => 'horská cyklistka',
    '🤸‍♂' => 'muž robí hviezdu',
    '🤸‍♀' => 'žena robí hviezdu',
    '🤼‍♂' => 'zápasníci',
    '🤼‍♀' => 'zápasníčky',
    '🤽‍♂' => 'pólista',
    '🤽‍♀' => 'pólistka',
    '🤾‍♂' => 'hádzanár',
    '🤾‍♀' => 'hádzanárka',
    '🤹‍♂' => 'žonglér',
    '🤹‍♀' => 'žonglérka',
    '🧘‍♂' => 'muž v lotosovom sede',
    '🧘‍♀' => 'žena v lotosovom sede',
    '🧑‍🧒' => 'rodina: dospelý, dieťa',
    '🐕‍🦺' => 'služobný pes',
    '🐈‍⬛' => 'čierna mačka',
    '🐻‍❄' => 'ľadový medveď',
    '🐦‍⬛' => 'čierny vták',
    '🐦‍🔥' => 'fénix',
    '🍋‍🟩' => 'limetka',
    '🍄‍🟫' => 'hnedý hríb',
    '⛓‍💥' => 'roztrhnutá reťaz',
    '🏳‍🌈' => 'dúhová zástava',
    '🏳‍⚧' => 'transgenderová zástava',
    '🏴‍☠' => 'pirátska zástava',
    '👋🏻' => 'mávajúca ruka: svetlý tón pleti',
    '👋🏼' => 'mávajúca ruka: stredne svetlý tón pleti',
    '👋🏽' => 'mávajúca ruka: stredný tón pleti',
    '👋🏾' => 'mávajúca ruka: stredne tmavý tón pleti',
    '👋🏿' => 'mávajúca ruka: tmavý tón pleti',
    '🤚🏻' => 'zdvihnutá ruka spakruky: svetlý tón pleti',
    '🤚🏼' => 'zdvihnutá ruka spakruky: stredne svetlý tón pleti',
    '🤚🏽' => 'zdvihnutá ruka spakruky: stredný tón pleti',
    '🤚🏾' => 'zdvihnutá ruka spakruky: stredne tmavý tón pleti',
    '🤚🏿' => 'zdvihnutá ruka spakruky: tmavý tón pleti',
    '🖐🏻' => 'roztiahnutá ruka: svetlý tón pleti',
    '🖐🏼' => 'roztiahnutá ruka: stredne svetlý tón pleti',
    '🖐🏽' => 'roztiahnutá ruka: stredný tón pleti',
    '🖐🏾' => 'roztiahnutá ruka: stredne tmavý tón pleti',
    '🖐🏿' => 'roztiahnutá ruka: tmavý tón pleti',
    '✋🏻' => 'zdvihnutá ruka: svetlý tón pleti',
    '✋🏼' => 'zdvihnutá ruka: stredne svetlý tón pleti',
    '✋🏽' => 'zdvihnutá ruka: stredný tón pleti',
    '✋🏾' => 'zdvihnutá ruka: stredne tmavý tón pleti',
    '✋🏿' => 'zdvihnutá ruka: tmavý tón pleti',
    '🖖🏻' => 'vulkánsky pozdrav: svetlý tón pleti',
    '🖖🏼' => 'vulkánsky pozdrav: stredne svetlý tón pleti',
    '🖖🏽' => 'vulkánsky pozdrav: stredný tón pleti',
    '🖖🏾' => 'vulkánsky pozdrav: stredne tmavý tón pleti',
    '🖖🏿' => 'vulkánsky pozdrav: tmavý tón pleti',
    '🫱🏻' => 'ruka doprava: svetlý tón pleti',
    '🫱🏼' => 'ruka doprava: stredne svetlý tón pleti',
    '🫱🏽' => 'ruka doprava: stredný tón pleti',
    '🫱🏾' => 'ruka doprava: stredne tmavý tón pleti',
    '🫱🏿' => 'ruka doprava: tmavý tón pleti',
    '🫲🏻' => 'ruka doľava: svetlý tón pleti',
    '🫲🏼' => 'ruka doľava: stredne svetlý tón pleti',
    '🫲🏽' => 'ruka doľava: stredný tón pleti',
    '🫲🏾' => 'ruka doľava: stredne tmavý tón pleti',
    '🫲🏿' => 'ruka doľava: tmavý tón pleti',
    '🫳🏻' => 'ruka dlaňou nadol: svetlý tón pleti',
    '🫳🏼' => 'ruka dlaňou nadol: stredne svetlý tón pleti',
    '🫳🏽' => 'ruka dlaňou nadol: stredný tón pleti',
    '🫳🏾' => 'ruka dlaňou nadol: stredne tmavý tón pleti',
    '🫳🏿' => 'ruka dlaňou nadol: tmavý tón pleti',
    '🫴🏻' => 'ruka dlaňou nahor: svetlý tón pleti',
    '🫴🏼' => 'ruka dlaňou nahor: stredne svetlý tón pleti',
    '🫴🏽' => 'ruka dlaňou nahor: stredný tón pleti',
    '🫴🏾' => 'ruka dlaňou nahor: stredne tmavý tón pleti',
    '🫴🏿' => 'ruka dlaňou nahor: tmavý tón pleti',
    '🫷🏻' => 'ruka tlačiaca vľavo: svetlý tón pleti',
    '🫷🏼' => 'ruka tlačiaca vľavo: stredne svetlý tón pleti',
    '🫷🏽' => 'ruka tlačiaca vľavo: stredný tón pleti',
    '🫷🏾' => 'ruka tlačiaca vľavo: stredne tmavý tón pleti',
    '🫷🏿' => 'ruka tlačiaca vľavo: tmavý tón pleti',
    '🫸🏻' => 'ruka tlačiaca vpravo: svetlý tón pleti',
    '🫸🏼' => 'ruka tlačiaca vpravo: stredne svetlý tón pleti',
    '🫸🏽' => 'ruka tlačiaca vpravo: stredný tón pleti',
    '🫸🏾' => 'ruka tlačiaca vpravo: stredne tmavý tón pleti',
    '🫸🏿' => 'ruka tlačiaca vpravo: tmavý tón pleti',
    '👌🏻' => 'výborne: svetlý tón pleti',
    '👌🏼' => 'výborne: stredne svetlý tón pleti',
    '👌🏽' => 'výborne: stredný tón pleti',
    '👌🏾' => 'výborne: stredne tmavý tón pleti',
    '👌🏿' => 'výborne: tmavý tón pleti',
    '🤌🏻' => 'štipka: svetlý tón pleti',
    '🤌🏼' => 'štipka: stredne svetlý tón pleti',
    '🤌🏽' => 'štipka: stredný tón pleti',
    '🤌🏾' => 'štipka: stredne tmavý tón pleti',
    '🤌🏿' => 'štipka: tmavý tón pleti',
    '🤏🏻' => 'málo: svetlý tón pleti',
    '🤏🏼' => 'málo: stredne svetlý tón pleti',
    '🤏🏽' => 'málo: stredný tón pleti',
    '🤏🏾' => 'málo: stredne tmavý tón pleti',
    '🤏🏿' => 'málo: tmavý tón pleti',
    '✌🏻' => 'víťazstvo: svetlý tón pleti',
    '✌🏼' => 'víťazstvo: stredne svetlý tón pleti',
    '✌🏽' => 'víťazstvo: stredný tón pleti',
    '✌🏾' => 'víťazstvo: stredne tmavý tón pleti',
    '✌🏿' => 'víťazstvo: tmavý tón pleti',
    '🤞🏻' => 'držím palce: svetlý tón pleti',
    '🤞🏼' => 'držím palce: stredne svetlý tón pleti',
    '🤞🏽' => 'držím palce: stredný tón pleti',
    '🤞🏾' => 'držím palce: stredne tmavý tón pleti',
    '🤞🏿' => 'držím palce: tmavý tón pleti',
    '🫰🏻' => 'ruka s prekríženým ukazovákom a palcom: svetlý tón pleti',
    '🫰🏼' => 'ruka s prekríženým ukazovákom a palcom: stredne svetlý tón pleti',
    '🫰🏽' => 'ruka s prekríženým ukazovákom a palcom: stredný tón pleti',
    '🫰🏾' => 'ruka s prekríženým ukazovákom a palcom: stredne tmavý tón pleti',
    '🫰🏿' => 'ruka s prekríženým ukazovákom a palcom: tmavý tón pleti',
    '🤟🏻' => 'ľúbim ťa: svetlý tón pleti',
    '🤟🏼' => 'ľúbim ťa: stredne svetlý tón pleti',
    '🤟🏽' => 'ľúbim ťa: stredný tón pleti',
    '🤟🏾' => 'ľúbim ťa: stredne tmavý tón pleti',
    '🤟🏿' => 'ľúbim ťa: tmavý tón pleti',
    '🤘🏻' => 'paroháč: svetlý tón pleti',
    '🤘🏼' => 'paroháč: stredne svetlý tón pleti',
    '🤘🏽' => 'paroháč: stredný tón pleti',
    '🤘🏾' => 'paroháč: stredne tmavý tón pleti',
    '🤘🏿' => 'paroháč: tmavý tón pleti',
    '🤙🏻' => 'zavoláme si: svetlý tón pleti',
    '🤙🏼' => 'zavoláme si: stredne svetlý tón pleti',
    '🤙🏽' => 'zavoláme si: stredný tón pleti',
    '🤙🏾' => 'zavoláme si: stredne tmavý tón pleti',
    '🤙🏿' => 'zavoláme si: tmavý tón pleti',
    '👈🏻' => 'ukazovák doľava: svetlý tón pleti',
    '👈🏼' => 'ukazovák doľava: stredne svetlý tón pleti',
    '👈🏽' => 'ukazovák doľava: stredný tón pleti',
    '👈🏾' => 'ukazovák doľava: stredne tmavý tón pleti',
    '👈🏿' => 'ukazovák doľava: tmavý tón pleti',
    '👉🏻' => 'ukazovák doprava: svetlý tón pleti',
    '👉🏼' => 'ukazovák doprava: stredne svetlý tón pleti',
    '👉🏽' => 'ukazovák doprava: stredný tón pleti',
    '👉🏾' => 'ukazovák doprava: stredne tmavý tón pleti',
    '👉🏿' => 'ukazovák doprava: tmavý tón pleti',
    '👆🏻' => 'ukazovák spakruky nahor: svetlý tón pleti',
    '👆🏼' => 'ukazovák spakruky nahor: stredne svetlý tón pleti',
    '👆🏽' => 'ukazovák spakruky nahor: stredný tón pleti',
    '👆🏾' => 'ukazovák spakruky nahor: stredne tmavý tón pleti',
    '👆🏿' => 'ukazovák spakruky nahor: tmavý tón pleti',
    '🖕🏻' => 'prostredník: svetlý tón pleti',
    '🖕🏼' => 'prostredník: stredne svetlý tón pleti',
    '🖕🏽' => 'prostredník: stredný tón pleti',
    '🖕🏾' => 'prostredník: stredne tmavý tón pleti',
    '🖕🏿' => 'prostredník: tmavý tón pleti',
    '👇🏻' => 'ukazovák spakruky nadol: svetlý tón pleti',
    '👇🏼' => 'ukazovák spakruky nadol: stredne svetlý tón pleti',
    '👇🏽' => 'ukazovák spakruky nadol: stredný tón pleti',
    '👇🏾' => 'ukazovák spakruky nadol: stredne tmavý tón pleti',
    '👇🏿' => 'ukazovák spakruky nadol: tmavý tón pleti',
    '☝🏻' => 'ukazovák nahor: svetlý tón pleti',
    '☝🏼' => 'ukazovák nahor: stredne svetlý tón pleti',
    '☝🏽' => 'ukazovák nahor: stredný tón pleti',
    '☝🏾' => 'ukazovák nahor: stredne tmavý tón pleti',
    '☝🏿' => 'ukazovák nahor: tmavý tón pleti',
    '🫵🏻' => 'ukazovanie ukazovákom: svetlý tón pleti',
    '🫵🏼' => 'ukazovanie ukazovákom: stredne svetlý tón pleti',
    '🫵🏽' => 'ukazovanie ukazovákom: stredný tón pleti',
    '🫵🏾' => 'ukazovanie ukazovákom: stredne tmavý tón pleti',
    '🫵🏿' => 'ukazovanie ukazovákom: tmavý tón pleti',
    '👍🏻' => 'palec nahor: svetlý tón pleti',
    '👍🏼' => 'palec nahor: stredne svetlý tón pleti',
    '👍🏽' => 'palec nahor: stredný tón pleti',
    '👍🏾' => 'palec nahor: stredne tmavý tón pleti',
    '👍🏿' => 'palec nahor: tmavý tón pleti',
    '👎🏻' => 'palec nadol: svetlý tón pleti',
    '👎🏼' => 'palec nadol: stredne svetlý tón pleti',
    '👎🏽' => 'palec nadol: stredný tón pleti',
    '👎🏾' => 'palec nadol: stredne tmavý tón pleti',
    '👎🏿' => 'palec nadol: tmavý tón pleti',
    '✊🏻' => 'zdvihnutá päsť: svetlý tón pleti',
    '✊🏼' => 'zdvihnutá päsť: stredne svetlý tón pleti',
    '✊🏽' => 'zdvihnutá päsť: stredný tón pleti',
    '✊🏾' => 'zdvihnutá päsť: stredne tmavý tón pleti',
    '✊🏿' => 'zdvihnutá päsť: tmavý tón pleti',
    '👊🏻' => 'päsť spredu: svetlý tón pleti',
    '👊🏼' => 'päsť spredu: stredne svetlý tón pleti',
    '👊🏽' => 'päsť spredu: stredný tón pleti',
    '👊🏾' => 'päsť spredu: stredne tmavý tón pleti',
    '👊🏿' => 'päsť spredu: tmavý tón pleti',
    '🤛🏻' => 'päsť doľava: svetlý tón pleti',
    '🤛🏼' => 'päsť doľava: stredne svetlý tón pleti',
    '🤛🏽' => 'päsť doľava: stredný tón pleti',
    '🤛🏾' => 'päsť doľava: stredne tmavý tón pleti',
    '🤛🏿' => 'päsť doľava: tmavý tón pleti',
    '🤜🏻' => 'päsť doprava: svetlý tón pleti',
    '🤜🏼' => 'päsť doprava: stredne svetlý tón pleti',
    '🤜🏽' => 'päsť doprava: stredný tón pleti',
    '🤜🏾' => 'päsť doprava: stredne tmavý tón pleti',
    '🤜🏿' => 'päsť doprava: tmavý tón pleti',
    '👏🏻' => 'tlieskajúce ruky: svetlý tón pleti',
    '👏🏼' => 'tlieskajúce ruky: stredne svetlý tón pleti',
    '👏🏽' => 'tlieskajúce ruky: stredný tón pleti',
    '👏🏾' => 'tlieskajúce ruky: stredne tmavý tón pleti',
    '👏🏿' => 'tlieskajúce ruky: tmavý tón pleti',
    '🙌🏻' => 'zdvihnuté ruky: svetlý tón pleti',
    '🙌🏼' => 'zdvihnuté ruky: stredne svetlý tón pleti',
    '🙌🏽' => 'zdvihnuté ruky: stredný tón pleti',
    '🙌🏾' => 'zdvihnuté ruky: stredne tmavý tón pleti',
    '🙌🏿' => 'zdvihnuté ruky: tmavý tón pleti',
    '🫶🏻' => 'srdce z dlaní: svetlý tón pleti',
    '🫶🏼' => 'srdce z dlaní: stredne svetlý tón pleti',
    '🫶🏽' => 'srdce z dlaní: stredný tón pleti',
    '🫶🏾' => 'srdce z dlaní: stredne tmavý tón pleti',
    '🫶🏿' => 'srdce z dlaní: tmavý tón pleti',
    '👐🏻' => 'roztvorené dlane: svetlý tón pleti',
    '👐🏼' => 'roztvorené dlane: stredne svetlý tón pleti',
    '👐🏽' => 'roztvorené dlane: stredný tón pleti',
    '👐🏾' => 'roztvorené dlane: stredne tmavý tón pleti',
    '👐🏿' => 'roztvorené dlane: tmavý tón pleti',
    '🤲🏻' => 'zdvihnuté dlane: svetlý tón pleti',
    '🤲🏼' => 'zdvihnuté dlane: stredne svetlý tón pleti',
    '🤲🏽' => 'zdvihnuté dlane: stredný tón pleti',
    '🤲🏾' => 'zdvihnuté dlane: stredne tmavý tón pleti',
    '🤲🏿' => 'zdvihnuté dlane: tmavý tón pleti',
    '🤝🏻' => 'potrasenie rukami: svetlý tón pleti',
    '🤝🏼' => 'potrasenie rukami: stredne svetlý tón pleti',
    '🤝🏽' => 'potrasenie rukami: stredný tón pleti',
    '🤝🏾' => 'potrasenie rukami: stredne tmavý tón pleti',
    '🤝🏿' => 'potrasenie rukami: tmavý tón pleti',
    '🙏🏻' => 'zopäté ruky: svetlý tón pleti',
    '🙏🏼' => 'zopäté ruky: stredne svetlý tón pleti',
    '🙏🏽' => 'zopäté ruky: stredný tón pleti',
    '🙏🏾' => 'zopäté ruky: stredne tmavý tón pleti',
    '🙏🏿' => 'zopäté ruky: tmavý tón pleti',
    '✍🏻' => 'píšuca ruka: svetlý tón pleti',
    '✍🏼' => 'píšuca ruka: stredne svetlý tón pleti',
    '✍🏽' => 'píšuca ruka: stredný tón pleti',
    '✍🏾' => 'píšuca ruka: stredne tmavý tón pleti',
    '✍🏿' => 'píšuca ruka: tmavý tón pleti',
    '💅🏻' => 'lakovanie nechtov: svetlý tón pleti',
    '💅🏼' => 'lakovanie nechtov: stredne svetlý tón pleti',
    '💅🏽' => 'lakovanie nechtov: stredný tón pleti',
    '💅🏾' => 'lakovanie nechtov: stredne tmavý tón pleti',
    '💅🏿' => 'lakovanie nechtov: tmavý tón pleti',
    '🤳🏻' => 'selfie: svetlý tón pleti',
    '🤳🏼' => 'selfie: stredne svetlý tón pleti',
    '🤳🏽' => 'selfie: stredný tón pleti',
    '🤳🏾' => 'selfie: stredne tmavý tón pleti',
    '🤳🏿' => 'selfie: tmavý tón pleti',
    '💪🏻' => 'napnutý biceps: svetlý tón pleti',
    '💪🏼' => 'napnutý biceps: stredne svetlý tón pleti',
    '💪🏽' => 'napnutý biceps: stredný tón pleti',
    '💪🏾' => 'napnutý biceps: stredne tmavý tón pleti',
    '💪🏿' => 'napnutý biceps: tmavý tón pleti',
    '🦵🏻' => 'noha: svetlý tón pleti',
    '🦵🏼' => 'noha: stredne svetlý tón pleti',
    '🦵🏽' => 'noha: stredný tón pleti',
    '🦵🏾' => 'noha: stredne tmavý tón pleti',
    '🦵🏿' => 'noha: tmavý tón pleti',
    '🦶🏻' => 'chodidlo: svetlý tón pleti',
    '🦶🏼' => 'chodidlo: stredne svetlý tón pleti',
    '🦶🏽' => 'chodidlo: stredný tón pleti',
    '🦶🏾' => 'chodidlo: stredne tmavý tón pleti',
    '🦶🏿' => 'chodidlo: tmavý tón pleti',
    '👂🏻' => 'ucho: svetlý tón pleti',
    '👂🏼' => 'ucho: stredne svetlý tón pleti',
    '👂🏽' => 'ucho: stredný tón pleti',
    '👂🏾' => 'ucho: stredne tmavý tón pleti',
    '👂🏿' => 'ucho: tmavý tón pleti',
    '🦻🏻' => 'ucho s načúvadlom: svetlý tón pleti',
    '🦻🏼' => 'ucho s načúvadlom: stredne svetlý tón pleti',
    '🦻🏽' => 'ucho s načúvadlom: stredný tón pleti',
    '🦻🏾' => 'ucho s načúvadlom: stredne tmavý tón pleti',
    '🦻🏿' => 'ucho s načúvadlom: tmavý tón pleti',
    '👃🏻' => 'nos: svetlý tón pleti',
    '👃🏼' => 'nos: stredne svetlý tón pleti',
    '👃🏽' => 'nos: stredný tón pleti',
    '👃🏾' => 'nos: stredne tmavý tón pleti',
    '👃🏿' => 'nos: tmavý tón pleti',
    '👶🏻' => 'bábätko: svetlý tón pleti',
    '👶🏼' => 'bábätko: stredne svetlý tón pleti',
    '👶🏽' => 'bábätko: stredný tón pleti',
    '👶🏾' => 'bábätko: stredne tmavý tón pleti',
    '👶🏿' => 'bábätko: tmavý tón pleti',
    '🧒🏻' => 'dieťa: svetlý tón pleti',
    '🧒🏼' => 'dieťa: stredne svetlý tón pleti',
    '🧒🏽' => 'dieťa: stredný tón pleti',
    '🧒🏾' => 'dieťa: stredne tmavý tón pleti',
    '🧒🏿' => 'dieťa: tmavý tón pleti',
    '👦🏻' => 'chlapec: svetlý tón pleti',
    '👦🏼' => 'chlapec: stredne svetlý tón pleti',
    '👦🏽' => 'chlapec: stredný tón pleti',
    '👦🏾' => 'chlapec: stredne tmavý tón pleti',
    '👦🏿' => 'chlapec: tmavý tón pleti',
    '👧🏻' => 'dievča: svetlý tón pleti',
    '👧🏼' => 'dievča: stredne svetlý tón pleti',
    '👧🏽' => 'dievča: stredný tón pleti',
    '👧🏾' => 'dievča: stredne tmavý tón pleti',
    '👧🏿' => 'dievča: tmavý tón pleti',
    '🧑🏻' => 'dospelý: svetlý tón pleti',
    '🧑🏼' => 'dospelý: stredne svetlý tón pleti',
    '🧑🏽' => 'dospelý: stredný tón pleti',
    '🧑🏾' => 'dospelý: stredne tmavý tón pleti',
    '🧑🏿' => 'dospelý: tmavý tón pleti',
    '👱🏻' => 'svetlovlasý človek: svetlý tón pleti',
    '👱🏼' => 'svetlovlasý človek: stredne svetlý tón pleti',
    '👱🏽' => 'svetlovlasý človek: stredný tón pleti',
    '👱🏾' => 'svetlovlasý človek: stredne tmavý tón pleti',
    '👱🏿' => 'svetlovlasý človek: tmavý tón pleti',
    '👨🏻' => 'muž: svetlý tón pleti',
    '👨🏼' => 'muž: stredne svetlý tón pleti',
    '👨🏽' => 'muž: stredný tón pleti',
    '👨🏾' => 'muž: stredne tmavý tón pleti',
    '👨🏿' => 'muž: tmavý tón pleti',
    '🧔🏻' => 'bradáč: svetlý tón pleti',
    '🧔🏼' => 'bradáč: stredne svetlý tón pleti',
    '🧔🏽' => 'bradáč: stredný tón pleti',
    '🧔🏾' => 'bradáč: stredne tmavý tón pleti',
    '🧔🏿' => 'bradáč: tmavý tón pleti',
    '👩🏻' => 'žena: svetlý tón pleti',
    '👩🏼' => 'žena: stredne svetlý tón pleti',
    '👩🏽' => 'žena: stredný tón pleti',
    '👩🏾' => 'žena: stredne tmavý tón pleti',
    '👩🏿' => 'žena: tmavý tón pleti',
    '🧓🏻' => 'starší človek: svetlý tón pleti',
    '🧓🏼' => 'starší človek: stredne svetlý tón pleti',
    '🧓🏽' => 'starší človek: stredný tón pleti',
    '🧓🏾' => 'starší človek: stredne tmavý tón pleti',
    '🧓🏿' => 'starší človek: tmavý tón pleti',
    '👴🏻' => 'starší muž: svetlý tón pleti',
    '👴🏼' => 'starší muž: stredne svetlý tón pleti',
    '👴🏽' => 'starší muž: stredný tón pleti',
    '👴🏾' => 'starší muž: stredne tmavý tón pleti',
    '👴🏿' => 'starší muž: tmavý tón pleti',
    '👵🏻' => 'staršia žena: svetlý tón pleti',
    '👵🏼' => 'staršia žena: stredne svetlý tón pleti',
    '👵🏽' => 'staršia žena: stredný tón pleti',
    '👵🏾' => 'staršia žena: stredne tmavý tón pleti',
    '👵🏿' => 'staršia žena: tmavý tón pleti',
    '🙍🏻' => 'zamračený človek: svetlý tón pleti',
    '🙍🏼' => 'zamračený človek: stredne svetlý tón pleti',
    '🙍🏽' => 'zamračený človek: stredný tón pleti',
    '🙍🏾' => 'zamračený človek: stredne tmavý tón pleti',
    '🙍🏿' => 'zamračený človek: tmavý tón pleti',
    '🙎🏻' => 'podráždený človek: svetlý tón pleti',
    '🙎🏼' => 'podráždený človek: stredne svetlý tón pleti',
    '🙎🏽' => 'podráždený človek: stredný tón pleti',
    '🙎🏾' => 'podráždený človek: stredne tmavý tón pleti',
    '🙎🏿' => 'podráždený človek: tmavý tón pleti',
    '🙅🏻' => 'človek s prekríženými rukami: svetlý tón pleti',
    '🙅🏼' => 'človek s prekríženými rukami: stredne svetlý tón pleti',
    '🙅🏽' => 'človek s prekríženými rukami: stredný tón pleti',
    '🙅🏾' => 'človek s prekríženými rukami: stredne tmavý tón pleti',
    '🙅🏿' => 'človek s prekríženými rukami: tmavý tón pleti',
    '🙆🏻' => 'človek s rukami nad hlavou: svetlý tón pleti',
    '🙆🏼' => 'človek s rukami nad hlavou: stredne svetlý tón pleti',
    '🙆🏽' => 'človek s rukami nad hlavou: stredný tón pleti',
    '🙆🏾' => 'človek s rukami nad hlavou: stredne tmavý tón pleti',
    '🙆🏿' => 'človek s rukami nad hlavou: tmavý tón pleti',
    '💁🏻' => 'človek s nastavenou dlaňou: svetlý tón pleti',
    '💁🏼' => 'človek s nastavenou dlaňou: stredne svetlý tón pleti',
    '💁🏽' => 'človek s nastavenou dlaňou: stredný tón pleti',
    '💁🏾' => 'človek s nastavenou dlaňou: stredne tmavý tón pleti',
    '💁🏿' => 'človek s nastavenou dlaňou: tmavý tón pleti',
    '🙋🏻' => 'človek so zdvihnutou rukou: svetlý tón pleti',
    '🙋🏼' => 'človek so zdvihnutou rukou: stredne svetlý tón pleti',
    '🙋🏽' => 'človek so zdvihnutou rukou: stredný tón pleti',
    '🙋🏾' => 'človek so zdvihnutou rukou: stredne tmavý tón pleti',
    '🙋🏿' => 'človek so zdvihnutou rukou: tmavý tón pleti',
    '🧏🏻' => 'nepočujúci človek: svetlý tón pleti',
    '🧏🏼' => 'nepočujúci človek: stredne svetlý tón pleti',
    '🧏🏽' => 'nepočujúci človek: stredný tón pleti',
    '🧏🏾' => 'nepočujúci človek: stredne tmavý tón pleti',
    '🧏🏿' => 'nepočujúci človek: tmavý tón pleti',
    '🙇🏻' => 'klaňajúci sa človek: svetlý tón pleti',
    '🙇🏼' => 'klaňajúci sa človek: stredne svetlý tón pleti',
    '🙇🏽' => 'klaňajúci sa človek: stredný tón pleti',
    '🙇🏾' => 'klaňajúci sa človek: stredne tmavý tón pleti',
    '🙇🏿' => 'klaňajúci sa človek: tmavý tón pleti',
    '🤦🏻' => 'človek chytajúci sa za hlavu: svetlý tón pleti',
    '🤦🏼' => 'človek chytajúci sa za hlavu: stredne svetlý tón pleti',
    '🤦🏽' => 'človek chytajúci sa za hlavu: stredný tón pleti',
    '🤦🏾' => 'človek chytajúci sa za hlavu: stredne tmavý tón pleti',
    '🤦🏿' => 'človek chytajúci sa za hlavu: tmavý tón pleti',
    '🤷🏻' => 'človek krčiaci plecami: svetlý tón pleti',
    '🤷🏼' => 'človek krčiaci plecami: stredne svetlý tón pleti',
    '🤷🏽' => 'človek krčiaci plecami: stredný tón pleti',
    '🤷🏾' => 'človek krčiaci plecami: stredne tmavý tón pleti',
    '🤷🏿' => 'človek krčiaci plecami: tmavý tón pleti',
    '👮🏻' => 'policajt: svetlý tón pleti',
    '👮🏼' => 'policajt: stredne svetlý tón pleti',
    '👮🏽' => 'policajt: stredný tón pleti',
    '👮🏾' => 'policajt: stredne tmavý tón pleti',
    '👮🏿' => 'policajt: tmavý tón pleti',
    '🕵🏻' => 'detektív: svetlý tón pleti',
    '🕵🏼' => 'detektív: stredne svetlý tón pleti',
    '🕵🏽' => 'detektív: stredný tón pleti',
    '🕵🏾' => 'detektív: stredne tmavý tón pleti',
    '🕵🏿' => 'detektív: tmavý tón pleti',
    '💂🏻' => 'stráž: svetlý tón pleti',
    '💂🏼' => 'stráž: stredne svetlý tón pleti',
    '💂🏽' => 'stráž: stredný tón pleti',
    '💂🏾' => 'stráž: stredne tmavý tón pleti',
    '💂🏿' => 'stráž: tmavý tón pleti',
    '🥷🏻' => 'nindža: svetlý tón pleti',
    '🥷🏼' => 'nindža: stredne svetlý tón pleti',
    '🥷🏽' => 'nindža: stredný tón pleti',
    '🥷🏾' => 'nindža: stredne tmavý tón pleti',
    '🥷🏿' => 'nindža: tmavý tón pleti',
    '👷🏻' => 'pracovník na stavbe: svetlý tón pleti',
    '👷🏼' => 'pracovník na stavbe: stredne svetlý tón pleti',
    '👷🏽' => 'pracovník na stavbe: stredný tón pleti',
    '👷🏾' => 'pracovník na stavbe: stredne tmavý tón pleti',
    '👷🏿' => 'pracovník na stavbe: tmavý tón pleti',
    '🫅🏻' => 'osoba s korunou: svetlý tón pleti',
    '🫅🏼' => 'osoba s korunou: stredne svetlý tón pleti',
    '🫅🏽' => 'osoba s korunou: stredný tón pleti',
    '🫅🏾' => 'osoba s korunou: stredne tmavý tón pleti',
    '🫅🏿' => 'osoba s korunou: tmavý tón pleti',
    '🤴🏻' => 'princ: svetlý tón pleti',
    '🤴🏼' => 'princ: stredne svetlý tón pleti',
    '🤴🏽' => 'princ: stredný tón pleti',
    '🤴🏾' => 'princ: stredne tmavý tón pleti',
    '🤴🏿' => 'princ: tmavý tón pleti',
    '👸🏻' => 'princezná: svetlý tón pleti',
    '👸🏼' => 'princezná: stredne svetlý tón pleti',
    '👸🏽' => 'princezná: stredný tón pleti',
    '👸🏾' => 'princezná: stredne tmavý tón pleti',
    '👸🏿' => 'princezná: tmavý tón pleti',
    '👳🏻' => 'človek s turbanom: svetlý tón pleti',
    '👳🏼' => 'človek s turbanom: stredne svetlý tón pleti',
    '👳🏽' => 'človek s turbanom: stredný tón pleti',
    '👳🏾' => 'človek s turbanom: stredne tmavý tón pleti',
    '👳🏿' => 'človek s turbanom: tmavý tón pleti',
    '👲🏻' => 'muž s čínskou čapicou: svetlý tón pleti',
    '👲🏼' => 'muž s čínskou čapicou: stredne svetlý tón pleti',
    '👲🏽' => 'muž s čínskou čapicou: stredný tón pleti',
    '👲🏾' => 'muž s čínskou čapicou: stredne tmavý tón pleti',
    '👲🏿' => 'muž s čínskou čapicou: tmavý tón pleti',
    '🧕🏻' => 'žena so šatkou: svetlý tón pleti',
    '🧕🏼' => 'žena so šatkou: stredne svetlý tón pleti',
    '🧕🏽' => 'žena so šatkou: stredný tón pleti',
    '🧕🏾' => 'žena so šatkou: stredne tmavý tón pleti',
    '🧕🏿' => 'žena so šatkou: tmavý tón pleti',
    '🤵🏻' => 'človek v smokingu: svetlý tón pleti',
    '🤵🏼' => 'človek v smokingu: stredne svetlý tón pleti',
    '🤵🏽' => 'človek v smokingu: stredný tón pleti',
    '🤵🏾' => 'človek v smokingu: stredne tmavý tón pleti',
    '🤵🏿' => 'človek v smokingu: tmavý tón pleti',
    '👰🏻' => 'človek so závojom: svetlý tón pleti',
    '👰🏼' => 'človek so závojom: stredne svetlý tón pleti',
    '👰🏽' => 'človek so závojom: stredný tón pleti',
    '👰🏾' => 'človek so závojom: stredne tmavý tón pleti',
    '👰🏿' => 'človek so závojom: tmavý tón pleti',
    '🤰🏻' => 'tehotná žena: svetlý tón pleti',
    '🤰🏼' => 'tehotná žena: stredne svetlý tón pleti',
    '🤰🏽' => 'tehotná žena: stredný tón pleti',
    '🤰🏾' => 'tehotná žena: stredne tmavý tón pleti',
    '🤰🏿' => 'tehotná žena: tmavý tón pleti',
    '🫃🏻' => 'tehotný muž: svetlý tón pleti',
    '🫃🏼' => 'tehotný muž: stredne svetlý tón pleti',
    '🫃🏽' => 'tehotný muž: stredný tón pleti',
    '🫃🏾' => 'tehotný muž: stredne tmavý tón pleti',
    '🫃🏿' => 'tehotný muž: tmavý tón pleti',
    '🫄🏻' => 'tehotná osoba: svetlý tón pleti',
    '🫄🏼' => 'tehotná osoba: stredne svetlý tón pleti',
    '🫄🏽' => 'tehotná osoba: stredný tón pleti',
    '🫄🏾' => 'tehotná osoba: stredne tmavý tón pleti',
    '🫄🏿' => 'tehotná osoba: tmavý tón pleti',
    '🤱🏻' => 'dojčenie: svetlý tón pleti',
    '🤱🏼' => 'dojčenie: stredne svetlý tón pleti',
    '🤱🏽' => 'dojčenie: stredný tón pleti',
    '🤱🏾' => 'dojčenie: stredne tmavý tón pleti',
    '🤱🏿' => 'dojčenie: tmavý tón pleti',
    '👼🏻' => 'anjelik: svetlý tón pleti',
    '👼🏼' => 'anjelik: stredne svetlý tón pleti',
    '👼🏽' => 'anjelik: stredný tón pleti',
    '👼🏾' => 'anjelik: stredne tmavý tón pleti',
    '👼🏿' => 'anjelik: tmavý tón pleti',
    '🎅🏻' => 'Santa: svetlý tón pleti',
    '🎅🏼' => 'Santa: stredne svetlý tón pleti',
    '🎅🏽' => 'Santa: stredný tón pleti',
    '🎅🏾' => 'Santa: stredne tmavý tón pleti',
    '🎅🏿' => 'Santa: tmavý tón pleti',
    '🤶🏻' => 'pani Santová: svetlý tón pleti',
    '🤶🏼' => 'pani Santová: stredne svetlý tón pleti',
    '🤶🏽' => 'pani Santová: stredný tón pleti',
    '🤶🏾' => 'pani Santová: stredne tmavý tón pleti',
    '🤶🏿' => 'pani Santová: tmavý tón pleti',
    '🦸🏻' => 'superhrdina: svetlý tón pleti',
    '🦸🏼' => 'superhrdina: stredne svetlý tón pleti',
    '🦸🏽' => 'superhrdina: stredný tón pleti',
    '🦸🏾' => 'superhrdina: stredne tmavý tón pleti',
    '🦸🏿' => 'superhrdina: tmavý tón pleti',
    '🦹🏻' => 'superdarebácka bytosť: svetlý tón pleti',
    '🦹🏼' => 'superdarebácka bytosť: stredne svetlý tón pleti',
    '🦹🏽' => 'superdarebácka bytosť: stredný tón pleti',
    '🦹🏾' => 'superdarebácka bytosť: stredne tmavý tón pleti',
    '🦹🏿' => 'superdarebácka bytosť: tmavý tón pleti',
    '🧙🏻' => 'čarodejná bytosť: svetlý tón pleti',
    '🧙🏼' => 'čarodejná bytosť: stredne svetlý tón pleti',
    '🧙🏽' => 'čarodejná bytosť: stredný tón pleti',
    '🧙🏾' => 'čarodejná bytosť: stredne tmavý tón pleti',
    '🧙🏿' => 'čarodejná bytosť: tmavý tón pleti',
    '🧚🏻' => 'rozprávková bytosť: svetlý tón pleti',
    '🧚🏼' => 'rozprávková bytosť: stredne svetlý tón pleti',
    '🧚🏽' => 'rozprávková bytosť: stredný tón pleti',
    '🧚🏾' => 'rozprávková bytosť: stredne tmavý tón pleti',
    '🧚🏿' => 'rozprávková bytosť: tmavý tón pleti',
    '🧛🏻' => 'upírska bytosť: svetlý tón pleti',
    '🧛🏼' => 'upírska bytosť: stredne svetlý tón pleti',
    '🧛🏽' => 'upírska bytosť: stredný tón pleti',
    '🧛🏾' => 'upírska bytosť: stredne tmavý tón pleti',
    '🧛🏿' => 'upírska bytosť: tmavý tón pleti',
    '🧜🏻' => 'morská bytosť: svetlý tón pleti',
    '🧜🏼' => 'morská bytosť: stredne svetlý tón pleti',
    '🧜🏽' => 'morská bytosť: stredný tón pleti',
    '🧜🏾' => 'morská bytosť: stredne tmavý tón pleti',
    '🧜🏿' => 'morská bytosť: tmavý tón pleti',
    '🧝🏻' => 'lesná bytosť: svetlý tón pleti',
    '🧝🏼' => 'lesná bytosť: stredne svetlý tón pleti',
    '🧝🏽' => 'lesná bytosť: stredný tón pleti',
    '🧝🏾' => 'lesná bytosť: stredne tmavý tón pleti',
    '🧝🏿' => 'lesná bytosť: tmavý tón pleti',
    '💆🏻' => 'masáž tváre: svetlý tón pleti',
    '💆🏼' => 'masáž tváre: stredne svetlý tón pleti',
    '💆🏽' => 'masáž tváre: stredný tón pleti',
    '💆🏾' => 'masáž tváre: stredne tmavý tón pleti',
    '💆🏿' => 'masáž tváre: tmavý tón pleti',
    '💇🏻' => 'strihanie vlasov: svetlý tón pleti',
    '💇🏼' => 'strihanie vlasov: stredne svetlý tón pleti',
    '💇🏽' => 'strihanie vlasov: stredný tón pleti',
    '💇🏾' => 'strihanie vlasov: stredne tmavý tón pleti',
    '💇🏿' => 'strihanie vlasov: tmavý tón pleti',
    '🚶🏻' => 'chodiaci človek: svetlý tón pleti',
    '🚶🏼' => 'chodiaci človek: stredne svetlý tón pleti',
    '🚶🏽' => 'chodiaci človek: stredný tón pleti',
    '🚶🏾' => 'chodiaci človek: stredne tmavý tón pleti',
    '🚶🏿' => 'chodiaci človek: tmavý tón pleti',
    '🧍🏻' => 'stojaci človek: svetlý tón pleti',
    '🧍🏼' => 'stojaci človek: stredne svetlý tón pleti',
    '🧍🏽' => 'stojaci človek: stredný tón pleti',
    '🧍🏾' => 'stojaci človek: stredne tmavý tón pleti',
    '🧍🏿' => 'stojaci človek: tmavý tón pleti',
    '🧎🏻' => 'kľačiaci človek: svetlý tón pleti',
    '🧎🏼' => 'kľačiaci človek: stredne svetlý tón pleti',
    '🧎🏽' => 'kľačiaci človek: stredný tón pleti',
    '🧎🏾' => 'kľačiaci človek: stredne tmavý tón pleti',
    '🧎🏿' => 'kľačiaci človek: tmavý tón pleti',
    '🏃🏻' => 'bežiaci človek: svetlý tón pleti',
    '🏃🏼' => 'bežiaci človek: stredne svetlý tón pleti',
    '🏃🏽' => 'bežiaci človek: stredný tón pleti',
    '🏃🏾' => 'bežiaci človek: stredne tmavý tón pleti',
    '🏃🏿' => 'bežiaci človek: tmavý tón pleti',
    '💃🏻' => 'tanečníčka: svetlý tón pleti',
    '💃🏼' => 'tanečníčka: stredne svetlý tón pleti',
    '💃🏽' => 'tanečníčka: stredný tón pleti',
    '💃🏾' => 'tanečníčka: stredne tmavý tón pleti',
    '💃🏿' => 'tanečníčka: tmavý tón pleti',
    '🕺🏻' => 'tanečník: svetlý tón pleti',
    '🕺🏼' => 'tanečník: stredne svetlý tón pleti',
    '🕺🏽' => 'tanečník: stredný tón pleti',
    '🕺🏾' => 'tanečník: stredne tmavý tón pleti',
    '🕺🏿' => 'tanečník: tmavý tón pleti',
    '🕴🏻' => 'levitujúci muž v saku: svetlý tón pleti',
    '🕴🏼' => 'levitujúci muž v saku: stredne svetlý tón pleti',
    '🕴🏽' => 'levitujúci muž v saku: stredný tón pleti',
    '🕴🏾' => 'levitujúci muž v saku: stredne tmavý tón pleti',
    '🕴🏿' => 'levitujúci muž v saku: tmavý tón pleti',
    '👯🏻' => 'ľudia so zajačími ušami: svetlý tón pleti',
    '👯🏼' => 'ľudia so zajačími ušami: stredne svetlý tón pleti',
    '👯🏽' => 'ľudia so zajačími ušami: stredný tón pleti',
    '👯🏾' => 'ľudia so zajačími ušami: stredne tmavý tón pleti',
    '👯🏿' => 'ľudia so zajačími ušami: tmavý tón pleti',
    '🧖🏻' => 'človek v pare: svetlý tón pleti',
    '🧖🏼' => 'človek v pare: stredne svetlý tón pleti',
    '🧖🏽' => 'človek v pare: stredný tón pleti',
    '🧖🏾' => 'človek v pare: stredne tmavý tón pleti',
    '🧖🏿' => 'človek v pare: tmavý tón pleti',
    '🧗🏻' => 'človek na skale: svetlý tón pleti',
    '🧗🏼' => 'človek na skale: stredne svetlý tón pleti',
    '🧗🏽' => 'človek na skale: stredný tón pleti',
    '🧗🏾' => 'človek na skale: stredne tmavý tón pleti',
    '🧗🏿' => 'človek na skale: tmavý tón pleti',
    '🏇🏻' => 'dostihy: svetlý tón pleti',
    '🏇🏼' => 'dostihy: stredne svetlý tón pleti',
    '🏇🏽' => 'dostihy: stredný tón pleti',
    '🏇🏾' => 'dostihy: stredne tmavý tón pleti',
    '🏇🏿' => 'dostihy: tmavý tón pleti',
    '🏂🏻' => 'snoubordista: svetlý tón pleti',
    '🏂🏼' => 'snoubordista: stredne svetlý tón pleti',
    '🏂🏽' => 'snoubordista: stredný tón pleti',
    '🏂🏾' => 'snoubordista: stredne tmavý tón pleti',
    '🏂🏿' => 'snoubordista: tmavý tón pleti',
    '🏌🏻' => 'hráč golfu: svetlý tón pleti',
    '🏌🏼' => 'hráč golfu: stredne svetlý tón pleti',
    '🏌🏽' => 'hráč golfu: stredný tón pleti',
    '🏌🏾' => 'hráč golfu: stredne tmavý tón pleti',
    '🏌🏿' => 'hráč golfu: tmavý tón pleti',
    '🏄🏻' => 'človek na surfe: svetlý tón pleti',
    '🏄🏼' => 'človek na surfe: stredne svetlý tón pleti',
    '🏄🏽' => 'človek na surfe: stredný tón pleti',
    '🏄🏾' => 'človek na surfe: stredne tmavý tón pleti',
    '🏄🏿' => 'človek na surfe: tmavý tón pleti',
    '🚣🏻' => 'človek na veslici: svetlý tón pleti',
    '🚣🏼' => 'človek na veslici: stredne svetlý tón pleti',
    '🚣🏽' => 'človek na veslici: stredný tón pleti',
    '🚣🏾' => 'človek na veslici: stredne tmavý tón pleti',
    '🚣🏿' => 'človek na veslici: tmavý tón pleti',
    '🏊🏻' => 'plávajúci človek: svetlý tón pleti',
    '🏊🏼' => 'plávajúci človek: stredne svetlý tón pleti',
    '🏊🏽' => 'plávajúci človek: stredný tón pleti',
    '🏊🏾' => 'plávajúci človek: stredne tmavý tón pleti',
    '🏊🏿' => 'plávajúci človek: tmavý tón pleti',
    '⛹🏻' => 'človek s loptou: svetlý tón pleti',
    '⛹🏼' => 'človek s loptou: stredne svetlý tón pleti',
    '⛹🏽' => 'človek s loptou: stredný tón pleti',
    '⛹🏾' => 'človek s loptou: stredne tmavý tón pleti',
    '⛹🏿' => 'človek s loptou: tmavý tón pleti',
    '🏋🏻' => 'vzpierajúci človek: svetlý tón pleti',
    '🏋🏼' => 'vzpierajúci človek: stredne svetlý tón pleti',
    '🏋🏽' => 'vzpierajúci človek: stredný tón pleti',
    '🏋🏾' => 'vzpierajúci človek: stredne tmavý tón pleti',
    '🏋🏿' => 'vzpierajúci človek: tmavý tón pleti',
    '🚴🏻' => 'človek na bicykli: svetlý tón pleti',
    '🚴🏼' => 'človek na bicykli: stredne svetlý tón pleti',
    '🚴🏽' => 'človek na bicykli: stredný tón pleti',
    '🚴🏾' => 'človek na bicykli: stredne tmavý tón pleti',
    '🚴🏿' => 'človek na bicykli: tmavý tón pleti',
    '🚵🏻' => 'človek na horskom bicykli: svetlý tón pleti',
    '🚵🏼' => 'človek na horskom bicykli: stredne svetlý tón pleti',
    '🚵🏽' => 'človek na horskom bicykli: stredný tón pleti',
    '🚵🏾' => 'človek na horskom bicykli: stredne tmavý tón pleti',
    '🚵🏿' => 'človek na horskom bicykli: tmavý tón pleti',
    '🤸🏻' => 'človek robí hviezdu: svetlý tón pleti',
    '🤸🏼' => 'človek robí hviezdu: stredne svetlý tón pleti',
    '🤸🏽' => 'človek robí hviezdu: stredný tón pleti',
    '🤸🏾' => 'človek robí hviezdu: stredne tmavý tón pleti',
    '🤸🏿' => 'človek robí hviezdu: tmavý tón pleti',
    '🤼🏻' => 'zápasiaci ľudia: svetlý tón pleti',
    '🤼🏼' => 'zápasiaci ľudia: stredne svetlý tón pleti',
    '🤼🏽' => 'zápasiaci ľudia: stredný tón pleti',
    '🤼🏾' => 'zápasiaci ľudia: stredne tmavý tón pleti',
    '🤼🏿' => 'zápasiaci ľudia: tmavý tón pleti',
    '🤽🏻' => 'vodné pólo: svetlý tón pleti',
    '🤽🏼' => 'vodné pólo: stredne svetlý tón pleti',
    '🤽🏽' => 'vodné pólo: stredný tón pleti',
    '🤽🏾' => 'vodné pólo: stredne tmavý tón pleti',
    '🤽🏿' => 'vodné pólo: tmavý tón pleti',
    '🤾🏻' => 'hádzaná: svetlý tón pleti',
    '🤾🏼' => 'hádzaná: stredne svetlý tón pleti',
    '🤾🏽' => 'hádzaná: stredný tón pleti',
    '🤾🏾' => 'hádzaná: stredne tmavý tón pleti',
    '🤾🏿' => 'hádzaná: tmavý tón pleti',
    '🤹🏻' => 'žonglovanie: svetlý tón pleti',
    '🤹🏼' => 'žonglovanie: stredne svetlý tón pleti',
    '🤹🏽' => 'žonglovanie: stredný tón pleti',
    '🤹🏾' => 'žonglovanie: stredne tmavý tón pleti',
    '🤹🏿' => 'žonglovanie: tmavý tón pleti',
    '🧘🏻' => 'človek v lotosovom sede: svetlý tón pleti',
    '🧘🏼' => 'človek v lotosovom sede: stredne svetlý tón pleti',
    '🧘🏽' => 'človek v lotosovom sede: stredný tón pleti',
    '🧘🏾' => 'človek v lotosovom sede: stredne tmavý tón pleti',
    '🧘🏿' => 'človek v lotosovom sede: tmavý tón pleti',
    '🛀🏻' => 'človek vo vani: svetlý tón pleti',
    '🛀🏼' => 'človek vo vani: stredne svetlý tón pleti',
    '🛀🏽' => 'človek vo vani: stredný tón pleti',
    '🛀🏾' => 'človek vo vani: stredne tmavý tón pleti',
    '🛀🏿' => 'človek vo vani: tmavý tón pleti',
    '🛌🏻' => 'človek v posteli: svetlý tón pleti',
    '🛌🏼' => 'človek v posteli: stredne svetlý tón pleti',
    '🛌🏽' => 'človek v posteli: stredný tón pleti',
    '🛌🏾' => 'človek v posteli: stredne tmavý tón pleti',
    '🛌🏿' => 'človek v posteli: tmavý tón pleti',
    '👭🏻' => 'ženy držiace sa za ruky: svetlý tón pleti',
    '👭🏼' => 'ženy držiace sa za ruky: stredne svetlý tón pleti',
    '👭🏽' => 'ženy držiace sa za ruky: stredný tón pleti',
    '👭🏾' => 'ženy držiace sa za ruky: stredne tmavý tón pleti',
    '👭🏿' => 'ženy držiace sa za ruky: tmavý tón pleti',
    '👫🏻' => 'žena a muž držiaci sa za ruky: svetlý tón pleti',
    '👫🏼' => 'žena a muž držiaci sa za ruky: stredne svetlý tón pleti',
    '👫🏽' => 'žena a muž držiaci sa za ruky: stredný tón pleti',
    '👫🏾' => 'žena a muž držiaci sa za ruky: stredne tmavý tón pleti',
    '👫🏿' => 'žena a muž držiaci sa za ruky: tmavý tón pleti',
    '👬🏻' => 'muži držiaci sa za ruky: svetlý tón pleti',
    '👬🏼' => 'muži držiaci sa za ruky: stredne svetlý tón pleti',
    '👬🏽' => 'muži držiaci sa za ruky: stredný tón pleti',
    '👬🏾' => 'muži držiaci sa za ruky: stredne tmavý tón pleti',
    '👬🏿' => 'muži držiaci sa za ruky: tmavý tón pleti',
    '💏🏻' => 'bozk: svetlý tón pleti',
    '💏🏼' => 'bozk: stredne svetlý tón pleti',
    '💏🏽' => 'bozk: stredný tón pleti',
    '💏🏾' => 'bozk: stredne tmavý tón pleti',
    '💏🏿' => 'bozk: tmavý tón pleti',
    '💑🏻' => 'pár so srdcom: svetlý tón pleti',
    '💑🏼' => 'pár so srdcom: stredne svetlý tón pleti',
    '💑🏽' => 'pár so srdcom: stredný tón pleti',
    '💑🏾' => 'pár so srdcom: stredne tmavý tón pleti',
    '💑🏿' => 'pár so srdcom: tmavý tón pleti',
    '🇦🇨' => 'zástava: Ascension',
    '🇦🇩' => 'zástava: Andorra',
    '🇦🇪' => 'zástava: Spojené arabské emiráty',
    '🇦🇫' => 'zástava: Afganistan',
    '🇦🇬' => 'zástava: Antigua a Barbuda',
    '🇦🇮' => 'zástava: Anguilla',
    '🇦🇱' => 'zástava: Albánsko',
    '🇦🇲' => 'zástava: Arménsko',
    '🇦🇴' => 'zástava: Angola',
    '🇦🇶' => 'zástava: Antarktída',
    '🇦🇷' => 'zástava: Argentína',
    '🇦🇸' => 'zástava: Americká Samoa',
    '🇦🇹' => 'zástava: Rakúsko',
    '🇦🇺' => 'zástava: Austrália',
    '🇦🇼' => 'zástava: Aruba',
    '🇦🇽' => 'zástava: Alandy',
    '🇦🇿' => 'zástava: Azerbajdžan',
    '🇧🇦' => 'zástava: Bosna a Hercegovina',
    '🇧🇧' => 'zástava: Barbados',
    '🇧🇩' => 'zástava: Bangladéš',
    '🇧🇪' => 'zástava: Belgicko',
    '🇧🇫' => 'zástava: Burkina Faso',
    '🇧🇬' => 'zástava: Bulharsko',
    '🇧🇭' => 'zástava: Bahrajn',
    '🇧🇮' => 'zástava: Burundi',
    '🇧🇯' => 'zástava: Benin',
    '🇧🇱' => 'zástava: Svätý Bartolomej',
    '🇧🇲' => 'zástava: Bermudy',
    '🇧🇳' => 'zástava: Brunej',
    '🇧🇴' => 'zástava: Bolívia',
    '🇧🇶' => 'zástava: Karibské Holandsko',
    '🇧🇷' => 'zástava: Brazília',
    '🇧🇸' => 'zástava: Bahamy',
    '🇧🇹' => 'zástava: Bhután',
    '🇧🇻' => 'zástava: Bouvetov ostrov',
    '🇧🇼' => 'zástava: Botswana',
    '🇧🇾' => 'zástava: Bielorusko',
    '🇧🇿' => 'zástava: Belize',
    '🇨🇦' => 'zástava: Kanada',
    '🇨🇨' => 'zástava: Kokosové ostrovy',
    '🇨🇩' => 'zástava: Konžská demokratická republika',
    '🇨🇫' => 'zástava: Stredoafrická republika',
    '🇨🇬' => 'zástava: Konžská republika',
    '🇨🇭' => 'zástava: Švajčiarsko',
    '🇨🇮' => 'zástava: Pobrežie Slonoviny',
    '🇨🇰' => 'zástava: Cookove ostrovy',
    '🇨🇱' => 'zástava: Čile',
    '🇨🇲' => 'zástava: Kamerun',
    '🇨🇳' => 'zástava: Čína',
    '🇨🇴' => 'zástava: Kolumbia',
    '🇨🇵' => 'zástava: Clipperton',
    '🇨🇶' => 'zástava: Sark',
    '🇨🇷' => 'zástava: Kostarika',
    '🇨🇺' => 'zástava: Kuba',
    '🇨🇻' => 'zástava: Kapverdy',
    '🇨🇼' => 'zástava: Curaçao',
    '🇨🇽' => 'zástava: Vianočný ostrov',
    '🇨🇾' => 'zástava: Cyprus',
    '🇨🇿' => 'zástava: Česko',
    '🇩🇪' => 'zástava: Nemecko',
    '🇩🇬' => 'zástava: Diego Garcia',
    '🇩🇯' => 'zástava: Džibutsko',
    '🇩🇰' => 'zástava: Dánsko',
    '🇩🇲' => 'zástava: Dominika',
    '🇩🇴' => 'zástava: Dominikánska republika',
    '🇩🇿' => 'zástava: Alžírsko',
    '🇪🇦' => 'zástava: Ceuta a Melilla',
    '🇪🇨' => 'zástava: Ekvádor',
    '🇪🇪' => 'zástava: Estónsko',
    '🇪🇬' => 'zástava: Egypt',
    '🇪🇭' => 'zástava: Západná Sahara',
    '🇪🇷' => 'zástava: Eritrea',
    '🇪🇸' => 'zástava: Španielsko',
    '🇪🇹' => 'zástava: Etiópia',
    '🇪🇺' => 'zástava: Európska únia',
    '🇫🇮' => 'zástava: Fínsko',
    '🇫🇯' => 'zástava: Fidži',
    '🇫🇰' => 'zástava: Falklandy',
    '🇫🇲' => 'zástava: Mikronézia',
    '🇫🇴' => 'zástava: Faerské ostrovy',
    '🇫🇷' => 'zástava: Francúzsko',
    '🇬🇦' => 'zástava: Gabon',
    '🇬🇧' => 'zástava: Spojené kráľovstvo',
    '🇬🇩' => 'zástava: Grenada',
    '🇬🇪' => 'zástava: Gruzínsko',
    '🇬🇫' => 'zástava: Francúzska Guyana',
    '🇬🇬' => 'zástava: Guernsey',
    '🇬🇭' => 'zástava: Ghana',
    '🇬🇮' => 'zástava: Gibraltár',
    '🇬🇱' => 'zástava: Grónsko',
    '🇬🇲' => 'zástava: Gambia',
    '🇬🇳' => 'zástava: Guinea',
    '🇬🇵' => 'zástava: Guadeloupe',
    '🇬🇶' => 'zástava: Rovníková Guinea',
    '🇬🇷' => 'zástava: Grécko',
    '🇬🇸' => 'zástava: Južná Georgia a Južné Sandwichove ostrovy',
    '🇬🇹' => 'zástava: Guatemala',
    '🇬🇺' => 'zástava: Guam',
    '🇬🇼' => 'zástava: Guinea-Bissau',
    '🇬🇾' => 'zástava: Guyana',
    '🇭🇰' => 'zástava: Hongkong – OAO Číny',
    '🇭🇲' => 'zástava: Heardov ostrov a Macdonaldove ostrovy',
    '🇭🇳' => 'zástava: Honduras',
    '🇭🇷' => 'zástava: Chorvátsko',
    '🇭🇹' => 'zástava: Haiti',
    '🇭🇺' => 'zástava: Maďarsko',
    '🇮🇨' => 'zástava: Kanárske ostrovy',
    '🇮🇩' => 'zástava: Indonézia',
    '🇮🇪' => 'zástava: Írsko',
    '🇮🇱' => 'zástava: Izrael',
    '🇮🇲' => 'zástava: Ostrov Man',
    '🇮🇳' => 'zástava: India',
    '🇮🇴' => 'zástava: Britské indickooceánske územie',
    '🇮🇶' => 'zástava: Irak',
    '🇮🇷' => 'zástava: Irán',
    '🇮🇸' => 'zástava: Island',
    '🇮🇹' => 'zástava: Taliansko',
    '🇯🇪' => 'zástava: Jersey',
    '🇯🇲' => 'zástava: Jamajka',
    '🇯🇴' => 'zástava: Jordánsko',
    '🇯🇵' => 'zástava: Japonsko',
    '🇰🇪' => 'zástava: Keňa',
    '🇰🇬' => 'zástava: Kirgizsko',
    '🇰🇭' => 'zástava: Kambodža',
    '🇰🇮' => 'zástava: Kiribati',
    '🇰🇲' => 'zástava: Komory',
    '🇰🇳' => 'zástava: Svätý Krištof a Nevis',
    '🇰🇵' => 'zástava: Severná Kórea',
    '🇰🇷' => 'zástava: Južná Kórea',
    '🇰🇼' => 'zástava: Kuvajt',
    '🇰🇾' => 'zástava: Kajmanie ostrovy',
    '🇰🇿' => 'zástava: Kazachstan',
    '🇱🇦' => 'zástava: Laos',
    '🇱🇧' => 'zástava: Libanon',
    '🇱🇨' => 'zástava: Svätá Lucia',
    '🇱🇮' => 'zástava: Lichtenštajnsko',
    '🇱🇰' => 'zástava: Srí Lanka',
    '🇱🇷' => 'zástava: Libéria',
    '🇱🇸' => 'zástava: Lesotho',
    '🇱🇹' => 'zástava: Litva',
    '🇱🇺' => 'zástava: Luxembursko',
    '🇱🇻' => 'zástava: Lotyšsko',
    '🇱🇾' => 'zástava: Líbya',
    '🇲🇦' => 'zástava: Maroko',
    '🇲🇨' => 'zástava: Monako',
    '🇲🇩' => 'zástava: Moldavsko',
    '🇲🇪' => 'zástava: Čierna Hora',
    '🇲🇫' => 'zástava: Svätý Martin (fr.)',
    '🇲🇬' => 'zástava: Madagaskar',
    '🇲🇭' => 'zástava: Marshallove ostrovy',
    '🇲🇰' => 'zástava: Severné Macedónsko',
    '🇲🇱' => 'zástava: Mali',
    '🇲🇲' => 'zástava: Mjanmarsko',
    '🇲🇳' => 'zástava: Mongolsko',
    '🇲🇴' => 'zástava: Macao – OAO Číny',
    '🇲🇵' => 'zástava: Severné Mariány',
    '🇲🇶' => 'zástava: Martinik',
    '🇲🇷' => 'zástava: Mauritánia',
    '🇲🇸' => 'zástava: Montserrat',
    '🇲🇹' => 'zástava: Malta',
    '🇲🇺' => 'zástava: Maurícius',
    '🇲🇻' => 'zástava: Maldivy',
    '🇲🇼' => 'zástava: Malawi',
    '🇲🇽' => 'zástava: Mexiko',
    '🇲🇾' => 'zástava: Malajzia',
    '🇲🇿' => 'zástava: Mozambik',
    '🇳🇦' => 'zástava: Namíbia',
    '🇳🇨' => 'zástava: Nová Kaledónia',
    '🇳🇪' => 'zástava: Niger',
    '🇳🇫' => 'zástava: Norfolk',
    '🇳🇬' => 'zástava: Nigéria',
    '🇳🇮' => 'zástava: Nikaragua',
    '🇳🇱' => 'zástava: Holandsko',
    '🇳🇴' => 'zástava: Nórsko',
    '🇳🇵' => 'zástava: Nepál',
    '🇳🇷' => 'zástava: Nauru',
    '🇳🇺' => 'zástava: Niue',
    '🇳🇿' => 'zástava: Nový Zéland',
    '🇴🇲' => 'zástava: Omán',
    '🇵🇦' => 'zástava: Panama',
    '🇵🇪' => 'zástava: Peru',
    '🇵🇫' => 'zástava: Francúzska Polynézia',
    '🇵🇬' => 'zástava: Papua-Nová Guinea',
    '🇵🇭' => 'zástava: Filipíny',
    '🇵🇰' => 'zástava: Pakistan',
    '🇵🇱' => 'zástava: Poľsko',
    '🇵🇲' => 'zástava: Saint Pierre a Miquelon',
    '🇵🇳' => 'zástava: Pitcairnove ostrovy',
    '🇵🇷' => 'zástava: Portoriko',
    '🇵🇸' => 'zástava: Palestínske územia',
    '🇵🇹' => 'zástava: Portugalsko',
    '🇵🇼' => 'zástava: Palau',
    '🇵🇾' => 'zástava: Paraguaj',
    '🇶🇦' => 'zástava: Katar',
    '🇷🇪' => 'zástava: Réunion',
    '🇷🇴' => 'zástava: Rumunsko',
    '🇷🇸' => 'zástava: Srbsko',
    '🇷🇺' => 'zástava: Rusko',
    '🇷🇼' => 'zástava: Rwanda',
    '🇸🇦' => 'zástava: Saudská Arábia',
    '🇸🇧' => 'zástava: Šalamúnove ostrovy',
    '🇸🇨' => 'zástava: Seychely',
    '🇸🇩' => 'zástava: Sudán',
    '🇸🇪' => 'zástava: Švédsko',
    '🇸🇬' => 'zástava: Singapur',
    '🇸🇭' => 'zástava: Svätá Helena',
    '🇸🇮' => 'zástava: Slovinsko',
    '🇸🇯' => 'zástava: Svalbard a Jan Mayen',
    '🇸🇰' => 'zástava: Slovensko',
    '🇸🇱' => 'zástava: Sierra Leone',
    '🇸🇲' => 'zástava: San Maríno',
    '🇸🇳' => 'zástava: Senegal',
    '🇸🇴' => 'zástava: Somálsko',
    '🇸🇷' => 'zástava: Surinam',
    '🇸🇸' => 'zástava: Južný Sudán',
    '🇸🇹' => 'zástava: Svätý Tomáš a Princov ostrov',
    '🇸🇻' => 'zástava: Salvádor',
    '🇸🇽' => 'zástava: Svätý Martin (hol.)',
    '🇸🇾' => 'zástava: Sýria',
    '🇸🇿' => 'zástava: Eswatini',
    '🇹🇦' => 'zástava: Tristan da Cunha',
    '🇹🇨' => 'zástava: Turks a Caicos',
    '🇹🇩' => 'zástava: Čad',
    '🇹🇫' => 'zástava: Francúzske južné a antarktické územia',
    '🇹🇬' => 'zástava: Togo',
    '🇹🇭' => 'zástava: Thajsko',
    '🇹🇯' => 'zástava: Tadžikistan',
    '🇹🇰' => 'zástava: Tokelau',
    '🇹🇱' => 'zástava: Východný Timor',
    '🇹🇲' => 'zástava: Turkménsko',
    '🇹🇳' => 'zástava: Tunisko',
    '🇹🇴' => 'zástava: Tonga',
    '🇹🇷' => 'zástava: Turecko',
    '🇹🇹' => 'zástava: Trinidad a Tobago',
    '🇹🇻' => 'zástava: Tuvalu',
    '🇹🇼' => 'zástava: Taiwan',
    '🇹🇿' => 'zástava: Tanzánia',
    '🇺🇦' => 'zástava: Ukrajina',
    '🇺🇬' => 'zástava: Uganda',
    '🇺🇲' => 'zástava: Menšie odľahlé ostrovy USA',
    '🇺🇳' => 'zástava: Organizácia Spojených národov',
    '🇺🇸' => 'zástava: Spojené štáty',
    '🇺🇾' => 'zástava: Uruguaj',
    '🇺🇿' => 'zástava: Uzbekistan',
    '🇻🇦' => 'zástava: Vatikán',
    '🇻🇨' => 'zástava: Svätý Vincent a Grenadíny',
    '🇻🇪' => 'zástava: Venezuela',
    '🇻🇬' => 'zástava: Britské Panenské ostrovy',
    '🇻🇮' => 'zástava: Americké Panenské ostrovy',
    '🇻🇳' => 'zástava: Vietnam',
    '🇻🇺' => 'zástava: Vanuatu',
    '🇼🇫' => 'zástava: Wallis a Futuna',
    '🇼🇸' => 'zástava: Samoa',
    '🇽🇰' => 'zástava: Kosovo',
    '🇾🇪' => 'zástava: Jemen',
    '🇾🇹' => 'zástava: Mayotte',
    '🇿🇦' => 'zástava: Južná Afrika',
    '🇿🇲' => 'zástava: Zambia',
    '🇿🇼' => 'zástava: Zimbabwe',
    '🔟' => 'kláves: 10',
    '🏻' => 'svetlý tón pleti',
    '🏼' => 'stredne svetlý tón pleti',
    '🏽' => 'stredný tón pleti',
    '🏾' => 'stredne tmavý tón pleti',
    '🏿' => 'tmavý tón pleti',
    '😀' => 'škeriaca sa tvár',
    '😃' => 'škeriaca sa tvár s veľkými očami',
    '😄' => 'škeriaca sa tvár s prižmúrenými očami',
    '😁' => 'natešená tvár s prižmúrenými očami',
    '😆' => 'škeriaca sa tvár s privretými očami',
    '😅' => 'škeriaca sa tvár s potom',
    '🤣' => 'váľam sa od smiechu',
    '😂' => 'plačem od smiechu',
    '🙂' => 'usmievajúca sa tvár',
    '🙃' => 'prevrátená tvár',
    '🫠' => 'roztopená tvár',
    '😉' => 'žmurkajúca tvár',
    '😊' => 'smejúca sa tvár s prižmúrenými očami',
    '😇' => 'smejúca sa tvár so svätožiarou',
    '🥰' => 'smejúca sa tvár s tromi srdiečkami',
    '😍' => 'smejúca sa tvár so srdiečkami',
    '🤩' => 'pobláznená tvár',
    '😘' => 'tvár posielajúca bozk',
    '😗' => 'bozkávajúca tvár',
    '☺' => 'smejúca sa tvár',
    '😚' => 'bozkávajúca tvár so zatvorenými očami',
    '😙' => 'bozkávajúca tvár s prižmúrenými očami',
    '🥲' => 'smejúca sa tvár so slzou',
    '😋' => 'pochutnávajúca si tvár',
    '😛' => 'tvár s vyplazeným jazykom',
    '😜' => 'žmurkajúca tvár s vyplazeným jazykom',
    '🤪' => 'bláznivá tvár',
    '😝' => 'škúliaca tvár s jazykom',
    '🤑' => 'tvár s peniazmi na jazyku',
    '🤗' => 'objímajúca tvár',
    '🤭' => 'tvár s rukou na ústach',
    '🫢' => 'tvár s otvorenými očami a rukou na ústach',
    '🫣' => 'tvár vykúkajúca pomedzi prsty',
    '🤫' => 'tvár s prstom na ústach',
    '🤔' => 'premýšľajúca tvár',
    '🫡' => 'salutujúca tvár',
    '🤐' => 'tvár so zazipsovanými ústami',
    '🤨' => 'tvár so zdvihnutým obočím',
    '😐' => 'neutrálna tvár',
    '😑' => 'bezvýrazná tvár',
    '😶' => 'tvár bez úst',
    '🫥' => 'tvár s prerušovanou čiarou',
    '😏' => 'samoľúba tvár',
    '😒' => 'znudená tvár',
    '🙄' => 'tvár prevracajúca oči',
    '😬' => 'vyškerená tvár',
    '🤥' => 'tvár s dlhým nosom',
    '🫨' => 'roztrasená tvár',
    '😌' => 'tvár vyjadrujúca úľavu',
    '😔' => 'zamyslená tvár',
    '😪' => 'ospalá tvár',
    '🤤' => 'slintajúca tvár',
    '😴' => 'spiaca tvár',
    '🫩' => 'tvár s kruhmi pod očami',
    '😷' => 'tvár s rúškom',
    '🤒' => 'tvár s teplomerom',
    '🤕' => 'tvár s obväzom',
    '🤢' => 'tvár, ktorej je zle',
    '🤮' => 'tvár, ktorá vracia',
    '🤧' => 'kýchajúca tvár',
    '🥵' => 'rozhorúčená tvár',
    '🥶' => 'mrznúca tvár',
    '🥴' => 'malátna tvár',
    '😵' => 'tvár so závratom',
    '🤯' => 'vybuchujúca hlava',
    '🤠' => 'tvár s kovbojským klobúkom',
    '🥳' => 'oslavujúca tvár',
    '🥸' => 'maskovaná tvár',
    '😎' => 'smejúca sa tvár s okuliarmi',
    '🤓' => 'vedátor',
    '🧐' => 'tvár s monoklom',
    '😕' => 'zmätená tvár',
    '🫤' => 'tvár so šikmými ústami',
    '😟' => 'ustaraná tvár',
    '🙁' => 'trochu zamračená tvár',
    '☹' => 'zamračená tvár',
    '😮' => 'tvár s otvorenými ústami',
    '😯' => 'umlčaná tvár',
    '😲' => 'udivená tvár',
    '😳' => 'zapýrená tvár',
    '🫪' => 'zdeformovaná tvár',
    '🥺' => 'prosebná tvár',
    '🥹' => 'tvár zadržujúca slzy',
    '😦' => 'zamračená tvár s otvorenými ústami',
    '😧' => 'utrápená tvár',
    '😨' => 'vystrašená tvár',
    '😰' => 'znepokojená tvár s potom',
    '😥' => 'sklamaná, ale uvoľnená tvár',
    '😢' => 'plačúca tvár',
    '😭' => 'nariekajúca tvár',
    '😱' => 'tvár kričiaca od strachu',
    '😖' => 'tvár v rozpakoch',
    '😣' => 'urputná tvár',
    '😞' => 'sklamaná tvár',
    '😓' => 'skľúčená tvár s potom',
    '😩' => 'ustatá tvár',
    '😫' => 'unavená tvár',
    '🥱' => 'zívajúca tvár',
    '😤' => 'tvár s parou z nosa',
    '😡' => 'podráždená tvár',
    '😠' => 'nahnevaná tvár',
    '🤬' => 'nadávajúca tvár',
    '😈' => 'smejúca sa tvár s rohmi',
    '👿' => 'nahnevaná tvár s rohmi',
    '💀' => 'lebka',
    '☠' => 'lebka s prekríženými kosťami',
    '💩' => 'hovienko',
    '🤡' => 'tvár klauna',
    '👹' => 'obluda',
    '👺' => 'škrat',
    '👻' => 'duch',
    '👽' => 'mimozemšťan',
    '👾' => 'mimozemská príšera',
    '🤖' => 'robot',
    '😺' => 'škeriaca sa mačka',
    '😸' => 'škeriaca sa mačka s prižmúrenými očami',
    '😹' => 'mačka plače od smiechu',
    '😻' => 'smejúca sa mačka so srdiečkami',
    '😼' => 'mačka s úškľabkom',
    '😽' => 'bozkávajúca mačka',
    '🙀' => 'vyčerpaná mačka',
    '😿' => 'plačúca mačka',
    '😾' => 'podráždená mačka',
    '🙈' => 'nevidím zlo',
    '🙉' => 'nepočujem zlo',
    '🙊' => 'nehovorím zlo',
    '💌' => 'ľúbostný list',
    '💘' => 'srdce so šípom',
    '💝' => 'srdce so stuhou',
    '💖' => 'ligotavé srdce',
    '💗' => 'rastúce srdce',
    '💓' => 'tlčúce srdce',
    '💞' => 'krúžiace srdcia',
    '💕' => 'dve srdcia',
    '💟' => 'ozdoba v tvare srdca',
    '❣' => 'výkričník v tvare srdca',
    '💔' => 'zlomené srdce',
    '❤' => 'červené srdce',
    '🩷' => 'ružové srdce',
    '🧡' => 'oranžové srdce',
    '💛' => 'žlté srdce',
    '💚' => 'zelené srdce',
    '💙' => 'modré srdce',
    '🩵' => 'svetlomodré srdce',
    '💜' => 'fialové srdce',
    '🤎' => 'hnedé srdce',
    '🖤' => 'čierne srdce',
    '🩶' => 'sivé srdce',
    '🤍' => 'biele srdce',
    '💋' => 'odtlačok pier',
    '💯' => 'sto bodov',
    '💢' => 'symbol hnevu',
    '🫯' => 'oblak bitky',
    '💥' => 'zrážka',
    '💫' => 'mám závrat',
    '💦' => 'kvapky potu',
    '💨' => 'utekám',
    '🕳' => 'jama',
    '💬' => 'reč',
    '🗨' => 'ľavá bublina',
    '🗯' => 'hnev',
    '💭' => 'myšlienka',
    '💤' => 'chŕ',
    '👋' => 'mávajúca ruka',
    '🤚' => 'zdvihnutá ruka spakruky',
    '🖐' => 'roztiahnutá ruka',
    '✋' => 'zdvihnutá ruka',
    '🖖' => 'vulkánsky pozdrav',
    '🫱' => 'ruka doprava',
    '🫲' => 'ruka doľava',
    '🫳' => 'ruka dlaňou nadol',
    '🫴' => 'ruka dlaňou nahor',
    '🫷' => 'ruka tlačiaca vľavo',
    '🫸' => 'ruka tlačiaca vpravo',
    '👌' => 'výborne',
    '🤌' => 'štipka',
    '🤏' => 'málo',
    '✌' => 'víťazstvo',
    '🤞' => 'držím palce',
    '🫰' => 'ruka s prekríženým ukazovákom a palcom',
    '🤟' => 'ľúbim ťa',
    '🤘' => 'paroháč',
    '🤙' => 'zavoláme si',
    '👈' => 'ukazovák doľava',
    '👉' => 'ukazovák doprava',
    '👆' => 'ukazovák spakruky nahor',
    '🖕' => 'prostredník',
    '👇' => 'ukazovák spakruky nadol',
    '☝' => 'ukazovák nahor',
    '🫵' => 'ukazovanie ukazovákom',
    '👍' => 'palec nahor',
    '👎' => 'palec nadol',
    '✊' => 'zdvihnutá päsť',
    '👊' => 'päsť spredu',
    '🤛' => 'päsť doľava',
    '🤜' => 'päsť doprava',
    '👏' => 'tlieskajúce ruky',
    '🙌' => 'zdvihnuté ruky',
    '🫶' => 'srdce z dlaní',
    '👐' => 'roztvorené dlane',
    '🤲' => 'zdvihnuté dlane',
    '🤝' => 'potrasenie rukami',
    '🙏' => 'zopäté ruky',
    '✍' => 'píšuca ruka',
    '💅' => 'lakovanie nechtov',
    '🤳' => 'selfie',
    '💪' => 'napnutý biceps',
    '🦾' => 'mechanická paža',
    '🦿' => 'mechanická noha',
    '🦵' => 'noha',
    '🦶' => 'chodidlo',
    '👂' => 'ucho',
    '🦻' => 'ucho s načúvadlom',
    '👃' => 'nos',
    '🧠' => 'mozog',
    '🫀' => 'orgán srdca',
    '🫁' => 'pľúca',
    '🦷' => 'zub',
    '🦴' => 'kosť',
    '👀' => 'oči',
    '👁' => 'oko',
    '👅' => 'jazyk',
    '👄' => 'ústa',
    '🫦' => 'zahryznutie do pery',
    '👶' => 'bábätko',
    '🧒' => 'dieťa',
    '👦' => 'chlapec',
    '👧' => 'dievča',
    '🧑' => 'dospelý',
    '👱' => 'svetlovlasý človek',
    '👨' => 'muž',
    '🧔' => 'bradáč',
    '👩' => 'žena',
    '🧓' => 'starší človek',
    '👴' => 'starší muž',
    '👵' => 'staršia žena',
    '🙍' => 'zamračený človek',
    '🙎' => 'podráždený človek',
    '🙅' => 'človek s prekríženými rukami',
    '🙆' => 'človek s rukami nad hlavou',
    '💁' => 'človek s nastavenou dlaňou',
    '🙋' => 'človek so zdvihnutou rukou',
    '🧏' => 'nepočujúci človek',
    '🙇' => 'klaňajúci sa človek',
    '🤦' => 'človek chytajúci sa za hlavu',
    '🤷' => 'človek krčiaci plecami',
    '👮' => 'policajt',
    '🕵' => 'detektív',
    '💂' => 'stráž',
    '🥷' => 'nindža',
    '👷' => 'pracovník na stavbe',
    '🫅' => 'osoba s korunou',
    '🤴' => 'princ',
    '👸' => 'princezná',
    '👳' => 'človek s turbanom',
    '👲' => 'muž s čínskou čapicou',
    '🧕' => 'žena so šatkou',
    '🤵' => 'človek v smokingu',
    '👰' => 'človek so závojom',
    '🤰' => 'tehotná žena',
    '🫃' => 'tehotný muž',
    '🫄' => 'tehotná osoba',
    '🤱' => 'dojčenie',
    '👼' => 'anjelik',
    '🎅' => 'Santa',
    '🤶' => 'pani Santová',
    '🦸' => 'superhrdina',
    '🦹' => 'superdarebácka bytosť',
    '🧙' => 'čarodejná bytosť',
    '🧚' => 'rozprávková bytosť',
    '🧛' => 'upírska bytosť',
    '🧜' => 'morská bytosť',
    '🧝' => 'lesná bytosť',
    '🧞' => 'džin',
    '🧟' => 'zombia',
    '🧌' => 'obor',
    '🫈' => 'chlpaté stvorenie',
    '💆' => 'masáž tváre',
    '💇' => 'strihanie vlasov',
    '🚶' => 'chodiaci človek',
    '🧍' => 'stojaci človek',
    '🧎' => 'kľačiaci človek',
    '🏃' => 'bežiaci človek',
    '💃' => 'tanečníčka',
    '🕺' => 'tanečník',
    '🕴' => 'levitujúci muž v saku',
    '👯' => 'ľudia so zajačími ušami',
    '🧖' => 'človek v pare',
    '🧗' => 'človek na skale',
    '🤺' => 'šermiar',
    '🏇' => 'dostihy',
    '⛷' => 'lyžiar',
    '🏂' => 'snoubordista',
    '🏌' => 'hráč golfu',
    '🏄' => 'človek na surfe',
    '🚣' => 'človek na veslici',
    '🏊' => 'plávajúci človek',
    '⛹' => 'človek s loptou',
    '🏋' => 'vzpierajúci človek',
    '🚴' => 'človek na bicykli',
    '🚵' => 'človek na horskom bicykli',
    '🤸' => 'človek robí hviezdu',
    '🤼' => 'zápasiaci ľudia',
    '🤽' => 'vodné pólo',
    '🤾' => 'hádzaná',
    '🤹' => 'žonglovanie',
    '🧘' => 'človek v lotosovom sede',
    '🛀' => 'človek vo vani',
    '🛌' => 'človek v posteli',
    '👭' => 'ženy držiace sa za ruky',
    '👫' => 'žena a muž držiaci sa za ruky',
    '👬' => 'muži držiaci sa za ruky',
    '💏' => 'bozk',
    '💑' => 'pár so srdcom',
    '🗣' => 'hovoriaca hlava',
    '👤' => 'silueta busty',
    '👥' => 'silueta búst',
    '🫂' => 'objímajúci sa ľudia',
    '👪' => 'rodina',
    '👣' => 'stopy',
    '🫆' => 'odtlačok prsta',
    '🦰' => 'ryšavé vlasy',
    '🦱' => 'kučeravé vlasy',
    '🦳' => 'sivé vlasy',
    '🦲' => 'holá hlava',
    '🐵' => 'hlava opice',
    '🐒' => 'opica',
    '🦍' => 'gorila',
    '🦧' => 'orangutan',
    '🐶' => 'hlava psa',
    '🐕' => 'pes',
    '🦮' => 'vodiaci pes',
    '🐩' => 'pudel',
    '🐺' => 'vlk',
    '🦊' => 'líška',
    '🦝' => 'medviedik čistotný',
    '🐱' => 'hlava mačky',
    '🐈' => 'mačka',
    '🦁' => 'lev',
    '🐯' => 'hlava tigra',
    '🐅' => 'tiger',
    '🐆' => 'leopard',
    '🐴' => 'hlava koňa',
    '🫎' => 'los',
    '🫏' => 'somár',
    '🐎' => 'kôň',
    '🦄' => 'jednorožec',
    '🦓' => 'zebra',
    '🦌' => 'jeleň',
    '🦬' => 'zubor',
    '🐮' => 'hlava kravy',
    '🐂' => 'býk',
    '🐃' => 'byvol',
    '🐄' => 'krava',
    '🐷' => 'hlava prasaťa',
    '🐖' => 'prasa',
    '🐗' => 'diviak',
    '🐽' => 'prasací rypák',
    '🐏' => 'baran',
    '🐑' => 'ovca',
    '🐐' => 'koza',
    '🐪' => 'dromedár',
    '🐫' => 'ťava',
    '🦙' => 'lama',
    '🦒' => 'žirafa',
    '🐘' => 'slon',
    '🦣' => 'mamut',
    '🦏' => 'nosorožec',
    '🦛' => 'hroch',
    '🐭' => 'hlava myši',
    '🐁' => 'myš',
    '🐀' => 'potkan',
    '🐹' => 'škrečok',
    '🐰' => 'hlava zajaca',
    '🐇' => 'zajac',
    '🐿' => 'veverica',
    '🦫' => 'bobor',
    '🦔' => 'jež',
    '🦇' => 'netopier',
    '🐻' => 'medveď',
    '🐨' => 'koala',
    '🐼' => 'panda',
    '🦥' => 'leňoch',
    '🦦' => 'vydra',
    '🦨' => 'skunk',
    '🦘' => 'kengura',
    '🦡' => 'jazvec',
    '🐾' => 'labky',
    '🦃' => 'moriak',
    '🐔' => 'sliepka',
    '🐓' => 'kohút',
    '🐣' => 'liahnuce sa kurča',
    '🐤' => 'kurča',
    '🐥' => 'kurča spredu',
    '🐦' => 'vták',
    '🐧' => 'tučniak',
    '🕊' => 'holubica',
    '🦅' => 'orol',
    '🦆' => 'kačka',
    '🦢' => 'labuť',
    '🦉' => 'sova',
    '🦤' => 'dront',
    '🪶' => 'pierko',
    '🦩' => 'plameniak',
    '🦚' => 'páv',
    '🦜' => 'papagáj',
    '🪽' => 'krídlo',
    '🪿' => 'hus',
    '🐸' => 'žaba',
    '🐊' => 'krokodíl',
    '🐢' => 'korytnačka',
    '🦎' => 'jašterica',
    '🐍' => 'had',
    '🐲' => 'hlava draka',
    '🐉' => 'drak',
    '🦕' => 'sauropód',
    '🦖' => 'tyrannosaurus',
    '🐳' => 'veľryba s gejzírom',
    '🐋' => 'veľryba',
    '🐬' => 'delfín',
    '🫍' => 'kosatka',
    '🦭' => 'uškatec',
    '🐟' => 'ryba',
    '🐠' => 'tropická ryba',
    '🐡' => 'štvorzubec',
    '🦈' => 'žralok',
    '🐙' => 'chobotnica',
    '🐚' => 'špirálovitá mušľa',
    '🪸' => 'koral',
    '🪼' => 'medúza',
    '🦀' => 'krab',
    '🦞' => 'homár',
    '🦐' => 'kreveta',
    '🦑' => 'kalmár',
    '🦪' => 'ustrica',
    '🐌' => 'slimák',
    '🦋' => 'motýľ',
    '🐛' => 'húsenica',
    '🐜' => 'mravec',
    '🐝' => 'včela',
    '🪲' => 'chrobák',
    '🐞' => 'lienka',
    '🦗' => 'svrček',
    '🪳' => 'šváb',
    '🕷' => 'pavúk',
    '🕸' => 'pavučina',
    '🦂' => 'škorpión',
    '🦟' => 'komár',
    '🪰' => 'mucha',
    '🪱' => 'dážďovka',
    '🦠' => 'mikrób',
    '💐' => 'kytica',
    '🌸' => 'čerešňový kvet',
    '💮' => 'biely kvet',
    '🪷' => 'lotos',
    '🏵' => 'ružička',
    '🌹' => 'ruža',
    '🥀' => 'zvädnutá kvetina',
    '🌺' => 'ibištek',
    '🌻' => 'slnečnica',
    '🌼' => 'kvet',
    '🌷' => 'tulipán',
    '🪻' => 'hyacint',
    '🌱' => 'sadenica',
    '🪴' => 'kvetináč',
    '🌲' => 'ihličnatý strom',
    '🌳' => 'listnatý strom',
    '🌴' => 'palma',
    '🌵' => 'kaktus',
    '🌾' => 'snop ryže',
    '🌿' => 'bylina',
    '☘' => 'trojlístok',
    '🍀' => 'štvorlístok',
    '🍁' => 'javorový list',
    '🍂' => 'opadnutý list',
    '🍃' => 'list vo vetre',
    '🪹' => 'prázdne hniezdo',
    '🪺' => 'hniezdo s vajcami',
    '🍄' => 'huba',
    '🪾' => 'strom bez listov',
    '🍇' => 'hrozno',
    '🍈' => 'cukrový melón',
    '🍉' => 'melón',
    '🍊' => 'mandarínka',
    '🍋' => 'citrón',
    '🍌' => 'banán',
    '🍍' => 'ananás',
    '🥭' => 'mango',
    '🍎' => 'červené jablko',
    '🍏' => 'zelené jablko',
    '🍐' => 'hruška',
    '🍑' => 'broskyňa',
    '🍒' => 'čerešne',
    '🍓' => 'jahoda',
    '🫐' => 'čučoriedky',
    '🥝' => 'kivi',
    '🍅' => 'paradajka',
    '🫒' => 'oliva',
    '🥥' => 'kokos',
    '🥑' => 'avokádo',
    '🍆' => 'baklažán',
    '🥔' => 'zemiak',
    '🥕' => 'mrkva',
    '🌽' => 'kukuričný klas',
    '🌶' => 'čili paprička',
    '🫑' => 'kapia',
    '🥒' => 'uhorka',
    '🥬' => 'listová zelenina',
    '🥦' => 'brokolica',
    '🧄' => 'cesnak',
    '🧅' => 'cibuľa',
    '🥜' => 'arašidy',
    '🫘' => 'fazuľa',
    '🌰' => 'gaštan',
    '🫚' => 'koreň ďumbiera',
    '🫛' => 'hrachový struk',
    '🫜' => 'koreňová zelenina',
    '🍞' => 'chlieb',
    '🥐' => 'croissant',
    '🥖' => 'bageta',
    '🫓' => 'chlebová placka',
    '🥨' => 'praclík',
    '🥯' => 'bagel',
    '🥞' => 'lievance',
    '🧇' => 'vafľa',
    '🧀' => 'kus syra',
    '🍖' => 'mäso s kosťou',
    '🍗' => 'kuracie stehno',
    '🥩' => 'plátok mäsa',
    '🥓' => 'slanina',
    '🍔' => 'hamburger',
    '🍟' => 'hranolčeky',
    '🍕' => 'pizza',
    '🌭' => 'párok v rožku',
    '🥪' => 'sendvič',
    '🌮' => 'taco',
    '🌯' => 'burrito',
    '🫔' => 'tamal',
    '🥙' => 'gyros',
    '🧆' => 'falafel',
    '🥚' => 'vajce',
    '🍳' => 'varenie',
    '🥘' => 'panvica s jedlom',
    '🍲' => 'kotlík s jedlom',
    '🫕' => 'fondue',
    '🥣' => 'misa s lyžicou',
    '🥗' => 'šalát',
    '🍿' => 'pukance',
    '🧈' => 'maslo',
    '🧂' => 'soľ',
    '🥫' => 'konzerva',
    '🍱' => 'krabička na jedlo',
    '🍘' => 'ryžová sušienka',
    '🍙' => 'kopček ryže',
    '🍚' => 'uvarená ryža',
    '🍛' => 'ryža s karí',
    '🍜' => 'miska s horúcim jedlom',
    '🍝' => 'špagety',
    '🍠' => 'pečený sladký zemiak',
    '🍢' => 'jedlo na špajdli',
    '🍣' => 'suši',
    '🍤' => 'pražená kreveta',
    '🍥' => 'rybia fašírka',
    '🥮' => 'mesačný koláč',
    '🍡' => 'dango',
    '🥟' => 'knedlička',
    '🥠' => 'sušienka s predpoveďou',
    '🥡' => 'rýchle občerstvenie',
    '🍦' => 'točená zmrzlina',
    '🍧' => 'mrazená dreň',
    '🍨' => 'zmrzlina',
    '🍩' => 'šiška',
    '🍪' => 'sušienka',
    '🎂' => 'narodeninová torta',
    '🍰' => 'kus torty',
    '🧁' => 'košíček',
    '🥧' => 'koláč',
    '🍫' => 'čokoláda',
    '🍬' => 'cukrík',
    '🍭' => 'lízanka',
    '🍮' => 'puding',
    '🍯' => 'pohár medu',
    '🍼' => 'detská fľaša',
    '🥛' => 'pohár mlieka',
    '☕' => 'horúci nápoj',
    '🫖' => 'čajová kanvica',
    '🍵' => 'čajová šálka',
    '🍶' => 'saké',
    '🍾' => 'šampanské',
    '🍷' => 'vínový pohár',
    '🍸' => 'kokteilový pohár',
    '🍹' => 'tropický nápoj',
    '🍺' => 'pivový pohár',
    '🍻' => 'štrngajúce pivové poháre',
    '🥂' => 'štrngajúce poháriky',
    '🥃' => 'pohár na whisky',
    '🫗' => 'liatie',
    '🥤' => 'pohár so slamkou',
    '🧋' => 'perlivý čaj',
    '🧃' => 'nápoj v krabičke',
    '🧉' => 'maté',
    '🧊' => 'kocka ľadu',
    '🥢' => 'paličky',
    '🍽' => 'vidlička, nôž a tanier',
    '🍴' => 'vidlička a nôž',
    '🥄' => 'lyžica',
    '🔪' => 'kuchynský nôž',
    '🫙' => 'pohár',
    '🏺' => 'amfora',
    '🌍' => 'zemeguľa s Európou a Afrikou',
    '🌎' => 'zemeguľa s Amerikou',
    '🌏' => 'zemeguľa s Áziou a Austráliou',
    '🌐' => 'zemeguľa s poludníkmi',
    '🗺' => 'mapa sveta',
    '🗾' => 'mapa Japonska',
    '🧭' => 'kompas',
    '🏔' => 'zasnežený vrch',
    '⛰' => 'vrch',
    '🛘' => 'zosuv pôdy',
    '🌋' => 'sopka',
    '🗻' => 'Fudžisan',
    '🏕' => 'stanovanie',
    '🏖' => 'pláž so slnečníkom',
    '🏜' => 'púšť',
    '🏝' => 'opustený ostrov',
    '🏞' => 'národný park',
    '🏟' => 'štadión',
    '🏛' => 'historická budova',
    '🏗' => 'stavba',
    '🧱' => 'tehla',
    '🪨' => 'kameň',
    '🪵' => 'drevo',
    '🛖' => 'chatrč',
    '🏘' => 'domy',
    '🏚' => 'opustený dom',
    '🏠' => 'dom',
    '🏡' => 'dom so záhradou',
    '🏢' => 'kancelárska budova',
    '🏣' => 'japonská pošta',
    '🏤' => 'európska pošta',
    '🏥' => 'nemocnica',
    '🏦' => 'banka',
    '🏨' => 'hotel',
    '🏩' => 'hodinový hotel',
    '🏪' => 'zmiešaný tovar',
    '🏫' => 'škola',
    '🏬' => 'obchodný dom',
    '🏭' => 'továreň',
    '🏯' => 'japonský zámok',
    '🏰' => 'zámok',
    '💒' => 'svadba',
    '🗼' => 'tokijská veža',
    '🗽' => 'socha slobody',
    '⛪' => 'kostol',
    '🕌' => 'mešita',
    '🛕' => 'hinduistický chrám',
    '🕍' => 'synagóga',
    '⛩' => 'šintoistická svätyňa',
    '🕋' => 'kába',
    '⛲' => 'fontána',
    '⛺' => 'stan',
    '🌁' => 'hmlisto',
    '🌃' => 'noc s hviezdami',
    '🏙' => 'mestská panoráma',
    '🌄' => 'východ slnka nad horami',
    '🌅' => 'východ slnka',
    '🌆' => 'mestská panoráma pri súmraku',
    '🌇' => 'západ slnka',
    '🌉' => 'most v noci',
    '♨' => 'horúce pramene',
    '🎠' => 'kolotočový kôň',
    '🛝' => 'šmykľavka',
    '🎡' => 'ruské koleso',
    '🎢' => 'horská dráha',
    '💈' => 'pútač holičstva',
    '🎪' => 'šapito',
    '🚂' => 'rušeň',
    '🚃' => 'vozeň',
    '🚄' => 'rýchlovlak',
    '🚅' => 'japonský rýchlovlak',
    '🚆' => 'vlak',
    '🚇' => 'metro',
    '🚈' => 'ľahké metro',
    '🚉' => 'stanica',
    '🚊' => 'električka',
    '🚝' => 'monorail',
    '🚞' => 'zubačka',
    '🚋' => 'vozeň električky',
    '🚌' => 'autobus',
    '🚍' => 'prichádzajúci autobus',
    '🚎' => 'trolejbus',
    '🚐' => 'minibus',
    '🚑' => 'sanitka',
    '🚒' => 'hasičské auto',
    '🚓' => 'policajné auto',
    '🚔' => 'prichádzajúce policajné auto',
    '🚕' => 'taxík',
    '🚖' => 'prichádzajúci taxík',
    '🚗' => 'auto',
    '🚘' => 'prichádzajúce auto',
    '🚙' => 'SUV',
    '🛻' => 'pikap',
    '🚚' => 'zásobovacie auto',
    '🚛' => 'ťahač s návesom',
    '🚜' => 'traktor',
    '🏎' => 'pretekárske auto',
    '🏍' => 'motocykel',
    '🛵' => 'skúter',
    '🦽' => 'mechanický invalidný vozík',
    '🦼' => 'elektrický invalidný vozík',
    '🛺' => 'autorikša',
    '🚲' => 'bicykel',
    '🛴' => 'kolobežka',
    '🛹' => 'skejtbord',
    '🛼' => 'koliesková korčuľa',
    '🚏' => 'autobusová zastávka',
    '🛣' => 'diaľnica',
    '🛤' => 'železničná trať',
    '🛢' => 'barel',
    '⛽' => 'čerpacia stanica',
    '🛞' => 'koleso',
    '🚨' => 'policajný maják',
    '🚥' => 'vodorovný semafor',
    '🚦' => 'zvislý semafor',
    '🛑' => 'značka stop',
    '🚧' => 'práce na ceste',
    '⚓' => 'kotva',
    '🛟' => 'záchranné koleso',
    '⛵' => 'plachetnica',
    '🛶' => 'kanoe',
    '🚤' => 'rýchly čln',
    '🛳' => 'zaoceánska loď',
    '⛴' => 'trajekt',
    '🛥' => 'motorový čln',
    '🚢' => 'loď',
    '✈' => 'lietadlo',
    '🛩' => 'malé lietadlo',
    '🛫' => 'odlet lietadla',
    '🛬' => 'prílet lietadla',
    '🪂' => 'padák',
    '💺' => 'sedadlo',
    '🚁' => 'helikoptéra',
    '🚟' => 'lanovka',
    '🚠' => 'horská lanovka',
    '🚡' => 'visutá lanovka',
    '🛰' => 'družica',
    '🚀' => 'raketa',
    '🛸' => 'lietajúci tanier',
    '🛎' => 'recepčný zvonček',
    '🧳' => 'batožina',
    '⌛' => 'presýpacie hodiny',
    '⏳' => 'bežiace presýpacie hodiny',
    '⌚' => 'hodinky',
    '⏰' => 'budík',
    '⏱' => 'stopky',
    '⏲' => 'časovač',
    '🕰' => 'kozubové hodiny',
    '🕛' => 'dvanásť hodín',
    '🕧' => 'pol jednej',
    '🕐' => 'jedna hodina',
    '🕜' => 'pol druhej',
    '🕑' => 'dve hodiny',
    '🕝' => 'pol tretej',
    '🕒' => 'tri hodiny',
    '🕞' => 'pol štvrtej',
    '🕓' => 'štyri hodiny',
    '🕟' => 'pol piatej',
    '🕔' => 'päť hodín',
    '🕠' => 'pol šiestej',
    '🕕' => 'šesť hodín',
    '🕡' => 'pol siedmej',
    '🕖' => 'sedem hodín',
    '🕢' => 'pol ôsmej',
    '🕗' => 'osem hodín',
    '🕣' => 'pol deviatej',
    '🕘' => 'deväť hodín',
    '🕤' => 'pol desiatej',
    '🕙' => 'desať hodín',
    '🕥' => 'pol jedenástej',
    '🕚' => 'jedenásť hodín',
    '🕦' => 'pol dvanástej',
    '🌑' => 'nov',
    '🌒' => 'dorastajúci polmesiac',
    '🌓' => 'prvá štvrť mesiaca',
    '🌔' => 'dorastajúci mesiac',
    '🌕' => 'spln',
    '🌖' => 'ubúdajúci mesiac',
    '🌗' => 'posledná štvrť mesiaca',
    '🌘' => 'ubúdajúci polmesiac',
    '🌙' => 'polmesiac',
    '🌚' => 'nov s tvárou',
    '🌛' => 'mesiac v prvej štvrti s tvárou',
    '🌜' => 'mesiac v poslednej štvrti s tvárou',
    '🌡' => 'teplomer',
    '☀' => 'slnko',
    '🌝' => 'spln s tvárou',
    '🌞' => 'slnko s tvárou',
    '🪐' => 'planéta s prstencom',
    '⭐' => 'hviezda',
    '🌟' => 'žiariaca hviezda',
    '🌠' => 'padajúca hviezda',
    '🌌' => 'mliečna dráha',
    '☁' => 'oblak',
    '⛅' => 'slnko za oblakom',
    '⛈' => 'oblak s bleskom a dažďom',
    '🌤' => 'slnko za malým oblakom',
    '🌥' => 'slnko za veľkým oblakom',
    '🌦' => 'slnko za dažďovým oblakom',
    '🌧' => 'dažďový oblak',
    '🌨' => 'snehový oblak',
    '🌩' => 'oblak s bleskom',
    '🌪' => 'tornádo',
    '🌫' => 'hmla',
    '🌬' => 'vietor',
    '🌀' => 'cyklón',
    '🌈' => 'dúha',
    '🌂' => 'zatvorený dáždnik',
    '☂' => 'dáždnik',
    '☔' => 'dáždnik s kvapkami',
    '⛱' => 'slnečník',
    '⚡' => 'vysoké napätie',
    '❄' => 'snehová vločka',
    '☃' => 'snehuliak',
    '⛄' => 'snehuliak bez snehu',
    '☄' => 'kométa',
    '🔥' => 'oheň',
    '💧' => 'kvapka',
    '🌊' => 'morská vlna',
    '🎃' => 'halloweenská tekvica',
    '🎄' => 'vianočný stromček',
    '🎆' => 'ohňostroj',
    '🎇' => 'prskavka',
    '🧨' => 'petarda',
    '✨' => 'iskry',
    '🎈' => 'balónik',
    '🎉' => 'konfety',
    '🎊' => 'konfetová guľa',
    '🎋' => 'stromček tanabata',
    '🎍' => 'borovicová dekorácia',
    '🎎' => 'japonské bábiky',
    '🎏' => 'koinobori',
    '🎐' => 'veterná zvonkohra',
    '🎑' => 'slávnosti mesiaca',
    '🧧' => 'červená obálka',
    '🎀' => 'stuha',
    '🎁' => 'zabalený darček',
    '🎗' => 'stužka',
    '🎟' => 'vstupenky',
    '🎫' => 'lístok',
    '🎖' => 'vojenská medaila',
    '🏆' => 'trofej',
    '🏅' => 'športová medaila',
    '🥇' => 'zlatá medaila',
    '🥈' => 'strieborná medaila',
    '🥉' => 'bronzová medaila',
    '⚽' => 'futbal',
    '⚾' => 'bejzbal',
    '🥎' => 'softbal',
    '🏀' => 'basketbal',
    '🏐' => 'volejbal',
    '🏈' => 'americký futbal',
    '🏉' => 'ragby',
    '🎾' => 'tenis',
    '🥏' => 'lietajúci disk',
    '🎳' => 'bowling',
    '🏏' => 'kriket',
    '🏑' => 'pozemný hokej',
    '🏒' => 'ľadový hokej',
    '🥍' => 'lakros',
    '🏓' => 'stolný tenis',
    '🏸' => 'bedminton',
    '🥊' => 'boxovacia rukavica',
    '🥋' => 'úbor na bojové umenie',
    '🥅' => 'bránka',
    '⛳' => 'zástava v jamke',
    '⛸' => 'korčuľa',
    '🎣' => 'udica',
    '🤿' => 'potápačská maska',
    '🎽' => 'bežecké tričko',
    '🎿' => 'lyže',
    '🛷' => 'sane',
    '🥌' => 'curlingový kameň',
    '🎯' => 'presný zásah',
    '🪀' => 'jojo',
    '🪁' => 'papierový šarkan',
    '🔫' => 'vodná pištoľ',
    '🎱' => 'biliardová guľa č. 8',
    '🔮' => 'krištáľová guľa',
    '🪄' => 'kúzelná palička',
    '🎮' => 'videohra',
    '🕹' => 'joystick',
    '🎰' => 'výherný automat',
    '🎲' => 'hracia kocka',
    '🧩' => 'skladačka',
    '🧸' => 'medvedík',
    '🪅' => 'piñata',
    '🪩' => 'zrkadlová guľa',
    '🪆' => 'matriošky',
    '♠' => 'pika',
    '♥' => 'srdce',
    '♦' => 'káro',
    '♣' => 'kríž',
    '♟' => 'pešiak',
    '🃏' => 'žolík',
    '🀄' => 'madžongový červený drak',
    '🎴' => 'japonské karty',
    '🎭' => 'divadlo',
    '🖼' => 'zarámovaný obraz',
    '🎨' => 'maliarska paleta',
    '🧵' => 'cievka nite',
    '🪡' => 'ihla',
    '🧶' => 'klbko',
    '🪢' => 'uzol',
    '👓' => 'okuliare',
    '🕶' => 'slnečné okuliare',
    '🥽' => 'ochranné okuliare',
    '🥼' => 'laboratórny plášť',
    '🦺' => 'bezpečnostná vesta',
    '👔' => 'kravata',
    '👕' => 'tričko',
    '👖' => 'rifle',
    '🧣' => 'šál',
    '🧤' => 'rukavice',
    '🧥' => 'kabát',
    '🧦' => 'ponožky',
    '👗' => 'šaty',
    '👘' => 'kimono',
    '🥻' => 'sárí',
    '🩱' => 'jednodielne plavky',
    '🩲' => 'slipy',
    '🩳' => 'šortky',
    '👙' => 'bikini',
    '👚' => 'dámske oblečenie',
    '🪭' => 'skladací vejár',
    '👛' => 'peňaženka',
    '👜' => 'kabelka',
    '👝' => 'malá kabelka',
    '🛍' => 'nákupné tašky',
    '🎒' => 'školský batoh',
    '🩴' => 'žabky',
    '👞' => 'pánska topánka',
    '👟' => 'bežecká topánka',
    '🥾' => 'pohorka',
    '🥿' => 'balerína',
    '👠' => 'topánka na podpätku',
    '👡' => 'dámsky sandál',
    '🩰' => 'baletné špice',
    '👢' => 'dámska čižma',
    '🪮' => 'hrebeň na kučeravé vlasy',
    '👑' => 'koruna',
    '👒' => 'dámsky klobúk',
    '🎩' => 'cylinder',
    '🎓' => 'promočná čiapka',
    '🧢' => 'šiltovka',
    '🪖' => 'vojenská helma',
    '⛑' => 'záchranárska helma',
    '📿' => 'modlitebné koráliky',
    '💄' => 'rúž',
    '💍' => 'prsteň',
    '💎' => 'drahokam',
    '🔇' => 'vypnutý reproduktor',
    '🔈' => 'nízka hlasitosť',
    '🔉' => 'stredná hlasitosť',
    '🔊' => 'vysoká hlasitosť',
    '📢' => 'amplión',
    '📣' => 'megafón',
    '📯' => 'poštová trúba',
    '🔔' => 'zvon',
    '🔕' => 'prečiarknutý zvon',
    '🎼' => 'notová osnova',
    '🎵' => 'nota',
    '🎶' => 'noty',
    '🎙' => 'štúdiový mikrofón',
    '🎚' => 'posúvač',
    '🎛' => 'gombíky',
    '🎤' => 'mikrofón',
    '🎧' => 'slúchadlá',
    '📻' => 'rádio',
    '🎷' => 'saxofón',
    '🎺' => 'trúbka',
    '🪊' => 'trombón',
    '🪗' => 'akordeón',
    '🎸' => 'gitara',
    '🎹' => 'klávesy',
    '🎻' => 'husle',
    '🪕' => 'bendžo',
    '🥁' => 'bubon',
    '🪘' => 'kongo',
    '🪇' => 'rumbagule',
    '🪈' => 'píšťalka',
    '🪉' => 'harfa',
    '📱' => 'mobil',
    '📲' => 'mobil so šípkou',
    '☎' => 'telefón',
    '📞' => 'slúchadlo telefónu',
    '📟' => 'pejdžer',
    '📠' => 'fax',
    '🔋' => 'batéria',
    '🪫' => 'slabá batéria',
    '🔌' => 'zástrčka',
    '💻' => 'prenosný počítač',
    '🖥' => 'stolný počítač',
    '🖨' => 'tlačiareň',
    '⌨' => 'klávesnica',
    '🖱' => 'počítačová myš',
    '🖲' => 'trackball',
    '💽' => 'počítačový disk',
    '💾' => 'disketa',
    '💿' => 'optický disk',
    '📀' => 'dvd',
    '🧮' => 'počítadlo',
    '🎥' => 'filmová kamera',
    '🎞' => 'filmový pás',
    '📽' => 'filmový projektor',
    '🎬' => 'klapka',
    '📺' => 'televízor',
    '📷' => 'fotoaparát',
    '📸' => 'fotoaparát s bleskom',
    '📹' => 'videokamera',
    '📼' => 'videokazeta',
    '🔍' => 'doľava naklonená lupa',
    '🔎' => 'doprava naklonená lupa',
    '🕯' => 'sviečka',
    '💡' => 'žiarovka',
    '🔦' => 'baterka',
    '🏮' => 'červený lampión',
    '🪔' => 'dija',
    '📔' => 'zápisník so zdobeným obalom',
    '📕' => 'zatvorená kniha',
    '📖' => 'otvorená kniha',
    '📗' => 'zelená kniha',
    '📘' => 'modrá kniha',
    '📙' => 'oranžová kniha',
    '📚' => 'knihy',
    '📓' => 'zápisník',
    '📒' => 'účtovná kniha',
    '📃' => 'ohnutá stránka',
    '📜' => 'zvitok',
    '📄' => 'líce stránky',
    '📰' => 'noviny',
    '🗞' => 'zvinuté noviny',
    '📑' => 'záložky',
    '🔖' => 'záložka',
    '🏷' => 'štítok',
    '🪙' => 'minca',
    '💰' => 'mešec peňazí',
    '🪎' => 'truhlica s pokladom',
    '💴' => 'jenová bankovka',
    '💵' => 'dolárová bankovka',
    '💶' => 'eurová bankovka',
    '💷' => 'librová bankovka',
    '💸' => 'peniaze s krídlami',
    '💳' => 'platobná karta',
    '🧾' => 'účtenka',
    '💹' => 'stúpajúci graf jenu',
    '✉' => 'obálka',
    '📧' => 'e-mail',
    '📨' => 'obálka s prichádzajúcou poštou',
    '📩' => 'obálka so šípkou',
    '📤' => 'priečinok na odchádzajúcu poštu',
    '📥' => 'priečinok na prichádzajúcu poštu',
    '📦' => 'zásielka',
    '📫' => 'zatvorená schránka so zdvihnutou zástavkou',
    '📪' => 'zatvorená schránka so spustenou zástavkou',
    '📬' => 'otvorená schránka so zdvihnutou zástavkou',
    '📭' => 'otvorená schránka so spustenou zástavkou',
    '📮' => 'poštová schránka',
    '🗳' => 'volebná schránka s lístkom',
    '✏' => 'ceruzka',
    '✒' => 'čierne pero',
    '🖋' => 'plniace pero',
    '🖊' => 'pero',
    '🖌' => 'štetec',
    '🖍' => 'pastelka',
    '📝' => 'oznam',
    '💼' => 'aktovka',
    '📁' => 'fascikel',
    '📂' => 'otvorený fascikel',
    '🗂' => 'štítky na indexovanie',
    '📅' => 'kalendár',
    '📆' => 'trhací kalendár',
    '🗒' => 'špirálový zápisník',
    '🗓' => 'špirálový kalendár',
    '📇' => 'otáčací stojan na vizitky',
    '📈' => 'stúpajúci graf',
    '📉' => 'klesajúci graf',
    '📊' => 'pruhový graf',
    '📋' => 'písacia podložka',
    '📌' => 'špendlík',
    '📍' => 'guľatý špendlík',
    '📎' => 'sponka na papier',
    '🖇' => 'spojené sponky na papier',
    '📏' => 'rovné pravítko',
    '📐' => 'trojuholníkové pravítko',
    '✂' => 'nožnice',
    '🗃' => 'škatuľa s kartotékou',
    '🗄' => 'kartotéková skriňa',
    '🗑' => 'odpadkový kôš',
    '🔒' => 'zatvorená zámka',
    '🔓' => 'otvorená zámka',
    '🔏' => 'zámka s perom',
    '🔐' => 'zámka s kľúčom',
    '🔑' => 'kľúč',
    '🗝' => 'starý kľúč',
    '🔨' => 'kladivo',
    '🪓' => 'sekera',
    '⛏' => 'krompáč',
    '⚒' => 'kladivo a krompáč',
    '🛠' => 'kladivo a kľúč',
    '🗡' => 'dýka',
    '⚔' => 'prekrížené meče',
    '💣' => 'bomba',
    '🪃' => 'bumerang',
    '🏹' => 'luk a šíp',
    '🛡' => 'štít',
    '🪚' => 'tesárska píla',
    '🔧' => 'francúzsky kľúč',
    '🪛' => 'skrutkovač',
    '🔩' => 'matica a skrutka',
    '⚙' => 'ozubené koliesko',
    '🗜' => 'zverák',
    '⚖' => 'miskové váhy',
    '🦯' => 'slepecká palica',
    '🔗' => 'spojovací článok',
    '⛓' => 'reťaz',
    '🪝' => 'hák',
    '🧰' => 'kufrík na náradie',
    '🧲' => 'magnet',
    '🪜' => 'rebrík',
    '🪏' => 'lopata',
    '⚗' => 'krivuľa',
    '🧪' => 'skúmavka',
    '🧫' => 'Petriho miska',
    '🧬' => 'dna',
    '🔬' => 'mikroskop',
    '🔭' => 'ďalekohľad',
    '📡' => 'satelitná anténa',
    '💉' => 'injekcia',
    '🩸' => 'kvapka krvi',
    '💊' => 'tabletka',
    '🩹' => 'náplasť',
    '🩼' => 'barla',
    '🩺' => 'stetoskop',
    '🩻' => 'röntgen',
    '🚪' => 'dvere',
    '🛗' => 'výťah',
    '🪞' => 'zrkadlo',
    '🪟' => 'okno',
    '🛏' => 'posteľ',
    '🛋' => 'gauč a lampa',
    '🪑' => 'stolička',
    '🚽' => 'záchod',
    '🪠' => 'čistiaci zvon',
    '🚿' => 'sprcha',
    '🛁' => 'vaňa',
    '🪤' => 'pasca na myši',
    '🪒' => 'britva',
    '🧴' => 'fľaštička krému',
    '🧷' => 'spínací špendlík',
    '🧹' => 'metla',
    '🧺' => 'kôš',
    '🧻' => 'rolka papiera',
    '🪣' => 'vedro',
    '🧼' => 'mydlo',
    '🫧' => 'bubliny',
    '🪥' => 'zubná kefka',
    '🧽' => 'špongia',
    '🧯' => 'hasiaci prístroj',
    '🛒' => 'nákupný vozík',
    '🚬' => 'cigareta',
    '⚰' => 'rakva',
    '🪦' => 'náhrobok',
    '⚱' => 'pohrebná urna',
    '🧿' => 'nazar',
    '🪬' => 'hamsa',
    '🗿' => 'socha moai',
    '🪧' => 'transparent',
    '🪪' => 'preukaz',
    '🏧' => 'bankomat',
    '🚮' => 'symbol odpadkového koša',
    '🚰' => 'pitná voda',
    '♿' => 'invalidný vozík',
    '🚹' => 'pánske toalety',
    '🚺' => 'dámske toalety',
    '🚻' => 'toalety',
    '🚼' => 'prebaľovacia miestnosť',
    '🚾' => 'splachovací záchod',
    '🛂' => 'pasová kontrola',
    '🛃' => 'colná prehliadka',
    '🛄' => 'výdaj batožiny',
    '🛅' => 'úschovňa batožiny',
    '⚠' => 'varovanie',
    '🚸' => 'deti na ceste',
    '⛔' => 'zákaz vjazdu',
    '🚫' => 'zákaz',
    '🚳' => 'zákaz bicyklov',
    '🚭' => 'zákaz fajčenia',
    '🚯' => 'neodhadzujte odpadky',
    '🚱' => 'nepitná voda',
    '🚷' => 'zákaz chodcov',
    '📵' => 'zákaz mobilov',
    '🔞' => 'zákaz vstupu do osemnásť rokov',
    '☢' => 'rádioaktivita',
    '☣' => 'biologické riziko',
    '⬆' => 'šípka nahor',
    '↗' => 'šípka doprava nahor',
    '➡' => 'šípka doprava',
    '↘' => 'šípka doprava nadol',
    '⬇' => 'šípka nadol',
    '↙' => 'šípka doľava nadol',
    '⬅' => 'šípka doľava',
    '↖' => 'šípka doľava nahor',
    '↕' => 'šípka nahor aj nadol',
    '↔' => 'šípka doprava aj doľava',
    '↩' => 'šípka doprava zakrivená doľava',
    '↪' => 'šípka doľava zakrivená doprava',
    '⤴' => 'šípka doprava zakrivená nahor',
    '⤵' => 'šípka doprava zakrivená nadol',
    '🔃' => 'zvislé šípky v smere hodinových ručičiek',
    '🔄' => 'šípky proti smeru hodinových ručičiek',
    '🔙' => 'šípka BACK',
    '🔚' => 'šípka END',
    '🔛' => 'šípka ON!',
    '🔜' => 'šípka SOON',
    '🔝' => 'šípka TOP',
    '🛐' => 'modlitebné miesto',
    '⚛' => 'symbol atómu',
    '🕉' => 'óm',
    '✡' => 'Dávidova hviezda',
    '☸' => 'koleso dharmy',
    '☯' => 'jin a jang',
    '✝' => 'latinský kríž',
    '☦' => 'pravoslávny kríž',
    '☪' => 'hviezda a polmesiac',
    '☮' => 'symbol mieru',
    '🕎' => 'menóra',
    '🔯' => 'šesťcípa hviezda s bodkou uprostred',
    '🪯' => 'khanda',
    '♈' => 'znamenie barana',
    '♉' => 'znamenie býka',
    '♊' => 'znamenie blížencov',
    '♋' => 'znamenie raka',
    '♌' => 'znamenie leva',
    '♍' => 'znamenie panny',
    '♎' => 'znamenie váh',
    '♏' => 'znamenie škorpióna',
    '♐' => 'znamenie strelca',
    '♑' => 'znamenie kozorožca',
    '♒' => 'znamenie vodnára',
    '♓' => 'znamenie rýb',
    '⛎' => 'znamenie hadonosa',
    '🔀' => 'tlačidlo náhodného prehrávania',
    '🔁' => 'tlačidlo opakovania',
    '🔂' => 'tlačidlo opakovania skladby',
    '▶' => 'tlačidlo prehrávania',
    '⏩' => 'tlačidlo pretáčania dopredu',
    '⏭' => 'tlačidlo ďalšej skladby',
    '⏯' => 'tlačidlo prehrávania a pozastavenia',
    '◀' => 'tlačidlo spätného prehrávania',
    '⏪' => 'tlačidlo pretáčania späť',
    '⏮' => 'tlačidlo predošlej skladby',
    '🔼' => 'tlačidlo nahor',
    '⏫' => 'tlačidlo rýchlo nahor',
    '🔽' => 'tlačidlo nadol',
    '⏬' => 'tlačidlo rýchlo nadol',
    '⏸' => 'tlačidlo pozastavenia',
    '⏹' => 'tlačidlo zastavenia',
    '⏺' => 'tlačidlo nahrávania',
    '⏏' => 'tlačidlo vysunutia',
    '🎦' => 'kino',
    '🔅' => 'tlačidlo stlmenia jasu',
    '🔆' => 'tlačidlo jasu',
    '📶' => 'sila signálu',
    '🛜' => 'bezdrôtový',
    '📳' => 'vibračný režim',
    '📴' => 'vypnutý mobil',
    '♀' => 'ženský symbol',
    '♂' => 'mužský symbol',
    '⚧' => 'transgenderový symbol',
    '✖' => 'krát',
    '➕' => 'plus',
    '➖' => 'mínus',
    '➗' => 'deleno',
    '🟰' => 'rovné',
    '♾' => 'nekonečno',
    '‼' => 'dvojitý výkričník',
    '⁉' => 'výkričník s otáznikom',
    '❓' => 'červený otáznik',
    '❔' => 'biely otáznik',
    '❕' => 'biely výkričník',
    '❗' => 'červený výkričník',
    '〰' => 'vlnovková pomlčka',
    '💱' => 'zmenáreň',
    '💲' => 'znak dolára',
    '⚕' => 'lekársky symbol',
    '♻' => 'symbol recyklácie',
    '⚜' => 'heraldický symbol ľalie',
    '🔱' => 'emblém trojzubca',
    '📛' => 'menovka',
    '🔰' => 'japonský symbol pre začiatočníka',
    '⭕' => 'prázdny červený kruh',
    '✅' => 'začiarkavacie políčko',
    '☑' => 'začiarknuté políčko',
    '✔' => 'znak začiarknutia',
    '❌' => 'krížik',
    '❎' => 'tlačidlo s krížikom',
    '➰' => 'slučka',
    '➿' => 'dvojitá slučka',
    '〽' => 'znak začiatku partu',
    '✳' => 'osemcípa hviezdička',
    '✴' => 'osemcípa hviezda',
    '❇' => 'iskra',
    '™' => 'obchodná známka',
    '🫟' => 'machuľa',
    '🔠' => 'zadávanie veľkých písmen latinky',
    '🔡' => 'zadávanie malých písmen latinky',
    '🔢' => 'zadávanie čísel',
    '🔣' => 'zadávanie symbolov',
    '🔤' => 'zadávanie písmen latinky',
    '🅰' => 'štítok A',
    '🆎' => 'štítok AB',
    '🅱' => 'štítok B',
    '🆑' => 'štítok CL',
    '🆒' => 'štítok COOL',
    '🆓' => 'štítok FREE',
    'ℹ' => 'informačný zdroj',
    '🆔' => 'štítok ID',
    'Ⓜ' => 'M v kruhu',
    '🆕' => 'štítok NEW',
    '🆖' => 'štítok NG',
    '🅾' => 'štítok 0',
    '🆗' => 'štítok OK',
    '🅿' => 'štítok P',
    '🆘' => 'štítok SOS',
    '🆙' => 'štítok UP!',
    '🆚' => 'štítok VS',
    '🈁' => 'japonský ideograf Tu',
    '🈂' => 'japonský ideograf Poplatok za službu',
    '🈷' => 'japonský ideograf Mesačná suma',
    '🈶' => 'japonský ideograf Nie je zadarmo',
    '🈯' => 'japonský ideograf Vyhradené',
    '🉐' => 'japonský ideograf Výhodný nákup',
    '🈹' => 'japonský ideograf Zľava',
    '🈚' => 'japonský ideograf Zadarmo',
    '🈲' => 'japonský ideograf Zákaz',
    '🉑' => 'japonský ideograf Prijateľné',
    '🈸' => 'japonský ideograf Žiadosť',
    '🈴' => 'japonský ideograf Úspešne vykonaná skúška',
    '🈳' => 'japonský ideograf Voľné',
    '㊗' => 'japonský ideograf Blahoželám',
    '㊙' => 'japonský ideograf Tajomstvo',
    '🈺' => 'japonský ideograf Otvorené',
    '🈵' => 'japonský ideograf Žiadne voľné miesta',
    '🔴' => 'červený kruh',
    '🟠' => 'oranžový kruh',
    '🟡' => 'žltý kruh',
    '🟢' => 'zelený kruh',
    '🔵' => 'modrý kruh',
    '🟣' => 'fialový kruh',
    '🟤' => 'hnedý kruh',
    '⚫' => 'čierny kruh',
    '⚪' => 'biely kruh',
    '🟥' => 'červený štvorec',
    '🟧' => 'oranžový štvorec',
    '🟨' => 'žltý štvorec',
    '🟩' => 'zelený štvorec',
    '🟦' => 'modrý štvorec',
    '🟪' => 'fialový štvorec',
    '🟫' => 'hnedý štvorec',
    '⬛' => 'veľký čierny štvorec',
    '⬜' => 'veľký biely štvorec',
    '◼' => 'stredný čierny štvorec',
    '◻' => 'stredný biely štvorec',
    '◾' => 'stredne malý čierny štvorec',
    '◽' => 'stredne malý biely štvorec',
    '▪' => 'čierny štvorček',
    '▫' => 'biely štvorček',
    '🔶' => 'veľký oranžový kosoštvorec',
    '🔷' => 'veľký modrý kosoštvorec',
    '🔸' => 'malý oranžový kosoštvorec',
    '🔹' => 'malý modrý kosoštvorec',
    '🔺' => 'červený trojuholník nahor',
    '🔻' => 'červený trojuholník nadol',
    '💠' => 'kosoštvorec s bodkou',
    '🔘' => 'okrúhle tlačidlo',
    '🔳' => 'biele hranaté tlačidlo',
    '🔲' => 'čierne hranaté tlačidlo',
    '🏁' => 'kockovaná zástava',
    '🚩' => 'trojuholníková zástava',
    '🎌' => 'skrížené zástavy',
    '🏴' => 'čierna zástava',
    '🏳' => 'biela zástava',
];
