<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'Ifẹnuko: àgbà, àgbà, amọ́lára, amọ́lára díẹ̀',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'Ifẹnuko: àgbà, àgbà, amọ́lára, amọ́láwọ̀ díẹ̀',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'Ifẹnuko: àgbà, àgbà, amọ́lára, adúláwọ̀ díẹ̀',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'Ifẹnuko: àgbà, àgbà, amọ́lára, adúláwọ̀',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'Ifẹnuko: àgbà, àgbà, amọ́lára díẹ̀, amọ́lára',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'Ifẹnuko: àgbà, àgbà, amọ́lára díẹ̀, amọ́láwọ̀ díẹ̀',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'Ifẹnuko: àgbà, àgbà, amọ́lára díẹ̀, adúláwọ̀ díẹ̀',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'Ifẹnuko: àgbà, àgbà, amọ́lára díẹ̀, adúláwọ̀',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'Ifẹnuko: àgbà, àgbà, amọ́láwọ̀ díẹ̀, amọ́lára',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'Ifẹnuko: àgbà, àgbà, amọ́láwọ̀ díẹ̀, amọ́lára díẹ̀',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'Ifẹnuko: àgbà, àgbà, amọ́láwọ̀ díẹ̀, adúláwọ̀ díẹ̀',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'Ifẹnuko: àgbà, àgbà, amọ́láwọ̀ díẹ̀, adúláwọ̀',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'Ifẹnuko: àgbà, àgbà, adúláwọ̀ díẹ̀, amọ́lára',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'Ifẹnuko: àgbà, àgbà, adúláwọ̀ díẹ̀, amọ́lára díẹ̀',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'Ifẹnuko: àgbà, àgbà, adúláwọ̀ díẹ̀, amọ́láwọ̀ díẹ̀',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'Ifẹnuko: àgbà, àgbà, adúláwọ̀ díẹ̀, adúláwọ̀',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'Ifẹnuko: àgbà, àgbà, adúláwọ̀, amọ́lára',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'Ifẹnuko: àgbà, àgbà, adúláwọ̀, amọ́lára díẹ̀',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'Ifẹnuko: àgbà, àgbà, adúláwọ̀, amọ́láwọ̀ díẹ̀',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'Ifẹnuko: àgbà, àgbà, adúláwọ̀, adúláwọ̀ díẹ̀',
    '👨🏻‍❤‍💋‍👨🏻' => 'Ifẹnuko: Ọkùnrin, Ọkùnrin, amọ́lára',
    '👨🏻‍❤‍💋‍👨🏼' => 'Ifẹnuko: Ọkùnrin, Ọkùnrin, amọ́lára, amọ́lára díẹ̀',
    '👨🏻‍❤‍💋‍👨🏽' => 'Ifẹnuko: Ọkùnrin, Ọkùnrin, amọ́lára, amọ́láwọ̀ díẹ̀',
    '👨🏻‍❤‍💋‍👨🏾' => 'Ifẹnuko: Ọkùnrin, Ọkùnrin, amọ́lára, adúláwọ̀ díẹ̀',
    '👨🏻‍❤‍💋‍👨🏿' => 'Ifẹnuko: Ọkùnrin, Ọkùnrin, amọ́lára, adúláwọ̀',
    '👨🏼‍❤‍💋‍👨🏻' => 'Ifẹnuko: Ọkùnrin, Ọkùnrin, amọ́lára díẹ̀, amọ́lára',
    '👨🏼‍❤‍💋‍👨🏼' => 'Ifẹnuko: Ọkùnrin, Ọkùnrin, amọ́lára díẹ̀',
    '👨🏼‍❤‍💋‍👨🏽' => 'Ifẹnuko: Ọkùnrin, Ọkùnrin, amọ́lára díẹ̀, amọ́láwọ̀ díẹ̀',
    '👨🏼‍❤‍💋‍👨🏾' => 'Ifẹnuko: Ọkùnrin, Ọkùnrin, amọ́lára díẹ̀, adúláwọ̀ díẹ̀',
    '👨🏼‍❤‍💋‍👨🏿' => 'Ifẹnuko: Ọkùnrin, Ọkùnrin, amọ́lára díẹ̀, adúláwọ̀',
    '👨🏽‍❤‍💋‍👨🏻' => 'Ifẹnuko: Ọkùnrin, Ọkùnrin, amọ́láwọ̀ díẹ̀, amọ́lára',
    '👨🏽‍❤‍💋‍👨🏼' => 'Ifẹnuko: Ọkùnrin, Ọkùnrin, amọ́láwọ̀ díẹ̀, amọ́lára díẹ̀',
    '👨🏽‍❤‍💋‍👨🏽' => 'Ifẹnuko: Ọkùnrin, Ọkùnrin, amọ́láwọ̀ díẹ̀',
    '👨🏽‍❤‍💋‍👨🏾' => 'Ifẹnuko: Ọkùnrin, Ọkùnrin, amọ́láwọ̀ díẹ̀, adúláwọ̀ díẹ̀',
    '👨🏽‍❤‍💋‍👨🏿' => 'Ifẹnuko: Ọkùnrin, Ọkùnrin, amọ́láwọ̀ díẹ̀, adúláwọ̀',
    '👨🏾‍❤‍💋‍👨🏻' => 'Ifẹnuko: Ọkùnrin, Ọkùnrin, adúláwọ̀ díẹ̀, amọ́lára',
    '👨🏾‍❤‍💋‍👨🏼' => 'Ifẹnuko: Ọkùnrin, Ọkùnrin, adúláwọ̀ díẹ̀, amọ́lára díẹ̀',
    '👨🏾‍❤‍💋‍👨🏽' => 'Ifẹnuko: Ọkùnrin, Ọkùnrin, adúláwọ̀ díẹ̀, amọ́láwọ̀ díẹ̀',
    '👨🏾‍❤‍💋‍👨🏾' => 'Ifẹnuko: Ọkùnrin, Ọkùnrin, adúláwọ̀ díẹ̀',
    '👨🏾‍❤‍💋‍👨🏿' => 'Ifẹnuko: Ọkùnrin, Ọkùnrin, adúláwọ̀ díẹ̀, adúláwọ̀',
    '👨🏿‍❤‍💋‍👨🏻' => 'Ifẹnuko: Ọkùnrin, Ọkùnrin, adúláwọ̀, amọ́lára',
    '👨🏿‍❤‍💋‍👨🏼' => 'Ifẹnuko: Ọkùnrin, Ọkùnrin, adúláwọ̀, amọ́lára díẹ̀',
    '👨🏿‍❤‍💋‍👨🏽' => 'Ifẹnuko: Ọkùnrin, Ọkùnrin, adúláwọ̀, amọ́láwọ̀ díẹ̀',
    '👨🏿‍❤‍💋‍👨🏾' => 'Ifẹnuko: Ọkùnrin, Ọkùnrin, adúláwọ̀, adúláwọ̀ díẹ̀',
    '👨🏿‍❤‍💋‍👨🏿' => 'Ifẹnuko: Ọkùnrin, Ọkùnrin, adúláwọ̀',
    '👩🏻‍❤‍💋‍👨🏻' => 'Ifẹnuko: Obìnrin, Ọkùnrin, amọ́lára',
    '👩🏻‍❤‍💋‍👨🏼' => 'Ifẹnuko: Obìnrin, Ọkùnrin, amọ́lára, amọ́lára díẹ̀',
    '👩🏻‍❤‍💋‍👨🏽' => 'Ifẹnuko: Obìnrin, Ọkùnrin, amọ́lára, amọ́láwọ̀ díẹ̀',
    '👩🏻‍❤‍💋‍👨🏾' => 'Ifẹnuko: Obìnrin, Ọkùnrin, amọ́lára, adúláwọ̀ díẹ̀',
    '👩🏻‍❤‍💋‍👨🏿' => 'Ifẹnuko: Obìnrin, Ọkùnrin, amọ́lára, adúláwọ̀',
    '👩🏼‍❤‍💋‍👨🏻' => 'Ifẹnuko: Obìnrin, Ọkùnrin, amọ́lára díẹ̀, amọ́lára',
    '👩🏼‍❤‍💋‍👨🏼' => 'Ifẹnuko: Obìnrin, Ọkùnrin, amọ́lára díẹ̀',
    '👩🏼‍❤‍💋‍👨🏽' => 'Ifẹnuko: Obìnrin, Ọkùnrin, amọ́lára díẹ̀, amọ́láwọ̀ díẹ̀',
    '👩🏼‍❤‍💋‍👨🏾' => 'Ifẹnuko: Obìnrin, Ọkùnrin, amọ́lára díẹ̀, adúláwọ̀ díẹ̀',
    '👩🏼‍❤‍💋‍👨🏿' => 'Ifẹnuko: Obìnrin, Ọkùnrin, amọ́lára díẹ̀, adúláwọ̀',
    '👩🏽‍❤‍💋‍👨🏻' => 'Ifẹnuko: Obìnrin, Ọkùnrin, amọ́láwọ̀ díẹ̀, amọ́lára',
    '👩🏽‍❤‍💋‍👨🏼' => 'Ifẹnuko: Obìnrin, Ọkùnrin, amọ́láwọ̀ díẹ̀, amọ́lára díẹ̀',
    '👩🏽‍❤‍💋‍👨🏽' => 'Ifẹnuko: Obìnrin, Ọkùnrin, amọ́láwọ̀ díẹ̀',
    '👩🏽‍❤‍💋‍👨🏾' => 'Ifẹnuko: Obìnrin, Ọkùnrin, amọ́láwọ̀ díẹ̀, adúláwọ̀ díẹ̀',
    '👩🏽‍❤‍💋‍👨🏿' => 'Ifẹnuko: Obìnrin, Ọkùnrin, amọ́láwọ̀ díẹ̀, adúláwọ̀',
    '👩🏾‍❤‍💋‍👨🏻' => 'Ifẹnuko: Obìnrin, Ọkùnrin, adúláwọ̀ díẹ̀, amọ́lára',
    '👩🏾‍❤‍💋‍👨🏼' => 'Ifẹnuko: Obìnrin, Ọkùnrin, adúláwọ̀ díẹ̀, amọ́lára díẹ̀',
    '👩🏾‍❤‍💋‍👨🏽' => 'Ifẹnuko: Obìnrin, Ọkùnrin, adúláwọ̀ díẹ̀, amọ́láwọ̀ díẹ̀',
    '👩🏾‍❤‍💋‍👨🏾' => 'Ifẹnuko: Obìnrin, Ọkùnrin, adúláwọ̀ díẹ̀',
    '👩🏾‍❤‍💋‍👨🏿' => 'Ifẹnuko: Obìnrin, Ọkùnrin, adúláwọ̀ díẹ̀, adúláwọ̀',
    '👩🏿‍❤‍💋‍👨🏻' => 'Ifẹnuko: Obìnrin, Ọkùnrin, adúláwọ̀, amọ́lára',
    '👩🏿‍❤‍💋‍👨🏼' => 'Ifẹnuko: Obìnrin, Ọkùnrin, adúláwọ̀, amọ́lára díẹ̀',
    '👩🏿‍❤‍💋‍👨🏽' => 'Ifẹnuko: Obìnrin, Ọkùnrin, adúláwọ̀, amọ́láwọ̀ díẹ̀',
    '👩🏿‍❤‍💋‍👨🏾' => 'Ifẹnuko: Obìnrin, Ọkùnrin, adúláwọ̀, adúláwọ̀ díẹ̀',
    '👩🏿‍❤‍💋‍👨🏿' => 'Ifẹnuko: Obìnrin, Ọkùnrin, adúláwọ̀',
    '👩🏻‍❤‍💋‍👩🏻' => 'Ifẹnuko: Obìnrin, Obìnrin, amọ́lára',
    '👩🏻‍❤‍💋‍👩🏼' => 'Ifẹnuko: Obìnrin, Obìnrin, amọ́lára, amọ́lára díẹ̀',
    '👩🏻‍❤‍💋‍👩🏽' => 'Ifẹnuko: Obìnrin, Obìnrin, amọ́lára, amọ́láwọ̀ díẹ̀',
    '👩🏻‍❤‍💋‍👩🏾' => 'Ifẹnuko: Obìnrin, Obìnrin, amọ́lára, adúláwọ̀ díẹ̀',
    '👩🏻‍❤‍💋‍👩🏿' => 'Ifẹnuko: Obìnrin, Obìnrin, amọ́lára, adúláwọ̀',
    '👩🏼‍❤‍💋‍👩🏻' => 'Ifẹnuko: Obìnrin, Obìnrin, amọ́lára díẹ̀, amọ́lára',
    '👩🏼‍❤‍💋‍👩🏼' => 'Ifẹnuko: Obìnrin, Obìnrin, amọ́lára díẹ̀',
    '👩🏼‍❤‍💋‍👩🏽' => 'Ifẹnuko: Obìnrin, Obìnrin, amọ́lára díẹ̀, amọ́láwọ̀ díẹ̀',
    '👩🏼‍❤‍💋‍👩🏾' => 'Ifẹnuko: Obìnrin, Obìnrin, amọ́lára díẹ̀, adúláwọ̀ díẹ̀',
    '👩🏼‍❤‍💋‍👩🏿' => 'Ifẹnuko: Obìnrin, Obìnrin, amọ́lára díẹ̀, adúláwọ̀',
    '👩🏽‍❤‍💋‍👩🏻' => 'Ifẹnuko: Obìnrin, Obìnrin, amọ́láwọ̀ díẹ̀, amọ́lára',
    '👩🏽‍❤‍💋‍👩🏼' => 'Ifẹnuko: Obìnrin, Obìnrin, amọ́láwọ̀ díẹ̀, amọ́lára díẹ̀',
    '👩🏽‍❤‍💋‍👩🏽' => 'Ifẹnuko: Obìnrin, Obìnrin, amọ́láwọ̀ díẹ̀',
    '👩🏽‍❤‍💋‍👩🏾' => 'Ifẹnuko: Obìnrin, Obìnrin, amọ́láwọ̀ díẹ̀, adúláwọ̀ díẹ̀',
    '👩🏽‍❤‍💋‍👩🏿' => 'Ifẹnuko: Obìnrin, Obìnrin, amọ́láwọ̀ díẹ̀, adúláwọ̀',
    '👩🏾‍❤‍💋‍👩🏻' => 'Ifẹnuko: Obìnrin, Obìnrin, adúláwọ̀ díẹ̀, amọ́lára',
    '👩🏾‍❤‍💋‍👩🏼' => 'Ifẹnuko: Obìnrin, Obìnrin, adúláwọ̀ díẹ̀, amọ́lára díẹ̀',
    '👩🏾‍❤‍💋‍👩🏽' => 'Ifẹnuko: Obìnrin, Obìnrin, adúláwọ̀ díẹ̀, amọ́láwọ̀ díẹ̀',
    '👩🏾‍❤‍💋‍👩🏾' => 'Ifẹnuko: Obìnrin, Obìnrin, adúláwọ̀ díẹ̀',
    '👩🏾‍❤‍💋‍👩🏿' => 'Ifẹnuko: Obìnrin, Obìnrin, adúláwọ̀ díẹ̀, adúláwọ̀',
    '👩🏿‍❤‍💋‍👩🏻' => 'Ifẹnuko: Obìnrin, Obìnrin, adúláwọ̀, amọ́lára',
    '👩🏿‍❤‍💋‍👩🏼' => 'Ifẹnuko: Obìnrin, Obìnrin, adúláwọ̀, amọ́lára díẹ̀',
    '👩🏿‍❤‍💋‍👩🏽' => 'Ifẹnuko: Obìnrin, Obìnrin, adúláwọ̀, amọ́láwọ̀ díẹ̀',
    '👩🏿‍❤‍💋‍👩🏾' => 'Ifẹnuko: Obìnrin, Obìnrin, adúláwọ̀, adúláwọ̀ díẹ̀',
    '👩🏿‍❤‍💋‍👩🏿' => 'Ifẹnuko: Obìnrin, Obìnrin, adúláwọ̀',
    '🧑🏻‍🫯‍🧑🏼' => 'Awọn Onigidigbo: amọ́lára àtiamọ́lára díẹ̀',
    '🧑🏻‍🫯‍🧑🏽' => 'Awọn Onigidigbo: amọ́lára àtiamọ́láwọ̀ díẹ̀',
    '🧑🏻‍🫯‍🧑🏾' => 'Awọn Onigidigbo: amọ́lára àtiadúláwọ̀ díẹ̀',
    '🧑🏻‍🫯‍🧑🏿' => 'Awọn Onigidigbo: amọ́lára àtiadúláwọ̀',
    '🧑🏼‍🫯‍🧑🏻' => 'Awọn Onigidigbo: amọ́lára díẹ̀ àtiamọ́lára',
    '🧑🏼‍🫯‍🧑🏽' => 'Awọn Onigidigbo: amọ́lára díẹ̀ àtiamọ́láwọ̀ díẹ̀',
    '🧑🏼‍🫯‍🧑🏾' => 'Awọn Onigidigbo: amọ́lára díẹ̀ àtiadúláwọ̀ díẹ̀',
    '🧑🏼‍🫯‍🧑🏿' => 'Awọn Onigidigbo: amọ́lára díẹ̀ àtiadúláwọ̀',
    '🧑🏽‍🫯‍🧑🏻' => 'Awọn Onigidigbo: amọ́láwọ̀ díẹ̀ àtiamọ́lára',
    '🧑🏽‍🫯‍🧑🏼' => 'Awọn Onigidigbo: amọ́láwọ̀ díẹ̀ àtiamọ́lára díẹ̀',
    '🧑🏽‍🫯‍🧑🏾' => 'Awọn Onigidigbo: amọ́láwọ̀ díẹ̀ àtiadúláwọ̀ díẹ̀',
    '🧑🏽‍🫯‍🧑🏿' => 'Awọn Onigidigbo: amọ́láwọ̀ díẹ̀ àtiadúláwọ̀',
    '🧑🏾‍🫯‍🧑🏻' => 'Awọn Onigidigbo: adúláwọ̀ díẹ̀ àtiamọ́lára',
    '🧑🏾‍🫯‍🧑🏼' => 'Awọn Onigidigbo: adúláwọ̀ díẹ̀ àtiamọ́lára díẹ̀',
    '🧑🏾‍🫯‍🧑🏽' => 'Awọn Onigidigbo: adúláwọ̀ díẹ̀ àtiamọ́láwọ̀ díẹ̀',
    '🧑🏾‍🫯‍🧑🏿' => 'Awọn Onigidigbo: adúláwọ̀ díẹ̀ àtiadúláwọ̀',
    '🧑🏿‍🫯‍🧑🏻' => 'Awọn Onigidigbo: adúláwọ̀ àtiamọ́lára',
    '🧑🏿‍🫯‍🧑🏼' => 'Awọn Onigidigbo: adúláwọ̀ àtiamọ́lára díẹ̀',
    '🧑🏿‍🫯‍🧑🏽' => 'Awọn Onigidigbo: adúláwọ̀ àtiamọ́láwọ̀ díẹ̀',
    '🧑🏿‍🫯‍🧑🏾' => 'Awọn Onigidigbo: adúláwọ̀ àtiadúláwọ̀ díẹ̀',
    '🧑🏻‍❤‍🧑🏼' => 'Lọkọlaya Pẹlu ọkan: àgbà, àgbà, amọ́lára, amọ́lára díẹ̀',
    '🧑🏻‍❤‍🧑🏽' => 'Lọkọlaya Pẹlu ọkan: àgbà, àgbà, amọ́lára, amọ́láwọ̀ díẹ̀',
    '🧑🏻‍❤‍🧑🏾' => 'Lọkọlaya Pẹlu ọkan: àgbà, àgbà, amọ́lára, adúláwọ̀ díẹ̀',
    '🧑🏻‍❤‍🧑🏿' => 'Lọkọlaya Pẹlu ọkan: àgbà, àgbà, amọ́lára, adúláwọ̀',
    '🧑🏼‍❤‍🧑🏻' => 'Lọkọlaya Pẹlu ọkan: àgbà, àgbà, amọ́lára díẹ̀, amọ́lára',
    '🧑🏼‍❤‍🧑🏽' => 'Lọkọlaya Pẹlu ọkan: àgbà, àgbà, amọ́lára díẹ̀, amọ́láwọ̀ díẹ̀',
    '🧑🏼‍❤‍🧑🏾' => 'Lọkọlaya Pẹlu ọkan: àgbà, àgbà, amọ́lára díẹ̀, adúláwọ̀ díẹ̀',
    '🧑🏼‍❤‍🧑🏿' => 'Lọkọlaya Pẹlu ọkan: àgbà, àgbà, amọ́lára díẹ̀, adúláwọ̀',
    '🧑🏽‍❤‍🧑🏻' => 'Lọkọlaya Pẹlu ọkan: àgbà, àgbà, amọ́láwọ̀ díẹ̀, amọ́lára',
    '🧑🏽‍❤‍🧑🏼' => 'Lọkọlaya Pẹlu ọkan: àgbà, àgbà, amọ́láwọ̀ díẹ̀, amọ́lára díẹ̀',
    '🧑🏽‍❤‍🧑🏾' => 'Lọkọlaya Pẹlu ọkan: àgbà, àgbà, amọ́láwọ̀ díẹ̀, adúláwọ̀ díẹ̀',
    '🧑🏽‍❤‍🧑🏿' => 'Lọkọlaya Pẹlu ọkan: àgbà, àgbà, amọ́láwọ̀ díẹ̀, adúláwọ̀',
    '🧑🏾‍❤‍🧑🏻' => 'Lọkọlaya Pẹlu ọkan: àgbà, àgbà, adúláwọ̀ díẹ̀, amọ́lára',
    '🧑🏾‍❤‍🧑🏼' => 'Lọkọlaya Pẹlu ọkan: àgbà, àgbà, adúláwọ̀ díẹ̀, amọ́lára díẹ̀',
    '🧑🏾‍❤‍🧑🏽' => 'Lọkọlaya Pẹlu ọkan: àgbà, àgbà, adúláwọ̀ díẹ̀, amọ́láwọ̀ díẹ̀',
    '🧑🏾‍❤‍🧑🏿' => 'Lọkọlaya Pẹlu ọkan: àgbà, àgbà, adúláwọ̀ díẹ̀, adúláwọ̀',
    '🧑🏿‍❤‍🧑🏻' => 'Lọkọlaya Pẹlu ọkan: àgbà, àgbà, adúláwọ̀, amọ́lára',
    '🧑🏿‍❤‍🧑🏼' => 'Lọkọlaya Pẹlu ọkan: àgbà, àgbà, adúláwọ̀, amọ́lára díẹ̀',
    '🧑🏿‍❤‍🧑🏽' => 'Lọkọlaya Pẹlu ọkan: àgbà, àgbà, adúláwọ̀, amọ́láwọ̀ díẹ̀',
    '🧑🏿‍❤‍🧑🏾' => 'Lọkọlaya Pẹlu ọkan: àgbà, àgbà, adúláwọ̀, adúláwọ̀ díẹ̀',
    '🧑🏻‍🐰‍🧑🏼' => 'awọn eniyan eleti ehoro: amọ́lára àtiamọ́lára díẹ̀',
    '🧑🏻‍🐰‍🧑🏽' => 'awọn eniyan eleti ehoro: amọ́lára àtiamọ́láwọ̀ díẹ̀',
    '🧑🏻‍🐰‍🧑🏾' => 'awọn eniyan eleti ehoro: amọ́lára àtiadúláwọ̀ díẹ̀',
    '🧑🏻‍🐰‍🧑🏿' => 'awọn eniyan eleti ehoro: amọ́lára àtiadúláwọ̀',
    '🧑🏼‍🐰‍🧑🏻' => 'awọn eniyan eleti ehoro: amọ́lára díẹ̀ àtiamọ́lára',
    '🧑🏼‍🐰‍🧑🏽' => 'awọn eniyan eleti ehoro: amọ́lára díẹ̀ àtiamọ́láwọ̀ díẹ̀',
    '🧑🏼‍🐰‍🧑🏾' => 'awọn eniyan eleti ehoro: amọ́lára díẹ̀ àtiadúláwọ̀ díẹ̀',
    '🧑🏼‍🐰‍🧑🏿' => 'awọn eniyan eleti ehoro: amọ́lára díẹ̀ àtiadúláwọ̀',
    '🧑🏽‍🐰‍🧑🏻' => 'awọn eniyan eleti ehoro: amọ́láwọ̀ díẹ̀ àtiamọ́lára',
    '🧑🏽‍🐰‍🧑🏼' => 'awọn eniyan eleti ehoro: amọ́láwọ̀ díẹ̀ àtiamọ́lára díẹ̀',
    '🧑🏽‍🐰‍🧑🏾' => 'awọn eniyan eleti ehoro: amọ́láwọ̀ díẹ̀ àtiadúláwọ̀ díẹ̀',
    '🧑🏽‍🐰‍🧑🏿' => 'awọn eniyan eleti ehoro: amọ́láwọ̀ díẹ̀ àtiadúláwọ̀',
    '🧑🏾‍🐰‍🧑🏻' => 'awọn eniyan eleti ehoro: adúláwọ̀ díẹ̀ àtiamọ́lára',
    '🧑🏾‍🐰‍🧑🏼' => 'awọn eniyan eleti ehoro: adúláwọ̀ díẹ̀ àtiamọ́lára díẹ̀',
    '🧑🏾‍🐰‍🧑🏽' => 'awọn eniyan eleti ehoro: adúláwọ̀ díẹ̀ àtiamọ́láwọ̀ díẹ̀',
    '🧑🏾‍🐰‍🧑🏿' => 'awọn eniyan eleti ehoro: adúláwọ̀ díẹ̀ àtiadúláwọ̀',
    '🧑🏿‍🐰‍🧑🏻' => 'awọn eniyan eleti ehoro: adúláwọ̀ àtiamọ́lára',
    '🧑🏿‍🐰‍🧑🏼' => 'awọn eniyan eleti ehoro: adúláwọ̀ àtiamọ́lára díẹ̀',
    '🧑🏿‍🐰‍🧑🏽' => 'awọn eniyan eleti ehoro: adúláwọ̀ àtiamọ́láwọ̀ díẹ̀',
    '🧑🏿‍🐰‍🧑🏾' => 'awọn eniyan eleti ehoro: adúláwọ̀ àtiadúláwọ̀ díẹ̀',
    '👨🏻‍🫯‍👨🏼' => 'àwọn ọkùnrin ti n ja ijakadi: amọ́lára àtiamọ́lára díẹ̀',
    '👨🏻‍🫯‍👨🏽' => 'àwọn ọkùnrin ti n ja ijakadi: amọ́lára àtiamọ́láwọ̀ díẹ̀',
    '👨🏻‍🫯‍👨🏾' => 'àwọn ọkùnrin ti n ja ijakadi: amọ́lára àtiadúláwọ̀ díẹ̀',
    '👨🏻‍🫯‍👨🏿' => 'àwọn ọkùnrin ti n ja ijakadi: amọ́lára àtiadúláwọ̀',
    '👨🏼‍🫯‍👨🏻' => 'àwọn ọkùnrin ti n ja ijakadi: amọ́lára díẹ̀ àtiamọ́lára',
    '👨🏼‍🫯‍👨🏽' => 'àwọn ọkùnrin ti n ja ijakadi: amọ́lára díẹ̀ àtiamọ́láwọ̀ díẹ̀',
    '👨🏼‍🫯‍👨🏾' => 'àwọn ọkùnrin ti n ja ijakadi: amọ́lára díẹ̀ àtiadúláwọ̀ díẹ̀',
    '👨🏼‍🫯‍👨🏿' => 'àwọn ọkùnrin ti n ja ijakadi: amọ́lára díẹ̀ àtiadúláwọ̀',
    '👨🏽‍🫯‍👨🏻' => 'àwọn ọkùnrin ti n ja ijakadi: amọ́láwọ̀ díẹ̀ àtiamọ́lára',
    '👨🏽‍🫯‍👨🏼' => 'àwọn ọkùnrin ti n ja ijakadi: amọ́láwọ̀ díẹ̀ àtiamọ́lára díẹ̀',
    '👨🏽‍🫯‍👨🏾' => 'àwọn ọkùnrin ti n ja ijakadi: amọ́láwọ̀ díẹ̀ àtiadúláwọ̀ díẹ̀',
    '👨🏽‍🫯‍👨🏿' => 'àwọn ọkùnrin ti n ja ijakadi: amọ́láwọ̀ díẹ̀ àtiadúláwọ̀',
    '👨🏾‍🫯‍👨🏻' => 'àwọn ọkùnrin ti n ja ijakadi: adúláwọ̀ díẹ̀ àtiamọ́lára',
    '👨🏾‍🫯‍👨🏼' => 'àwọn ọkùnrin ti n ja ijakadi: adúláwọ̀ díẹ̀ àtiamọ́lára díẹ̀',
    '👨🏾‍🫯‍👨🏽' => 'àwọn ọkùnrin ti n ja ijakadi: adúláwọ̀ díẹ̀ àtiamọ́láwọ̀ díẹ̀',
    '👨🏾‍🫯‍👨🏿' => 'àwọn ọkùnrin ti n ja ijakadi: adúláwọ̀ díẹ̀ àtiadúláwọ̀',
    '👨🏿‍🫯‍👨🏻' => 'àwọn ọkùnrin ti n ja ijakadi: adúláwọ̀ àtiamọ́lára',
    '👨🏿‍🫯‍👨🏼' => 'àwọn ọkùnrin ti n ja ijakadi: adúláwọ̀ àtiamọ́lára díẹ̀',
    '👨🏿‍🫯‍👨🏽' => 'àwọn ọkùnrin ti n ja ijakadi: adúláwọ̀ àtiamọ́láwọ̀ díẹ̀',
    '👨🏿‍🫯‍👨🏾' => 'àwọn ọkùnrin ti n ja ijakadi: adúláwọ̀ àtiadúláwọ̀ díẹ̀',
    '👨🏻‍❤‍👨🏻' => 'Lọkọlaya Pẹlu ọkan: Ọkùnrin, Ọkùnrin, amọ́lára',
    '👨🏻‍❤‍👨🏼' => 'Lọkọlaya Pẹlu ọkan: Ọkùnrin, Ọkùnrin, amọ́lára, amọ́lára díẹ̀',
    '👨🏻‍❤‍👨🏽' => 'Lọkọlaya Pẹlu ọkan: Ọkùnrin, Ọkùnrin, amọ́lára, amọ́láwọ̀ díẹ̀',
    '👨🏻‍❤‍👨🏾' => 'Lọkọlaya Pẹlu ọkan: Ọkùnrin, Ọkùnrin, amọ́lára, adúláwọ̀ díẹ̀',
    '👨🏻‍❤‍👨🏿' => 'Lọkọlaya Pẹlu ọkan: Ọkùnrin, Ọkùnrin, amọ́lára, adúláwọ̀',
    '👨🏼‍❤‍👨🏻' => 'Lọkọlaya Pẹlu ọkan: Ọkùnrin, Ọkùnrin, amọ́lára díẹ̀, amọ́lára',
    '👨🏼‍❤‍👨🏼' => 'Lọkọlaya Pẹlu ọkan: Ọkùnrin, Ọkùnrin, amọ́lára díẹ̀',
    '👨🏼‍❤‍👨🏽' => 'Lọkọlaya Pẹlu ọkan: Ọkùnrin, Ọkùnrin, amọ́lára díẹ̀, amọ́láwọ̀ díẹ̀',
    '👨🏼‍❤‍👨🏾' => 'Lọkọlaya Pẹlu ọkan: Ọkùnrin, Ọkùnrin, amọ́lára díẹ̀, adúláwọ̀ díẹ̀',
    '👨🏼‍❤‍👨🏿' => 'Lọkọlaya Pẹlu ọkan: Ọkùnrin, Ọkùnrin, amọ́lára díẹ̀, adúláwọ̀',
    '👨🏽‍❤‍👨🏻' => 'Lọkọlaya Pẹlu ọkan: Ọkùnrin, Ọkùnrin, amọ́láwọ̀ díẹ̀, amọ́lára',
    '👨🏽‍❤‍👨🏼' => 'Lọkọlaya Pẹlu ọkan: Ọkùnrin, Ọkùnrin, amọ́láwọ̀ díẹ̀, amọ́lára díẹ̀',
    '👨🏽‍❤‍👨🏽' => 'Lọkọlaya Pẹlu ọkan: Ọkùnrin, Ọkùnrin, amọ́láwọ̀ díẹ̀',
    '👨🏽‍❤‍👨🏾' => 'Lọkọlaya Pẹlu ọkan: Ọkùnrin, Ọkùnrin, amọ́láwọ̀ díẹ̀, adúláwọ̀ díẹ̀',
    '👨🏽‍❤‍👨🏿' => 'Lọkọlaya Pẹlu ọkan: Ọkùnrin, Ọkùnrin, amọ́láwọ̀ díẹ̀, adúláwọ̀',
    '👨🏾‍❤‍👨🏻' => 'Lọkọlaya Pẹlu ọkan: Ọkùnrin, Ọkùnrin, adúláwọ̀ díẹ̀, amọ́lára',
    '👨🏾‍❤‍👨🏼' => 'Lọkọlaya Pẹlu ọkan: Ọkùnrin, Ọkùnrin, adúláwọ̀ díẹ̀, amọ́lára díẹ̀',
    '👨🏾‍❤‍👨🏽' => 'Lọkọlaya Pẹlu ọkan: Ọkùnrin, Ọkùnrin, adúláwọ̀ díẹ̀, amọ́láwọ̀ díẹ̀',
    '👨🏾‍❤‍👨🏾' => 'Lọkọlaya Pẹlu ọkan: Ọkùnrin, Ọkùnrin, adúláwọ̀ díẹ̀',
    '👨🏾‍❤‍👨🏿' => 'Lọkọlaya Pẹlu ọkan: Ọkùnrin, Ọkùnrin, adúláwọ̀ díẹ̀, adúláwọ̀',
    '👨🏿‍❤‍👨🏻' => 'Lọkọlaya Pẹlu ọkan: Ọkùnrin, Ọkùnrin, adúláwọ̀, amọ́lára',
    '👨🏿‍❤‍👨🏼' => 'Lọkọlaya Pẹlu ọkan: Ọkùnrin, Ọkùnrin, adúláwọ̀, amọ́lára díẹ̀',
    '👨🏿‍❤‍👨🏽' => 'Lọkọlaya Pẹlu ọkan: Ọkùnrin, Ọkùnrin, adúláwọ̀, amọ́láwọ̀ díẹ̀',
    '👨🏿‍❤‍👨🏾' => 'Lọkọlaya Pẹlu ọkan: Ọkùnrin, Ọkùnrin, adúláwọ̀, adúláwọ̀ díẹ̀',
    '👨🏿‍❤‍👨🏿' => 'Lọkọlaya Pẹlu ọkan: Ọkùnrin, Ọkùnrin, adúláwọ̀',
    '👨🏻‍🐰‍👨🏼' => 'àwọn ọkùnrin elétí ehoro: amọ́lára àtiamọ́lára díẹ̀',
    '👨🏻‍🐰‍👨🏽' => 'àwọn ọkùnrin elétí ehoro: amọ́lára àtiamọ́láwọ̀ díẹ̀',
    '👨🏻‍🐰‍👨🏾' => 'àwọn ọkùnrin elétí ehoro: amọ́lára àtiadúláwọ̀ díẹ̀',
    '👨🏻‍🐰‍👨🏿' => 'àwọn ọkùnrin elétí ehoro: amọ́lára àtiadúláwọ̀',
    '👨🏼‍🐰‍👨🏻' => 'àwọn ọkùnrin elétí ehoro: amọ́lára díẹ̀ àtiamọ́lára',
    '👨🏼‍🐰‍👨🏽' => 'àwọn ọkùnrin elétí ehoro: amọ́lára díẹ̀ àtiamọ́láwọ̀ díẹ̀',
    '👨🏼‍🐰‍👨🏾' => 'àwọn ọkùnrin elétí ehoro: amọ́lára díẹ̀ àtiadúláwọ̀ díẹ̀',
    '👨🏼‍🐰‍👨🏿' => 'àwọn ọkùnrin elétí ehoro: amọ́lára díẹ̀ àtiadúláwọ̀',
    '👨🏽‍🐰‍👨🏻' => 'àwọn ọkùnrin elétí ehoro: amọ́láwọ̀ díẹ̀ àtiamọ́lára',
    '👨🏽‍🐰‍👨🏼' => 'àwọn ọkùnrin elétí ehoro: amọ́láwọ̀ díẹ̀ àtiamọ́lára díẹ̀',
    '👨🏽‍🐰‍👨🏾' => 'àwọn ọkùnrin elétí ehoro: amọ́láwọ̀ díẹ̀ àtiadúláwọ̀ díẹ̀',
    '👨🏽‍🐰‍👨🏿' => 'àwọn ọkùnrin elétí ehoro: amọ́láwọ̀ díẹ̀ àtiadúláwọ̀',
    '👨🏾‍🐰‍👨🏻' => 'àwọn ọkùnrin elétí ehoro: adúláwọ̀ díẹ̀ àtiamọ́lára',
    '👨🏾‍🐰‍👨🏼' => 'àwọn ọkùnrin elétí ehoro: adúláwọ̀ díẹ̀ àtiamọ́lára díẹ̀',
    '👨🏾‍🐰‍👨🏽' => 'àwọn ọkùnrin elétí ehoro: adúláwọ̀ díẹ̀ àtiamọ́láwọ̀ díẹ̀',
    '👨🏾‍🐰‍👨🏿' => 'àwọn ọkùnrin elétí ehoro: adúláwọ̀ díẹ̀ àtiadúláwọ̀',
    '👨🏿‍🐰‍👨🏻' => 'àwọn ọkùnrin elétí ehoro: adúláwọ̀ àtiamọ́lára',
    '👨🏿‍🐰‍👨🏼' => 'àwọn ọkùnrin elétí ehoro: adúláwọ̀ àtiamọ́lára díẹ̀',
    '👨🏿‍🐰‍👨🏽' => 'àwọn ọkùnrin elétí ehoro: adúláwọ̀ àtiamọ́láwọ̀ díẹ̀',
    '👨🏿‍🐰‍👨🏾' => 'àwọn ọkùnrin elétí ehoro: adúláwọ̀ àtiadúláwọ̀ díẹ̀',
    '👩🏻‍🫯‍👩🏼' => 'àwọn obìnrn tí ń jà ijakadi: amọ́lára àtiamọ́lára díẹ̀',
    '👩🏻‍🫯‍👩🏽' => 'àwọn obìnrn tí ń jà ijakadi: amọ́lára àtiamọ́láwọ̀ díẹ̀',
    '👩🏻‍🫯‍👩🏾' => 'àwọn obìnrn tí ń jà ijakadi: amọ́lára àtiadúláwọ̀ díẹ̀',
    '👩🏻‍🫯‍👩🏿' => 'àwọn obìnrn tí ń jà ijakadi: amọ́lára àtiadúláwọ̀',
    '👩🏼‍🫯‍👩🏻' => 'àwọn obìnrn tí ń jà ijakadi: amọ́lára díẹ̀ àtiamọ́lára',
    '👩🏼‍🫯‍👩🏽' => 'àwọn obìnrn tí ń jà ijakadi: amọ́lára díẹ̀ àtiamọ́láwọ̀ díẹ̀',
    '👩🏼‍🫯‍👩🏾' => 'àwọn obìnrn tí ń jà ijakadi: amọ́lára díẹ̀ àtiadúláwọ̀ díẹ̀',
    '👩🏼‍🫯‍👩🏿' => 'àwọn obìnrn tí ń jà ijakadi: amọ́lára díẹ̀ àtiadúláwọ̀',
    '👩🏽‍🫯‍👩🏻' => 'àwọn obìnrn tí ń jà ijakadi: amọ́láwọ̀ díẹ̀ àtiamọ́lára',
    '👩🏽‍🫯‍👩🏼' => 'àwọn obìnrn tí ń jà ijakadi: amọ́láwọ̀ díẹ̀ àtiamọ́lára díẹ̀',
    '👩🏽‍🫯‍👩🏾' => 'àwọn obìnrn tí ń jà ijakadi: amọ́láwọ̀ díẹ̀ àtiadúláwọ̀ díẹ̀',
    '👩🏽‍🫯‍👩🏿' => 'àwọn obìnrn tí ń jà ijakadi: amọ́láwọ̀ díẹ̀ àtiadúláwọ̀',
    '👩🏾‍🫯‍👩🏻' => 'àwọn obìnrn tí ń jà ijakadi: adúláwọ̀ díẹ̀ àtiamọ́lára',
    '👩🏾‍🫯‍👩🏼' => 'àwọn obìnrn tí ń jà ijakadi: adúláwọ̀ díẹ̀ àtiamọ́lára díẹ̀',
    '👩🏾‍🫯‍👩🏽' => 'àwọn obìnrn tí ń jà ijakadi: adúláwọ̀ díẹ̀ àtiamọ́láwọ̀ díẹ̀',
    '👩🏾‍🫯‍👩🏿' => 'àwọn obìnrn tí ń jà ijakadi: adúláwọ̀ díẹ̀ àtiadúláwọ̀',
    '👩🏿‍🫯‍👩🏻' => 'àwọn obìnrn tí ń jà ijakadi: adúláwọ̀ àtiamọ́lára',
    '👩🏿‍🫯‍👩🏼' => 'àwọn obìnrn tí ń jà ijakadi: adúláwọ̀ àtiamọ́lára díẹ̀',
    '👩🏿‍🫯‍👩🏽' => 'àwọn obìnrn tí ń jà ijakadi: adúláwọ̀ àtiamọ́láwọ̀ díẹ̀',
    '👩🏿‍🫯‍👩🏾' => 'àwọn obìnrn tí ń jà ijakadi: adúláwọ̀ àtiadúláwọ̀ díẹ̀',
    '👩🏻‍❤‍👨🏻' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Ọkùnrin, amọ́lára',
    '👩🏻‍❤‍👨🏼' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Ọkùnrin, amọ́lára, amọ́lára díẹ̀',
    '👩🏻‍❤‍👨🏽' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Ọkùnrin, amọ́lára, amọ́láwọ̀ díẹ̀',
    '👩🏻‍❤‍👨🏾' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Ọkùnrin, amọ́lára, adúláwọ̀ díẹ̀',
    '👩🏻‍❤‍👨🏿' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Ọkùnrin, amọ́lára, adúláwọ̀',
    '👩🏼‍❤‍👨🏻' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Ọkùnrin, amọ́lára díẹ̀, amọ́lára',
    '👩🏼‍❤‍👨🏼' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Ọkùnrin, amọ́lára díẹ̀',
    '👩🏼‍❤‍👨🏽' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Ọkùnrin, amọ́lára díẹ̀, amọ́láwọ̀ díẹ̀',
    '👩🏼‍❤‍👨🏾' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Ọkùnrin, amọ́lára díẹ̀, adúláwọ̀ díẹ̀',
    '👩🏼‍❤‍👨🏿' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Ọkùnrin, amọ́lára díẹ̀, adúláwọ̀',
    '👩🏽‍❤‍👨🏻' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Ọkùnrin, amọ́láwọ̀ díẹ̀, amọ́lára',
    '👩🏽‍❤‍👨🏼' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Ọkùnrin, amọ́láwọ̀ díẹ̀, amọ́lára díẹ̀',
    '👩🏽‍❤‍👨🏽' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Ọkùnrin, amọ́láwọ̀ díẹ̀',
    '👩🏽‍❤‍👨🏾' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Ọkùnrin, amọ́láwọ̀ díẹ̀, adúláwọ̀ díẹ̀',
    '👩🏽‍❤‍👨🏿' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Ọkùnrin, amọ́láwọ̀ díẹ̀, adúláwọ̀',
    '👩🏾‍❤‍👨🏻' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Ọkùnrin, adúláwọ̀ díẹ̀, amọ́lára',
    '👩🏾‍❤‍👨🏼' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Ọkùnrin, adúláwọ̀ díẹ̀, amọ́lára díẹ̀',
    '👩🏾‍❤‍👨🏽' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Ọkùnrin, adúláwọ̀ díẹ̀, amọ́láwọ̀ díẹ̀',
    '👩🏾‍❤‍👨🏾' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Ọkùnrin, adúláwọ̀ díẹ̀',
    '👩🏾‍❤‍👨🏿' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Ọkùnrin, adúláwọ̀ díẹ̀, adúláwọ̀',
    '👩🏿‍❤‍👨🏻' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Ọkùnrin, adúláwọ̀, amọ́lára',
    '👩🏿‍❤‍👨🏼' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Ọkùnrin, adúláwọ̀, amọ́lára díẹ̀',
    '👩🏿‍❤‍👨🏽' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Ọkùnrin, adúláwọ̀, amọ́láwọ̀ díẹ̀',
    '👩🏿‍❤‍👨🏾' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Ọkùnrin, adúláwọ̀, adúláwọ̀ díẹ̀',
    '👩🏿‍❤‍👨🏿' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Ọkùnrin, adúláwọ̀',
    '👩🏻‍❤‍👩🏻' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Obìnrin, amọ́lára',
    '👩🏻‍❤‍👩🏼' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Obìnrin, amọ́lára, amọ́lára díẹ̀',
    '👩🏻‍❤‍👩🏽' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Obìnrin, amọ́lára, amọ́láwọ̀ díẹ̀',
    '👩🏻‍❤‍👩🏾' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Obìnrin, amọ́lára, adúláwọ̀ díẹ̀',
    '👩🏻‍❤‍👩🏿' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Obìnrin, amọ́lára, adúláwọ̀',
    '👩🏼‍❤‍👩🏻' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Obìnrin, amọ́lára díẹ̀, amọ́lára',
    '👩🏼‍❤‍👩🏼' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Obìnrin, amọ́lára díẹ̀',
    '👩🏼‍❤‍👩🏽' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Obìnrin, amọ́lára díẹ̀, amọ́láwọ̀ díẹ̀',
    '👩🏼‍❤‍👩🏾' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Obìnrin, amọ́lára díẹ̀, adúláwọ̀ díẹ̀',
    '👩🏼‍❤‍👩🏿' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Obìnrin, amọ́lára díẹ̀, adúláwọ̀',
    '👩🏽‍❤‍👩🏻' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Obìnrin, amọ́láwọ̀ díẹ̀, amọ́lára',
    '👩🏽‍❤‍👩🏼' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Obìnrin, amọ́láwọ̀ díẹ̀, amọ́lára díẹ̀',
    '👩🏽‍❤‍👩🏽' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Obìnrin, amọ́láwọ̀ díẹ̀',
    '👩🏽‍❤‍👩🏾' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Obìnrin, amọ́láwọ̀ díẹ̀, adúláwọ̀ díẹ̀',
    '👩🏽‍❤‍👩🏿' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Obìnrin, amọ́láwọ̀ díẹ̀, adúláwọ̀',
    '👩🏾‍❤‍👩🏻' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Obìnrin, adúláwọ̀ díẹ̀, amọ́lára',
    '👩🏾‍❤‍👩🏼' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Obìnrin, adúláwọ̀ díẹ̀, amọ́lára díẹ̀',
    '👩🏾‍❤‍👩🏽' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Obìnrin, adúláwọ̀ díẹ̀, amọ́láwọ̀ díẹ̀',
    '👩🏾‍❤‍👩🏾' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Obìnrin, adúláwọ̀ díẹ̀',
    '👩🏾‍❤‍👩🏿' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Obìnrin, adúláwọ̀ díẹ̀, adúláwọ̀',
    '👩🏿‍❤‍👩🏻' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Obìnrin, adúláwọ̀, amọ́lára',
    '👩🏿‍❤‍👩🏼' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Obìnrin, adúláwọ̀, amọ́lára díẹ̀',
    '👩🏿‍❤‍👩🏽' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Obìnrin, adúláwọ̀, amọ́láwọ̀ díẹ̀',
    '👩🏿‍❤‍👩🏾' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Obìnrin, adúláwọ̀, adúláwọ̀ díẹ̀',
    '👩🏿‍❤‍👩🏿' => 'Lọkọlaya Pẹlu ọkan: Obìnrin, Obìnrin, adúláwọ̀',
    '👩🏻‍🐰‍👩🏼' => 'awọn obìnrin eleti ehoro: amọ́lára àtiamọ́lára díẹ̀',
    '👩🏻‍🐰‍👩🏽' => 'awọn obìnrin eleti ehoro: amọ́lára àtiamọ́láwọ̀ díẹ̀',
    '👩🏻‍🐰‍👩🏾' => 'awọn obìnrin eleti ehoro: amọ́lára àtiadúláwọ̀ díẹ̀',
    '👩🏻‍🐰‍👩🏿' => 'awọn obìnrin eleti ehoro: amọ́lára àtiadúláwọ̀',
    '👩🏼‍🐰‍👩🏻' => 'awọn obìnrin eleti ehoro: amọ́lára díẹ̀ àtiamọ́lára',
    '👩🏼‍🐰‍👩🏽' => 'awọn obìnrin eleti ehoro: amọ́lára díẹ̀ àtiamọ́láwọ̀ díẹ̀',
    '👩🏼‍🐰‍👩🏾' => 'awọn obìnrin eleti ehoro: amọ́lára díẹ̀ àtiadúláwọ̀ díẹ̀',
    '👩🏼‍🐰‍👩🏿' => 'awọn obìnrin eleti ehoro: amọ́lára díẹ̀ àtiadúláwọ̀',
    '👩🏽‍🐰‍👩🏻' => 'awọn obìnrin eleti ehoro: amọ́láwọ̀ díẹ̀ àtiamọ́lára',
    '👩🏽‍🐰‍👩🏼' => 'awọn obìnrin eleti ehoro: amọ́láwọ̀ díẹ̀ àtiamọ́lára díẹ̀',
    '👩🏽‍🐰‍👩🏾' => 'awọn obìnrin eleti ehoro: amọ́láwọ̀ díẹ̀ àtiadúláwọ̀ díẹ̀',
    '👩🏽‍🐰‍👩🏿' => 'awọn obìnrin eleti ehoro: amọ́láwọ̀ díẹ̀ àtiadúláwọ̀',
    '👩🏾‍🐰‍👩🏻' => 'awọn obìnrin eleti ehoro: adúláwọ̀ díẹ̀ àtiamọ́lára',
    '👩🏾‍🐰‍👩🏼' => 'awọn obìnrin eleti ehoro: adúláwọ̀ díẹ̀ àtiamọ́lára díẹ̀',
    '👩🏾‍🐰‍👩🏽' => 'awọn obìnrin eleti ehoro: adúláwọ̀ díẹ̀ àtiamọ́láwọ̀ díẹ̀',
    '👩🏾‍🐰‍👩🏿' => 'awọn obìnrin eleti ehoro: adúláwọ̀ díẹ̀ àtiadúláwọ̀',
    '👩🏿‍🐰‍👩🏻' => 'awọn obìnrin eleti ehoro: adúláwọ̀ àtiamọ́lára',
    '👩🏿‍🐰‍👩🏼' => 'awọn obìnrin eleti ehoro: adúláwọ̀ àtiamọ́lára díẹ̀',
    '👩🏿‍🐰‍👩🏽' => 'awọn obìnrin eleti ehoro: adúláwọ̀ àtiamọ́láwọ̀ díẹ̀',
    '👩🏿‍🐰‍👩🏾' => 'awọn obìnrin eleti ehoro: adúláwọ̀ àtiadúláwọ̀ díẹ̀',
    '🧑🏻‍🤝‍🧑🏻' => 'àwọn ènìyàn tó di ara wọn lọ́wọ́ mú: amọ́lára',
    '🧑🏻‍🤝‍🧑🏼' => 'àwọn ènìyàn tó di ara wọn lọ́wọ́ mú: amọ́lára àtiamọ́lára díẹ̀',
    '🧑🏻‍🤝‍🧑🏽' => 'àwọn ènìyàn tó di ara wọn lọ́wọ́ mú: amọ́lára àtiamọ́láwọ̀ díẹ̀',
    '🧑🏻‍🤝‍🧑🏾' => 'àwọn ènìyàn tó di ara wọn lọ́wọ́ mú: amọ́lára àtiadúláwọ̀ díẹ̀',
    '🧑🏻‍🤝‍🧑🏿' => 'àwọn ènìyàn tó di ara wọn lọ́wọ́ mú: amọ́lára àtiadúláwọ̀',
    '🧑🏼‍🤝‍🧑🏻' => 'àwọn ènìyàn tó di ara wọn lọ́wọ́ mú: amọ́lára díẹ̀ àtiamọ́lára',
    '🧑🏼‍🤝‍🧑🏼' => 'àwọn ènìyàn tó di ara wọn lọ́wọ́ mú: amọ́lára díẹ̀',
    '🧑🏼‍🤝‍🧑🏽' => 'àwọn ènìyàn tó di ara wọn lọ́wọ́ mú: amọ́lára díẹ̀ àtiamọ́láwọ̀ díẹ̀',
    '🧑🏼‍🤝‍🧑🏾' => 'àwọn ènìyàn tó di ara wọn lọ́wọ́ mú: amọ́lára díẹ̀ àtiadúláwọ̀ díẹ̀',
    '🧑🏼‍🤝‍🧑🏿' => 'àwọn ènìyàn tó di ara wọn lọ́wọ́ mú: amọ́lára díẹ̀ àtiadúláwọ̀',
    '🧑🏽‍🤝‍🧑🏻' => 'àwọn ènìyàn tó di ara wọn lọ́wọ́ mú: amọ́láwọ̀ díẹ̀ àtiamọ́lára',
    '🧑🏽‍🤝‍🧑🏼' => 'àwọn ènìyàn tó di ara wọn lọ́wọ́ mú: amọ́láwọ̀ díẹ̀ àtiamọ́lára díẹ̀',
    '🧑🏽‍🤝‍🧑🏽' => 'àwọn ènìyàn tó di ara wọn lọ́wọ́ mú: amọ́láwọ̀ díẹ̀',
    '🧑🏽‍🤝‍🧑🏾' => 'àwọn ènìyàn tó di ara wọn lọ́wọ́ mú: amọ́láwọ̀ díẹ̀ àtiadúláwọ̀ díẹ̀',
    '🧑🏽‍🤝‍🧑🏿' => 'àwọn ènìyàn tó di ara wọn lọ́wọ́ mú: amọ́láwọ̀ díẹ̀ àtiadúláwọ̀',
    '🧑🏾‍🤝‍🧑🏻' => 'àwọn ènìyàn tó di ara wọn lọ́wọ́ mú: adúláwọ̀ díẹ̀ àtiamọ́lára',
    '🧑🏾‍🤝‍🧑🏼' => 'àwọn ènìyàn tó di ara wọn lọ́wọ́ mú: adúláwọ̀ díẹ̀ àtiamọ́lára díẹ̀',
    '🧑🏾‍🤝‍🧑🏽' => 'àwọn ènìyàn tó di ara wọn lọ́wọ́ mú: adúláwọ̀ díẹ̀ àtiamọ́láwọ̀ díẹ̀',
    '🧑🏾‍🤝‍🧑🏾' => 'àwọn ènìyàn tó di ara wọn lọ́wọ́ mú: adúláwọ̀ díẹ̀',
    '🧑🏾‍🤝‍🧑🏿' => 'àwọn ènìyàn tó di ara wọn lọ́wọ́ mú: adúláwọ̀ díẹ̀ àtiadúláwọ̀',
    '🧑🏿‍🤝‍🧑🏻' => 'àwọn ènìyàn tó di ara wọn lọ́wọ́ mú: adúláwọ̀ àtiamọ́lára',
    '🧑🏿‍🤝‍🧑🏼' => 'àwọn ènìyàn tó di ara wọn lọ́wọ́ mú: adúláwọ̀ àtiamọ́lára díẹ̀',
    '🧑🏿‍🤝‍🧑🏽' => 'àwọn ènìyàn tó di ara wọn lọ́wọ́ mú: adúláwọ̀ àtiamọ́láwọ̀ díẹ̀',
    '🧑🏿‍🤝‍🧑🏾' => 'àwọn ènìyàn tó di ara wọn lọ́wọ́ mú: adúláwọ̀ àtiadúláwọ̀ díẹ̀',
    '🧑🏿‍🤝‍🧑🏿' => 'àwọn ènìyàn tó di ara wọn lọ́wọ́ mú: adúláwọ̀',
    '👩🏻‍🤝‍👩🏼' => 'Obinrin Meji Ti O Dọwọ Ara Wọn Mu: amọ́lára àtiamọ́lára díẹ̀',
    '👩🏻‍🤝‍👩🏽' => 'Obinrin Meji Ti O Dọwọ Ara Wọn Mu: amọ́lára àtiamọ́láwọ̀ díẹ̀',
    '👩🏻‍🤝‍👩🏾' => 'Obinrin Meji Ti O Dọwọ Ara Wọn Mu: amọ́lára àtiadúláwọ̀ díẹ̀',
    '👩🏻‍🤝‍👩🏿' => 'Obinrin Meji Ti O Dọwọ Ara Wọn Mu: amọ́lára àtiadúláwọ̀',
    '👩🏼‍🤝‍👩🏻' => 'Obinrin Meji Ti O Dọwọ Ara Wọn Mu: amọ́lára díẹ̀ àtiamọ́lára',
    '👩🏼‍🤝‍👩🏽' => 'Obinrin Meji Ti O Dọwọ Ara Wọn Mu: amọ́lára díẹ̀ àtiamọ́láwọ̀ díẹ̀',
    '👩🏼‍🤝‍👩🏾' => 'Obinrin Meji Ti O Dọwọ Ara Wọn Mu: amọ́lára díẹ̀ àtiadúláwọ̀ díẹ̀',
    '👩🏼‍🤝‍👩🏿' => 'Obinrin Meji Ti O Dọwọ Ara Wọn Mu: amọ́lára díẹ̀ àtiadúláwọ̀',
    '👩🏽‍🤝‍👩🏻' => 'Obinrin Meji Ti O Dọwọ Ara Wọn Mu: amọ́láwọ̀ díẹ̀ àtiamọ́lára',
    '👩🏽‍🤝‍👩🏼' => 'Obinrin Meji Ti O Dọwọ Ara Wọn Mu: amọ́láwọ̀ díẹ̀ àtiamọ́lára díẹ̀',
    '👩🏽‍🤝‍👩🏾' => 'Obinrin Meji Ti O Dọwọ Ara Wọn Mu: amọ́láwọ̀ díẹ̀ àtiadúláwọ̀ díẹ̀',
    '👩🏽‍🤝‍👩🏿' => 'Obinrin Meji Ti O Dọwọ Ara Wọn Mu: amọ́láwọ̀ díẹ̀ àtiadúláwọ̀',
    '👩🏾‍🤝‍👩🏻' => 'Obinrin Meji Ti O Dọwọ Ara Wọn Mu: adúláwọ̀ díẹ̀ àtiamọ́lára',
    '👩🏾‍🤝‍👩🏼' => 'Obinrin Meji Ti O Dọwọ Ara Wọn Mu: adúláwọ̀ díẹ̀ àtiamọ́lára díẹ̀',
    '👩🏾‍🤝‍👩🏽' => 'Obinrin Meji Ti O Dọwọ Ara Wọn Mu: adúláwọ̀ díẹ̀ àtiamọ́láwọ̀ díẹ̀',
    '👩🏾‍🤝‍👩🏿' => 'Obinrin Meji Ti O Dọwọ Ara Wọn Mu: adúláwọ̀ díẹ̀ àtiadúláwọ̀',
    '👩🏿‍🤝‍👩🏻' => 'Obinrin Meji Ti O Dọwọ Ara Wọn Mu: adúláwọ̀ àtiamọ́lára',
    '👩🏿‍🤝‍👩🏼' => 'Obinrin Meji Ti O Dọwọ Ara Wọn Mu: adúláwọ̀ àtiamọ́lára díẹ̀',
    '👩🏿‍🤝‍👩🏽' => 'Obinrin Meji Ti O Dọwọ Ara Wọn Mu: adúláwọ̀ àtiamọ́láwọ̀ díẹ̀',
    '👩🏿‍🤝‍👩🏾' => 'Obinrin Meji Ti O Dọwọ Ara Wọn Mu: adúláwọ̀ àtiadúláwọ̀ díẹ̀',
    '👩🏻‍🤝‍👨🏼' => 'Ọkunrin Ati Obirin Ti O Dọwọ Ara Wọn Mu: amọ́lára àtiamọ́lára díẹ̀',
    '👩🏻‍🤝‍👨🏽' => 'Ọkunrin Ati Obirin Ti O Dọwọ Ara Wọn Mu: amọ́lára àtiamọ́láwọ̀ díẹ̀',
    '👩🏻‍🤝‍👨🏾' => 'Ọkunrin Ati Obirin Ti O Dọwọ Ara Wọn Mu: amọ́lára àtiadúláwọ̀ díẹ̀',
    '👩🏻‍🤝‍👨🏿' => 'Ọkunrin Ati Obirin Ti O Dọwọ Ara Wọn Mu: amọ́lára àtiadúláwọ̀',
    '👩🏼‍🤝‍👨🏻' => 'Ọkunrin Ati Obirin Ti O Dọwọ Ara Wọn Mu: amọ́lára díẹ̀ àtiamọ́lára',
    '👩🏼‍🤝‍👨🏽' => 'Ọkunrin Ati Obirin Ti O Dọwọ Ara Wọn Mu: amọ́lára díẹ̀ àtiamọ́láwọ̀ díẹ̀',
    '👩🏼‍🤝‍👨🏾' => 'Ọkunrin Ati Obirin Ti O Dọwọ Ara Wọn Mu: amọ́lára díẹ̀ àtiadúláwọ̀ díẹ̀',
    '👩🏼‍🤝‍👨🏿' => 'Ọkunrin Ati Obirin Ti O Dọwọ Ara Wọn Mu: amọ́lára díẹ̀ àtiadúláwọ̀',
    '👩🏽‍🤝‍👨🏻' => 'Ọkunrin Ati Obirin Ti O Dọwọ Ara Wọn Mu: amọ́láwọ̀ díẹ̀ àtiamọ́lára',
    '👩🏽‍🤝‍👨🏼' => 'Ọkunrin Ati Obirin Ti O Dọwọ Ara Wọn Mu: amọ́láwọ̀ díẹ̀ àtiamọ́lára díẹ̀',
    '👩🏽‍🤝‍👨🏾' => 'Ọkunrin Ati Obirin Ti O Dọwọ Ara Wọn Mu: amọ́láwọ̀ díẹ̀ àtiadúláwọ̀ díẹ̀',
    '👩🏽‍🤝‍👨🏿' => 'Ọkunrin Ati Obirin Ti O Dọwọ Ara Wọn Mu: amọ́láwọ̀ díẹ̀ àtiadúláwọ̀',
    '👩🏾‍🤝‍👨🏻' => 'Ọkunrin Ati Obirin Ti O Dọwọ Ara Wọn Mu: adúláwọ̀ díẹ̀ àtiamọ́lára',
    '👩🏾‍🤝‍👨🏼' => 'Ọkunrin Ati Obirin Ti O Dọwọ Ara Wọn Mu: adúláwọ̀ díẹ̀ àtiamọ́lára díẹ̀',
    '👩🏾‍🤝‍👨🏽' => 'Ọkunrin Ati Obirin Ti O Dọwọ Ara Wọn Mu: adúláwọ̀ díẹ̀ àtiamọ́láwọ̀ díẹ̀',
    '👩🏾‍🤝‍👨🏿' => 'Ọkunrin Ati Obirin Ti O Dọwọ Ara Wọn Mu: adúláwọ̀ díẹ̀ àtiadúláwọ̀',
    '👩🏿‍🤝‍👨🏻' => 'Ọkunrin Ati Obirin Ti O Dọwọ Ara Wọn Mu: adúláwọ̀ àtiamọ́lára',
    '👩🏿‍🤝‍👨🏼' => 'Ọkunrin Ati Obirin Ti O Dọwọ Ara Wọn Mu: adúláwọ̀ àtiamọ́lára díẹ̀',
    '👩🏿‍🤝‍👨🏽' => 'Ọkunrin Ati Obirin Ti O Dọwọ Ara Wọn Mu: adúláwọ̀ àtiamọ́láwọ̀ díẹ̀',
    '👩🏿‍🤝‍👨🏾' => 'Ọkunrin Ati Obirin Ti O Dọwọ Ara Wọn Mu: adúláwọ̀ àtiadúláwọ̀ díẹ̀',
    '👨🏻‍🤝‍👨🏼' => 'Ọkunrin Meji Ti O Dọwọ Ara Wọn Mu: amọ́lára àtiamọ́lára díẹ̀',
    '👨🏻‍🤝‍👨🏽' => 'Ọkunrin Meji Ti O Dọwọ Ara Wọn Mu: amọ́lára àtiamọ́láwọ̀ díẹ̀',
    '👨🏻‍🤝‍👨🏾' => 'Ọkunrin Meji Ti O Dọwọ Ara Wọn Mu: amọ́lára àtiadúláwọ̀ díẹ̀',
    '👨🏻‍🤝‍👨🏿' => 'Ọkunrin Meji Ti O Dọwọ Ara Wọn Mu: amọ́lára àtiadúláwọ̀',
    '👨🏼‍🤝‍👨🏻' => 'Ọkunrin Meji Ti O Dọwọ Ara Wọn Mu: amọ́lára díẹ̀ àtiamọ́lára',
    '👨🏼‍🤝‍👨🏽' => 'Ọkunrin Meji Ti O Dọwọ Ara Wọn Mu: amọ́lára díẹ̀ àtiamọ́láwọ̀ díẹ̀',
    '👨🏼‍🤝‍👨🏾' => 'Ọkunrin Meji Ti O Dọwọ Ara Wọn Mu: amọ́lára díẹ̀ àtiadúláwọ̀ díẹ̀',
    '👨🏼‍🤝‍👨🏿' => 'Ọkunrin Meji Ti O Dọwọ Ara Wọn Mu: amọ́lára díẹ̀ àtiadúláwọ̀',
    '👨🏽‍🤝‍👨🏻' => 'Ọkunrin Meji Ti O Dọwọ Ara Wọn Mu: amọ́láwọ̀ díẹ̀ àtiamọ́lára',
    '👨🏽‍🤝‍👨🏼' => 'Ọkunrin Meji Ti O Dọwọ Ara Wọn Mu: amọ́láwọ̀ díẹ̀ àtiamọ́lára díẹ̀',
    '👨🏽‍🤝‍👨🏾' => 'Ọkunrin Meji Ti O Dọwọ Ara Wọn Mu: amọ́láwọ̀ díẹ̀ àtiadúláwọ̀ díẹ̀',
    '👨🏽‍🤝‍👨🏿' => 'Ọkunrin Meji Ti O Dọwọ Ara Wọn Mu: amọ́láwọ̀ díẹ̀ àtiadúláwọ̀',
    '👨🏾‍🤝‍👨🏻' => 'Ọkunrin Meji Ti O Dọwọ Ara Wọn Mu: adúláwọ̀ díẹ̀ àtiamọ́lára',
    '👨🏾‍🤝‍👨🏼' => 'Ọkunrin Meji Ti O Dọwọ Ara Wọn Mu: adúláwọ̀ díẹ̀ àtiamọ́lára díẹ̀',
    '👨🏾‍🤝‍👨🏽' => 'Ọkunrin Meji Ti O Dọwọ Ara Wọn Mu: adúláwọ̀ díẹ̀ àtiamọ́láwọ̀ díẹ̀',
    '👨🏾‍🤝‍👨🏿' => 'Ọkunrin Meji Ti O Dọwọ Ara Wọn Mu: adúláwọ̀ díẹ̀ àtiadúláwọ̀',
    '👨🏿‍🤝‍👨🏻' => 'Ọkunrin Meji Ti O Dọwọ Ara Wọn Mu: adúláwọ̀ àtiamọ́lára',
    '👨🏿‍🤝‍👨🏼' => 'Ọkunrin Meji Ti O Dọwọ Ara Wọn Mu: adúláwọ̀ àtiamọ́lára díẹ̀',
    '👨🏿‍🤝‍👨🏽' => 'Ọkunrin Meji Ti O Dọwọ Ara Wọn Mu: adúláwọ̀ àtiamọ́láwọ̀ díẹ̀',
    '👨🏿‍🤝‍👨🏾' => 'Ọkunrin Meji Ti O Dọwọ Ara Wọn Mu: adúláwọ̀ àtiadúláwọ̀ díẹ̀',
    '👩‍❤‍💋‍👨' => 'Ifẹnuko: Obìnrin àtiỌkùnrin',
    '👨‍❤‍💋‍👨' => 'Ifẹnuko: Ọkùnrin àtiỌkùnrin',
    '👩‍❤‍💋‍👩' => 'Ifẹnuko: Obìnrin àtiObìnrin',
    '👨‍👩‍👧‍👦' => 'Ẹbí: Ọkùnrin, Obìnrin, ọmọbìrin, ọmọkùnrin',
    '👨‍👩‍👦‍👦' => 'Ẹbí: Ọkùnrin, Obìnrin, ọmọkùnrin, ọmọkùnrin',
    '👨‍👩‍👧‍👧' => 'Ẹbí: Ọkùnrin, Obìnrin, ọmọbìrin, ọmọbìrin',
    '👨‍👨‍👧‍👦' => 'Ẹbí: Ọkùnrin, Ọkùnrin, ọmọbìrin, ọmọkùnrin',
    '👨‍👨‍👦‍👦' => 'Ẹbí: Ọkùnrin, Ọkùnrin, ọmọkùnrin, ọmọkùnrin',
    '👨‍👨‍👧‍👧' => 'Ẹbí: Ọkùnrin, Ọkùnrin, ọmọbìrin, ọmọbìrin',
    '👩‍👩‍👧‍👦' => 'Ẹbí: Obìnrin, Obìnrin, ọmọbìrin, ọmọkùnrin',
    '👩‍👩‍👦‍👦' => 'Ẹbí: Obìnrin, Obìnrin, ọmọkùnrin, ọmọkùnrin',
    '👩‍👩‍👧‍👧' => 'Ẹbí: Obìnrin, Obìnrin, ọmọbìrin, ọmọbìrin',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'filaagi: Ilẹ̀gẹ̀ẹ́sì',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'filaagi: Skọ́tlándì',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'filaagi: Wélsì',
    '🧑‍🧑‍🧒‍🧒' => 'ìdílé: àgbàlagbà, àgbàlagbà, ọmọdé, ọmọdé',
    '🚶🏻‍♀‍➡' => 'obìnrin tí ń rìn: amọ́lára àtiìdojúkọ ọ̀tún',
    '🚶🏼‍♀‍➡' => 'obìnrin tí ń rìn: amọ́lára díẹ̀ àtiìdojúkọ ọ̀tún',
    '🚶🏽‍♀‍➡' => 'obìnrin tí ń rìn: amọ́láwọ̀ díẹ̀ àtiìdojúkọ ọ̀tún',
    '🚶🏾‍♀‍➡' => 'obìnrin tí ń rìn: adúláwọ̀ díẹ̀ àtiìdojúkọ ọ̀tún',
    '🚶🏿‍♀‍➡' => 'obìnrin tí ń rìn: adúláwọ̀ àtiìdojúkọ ọ̀tún',
    '🚶🏻‍♂‍➡' => 'ọkùnrin tí ń rìn: amọ́lára àtiìdojúkọ ọ̀tún',
    '🚶🏼‍♂‍➡' => 'ọkùnrin tí ń rìn: amọ́lára díẹ̀ àtiìdojúkọ ọ̀tún',
    '🚶🏽‍♂‍➡' => 'ọkùnrin tí ń rìn: amọ́láwọ̀ díẹ̀ àtiìdojúkọ ọ̀tún',
    '🚶🏾‍♂‍➡' => 'ọkùnrin tí ń rìn: adúláwọ̀ díẹ̀ àtiìdojúkọ ọ̀tún',
    '🚶🏿‍♂‍➡' => 'ọkùnrin tí ń rìn: adúláwọ̀ àtiìdojúkọ ọ̀tún',
    '🧎🏻‍♀‍➡' => 'obìnrin tó kúnlẹ̀: amọ́lára àtiìdojúkọ ọ̀tún',
    '🧎🏼‍♀‍➡' => 'obìnrin tó kúnlẹ̀: amọ́lára díẹ̀ àtiìdojúkọ ọ̀tún',
    '🧎🏽‍♀‍➡' => 'obìnrin tó kúnlẹ̀: amọ́láwọ̀ díẹ̀ àtiìdojúkọ ọ̀tún',
    '🧎🏾‍♀‍➡' => 'obìnrin tó kúnlẹ̀: adúláwọ̀ díẹ̀ àtiìdojúkọ ọ̀tún',
    '🧎🏿‍♀‍➡' => 'obìnrin tó kúnlẹ̀: adúláwọ̀ àtiìdojúkọ ọ̀tún',
    '🧎🏻‍♂‍➡' => 'ọkùnrin tó kúnlẹ̀: amọ́lára àtiìdojúkọ ọ̀tún',
    '🧎🏼‍♂‍➡' => 'ọkùnrin tó kúnlẹ̀: amọ́lára díẹ̀ àtiìdojúkọ ọ̀tún',
    '🧎🏽‍♂‍➡' => 'ọkùnrin tó kúnlẹ̀: amọ́láwọ̀ díẹ̀ àtiìdojúkọ ọ̀tún',
    '🧎🏾‍♂‍➡' => 'ọkùnrin tó kúnlẹ̀: adúláwọ̀ díẹ̀ àtiìdojúkọ ọ̀tún',
    '🧎🏿‍♂‍➡' => 'ọkùnrin tó kúnlẹ̀: adúláwọ̀ àtiìdojúkọ ọ̀tún',
    '🧑🏻‍🦯‍➡' => 'ènìyàn pẹ̀lú ọ̀pá funfun: amọ́lára àtiìdojúkọ ọ̀tún',
    '🧑🏼‍🦯‍➡' => 'ènìyàn pẹ̀lú ọ̀pá funfun: amọ́lára díẹ̀ àtiìdojúkọ ọ̀tún',
    '🧑🏽‍🦯‍➡' => 'ènìyàn pẹ̀lú ọ̀pá funfun: amọ́láwọ̀ díẹ̀ àtiìdojúkọ ọ̀tún',
    '🧑🏾‍🦯‍➡' => 'ènìyàn pẹ̀lú ọ̀pá funfun: adúláwọ̀ díẹ̀ àtiìdojúkọ ọ̀tún',
    '🧑🏿‍🦯‍➡' => 'ènìyàn pẹ̀lú ọ̀pá funfun: adúláwọ̀ àtiìdojúkọ ọ̀tún',
    '👨🏻‍🦯‍➡' => 'ọkùnrin pẹ̀lú ọ̀pá funfun: amọ́lára àtiìdojúkọ ọ̀tún',
    '👨🏼‍🦯‍➡' => 'ọkùnrin pẹ̀lú ọ̀pá funfun: amọ́lára díẹ̀ àtiìdojúkọ ọ̀tún',
    '👨🏽‍🦯‍➡' => 'ọkùnrin pẹ̀lú ọ̀pá funfun: amọ́láwọ̀ díẹ̀ àtiìdojúkọ ọ̀tún',
    '👨🏾‍🦯‍➡' => 'ọkùnrin pẹ̀lú ọ̀pá funfun: adúláwọ̀ díẹ̀ àtiìdojúkọ ọ̀tún',
    '👨🏿‍🦯‍➡' => 'ọkùnrin pẹ̀lú ọ̀pá funfun: adúláwọ̀ àtiìdojúkọ ọ̀tún',
    '👩🏻‍🦯‍➡' => 'obìnrin pẹ̀lú ọ̀pá funfun: amọ́lára àtiìdojúkọ ọ̀tún',
    '👩🏼‍🦯‍➡' => 'obìnrin pẹ̀lú ọ̀pá funfun: amọ́lára díẹ̀ àtiìdojúkọ ọ̀tún',
    '👩🏽‍🦯‍➡' => 'obìnrin pẹ̀lú ọ̀pá funfun: amọ́láwọ̀ díẹ̀ àtiìdojúkọ ọ̀tún',
    '👩🏾‍🦯‍➡' => 'obìnrin pẹ̀lú ọ̀pá funfun: adúláwọ̀ díẹ̀ àtiìdojúkọ ọ̀tún',
    '👩🏿‍🦯‍➡' => 'obìnrin pẹ̀lú ọ̀pá funfun: adúláwọ̀ àtiìdojúkọ ọ̀tún',
    '🧑🏻‍🦼‍➡' => 'ènìyàn nínú kẹ̀kẹ́-abirùn ẹlẹ́rọ-mọ́tò: amọ́lára àtiìdojúkọ ọ̀tún',
    '🧑🏼‍🦼‍➡' => 'ènìyàn nínú kẹ̀kẹ́-abirùn ẹlẹ́rọ-mọ́tò: amọ́lára díẹ̀ àtiìdojúkọ ọ̀tún',
    '🧑🏽‍🦼‍➡' => 'ènìyàn nínú kẹ̀kẹ́-abirùn ẹlẹ́rọ-mọ́tò: amọ́láwọ̀ díẹ̀ àtiìdojúkọ ọ̀tún',
    '🧑🏾‍🦼‍➡' => 'ènìyàn nínú kẹ̀kẹ́-abirùn ẹlẹ́rọ-mọ́tò: adúláwọ̀ díẹ̀ àtiìdojúkọ ọ̀tún',
    '🧑🏿‍🦼‍➡' => 'ènìyàn nínú kẹ̀kẹ́-abirùn ẹlẹ́rọ-mọ́tò: adúláwọ̀ àtiìdojúkọ ọ̀tún',
    '👨🏻‍🦼‍➡' => 'ọkùnrin nínú kẹ̀kẹ́-abirùn ẹlẹ́rọ-mọ́tò: amọ́lára àtiìdojúkọ ọ̀tún',
    '👨🏼‍🦼‍➡' => 'ọkùnrin nínú kẹ̀kẹ́-abirùn ẹlẹ́rọ-mọ́tò: amọ́lára díẹ̀ àtiìdojúkọ ọ̀tún',
    '👨🏽‍🦼‍➡' => 'ọkùnrin nínú kẹ̀kẹ́-abirùn ẹlẹ́rọ-mọ́tò: amọ́láwọ̀ díẹ̀ àtiìdojúkọ ọ̀tún',
    '👨🏾‍🦼‍➡' => 'ọkùnrin nínú kẹ̀kẹ́-abirùn ẹlẹ́rọ-mọ́tò: adúláwọ̀ díẹ̀ àtiìdojúkọ ọ̀tún',
    '👨🏿‍🦼‍➡' => 'ọkùnrin nínú kẹ̀kẹ́-abirùn ẹlẹ́rọ-mọ́tò: adúláwọ̀ àtiìdojúkọ ọ̀tún',
    '👩🏻‍🦼‍➡' => 'obìnrin nínú kẹ̀kẹ́-abirùn ẹlẹ́rọ-mọ́tò: amọ́lára àtiìdojúkọ ọ̀tún',
    '👩🏼‍🦼‍➡' => 'obìnrin nínú kẹ̀kẹ́-abirùn ẹlẹ́rọ-mọ́tò: amọ́lára díẹ̀ àtiìdojúkọ ọ̀tún',
    '👩🏽‍🦼‍➡' => 'obìnrin nínú kẹ̀kẹ́-abirùn ẹlẹ́rọ-mọ́tò: amọ́láwọ̀ díẹ̀ àtiìdojúkọ ọ̀tún',
    '👩🏾‍🦼‍➡' => 'obìnrin nínú kẹ̀kẹ́-abirùn ẹlẹ́rọ-mọ́tò: adúláwọ̀ díẹ̀ àtiìdojúkọ ọ̀tún',
    '👩🏿‍🦼‍➡' => 'obìnrin nínú kẹ̀kẹ́-abirùn ẹlẹ́rọ-mọ́tò: adúláwọ̀ àtiìdojúkọ ọ̀tún',
    '🧑🏻‍🦽‍➡' => 'ènìyàn nínú kẹ̀kẹ́-abirùn aláfọwọ́yí: amọ́lára àtiìdojúkọ ọ̀tún',
    '🧑🏼‍🦽‍➡' => 'ènìyàn nínú kẹ̀kẹ́-abirùn aláfọwọ́yí: amọ́lára díẹ̀ àtiìdojúkọ ọ̀tún',
    '🧑🏽‍🦽‍➡' => 'ènìyàn nínú kẹ̀kẹ́-abirùn aláfọwọ́yí: amọ́láwọ̀ díẹ̀ àtiìdojúkọ ọ̀tún',
    '🧑🏾‍🦽‍➡' => 'ènìyàn nínú kẹ̀kẹ́-abirùn aláfọwọ́yí: adúláwọ̀ díẹ̀ àtiìdojúkọ ọ̀tún',
    '🧑🏿‍🦽‍➡' => 'ènìyàn nínú kẹ̀kẹ́-abirùn aláfọwọ́yí: adúláwọ̀ àtiìdojúkọ ọ̀tún',
    '👨🏻‍🦽‍➡' => 'ọkùnrin nínú kẹ̀kẹ́-abirùn aláfọwọ́yí: amọ́lára àtiìdojúkọ ọ̀tún',
    '👨🏼‍🦽‍➡' => 'ọkùnrin nínú kẹ̀kẹ́-abirùn aláfọwọ́yí: amọ́lára díẹ̀ àtiìdojúkọ ọ̀tún',
    '👨🏽‍🦽‍➡' => 'ọkùnrin nínú kẹ̀kẹ́-abirùn aláfọwọ́yí: amọ́láwọ̀ díẹ̀ àtiìdojúkọ ọ̀tún',
    '👨🏾‍🦽‍➡' => 'ọkùnrin nínú kẹ̀kẹ́-abirùn aláfọwọ́yí: adúláwọ̀ díẹ̀ àtiìdojúkọ ọ̀tún',
    '👨🏿‍🦽‍➡' => 'ọkùnrin nínú kẹ̀kẹ́-abirùn aláfọwọ́yí: adúláwọ̀ àtiìdojúkọ ọ̀tún',
    '👩🏻‍🦽‍➡' => 'obìnrin nínú kẹ̀kẹ́-abirùn aláfọwọ́yí: amọ́lára àtiìdojúkọ ọ̀tún',
    '👩🏼‍🦽‍➡' => 'obìnrin nínú kẹ̀kẹ́-abirùn aláfọwọ́yí: amọ́lára díẹ̀ àtiìdojúkọ ọ̀tún',
    '👩🏽‍🦽‍➡' => 'obìnrin nínú kẹ̀kẹ́-abirùn aláfọwọ́yí: amọ́láwọ̀ díẹ̀ àtiìdojúkọ ọ̀tún',
    '👩🏾‍🦽‍➡' => 'obìnrin nínú kẹ̀kẹ́-abirùn aláfọwọ́yí: adúláwọ̀ díẹ̀ àtiìdojúkọ ọ̀tún',
    '👩🏿‍🦽‍➡' => 'obìnrin nínú kẹ̀kẹ́-abirùn aláfọwọ́yí: adúláwọ̀ àtiìdojúkọ ọ̀tún',
    '🏃🏻‍♀‍➡' => 'obìrin tí ń sáré: amọ́lára àtiìdojúkọ ọ̀tún',
    '🏃🏼‍♀‍➡' => 'obìrin tí ń sáré: amọ́lára díẹ̀ àtiìdojúkọ ọ̀tún',
    '🏃🏽‍♀‍➡' => 'obìrin tí ń sáré: amọ́láwọ̀ díẹ̀ àtiìdojúkọ ọ̀tún',
    '🏃🏾‍♀‍➡' => 'obìrin tí ń sáré: adúláwọ̀ díẹ̀ àtiìdojúkọ ọ̀tún',
    '🏃🏿‍♀‍➡' => 'obìrin tí ń sáré: adúláwọ̀ àtiìdojúkọ ọ̀tún',
    '🏃🏻‍♂‍➡' => 'ọkùnrin tí ń sáré: amọ́lára àtiìdojúkọ ọ̀tún',
    '🏃🏼‍♂‍➡' => 'ọkùnrin tí ń sáré: amọ́lára díẹ̀ àtiìdojúkọ ọ̀tún',
    '🏃🏽‍♂‍➡' => 'ọkùnrin tí ń sáré: amọ́láwọ̀ díẹ̀ àtiìdojúkọ ọ̀tún',
    '🏃🏾‍♂‍➡' => 'ọkùnrin tí ń sáré: adúláwọ̀ díẹ̀ àtiìdojúkọ ọ̀tún',
    '🏃🏿‍♂‍➡' => 'ọkùnrin tí ń sáré: adúláwọ̀ àtiìdojúkọ ọ̀tún',
    '🫱🏻‍🫲🏼' => 'Ìbọwọ́: amọ́lára àtiamọ́lára díẹ̀',
    '🫱🏻‍🫲🏽' => 'Ìbọwọ́: amọ́lára àtiamọ́láwọ̀ díẹ̀',
    '🫱🏻‍🫲🏾' => 'Ìbọwọ́: amọ́lára àtiadúláwọ̀ díẹ̀',
    '🫱🏻‍🫲🏿' => 'Ìbọwọ́: amọ́lára àtiadúláwọ̀',
    '🫱🏼‍🫲🏻' => 'Ìbọwọ́: amọ́lára díẹ̀ àtiamọ́lára',
    '🫱🏼‍🫲🏽' => 'Ìbọwọ́: amọ́lára díẹ̀ àtiamọ́láwọ̀ díẹ̀',
    '🫱🏼‍🫲🏾' => 'Ìbọwọ́: amọ́lára díẹ̀ àtiadúláwọ̀ díẹ̀',
    '🫱🏼‍🫲🏿' => 'Ìbọwọ́: amọ́lára díẹ̀ àtiadúláwọ̀',
    '🫱🏽‍🫲🏻' => 'Ìbọwọ́: amọ́láwọ̀ díẹ̀ àtiamọ́lára',
    '🫱🏽‍🫲🏼' => 'Ìbọwọ́: amọ́láwọ̀ díẹ̀ àtiamọ́lára díẹ̀',
    '🫱🏽‍🫲🏾' => 'Ìbọwọ́: amọ́láwọ̀ díẹ̀ àtiadúláwọ̀ díẹ̀',
    '🫱🏽‍🫲🏿' => 'Ìbọwọ́: amọ́láwọ̀ díẹ̀ àtiadúláwọ̀',
    '🫱🏾‍🫲🏻' => 'Ìbọwọ́: adúláwọ̀ díẹ̀ àtiamọ́lára',
    '🫱🏾‍🫲🏼' => 'Ìbọwọ́: adúláwọ̀ díẹ̀ àtiamọ́lára díẹ̀',
    '🫱🏾‍🫲🏽' => 'Ìbọwọ́: adúláwọ̀ díẹ̀ àtiamọ́láwọ̀ díẹ̀',
    '🫱🏾‍🫲🏿' => 'Ìbọwọ́: adúláwọ̀ díẹ̀ àtiadúláwọ̀',
    '🫱🏿‍🫲🏻' => 'Ìbọwọ́: adúláwọ̀ àtiamọ́lára',
    '🫱🏿‍🫲🏼' => 'Ìbọwọ́: adúláwọ̀ àtiamọ́lára díẹ̀',
    '🫱🏿‍🫲🏽' => 'Ìbọwọ́: adúláwọ̀ àtiamọ́láwọ̀ díẹ̀',
    '🫱🏿‍🫲🏾' => 'Ìbọwọ́: adúláwọ̀ àtiadúláwọ̀ díẹ̀',
    '🚶‍♀‍➡' => 'obìnrin tí ń rìn: ìdojúkọ ọ̀tún',
    '🚶‍♂‍➡' => 'ọkùnrin tí ń rìn: ìdojúkọ ọ̀tún',
    '🧎‍♀‍➡' => 'obìnrin tó kúnlẹ̀: ìdojúkọ ọ̀tún',
    '🧎‍♂‍➡' => 'ọkùnrin tó kúnlẹ̀: ìdojúkọ ọ̀tún',
    '🧑‍🦯‍➡' => 'ènìyàn pẹ̀lú ọ̀pá funfun: ìdojúkọ ọ̀tún',
    '👨‍🦯‍➡' => 'ọkùnrin pẹ̀lú ọ̀pá funfun: ìdojúkọ ọ̀tún',
    '👩‍🦯‍➡' => 'obìnrin pẹ̀lú ọ̀pá funfun: ìdojúkọ ọ̀tún',
    '🧑‍🦼‍➡' => 'ènìyàn nínú kẹ̀kẹ́-abirùn ẹlẹ́rọ-mọ́tò: ìdojúkọ ọ̀tún',
    '👨‍🦼‍➡' => 'ọkùnrin nínú kẹ̀kẹ́-abirùn ẹlẹ́rọ-mọ́tò: ìdojúkọ ọ̀tún',
    '👩‍🦼‍➡' => 'obìnrin nínú kẹ̀kẹ́-abirùn ẹlẹ́rọ-mọ́tò: ìdojúkọ ọ̀tún',
    '🧑‍🦽‍➡' => 'ènìyàn nínú kẹ̀kẹ́-abirùn aláfọwọ́yí: ìdojúkọ ọ̀tún',
    '👨‍🦽‍➡' => 'ọkùnrin nínú kẹ̀kẹ́-abirùn aláfọwọ́yí: ìdojúkọ ọ̀tún',
    '👩‍🦽‍➡' => 'obìnrin nínú kẹ̀kẹ́-abirùn aláfọwọ́yí: ìdojúkọ ọ̀tún',
    '🏃‍♀‍➡' => 'obìrin tí ń sáré: ìdojúkọ ọ̀tún',
    '🏃‍♂‍➡' => 'ọkùnrin tí ń sáré: ìdojúkọ ọ̀tún',
    '👩‍❤‍👨' => 'Lọkọlaya Pẹlu ọkan: Obìnrin àtiỌkùnrin',
    '👨‍❤‍👨' => 'Lọkọlaya Pẹlu ọkan: Ọkùnrin àtiỌkùnrin',
    '👩‍❤‍👩' => 'Lọkọlaya Pẹlu ọkan: Obìnrin àtiObìnrin',
    '👨‍👩‍👦' => 'Ẹbí: Ọkùnrin, Obìnrin, ọmọkùnrin',
    '👨‍👩‍👧' => 'Ẹbí: Ọkùnrin, Obìnrin, ọmọbìrin',
    '👨‍👨‍👦' => 'Ẹbí: Ọkùnrin, Ọkùnrin, ọmọkùnrin',
    '👨‍👨‍👧' => 'Ẹbí: Ọkùnrin, Ọkùnrin, ọmọbìrin',
    '👩‍👩‍👦' => 'Ẹbí: Obìnrin, Obìnrin, ọmọkùnrin',
    '👩‍👩‍👧' => 'Ẹbí: Obìnrin, Obìnrin, ọmọbìrin',
    '👨‍👦‍👦' => 'Ẹbí: Ọkùnrin, ọmọkùnrin, ọmọkùnrin',
    '👨‍👧‍👦' => 'Ẹbí: Ọkùnrin, ọmọbìrin, ọmọkùnrin',
    '👨‍👧‍👧' => 'Ẹbí: Ọkùnrin, ọmọbìrin, ọmọbìrin',
    '👩‍👦‍👦' => 'Ẹbí: Obìnrin, ọmọkùnrin, ọmọkùnrin',
    '👩‍👧‍👦' => 'Ẹbí: Obìnrin, ọmọbìrin, ọmọkùnrin',
    '👩‍👧‍👧' => 'Ẹbí: Obìnrin, ọmọbìrin, ọmọbìrin',
    '🧑‍🤝‍🧑' => 'àwọn ènìyàn tó di ara wọn lọ́wọ́ mú',
    '🧑‍🧑‍🧒' => 'ìdílé: àgbàlagbà, àgbàlagbà, ọmọdé',
    '🧑‍🧒‍🧒' => 'ìdílé: àgbàlagbà, ọmọdé, ọmọdé',
    '🧑🏻‍🦰' => 'àgbà: amọ́lára àtiirun pupa',
    '🧑🏼‍🦰' => 'àgbà: amọ́lára díẹ̀ àtiirun pupa',
    '🧑🏽‍🦰' => 'àgbà: amọ́láwọ̀ díẹ̀ àtiirun pupa',
    '🧑🏾‍🦰' => 'àgbà: adúláwọ̀ díẹ̀ àtiirun pupa',
    '🧑🏿‍🦰' => 'àgbà: adúláwọ̀ àtiirun pupa',
    '🧑🏻‍🦱' => 'àgbà: amọ́lára àtiirun rírọ̀',
    '🧑🏼‍🦱' => 'àgbà: amọ́lára díẹ̀ àtiirun rírọ̀',
    '🧑🏽‍🦱' => 'àgbà: amọ́láwọ̀ díẹ̀ àtiirun rírọ̀',
    '🧑🏾‍🦱' => 'àgbà: adúláwọ̀ díẹ̀ àtiirun rírọ̀',
    '🧑🏿‍🦱' => 'àgbà: adúláwọ̀ àtiirun rírọ̀',
    '🧑🏻‍🦳' => 'àgbà: amọ́lára àtiirun funfun',
    '🧑🏼‍🦳' => 'àgbà: amọ́lára díẹ̀ àtiirun funfun',
    '🧑🏽‍🦳' => 'àgbà: amọ́láwọ̀ díẹ̀ àtiirun funfun',
    '🧑🏾‍🦳' => 'àgbà: adúláwọ̀ díẹ̀ àtiirun funfun',
    '🧑🏿‍🦳' => 'àgbà: adúláwọ̀ àtiirun funfun',
    '🧑🏻‍🦲' => 'àgbà: amọ́lára àtiorí pípá',
    '🧑🏼‍🦲' => 'àgbà: amọ́lára díẹ̀ àtiorí pípá',
    '🧑🏽‍🦲' => 'àgbà: amọ́láwọ̀ díẹ̀ àtiorí pípá',
    '🧑🏾‍🦲' => 'àgbà: adúláwọ̀ díẹ̀ àtiorí pípá',
    '🧑🏿‍🦲' => 'àgbà: adúláwọ̀ àtiorí pípá',
    '🧑🏻‍🩰' => 'oníjó alájòóyípo: amọ́lára',
    '🧑🏼‍🩰' => 'oníjó alájòóyípo: amọ́lára díẹ̀',
    '🧑🏽‍🩰' => 'oníjó alájòóyípo: amọ́láwọ̀ díẹ̀',
    '🧑🏾‍🩰' => 'oníjó alájòóyípo: adúláwọ̀ díẹ̀',
    '🧑🏿‍🩰' => 'oníjó alájòóyípo: adúláwọ̀',
    '🧔🏻‍♂' => 'ọkùnrin: amọ́lára àtiirùgbọ̀n',
    '🧔🏼‍♂' => 'ọkùnrin: amọ́lára díẹ̀ àtiirùgbọ̀n',
    '🧔🏽‍♂' => 'ọkùnrin: amọ́láwọ̀ díẹ̀ àtiirùgbọ̀n',
    '🧔🏾‍♂' => 'ọkùnrin: adúláwọ̀ díẹ̀ àtiirùgbọ̀n',
    '🧔🏿‍♂' => 'ọkùnrin: adúláwọ̀ àtiirùgbọ̀n',
    '👱🏻‍♂' => 'ọkùnrin onírun funfun: amọ́lára',
    '👱🏼‍♂' => 'ọkùnrin onírun funfun: amọ́lára díẹ̀',
    '👱🏽‍♂' => 'ọkùnrin onírun funfun: amọ́láwọ̀ díẹ̀',
    '👱🏾‍♂' => 'ọkùnrin onírun funfun: adúláwọ̀ díẹ̀',
    '👱🏿‍♂' => 'ọkùnrin onírun funfun: adúláwọ̀',
    '👨🏻‍🦰' => 'Ọkùnrin: amọ́lára àtiirun pupa',
    '👨🏼‍🦰' => 'Ọkùnrin: amọ́lára díẹ̀ àtiirun pupa',
    '👨🏽‍🦰' => 'Ọkùnrin: amọ́láwọ̀ díẹ̀ àtiirun pupa',
    '👨🏾‍🦰' => 'Ọkùnrin: adúláwọ̀ díẹ̀ àtiirun pupa',
    '👨🏿‍🦰' => 'Ọkùnrin: adúláwọ̀ àtiirun pupa',
    '👨🏻‍🦱' => 'Ọkùnrin: amọ́lára àtiirun rírọ̀',
    '👨🏼‍🦱' => 'Ọkùnrin: amọ́lára díẹ̀ àtiirun rírọ̀',
    '👨🏽‍🦱' => 'Ọkùnrin: amọ́láwọ̀ díẹ̀ àtiirun rírọ̀',
    '👨🏾‍🦱' => 'Ọkùnrin: adúláwọ̀ díẹ̀ àtiirun rírọ̀',
    '👨🏿‍🦱' => 'Ọkùnrin: adúláwọ̀ àtiirun rírọ̀',
    '👨🏻‍🦳' => 'Ọkùnrin: amọ́lára àtiirun funfun',
    '👨🏼‍🦳' => 'Ọkùnrin: amọ́lára díẹ̀ àtiirun funfun',
    '👨🏽‍🦳' => 'Ọkùnrin: amọ́láwọ̀ díẹ̀ àtiirun funfun',
    '👨🏾‍🦳' => 'Ọkùnrin: adúláwọ̀ díẹ̀ àtiirun funfun',
    '👨🏿‍🦳' => 'Ọkùnrin: adúláwọ̀ àtiirun funfun',
    '👨🏻‍🦲' => 'Ọkùnrin: amọ́lára àtiorí pípá',
    '👨🏼‍🦲' => 'Ọkùnrin: amọ́lára díẹ̀ àtiorí pípá',
    '👨🏽‍🦲' => 'Ọkùnrin: amọ́láwọ̀ díẹ̀ àtiorí pípá',
    '👨🏾‍🦲' => 'Ọkùnrin: adúláwọ̀ díẹ̀ àtiorí pípá',
    '👨🏿‍🦲' => 'Ọkùnrin: adúláwọ̀ àtiorí pípá',
    '🧔🏻‍♀' => 'obìnrin: amọ́lára àtiirùgbọ̀n',
    '🧔🏼‍♀' => 'obìnrin: amọ́lára díẹ̀ àtiirùgbọ̀n',
    '🧔🏽‍♀' => 'obìnrin: amọ́láwọ̀ díẹ̀ àtiirùgbọ̀n',
    '🧔🏾‍♀' => 'obìnrin: adúláwọ̀ díẹ̀ àtiirùgbọ̀n',
    '🧔🏿‍♀' => 'obìnrin: adúláwọ̀ àtiirùgbọ̀n',
    '👱🏻‍♀' => 'obìnrin onírun funfun: amọ́lára',
    '👱🏼‍♀' => 'obìnrin onírun funfun: amọ́lára díẹ̀',
    '👱🏽‍♀' => 'obìnrin onírun funfun: amọ́láwọ̀ díẹ̀',
    '👱🏾‍♀' => 'obìnrin onírun funfun: adúláwọ̀ díẹ̀',
    '👱🏿‍♀' => 'obìnrin onírun funfun: adúláwọ̀',
    '👩🏻‍🦰' => 'Obìnrin: amọ́lára àtiirun pupa',
    '👩🏼‍🦰' => 'Obìnrin: amọ́lára díẹ̀ àtiirun pupa',
    '👩🏽‍🦰' => 'Obìnrin: amọ́láwọ̀ díẹ̀ àtiirun pupa',
    '👩🏾‍🦰' => 'Obìnrin: adúláwọ̀ díẹ̀ àtiirun pupa',
    '👩🏿‍🦰' => 'Obìnrin: adúláwọ̀ àtiirun pupa',
    '👩🏻‍🦱' => 'Obìnrin: amọ́lára àtiirun rírọ̀',
    '👩🏼‍🦱' => 'Obìnrin: amọ́lára díẹ̀ àtiirun rírọ̀',
    '👩🏽‍🦱' => 'Obìnrin: amọ́láwọ̀ díẹ̀ àtiirun rírọ̀',
    '👩🏾‍🦱' => 'Obìnrin: adúláwọ̀ díẹ̀ àtiirun rírọ̀',
    '👩🏿‍🦱' => 'Obìnrin: adúláwọ̀ àtiirun rírọ̀',
    '👩🏻‍🦳' => 'Obìnrin: amọ́lára àtiirun funfun',
    '👩🏼‍🦳' => 'Obìnrin: amọ́lára díẹ̀ àtiirun funfun',
    '👩🏽‍🦳' => 'Obìnrin: amọ́láwọ̀ díẹ̀ àtiirun funfun',
    '👩🏾‍🦳' => 'Obìnrin: adúláwọ̀ díẹ̀ àtiirun funfun',
    '👩🏿‍🦳' => 'Obìnrin: adúláwọ̀ àtiirun funfun',
    '👩🏻‍🦲' => 'Obìnrin: amọ́lára àtiorí pípá',
    '👩🏼‍🦲' => 'Obìnrin: amọ́lára díẹ̀ àtiorí pípá',
    '👩🏽‍🦲' => 'Obìnrin: amọ́láwọ̀ díẹ̀ àtiorí pípá',
    '👩🏾‍🦲' => 'Obìnrin: adúláwọ̀ díẹ̀ àtiorí pípá',
    '👩🏿‍🦲' => 'Obìnrin: adúláwọ̀ àtiorí pípá',
    '🙍🏻‍♂' => 'ọkùnrin tí ń fajúro: amọ́lára',
    '🙍🏼‍♂' => 'ọkùnrin tí ń fajúro: amọ́lára díẹ̀',
    '🙍🏽‍♂' => 'ọkùnrin tí ń fajúro: amọ́láwọ̀ díẹ̀',
    '🙍🏾‍♂' => 'ọkùnrin tí ń fajúro: adúláwọ̀ díẹ̀',
    '🙍🏿‍♂' => 'ọkùnrin tí ń fajúro: adúláwọ̀',
    '🙍🏻‍♀' => 'obìnrin tí ń fajúro: amọ́lára',
    '🙍🏼‍♀' => 'obìnrin tí ń fajúro: amọ́lára díẹ̀',
    '🙍🏽‍♀' => 'obìnrin tí ń fajúro: amọ́láwọ̀ díẹ̀',
    '🙍🏾‍♀' => 'obìnrin tí ń fajúro: adúláwọ̀ díẹ̀',
    '🙍🏿‍♀' => 'obìnrin tí ń fajúro: adúláwọ̀',
    '🙎🏻‍♂' => 'ọkùnrin tí ń ṣíṣù ètè síta: amọ́lára',
    '🙎🏼‍♂' => 'ọkùnrin tí ń ṣíṣù ètè síta: amọ́lára díẹ̀',
    '🙎🏽‍♂' => 'ọkùnrin tí ń ṣíṣù ètè síta: amọ́láwọ̀ díẹ̀',
    '🙎🏾‍♂' => 'ọkùnrin tí ń ṣíṣù ètè síta: adúláwọ̀ díẹ̀',
    '🙎🏿‍♂' => 'ọkùnrin tí ń ṣíṣù ètè síta: adúláwọ̀',
    '🙎🏻‍♀' => 'obìnrin tí ń ṣíṣù ètè síta: amọ́lára',
    '🙎🏼‍♀' => 'obìnrin tí ń ṣíṣù ètè síta: amọ́lára díẹ̀',
    '🙎🏽‍♀' => 'obìnrin tí ń ṣíṣù ètè síta: amọ́láwọ̀ díẹ̀',
    '🙎🏾‍♀' => 'obìnrin tí ń ṣíṣù ètè síta: adúláwọ̀ díẹ̀',
    '🙎🏿‍♀' => 'obìnrin tí ń ṣíṣù ètè síta: adúláwọ̀',
    '🙅🏻‍♂' => 'ọkùnrin tí ń sọ RÁRÁ: amọ́lára',
    '🙅🏼‍♂' => 'ọkùnrin tí ń sọ RÁRÁ: amọ́lára díẹ̀',
    '🙅🏽‍♂' => 'ọkùnrin tí ń sọ RÁRÁ: amọ́láwọ̀ díẹ̀',
    '🙅🏾‍♂' => 'ọkùnrin tí ń sọ RÁRÁ: adúláwọ̀ díẹ̀',
    '🙅🏿‍♂' => 'ọkùnrin tí ń sọ RÁRÁ: adúláwọ̀',
    '🙅🏻‍♀' => 'obìnrin tí ń sọ RÁRÁ: amọ́lára',
    '🙅🏼‍♀' => 'obìnrin tí ń sọ RÁRÁ: amọ́lára díẹ̀',
    '🙅🏽‍♀' => 'obìnrin tí ń sọ RÁRÁ: amọ́láwọ̀ díẹ̀',
    '🙅🏾‍♀' => 'obìnrin tí ń sọ RÁRÁ: adúláwọ̀ díẹ̀',
    '🙅🏿‍♀' => 'obìnrin tí ń sọ RÁRÁ: adúláwọ̀',
    '🙆🏻‍♂' => 'ọkùnrin tí ń sọ ÓDÁRA: amọ́lára',
    '🙆🏼‍♂' => 'ọkùnrin tí ń sọ ÓDÁRA: amọ́lára díẹ̀',
    '🙆🏽‍♂' => 'ọkùnrin tí ń sọ ÓDÁRA: amọ́láwọ̀ díẹ̀',
    '🙆🏾‍♂' => 'ọkùnrin tí ń sọ ÓDÁRA: adúláwọ̀ díẹ̀',
    '🙆🏿‍♂' => 'ọkùnrin tí ń sọ ÓDÁRA: adúláwọ̀',
    '🙆🏻‍♀' => 'obìnrin tí ń sọ ÓDÁRA: amọ́lára',
    '🙆🏼‍♀' => 'obìnrin tí ń sọ ÓDÁRA: amọ́lára díẹ̀',
    '🙆🏽‍♀' => 'obìnrin tí ń sọ ÓDÁRA: amọ́láwọ̀ díẹ̀',
    '🙆🏾‍♀' => 'obìnrin tí ń sọ ÓDÁRA: adúláwọ̀ díẹ̀',
    '🙆🏿‍♀' => 'obìnrin tí ń sọ ÓDÁRA: adúláwọ̀',
    '💁🏻‍♂' => 'ọkùnrin tí ń tọ́ka ọwọ́: amọ́lára',
    '💁🏼‍♂' => 'ọkùnrin tí ń tọ́ka ọwọ́: amọ́lára díẹ̀',
    '💁🏽‍♂' => 'ọkùnrin tí ń tọ́ka ọwọ́: amọ́láwọ̀ díẹ̀',
    '💁🏾‍♂' => 'ọkùnrin tí ń tọ́ka ọwọ́: adúláwọ̀ díẹ̀',
    '💁🏿‍♂' => 'ọkùnrin tí ń tọ́ka ọwọ́: adúláwọ̀',
    '💁🏻‍♀' => 'obìnrin tí ń tọ́ka ọwọ́: amọ́lára',
    '💁🏼‍♀' => 'obìnrin tí ń tọ́ka ọwọ́: amọ́lára díẹ̀',
    '💁🏽‍♀' => 'obìnrin tí ń tọ́ka ọwọ́: amọ́láwọ̀ díẹ̀',
    '💁🏾‍♀' => 'obìnrin tí ń tọ́ka ọwọ́: adúláwọ̀ díẹ̀',
    '💁🏿‍♀' => 'obìnrin tí ń tọ́ka ọwọ́: adúláwọ̀',
    '🙋🏻‍♂' => 'ọkùnrintí ń nawọ́ sókè: amọ́lára',
    '🙋🏼‍♂' => 'ọkùnrintí ń nawọ́ sókè: amọ́lára díẹ̀',
    '🙋🏽‍♂' => 'ọkùnrintí ń nawọ́ sókè: amọ́láwọ̀ díẹ̀',
    '🙋🏾‍♂' => 'ọkùnrintí ń nawọ́ sókè: adúláwọ̀ díẹ̀',
    '🙋🏿‍♂' => 'ọkùnrintí ń nawọ́ sókè: adúláwọ̀',
    '🙋🏻‍♀' => 'obìnrin tí ń nawọ́ sókè: amọ́lára',
    '🙋🏼‍♀' => 'obìnrin tí ń nawọ́ sókè: amọ́lára díẹ̀',
    '🙋🏽‍♀' => 'obìnrin tí ń nawọ́ sókè: amọ́láwọ̀ díẹ̀',
    '🙋🏾‍♀' => 'obìnrin tí ń nawọ́ sókè: adúláwọ̀ díẹ̀',
    '🙋🏿‍♀' => 'obìnrin tí ń nawọ́ sókè: adúláwọ̀',
    '🧏🏻‍♂' => 'ọkùnrin adití: amọ́lára',
    '🧏🏼‍♂' => 'ọkùnrin adití: amọ́lára díẹ̀',
    '🧏🏽‍♂' => 'ọkùnrin adití: amọ́láwọ̀ díẹ̀',
    '🧏🏾‍♂' => 'ọkùnrin adití: adúláwọ̀ díẹ̀',
    '🧏🏿‍♂' => 'ọkùnrin adití: adúláwọ̀',
    '🧏🏻‍♀' => 'obìnrin adití: amọ́lára',
    '🧏🏼‍♀' => 'obìnrin adití: amọ́lára díẹ̀',
    '🧏🏽‍♀' => 'obìnrin adití: amọ́láwọ̀ díẹ̀',
    '🧏🏾‍♀' => 'obìnrin adití: adúláwọ̀ díẹ̀',
    '🧏🏿‍♀' => 'obìnrin adití: adúláwọ̀',
    '🙇🏻‍♂' => 'ọkùnrin tí ń tẹríba: amọ́lára',
    '🙇🏼‍♂' => 'ọkùnrin tí ń tẹríba: amọ́lára díẹ̀',
    '🙇🏽‍♂' => 'ọkùnrin tí ń tẹríba: amọ́láwọ̀ díẹ̀',
    '🙇🏾‍♂' => 'ọkùnrin tí ń tẹríba: adúláwọ̀ díẹ̀',
    '🙇🏿‍♂' => 'ọkùnrin tí ń tẹríba: adúláwọ̀',
    '🙇🏻‍♀' => 'obìnrin tí ń tẹríba: amọ́lára',
    '🙇🏼‍♀' => 'obìnrin tí ń tẹríba: amọ́lára díẹ̀',
    '🙇🏽‍♀' => 'obìnrin tí ń tẹríba: amọ́láwọ̀ díẹ̀',
    '🙇🏾‍♀' => 'obìnrin tí ń tẹríba: adúláwọ̀ díẹ̀',
    '🙇🏿‍♀' => 'obìnrin tí ń tẹríba: adúláwọ̀',
    '🤦🏻‍♂' => 'ọkùnrin tín fọwọ́bojú: amọ́lára',
    '🤦🏼‍♂' => 'ọkùnrin tín fọwọ́bojú: amọ́lára díẹ̀',
    '🤦🏽‍♂' => 'ọkùnrin tín fọwọ́bojú: amọ́láwọ̀ díẹ̀',
    '🤦🏾‍♂' => 'ọkùnrin tín fọwọ́bojú: adúláwọ̀ díẹ̀',
    '🤦🏿‍♂' => 'ọkùnrin tín fọwọ́bojú: adúláwọ̀',
    '🤦🏻‍♀' => 'obìnrí tín fọwọ́bojú: amọ́lára',
    '🤦🏼‍♀' => 'obìnrí tín fọwọ́bojú: amọ́lára díẹ̀',
    '🤦🏽‍♀' => 'obìnrí tín fọwọ́bojú: amọ́láwọ̀ díẹ̀',
    '🤦🏾‍♀' => 'obìnrí tín fọwọ́bojú: adúláwọ̀ díẹ̀',
    '🤦🏿‍♀' => 'obìnrí tín fọwọ́bojú: adúláwọ̀',
    '🤷🏻‍♂' => 'ọkùnrin tí ń gúnpá: amọ́lára',
    '🤷🏼‍♂' => 'ọkùnrin tí ń gúnpá: amọ́lára díẹ̀',
    '🤷🏽‍♂' => 'ọkùnrin tí ń gúnpá: amọ́láwọ̀ díẹ̀',
    '🤷🏾‍♂' => 'ọkùnrin tí ń gúnpá: adúláwọ̀ díẹ̀',
    '🤷🏿‍♂' => 'ọkùnrin tí ń gúnpá: adúláwọ̀',
    '🤷🏻‍♀' => 'obìǹrin tí ń gúnpa: amọ́lára',
    '🤷🏼‍♀' => 'obìǹrin tí ń gúnpa: amọ́lára díẹ̀',
    '🤷🏽‍♀' => 'obìǹrin tí ń gúnpa: amọ́láwọ̀ díẹ̀',
    '🤷🏾‍♀' => 'obìǹrin tí ń gúnpa: adúláwọ̀ díẹ̀',
    '🤷🏿‍♀' => 'obìǹrin tí ń gúnpa: adúláwọ̀',
    '🧑🏻‍⚕' => 'òṣìṣẹ́ ìlera: amọ́lára',
    '🧑🏼‍⚕' => 'òṣìṣẹ́ ìlera: amọ́lára díẹ̀',
    '🧑🏽‍⚕' => 'òṣìṣẹ́ ìlera: amọ́láwọ̀ díẹ̀',
    '🧑🏾‍⚕' => 'òṣìṣẹ́ ìlera: adúláwọ̀ díẹ̀',
    '🧑🏿‍⚕' => 'òṣìṣẹ́ ìlera: adúláwọ̀',
    '👨🏻‍⚕' => 'ọkùnrín òṣìṣẹ́ ètò ìlera: amọ́lára',
    '👨🏼‍⚕' => 'ọkùnrín òṣìṣẹ́ ètò ìlera: amọ́lára díẹ̀',
    '👨🏽‍⚕' => 'ọkùnrín òṣìṣẹ́ ètò ìlera: amọ́láwọ̀ díẹ̀',
    '👨🏾‍⚕' => 'ọkùnrín òṣìṣẹ́ ètò ìlera: adúláwọ̀ díẹ̀',
    '👨🏿‍⚕' => 'ọkùnrín òṣìṣẹ́ ètò ìlera: adúláwọ̀',
    '👩🏻‍⚕' => 'obìrin òṣìṣẹ́ ètò ìlera: amọ́lára',
    '👩🏼‍⚕' => 'obìrin òṣìṣẹ́ ètò ìlera: amọ́lára díẹ̀',
    '👩🏽‍⚕' => 'obìrin òṣìṣẹ́ ètò ìlera: amọ́láwọ̀ díẹ̀',
    '👩🏾‍⚕' => 'obìrin òṣìṣẹ́ ètò ìlera: adúláwọ̀ díẹ̀',
    '👩🏿‍⚕' => 'obìrin òṣìṣẹ́ ètò ìlera: adúláwọ̀',
    '🧑🏻‍🎓' => 'akẹ́kọ̀ọ́: amọ́lára',
    '🧑🏼‍🎓' => 'akẹ́kọ̀ọ́: amọ́lára díẹ̀',
    '🧑🏽‍🎓' => 'akẹ́kọ̀ọ́: amọ́láwọ̀ díẹ̀',
    '🧑🏾‍🎓' => 'akẹ́kọ̀ọ́: adúláwọ̀ díẹ̀',
    '🧑🏿‍🎓' => 'akẹ́kọ̀ọ́: adúláwọ̀',
    '👨🏻‍🎓' => 'ọkùnrin akẹ́kọ̀ọ́: amọ́lára',
    '👨🏼‍🎓' => 'ọkùnrin akẹ́kọ̀ọ́: amọ́lára díẹ̀',
    '👨🏽‍🎓' => 'ọkùnrin akẹ́kọ̀ọ́: amọ́láwọ̀ díẹ̀',
    '👨🏾‍🎓' => 'ọkùnrin akẹ́kọ̀ọ́: adúláwọ̀ díẹ̀',
    '👨🏿‍🎓' => 'ọkùnrin akẹ́kọ̀ọ́: adúláwọ̀',
    '👩🏻‍🎓' => 'obìrin akẹ́kọ̀ọ́: amọ́lára',
    '👩🏼‍🎓' => 'obìrin akẹ́kọ̀ọ́: amọ́lára díẹ̀',
    '👩🏽‍🎓' => 'obìrin akẹ́kọ̀ọ́: amọ́láwọ̀ díẹ̀',
    '👩🏾‍🎓' => 'obìrin akẹ́kọ̀ọ́: adúláwọ̀ díẹ̀',
    '👩🏿‍🎓' => 'obìrin akẹ́kọ̀ọ́: adúláwọ̀',
    '🧑🏻‍🏫' => 'olùkọ́: amọ́lára',
    '🧑🏼‍🏫' => 'olùkọ́: amọ́lára díẹ̀',
    '🧑🏽‍🏫' => 'olùkọ́: amọ́láwọ̀ díẹ̀',
    '🧑🏾‍🏫' => 'olùkọ́: adúláwọ̀ díẹ̀',
    '🧑🏿‍🏫' => 'olùkọ́: adúláwọ̀',
    '👨🏻‍🏫' => 'ọkùnrin olùkọ́: amọ́lára',
    '👨🏼‍🏫' => 'ọkùnrin olùkọ́: amọ́lára díẹ̀',
    '👨🏽‍🏫' => 'ọkùnrin olùkọ́: amọ́láwọ̀ díẹ̀',
    '👨🏾‍🏫' => 'ọkùnrin olùkọ́: adúláwọ̀ díẹ̀',
    '👨🏿‍🏫' => 'ọkùnrin olùkọ́: adúláwọ̀',
    '👩🏻‍🏫' => 'obìnrin olùkọ́: amọ́lára',
    '👩🏼‍🏫' => 'obìnrin olùkọ́: amọ́lára díẹ̀',
    '👩🏽‍🏫' => 'obìnrin olùkọ́: amọ́láwọ̀ díẹ̀',
    '👩🏾‍🏫' => 'obìnrin olùkọ́: adúláwọ̀ díẹ̀',
    '👩🏿‍🏫' => 'obìnrin olùkọ́: adúláwọ̀',
    '🧑🏻‍⚖' => 'adájọ́: amọ́lára',
    '🧑🏼‍⚖' => 'adájọ́: amọ́lára díẹ̀',
    '🧑🏽‍⚖' => 'adájọ́: amọ́láwọ̀ díẹ̀',
    '🧑🏾‍⚖' => 'adájọ́: adúláwọ̀ díẹ̀',
    '🧑🏿‍⚖' => 'adájọ́: adúláwọ̀',
    '👨🏻‍⚖' => 'ọkùnrin adájọ́: amọ́lára',
    '👨🏼‍⚖' => 'ọkùnrin adájọ́: amọ́lára díẹ̀',
    '👨🏽‍⚖' => 'ọkùnrin adájọ́: amọ́láwọ̀ díẹ̀',
    '👨🏾‍⚖' => 'ọkùnrin adájọ́: adúláwọ̀ díẹ̀',
    '👨🏿‍⚖' => 'ọkùnrin adájọ́: adúláwọ̀',
    '👩🏻‍⚖' => 'obìnrin adájọ́: amọ́lára',
    '👩🏼‍⚖' => 'obìnrin adájọ́: amọ́lára díẹ̀',
    '👩🏽‍⚖' => 'obìnrin adájọ́: amọ́láwọ̀ díẹ̀',
    '👩🏾‍⚖' => 'obìnrin adájọ́: adúláwọ̀ díẹ̀',
    '👩🏿‍⚖' => 'obìnrin adájọ́: adúláwọ̀',
    '🧑🏻‍🌾' => 'àgbẹ̀: amọ́lára',
    '🧑🏼‍🌾' => 'àgbẹ̀: amọ́lára díẹ̀',
    '🧑🏽‍🌾' => 'àgbẹ̀: amọ́láwọ̀ díẹ̀',
    '🧑🏾‍🌾' => 'àgbẹ̀: adúláwọ̀ díẹ̀',
    '🧑🏿‍🌾' => 'àgbẹ̀: adúláwọ̀',
    '👨🏻‍🌾' => 'ọkùnrin àgbẹ́: amọ́lára',
    '👨🏼‍🌾' => 'ọkùnrin àgbẹ́: amọ́lára díẹ̀',
    '👨🏽‍🌾' => 'ọkùnrin àgbẹ́: amọ́láwọ̀ díẹ̀',
    '👨🏾‍🌾' => 'ọkùnrin àgbẹ́: adúláwọ̀ díẹ̀',
    '👨🏿‍🌾' => 'ọkùnrin àgbẹ́: adúláwọ̀',
    '👩🏻‍🌾' => 'obìrinàgbẹ́: amọ́lára',
    '👩🏼‍🌾' => 'obìrinàgbẹ́: amọ́lára díẹ̀',
    '👩🏽‍🌾' => 'obìrinàgbẹ́: amọ́láwọ̀ díẹ̀',
    '👩🏾‍🌾' => 'obìrinàgbẹ́: adúláwọ̀ díẹ̀',
    '👩🏿‍🌾' => 'obìrinàgbẹ́: adúláwọ̀',
    '🧑🏻‍🍳' => 'alásè: amọ́lára',
    '🧑🏼‍🍳' => 'alásè: amọ́lára díẹ̀',
    '🧑🏽‍🍳' => 'alásè: amọ́láwọ̀ díẹ̀',
    '🧑🏾‍🍳' => 'alásè: adúláwọ̀ díẹ̀',
    '🧑🏿‍🍳' => 'alásè: adúláwọ̀',
    '👨🏻‍🍳' => 'ọkùnrin olùse ónjẹ: amọ́lára',
    '👨🏼‍🍳' => 'ọkùnrin olùse ónjẹ: amọ́lára díẹ̀',
    '👨🏽‍🍳' => 'ọkùnrin olùse ónjẹ: amọ́láwọ̀ díẹ̀',
    '👨🏾‍🍳' => 'ọkùnrin olùse ónjẹ: adúláwọ̀ díẹ̀',
    '👨🏿‍🍳' => 'ọkùnrin olùse ónjẹ: adúláwọ̀',
    '👩🏻‍🍳' => 'obìrin olùse ónjẹ: amọ́lára',
    '👩🏼‍🍳' => 'obìrin olùse ónjẹ: amọ́lára díẹ̀',
    '👩🏽‍🍳' => 'obìrin olùse ónjẹ: amọ́láwọ̀ díẹ̀',
    '👩🏾‍🍳' => 'obìrin olùse ónjẹ: adúláwọ̀ díẹ̀',
    '👩🏿‍🍳' => 'obìrin olùse ónjẹ: adúláwọ̀',
    '🧑🏻‍🔧' => 'mẹkáníìkì: amọ́lára',
    '🧑🏼‍🔧' => 'mẹkáníìkì: amọ́lára díẹ̀',
    '🧑🏽‍🔧' => 'mẹkáníìkì: amọ́láwọ̀ díẹ̀',
    '🧑🏾‍🔧' => 'mẹkáníìkì: adúláwọ̀ díẹ̀',
    '🧑🏿‍🔧' => 'mẹkáníìkì: adúláwọ̀',
    '👨🏻‍🔧' => 'ọkùnrin atún ọkọ̀ ṣe: amọ́lára',
    '👨🏼‍🔧' => 'ọkùnrin atún ọkọ̀ ṣe: amọ́lára díẹ̀',
    '👨🏽‍🔧' => 'ọkùnrin atún ọkọ̀ ṣe: amọ́láwọ̀ díẹ̀',
    '👨🏾‍🔧' => 'ọkùnrin atún ọkọ̀ ṣe: adúláwọ̀ díẹ̀',
    '👨🏿‍🔧' => 'ọkùnrin atún ọkọ̀ ṣe: adúláwọ̀',
    '👩🏻‍🔧' => 'obìrin atún ọkọ̀ ṣe: amọ́lára',
    '👩🏼‍🔧' => 'obìrin atún ọkọ̀ ṣe: amọ́lára díẹ̀',
    '👩🏽‍🔧' => 'obìrin atún ọkọ̀ ṣe: amọ́láwọ̀ díẹ̀',
    '👩🏾‍🔧' => 'obìrin atún ọkọ̀ ṣe: adúláwọ̀ díẹ̀',
    '👩🏿‍🔧' => 'obìrin atún ọkọ̀ ṣe: adúláwọ̀',
    '🧑🏻‍🏭' => 'òṣìṣẹ́ ilé-iṣẹ́ aṣàgbéjáde ọjà: amọ́lára',
    '🧑🏼‍🏭' => 'òṣìṣẹ́ ilé-iṣẹ́ aṣàgbéjáde ọjà: amọ́lára díẹ̀',
    '🧑🏽‍🏭' => 'òṣìṣẹ́ ilé-iṣẹ́ aṣàgbéjáde ọjà: amọ́láwọ̀ díẹ̀',
    '🧑🏾‍🏭' => 'òṣìṣẹ́ ilé-iṣẹ́ aṣàgbéjáde ọjà: adúláwọ̀ díẹ̀',
    '🧑🏿‍🏭' => 'òṣìṣẹ́ ilé-iṣẹ́ aṣàgbéjáde ọjà: adúláwọ̀',
    '👨🏻‍🏭' => 'ọkùnrin òṣìṣẹ́ ilé-iṣẹ́: amọ́lára',
    '👨🏼‍🏭' => 'ọkùnrin òṣìṣẹ́ ilé-iṣẹ́: amọ́lára díẹ̀',
    '👨🏽‍🏭' => 'ọkùnrin òṣìṣẹ́ ilé-iṣẹ́: amọ́láwọ̀ díẹ̀',
    '👨🏾‍🏭' => 'ọkùnrin òṣìṣẹ́ ilé-iṣẹ́: adúláwọ̀ díẹ̀',
    '👨🏿‍🏭' => 'ọkùnrin òṣìṣẹ́ ilé-iṣẹ́: adúláwọ̀',
    '👩🏻‍🏭' => 'obìrin òṣìṣẹ́ ilé-iṣẹ́: amọ́lára',
    '👩🏼‍🏭' => 'obìrin òṣìṣẹ́ ilé-iṣẹ́: amọ́lára díẹ̀',
    '👩🏽‍🏭' => 'obìrin òṣìṣẹ́ ilé-iṣẹ́: amọ́láwọ̀ díẹ̀',
    '👩🏾‍🏭' => 'obìrin òṣìṣẹ́ ilé-iṣẹ́: adúláwọ̀ díẹ̀',
    '👩🏿‍🏭' => 'obìrin òṣìṣẹ́ ilé-iṣẹ́: adúláwọ̀',
    '🧑🏻‍💼' => 'òṣìṣẹ́ ọ́fíìsì: amọ́lára',
    '🧑🏼‍💼' => 'òṣìṣẹ́ ọ́fíìsì: amọ́lára díẹ̀',
    '🧑🏽‍💼' => 'òṣìṣẹ́ ọ́fíìsì: amọ́láwọ̀ díẹ̀',
    '🧑🏾‍💼' => 'òṣìṣẹ́ ọ́fíìsì: adúláwọ̀ díẹ̀',
    '🧑🏿‍💼' => 'òṣìṣẹ́ ọ́fíìsì: adúláwọ̀',
    '👨🏻‍💼' => 'ọkùnrin òṣìṣẹ́ ọ́físì: amọ́lára',
    '👨🏼‍💼' => 'ọkùnrin òṣìṣẹ́ ọ́físì: amọ́lára díẹ̀',
    '👨🏽‍💼' => 'ọkùnrin òṣìṣẹ́ ọ́físì: amọ́láwọ̀ díẹ̀',
    '👨🏾‍💼' => 'ọkùnrin òṣìṣẹ́ ọ́físì: adúláwọ̀ díẹ̀',
    '👨🏿‍💼' => 'ọkùnrin òṣìṣẹ́ ọ́físì: adúláwọ̀',
    '👩🏻‍💼' => 'obìrin òṣìṣẹ́ ọ́físì: amọ́lára',
    '👩🏼‍💼' => 'obìrin òṣìṣẹ́ ọ́físì: amọ́lára díẹ̀',
    '👩🏽‍💼' => 'obìrin òṣìṣẹ́ ọ́físì: amọ́láwọ̀ díẹ̀',
    '👩🏾‍💼' => 'obìrin òṣìṣẹ́ ọ́físì: adúláwọ̀ díẹ̀',
    '👩🏿‍💼' => 'obìrin òṣìṣẹ́ ọ́físì: adúláwọ̀',
    '🧑🏻‍🔬' => 'onímọ̀ sáyẹ́ǹsì: amọ́lára',
    '🧑🏼‍🔬' => 'onímọ̀ sáyẹ́ǹsì: amọ́lára díẹ̀',
    '🧑🏽‍🔬' => 'onímọ̀ sáyẹ́ǹsì: amọ́láwọ̀ díẹ̀',
    '🧑🏾‍🔬' => 'onímọ̀ sáyẹ́ǹsì: adúláwọ̀ díẹ̀',
    '🧑🏿‍🔬' => 'onímọ̀ sáyẹ́ǹsì: adúláwọ̀',
    '👨🏻‍🔬' => 'ọkùnrín síyẹ́nsì: amọ́lára',
    '👨🏼‍🔬' => 'ọkùnrín síyẹ́nsì: amọ́lára díẹ̀',
    '👨🏽‍🔬' => 'ọkùnrín síyẹ́nsì: amọ́láwọ̀ díẹ̀',
    '👨🏾‍🔬' => 'ọkùnrín síyẹ́nsì: adúláwọ̀ díẹ̀',
    '👨🏿‍🔬' => 'ọkùnrín síyẹ́nsì: adúláwọ̀',
    '👩🏻‍🔬' => 'obìrin síyẹ́nsì: amọ́lára',
    '👩🏼‍🔬' => 'obìrin síyẹ́nsì: amọ́lára díẹ̀',
    '👩🏽‍🔬' => 'obìrin síyẹ́nsì: amọ́láwọ̀ díẹ̀',
    '👩🏾‍🔬' => 'obìrin síyẹ́nsì: adúláwọ̀ díẹ̀',
    '👩🏿‍🔬' => 'obìrin síyẹ́nsì: adúláwọ̀',
    '🧑🏻‍💻' => 'akọ́ṣẹ́mọṣẹ́ ìmọ̀-ẹ̀rọ: amọ́lára',
    '🧑🏼‍💻' => 'akọ́ṣẹ́mọṣẹ́ ìmọ̀-ẹ̀rọ: amọ́lára díẹ̀',
    '🧑🏽‍💻' => 'akọ́ṣẹ́mọṣẹ́ ìmọ̀-ẹ̀rọ: amọ́láwọ̀ díẹ̀',
    '🧑🏾‍💻' => 'akọ́ṣẹ́mọṣẹ́ ìmọ̀-ẹ̀rọ: adúláwọ̀ díẹ̀',
    '🧑🏿‍💻' => 'akọ́ṣẹ́mọṣẹ́ ìmọ̀-ẹ̀rọ: adúláwọ̀',
    '👨🏻‍💻' => 'ọkùnrin oníms ẹ̀rọ: amọ́lára',
    '👨🏼‍💻' => 'ọkùnrin oníms ẹ̀rọ: amọ́lára díẹ̀',
    '👨🏽‍💻' => 'ọkùnrin oníms ẹ̀rọ: amọ́láwọ̀ díẹ̀',
    '👨🏾‍💻' => 'ọkùnrin oníms ẹ̀rọ: adúláwọ̀ díẹ̀',
    '👨🏿‍💻' => 'ọkùnrin oníms ẹ̀rọ: adúláwọ̀',
    '👩🏻‍💻' => 'obìrin onímọ̀ ẹ̀rọ: amọ́lára',
    '👩🏼‍💻' => 'obìrin onímọ̀ ẹ̀rọ: amọ́lára díẹ̀',
    '👩🏽‍💻' => 'obìrin onímọ̀ ẹ̀rọ: amọ́láwọ̀ díẹ̀',
    '👩🏾‍💻' => 'obìrin onímọ̀ ẹ̀rọ: adúláwọ̀ díẹ̀',
    '👩🏿‍💻' => 'obìrin onímọ̀ ẹ̀rọ: adúláwọ̀',
    '🧑🏻‍🎤' => 'akọrin: amọ́lára',
    '🧑🏼‍🎤' => 'akọrin: amọ́lára díẹ̀',
    '🧑🏽‍🎤' => 'akọrin: amọ́láwọ̀ díẹ̀',
    '🧑🏾‍🎤' => 'akọrin: adúláwọ̀ díẹ̀',
    '🧑🏿‍🎤' => 'akọrin: adúláwọ̀',
    '👨🏻‍🎤' => 'ọkùnrin olórin: amọ́lára',
    '👨🏼‍🎤' => 'ọkùnrin olórin: amọ́lára díẹ̀',
    '👨🏽‍🎤' => 'ọkùnrin olórin: amọ́láwọ̀ díẹ̀',
    '👨🏾‍🎤' => 'ọkùnrin olórin: adúláwọ̀ díẹ̀',
    '👨🏿‍🎤' => 'ọkùnrin olórin: adúláwọ̀',
    '👩🏻‍🎤' => 'obìnrin olórin: amọ́lára',
    '👩🏼‍🎤' => 'obìnrin olórin: amọ́lára díẹ̀',
    '👩🏽‍🎤' => 'obìnrin olórin: amọ́láwọ̀ díẹ̀',
    '👩🏾‍🎤' => 'obìnrin olórin: adúláwọ̀ díẹ̀',
    '👩🏿‍🎤' => 'obìnrin olórin: adúláwọ̀',
    '🧑🏻‍🎨' => 'aṣẹ̀dá àwòrán: amọ́lára',
    '🧑🏼‍🎨' => 'aṣẹ̀dá àwòrán: amọ́lára díẹ̀',
    '🧑🏽‍🎨' => 'aṣẹ̀dá àwòrán: amọ́láwọ̀ díẹ̀',
    '🧑🏾‍🎨' => 'aṣẹ̀dá àwòrán: adúláwọ̀ díẹ̀',
    '🧑🏿‍🎨' => 'aṣẹ̀dá àwòrán: adúláwọ̀',
    '👨🏻‍🎨' => 'ọkùnrin òṣèré: amọ́lára',
    '👨🏼‍🎨' => 'ọkùnrin òṣèré: amọ́lára díẹ̀',
    '👨🏽‍🎨' => 'ọkùnrin òṣèré: amọ́láwọ̀ díẹ̀',
    '👨🏾‍🎨' => 'ọkùnrin òṣèré: adúláwọ̀ díẹ̀',
    '👨🏿‍🎨' => 'ọkùnrin òṣèré: adúláwọ̀',
    '👩🏻‍🎨' => 'obìrin òṣèré: amọ́lára',
    '👩🏼‍🎨' => 'obìrin òṣèré: amọ́lára díẹ̀',
    '👩🏽‍🎨' => 'obìrin òṣèré: amọ́láwọ̀ díẹ̀',
    '👩🏾‍🎨' => 'obìrin òṣèré: adúláwọ̀ díẹ̀',
    '👩🏿‍🎨' => 'obìrin òṣèré: adúláwọ̀',
    '🧑🏻‍✈' => 'atukọ̀-òfurufú: amọ́lára',
    '🧑🏼‍✈' => 'atukọ̀-òfurufú: amọ́lára díẹ̀',
    '🧑🏽‍✈' => 'atukọ̀-òfurufú: amọ́láwọ̀ díẹ̀',
    '🧑🏾‍✈' => 'atukọ̀-òfurufú: adúláwọ̀ díẹ̀',
    '🧑🏿‍✈' => 'atukọ̀-òfurufú: adúláwọ̀',
    '👨🏻‍✈' => 'ọkùnrin awa ọkọ́ bàlú: amọ́lára',
    '👨🏼‍✈' => 'ọkùnrin awa ọkọ́ bàlú: amọ́lára díẹ̀',
    '👨🏽‍✈' => 'ọkùnrin awa ọkọ́ bàlú: amọ́láwọ̀ díẹ̀',
    '👨🏾‍✈' => 'ọkùnrin awa ọkọ́ bàlú: adúláwọ̀ díẹ̀',
    '👨🏿‍✈' => 'ọkùnrin awa ọkọ́ bàlú: adúláwọ̀',
    '👩🏻‍✈' => 'obìrin awa ọkọ́ bàlú: amọ́lára',
    '👩🏼‍✈' => 'obìrin awa ọkọ́ bàlú: amọ́lára díẹ̀',
    '👩🏽‍✈' => 'obìrin awa ọkọ́ bàlú: amọ́láwọ̀ díẹ̀',
    '👩🏾‍✈' => 'obìrin awa ọkọ́ bàlú: adúláwọ̀ díẹ̀',
    '👩🏿‍✈' => 'obìrin awa ọkọ́ bàlú: adúláwọ̀',
    '🧑🏻‍🚀' => 'arìnrìn-àjò lọ sí ayé mìíràn: amọ́lára',
    '🧑🏼‍🚀' => 'arìnrìn-àjò lọ sí ayé mìíràn: amọ́lára díẹ̀',
    '🧑🏽‍🚀' => 'arìnrìn-àjò lọ sí ayé mìíràn: amọ́láwọ̀ díẹ̀',
    '🧑🏾‍🚀' => 'arìnrìn-àjò lọ sí ayé mìíràn: adúláwọ̀ díẹ̀',
    '🧑🏿‍🚀' => 'arìnrìn-àjò lọ sí ayé mìíràn: adúláwọ̀',
    '👨🏻‍🚀' => 'ọkùnrin olùwádìí inú òṣùpá: amọ́lára',
    '👨🏼‍🚀' => 'ọkùnrin olùwádìí inú òṣùpá: amọ́lára díẹ̀',
    '👨🏽‍🚀' => 'ọkùnrin olùwádìí inú òṣùpá: amọ́láwọ̀ díẹ̀',
    '👨🏾‍🚀' => 'ọkùnrin olùwádìí inú òṣùpá: adúláwọ̀ díẹ̀',
    '👨🏿‍🚀' => 'ọkùnrin olùwádìí inú òṣùpá: adúláwọ̀',
    '👩🏻‍🚀' => 'obìrinolùwádìí inú òṣùpá: amọ́lára',
    '👩🏼‍🚀' => 'obìrinolùwádìí inú òṣùpá: amọ́lára díẹ̀',
    '👩🏽‍🚀' => 'obìrinolùwádìí inú òṣùpá: amọ́láwọ̀ díẹ̀',
    '👩🏾‍🚀' => 'obìrinolùwádìí inú òṣùpá: adúláwọ̀ díẹ̀',
    '👩🏿‍🚀' => 'obìrinolùwádìí inú òṣùpá: adúláwọ̀',
    '🧑🏻‍🚒' => 'panápaná: amọ́lára',
    '🧑🏼‍🚒' => 'panápaná: amọ́lára díẹ̀',
    '🧑🏽‍🚒' => 'panápaná: amọ́láwọ̀ díẹ̀',
    '🧑🏾‍🚒' => 'panápaná: adúláwọ̀ díẹ̀',
    '🧑🏿‍🚒' => 'panápaná: adúláwọ̀',
    '👨🏻‍🚒' => 'ọkùnrin panapanọ́: amọ́lára',
    '👨🏼‍🚒' => 'ọkùnrin panapanọ́: amọ́lára díẹ̀',
    '👨🏽‍🚒' => 'ọkùnrin panapanọ́: amọ́láwọ̀ díẹ̀',
    '👨🏾‍🚒' => 'ọkùnrin panapanọ́: adúláwọ̀ díẹ̀',
    '👨🏿‍🚒' => 'ọkùnrin panapanọ́: adúláwọ̀',
    '👩🏻‍🚒' => 'obìrin panapanọ́: amọ́lára',
    '👩🏼‍🚒' => 'obìrin panapanọ́: amọ́lára díẹ̀',
    '👩🏽‍🚒' => 'obìrin panapanọ́: amọ́láwọ̀ díẹ̀',
    '👩🏾‍🚒' => 'obìrin panapanọ́: adúláwọ̀ díẹ̀',
    '👩🏿‍🚒' => 'obìrin panapanọ́: adúláwọ̀',
    '👮🏻‍♂' => 'ọkùnrin ọlọpa: amọ́lára',
    '👮🏼‍♂' => 'ọkùnrin ọlọpa: amọ́lára díẹ̀',
    '👮🏽‍♂' => 'ọkùnrin ọlọpa: amọ́láwọ̀ díẹ̀',
    '👮🏾‍♂' => 'ọkùnrin ọlọpa: adúláwọ̀ díẹ̀',
    '👮🏿‍♂' => 'ọkùnrin ọlọpa: adúláwọ̀',
    '👮🏻‍♀' => 'obìnrin ọlọpa: amọ́lára',
    '👮🏼‍♀' => 'obìnrin ọlọpa: amọ́lára díẹ̀',
    '👮🏽‍♀' => 'obìnrin ọlọpa: amọ́láwọ̀ díẹ̀',
    '👮🏾‍♀' => 'obìnrin ọlọpa: adúláwọ̀ díẹ̀',
    '👮🏿‍♀' => 'obìnrin ọlọpa: adúláwọ̀',
    '🕵🏻‍♂' => 'ọkùnrin ọ̀tẹlèmúyé: amọ́lára',
    '🕵🏼‍♂' => 'ọkùnrin ọ̀tẹlèmúyé: amọ́lára díẹ̀',
    '🕵🏽‍♂' => 'ọkùnrin ọ̀tẹlèmúyé: amọ́láwọ̀ díẹ̀',
    '🕵🏾‍♂' => 'ọkùnrin ọ̀tẹlèmúyé: adúláwọ̀ díẹ̀',
    '🕵🏿‍♂' => 'ọkùnrin ọ̀tẹlèmúyé: adúláwọ̀',
    '🕵🏻‍♀' => 'obìnrin ọ̀tẹlèmúyé: amọ́lára',
    '🕵🏼‍♀' => 'obìnrin ọ̀tẹlèmúyé: amọ́lára díẹ̀',
    '🕵🏽‍♀' => 'obìnrin ọ̀tẹlèmúyé: amọ́láwọ̀ díẹ̀',
    '🕵🏾‍♀' => 'obìnrin ọ̀tẹlèmúyé: adúláwọ̀ díẹ̀',
    '🕵🏿‍♀' => 'obìnrin ọ̀tẹlèmúyé: adúláwọ̀',
    '💂🏻‍♂' => 'ọkùnrin olùṣọ́: amọ́lára',
    '💂🏼‍♂' => 'ọkùnrin olùṣọ́: amọ́lára díẹ̀',
    '💂🏽‍♂' => 'ọkùnrin olùṣọ́: amọ́láwọ̀ díẹ̀',
    '💂🏾‍♂' => 'ọkùnrin olùṣọ́: adúláwọ̀ díẹ̀',
    '💂🏿‍♂' => 'ọkùnrin olùṣọ́: adúláwọ̀',
    '💂🏻‍♀' => 'obìnrin olùṣọ́: amọ́lára',
    '💂🏼‍♀' => 'obìnrin olùṣọ́: amọ́lára díẹ̀',
    '💂🏽‍♀' => 'obìnrin olùṣọ́: amọ́láwọ̀ díẹ̀',
    '💂🏾‍♀' => 'obìnrin olùṣọ́: adúláwọ̀ díẹ̀',
    '💂🏿‍♀' => 'obìnrin olùṣọ́: adúláwọ̀',
    '👷🏻‍♂' => 'òṣiṣẹ́ ìkọ́lé ọkùnrin: amọ́lára',
    '👷🏼‍♂' => 'òṣiṣẹ́ ìkọ́lé ọkùnrin: amọ́lára díẹ̀',
    '👷🏽‍♂' => 'òṣiṣẹ́ ìkọ́lé ọkùnrin: amọ́láwọ̀ díẹ̀',
    '👷🏾‍♂' => 'òṣiṣẹ́ ìkọ́lé ọkùnrin: adúláwọ̀ díẹ̀',
    '👷🏿‍♂' => 'òṣiṣẹ́ ìkọ́lé ọkùnrin: adúláwọ̀',
    '👷🏻‍♀' => 'òṣiṣẹ́ ìkọ́lé obìnrin: amọ́lára',
    '👷🏼‍♀' => 'òṣiṣẹ́ ìkọ́lé obìnrin: amọ́lára díẹ̀',
    '👷🏽‍♀' => 'òṣiṣẹ́ ìkọ́lé obìnrin: amọ́láwọ̀ díẹ̀',
    '👷🏾‍♀' => 'òṣiṣẹ́ ìkọ́lé obìnrin: adúláwọ̀ díẹ̀',
    '👷🏿‍♀' => 'òṣiṣẹ́ ìkọ́lé obìnrin: adúláwọ̀',
    '👳🏻‍♂' => 'ọkùnrin tó dé láwàní: amọ́lára',
    '👳🏼‍♂' => 'ọkùnrin tó dé láwàní: amọ́lára díẹ̀',
    '👳🏽‍♂' => 'ọkùnrin tó dé láwàní: amọ́láwọ̀ díẹ̀',
    '👳🏾‍♂' => 'ọkùnrin tó dé láwàní: adúláwọ̀ díẹ̀',
    '👳🏿‍♂' => 'ọkùnrin tó dé láwàní: adúláwọ̀',
    '👳🏻‍♀' => 'obìnrin tó dé láwàní: amọ́lára',
    '👳🏼‍♀' => 'obìnrin tó dé láwàní: amọ́lára díẹ̀',
    '👳🏽‍♀' => 'obìnrin tó dé láwàní: amọ́láwọ̀ díẹ̀',
    '👳🏾‍♀' => 'obìnrin tó dé láwàní: adúláwọ̀ díẹ̀',
    '👳🏿‍♀' => 'obìnrin tó dé láwàní: adúláwọ̀',
    '🤵🏻‍♂' => 'ọkùnrin tó wọ kóòtù ìlọsóde ìrọ̀lẹ́: amọ́lára',
    '🤵🏼‍♂' => 'ọkùnrin tó wọ kóòtù ìlọsóde ìrọ̀lẹ́: amọ́lára díẹ̀',
    '🤵🏽‍♂' => 'ọkùnrin tó wọ kóòtù ìlọsóde ìrọ̀lẹ́: amọ́láwọ̀ díẹ̀',
    '🤵🏾‍♂' => 'ọkùnrin tó wọ kóòtù ìlọsóde ìrọ̀lẹ́: adúláwọ̀ díẹ̀',
    '🤵🏿‍♂' => 'ọkùnrin tó wọ kóòtù ìlọsóde ìrọ̀lẹ́: adúláwọ̀',
    '🤵🏻‍♀' => 'obìnrin tó wọ kóòtù ìlọsóde ìrọ̀lẹ́: amọ́lára',
    '🤵🏼‍♀' => 'obìnrin tó wọ kóòtù ìlọsóde ìrọ̀lẹ́: amọ́lára díẹ̀',
    '🤵🏽‍♀' => 'obìnrin tó wọ kóòtù ìlọsóde ìrọ̀lẹ́: amọ́láwọ̀ díẹ̀',
    '🤵🏾‍♀' => 'obìnrin tó wọ kóòtù ìlọsóde ìrọ̀lẹ́: adúláwọ̀ díẹ̀',
    '🤵🏿‍♀' => 'obìnrin tó wọ kóòtù ìlọsóde ìrọ̀lẹ́: adúláwọ̀',
    '👰🏻‍♂' => 'ọkùnrin tó fi aṣọ bojú: amọ́lára',
    '👰🏼‍♂' => 'ọkùnrin tó fi aṣọ bojú: amọ́lára díẹ̀',
    '👰🏽‍♂' => 'ọkùnrin tó fi aṣọ bojú: amọ́láwọ̀ díẹ̀',
    '👰🏾‍♂' => 'ọkùnrin tó fi aṣọ bojú: adúláwọ̀ díẹ̀',
    '👰🏿‍♂' => 'ọkùnrin tó fi aṣọ bojú: adúláwọ̀',
    '👰🏻‍♀' => 'obìnrin tó fi aṣọ bojú: amọ́lára',
    '👰🏼‍♀' => 'obìnrin tó fi aṣọ bojú: amọ́lára díẹ̀',
    '👰🏽‍♀' => 'obìnrin tó fi aṣọ bojú: amọ́láwọ̀ díẹ̀',
    '👰🏾‍♀' => 'obìnrin tó fi aṣọ bojú: adúláwọ̀ díẹ̀',
    '👰🏿‍♀' => 'obìnrin tó fi aṣọ bojú: adúláwọ̀',
    '👩🏻‍🍼' => 'obìnrin tó ń fọ́mọ lóúnjẹ: amọ́lára',
    '👩🏼‍🍼' => 'obìnrin tó ń fọ́mọ lóúnjẹ: amọ́lára díẹ̀',
    '👩🏽‍🍼' => 'obìnrin tó ń fọ́mọ lóúnjẹ: amọ́láwọ̀ díẹ̀',
    '👩🏾‍🍼' => 'obìnrin tó ń fọ́mọ lóúnjẹ: adúláwọ̀ díẹ̀',
    '👩🏿‍🍼' => 'obìnrin tó ń fọ́mọ lóúnjẹ: adúláwọ̀',
    '👨🏻‍🍼' => 'ọkùnrin tó ń fọ́mọ lóúnjẹ: amọ́lára',
    '👨🏼‍🍼' => 'ọkùnrin tó ń fọ́mọ lóúnjẹ: amọ́lára díẹ̀',
    '👨🏽‍🍼' => 'ọkùnrin tó ń fọ́mọ lóúnjẹ: amọ́láwọ̀ díẹ̀',
    '👨🏾‍🍼' => 'ọkùnrin tó ń fọ́mọ lóúnjẹ: adúláwọ̀ díẹ̀',
    '👨🏿‍🍼' => 'ọkùnrin tó ń fọ́mọ lóúnjẹ: adúláwọ̀',
    '🧑🏻‍🍼' => 'ẹnìkan tó ń fọ́mọ lóúnjẹ: amọ́lára',
    '🧑🏼‍🍼' => 'ẹnìkan tó ń fọ́mọ lóúnjẹ: amọ́lára díẹ̀',
    '🧑🏽‍🍼' => 'ẹnìkan tó ń fọ́mọ lóúnjẹ: amọ́láwọ̀ díẹ̀',
    '🧑🏾‍🍼' => 'ẹnìkan tó ń fọ́mọ lóúnjẹ: adúláwọ̀ díẹ̀',
    '🧑🏿‍🍼' => 'ẹnìkan tó ń fọ́mọ lóúnjẹ: adúláwọ̀',
    '🧑🏻‍🎄' => 'mx claus: amọ́lára',
    '🧑🏼‍🎄' => 'mx claus: amọ́lára díẹ̀',
    '🧑🏽‍🎄' => 'mx claus: amọ́láwọ̀ díẹ̀',
    '🧑🏾‍🎄' => 'mx claus: adúláwọ̀ díẹ̀',
    '🧑🏿‍🎄' => 'mx claus: adúláwọ̀',
    '🦸🏻‍♂' => 'ọkùnrin akọni ńlá: amọ́lára',
    '🦸🏼‍♂' => 'ọkùnrin akọni ńlá: amọ́lára díẹ̀',
    '🦸🏽‍♂' => 'ọkùnrin akọni ńlá: amọ́láwọ̀ díẹ̀',
    '🦸🏾‍♂' => 'ọkùnrin akọni ńlá: adúláwọ̀ díẹ̀',
    '🦸🏿‍♂' => 'ọkùnrin akọni ńlá: adúláwọ̀',
    '🦸🏻‍♀' => 'obìnrin akọni ńlá: amọ́lára',
    '🦸🏼‍♀' => 'obìnrin akọni ńlá: amọ́lára díẹ̀',
    '🦸🏽‍♀' => 'obìnrin akọni ńlá: amọ́láwọ̀ díẹ̀',
    '🦸🏾‍♀' => 'obìnrin akọni ńlá: adúláwọ̀ díẹ̀',
    '🦸🏿‍♀' => 'obìnrin akọni ńlá: adúláwọ̀',
    '🦹🏻‍♂' => 'ọkùnrin aṣèbàjẹ́ ńlá: amọ́lára',
    '🦹🏼‍♂' => 'ọkùnrin aṣèbàjẹ́ ńlá: amọ́lára díẹ̀',
    '🦹🏽‍♂' => 'ọkùnrin aṣèbàjẹ́ ńlá: amọ́láwọ̀ díẹ̀',
    '🦹🏾‍♂' => 'ọkùnrin aṣèbàjẹ́ ńlá: adúláwọ̀ díẹ̀',
    '🦹🏿‍♂' => 'ọkùnrin aṣèbàjẹ́ ńlá: adúláwọ̀',
    '🦹🏻‍♀' => 'obìnrin aṣèbàjẹ́ ńlá: amọ́lára',
    '🦹🏼‍♀' => 'obìnrin aṣèbàjẹ́ ńlá: amọ́lára díẹ̀',
    '🦹🏽‍♀' => 'obìnrin aṣèbàjẹ́ ńlá: amọ́láwọ̀ díẹ̀',
    '🦹🏾‍♀' => 'obìnrin aṣèbàjẹ́ ńlá: adúláwọ̀ díẹ̀',
    '🦹🏿‍♀' => 'obìnrin aṣèbàjẹ́ ńlá: adúláwọ̀',
    '🧙🏻‍♂' => 'Ọkùnrin onídán: amọ́lára',
    '🧙🏼‍♂' => 'Ọkùnrin onídán: amọ́lára díẹ̀',
    '🧙🏽‍♂' => 'Ọkùnrin onídán: amọ́láwọ̀ díẹ̀',
    '🧙🏾‍♂' => 'Ọkùnrin onídán: adúláwọ̀ díẹ̀',
    '🧙🏿‍♂' => 'Ọkùnrin onídán: adúláwọ̀',
    '🧙🏻‍♀' => 'Obìnrin onídán: amọ́lára',
    '🧙🏼‍♀' => 'Obìnrin onídán: amọ́lára díẹ̀',
    '🧙🏽‍♀' => 'Obìnrin onídán: amọ́láwọ̀ díẹ̀',
    '🧙🏾‍♀' => 'Obìnrin onídán: adúláwọ̀ díẹ̀',
    '🧙🏿‍♀' => 'Obìnrin onídán: adúláwọ̀',
    '🧚🏻‍♂' => 'Iwin ọkùnrin: amọ́lára',
    '🧚🏼‍♂' => 'Iwin ọkùnrin: amọ́lára díẹ̀',
    '🧚🏽‍♂' => 'Iwin ọkùnrin: amọ́láwọ̀ díẹ̀',
    '🧚🏾‍♂' => 'Iwin ọkùnrin: adúláwọ̀ díẹ̀',
    '🧚🏿‍♂' => 'Iwin ọkùnrin: adúláwọ̀',
    '🧚🏻‍♀' => 'Iwin obìnrin: amọ́lára',
    '🧚🏼‍♀' => 'Iwin obìnrin: amọ́lára díẹ̀',
    '🧚🏽‍♀' => 'Iwin obìnrin: amọ́láwọ̀ díẹ̀',
    '🧚🏾‍♀' => 'Iwin obìnrin: adúláwọ̀ díẹ̀',
    '🧚🏿‍♀' => 'Iwin obìnrin: adúláwọ̀',
    '🧛🏻‍♂' => 'Fánpáyà ọkùnrin: amọ́lára',
    '🧛🏼‍♂' => 'Fánpáyà ọkùnrin: amọ́lára díẹ̀',
    '🧛🏽‍♂' => 'Fánpáyà ọkùnrin: amọ́láwọ̀ díẹ̀',
    '🧛🏾‍♂' => 'Fánpáyà ọkùnrin: adúláwọ̀ díẹ̀',
    '🧛🏿‍♂' => 'Fánpáyà ọkùnrin: adúláwọ̀',
    '🧛🏻‍♀' => 'Fánpáyà obìnrin: amọ́lára',
    '🧛🏼‍♀' => 'Fánpáyà obìnrin: amọ́lára díẹ̀',
    '🧛🏽‍♀' => 'Fánpáyà obìnrin: amọ́láwọ̀ díẹ̀',
    '🧛🏾‍♀' => 'Fánpáyà obìnrin: adúláwọ̀ díẹ̀',
    '🧛🏿‍♀' => 'Fánpáyà obìnrin: adúláwọ̀',
    '🧜🏻‍♂' => 'Yemọja ọkùnrin: amọ́lára',
    '🧜🏼‍♂' => 'Yemọja ọkùnrin: amọ́lára díẹ̀',
    '🧜🏽‍♂' => 'Yemọja ọkùnrin: amọ́láwọ̀ díẹ̀',
    '🧜🏾‍♂' => 'Yemọja ọkùnrin: adúláwọ̀ díẹ̀',
    '🧜🏿‍♂' => 'Yemọja ọkùnrin: adúláwọ̀',
    '🧜🏻‍♀' => 'iyemọja: amọ́lára',
    '🧜🏼‍♀' => 'iyemọja: amọ́lára díẹ̀',
    '🧜🏽‍♀' => 'iyemọja: amọ́láwọ̀ díẹ̀',
    '🧜🏾‍♀' => 'iyemọja: adúláwọ̀ díẹ̀',
    '🧜🏿‍♀' => 'iyemọja: adúláwọ̀',
    '🧝🏻‍♂' => 'egbére ọkùnrin: amọ́lára',
    '🧝🏼‍♂' => 'egbére ọkùnrin: amọ́lára díẹ̀',
    '🧝🏽‍♂' => 'egbére ọkùnrin: amọ́láwọ̀ díẹ̀',
    '🧝🏾‍♂' => 'egbére ọkùnrin: adúláwọ̀ díẹ̀',
    '🧝🏿‍♂' => 'egbére ọkùnrin: adúláwọ̀',
    '🧝🏻‍♀' => 'egbére obìnrin: amọ́lára',
    '🧝🏼‍♀' => 'egbére obìnrin: amọ́lára díẹ̀',
    '🧝🏽‍♀' => 'egbére obìnrin: amọ́láwọ̀ díẹ̀',
    '🧝🏾‍♀' => 'egbére obìnrin: adúláwọ̀ díẹ̀',
    '🧝🏿‍♀' => 'egbére obìnrin: adúláwọ̀',
    '💆🏻‍♂' => 'ọkùnrin tí ń gba ifọwọwọnilara: amọ́lára',
    '💆🏼‍♂' => 'ọkùnrin tí ń gba ifọwọwọnilara: amọ́lára díẹ̀',
    '💆🏽‍♂' => 'ọkùnrin tí ń gba ifọwọwọnilara: amọ́láwọ̀ díẹ̀',
    '💆🏾‍♂' => 'ọkùnrin tí ń gba ifọwọwọnilara: adúláwọ̀ díẹ̀',
    '💆🏿‍♂' => 'ọkùnrin tí ń gba ifọwọwọnilara: adúláwọ̀',
    '💆🏻‍♀' => 'obìnrin tí ń gba ifọwọwọnilara: amọ́lára',
    '💆🏼‍♀' => 'obìnrin tí ń gba ifọwọwọnilara: amọ́lára díẹ̀',
    '💆🏽‍♀' => 'obìnrin tí ń gba ifọwọwọnilara: amọ́láwọ̀ díẹ̀',
    '💆🏾‍♀' => 'obìnrin tí ń gba ifọwọwọnilara: adúláwọ̀ díẹ̀',
    '💆🏿‍♀' => 'obìnrin tí ń gba ifọwọwọnilara: adúláwọ̀',
    '💇🏻‍♂' => 'ọkùnrin tí ń gẹrun: amọ́lára',
    '💇🏼‍♂' => 'ọkùnrin tí ń gẹrun: amọ́lára díẹ̀',
    '💇🏽‍♂' => 'ọkùnrin tí ń gẹrun: amọ́láwọ̀ díẹ̀',
    '💇🏾‍♂' => 'ọkùnrin tí ń gẹrun: adúláwọ̀ díẹ̀',
    '💇🏿‍♂' => 'ọkùnrin tí ń gẹrun: adúláwọ̀',
    '💇🏻‍♀' => 'obìnrin tí ń gẹrun: amọ́lára',
    '💇🏼‍♀' => 'obìnrin tí ń gẹrun: amọ́lára díẹ̀',
    '💇🏽‍♀' => 'obìnrin tí ń gẹrun: amọ́láwọ̀ díẹ̀',
    '💇🏾‍♀' => 'obìnrin tí ń gẹrun: adúláwọ̀ díẹ̀',
    '💇🏿‍♀' => 'obìnrin tí ń gẹrun: adúláwọ̀',
    '🚶🏻‍♂' => 'ọkùnrin tí ń rìn: amọ́lára',
    '🚶🏼‍♂' => 'ọkùnrin tí ń rìn: amọ́lára díẹ̀',
    '🚶🏽‍♂' => 'ọkùnrin tí ń rìn: amọ́láwọ̀ díẹ̀',
    '🚶🏾‍♂' => 'ọkùnrin tí ń rìn: adúláwọ̀ díẹ̀',
    '🚶🏿‍♂' => 'ọkùnrin tí ń rìn: adúláwọ̀',
    '🚶🏻‍♀' => 'obìnrin tí ń rìn: amọ́lára',
    '🚶🏼‍♀' => 'obìnrin tí ń rìn: amọ́lára díẹ̀',
    '🚶🏽‍♀' => 'obìnrin tí ń rìn: amọ́láwọ̀ díẹ̀',
    '🚶🏾‍♀' => 'obìnrin tí ń rìn: adúláwọ̀ díẹ̀',
    '🚶🏿‍♀' => 'obìnrin tí ń rìn: adúláwọ̀',
    '🚶🏻‍➡' => 'Ẹni N Rin: amọ́lára àtiìdojúkọ ọ̀tún',
    '🚶🏼‍➡' => 'Ẹni N Rin: amọ́lára díẹ̀ àtiìdojúkọ ọ̀tún',
    '🚶🏽‍➡' => 'Ẹni N Rin: amọ́láwọ̀ díẹ̀ àtiìdojúkọ ọ̀tún',
    '🚶🏾‍➡' => 'Ẹni N Rin: adúláwọ̀ díẹ̀ àtiìdojúkọ ọ̀tún',
    '🚶🏿‍➡' => 'Ẹni N Rin: adúláwọ̀ àtiìdojúkọ ọ̀tún',
    '🧍🏻‍♂' => 'ọkùnrin tó dúró: amọ́lára',
    '🧍🏼‍♂' => 'ọkùnrin tó dúró: amọ́lára díẹ̀',
    '🧍🏽‍♂' => 'ọkùnrin tó dúró: amọ́láwọ̀ díẹ̀',
    '🧍🏾‍♂' => 'ọkùnrin tó dúró: adúláwọ̀ díẹ̀',
    '🧍🏿‍♂' => 'ọkùnrin tó dúró: adúláwọ̀',
    '🧍🏻‍♀' => 'obìnrin tó dúró: amọ́lára',
    '🧍🏼‍♀' => 'obìnrin tó dúró: amọ́lára díẹ̀',
    '🧍🏽‍♀' => 'obìnrin tó dúró: amọ́láwọ̀ díẹ̀',
    '🧍🏾‍♀' => 'obìnrin tó dúró: adúláwọ̀ díẹ̀',
    '🧍🏿‍♀' => 'obìnrin tó dúró: adúláwọ̀',
    '🧎🏻‍♂' => 'ọkùnrin tó kúnlẹ̀: amọ́lára',
    '🧎🏼‍♂' => 'ọkùnrin tó kúnlẹ̀: amọ́lára díẹ̀',
    '🧎🏽‍♂' => 'ọkùnrin tó kúnlẹ̀: amọ́láwọ̀ díẹ̀',
    '🧎🏾‍♂' => 'ọkùnrin tó kúnlẹ̀: adúláwọ̀ díẹ̀',
    '🧎🏿‍♂' => 'ọkùnrin tó kúnlẹ̀: adúláwọ̀',
    '🧎🏻‍♀' => 'obìnrin tó kúnlẹ̀: amọ́lára',
    '🧎🏼‍♀' => 'obìnrin tó kúnlẹ̀: amọ́lára díẹ̀',
    '🧎🏽‍♀' => 'obìnrin tó kúnlẹ̀: amọ́láwọ̀ díẹ̀',
    '🧎🏾‍♀' => 'obìnrin tó kúnlẹ̀: adúláwọ̀ díẹ̀',
    '🧎🏿‍♀' => 'obìnrin tó kúnlẹ̀: adúláwọ̀',
    '🧎🏻‍➡' => 'ènìyàn kíkúnlẹ̀: amọ́lára àtiìdojúkọ ọ̀tún',
    '🧎🏼‍➡' => 'ènìyàn kíkúnlẹ̀: amọ́lára díẹ̀ àtiìdojúkọ ọ̀tún',
    '🧎🏽‍➡' => 'ènìyàn kíkúnlẹ̀: amọ́láwọ̀ díẹ̀ àtiìdojúkọ ọ̀tún',
    '🧎🏾‍➡' => 'ènìyàn kíkúnlẹ̀: adúláwọ̀ díẹ̀ àtiìdojúkọ ọ̀tún',
    '🧎🏿‍➡' => 'ènìyàn kíkúnlẹ̀: adúláwọ̀ àtiìdojúkọ ọ̀tún',
    '🧑🏻‍🦯' => 'ènìyàn pẹ̀lú ọ̀pá funfun: amọ́lára',
    '🧑🏼‍🦯' => 'ènìyàn pẹ̀lú ọ̀pá funfun: amọ́lára díẹ̀',
    '🧑🏽‍🦯' => 'ènìyàn pẹ̀lú ọ̀pá funfun: amọ́láwọ̀ díẹ̀',
    '🧑🏾‍🦯' => 'ènìyàn pẹ̀lú ọ̀pá funfun: adúláwọ̀ díẹ̀',
    '🧑🏿‍🦯' => 'ènìyàn pẹ̀lú ọ̀pá funfun: adúláwọ̀',
    '👨🏻‍🦯' => 'ọkùnrin pẹ̀lú ọ̀pá funfun: amọ́lára',
    '👨🏼‍🦯' => 'ọkùnrin pẹ̀lú ọ̀pá funfun: amọ́lára díẹ̀',
    '👨🏽‍🦯' => 'ọkùnrin pẹ̀lú ọ̀pá funfun: amọ́láwọ̀ díẹ̀',
    '👨🏾‍🦯' => 'ọkùnrin pẹ̀lú ọ̀pá funfun: adúláwọ̀ díẹ̀',
    '👨🏿‍🦯' => 'ọkùnrin pẹ̀lú ọ̀pá funfun: adúláwọ̀',
    '👩🏻‍🦯' => 'obìnrin pẹ̀lú ọ̀pá funfun: amọ́lára',
    '👩🏼‍🦯' => 'obìnrin pẹ̀lú ọ̀pá funfun: amọ́lára díẹ̀',
    '👩🏽‍🦯' => 'obìnrin pẹ̀lú ọ̀pá funfun: amọ́láwọ̀ díẹ̀',
    '👩🏾‍🦯' => 'obìnrin pẹ̀lú ọ̀pá funfun: adúláwọ̀ díẹ̀',
    '👩🏿‍🦯' => 'obìnrin pẹ̀lú ọ̀pá funfun: adúláwọ̀',
    '🧑🏻‍🦼' => 'ènìyàn nínú kẹ̀kẹ́-abirùn ẹlẹ́rọ-mọ́tò: amọ́lára',
    '🧑🏼‍🦼' => 'ènìyàn nínú kẹ̀kẹ́-abirùn ẹlẹ́rọ-mọ́tò: amọ́lára díẹ̀',
    '🧑🏽‍🦼' => 'ènìyàn nínú kẹ̀kẹ́-abirùn ẹlẹ́rọ-mọ́tò: amọ́láwọ̀ díẹ̀',
    '🧑🏾‍🦼' => 'ènìyàn nínú kẹ̀kẹ́-abirùn ẹlẹ́rọ-mọ́tò: adúláwọ̀ díẹ̀',
    '🧑🏿‍🦼' => 'ènìyàn nínú kẹ̀kẹ́-abirùn ẹlẹ́rọ-mọ́tò: adúláwọ̀',
    '👨🏻‍🦼' => 'ọkùnrin nínú kẹ̀kẹ́-abirùn ẹlẹ́rọ-mọ́tò: amọ́lára',
    '👨🏼‍🦼' => 'ọkùnrin nínú kẹ̀kẹ́-abirùn ẹlẹ́rọ-mọ́tò: amọ́lára díẹ̀',
    '👨🏽‍🦼' => 'ọkùnrin nínú kẹ̀kẹ́-abirùn ẹlẹ́rọ-mọ́tò: amọ́láwọ̀ díẹ̀',
    '👨🏾‍🦼' => 'ọkùnrin nínú kẹ̀kẹ́-abirùn ẹlẹ́rọ-mọ́tò: adúláwọ̀ díẹ̀',
    '👨🏿‍🦼' => 'ọkùnrin nínú kẹ̀kẹ́-abirùn ẹlẹ́rọ-mọ́tò: adúláwọ̀',
    '👩🏻‍🦼' => 'obìnrin nínú kẹ̀kẹ́-abirùn ẹlẹ́rọ-mọ́tò: amọ́lára',
    '👩🏼‍🦼' => 'obìnrin nínú kẹ̀kẹ́-abirùn ẹlẹ́rọ-mọ́tò: amọ́lára díẹ̀',
    '👩🏽‍🦼' => 'obìnrin nínú kẹ̀kẹ́-abirùn ẹlẹ́rọ-mọ́tò: amọ́láwọ̀ díẹ̀',
    '👩🏾‍🦼' => 'obìnrin nínú kẹ̀kẹ́-abirùn ẹlẹ́rọ-mọ́tò: adúláwọ̀ díẹ̀',
    '👩🏿‍🦼' => 'obìnrin nínú kẹ̀kẹ́-abirùn ẹlẹ́rọ-mọ́tò: adúláwọ̀',
    '🧑🏻‍🦽' => 'ènìyàn nínú kẹ̀kẹ́-abirùn aláfọwọ́yí: amọ́lára',
    '🧑🏼‍🦽' => 'ènìyàn nínú kẹ̀kẹ́-abirùn aláfọwọ́yí: amọ́lára díẹ̀',
    '🧑🏽‍🦽' => 'ènìyàn nínú kẹ̀kẹ́-abirùn aláfọwọ́yí: amọ́láwọ̀ díẹ̀',
    '🧑🏾‍🦽' => 'ènìyàn nínú kẹ̀kẹ́-abirùn aláfọwọ́yí: adúláwọ̀ díẹ̀',
    '🧑🏿‍🦽' => 'ènìyàn nínú kẹ̀kẹ́-abirùn aláfọwọ́yí: adúláwọ̀',
    '👨🏻‍🦽' => 'ọkùnrin nínú kẹ̀kẹ́-abirùn aláfọwọ́yí: amọ́lára',
    '👨🏼‍🦽' => 'ọkùnrin nínú kẹ̀kẹ́-abirùn aláfọwọ́yí: amọ́lára díẹ̀',
    '👨🏽‍🦽' => 'ọkùnrin nínú kẹ̀kẹ́-abirùn aláfọwọ́yí: amọ́láwọ̀ díẹ̀',
    '👨🏾‍🦽' => 'ọkùnrin nínú kẹ̀kẹ́-abirùn aláfọwọ́yí: adúláwọ̀ díẹ̀',
    '👨🏿‍🦽' => 'ọkùnrin nínú kẹ̀kẹ́-abirùn aláfọwọ́yí: adúláwọ̀',
    '👩🏻‍🦽' => 'obìnrin nínú kẹ̀kẹ́-abirùn aláfọwọ́yí: amọ́lára',
    '👩🏼‍🦽' => 'obìnrin nínú kẹ̀kẹ́-abirùn aláfọwọ́yí: amọ́lára díẹ̀',
    '👩🏽‍🦽' => 'obìnrin nínú kẹ̀kẹ́-abirùn aláfọwọ́yí: amọ́láwọ̀ díẹ̀',
    '👩🏾‍🦽' => 'obìnrin nínú kẹ̀kẹ́-abirùn aláfọwọ́yí: adúláwọ̀ díẹ̀',
    '👩🏿‍🦽' => 'obìnrin nínú kẹ̀kẹ́-abirùn aláfọwọ́yí: adúláwọ̀',
    '🏃🏻‍♂' => 'ọkùnrin tí ń sáré: amọ́lára',
    '🏃🏼‍♂' => 'ọkùnrin tí ń sáré: amọ́lára díẹ̀',
    '🏃🏽‍♂' => 'ọkùnrin tí ń sáré: amọ́láwọ̀ díẹ̀',
    '🏃🏾‍♂' => 'ọkùnrin tí ń sáré: adúláwọ̀ díẹ̀',
    '🏃🏿‍♂' => 'ọkùnrin tí ń sáré: adúláwọ̀',
    '🏃🏻‍♀' => 'obìrin tí ń sáré: amọ́lára',
    '🏃🏼‍♀' => 'obìrin tí ń sáré: amọ́lára díẹ̀',
    '🏃🏽‍♀' => 'obìrin tí ń sáré: amọ́láwọ̀ díẹ̀',
    '🏃🏾‍♀' => 'obìrin tí ń sáré: adúláwọ̀ díẹ̀',
    '🏃🏿‍♀' => 'obìrin tí ń sáré: adúláwọ̀',
    '🏃🏻‍➡' => 'Ẹni N Sare: amọ́lára àtiìdojúkọ ọ̀tún',
    '🏃🏼‍➡' => 'Ẹni N Sare: amọ́lára díẹ̀ àtiìdojúkọ ọ̀tún',
    '🏃🏽‍➡' => 'Ẹni N Sare: amọ́láwọ̀ díẹ̀ àtiìdojúkọ ọ̀tún',
    '🏃🏾‍➡' => 'Ẹni N Sare: adúláwọ̀ díẹ̀ àtiìdojúkọ ọ̀tún',
    '🏃🏿‍➡' => 'Ẹni N Sare: adúláwọ̀ àtiìdojúkọ ọ̀tún',
    '👯🏻‍♀' => 'awọn obìnrin eleti ehoro: amọ́lára',
    '👯🏼‍♀' => 'awọn obìnrin eleti ehoro: amọ́lára díẹ̀',
    '👯🏽‍♀' => 'awọn obìnrin eleti ehoro: amọ́láwọ̀ díẹ̀',
    '👯🏾‍♀' => 'awọn obìnrin eleti ehoro: adúláwọ̀ díẹ̀',
    '👯🏿‍♀' => 'awọn obìnrin eleti ehoro: adúláwọ̀',
    '👯🏻‍♂' => 'àwọn ọkùnrin elétí ehoro: amọ́lára',
    '👯🏼‍♂' => 'àwọn ọkùnrin elétí ehoro: amọ́lára díẹ̀',
    '👯🏽‍♂' => 'àwọn ọkùnrin elétí ehoro: amọ́láwọ̀ díẹ̀',
    '👯🏾‍♂' => 'àwọn ọkùnrin elétí ehoro: adúláwọ̀ díẹ̀',
    '👯🏿‍♂' => 'àwọn ọkùnrin elétí ehoro: adúláwọ̀',
    '🧖🏻‍♂' => 'Ọkùnrin nínú Ìyàrá tó n gbóná: amọ́lára',
    '🧖🏼‍♂' => 'Ọkùnrin nínú Ìyàrá tó n gbóná: amọ́lára díẹ̀',
    '🧖🏽‍♂' => 'Ọkùnrin nínú Ìyàrá tó n gbóná: amọ́láwọ̀ díẹ̀',
    '🧖🏾‍♂' => 'Ọkùnrin nínú Ìyàrá tó n gbóná: adúláwọ̀ díẹ̀',
    '🧖🏿‍♂' => 'Ọkùnrin nínú Ìyàrá tó n gbóná: adúláwọ̀',
    '🧖🏻‍♀' => 'Obìnrin nínú Ìyàrá tó n gbóná: amọ́lára',
    '🧖🏼‍♀' => 'Obìnrin nínú Ìyàrá tó n gbóná: amọ́lára díẹ̀',
    '🧖🏽‍♀' => 'Obìnrin nínú Ìyàrá tó n gbóná: amọ́láwọ̀ díẹ̀',
    '🧖🏾‍♀' => 'Obìnrin nínú Ìyàrá tó n gbóná: adúláwọ̀ díẹ̀',
    '🧖🏿‍♀' => 'Obìnrin nínú Ìyàrá tó n gbóná: adúláwọ̀',
    '🧗🏻‍♂' => 'O̩kùnrin tó n gòkè: amọ́lára',
    '🧗🏼‍♂' => 'O̩kùnrin tó n gòkè: amọ́lára díẹ̀',
    '🧗🏽‍♂' => 'O̩kùnrin tó n gòkè: amọ́láwọ̀ díẹ̀',
    '🧗🏾‍♂' => 'O̩kùnrin tó n gòkè: adúláwọ̀ díẹ̀',
    '🧗🏿‍♂' => 'O̩kùnrin tó n gòkè: adúláwọ̀',
    '🧗🏻‍♀' => 'Obìnrin tó n gòkè: amọ́lára',
    '🧗🏼‍♀' => 'Obìnrin tó n gòkè: amọ́lára díẹ̀',
    '🧗🏽‍♀' => 'Obìnrin tó n gòkè: amọ́láwọ̀ díẹ̀',
    '🧗🏾‍♀' => 'Obìnrin tó n gòkè: adúláwọ̀ díẹ̀',
    '🧗🏿‍♀' => 'Obìnrin tó n gòkè: adúláwọ̀',
    '🏌🏻‍♂' => 'ọkùnrin tí ń gọ́ọ̀fù: amọ́lára',
    '🏌🏼‍♂' => 'ọkùnrin tí ń gọ́ọ̀fù: amọ́lára díẹ̀',
    '🏌🏽‍♂' => 'ọkùnrin tí ń gọ́ọ̀fù: amọ́láwọ̀ díẹ̀',
    '🏌🏾‍♂' => 'ọkùnrin tí ń gọ́ọ̀fù: adúláwọ̀ díẹ̀',
    '🏌🏿‍♂' => 'ọkùnrin tí ń gọ́ọ̀fù: adúláwọ̀',
    '🏌🏻‍♀' => 'obìnrin tí ń gọ́ọ̀fù: amọ́lára',
    '🏌🏼‍♀' => 'obìnrin tí ń gọ́ọ̀fù: amọ́lára díẹ̀',
    '🏌🏽‍♀' => 'obìnrin tí ń gọ́ọ̀fù: amọ́láwọ̀ díẹ̀',
    '🏌🏾‍♀' => 'obìnrin tí ń gọ́ọ̀fù: adúláwọ̀ díẹ̀',
    '🏌🏿‍♀' => 'obìnrin tí ń gọ́ọ̀fù: adúláwọ̀',
    '🏄🏻‍♂' => 'ọkùnrin tí ń wá íńtánẹ́tì: amọ́lára',
    '🏄🏼‍♂' => 'ọkùnrin tí ń wá íńtánẹ́tì: amọ́lára díẹ̀',
    '🏄🏽‍♂' => 'ọkùnrin tí ń wá íńtánẹ́tì: amọ́láwọ̀ díẹ̀',
    '🏄🏾‍♂' => 'ọkùnrin tí ń wá íńtánẹ́tì: adúláwọ̀ díẹ̀',
    '🏄🏿‍♂' => 'ọkùnrin tí ń wá íńtánẹ́tì: adúláwọ̀',
    '🏄🏻‍♀' => 'obìnrín tí ń wá íńtánẹ́tì: amọ́lára',
    '🏄🏼‍♀' => 'obìnrín tí ń wá íńtánẹ́tì: amọ́lára díẹ̀',
    '🏄🏽‍♀' => 'obìnrín tí ń wá íńtánẹ́tì: amọ́láwọ̀ díẹ̀',
    '🏄🏾‍♀' => 'obìnrín tí ń wá íńtánẹ́tì: adúláwọ̀ díẹ̀',
    '🏄🏿‍♀' => 'obìnrín tí ń wá íńtánẹ́tì: adúláwọ̀',
    '🚣🏻‍♂' => 'ọkùnrin tí ń wakọ̀ ojú omi kékeré: amọ́lára',
    '🚣🏼‍♂' => 'ọkùnrin tí ń wakọ̀ ojú omi kékeré: amọ́lára díẹ̀',
    '🚣🏽‍♂' => 'ọkùnrin tí ń wakọ̀ ojú omi kékeré: amọ́láwọ̀ díẹ̀',
    '🚣🏾‍♂' => 'ọkùnrin tí ń wakọ̀ ojú omi kékeré: adúláwọ̀ díẹ̀',
    '🚣🏿‍♂' => 'ọkùnrin tí ń wakọ̀ ojú omi kékeré: adúláwọ̀',
    '🚣🏻‍♀' => 'obìnrin tí ń wakọ̀ ojú omi kékeré: amọ́lára',
    '🚣🏼‍♀' => 'obìnrin tí ń wakọ̀ ojú omi kékeré: amọ́lára díẹ̀',
    '🚣🏽‍♀' => 'obìnrin tí ń wakọ̀ ojú omi kékeré: amọ́láwọ̀ díẹ̀',
    '🚣🏾‍♀' => 'obìnrin tí ń wakọ̀ ojú omi kékeré: adúláwọ̀ díẹ̀',
    '🚣🏿‍♀' => 'obìnrin tí ń wakọ̀ ojú omi kékeré: adúláwọ̀',
    '🏊🏻‍♂' => 'ọkùnrin tí ń wẹdò: amọ́lára',
    '🏊🏼‍♂' => 'ọkùnrin tí ń wẹdò: amọ́lára díẹ̀',
    '🏊🏽‍♂' => 'ọkùnrin tí ń wẹdò: amọ́láwọ̀ díẹ̀',
    '🏊🏾‍♂' => 'ọkùnrin tí ń wẹdò: adúláwọ̀ díẹ̀',
    '🏊🏿‍♂' => 'ọkùnrin tí ń wẹdò: adúláwọ̀',
    '🏊🏻‍♀' => 'obìnrin tí ń wẹdò: amọ́lára',
    '🏊🏼‍♀' => 'obìnrin tí ń wẹdò: amọ́lára díẹ̀',
    '🏊🏽‍♀' => 'obìnrin tí ń wẹdò: amọ́láwọ̀ díẹ̀',
    '🏊🏾‍♀' => 'obìnrin tí ń wẹdò: adúláwọ̀ díẹ̀',
    '🏊🏿‍♀' => 'obìnrin tí ń wẹdò: adúláwọ̀',
    '⛹🏻‍♂' => 'ọkùnrin tí ń tà boun bọ́ọ̀lù: amọ́lára',
    '⛹🏼‍♂' => 'ọkùnrin tí ń tà boun bọ́ọ̀lù: amọ́lára díẹ̀',
    '⛹🏽‍♂' => 'ọkùnrin tí ń tà boun bọ́ọ̀lù: amọ́láwọ̀ díẹ̀',
    '⛹🏾‍♂' => 'ọkùnrin tí ń tà boun bọ́ọ̀lù: adúláwọ̀ díẹ̀',
    '⛹🏿‍♂' => 'ọkùnrin tí ń tà boun bọ́ọ̀lù: adúláwọ̀',
    '⛹🏻‍♀' => 'obìnrin tà boun bọ́ọ̀lù: amọ́lára',
    '⛹🏼‍♀' => 'obìnrin tà boun bọ́ọ̀lù: amọ́lára díẹ̀',
    '⛹🏽‍♀' => 'obìnrin tà boun bọ́ọ̀lù: amọ́láwọ̀ díẹ̀',
    '⛹🏾‍♀' => 'obìnrin tà boun bọ́ọ̀lù: adúláwọ̀ díẹ̀',
    '⛹🏿‍♀' => 'obìnrin tà boun bọ́ọ̀lù: adúláwọ̀',
    '🏋🏻‍♂' => 'ọkùnrin tí ń a fà ìwọ̀n sókè: amọ́lára',
    '🏋🏼‍♂' => 'ọkùnrin tí ń a fà ìwọ̀n sókè: amọ́lára díẹ̀',
    '🏋🏽‍♂' => 'ọkùnrin tí ń a fà ìwọ̀n sókè: amọ́láwọ̀ díẹ̀',
    '🏋🏾‍♂' => 'ọkùnrin tí ń a fà ìwọ̀n sókè: adúláwọ̀ díẹ̀',
    '🏋🏿‍♂' => 'ọkùnrin tí ń a fà ìwọ̀n sókè: adúláwọ̀',
    '🏋🏻‍♀' => 'obìnrin tí ń a fà ìwọ̀n sókè: amọ́lára',
    '🏋🏼‍♀' => 'obìnrin tí ń a fà ìwọ̀n sókè: amọ́lára díẹ̀',
    '🏋🏽‍♀' => 'obìnrin tí ń a fà ìwọ̀n sókè: amọ́láwọ̀ díẹ̀',
    '🏋🏾‍♀' => 'obìnrin tí ń a fà ìwọ̀n sókè: adúláwọ̀ díẹ̀',
    '🏋🏿‍♀' => 'obìnrin tí ń a fà ìwọ̀n sókè: adúláwọ̀',
    '🚴🏻‍♂' => 'ọkùnrin tí ń wa kẹ̀kẹ́: amọ́lára',
    '🚴🏼‍♂' => 'ọkùnrin tí ń wa kẹ̀kẹ́: amọ́lára díẹ̀',
    '🚴🏽‍♂' => 'ọkùnrin tí ń wa kẹ̀kẹ́: amọ́láwọ̀ díẹ̀',
    '🚴🏾‍♂' => 'ọkùnrin tí ń wa kẹ̀kẹ́: adúláwọ̀ díẹ̀',
    '🚴🏿‍♂' => 'ọkùnrin tí ń wa kẹ̀kẹ́: adúláwọ̀',
    '🚴🏻‍♀' => 'obìnrin tí ń wa kẹ̀kẹ́: amọ́lára',
    '🚴🏼‍♀' => 'obìnrin tí ń wa kẹ̀kẹ́: amọ́lára díẹ̀',
    '🚴🏽‍♀' => 'obìnrin tí ń wa kẹ̀kẹ́: amọ́láwọ̀ díẹ̀',
    '🚴🏾‍♀' => 'obìnrin tí ń wa kẹ̀kẹ́: adúláwọ̀ díẹ̀',
    '🚴🏿‍♀' => 'obìnrin tí ń wa kẹ̀kẹ́: adúláwọ̀',
    '🚵🏻‍♂' => 'ọkùnrin tín gùn kè wa kẹ̀kẹ́: amọ́lára',
    '🚵🏼‍♂' => 'ọkùnrin tín gùn kè wa kẹ̀kẹ́: amọ́lára díẹ̀',
    '🚵🏽‍♂' => 'ọkùnrin tín gùn kè wa kẹ̀kẹ́: amọ́láwọ̀ díẹ̀',
    '🚵🏾‍♂' => 'ọkùnrin tín gùn kè wa kẹ̀kẹ́: adúláwọ̀ díẹ̀',
    '🚵🏿‍♂' => 'ọkùnrin tín gùn kè wa kẹ̀kẹ́: adúláwọ̀',
    '🚵🏻‍♀' => 'obìnrin tín gùn kè wa kẹ̀kẹ́: amọ́lára',
    '🚵🏼‍♀' => 'obìnrin tín gùn kè wa kẹ̀kẹ́: amọ́lára díẹ̀',
    '🚵🏽‍♀' => 'obìnrin tín gùn kè wa kẹ̀kẹ́: amọ́láwọ̀ díẹ̀',
    '🚵🏾‍♀' => 'obìnrin tín gùn kè wa kẹ̀kẹ́: adúláwọ̀ díẹ̀',
    '🚵🏿‍♀' => 'obìnrin tín gùn kè wa kẹ̀kẹ́: adúláwọ̀',
    '🤸🏻‍♂' => 'ọkùnrin tí ń yí kẹ̀kẹ́ alágbọ̀n: amọ́lára',
    '🤸🏼‍♂' => 'ọkùnrin tí ń yí kẹ̀kẹ́ alágbọ̀n: amọ́lára díẹ̀',
    '🤸🏽‍♂' => 'ọkùnrin tí ń yí kẹ̀kẹ́ alágbọ̀n: amọ́láwọ̀ díẹ̀',
    '🤸🏾‍♂' => 'ọkùnrin tí ń yí kẹ̀kẹ́ alágbọ̀n: adúláwọ̀ díẹ̀',
    '🤸🏿‍♂' => 'ọkùnrin tí ń yí kẹ̀kẹ́ alágbọ̀n: adúláwọ̀',
    '🤸🏻‍♀' => 'obìnrin tí ń yí kẹ̀kẹ́ alágbọ̀n: amọ́lára',
    '🤸🏼‍♀' => 'obìnrin tí ń yí kẹ̀kẹ́ alágbọ̀n: amọ́lára díẹ̀',
    '🤸🏽‍♀' => 'obìnrin tí ń yí kẹ̀kẹ́ alágbọ̀n: amọ́láwọ̀ díẹ̀',
    '🤸🏾‍♀' => 'obìnrin tí ń yí kẹ̀kẹ́ alágbọ̀n: adúláwọ̀ díẹ̀',
    '🤸🏿‍♀' => 'obìnrin tí ń yí kẹ̀kẹ́ alágbọ̀n: adúláwọ̀',
    '🤼🏻‍♀' => 'àwọn obìnrn tí ń jà ijakadi: amọ́lára',
    '🤼🏼‍♀' => 'àwọn obìnrn tí ń jà ijakadi: amọ́lára díẹ̀',
    '🤼🏽‍♀' => 'àwọn obìnrn tí ń jà ijakadi: amọ́láwọ̀ díẹ̀',
    '🤼🏾‍♀' => 'àwọn obìnrn tí ń jà ijakadi: adúláwọ̀ díẹ̀',
    '🤼🏿‍♀' => 'àwọn obìnrn tí ń jà ijakadi: adúláwọ̀',
    '🤼🏻‍♂' => 'àwọn ọkùnrin ti n ja ijakadi: amọ́lára',
    '🤼🏼‍♂' => 'àwọn ọkùnrin ti n ja ijakadi: amọ́lára díẹ̀',
    '🤼🏽‍♂' => 'àwọn ọkùnrin ti n ja ijakadi: amọ́láwọ̀ díẹ̀',
    '🤼🏾‍♂' => 'àwọn ọkùnrin ti n ja ijakadi: adúláwọ̀ díẹ̀',
    '🤼🏿‍♂' => 'àwọn ọkùnrin ti n ja ijakadi: adúláwọ̀',
    '🤽🏻‍♂' => 'ọkùnrin n ṣere olomi: amọ́lára',
    '🤽🏼‍♂' => 'ọkùnrin n ṣere olomi: amọ́lára díẹ̀',
    '🤽🏽‍♂' => 'ọkùnrin n ṣere olomi: amọ́láwọ̀ díẹ̀',
    '🤽🏾‍♂' => 'ọkùnrin n ṣere olomi: adúláwọ̀ díẹ̀',
    '🤽🏿‍♂' => 'ọkùnrin n ṣere olomi: adúláwọ̀',
    '🤽🏻‍♀' => 'obìnrin n ṣere olomi: amọ́lára',
    '🤽🏼‍♀' => 'obìnrin n ṣere olomi: amọ́lára díẹ̀',
    '🤽🏽‍♀' => 'obìnrin n ṣere olomi: amọ́láwọ̀ díẹ̀',
    '🤽🏾‍♀' => 'obìnrin n ṣere olomi: adúláwọ̀ díẹ̀',
    '🤽🏿‍♀' => 'obìnrin n ṣere olomi: adúláwọ̀',
    '🤾🏻‍♂' => 'ọkùnrin tí ń gbá bọ́ọ̀lù ọlọ́wọ́: amọ́lára',
    '🤾🏼‍♂' => 'ọkùnrin tí ń gbá bọ́ọ̀lù ọlọ́wọ́: amọ́lára díẹ̀',
    '🤾🏽‍♂' => 'ọkùnrin tí ń gbá bọ́ọ̀lù ọlọ́wọ́: amọ́láwọ̀ díẹ̀',
    '🤾🏾‍♂' => 'ọkùnrin tí ń gbá bọ́ọ̀lù ọlọ́wọ́: adúláwọ̀ díẹ̀',
    '🤾🏿‍♂' => 'ọkùnrin tí ń gbá bọ́ọ̀lù ọlọ́wọ́: adúláwọ̀',
    '🤾🏻‍♀' => 'obìnrin tí ń gbá bọ́ọ̀lù ọlọ́wọ́: amọ́lára',
    '🤾🏼‍♀' => 'obìnrin tí ń gbá bọ́ọ̀lù ọlọ́wọ́: amọ́lára díẹ̀',
    '🤾🏽‍♀' => 'obìnrin tí ń gbá bọ́ọ̀lù ọlọ́wọ́: amọ́láwọ̀ díẹ̀',
    '🤾🏾‍♀' => 'obìnrin tí ń gbá bọ́ọ̀lù ọlọ́wọ́: adúláwọ̀ díẹ̀',
    '🤾🏿‍♀' => 'obìnrin tí ń gbá bọ́ọ̀lù ọlọ́wọ́: adúláwọ̀',
    '🤹🏻‍♂' => 'ọkùnrin tí ń jù ǹkan sókè: amọ́lára',
    '🤹🏼‍♂' => 'ọkùnrin tí ń jù ǹkan sókè: amọ́lára díẹ̀',
    '🤹🏽‍♂' => 'ọkùnrin tí ń jù ǹkan sókè: amọ́láwọ̀ díẹ̀',
    '🤹🏾‍♂' => 'ọkùnrin tí ń jù ǹkan sókè: adúláwọ̀ díẹ̀',
    '🤹🏿‍♂' => 'ọkùnrin tí ń jù ǹkan sókè: adúláwọ̀',
    '🤹🏻‍♀' => 'obìnrin tí ń jú ǹkan sókè: amọ́lára',
    '🤹🏼‍♀' => 'obìnrin tí ń jú ǹkan sókè: amọ́lára díẹ̀',
    '🤹🏽‍♀' => 'obìnrin tí ń jú ǹkan sókè: amọ́láwọ̀ díẹ̀',
    '🤹🏾‍♀' => 'obìnrin tí ń jú ǹkan sókè: adúláwọ̀ díẹ̀',
    '🤹🏿‍♀' => 'obìnrin tí ń jú ǹkan sókè: adúláwọ̀',
    '🧘🏻‍♂' => 'Ọkùnrin nípò ìgbàgbé: amọ́lára',
    '🧘🏼‍♂' => 'Ọkùnrin nípò ìgbàgbé: amọ́lára díẹ̀',
    '🧘🏽‍♂' => 'Ọkùnrin nípò ìgbàgbé: amọ́láwọ̀ díẹ̀',
    '🧘🏾‍♂' => 'Ọkùnrin nípò ìgbàgbé: adúláwọ̀ díẹ̀',
    '🧘🏿‍♂' => 'Ọkùnrin nípò ìgbàgbé: adúláwọ̀',
    '🧘🏻‍♀' => 'Obìnrin nípò ìgbàgbé: amọ́lára',
    '🧘🏼‍♀' => 'Obìnrin nípò ìgbàgbé: amọ́lára díẹ̀',
    '🧘🏽‍♀' => 'Obìnrin nípò ìgbàgbé: amọ́láwọ̀ díẹ̀',
    '🧘🏾‍♀' => 'Obìnrin nípò ìgbàgbé: adúláwọ̀ díẹ̀',
    '🧘🏿‍♀' => 'Obìnrin nípò ìgbàgbé: adúláwọ̀',
    '🧑‍🦰' => 'àgbà: irun pupa',
    '🧑‍🦱' => 'àgbà: irun rírọ̀',
    '🧑‍🦳' => 'àgbà: irun funfun',
    '🧑‍🦲' => 'àgbà: orí pípá',
    '👨‍🦰' => 'Ọkùnrin: irun pupa',
    '👨‍🦱' => 'Ọkùnrin: irun rírọ̀',
    '👨‍🦳' => 'Ọkùnrin: irun funfun',
    '👨‍🦲' => 'Ọkùnrin: orí pípá',
    '👩‍🦰' => 'Obìnrin: irun pupa',
    '👩‍🦱' => 'Obìnrin: irun rírọ̀',
    '👩‍🦳' => 'Obìnrin: irun funfun',
    '👩‍🦲' => 'Obìnrin: orí pípá',
    '🚶‍➡' => 'Ẹni N Rin: ìdojúkọ ọ̀tún',
    '🧎‍➡' => 'ènìyàn kíkúnlẹ̀: ìdojúkọ ọ̀tún',
    '🏃‍➡' => 'Ẹni N Sare: ìdojúkọ ọ̀tún',
    '👨‍👦' => 'Ẹbí: Ọkùnrin àtiọmọkùnrin',
    '👨‍👧' => 'Ẹbí: Ọkùnrin àtiọmọbìrin',
    '👩‍👦' => 'Ẹbí: Obìnrin àtiọmọkùnrin',
    '👩‍👧' => 'Ẹbí: Obìnrin àtiọmọbìrin',
    '😶‍🌫' => 'ojú nínú àwọ̀sánmà',
    '😮‍💨' => 'ojú ń mí síta',
    '🙂‍↕' => 'orí mímì látòkè-sílẹ̀',
    '😵‍💫' => 'ojú pẹ̀lú ẹyinjú lílọ́pọ̀',
    '❤‍🔥' => 'iná ń jóni lọ́kàn',
    '❤‍🩹' => 'ọkàn tó ń ṣàtúnṣe ara rẹ̀',
    '👁‍🗨' => 'ojú ní àlú ọ̀rọ̀',
    '🧔‍♂' => 'ọkùnrin: irùgbọ̀n',
    '👱‍♂' => 'ọkùnrin onírun funfun',
    '🧔‍♀' => 'obìnrin: irùgbọ̀n',
    '👱‍♀' => 'obìnrin onírun funfun',
    '🙍‍♂' => 'ọkùnrin tí ń fajúro',
    '🙍‍♀' => 'obìnrin tí ń fajúro',
    '🙎‍♂' => 'ọkùnrin tí ń ṣíṣù ètè síta',
    '🙎‍♀' => 'obìnrin tí ń ṣíṣù ètè síta',
    '🙅‍♂' => 'ọkùnrin tí ń sọ RÁRÁ',
    '🙅‍♀' => 'obìnrin tí ń sọ RÁRÁ',
    '🙆‍♂' => 'ọkùnrin tí ń sọ ÓDÁRA',
    '🙆‍♀' => 'obìnrin tí ń sọ ÓDÁRA',
    '💁‍♂' => 'ọkùnrin tí ń tọ́ka ọwọ́',
    '💁‍♀' => 'obìnrin tí ń tọ́ka ọwọ́',
    '🙋‍♂' => 'ọkùnrintí ń nawọ́ sókè',
    '🙋‍♀' => 'obìnrin tí ń nawọ́ sókè',
    '🧏‍♂' => 'ọkùnrin adití',
    '🧏‍♀' => 'obìnrin adití',
    '🙇‍♂' => 'ọkùnrin tí ń tẹríba',
    '🙇‍♀' => 'obìnrin tí ń tẹríba',
    '🤦‍♂' => 'ọkùnrin tín fọwọ́bojú',
    '🤦‍♀' => 'obìnrí tín fọwọ́bojú',
    '🤷‍♂' => 'ọkùnrin tí ń gúnpá',
    '🤷‍♀' => 'obìǹrin tí ń gúnpa',
    '🧑‍⚕' => 'òṣìṣẹ́ ìlera',
    '👨‍⚕' => 'ọkùnrín òṣìṣẹ́ ètò ìlera',
    '👩‍⚕' => 'obìrin òṣìṣẹ́ ètò ìlera',
    '🧑‍🎓' => 'akẹ́kọ̀ọ́',
    '👨‍🎓' => 'ọkùnrin akẹ́kọ̀ọ́',
    '👩‍🎓' => 'obìrin akẹ́kọ̀ọ́',
    '🧑‍🏫' => 'olùkọ́',
    '👨‍🏫' => 'ọkùnrin olùkọ́',
    '👩‍🏫' => 'obìnrin olùkọ́',
    '🧑‍⚖' => 'adájọ́',
    '👨‍⚖' => 'ọkùnrin adájọ́',
    '👩‍⚖' => 'obìnrin adájọ́',
    '🧑‍🌾' => 'àgbẹ̀',
    '👨‍🌾' => 'ọkùnrin àgbẹ́',
    '👩‍🌾' => 'obìrinàgbẹ́',
    '🧑‍🍳' => 'alásè',
    '👨‍🍳' => 'ọkùnrin olùse ónjẹ',
    '👩‍🍳' => 'obìrin olùse ónjẹ',
    '🧑‍🔧' => 'mẹkáníìkì',
    '👨‍🔧' => 'ọkùnrin atún ọkọ̀ ṣe',
    '👩‍🔧' => 'obìrin atún ọkọ̀ ṣe',
    '🧑‍🏭' => 'òṣìṣẹ́ ilé-iṣẹ́ aṣàgbéjáde ọjà',
    '👨‍🏭' => 'ọkùnrin òṣìṣẹ́ ilé-iṣẹ́',
    '👩‍🏭' => 'obìrin òṣìṣẹ́ ilé-iṣẹ́',
    '🧑‍💼' => 'òṣìṣẹ́ ọ́fíìsì',
    '👨‍💼' => 'ọkùnrin òṣìṣẹ́ ọ́físì',
    '👩‍💼' => 'obìrin òṣìṣẹ́ ọ́físì',
    '🧑‍🔬' => 'onímọ̀ sáyẹ́ǹsì',
    '👨‍🔬' => 'ọkùnrín síyẹ́nsì',
    '👩‍🔬' => 'obìrin síyẹ́nsì',
    '🧑‍💻' => 'akọ́ṣẹ́mọṣẹ́ ìmọ̀-ẹ̀rọ',
    '👨‍💻' => 'ọkùnrin oníms ẹ̀rọ',
    '👩‍💻' => 'obìrin onímọ̀ ẹ̀rọ',
    '🧑‍🎤' => 'akọrin',
    '👨‍🎤' => 'ọkùnrin olórin',
    '👩‍🎤' => 'obìnrin olórin',
    '🧑‍🎨' => 'aṣẹ̀dá àwòrán',
    '👨‍🎨' => 'ọkùnrin òṣèré',
    '👩‍🎨' => 'obìrin òṣèré',
    '🧑‍✈' => 'atukọ̀-òfurufú',
    '👨‍✈' => 'ọkùnrin awa ọkọ́ bàlú',
    '👩‍✈' => 'obìrin awa ọkọ́ bàlú',
    '🧑‍🚀' => 'arìnrìn-àjò lọ sí ayé mìíràn',
    '👨‍🚀' => 'ọkùnrin olùwádìí inú òṣùpá',
    '👩‍🚀' => 'obìrinolùwádìí inú òṣùpá',
    '🧑‍🚒' => 'panápaná',
    '👨‍🚒' => 'ọkùnrin panapanọ́',
    '👩‍🚒' => 'obìrin panapanọ́',
    '👮‍♂' => 'ọkùnrin ọlọpa',
    '👮‍♀' => 'obìnrin ọlọpa',
    '🕵‍♂' => 'ọkùnrin ọ̀tẹlèmúyé',
    '🕵‍♀' => 'obìnrin ọ̀tẹlèmúyé',
    '💂‍♂' => 'ọkùnrin olùṣọ́',
    '💂‍♀' => 'obìnrin olùṣọ́',
    '👷‍♂' => 'òṣiṣẹ́ ìkọ́lé ọkùnrin',
    '👷‍♀' => 'òṣiṣẹ́ ìkọ́lé obìnrin',
    '👳‍♂' => 'ọkùnrin tó dé láwàní',
    '👳‍♀' => 'obìnrin tó dé láwàní',
    '🤵‍♂' => 'ọkùnrin tó wọ kóòtù ìlọsóde ìrọ̀lẹ́',
    '🤵‍♀' => 'obìnrin tó wọ kóòtù ìlọsóde ìrọ̀lẹ́',
    '👰‍♂' => 'ọkùnrin tó fi aṣọ bojú',
    '👰‍♀' => 'obìnrin tó fi aṣọ bojú',
    '👩‍🍼' => 'obìnrin tó ń fọ́mọ lóúnjẹ',
    '👨‍🍼' => 'ọkùnrin tó ń fọ́mọ lóúnjẹ',
    '🧑‍🍼' => 'ẹnìkan tó ń fọ́mọ lóúnjẹ',
    '🧑‍🎄' => 'mx claus',
    '🦸‍♂' => 'ọkùnrin akọni ńlá',
    '🦸‍♀' => 'obìnrin akọni ńlá',
    '🦹‍♂' => 'ọkùnrin aṣèbàjẹ́ ńlá',
    '🦹‍♀' => 'obìnrin aṣèbàjẹ́ ńlá',
    '🧙‍♂' => 'Ọkùnrin onídán',
    '🧙‍♀' => 'Obìnrin onídán',
    '🧚‍♂' => 'Iwin ọkùnrin',
    '🧚‍♀' => 'Iwin obìnrin',
    '🧛‍♂' => 'Fánpáyà ọkùnrin',
    '🧛‍♀' => 'Fánpáyà obìnrin',
    '🧜‍♂' => 'Yemọja ọkùnrin',
    '🧜‍♀' => 'iyemọja',
    '🧝‍♂' => 'egbére ọkùnrin',
    '🧝‍♀' => 'egbére obìnrin',
    '🧞‍♂' => 'Ànjọ̀nnú ọkùnrin',
    '🧞‍♀' => 'Ànjọ̀nnú obìnrin',
    '🧟‍♂' => 'Ẹbọra ọkùnrin',
    '🧟‍♀' => 'Ẹbọra obìnrin',
    '💆‍♂' => 'ọkùnrin tí ń gba ifọwọwọnilara',
    '💆‍♀' => 'obìnrin tí ń gba ifọwọwọnilara',
    '💇‍♂' => 'ọkùnrin tí ń gẹrun',
    '💇‍♀' => 'obìnrin tí ń gẹrun',
    '🚶‍♂' => 'ọkùnrin tí ń rìn',
    '🚶‍♀' => 'obìnrin tí ń rìn',
    '🧍‍♂' => 'ọkùnrin tó dúró',
    '🧍‍♀' => 'obìnrin tó dúró',
    '🧎‍♂' => 'ọkùnrin tó kúnlẹ̀',
    '🧎‍♀' => 'obìnrin tó kúnlẹ̀',
    '🧑‍🦯' => 'ènìyàn pẹ̀lú ọ̀pá funfun',
    '👨‍🦯' => 'ọkùnrin pẹ̀lú ọ̀pá funfun',
    '👩‍🦯' => 'obìnrin pẹ̀lú ọ̀pá funfun',
    '🧑‍🦼' => 'ènìyàn nínú kẹ̀kẹ́-abirùn ẹlẹ́rọ-mọ́tò',
    '👨‍🦼' => 'ọkùnrin nínú kẹ̀kẹ́-abirùn ẹlẹ́rọ-mọ́tò',
    '👩‍🦼' => 'obìnrin nínú kẹ̀kẹ́-abirùn ẹlẹ́rọ-mọ́tò',
    '🧑‍🦽' => 'ènìyàn nínú kẹ̀kẹ́-abirùn aláfọwọ́yí',
    '👨‍🦽' => 'ọkùnrin nínú kẹ̀kẹ́-abirùn aláfọwọ́yí',
    '👩‍🦽' => 'obìnrin nínú kẹ̀kẹ́-abirùn aláfọwọ́yí',
    '🏃‍♂' => 'ọkùnrin tí ń sáré',
    '🏃‍♀' => 'obìrin tí ń sáré',
    '🧑‍🩰' => 'oníjó alájòóyípo',
    '👯‍♂' => 'àwọn ọkùnrin elétí ehoro',
    '👯‍♀' => 'awọn obìnrin eleti ehoro',
    '🧖‍♂' => 'Ọkùnrin nínú Ìyàrá tó n gbóná',
    '🧖‍♀' => 'Obìnrin nínú Ìyàrá tó n gbóná',
    '🧗‍♂' => 'O̩kùnrin tó n gòkè',
    '🧗‍♀' => 'Obìnrin tó n gòkè',
    '🏌‍♂' => 'ọkùnrin tí ń gọ́ọ̀fù',
    '🏌‍♀' => 'obìnrin tí ń gọ́ọ̀fù',
    '🏄‍♂' => 'ọkùnrin tí ń wá íńtánẹ́tì',
    '🏄‍♀' => 'obìnrín tí ń wá íńtánẹ́tì',
    '🚣‍♂' => 'ọkùnrin tí ń wakọ̀ ojú omi kékeré',
    '🚣‍♀' => 'obìnrin tí ń wakọ̀ ojú omi kékeré',
    '🏊‍♂' => 'ọkùnrin tí ń wẹdò',
    '🏊‍♀' => 'obìnrin tí ń wẹdò',
    '⛹‍♂' => 'ọkùnrin tí ń tà boun bọ́ọ̀lù',
    '⛹‍♀' => 'obìnrin tà boun bọ́ọ̀lù',
    '🏋‍♂' => 'ọkùnrin tí ń a fà ìwọ̀n sókè',
    '🏋‍♀' => 'obìnrin tí ń a fà ìwọ̀n sókè',
    '🚴‍♂' => 'ọkùnrin tí ń wa kẹ̀kẹ́',
    '🚴‍♀' => 'obìnrin tí ń wa kẹ̀kẹ́',
    '🚵‍♂' => 'ọkùnrin tín gùn kè wa kẹ̀kẹ́',
    '🚵‍♀' => 'obìnrin tín gùn kè wa kẹ̀kẹ́',
    '🤸‍♂' => 'ọkùnrin tí ń yí kẹ̀kẹ́ alágbọ̀n',
    '🤸‍♀' => 'obìnrin tí ń yí kẹ̀kẹ́ alágbọ̀n',
    '🤼‍♂' => 'àwọn ọkùnrin ti n ja ijakadi',
    '🤼‍♀' => 'àwọn obìnrn tí ń jà ijakadi',
    '🤽‍♂' => 'ọkùnrin n ṣere olomi',
    '🤽‍♀' => 'obìnrin n ṣere olomi',
    '🤾‍♂' => 'ọkùnrin tí ń gbá bọ́ọ̀lù ọlọ́wọ́',
    '🤾‍♀' => 'obìnrin tí ń gbá bọ́ọ̀lù ọlọ́wọ́',
    '🤹‍♂' => 'ọkùnrin tí ń jù ǹkan sókè',
    '🤹‍♀' => 'obìnrin tí ń jú ǹkan sókè',
    '🧘‍♂' => 'Ọkùnrin nípò ìgbàgbé',
    '🧘‍♀' => 'Obìnrin nípò ìgbàgbé',
    '🧑‍🧒' => 'ìdílé: àgbàlagbà, ọmọdé',
    '🐕‍🦺' => 'ajá iṣẹ́ àwọn abirùn',
    '🐈‍⬛' => 'ológbò dúdú',
    '🐻‍❄' => 'ẹranko beari funfun tí ń gbé orí yìnyín',
    '🐦‍⬛' => 'ẹyẹ dúdú',
    '🐦‍🔥' => 'ẹyẹ ìtàn àìlèkú',
    '🍋‍🟩' => 'ọsàn wẹ́wẹ́',
    '🍄‍🟫' => 'olú aláwọ̀ pupa rẹ́súrẹ́sú',
    '⛓‍💥' => 'ìdè tó ti já',
    '🏳‍🌈' => 'àsíá olóṣùmarè',
    '🏳‍⚧' => 'àsíá aṣàyípadà-akọ-n-bábo',
    '🏴‍☠' => 'àsíá jàgùdà orí omi-òkun',
    '👋🏻' => 'N Juwọ: amọ́lára',
    '👋🏼' => 'N Juwọ: amọ́lára díẹ̀',
    '👋🏽' => 'N Juwọ: amọ́láwọ̀ díẹ̀',
    '👋🏾' => 'N Juwọ: adúláwọ̀ díẹ̀',
    '👋🏿' => 'N Juwọ: adúláwọ̀',
    '🤚🏻' => 'Na Ẹhin Ọwọ Soke: amọ́lára',
    '🤚🏼' => 'Na Ẹhin Ọwọ Soke: amọ́lára díẹ̀',
    '🤚🏽' => 'Na Ẹhin Ọwọ Soke: amọ́láwọ̀ díẹ̀',
    '🤚🏾' => 'Na Ẹhin Ọwọ Soke: adúláwọ̀ díẹ̀',
    '🤚🏿' => 'Na Ẹhin Ọwọ Soke: adúláwọ̀',
    '🖐🏻' => 'nawọ́ sókè pẹ̀lú ìyàka: amọ́lára',
    '🖐🏼' => 'nawọ́ sókè pẹ̀lú ìyàka: amọ́lára díẹ̀',
    '🖐🏽' => 'nawọ́ sókè pẹ̀lú ìyàka: amọ́láwọ̀ díẹ̀',
    '🖐🏾' => 'nawọ́ sókè pẹ̀lú ìyàka: adúláwọ̀ díẹ̀',
    '🖐🏿' => 'nawọ́ sókè pẹ̀lú ìyàka: adúláwọ̀',
    '✋🏻' => 'Ọwọ Nina Soke: amọ́lára',
    '✋🏼' => 'Ọwọ Nina Soke: amọ́lára díẹ̀',
    '✋🏽' => 'Ọwọ Nina Soke: amọ́láwọ̀ díẹ̀',
    '✋🏾' => 'Ọwọ Nina Soke: adúláwọ̀ díẹ̀',
    '✋🏿' => 'Ọwọ Nina Soke: adúláwọ̀',
    '🖖🏻' => 'Kiki Ibẹri Funni: amọ́lára',
    '🖖🏼' => 'Kiki Ibẹri Funni: amọ́lára díẹ̀',
    '🖖🏽' => 'Kiki Ibẹri Funni: amọ́láwọ̀ díẹ̀',
    '🖖🏾' => 'Kiki Ibẹri Funni: adúláwọ̀ díẹ̀',
    '🖖🏿' => 'Kiki Ibẹri Funni: adúláwọ̀',
    '🫱🏻' => 'ọwọ́ ọ̀tún: amọ́lára',
    '🫱🏼' => 'ọwọ́ ọ̀tún: amọ́lára díẹ̀',
    '🫱🏽' => 'ọwọ́ ọ̀tún: amọ́láwọ̀ díẹ̀',
    '🫱🏾' => 'ọwọ́ ọ̀tún: adúláwọ̀ díẹ̀',
    '🫱🏿' => 'ọwọ́ ọ̀tún: adúláwọ̀',
    '🫲🏻' => 'ọwọ́ òsì: amọ́lára',
    '🫲🏼' => 'ọwọ́ òsì: amọ́lára díẹ̀',
    '🫲🏽' => 'ọwọ́ òsì: amọ́láwọ̀ díẹ̀',
    '🫲🏾' => 'ọwọ́ òsì: adúláwọ̀ díẹ̀',
    '🫲🏿' => 'ọwọ́ òsì: adúláwọ̀',
    '🫳🏻' => 'àtẹ́lẹ̀wọ́ ìsàlẹ̀: amọ́lára',
    '🫳🏼' => 'àtẹ́lẹ̀wọ́ ìsàlẹ̀: amọ́lára díẹ̀',
    '🫳🏽' => 'àtẹ́lẹ̀wọ́ ìsàlẹ̀: amọ́láwọ̀ díẹ̀',
    '🫳🏾' => 'àtẹ́lẹ̀wọ́ ìsàlẹ̀: adúláwọ̀ díẹ̀',
    '🫳🏿' => 'àtẹ́lẹ̀wọ́ ìsàlẹ̀: adúláwọ̀',
    '🫴🏻' => 'àtẹ́lẹwọ́ òkè: amọ́lára',
    '🫴🏼' => 'àtẹ́lẹwọ́ òkè: amọ́lára díẹ̀',
    '🫴🏽' => 'àtẹ́lẹwọ́ òkè: amọ́láwọ̀ díẹ̀',
    '🫴🏾' => 'àtẹ́lẹwọ́ òkè: adúláwọ̀ díẹ̀',
    '🫴🏿' => 'àtẹ́lẹwọ́ òkè: adúláwọ̀',
    '🫷🏻' => 'títi ọwọ́ sọ́sì: amọ́lára',
    '🫷🏼' => 'títi ọwọ́ sọ́sì: amọ́lára díẹ̀',
    '🫷🏽' => 'títi ọwọ́ sọ́sì: amọ́láwọ̀ díẹ̀',
    '🫷🏾' => 'títi ọwọ́ sọ́sì: adúláwọ̀ díẹ̀',
    '🫷🏿' => 'títi ọwọ́ sọ́sì: adúláwọ̀',
    '🫸🏻' => 'títi ọwọ́ sọ́tun: amọ́lára',
    '🫸🏼' => 'títi ọwọ́ sọ́tun: amọ́lára díẹ̀',
    '🫸🏽' => 'títi ọwọ́ sọ́tun: amọ́láwọ̀ díẹ̀',
    '🫸🏾' => 'títi ọwọ́ sọ́tun: adúláwọ̀ díẹ̀',
    '🫸🏿' => 'títi ọwọ́ sọ́tun: adúláwọ̀',
    '👌🏻' => 'Ọwọ ODARA: amọ́lára',
    '👌🏼' => 'Ọwọ ODARA: amọ́lára díẹ̀',
    '👌🏽' => 'Ọwọ ODARA: amọ́láwọ̀ díẹ̀',
    '👌🏾' => 'Ọwọ ODARA: adúláwọ̀ díẹ̀',
    '👌🏿' => 'Ọwọ ODARA: adúláwọ̀',
    '🤌🏻' => 'ìka kíkákò: amọ́lára',
    '🤌🏼' => 'ìka kíkákò: amọ́lára díẹ̀',
    '🤌🏽' => 'ìka kíkákò: amọ́láwọ̀ díẹ̀',
    '🤌🏾' => 'ìka kíkákò: adúláwọ̀ díẹ̀',
    '🤌🏿' => 'ìka kíkákò: adúláwọ̀',
    '🤏🏻' => 'ìka kíká: amọ́lára',
    '🤏🏼' => 'ìka kíká: amọ́lára díẹ̀',
    '🤏🏽' => 'ìka kíká: amọ́láwọ̀ díẹ̀',
    '🤏🏾' => 'ìka kíká: adúláwọ̀ díẹ̀',
    '🤏🏿' => 'ìka kíká: adúláwọ̀',
    '✌🏻' => 'aṣeyọrí ọwọ́: amọ́lára',
    '✌🏼' => 'aṣeyọrí ọwọ́: amọ́lára díẹ̀',
    '✌🏽' => 'aṣeyọrí ọwọ́: amọ́láwọ̀ díẹ̀',
    '✌🏾' => 'aṣeyọrí ọwọ́: adúláwọ̀ díẹ̀',
    '✌🏿' => 'aṣeyọrí ọwọ́: adúláwọ̀',
    '🤞🏻' => 'Igbekalera: amọ́lára',
    '🤞🏼' => 'Igbekalera: amọ́lára díẹ̀',
    '🤞🏽' => 'Igbekalera: amọ́láwọ̀ díẹ̀',
    '🤞🏾' => 'Igbekalera: adúláwọ̀ díẹ̀',
    '🤞🏿' => 'Igbekalera: adúláwọ̀',
    '🫰🏻' => 'ọwọ́ pẹ̀lú ìka kẹ́keré àti ìka ńlá ní pípapọ̀: amọ́lára',
    '🫰🏼' => 'ọwọ́ pẹ̀lú ìka kẹ́keré àti ìka ńlá ní pípapọ̀: amọ́lára díẹ̀',
    '🫰🏽' => 'ọwọ́ pẹ̀lú ìka kẹ́keré àti ìka ńlá ní pípapọ̀: amọ́láwọ̀ díẹ̀',
    '🫰🏾' => 'ọwọ́ pẹ̀lú ìka kẹ́keré àti ìka ńlá ní pípapọ̀: adúláwọ̀ díẹ̀',
    '🫰🏿' => 'ọwọ́ pẹ̀lú ìka kẹ́keré àti ìka ńlá ní pípapọ̀: adúláwọ̀',
    '🤟🏻' => 'ìfọwọ́júwè mo ní ìfẹ́: amọ́lára',
    '🤟🏼' => 'ìfọwọ́júwè mo ní ìfẹ́: amọ́lára díẹ̀',
    '🤟🏽' => 'ìfọwọ́júwè mo ní ìfẹ́: amọ́láwọ̀ díẹ̀',
    '🤟🏾' => 'ìfọwọ́júwè mo ní ìfẹ́: adúláwọ̀ díẹ̀',
    '🤟🏿' => 'ìfọwọ́júwè mo ní ìfẹ́: adúláwọ̀',
    '🤘🏻' => 'Aami Awọn Iwo: amọ́lára',
    '🤘🏼' => 'Aami Awọn Iwo: amọ́lára díẹ̀',
    '🤘🏽' => 'Aami Awọn Iwo: amọ́láwọ̀ díẹ̀',
    '🤘🏾' => 'Aami Awọn Iwo: adúláwọ̀ díẹ̀',
    '🤘🏿' => 'Aami Awọn Iwo: adúláwọ̀',
    '🤙🏻' => 'Ọwọ Ipeni: amọ́lára',
    '🤙🏼' => 'Ọwọ Ipeni: amọ́lára díẹ̀',
    '🤙🏽' => 'Ọwọ Ipeni: amọ́láwọ̀ díẹ̀',
    '🤙🏾' => 'Ọwọ Ipeni: adúláwọ̀ díẹ̀',
    '🤙🏿' => 'Ọwọ Ipeni: adúláwọ̀',
    '👈🏻' => 'Ẹyin Ọwọ Ti O Tọka Si Apa Osi: amọ́lára',
    '👈🏼' => 'Ẹyin Ọwọ Ti O Tọka Si Apa Osi: amọ́lára díẹ̀',
    '👈🏽' => 'Ẹyin Ọwọ Ti O Tọka Si Apa Osi: amọ́láwọ̀ díẹ̀',
    '👈🏾' => 'Ẹyin Ọwọ Ti O Tọka Si Apa Osi: adúláwọ̀ díẹ̀',
    '👈🏿' => 'Ẹyin Ọwọ Ti O Tọka Si Apa Osi: adúláwọ̀',
    '👉🏻' => 'Ẹyin Ọwọ Ti O Tọka Si Apa Ọtun: amọ́lára',
    '👉🏼' => 'Ẹyin Ọwọ Ti O Tọka Si Apa Ọtun: amọ́lára díẹ̀',
    '👉🏽' => 'Ẹyin Ọwọ Ti O Tọka Si Apa Ọtun: amọ́láwọ̀ díẹ̀',
    '👉🏾' => 'Ẹyin Ọwọ Ti O Tọka Si Apa Ọtun: adúláwọ̀ díẹ̀',
    '👉🏿' => 'Ẹyin Ọwọ Ti O Tọka Si Apa Ọtun: adúláwọ̀',
    '👆🏻' => 'Ẹyin Ọwọ Ti O Tọka Si Oke: amọ́lára',
    '👆🏼' => 'Ẹyin Ọwọ Ti O Tọka Si Oke: amọ́lára díẹ̀',
    '👆🏽' => 'Ẹyin Ọwọ Ti O Tọka Si Oke: amọ́láwọ̀ díẹ̀',
    '👆🏾' => 'Ẹyin Ọwọ Ti O Tọka Si Oke: adúláwọ̀ díẹ̀',
    '👆🏿' => 'Ẹyin Ọwọ Ti O Tọka Si Oke: adúláwọ̀',
    '🖕🏻' => 'ìka àárín: amọ́lára',
    '🖕🏼' => 'ìka àárín: amọ́lára díẹ̀',
    '🖕🏽' => 'ìka àárín: amọ́láwọ̀ díẹ̀',
    '🖕🏾' => 'ìka àárín: adúláwọ̀ díẹ̀',
    '🖕🏿' => 'ìka àárín: adúláwọ̀',
    '👇🏻' => 'Ẹyin Ọwọ Ti O Tọka Si Isalẹ: amọ́lára',
    '👇🏼' => 'Ẹyin Ọwọ Ti O Tọka Si Isalẹ: amọ́lára díẹ̀',
    '👇🏽' => 'Ẹyin Ọwọ Ti O Tọka Si Isalẹ: amọ́láwọ̀ díẹ̀',
    '👇🏾' => 'Ẹyin Ọwọ Ti O Tọka Si Isalẹ: adúláwọ̀ díẹ̀',
    '👇🏿' => 'Ẹyin Ọwọ Ti O Tọka Si Isalẹ: adúláwọ̀',
    '☝🏻' => 'ìka kékeré tí ń tọ́ka sókè: amọ́lára',
    '☝🏼' => 'ìka kékeré tí ń tọ́ka sókè: amọ́lára díẹ̀',
    '☝🏽' => 'ìka kékeré tí ń tọ́ka sókè: amọ́láwọ̀ díẹ̀',
    '☝🏾' => 'ìka kékeré tí ń tọ́ka sókè: adúláwọ̀ díẹ̀',
    '☝🏿' => 'ìka kékeré tí ń tọ́ka sókè: adúláwọ̀',
    '🫵🏻' => 'títọ́ka sí olùwòran: amọ́lára',
    '🫵🏼' => 'títọ́ka sí olùwòran: amọ́lára díẹ̀',
    '🫵🏽' => 'títọ́ka sí olùwòran: amọ́láwọ̀ díẹ̀',
    '🫵🏾' => 'títọ́ka sí olùwòran: adúláwọ̀ díẹ̀',
    '🫵🏿' => 'títọ́ka sí olùwòran: adúláwọ̀',
    '👍🏻' => 'Atanpako Loke: amọ́lára',
    '👍🏼' => 'Atanpako Loke: amọ́lára díẹ̀',
    '👍🏽' => 'Atanpako Loke: amọ́láwọ̀ díẹ̀',
    '👍🏾' => 'Atanpako Loke: adúláwọ̀ díẹ̀',
    '👍🏿' => 'Atanpako Loke: adúláwọ̀',
    '👎🏻' => 'Atanpako Nisalẹ: amọ́lára',
    '👎🏼' => 'Atanpako Nisalẹ: amọ́lára díẹ̀',
    '👎🏽' => 'Atanpako Nisalẹ: amọ́láwọ̀ díẹ̀',
    '👎🏾' => 'Atanpako Nisalẹ: adúláwọ̀ díẹ̀',
    '👎🏿' => 'Atanpako Nisalẹ: adúláwọ̀',
    '✊🏻' => 'Ẹṣẹ Ti a Na Soke: amọ́lára',
    '✊🏼' => 'Ẹṣẹ Ti a Na Soke: amọ́lára díẹ̀',
    '✊🏽' => 'Ẹṣẹ Ti a Na Soke: amọ́láwọ̀ díẹ̀',
    '✊🏾' => 'Ẹṣẹ Ti a Na Soke: adúláwọ̀ díẹ̀',
    '✊🏿' => 'Ẹṣẹ Ti a Na Soke: adúláwọ̀',
    '👊🏻' => 'Ẹṣẹ Ti o Nbọ: amọ́lára',
    '👊🏼' => 'Ẹṣẹ Ti o Nbọ: amọ́lára díẹ̀',
    '👊🏽' => 'Ẹṣẹ Ti o Nbọ: amọ́láwọ̀ díẹ̀',
    '👊🏾' => 'Ẹṣẹ Ti o Nbọ: adúláwọ̀ díẹ̀',
    '👊🏿' => 'Ẹṣẹ Ti o Nbọ: adúláwọ̀',
    '🤛🏻' => 'Ẹsẹ ti O Kọju sosi: amọ́lára',
    '🤛🏼' => 'Ẹsẹ ti O Kọju sosi: amọ́lára díẹ̀',
    '🤛🏽' => 'Ẹsẹ ti O Kọju sosi: amọ́láwọ̀ díẹ̀',
    '🤛🏾' => 'Ẹsẹ ti O Kọju sosi: adúláwọ̀ díẹ̀',
    '🤛🏿' => 'Ẹsẹ ti O Kọju sosi: adúláwọ̀',
    '🤜🏻' => 'Ẹsẹ ti O Kọju sọtun: amọ́lára',
    '🤜🏼' => 'Ẹsẹ ti O Kọju sọtun: amọ́lára díẹ̀',
    '🤜🏽' => 'Ẹsẹ ti O Kọju sọtun: amọ́láwọ̀ díẹ̀',
    '🤜🏾' => 'Ẹsẹ ti O Kọju sọtun: adúláwọ̀ díẹ̀',
    '🤜🏿' => 'Ẹsẹ ti O Kọju sọtun: adúláwọ̀',
    '👏🏻' => 'N Patẹwọ: amọ́lára',
    '👏🏼' => 'N Patẹwọ: amọ́lára díẹ̀',
    '👏🏽' => 'N Patẹwọ: amọ́láwọ̀ díẹ̀',
    '👏🏾' => 'N Patẹwọ: adúláwọ̀ díẹ̀',
    '👏🏿' => 'N Patẹwọ: adúláwọ̀',
    '🙌🏻' => 'Ina Awọn Ọwọ: amọ́lára',
    '🙌🏼' => 'Ina Awọn Ọwọ: amọ́lára díẹ̀',
    '🙌🏽' => 'Ina Awọn Ọwọ: amọ́láwọ̀ díẹ̀',
    '🙌🏾' => 'Ina Awọn Ọwọ: adúláwọ̀ díẹ̀',
    '🙌🏿' => 'Ina Awọn Ọwọ: adúláwọ̀',
    '🫶🏻' => 'ọwọ́ ọkàn: amọ́lára',
    '🫶🏼' => 'ọwọ́ ọkàn: amọ́lára díẹ̀',
    '🫶🏽' => 'ọwọ́ ọkàn: amọ́láwọ̀ díẹ̀',
    '🫶🏾' => 'ọwọ́ ọkàn: adúláwọ̀ díẹ̀',
    '🫶🏿' => 'ọwọ́ ọkàn: adúláwọ̀',
    '👐🏻' => 'Awọn Ọwọ Ṣiṣi: amọ́lára',
    '👐🏼' => 'Awọn Ọwọ Ṣiṣi: amọ́lára díẹ̀',
    '👐🏽' => 'Awọn Ọwọ Ṣiṣi: amọ́láwọ̀ díẹ̀',
    '👐🏾' => 'Awọn Ọwọ Ṣiṣi: adúláwọ̀ díẹ̀',
    '👐🏿' => 'Awọn Ọwọ Ṣiṣi: adúláwọ̀',
    '🤲🏻' => 'àtẹ́lẹ́ọwọ́ papọ̀: amọ́lára',
    '🤲🏼' => 'àtẹ́lẹ́ọwọ́ papọ̀: amọ́lára díẹ̀',
    '🤲🏽' => 'àtẹ́lẹ́ọwọ́ papọ̀: amọ́láwọ̀ díẹ̀',
    '🤲🏾' => 'àtẹ́lẹ́ọwọ́ papọ̀: adúláwọ̀ díẹ̀',
    '🤲🏿' => 'àtẹ́lẹ́ọwọ́ papọ̀: adúláwọ̀',
    '🤝🏻' => 'Ìbọwọ́: amọ́lára',
    '🤝🏼' => 'Ìbọwọ́: amọ́lára díẹ̀',
    '🤝🏽' => 'Ìbọwọ́: amọ́láwọ̀ díẹ̀',
    '🤝🏾' => 'Ìbọwọ́: adúláwọ̀ díẹ̀',
    '🤝🏿' => 'Ìbọwọ́: adúláwọ̀',
    '🙏🏻' => 'Ika Awọn Ọwọ: amọ́lára',
    '🙏🏼' => 'Ika Awọn Ọwọ: amọ́lára díẹ̀',
    '🙏🏽' => 'Ika Awọn Ọwọ: amọ́láwọ̀ díẹ̀',
    '🙏🏾' => 'Ika Awọn Ọwọ: adúláwọ̀ díẹ̀',
    '🙏🏿' => 'Ika Awọn Ọwọ: adúláwọ̀',
    '✍🏻' => 'ńkọ́wé: amọ́lára',
    '✍🏼' => 'ńkọ́wé: amọ́lára díẹ̀',
    '✍🏽' => 'ńkọ́wé: amọ́láwọ̀ díẹ̀',
    '✍🏾' => 'ńkọ́wé: adúláwọ̀ díẹ̀',
    '✍🏿' => 'ńkọ́wé: adúláwọ̀',
    '💅🏻' => 'Ikun Eekanna: amọ́lára',
    '💅🏼' => 'Ikun Eekanna: amọ́lára díẹ̀',
    '💅🏽' => 'Ikun Eekanna: amọ́láwọ̀ díẹ̀',
    '💅🏾' => 'Ikun Eekanna: adúláwọ̀ díẹ̀',
    '💅🏿' => 'Ikun Eekanna: adúláwọ̀',
    '🤳🏻' => 'Yiya Ara ẹni: amọ́lára',
    '🤳🏼' => 'Yiya Ara ẹni: amọ́lára díẹ̀',
    '🤳🏽' => 'Yiya Ara ẹni: amọ́láwọ̀ díẹ̀',
    '🤳🏾' => 'Yiya Ara ẹni: adúláwọ̀ díẹ̀',
    '🤳🏿' => 'Yiya Ara ẹni: adúláwọ̀',
    '💪🏻' => 'Aya Fifẹ: amọ́lára',
    '💪🏼' => 'Aya Fifẹ: amọ́lára díẹ̀',
    '💪🏽' => 'Aya Fifẹ: amọ́láwọ̀ díẹ̀',
    '💪🏾' => 'Aya Fifẹ: adúláwọ̀ díẹ̀',
    '💪🏿' => 'Aya Fifẹ: adúláwọ̀',
    '🦵🏻' => 'ese: amọ́lára',
    '🦵🏼' => 'ese: amọ́lára díẹ̀',
    '🦵🏽' => 'ese: amọ́láwọ̀ díẹ̀',
    '🦵🏾' => 'ese: adúláwọ̀ díẹ̀',
    '🦵🏿' => 'ese: adúláwọ̀',
    '🦶🏻' => 'ẹsẹ̀: amọ́lára',
    '🦶🏼' => 'ẹsẹ̀: amọ́lára díẹ̀',
    '🦶🏽' => 'ẹsẹ̀: amọ́láwọ̀ díẹ̀',
    '🦶🏾' => 'ẹsẹ̀: adúláwọ̀ díẹ̀',
    '🦶🏿' => 'ẹsẹ̀: adúláwọ̀',
    '👂🏻' => 'Etí: amọ́lára',
    '👂🏼' => 'Etí: amọ́lára díẹ̀',
    '👂🏽' => 'Etí: amọ́láwọ̀ díẹ̀',
    '👂🏾' => 'Etí: adúláwọ̀ díẹ̀',
    '👂🏿' => 'Etí: adúláwọ̀',
    '🦻🏻' => 'etí pẹ̀lú ohun ìgbọ́ràn: amọ́lára',
    '🦻🏼' => 'etí pẹ̀lú ohun ìgbọ́ràn: amọ́lára díẹ̀',
    '🦻🏽' => 'etí pẹ̀lú ohun ìgbọ́ràn: amọ́láwọ̀ díẹ̀',
    '🦻🏾' => 'etí pẹ̀lú ohun ìgbọ́ràn: adúláwọ̀ díẹ̀',
    '🦻🏿' => 'etí pẹ̀lú ohun ìgbọ́ràn: adúláwọ̀',
    '👃🏻' => 'Imu: amọ́lára',
    '👃🏼' => 'Imu: amọ́lára díẹ̀',
    '👃🏽' => 'Imu: amọ́láwọ̀ díẹ̀',
    '👃🏾' => 'Imu: adúláwọ̀ díẹ̀',
    '👃🏿' => 'Imu: adúláwọ̀',
    '👶🏻' => 'ìkókó: amọ́lára',
    '👶🏼' => 'ìkókó: amọ́lára díẹ̀',
    '👶🏽' => 'ìkókó: amọ́láwọ̀ díẹ̀',
    '👶🏾' => 'ìkókó: adúláwọ̀ díẹ̀',
    '👶🏿' => 'ìkókó: adúláwọ̀',
    '🧒🏻' => 'ọmọ: amọ́lára',
    '🧒🏼' => 'ọmọ: amọ́lára díẹ̀',
    '🧒🏽' => 'ọmọ: amọ́láwọ̀ díẹ̀',
    '🧒🏾' => 'ọmọ: adúláwọ̀ díẹ̀',
    '🧒🏿' => 'ọmọ: adúláwọ̀',
    '👦🏻' => 'ọmọkùnrin: amọ́lára',
    '👦🏼' => 'ọmọkùnrin: amọ́lára díẹ̀',
    '👦🏽' => 'ọmọkùnrin: amọ́láwọ̀ díẹ̀',
    '👦🏾' => 'ọmọkùnrin: adúláwọ̀ díẹ̀',
    '👦🏿' => 'ọmọkùnrin: adúláwọ̀',
    '👧🏻' => 'ọmọbìrin: amọ́lára',
    '👧🏼' => 'ọmọbìrin: amọ́lára díẹ̀',
    '👧🏽' => 'ọmọbìrin: amọ́láwọ̀ díẹ̀',
    '👧🏾' => 'ọmọbìrin: adúláwọ̀ díẹ̀',
    '👧🏿' => 'ọmọbìrin: adúláwọ̀',
    '🧑🏻' => 'àgbà: amọ́lára',
    '🧑🏼' => 'àgbà: amọ́lára díẹ̀',
    '🧑🏽' => 'àgbà: amọ́láwọ̀ díẹ̀',
    '🧑🏾' => 'àgbà: adúláwọ̀ díẹ̀',
    '🧑🏿' => 'àgbà: adúláwọ̀',
    '👱🏻' => 'Eniyan Onirun funfun: amọ́lára',
    '👱🏼' => 'Eniyan Onirun funfun: amọ́lára díẹ̀',
    '👱🏽' => 'Eniyan Onirun funfun: amọ́láwọ̀ díẹ̀',
    '👱🏾' => 'Eniyan Onirun funfun: adúláwọ̀ díẹ̀',
    '👱🏿' => 'Eniyan Onirun funfun: adúláwọ̀',
    '👨🏻' => 'Ọkùnrin: amọ́lára',
    '👨🏼' => 'Ọkùnrin: amọ́lára díẹ̀',
    '👨🏽' => 'Ọkùnrin: amọ́láwọ̀ díẹ̀',
    '👨🏾' => 'Ọkùnrin: adúláwọ̀ díẹ̀',
    '👨🏿' => 'Ọkùnrin: adúláwọ̀',
    '🧔🏻' => 'apárí: amọ́lára',
    '🧔🏼' => 'apárí: amọ́lára díẹ̀',
    '🧔🏽' => 'apárí: amọ́láwọ̀ díẹ̀',
    '🧔🏾' => 'apárí: adúláwọ̀ díẹ̀',
    '🧔🏿' => 'apárí: adúláwọ̀',
    '👩🏻' => 'Obìnrin: amọ́lára',
    '👩🏼' => 'Obìnrin: amọ́lára díẹ̀',
    '👩🏽' => 'Obìnrin: amọ́láwọ̀ díẹ̀',
    '👩🏾' => 'Obìnrin: adúláwọ̀ díẹ̀',
    '👩🏿' => 'Obìnrin: adúláwọ̀',
    '🧓🏻' => 'àgbàlagbà: amọ́lára',
    '🧓🏼' => 'àgbàlagbà: amọ́lára díẹ̀',
    '🧓🏽' => 'àgbàlagbà: amọ́láwọ̀ díẹ̀',
    '🧓🏾' => 'àgbàlagbà: adúláwọ̀ díẹ̀',
    '🧓🏿' => 'àgbàlagbà: adúláwọ̀',
    '👴🏻' => 'Agbalagba Ọkunrin: amọ́lára',
    '👴🏼' => 'Agbalagba Ọkunrin: amọ́lára díẹ̀',
    '👴🏽' => 'Agbalagba Ọkunrin: amọ́láwọ̀ díẹ̀',
    '👴🏾' => 'Agbalagba Ọkunrin: adúláwọ̀ díẹ̀',
    '👴🏿' => 'Agbalagba Ọkunrin: adúláwọ̀',
    '👵🏻' => 'Agbalagba Obinrin: amọ́lára',
    '👵🏼' => 'Agbalagba Obinrin: amọ́lára díẹ̀',
    '👵🏽' => 'Agbalagba Obinrin: amọ́láwọ̀ díẹ̀',
    '👵🏾' => 'Agbalagba Obinrin: adúláwọ̀ díẹ̀',
    '👵🏿' => 'Agbalagba Obinrin: adúláwọ̀',
    '🙍🏻' => 'Ẹni N Bojujẹ: amọ́lára',
    '🙍🏼' => 'Ẹni N Bojujẹ: amọ́lára díẹ̀',
    '🙍🏽' => 'Ẹni N Bojujẹ: amọ́láwọ̀ díẹ̀',
    '🙍🏾' => 'Ẹni N Bojujẹ: adúláwọ̀ díẹ̀',
    '🙍🏿' => 'Ẹni N Bojujẹ: adúláwọ̀',
    '🙎🏻' => 'Ẹni Yahọn sita: amọ́lára',
    '🙎🏼' => 'Ẹni Yahọn sita: amọ́lára díẹ̀',
    '🙎🏽' => 'Ẹni Yahọn sita: amọ́láwọ̀ díẹ̀',
    '🙎🏾' => 'Ẹni Yahọn sita: adúláwọ̀ díẹ̀',
    '🙎🏿' => 'Ẹni Yahọn sita: adúláwọ̀',
    '🙅🏻' => 'Ẹni Nsọ RARA: amọ́lára',
    '🙅🏼' => 'Ẹni Nsọ RARA: amọ́lára díẹ̀',
    '🙅🏽' => 'Ẹni Nsọ RARA: amọ́láwọ̀ díẹ̀',
    '🙅🏾' => 'Ẹni Nsọ RARA: adúláwọ̀ díẹ̀',
    '🙅🏿' => 'Ẹni Nsọ RARA: adúláwọ̀',
    '🙆🏻' => 'Ẹni Nsọ O DARA: amọ́lára',
    '🙆🏼' => 'Ẹni Nsọ O DARA: amọ́lára díẹ̀',
    '🙆🏽' => 'Ẹni Nsọ O DARA: amọ́láwọ̀ díẹ̀',
    '🙆🏾' => 'Ẹni Nsọ O DARA: adúláwọ̀ díẹ̀',
    '🙆🏿' => 'Ẹni Nsọ O DARA: adúláwọ̀',
    '💁🏻' => 'Ẹni N Tọka Ọwọ: amọ́lára',
    '💁🏼' => 'Ẹni N Tọka Ọwọ: amọ́lára díẹ̀',
    '💁🏽' => 'Ẹni N Tọka Ọwọ: amọ́láwọ̀ díẹ̀',
    '💁🏾' => 'Ẹni N Tọka Ọwọ: adúláwọ̀ díẹ̀',
    '💁🏿' => 'Ẹni N Tọka Ọwọ: adúláwọ̀',
    '🙋🏻' => 'Ẹni N Nawọ Soke: amọ́lára',
    '🙋🏼' => 'Ẹni N Nawọ Soke: amọ́lára díẹ̀',
    '🙋🏽' => 'Ẹni N Nawọ Soke: amọ́láwọ̀ díẹ̀',
    '🙋🏾' => 'Ẹni N Nawọ Soke: adúláwọ̀ díẹ̀',
    '🙋🏿' => 'Ẹni N Nawọ Soke: adúláwọ̀',
    '🧏🏻' => 'odi: amọ́lára',
    '🧏🏼' => 'odi: amọ́lára díẹ̀',
    '🧏🏽' => 'odi: amọ́láwọ̀ díẹ̀',
    '🧏🏾' => 'odi: adúláwọ̀ díẹ̀',
    '🧏🏿' => 'odi: adúláwọ̀',
    '🙇🏻' => 'Ẹni N Tẹriba: amọ́lára',
    '🙇🏼' => 'Ẹni N Tẹriba: amọ́lára díẹ̀',
    '🙇🏽' => 'Ẹni N Tẹriba: amọ́láwọ̀ díẹ̀',
    '🙇🏾' => 'Ẹni N Tẹriba: adúláwọ̀ díẹ̀',
    '🙇🏿' => 'Ẹni N Tẹriba: adúláwọ̀',
    '🤦🏻' => 'Ẹni Fọwọ Boju: amọ́lára',
    '🤦🏼' => 'Ẹni Fọwọ Boju: amọ́lára díẹ̀',
    '🤦🏽' => 'Ẹni Fọwọ Boju: amọ́láwọ̀ díẹ̀',
    '🤦🏾' => 'Ẹni Fọwọ Boju: adúláwọ̀ díẹ̀',
    '🤦🏿' => 'Ẹni Fọwọ Boju: adúláwọ̀',
    '🤷🏻' => 'Ẹni N Gunpa: amọ́lára',
    '🤷🏼' => 'Ẹni N Gunpa: amọ́lára díẹ̀',
    '🤷🏽' => 'Ẹni N Gunpa: amọ́láwọ̀ díẹ̀',
    '🤷🏾' => 'Ẹni N Gunpa: adúláwọ̀ díẹ̀',
    '🤷🏿' => 'Ẹni N Gunpa: adúláwọ̀',
    '👮🏻' => 'Ọlọpa: amọ́lára',
    '👮🏼' => 'Ọlọpa: amọ́lára díẹ̀',
    '👮🏽' => 'Ọlọpa: amọ́láwọ̀ díẹ̀',
    '👮🏾' => 'Ọlọpa: adúláwọ̀ díẹ̀',
    '👮🏿' => 'Ọlọpa: adúláwọ̀',
    '🕵🏻' => 'ọ̀tẹlèmúyé: amọ́lára',
    '🕵🏼' => 'ọ̀tẹlèmúyé: amọ́lára díẹ̀',
    '🕵🏽' => 'ọ̀tẹlèmúyé: amọ́láwọ̀ díẹ̀',
    '🕵🏾' => 'ọ̀tẹlèmúyé: adúláwọ̀ díẹ̀',
    '🕵🏿' => 'ọ̀tẹlèmúyé: adúláwọ̀',
    '💂🏻' => 'Oluṣọ: amọ́lára',
    '💂🏼' => 'Oluṣọ: amọ́lára díẹ̀',
    '💂🏽' => 'Oluṣọ: amọ́láwọ̀ díẹ̀',
    '💂🏾' => 'Oluṣọ: adúláwọ̀ díẹ̀',
    '💂🏿' => 'Oluṣọ: adúláwọ̀',
    '🥷🏻' => 'nínjà: amọ́lára',
    '🥷🏼' => 'nínjà: amọ́lára díẹ̀',
    '🥷🏽' => 'nínjà: amọ́láwọ̀ díẹ̀',
    '🥷🏾' => 'nínjà: adúláwọ̀ díẹ̀',
    '🥷🏿' => 'nínjà: adúláwọ̀',
    '👷🏻' => 'Oṣiṣẹ Ikọle: amọ́lára',
    '👷🏼' => 'Oṣiṣẹ Ikọle: amọ́lára díẹ̀',
    '👷🏽' => 'Oṣiṣẹ Ikọle: amọ́láwọ̀ díẹ̀',
    '👷🏾' => 'Oṣiṣẹ Ikọle: adúláwọ̀ díẹ̀',
    '👷🏿' => 'Oṣiṣẹ Ikọle: adúláwọ̀',
    '🫅🏻' => 'ènìyàn pẹ̀lú adé: amọ́lára',
    '🫅🏼' => 'ènìyàn pẹ̀lú adé: amọ́lára díẹ̀',
    '🫅🏽' => 'ènìyàn pẹ̀lú adé: amọ́láwọ̀ díẹ̀',
    '🫅🏾' => 'ènìyàn pẹ̀lú adé: adúláwọ̀ díẹ̀',
    '🫅🏿' => 'ènìyàn pẹ̀lú adé: adúláwọ̀',
    '🤴🏻' => 'Ọmọkunrin Alade: amọ́lára',
    '🤴🏼' => 'Ọmọkunrin Alade: amọ́lára díẹ̀',
    '🤴🏽' => 'Ọmọkunrin Alade: amọ́láwọ̀ díẹ̀',
    '🤴🏾' => 'Ọmọkunrin Alade: adúláwọ̀ díẹ̀',
    '🤴🏿' => 'Ọmọkunrin Alade: adúláwọ̀',
    '👸🏻' => 'Ọmọbinrin Alade: amọ́lára',
    '👸🏼' => 'Ọmọbinrin Alade: amọ́lára díẹ̀',
    '👸🏽' => 'Ọmọbinrin Alade: amọ́láwọ̀ díẹ̀',
    '👸🏾' => 'Ọmọbinrin Alade: adúláwọ̀ díẹ̀',
    '👸🏿' => 'Ọmọbinrin Alade: adúláwọ̀',
    '👳🏻' => 'Ẹni wọ Lawani: amọ́lára',
    '👳🏼' => 'Ẹni wọ Lawani: amọ́lára díẹ̀',
    '👳🏽' => 'Ẹni wọ Lawani: amọ́láwọ̀ díẹ̀',
    '👳🏾' => 'Ẹni wọ Lawani: adúláwọ̀ díẹ̀',
    '👳🏿' => 'Ẹni wọ Lawani: adúláwọ̀',
    '👲🏻' => 'Ọkunrin Pẹlu Fila Ṣainisi: amọ́lára',
    '👲🏼' => 'Ọkunrin Pẹlu Fila Ṣainisi: amọ́lára díẹ̀',
    '👲🏽' => 'Ọkunrin Pẹlu Fila Ṣainisi: amọ́láwọ̀ díẹ̀',
    '👲🏾' => 'Ọkunrin Pẹlu Fila Ṣainisi: adúláwọ̀ díẹ̀',
    '👲🏿' => 'Ọkunrin Pẹlu Fila Ṣainisi: adúláwọ̀',
    '🧕🏻' => 'obinrin tó wé gèlè: amọ́lára',
    '🧕🏼' => 'obinrin tó wé gèlè: amọ́lára díẹ̀',
    '🧕🏽' => 'obinrin tó wé gèlè: amọ́láwọ̀ díẹ̀',
    '🧕🏾' => 'obinrin tó wé gèlè: adúláwọ̀ díẹ̀',
    '🧕🏿' => 'obinrin tó wé gèlè: adúláwọ̀',
    '🤵🏻' => 'Ọkunrin Pẹlu Kootu: amọ́lára',
    '🤵🏼' => 'Ọkunrin Pẹlu Kootu: amọ́lára díẹ̀',
    '🤵🏽' => 'Ọkunrin Pẹlu Kootu: amọ́láwọ̀ díẹ̀',
    '🤵🏾' => 'Ọkunrin Pẹlu Kootu: adúláwọ̀ díẹ̀',
    '🤵🏿' => 'Ọkunrin Pẹlu Kootu: adúláwọ̀',
    '👰🏻' => 'Iyawo Pẹlu Iboju: amọ́lára',
    '👰🏼' => 'Iyawo Pẹlu Iboju: amọ́lára díẹ̀',
    '👰🏽' => 'Iyawo Pẹlu Iboju: amọ́láwọ̀ díẹ̀',
    '👰🏾' => 'Iyawo Pẹlu Iboju: adúláwọ̀ díẹ̀',
    '👰🏿' => 'Iyawo Pẹlu Iboju: adúláwọ̀',
    '🤰🏻' => 'obinrin alaboyun: amọ́lára',
    '🤰🏼' => 'obinrin alaboyun: amọ́lára díẹ̀',
    '🤰🏽' => 'obinrin alaboyun: amọ́láwọ̀ díẹ̀',
    '🤰🏾' => 'obinrin alaboyun: adúláwọ̀ díẹ̀',
    '🤰🏿' => 'obinrin alaboyun: adúláwọ̀',
    '🫃🏻' => 'aláboyún ọkùnrin: amọ́lára',
    '🫃🏼' => 'aláboyún ọkùnrin: amọ́lára díẹ̀',
    '🫃🏽' => 'aláboyún ọkùnrin: amọ́láwọ̀ díẹ̀',
    '🫃🏾' => 'aláboyún ọkùnrin: adúláwọ̀ díẹ̀',
    '🫃🏿' => 'aláboyún ọkùnrin: adúláwọ̀',
    '🫄🏻' => 'aláboyún: amọ́lára',
    '🫄🏼' => 'aláboyún: amọ́lára díẹ̀',
    '🫄🏽' => 'aláboyún: amọ́láwọ̀ díẹ̀',
    '🫄🏾' => 'aláboyún: adúláwọ̀ díẹ̀',
    '🫄🏿' => 'aláboyún: adúláwọ̀',
    '🤱🏻' => 'ìfọ́mọlọ́yàn: amọ́lára',
    '🤱🏼' => 'ìfọ́mọlọ́yàn: amọ́lára díẹ̀',
    '🤱🏽' => 'ìfọ́mọlọ́yàn: amọ́láwọ̀ díẹ̀',
    '🤱🏾' => 'ìfọ́mọlọ́yàn: adúláwọ̀ díẹ̀',
    '🤱🏿' => 'ìfọ́mọlọ́yàn: adúláwọ̀',
    '👼🏻' => 'ángẹli ìkókó: amọ́lára',
    '👼🏼' => 'ángẹli ìkókó: amọ́lára díẹ̀',
    '👼🏽' => 'ángẹli ìkókó: amọ́láwọ̀ díẹ̀',
    '👼🏾' => 'ángẹli ìkókó: adúláwọ̀ díẹ̀',
    '👼🏿' => 'ángẹli ìkókó: adúláwọ̀',
    '🎅🏻' => 'Baba Keresi: amọ́lára',
    '🎅🏼' => 'Baba Keresi: amọ́lára díẹ̀',
    '🎅🏽' => 'Baba Keresi: amọ́láwọ̀ díẹ̀',
    '🎅🏾' => 'Baba Keresi: adúláwọ̀ díẹ̀',
    '🎅🏿' => 'Baba Keresi: adúláwọ̀',
    '🤶🏻' => 'Arabinrin Keresi: amọ́lára',
    '🤶🏼' => 'Arabinrin Keresi: amọ́lára díẹ̀',
    '🤶🏽' => 'Arabinrin Keresi: amọ́láwọ̀ díẹ̀',
    '🤶🏾' => 'Arabinrin Keresi: adúláwọ̀ díẹ̀',
    '🤶🏿' => 'Arabinrin Keresi: adúláwọ̀',
    '🦸🏻' => 'akọni alágbára: amọ́lára',
    '🦸🏼' => 'akọni alágbára: amọ́lára díẹ̀',
    '🦸🏽' => 'akọni alágbára: amọ́láwọ̀ díẹ̀',
    '🦸🏾' => 'akọni alágbára: adúláwọ̀ díẹ̀',
    '🦸🏿' => 'akọni alágbára: adúláwọ̀',
    '🦹🏻' => 'alátakọ̀ alágbára: amọ́lára',
    '🦹🏼' => 'alátakọ̀ alágbára: amọ́lára díẹ̀',
    '🦹🏽' => 'alátakọ̀ alágbára: amọ́láwọ̀ díẹ̀',
    '🦹🏾' => 'alátakọ̀ alágbára: adúláwọ̀ díẹ̀',
    '🦹🏿' => 'alátakọ̀ alágbára: adúláwọ̀',
    '🧙🏻' => 'onídán: amọ́lára',
    '🧙🏼' => 'onídán: amọ́lára díẹ̀',
    '🧙🏽' => 'onídán: amọ́láwọ̀ díẹ̀',
    '🧙🏾' => 'onídán: adúláwọ̀ díẹ̀',
    '🧙🏿' => 'onídán: adúláwọ̀',
    '🧚🏻' => 'Iwin: amọ́lára',
    '🧚🏼' => 'Iwin: amọ́lára díẹ̀',
    '🧚🏽' => 'Iwin: amọ́láwọ̀ díẹ̀',
    '🧚🏾' => 'Iwin: adúláwọ̀ díẹ̀',
    '🧚🏿' => 'Iwin: adúláwọ̀',
    '🧛🏻' => 'Fánpáyà: amọ́lára',
    '🧛🏼' => 'Fánpáyà: amọ́lára díẹ̀',
    '🧛🏽' => 'Fánpáyà: amọ́láwọ̀ díẹ̀',
    '🧛🏾' => 'Fánpáyà: adúláwọ̀ díẹ̀',
    '🧛🏿' => 'Fánpáyà: adúláwọ̀',
    '🧜🏻' => 'Yemọja ènìyàn: amọ́lára',
    '🧜🏼' => 'Yemọja ènìyàn: amọ́lára díẹ̀',
    '🧜🏽' => 'Yemọja ènìyàn: amọ́láwọ̀ díẹ̀',
    '🧜🏾' => 'Yemọja ènìyàn: adúláwọ̀ díẹ̀',
    '🧜🏿' => 'Yemọja ènìyàn: adúláwọ̀',
    '🧝🏻' => 'Egbére: amọ́lára',
    '🧝🏼' => 'Egbére: amọ́lára díẹ̀',
    '🧝🏽' => 'Egbére: amọ́láwọ̀ díẹ̀',
    '🧝🏾' => 'Egbére: adúláwọ̀ díẹ̀',
    '🧝🏿' => 'Egbére: adúláwọ̀',
    '💆🏻' => 'ẹni N gba Ifọwọwọnilara: amọ́lára',
    '💆🏼' => 'ẹni N gba Ifọwọwọnilara: amọ́lára díẹ̀',
    '💆🏽' => 'ẹni N gba Ifọwọwọnilara: amọ́láwọ̀ díẹ̀',
    '💆🏾' => 'ẹni N gba Ifọwọwọnilara: adúláwọ̀ díẹ̀',
    '💆🏿' => 'ẹni N gba Ifọwọwọnilara: adúláwọ̀',
    '💇🏻' => 'Ẹni N Gẹrun: amọ́lára',
    '💇🏼' => 'Ẹni N Gẹrun: amọ́lára díẹ̀',
    '💇🏽' => 'Ẹni N Gẹrun: amọ́láwọ̀ díẹ̀',
    '💇🏾' => 'Ẹni N Gẹrun: adúláwọ̀ díẹ̀',
    '💇🏿' => 'Ẹni N Gẹrun: adúláwọ̀',
    '🚶🏻' => 'Ẹni N Rin: amọ́lára',
    '🚶🏼' => 'Ẹni N Rin: amọ́lára díẹ̀',
    '🚶🏽' => 'Ẹni N Rin: amọ́láwọ̀ díẹ̀',
    '🚶🏾' => 'Ẹni N Rin: adúláwọ̀ díẹ̀',
    '🚶🏿' => 'Ẹni N Rin: adúláwọ̀',
    '🧍🏻' => 'ènìyàn dídúró: amọ́lára',
    '🧍🏼' => 'ènìyàn dídúró: amọ́lára díẹ̀',
    '🧍🏽' => 'ènìyàn dídúró: amọ́láwọ̀ díẹ̀',
    '🧍🏾' => 'ènìyàn dídúró: adúláwọ̀ díẹ̀',
    '🧍🏿' => 'ènìyàn dídúró: adúláwọ̀',
    '🧎🏻' => 'ènìyàn kíkúnlẹ̀: amọ́lára',
    '🧎🏼' => 'ènìyàn kíkúnlẹ̀: amọ́lára díẹ̀',
    '🧎🏽' => 'ènìyàn kíkúnlẹ̀: amọ́láwọ̀ díẹ̀',
    '🧎🏾' => 'ènìyàn kíkúnlẹ̀: adúláwọ̀ díẹ̀',
    '🧎🏿' => 'ènìyàn kíkúnlẹ̀: adúláwọ̀',
    '🏃🏻' => 'Ẹni N Sare: amọ́lára',
    '🏃🏼' => 'Ẹni N Sare: amọ́lára díẹ̀',
    '🏃🏽' => 'Ẹni N Sare: amọ́láwọ̀ díẹ̀',
    '🏃🏾' => 'Ẹni N Sare: adúláwọ̀ díẹ̀',
    '🏃🏿' => 'Ẹni N Sare: adúláwọ̀',
    '💃🏻' => 'Obinrin Ti Njo: amọ́lára',
    '💃🏼' => 'Obinrin Ti Njo: amọ́lára díẹ̀',
    '💃🏽' => 'Obinrin Ti Njo: amọ́láwọ̀ díẹ̀',
    '💃🏾' => 'Obinrin Ti Njo: adúláwọ̀ díẹ̀',
    '💃🏿' => 'Obinrin Ti Njo: adúláwọ̀',
    '🕺🏻' => 'Ọkunrin Ti Njo: amọ́lára',
    '🕺🏼' => 'Ọkunrin Ti Njo: amọ́lára díẹ̀',
    '🕺🏽' => 'Ọkunrin Ti Njo: amọ́láwọ̀ díẹ̀',
    '🕺🏾' => 'Ọkunrin Ti Njo: adúláwọ̀ díẹ̀',
    '🕺🏿' => 'Ọkunrin Ti Njo: adúláwọ̀',
    '🕴🏻' => 'ọkùnrin nínu kóòtú òwò: amọ́lára',
    '🕴🏼' => 'ọkùnrin nínu kóòtú òwò: amọ́lára díẹ̀',
    '🕴🏽' => 'ọkùnrin nínu kóòtú òwò: amọ́láwọ̀ díẹ̀',
    '🕴🏾' => 'ọkùnrin nínu kóòtú òwò: adúláwọ̀ díẹ̀',
    '🕴🏿' => 'ọkùnrin nínu kóòtú òwò: adúláwọ̀',
    '👯🏻' => 'awọn eniyan eleti ehoro: amọ́lára',
    '👯🏼' => 'awọn eniyan eleti ehoro: amọ́lára díẹ̀',
    '👯🏽' => 'awọn eniyan eleti ehoro: amọ́láwọ̀ díẹ̀',
    '👯🏾' => 'awọn eniyan eleti ehoro: adúláwọ̀ díẹ̀',
    '👯🏿' => 'awọn eniyan eleti ehoro: adúláwọ̀',
    '🧖🏻' => 'Ènìyàn nínú Ìyàrá tó n gbóná: amọ́lára',
    '🧖🏼' => 'Ènìyàn nínú Ìyàrá tó n gbóná: amọ́lára díẹ̀',
    '🧖🏽' => 'Ènìyàn nínú Ìyàrá tó n gbóná: amọ́láwọ̀ díẹ̀',
    '🧖🏾' => 'Ènìyàn nínú Ìyàrá tó n gbóná: adúláwọ̀ díẹ̀',
    '🧖🏿' => 'Ènìyàn nínú Ìyàrá tó n gbóná: adúláwọ̀',
    '🧗🏻' => 'Ènìyàn tó n gòkè: amọ́lára',
    '🧗🏼' => 'Ènìyàn tó n gòkè: amọ́lára díẹ̀',
    '🧗🏽' => 'Ènìyàn tó n gòkè: amọ́láwọ̀ díẹ̀',
    '🧗🏾' => 'Ènìyàn tó n gòkè: adúláwọ̀ díẹ̀',
    '🧗🏿' => 'Ènìyàn tó n gòkè: adúláwọ̀',
    '🏇🏻' => 'Ereje Ẹlẹsin: amọ́lára',
    '🏇🏼' => 'Ereje Ẹlẹsin: amọ́lára díẹ̀',
    '🏇🏽' => 'Ereje Ẹlẹsin: amọ́láwọ̀ díẹ̀',
    '🏇🏾' => 'Ereje Ẹlẹsin: adúláwọ̀ díẹ̀',
    '🏇🏿' => 'Ereje Ẹlẹsin: adúláwọ̀',
    '🏂🏻' => 'Iṣere Ori Yiyin: amọ́lára',
    '🏂🏼' => 'Iṣere Ori Yiyin: amọ́lára díẹ̀',
    '🏂🏽' => 'Iṣere Ori Yiyin: amọ́láwọ̀ díẹ̀',
    '🏂🏾' => 'Iṣere Ori Yiyin: adúláwọ̀ díẹ̀',
    '🏂🏿' => 'Iṣere Ori Yiyin: adúláwọ̀',
    '🏌🏻' => 'ẹni gọ́ọ̀fù: amọ́lára',
    '🏌🏼' => 'ẹni gọ́ọ̀fù: amọ́lára díẹ̀',
    '🏌🏽' => 'ẹni gọ́ọ̀fù: amọ́láwọ̀ díẹ̀',
    '🏌🏾' => 'ẹni gọ́ọ̀fù: adúláwọ̀ díẹ̀',
    '🏌🏿' => 'ẹni gọ́ọ̀fù: adúláwọ̀',
    '🏄🏻' => 'Ẹni N Gun Iji: amọ́lára',
    '🏄🏼' => 'Ẹni N Gun Iji: amọ́lára díẹ̀',
    '🏄🏽' => 'Ẹni N Gun Iji: amọ́láwọ̀ díẹ̀',
    '🏄🏾' => 'Ẹni N Gun Iji: adúláwọ̀ díẹ̀',
    '🏄🏿' => 'Ẹni N Gun Iji: adúláwọ̀',
    '🚣🏻' => 'Ẹni N wa Ọkọ: amọ́lára',
    '🚣🏼' => 'Ẹni N wa Ọkọ: amọ́lára díẹ̀',
    '🚣🏽' => 'Ẹni N wa Ọkọ: amọ́láwọ̀ díẹ̀',
    '🚣🏾' => 'Ẹni N wa Ọkọ: adúláwọ̀ díẹ̀',
    '🚣🏿' => 'Ẹni N wa Ọkọ: adúláwọ̀',
    '🏊🏻' => 'Ẹni tí ń wẹdò: amọ́lára',
    '🏊🏼' => 'Ẹni tí ń wẹdò: amọ́lára díẹ̀',
    '🏊🏽' => 'Ẹni tí ń wẹdò: amọ́láwọ̀ díẹ̀',
    '🏊🏾' => 'Ẹni tí ń wẹdò: adúláwọ̀ díẹ̀',
    '🏊🏿' => 'Ẹni tí ń wẹdò: adúláwọ̀',
    '⛹🏻' => 'ẹni tà boun bọ́ọ̀lù: amọ́lára',
    '⛹🏼' => 'ẹni tà boun bọ́ọ̀lù: amọ́lára díẹ̀',
    '⛹🏽' => 'ẹni tà boun bọ́ọ̀lù: amọ́láwọ̀ díẹ̀',
    '⛹🏾' => 'ẹni tà boun bọ́ọ̀lù: adúláwọ̀ díẹ̀',
    '⛹🏿' => 'ẹni tà boun bọ́ọ̀lù: adúláwọ̀',
    '🏋🏻' => 'ẹni fa ìwọ̀n sókè: amọ́lára',
    '🏋🏼' => 'ẹni fa ìwọ̀n sókè: amọ́lára díẹ̀',
    '🏋🏽' => 'ẹni fa ìwọ̀n sókè: amọ́láwọ̀ díẹ̀',
    '🏋🏾' => 'ẹni fa ìwọ̀n sókè: adúláwọ̀ díẹ̀',
    '🏋🏿' => 'ẹni fa ìwọ̀n sókè: adúláwọ̀',
    '🚴🏻' => 'Ẹni N Gun Kẹkẹ: amọ́lára',
    '🚴🏼' => 'Ẹni N Gun Kẹkẹ: amọ́lára díẹ̀',
    '🚴🏽' => 'Ẹni N Gun Kẹkẹ: amọ́láwọ̀ díẹ̀',
    '🚴🏾' => 'Ẹni N Gun Kẹkẹ: adúláwọ̀ díẹ̀',
    '🚴🏿' => 'Ẹni N Gun Kẹkẹ: adúláwọ̀',
    '🚵🏻' => 'Ẹni N Gun Kẹkẹ Gun Apata: amọ́lára',
    '🚵🏼' => 'Ẹni N Gun Kẹkẹ Gun Apata: amọ́lára díẹ̀',
    '🚵🏽' => 'Ẹni N Gun Kẹkẹ Gun Apata: amọ́láwọ̀ díẹ̀',
    '🚵🏾' => 'Ẹni N Gun Kẹkẹ Gun Apata: adúláwọ̀ díẹ̀',
    '🚵🏿' => 'Ẹni N Gun Kẹkẹ Gun Apata: adúláwọ̀',
    '🤸🏻' => 'Ẹni Kawọ Tilẹ Kẹsẹ Soke: amọ́lára',
    '🤸🏼' => 'Ẹni Kawọ Tilẹ Kẹsẹ Soke: amọ́lára díẹ̀',
    '🤸🏽' => 'Ẹni Kawọ Tilẹ Kẹsẹ Soke: amọ́láwọ̀ díẹ̀',
    '🤸🏾' => 'Ẹni Kawọ Tilẹ Kẹsẹ Soke: adúláwọ̀ díẹ̀',
    '🤸🏿' => 'Ẹni Kawọ Tilẹ Kẹsẹ Soke: adúláwọ̀',
    '🤼🏻' => 'Awọn Onigidigbo: amọ́lára',
    '🤼🏼' => 'Awọn Onigidigbo: amọ́lára díẹ̀',
    '🤼🏽' => 'Awọn Onigidigbo: amọ́láwọ̀ díẹ̀',
    '🤼🏾' => 'Awọn Onigidigbo: adúláwọ̀ díẹ̀',
    '🤼🏿' => 'Awọn Onigidigbo: adúláwọ̀',
    '🤽🏻' => 'Ẹni N ṣere Olomi: amọ́lára',
    '🤽🏼' => 'Ẹni N ṣere Olomi: amọ́lára díẹ̀',
    '🤽🏽' => 'Ẹni N ṣere Olomi: amọ́láwọ̀ díẹ̀',
    '🤽🏾' => 'Ẹni N ṣere Olomi: adúláwọ̀ díẹ̀',
    '🤽🏿' => 'Ẹni N ṣere Olomi: adúláwọ̀',
    '🤾🏻' => 'Ẹni N Ṣere Bọọlu Ọlọwọ: amọ́lára',
    '🤾🏼' => 'Ẹni N Ṣere Bọọlu Ọlọwọ: amọ́lára díẹ̀',
    '🤾🏽' => 'Ẹni N Ṣere Bọọlu Ọlọwọ: amọ́láwọ̀ díẹ̀',
    '🤾🏾' => 'Ẹni N Ṣere Bọọlu Ọlọwọ: adúláwọ̀ díẹ̀',
    '🤾🏿' => 'Ẹni N Ṣere Bọọlu Ọlọwọ: adúláwọ̀',
    '🤹🏻' => 'Ẹni N ju Nnkan soke: amọ́lára',
    '🤹🏼' => 'Ẹni N ju Nnkan soke: amọ́lára díẹ̀',
    '🤹🏽' => 'Ẹni N ju Nnkan soke: amọ́láwọ̀ díẹ̀',
    '🤹🏾' => 'Ẹni N ju Nnkan soke: adúláwọ̀ díẹ̀',
    '🤹🏿' => 'Ẹni N ju Nnkan soke: adúláwọ̀',
    '🧘🏻' => 'Ènìyàn nípò ìgbàgbé: amọ́lára',
    '🧘🏼' => 'Ènìyàn nípò ìgbàgbé: amọ́lára díẹ̀',
    '🧘🏽' => 'Ènìyàn nípò ìgbàgbé: amọ́láwọ̀ díẹ̀',
    '🧘🏾' => 'Ènìyàn nípò ìgbàgbé: adúláwọ̀ díẹ̀',
    '🧘🏿' => 'Ènìyàn nípò ìgbàgbé: adúláwọ̀',
    '🛀🏻' => 'Ẹni Nwẹ: amọ́lára',
    '🛀🏼' => 'Ẹni Nwẹ: amọ́lára díẹ̀',
    '🛀🏽' => 'Ẹni Nwẹ: amọ́láwọ̀ díẹ̀',
    '🛀🏾' => 'Ẹni Nwẹ: adúláwọ̀ díẹ̀',
    '🛀🏿' => 'Ẹni Nwẹ: adúláwọ̀',
    '🛌🏻' => 'Ẹniyan Nibusun: amọ́lára',
    '🛌🏼' => 'Ẹniyan Nibusun: amọ́lára díẹ̀',
    '🛌🏽' => 'Ẹniyan Nibusun: amọ́láwọ̀ díẹ̀',
    '🛌🏾' => 'Ẹniyan Nibusun: adúláwọ̀ díẹ̀',
    '🛌🏿' => 'Ẹniyan Nibusun: adúláwọ̀',
    '👭🏻' => 'Obinrin Meji Ti O Dọwọ Ara Wọn Mu: amọ́lára',
    '👭🏼' => 'Obinrin Meji Ti O Dọwọ Ara Wọn Mu: amọ́lára díẹ̀',
    '👭🏽' => 'Obinrin Meji Ti O Dọwọ Ara Wọn Mu: amọ́láwọ̀ díẹ̀',
    '👭🏾' => 'Obinrin Meji Ti O Dọwọ Ara Wọn Mu: adúláwọ̀ díẹ̀',
    '👭🏿' => 'Obinrin Meji Ti O Dọwọ Ara Wọn Mu: adúláwọ̀',
    '👫🏻' => 'Ọkunrin Ati Obirin Ti O Dọwọ Ara Wọn Mu: amọ́lára',
    '👫🏼' => 'Ọkunrin Ati Obirin Ti O Dọwọ Ara Wọn Mu: amọ́lára díẹ̀',
    '👫🏽' => 'Ọkunrin Ati Obirin Ti O Dọwọ Ara Wọn Mu: amọ́láwọ̀ díẹ̀',
    '👫🏾' => 'Ọkunrin Ati Obirin Ti O Dọwọ Ara Wọn Mu: adúláwọ̀ díẹ̀',
    '👫🏿' => 'Ọkunrin Ati Obirin Ti O Dọwọ Ara Wọn Mu: adúláwọ̀',
    '👬🏻' => 'Ọkunrin Meji Ti O Dọwọ Ara Wọn Mu: amọ́lára',
    '👬🏼' => 'Ọkunrin Meji Ti O Dọwọ Ara Wọn Mu: amọ́lára díẹ̀',
    '👬🏽' => 'Ọkunrin Meji Ti O Dọwọ Ara Wọn Mu: amọ́láwọ̀ díẹ̀',
    '👬🏾' => 'Ọkunrin Meji Ti O Dọwọ Ara Wọn Mu: adúláwọ̀ díẹ̀',
    '👬🏿' => 'Ọkunrin Meji Ti O Dọwọ Ara Wọn Mu: adúláwọ̀',
    '💏🏻' => 'Ifẹnuko: amọ́lára',
    '💏🏼' => 'Ifẹnuko: amọ́lára díẹ̀',
    '💏🏽' => 'Ifẹnuko: amọ́láwọ̀ díẹ̀',
    '💏🏾' => 'Ifẹnuko: adúláwọ̀ díẹ̀',
    '💏🏿' => 'Ifẹnuko: adúláwọ̀',
    '💑🏻' => 'Lọkọlaya Pẹlu ọkan: amọ́lára',
    '💑🏼' => 'Lọkọlaya Pẹlu ọkan: amọ́lára díẹ̀',
    '💑🏽' => 'Lọkọlaya Pẹlu ọkan: amọ́láwọ̀ díẹ̀',
    '💑🏾' => 'Lọkọlaya Pẹlu ọkan: adúláwọ̀ díẹ̀',
    '💑🏿' => 'Lọkọlaya Pẹlu ọkan: adúláwọ̀',
    '🇦🇨' => 'filaagi: Erékùsù Ascension',
    '🇦🇩' => 'filaagi: Ààndórà',
    '🇦🇪' => 'filaagi: Ẹmirate ti Awọn Arabu',
    '🇦🇫' => 'filaagi: Àfùgànístánì',
    '🇦🇬' => 'filaagi: Ààntígúà àti Báríbúdà',
    '🇦🇮' => 'filaagi: Ààngúlílà',
    '🇦🇱' => 'filaagi: Àlùbàníánì',
    '🇦🇲' => 'filaagi: Améníà',
    '🇦🇴' => 'filaagi: Ààngólà',
    '🇦🇶' => 'filaagi: Antakítíkà',
    '🇦🇷' => 'filaagi: Agentínà',
    '🇦🇸' => 'filaagi: Sámóánì ti Orílẹ́ède Àméríkà',
    '🇦🇹' => 'filaagi: Asítíríà',
    '🇦🇺' => 'filaagi: Austrálíà',
    '🇦🇼' => 'filaagi: Árúbà',
    '🇦🇽' => 'filaagi: Àwọn Erékùsù ti Aland',
    '🇦🇿' => 'filaagi: Asẹ́bájánì',
    '🇧🇦' => 'filaagi: Bọ̀síníà àti Ẹtisẹgófínà',
    '🇧🇧' => 'filaagi: Bábádósì',
    '🇧🇩' => 'filaagi: Bángáládésì',
    '🇧🇪' => 'filaagi: Bégíọ́mù',
    '🇧🇫' => 'filaagi: Bùùkíná Fasò',
    '🇧🇬' => 'filaagi: Bùùgáríà',
    '🇧🇭' => 'filaagi: Báránì',
    '🇧🇮' => 'filaagi: Bùùrúndì',
    '🇧🇯' => 'filaagi: Bẹ̀nẹ̀',
    '🇧🇱' => 'filaagi: Ìlú Bátílẹ́mì',
    '🇧🇲' => 'filaagi: Bémúdà',
    '🇧🇳' => 'filaagi: Búrúnẹ́lì',
    '🇧🇴' => 'filaagi: Bọ̀lífíyà',
    '🇧🇶' => 'filaagi: Kàríbíánì ti Nẹ́dálándì',
    '🇧🇷' => 'filaagi: Bàràsílì',
    '🇧🇸' => 'filaagi: Bàhámásì',
    '🇧🇹' => 'filaagi: Bútánì',
    '🇧🇻' => 'filaagi: Erékùsù Bouvet',
    '🇧🇼' => 'filaagi: Bọ̀tìsúwánà',
    '🇧🇾' => 'filaagi: Bélárúsì',
    '🇧🇿' => 'filaagi: Bèlísẹ̀',
    '🇨🇦' => 'filaagi: Kánádà',
    '🇨🇨' => 'filaagi: Erékùsù Cocos (Keeling)',
    '🇨🇩' => 'filaagi: Kóńgò – Kinshasa',
    '🇨🇫' => 'filaagi: Àrin gùngun Áfíríkà',
    '🇨🇬' => 'filaagi: Kóńgò – Brazaville',
    '🇨🇭' => 'filaagi: Súwísìlanìdì',
    '🇨🇮' => 'filaagi: Kóútè forà',
    '🇨🇰' => 'filaagi: Etíokun Kùúkù',
    '🇨🇱' => 'filaagi: Ṣílè',
    '🇨🇲' => 'filaagi: Kamerúúnì',
    '🇨🇳' => 'filaagi: Ṣáínà',
    '🇨🇴' => 'filaagi: Kòlómíbìa',
    '🇨🇵' => 'filaagi: Erékùsù Clipperston',
    '🇨🇶' => 'filaagi: Sáàkì',
    '🇨🇷' => 'filaagi: Kuusita Ríkà',
    '🇨🇺' => 'filaagi: Kúbà',
    '🇨🇻' => 'filaagi: Etíokun Kápé féndè',
    '🇨🇼' => 'filaagi: Curaçao',
    '🇨🇽' => 'filaagi: Erékùsù Christmas',
    '🇨🇾' => 'filaagi: Kúrúsì',
    '🇨🇿' => 'filaagi: Ṣẹ́ẹ́kì',
    '🇩🇪' => 'filaagi: Jámánì',
    '🇩🇬' => 'filaagi: Diego Gaṣia',
    '🇩🇯' => 'filaagi: Díbọ́ótì',
    '🇩🇰' => 'filaagi: Dẹ́mákì',
    '🇩🇲' => 'filaagi: Dòmíníkà',
    '🇩🇴' => 'filaagi: Dòmíníkánì',
    '🇩🇿' => 'filaagi: Àlùgèríánì',
    '🇪🇦' => 'filaagi: Seuta àti Melilla',
    '🇪🇨' => 'filaagi: Ekuádò',
    '🇪🇪' => 'filaagi: Esitonia',
    '🇪🇬' => 'filaagi: Égípítì',
    '🇪🇭' => 'filaagi: Ìwọ̀òòrùn Sàhárà',
    '🇪🇷' => 'filaagi: Eritira',
    '🇪🇸' => 'filaagi: Sípéìnì',
    '🇪🇹' => 'filaagi: Etopia',
    '🇪🇺' => 'filaagi: Àpapọ̀ Yúróòpù',
    '🇫🇮' => 'filaagi: Filandi',
    '🇫🇯' => 'filaagi: Fíjì',
    '🇫🇰' => 'filaagi: Etikun Fakalandi',
    '🇫🇲' => 'filaagi: Makoronesia',
    '🇫🇴' => 'filaagi: Àwọn Erékùsù ti Faroe',
    '🇫🇷' => 'filaagi: Faranse',
    '🇬🇦' => 'filaagi: Gabon',
    '🇬🇧' => 'filaagi: Gẹ̀ẹ́sì',
    '🇬🇩' => 'filaagi: Genada',
    '🇬🇪' => 'filaagi: Gọgia',
    '🇬🇫' => 'filaagi: Firenṣi Guana',
    '🇬🇬' => 'filaagi: Guernsey',
    '🇬🇭' => 'filaagi: Gana',
    '🇬🇮' => 'filaagi: Gibaratara',
    '🇬🇱' => 'filaagi: Gerelandi',
    '🇬🇲' => 'filaagi: Gambia',
    '🇬🇳' => 'filaagi: Gene',
    '🇬🇵' => 'filaagi: Gadelope',
    '🇬🇶' => 'filaagi: Ekutoria Gini',
    '🇬🇷' => 'filaagi: Gíríìsì',
    '🇬🇸' => 'filaagi: Gúúsù Georgia àti Gúúsù Àwọn Erékùsù Sandwich',
    '🇬🇹' => 'filaagi: Guatemálà',
    '🇬🇺' => 'filaagi: Guamu',
    '🇬🇼' => 'filaagi: Gene-Busau',
    '🇬🇾' => 'filaagi: Guyana',
    '🇭🇰' => 'filaagi: Agbègbè Ìṣàkóso Ìṣúná Hong Kong Tí Ṣánà Ń Darí',
    '🇭🇲' => 'filaagi: Erékùsù Heard àti Erékùsù McDonald',
    '🇭🇳' => 'filaagi: Hondurasi',
    '🇭🇷' => 'filaagi: Kòróátíà',
    '🇭🇹' => 'filaagi: Haati',
    '🇭🇺' => 'filaagi: Hungari',
    '🇮🇨' => 'filaagi: Ẹrékùsù Kánárì',
    '🇮🇩' => 'filaagi: Indonéṣíà',
    '🇮🇪' => 'filaagi: Ailandi',
    '🇮🇱' => 'filaagi: Iserẹli',
    '🇮🇲' => 'filaagi: Erékùṣù ilẹ̀ Man',
    '🇮🇳' => 'filaagi: Íńdíà',
    '🇮🇴' => 'filaagi: Etíkun Índíánì ti Ìlú Bírítísì',
    '🇮🇶' => 'filaagi: Iraki',
    '🇮🇷' => 'filaagi: Irani',
    '🇮🇸' => 'filaagi: Aṣilandi',
    '🇮🇹' => 'filaagi: Itáli',
    '🇯🇪' => 'filaagi: Jẹsì',
    '🇯🇲' => 'filaagi: Jamaika',
    '🇯🇴' => 'filaagi: Jọdani',
    '🇯🇵' => 'filaagi: Japani',
    '🇰🇪' => 'filaagi: Kenya',
    '🇰🇬' => 'filaagi: Kuriṣisitani',
    '🇰🇭' => 'filaagi: Kàmùbódíà',
    '🇰🇮' => 'filaagi: Kiribati',
    '🇰🇲' => 'filaagi: Kòmòrósì',
    '🇰🇳' => 'filaagi: Kiiti ati Neefi',
    '🇰🇵' => 'filaagi: Guusu Kọria',
    '🇰🇷' => 'filaagi: Ariwa Kọria',
    '🇰🇼' => 'filaagi: Kuweti',
    '🇰🇾' => 'filaagi: Etíokun Kámánì',
    '🇰🇿' => 'filaagi: Kaṣaṣatani',
    '🇱🇦' => 'filaagi: Laosi',
    '🇱🇧' => 'filaagi: Lebanoni',
    '🇱🇨' => 'filaagi: Luṣia',
    '🇱🇮' => 'filaagi: Lẹṣitẹnisiteni',
    '🇱🇰' => 'filaagi: Siri Lanka',
    '🇱🇷' => 'filaagi: Laberia',
    '🇱🇸' => 'filaagi: Lesoto',
    '🇱🇹' => 'filaagi: Lituania',
    '🇱🇺' => 'filaagi: Lusemogi',
    '🇱🇻' => 'filaagi: Latifia',
    '🇱🇾' => 'filaagi: Libiya',
    '🇲🇦' => 'filaagi: Moroko',
    '🇲🇨' => 'filaagi: Monako',
    '🇲🇩' => 'filaagi: Modofia',
    '🇲🇪' => 'filaagi: Montenégrò',
    '🇲🇫' => 'filaagi: Ìlú Màtìnì',
    '🇲🇬' => 'filaagi: Madasika',
    '🇲🇭' => 'filaagi: Etikun Máṣali',
    '🇲🇰' => 'filaagi: Àríwá Macedonia',
    '🇲🇱' => 'filaagi: Mali',
    '🇲🇲' => 'filaagi: Manamari',
    '🇲🇳' => 'filaagi: Mogolia',
    '🇲🇴' => 'filaagi: Agbègbè Ìṣàkóso Pàtàkì Macao',
    '🇲🇵' => 'filaagi: Etikun Guusu Mariana',
    '🇲🇶' => 'filaagi: Matinikuwi',
    '🇲🇷' => 'filaagi: Maritania',
    '🇲🇸' => 'filaagi: Motserati',
    '🇲🇹' => 'filaagi: Malata',
    '🇲🇺' => 'filaagi: Maritiusi',
    '🇲🇻' => 'filaagi: Maladifi',
    '🇲🇼' => 'filaagi: Malawi',
    '🇲🇽' => 'filaagi: Mesiko',
    '🇲🇾' => 'filaagi: Malasia',
    '🇲🇿' => 'filaagi: Moṣamibiku',
    '🇳🇦' => 'filaagi: Namibia',
    '🇳🇨' => 'filaagi: Kaledonia Titun',
    '🇳🇪' => 'filaagi: Nàìjá',
    '🇳🇫' => 'filaagi: Erékùsù Nọ́úfókì',
    '🇳🇬' => 'filaagi: Nàìjíríà',
    '🇳🇮' => 'filaagi: Nikaragua',
    '🇳🇱' => 'filaagi: Nedalandi',
    '🇳🇴' => 'filaagi: Nọọwii',
    '🇳🇵' => 'filaagi: Nepa',
    '🇳🇷' => 'filaagi: Nauru',
    '🇳🇺' => 'filaagi: Niue',
    '🇳🇿' => 'filaagi: Ṣilandi Titun',
    '🇴🇲' => 'filaagi: Ọọma',
    '🇵🇦' => 'filaagi: Paramá',
    '🇵🇪' => 'filaagi: Pèérù',
    '🇵🇫' => 'filaagi: Firenṣi Polinesia',
    '🇵🇬' => 'filaagi: Paapu ti Giini',
    '🇵🇭' => 'filaagi: Filipini',
    '🇵🇰' => 'filaagi: Pakisitan',
    '🇵🇱' => 'filaagi: Polandi',
    '🇵🇲' => 'filaagi: Pẹẹri ati mikuloni',
    '🇵🇳' => 'filaagi: Pikarini',
    '🇵🇷' => 'filaagi: Pọto Riko',
    '🇵🇸' => 'filaagi: Agbègbè ara Palẹsítínì',
    '🇵🇹' => 'filaagi: Pọ́túgà',
    '🇵🇼' => 'filaagi: Paalu',
    '🇵🇾' => 'filaagi: Paraguye',
    '🇶🇦' => 'filaagi: Kota',
    '🇷🇪' => 'filaagi: Riuniyan',
    '🇷🇴' => 'filaagi: Romaniya',
    '🇷🇸' => 'filaagi: Sẹ́bíà',
    '🇷🇺' => 'filaagi: Rọṣia',
    '🇷🇼' => 'filaagi: Ruwanda',
    '🇸🇦' => 'filaagi: Saudi Arabia',
    '🇸🇧' => 'filaagi: Etikun Solomoni',
    '🇸🇨' => 'filaagi: Ṣeṣẹlẹsi',
    '🇸🇩' => 'filaagi: Sudani',
    '🇸🇪' => 'filaagi: Swidini',
    '🇸🇬' => 'filaagi: Singapo',
    '🇸🇭' => 'filaagi: Hẹlena',
    '🇸🇮' => 'filaagi: Silofania',
    '🇸🇯' => 'filaagi: Sífábáàdì àti Jánì Máyẹ̀nì',
    '🇸🇰' => 'filaagi: Silofakia',
    '🇸🇱' => 'filaagi: Siria looni',
    '🇸🇲' => 'filaagi: Sani Marino',
    '🇸🇳' => 'filaagi: Sẹnẹga',
    '🇸🇴' => 'filaagi: Sòmálíà',
    '🇸🇷' => 'filaagi: Surinami',
    '🇸🇸' => 'filaagi: Gúúsù Sudan',
    '🇸🇹' => 'filaagi: Sao tomi ati piriiṣipi',
    '🇸🇻' => 'filaagi: Ẹẹsáfádò',
    '🇸🇽' => 'filaagi: Síntì Mátẹ́ẹ̀nì',
    '🇸🇾' => 'filaagi: Siria',
    '🇸🇿' => 'filaagi: Saṣiland',
    '🇹🇦' => 'filaagi: Tristan da Kunha',
    '🇹🇨' => 'filaagi: Tọọki ati Etikun Kakọsi',
    '🇹🇩' => 'filaagi: Ṣààdì',
    '🇹🇫' => 'filaagi: Agbègbè Gúúsù Faranṣé',
    '🇹🇬' => 'filaagi: Togo',
    '🇹🇭' => 'filaagi: Tailandi',
    '🇹🇯' => 'filaagi: Takisitani',
    '🇹🇰' => 'filaagi: Tokelau',
    '🇹🇱' => 'filaagi: Tímọ̀ Lẹsiti',
    '🇹🇲' => 'filaagi: Tọ́kìmẹ́nísítànì',
    '🇹🇳' => 'filaagi: Tuniṣia',
    '🇹🇴' => 'filaagi: Tonga',
    '🇹🇷' => 'filaagi: Tọọki',
    '🇹🇹' => 'filaagi: Tirinida ati Tobaga',
    '🇹🇻' => 'filaagi: Tufalu',
    '🇹🇼' => 'filaagi: Taiwani',
    '🇹🇿' => 'filaagi: Tàǹsáníà',
    '🇺🇦' => 'filaagi: Ukarini',
    '🇺🇬' => 'filaagi: Uganda',
    '🇺🇲' => 'filaagi: Àwọn Erékùsù Kékèké Agbègbè US',
    '🇺🇳' => 'filaagi: Ìṣọ̀kan àgbáyé',
    '🇺🇸' => 'filaagi: Amẹrikà',
    '🇺🇾' => 'filaagi: Úrúgúwè',
    '🇺🇿' => 'filaagi: Nṣibẹkisitani',
    '🇻🇦' => 'filaagi: Ìlú Vatican',
    '🇻🇨' => 'filaagi: Fisẹnnti ati Genadina',
    '🇻🇪' => 'filaagi: Fẹnẹṣuẹla',
    '🇻🇬' => 'filaagi: Etíkun Fágínì ti ìlú Bírítísì',
    '🇻🇮' => 'filaagi: Etikun Fagini ti Amẹrika',
    '🇻🇳' => 'filaagi: Fẹtinami',
    '🇻🇺' => 'filaagi: Faniatu',
    '🇼🇫' => 'filaagi: Wali ati futuna',
    '🇼🇸' => 'filaagi: Samọ',
    '🇽🇰' => 'filaagi: Kòsófò',
    '🇾🇪' => 'filaagi: Yemeni',
    '🇾🇹' => 'filaagi: Mayote',
    '🇿🇦' => 'filaagi: Gúúṣù Áfíríkà',
    '🇿🇲' => 'filaagi: Ṣamibia',
    '🇿🇼' => 'filaagi: Ṣimibabe',
    '🔟' => 'Keyacap: 10',
    '🏻' => 'amọ́lára',
    '🏼' => 'amọ́lára díẹ̀',
    '🏽' => 'amọ́láwọ̀ díẹ̀',
    '🏾' => 'adúláwọ̀ díẹ̀',
    '🏿' => 'adúláwọ̀',
    '😀' => 'Ojú tó rẹ́rìn',
    '😃' => 'Ojú tó rẹ́rìn Pẹ̀lú Ẹnu Lílà sílẹ̀',
    '😄' => 'ojú tó ń rẹ́rìń músẹ́ pẹ̀lú ẹnu lílà sílẹ̀ àti ẹyinjú tó ń rkrìń músẹ́',
    '😁' => 'Ojú tó fẹyín pẹ̀lú Ẹyinjú tó rẹ́rìn músẹ́',
    '😆' => 'ojú tó ń rẹ́rìń músẹ́ pẹ̀lú ẹnu lílà sílẹ̀ àti òógùn tútù',
    '😅' => 'ojú tó ń rẹ́rìń pẹ̀lú ẹnu lílà sílẹ̀ àti òógùn',
    '🤣' => 'Yíyí ní ilẹ̀nlẹ̀ tún rẹ́rìn',
    '😂' => 'Ojú pẹ̀lú ẹkún ayọ̀',
    '🙂' => 'Oju Ti O N Rẹrin Muṣẹn',
    '🙃' => 'Oju Ti O Rọ walẹ',
    '🫠' => 'Oju Ti O tẹ̀',
    '😉' => 'Ojú tó ṣẹ́jù',
    '😊' => 'Ojú tó rẹ́rìn Músẹ́ Pẹ̀lú Ẹyinjú tó rẹ́rìn Músẹ́',
    '😇' => 'Oju Ẹrin Ati Bawo',
    '🥰' => 'ojú erin pelu okan',
    '😍' => 'Oju Ti O N Rẹrin Pẹlu awọn oju Ọkan',
    '🤩' => 'Pípa pè̩lú ìràwọ̀',
    '😘' => 'Oju Ti O N Fẹ Ifẹnuko',
    '😗' => 'Ojú tó Fẹnuko ẹnu',
    '☺' => 'ojú tó ń rẹ́rìń músẹ́',
    '😚' => 'Oju Ti O N Fẹnuko Pẹlu Awọn Oju didi',
    '😙' => 'Ojú tó Fẹnuko ẹnu Pẹ̀lú Ẹyinjú tọ rẹ́rìn Músẹ́',
    '🥲' => 'ojú ẹ̀rín pẹ̀lú ẹkún',
    '😋' => 'Oju Ti O N jẹ Ounjẹ Aladidun',
    '😛' => 'Oju Ti Ahọn Ti O Yọ Sita',
    '😜' => 'ojú pẹ̀lú ahọ́n lílà sílẹ̀ àti ẹyinjú tí ń ṣẹ́jú',
    '🤪' => 'Ojú aṣiwèrè',
    '😝' => 'ojú pẹ̀lú ahọ́n lílà sílẹ̀ àti ẹyinjú tó padé',
    '🤑' => 'Oju Ẹnu owo',
    '🤗' => 'oju Ti O fanimọra',
    '🤭' => 'Ojú tá fọwọ́ bo ẹnu',
    '🫢' => 'ojú sísí lẹ̀ àti owo lori enu',
    '🫣' => 'ojú pẹ̀lú títọpinpin',
    '🤫' => 'Ojú tó sùpò̩',
    '🤔' => 'Ojú tó Ronú',
    '🫡' => 'ojú bíbọ̀wọ́',
    '🤐' => 'Oju Ẹni Ti A Tipa',
    '🤨' => 'Ìrun ojú ta gbé sókè',
    '😐' => 'Ojú Ìbíìbí',
    '😑' => 'Oju Ti Ko Fanimọra',
    '😶' => 'Ojú tí kò ní Ẹnu',
    '🫥' => 'ojú ìlà tótótó',
    '😏' => 'Oju Ẹrin Abosi',
    '😒' => 'Oju Aifanimọra',
    '🙄' => 'Ojú Pẹ̀lú Ẹyinjú tó yín',
    '😬' => 'Oju Ifaro',
    '🤥' => 'Oju Irọ',
    '🫨' => 'ojú gbígbọ̀n',
    '😌' => 'Oju Itura',
    '😔' => 'Oju Ironu',
    '😪' => 'Oju Iloorun',
    '🤤' => 'oju adatọ',
    '😴' => 'Oju Ti O N Sun',
    '🫩' => 'ojú pẹ̀lú ìsàlẹ̀ ojú tó wú',
    '😷' => 'Oju Pẹlu Iboju Iṣoogun',
    '🤒' => 'oju pẹlu oṣuwọn igbona',
    '🤕' => 'Oju Pẹlu Ori ti a de Lọja',
    '🤢' => 'Oju Ailera',
    '🤮' => 'Èébì ajẹmọ́jú',
    '🤧' => 'Oju Sinsin',
    '🥵' => 'ojú gbígbóná',
    '🥶' => 'ojú tútú',
    '🥴' => 'ojú to wópọ̀',
    '😵' => 'Oju Itoogbe',
    '🤯' => 'Orí tó bú gbàmù',
    '🤠' => 'Oju Fila Adaran',
    '🥳' => 'ojú patí',
    '🥸' => 'ojú ìsápamọ́',
    '😎' => 'Oju Ti O N Rẹrin Pẹlu Digi Oju',
    '🤓' => 'Oju Ọmọwe Ti O Jafafa',
    '🧐' => 'Ojú tó súnkì',
    '😕' => 'Oju Iporuru',
    '🫤' => 'ojú pẹ̀lú ẹnu ẹ̀gbẹ́',
    '😟' => 'Oju Idamu',
    '🙁' => 'Oju Ifajuro Diẹ',
    '☹' => 'ojú tó fajúro',
    '😮' => 'Oju Pẹlu Ẹnu Lila',
    '😯' => 'Oju Idakẹjẹ',
    '😲' => 'ojú ìyalẹnu',
    '😳' => 'Oju Idunnu',
    '🫪' => 'ojú tó ti dìdàkudà',
    '🥺' => 'ojú tónbẹ̀bẹ̀',
    '🥹' => 'ojú tón mu ẹkún dúró',
    '😦' => 'Oju Ti o Faro Pẹlu Ẹnu lila silẹ',
    '😧' => 'ojú ìrora',
    '😨' => 'Oju Ẹru',
    '😰' => 'ojú pẹ̀lú ẹnu lílà sílẹ̀ àti òógùn tútù',
    '😥' => 'Oju Ijakulẹ Ṣugbọn Itura',
    '😢' => 'Oju Ẹkun',
    '😭' => 'Oju Ti n Sunkun Gidi',
    '😱' => 'Oju Fifi Ẹru han an',
    '😖' => 'Oju Itiju',
    '😣' => 'Oju Ifarada',
    '😞' => 'ojú ìjakulẹ̀',
    '😓' => 'Oju Pẹlu Ilaagun Tutu',
    '😩' => 'Oju Ti o Rẹ̀',
    '😫' => 'Oju Rirẹ',
    '🥱' => 'ojú tón yán',
    '😤' => 'Oju Pẹlu Ooru Nimu',
    '😡' => 'Oju Iyaahan',
    '😠' => 'Oju Ibinu',
    '🤬' => 'Àmì ojú tó rékọjá ẹnu',
    '😈' => 'Oju Ẹrin Pẹlu Awọn Iwo',
    '👿' => 'Oju Ibinu Pẹlu Awọn Iwo',
    '💀' => 'Ipakọ',
    '☠' => 'ìpàkọ́ àti àwọn egun àgbélébù',
    '💩' => 'Okiti Igbẹ',
    '🤡' => 'ojú apanilẹrin',
    '👹' => 'Omiran Ajẹniyan',
    '👺' => 'abàmì aràrá',
    '👻' => 'òkú',
    '👽' => 'àjòjì',
    '👾' => 'Àjòjì Abami',
    '🤖' => 'Oju Ṣigidi',
    '😺' => 'Oju Arẹrin Ologbo Pẹlu Ẹnu Yiya',
    '😸' => 'Oju Ibinu Ologbo Pẹlu Awọn Oju Arẹrin',
    '😹' => 'Oju Ologbo Pẹlu Ẹkun Ayọ',
    '😻' => 'Oju Arẹrin Ologbo Pẹlu Oju-ọkan',
    '😼' => 'Oju Ologbo Pẹlu Ẹrin Afiniṣẹsin',
    '😽' => 'Oju Ologbo Afẹnukonu',
    '🙀' => 'Oju Ologbo Ti o Rẹ',
    '😿' => 'Oju Ẹkun Ologbo',
    '😾' => 'Oju Ete Ologbo',
    '🙈' => 'Ọbọ Mari Ibi',
    '🙉' => 'Ọbọ Magbọ Ibi',
    '🙊' => 'Ọbọ Masọ ibi',
    '💌' => 'Lẹta Ifẹ',
    '💘' => 'Ọkan Ti o Ni Ọfa',
    '💝' => 'Ọkan Pẹlu Riboni',
    '💖' => 'Ọkan Didan',
    '💗' => 'Ọkan Didagba',
    '💓' => 'Ọkan Ti O N Mi',
    '💞' => 'Ọkan Ti O N Yi',
    '💕' => 'Awọn Ọkan Meji',
    '💟' => 'Ọṣọ Ọkan',
    '❣' => 'àmì ìyanú ọkàn tó wúwo',
    '💔' => 'Ibanujẹ Ọkan',
    '❤' => 'ọkàn pupa',
    '🩷' => 'ọkàn pinki',
    '🧡' => 'ọlọkàn omi ọsàn',
    '💛' => 'Ọkan Awọ Ofeefe',
    '💚' => 'Ọkan Awọ Ewe',
    '💙' => 'Ọkan Bulu',
    '🩵' => 'okàn buluu díè',
    '💜' => 'Ọkan Awọ Pọpu',
    '🤎' => 'ọkàn awo igi',
    '🖤' => 'Ọkàn Dúdú',
    '🩶' => 'ọkan eerú',
    '🤍' => 'ọkàn funfun',
    '💋' => 'Aami Ifẹnuko',
    '💯' => 'koko ọgọrun',
    '💢' => 'Àmì Ibinu',
    '🫯' => 'ìjà inu ìkùukùu',
    '💥' => 'Ikọlu',
    '💫' => 'Itoogbe',
    '💦' => 'Ilaagun Ti N kan',
    '💨' => 'N Salọ',
    '🕳' => 'ihò',
    '💬' => 'Bàlúnù Ọ̀rọ̀ Sísọ',
    '🗨' => 'bàlúnù ọ̀rọ̀ sísọ òsì',
    '🗯' => 'bàlúnù ọ̀rọ̀ sísọ ọ̀tún',
    '💭' => 'Bàlúnù Ero',
    '💤' => 'Zzz',
    '👋' => 'N Juwọ',
    '🤚' => 'Na Ẹhin Ọwọ Soke',
    '🖐' => 'nawọ́ sókè pẹ̀lú ìyàka',
    '✋' => 'Ọwọ Nina Soke',
    '🖖' => 'Kiki Ibẹri Funni',
    '🫱' => 'ọwọ́ ọ̀tún',
    '🫲' => 'ọwọ́ òsì',
    '🫳' => 'àtẹ́lẹ̀wọ́ ìsàlẹ̀',
    '🫴' => 'àtẹ́lẹwọ́ òkè',
    '🫷' => 'títi ọwọ́ sọ́sì',
    '🫸' => 'títi ọwọ́ sọ́tun',
    '👌' => 'Ọwọ ODARA',
    '🤌' => 'ìka kíkákò',
    '🤏' => 'ìka kíká',
    '✌' => 'aṣeyọrí ọwọ́',
    '🤞' => 'Igbekalera',
    '🫰' => 'ọwọ́ pẹ̀lú ìka kẹ́keré àti ìka ńlá ní pípapọ̀',
    '🤟' => 'ìfọwọ́júwè mo ní ìfẹ́',
    '🤘' => 'Aami Awọn Iwo',
    '🤙' => 'Ọwọ Ipeni',
    '👈' => 'Ẹyin Ọwọ Ti O Tọka Si Apa Osi',
    '👉' => 'Ẹyin Ọwọ Ti O Tọka Si Apa Ọtun',
    '👆' => 'Ẹyin Ọwọ Ti O Tọka Si Oke',
    '🖕' => 'ìka àárín',
    '👇' => 'Ẹyin Ọwọ Ti O Tọka Si Isalẹ',
    '☝' => 'ìka kékeré tí ń tọ́ka sókè',
    '🫵' => 'títọ́ka sí olùwòran',
    '👍' => 'Atanpako Loke',
    '👎' => 'Atanpako Nisalẹ',
    '✊' => 'Ẹṣẹ Ti a Na Soke',
    '👊' => 'Ẹṣẹ Ti o Nbọ',
    '🤛' => 'Ẹsẹ ti O Kọju sosi',
    '🤜' => 'Ẹsẹ ti O Kọju sọtun',
    '👏' => 'N Patẹwọ',
    '🙌' => 'Ina Awọn Ọwọ',
    '🫶' => 'ọwọ́ ọkàn',
    '👐' => 'Awọn Ọwọ Ṣiṣi',
    '🤲' => 'àtẹ́lẹ́ọwọ́ papọ̀',
    '🤝' => 'Ìbọwọ́',
    '🙏' => 'Ika Awọn Ọwọ',
    '✍' => 'ńkọ́wé',
    '💅' => 'Ikun Eekanna',
    '🤳' => 'Yiya Ara ẹni',
    '💪' => 'Aya Fifẹ',
    '🦾' => 'apá iṣẹ̀',
    '🦿' => 'ese ise',
    '🦵' => 'ese',
    '🦶' => 'ẹsẹ̀',
    '👂' => 'Etí',
    '🦻' => 'etí pẹ̀lú ohun ìgbọ́ràn',
    '👃' => 'Imu',
    '🧠' => 'ọpọlọ',
    '🫀' => 'ọ̀kan alára',
    '🫁' => 'ẹ̀yà èémí',
    '🦷' => 'eyín',
    '🦴' => 'eegun',
    '👀' => 'Awọn Ojú',
    '👁' => 'eyinjú',
    '👅' => 'Ahọn',
    '👄' => 'Ẹnu',
    '🫦' => 'ètè gígé',
    '👶' => 'ìkókó',
    '🧒' => 'ọmọ',
    '👦' => 'ọmọkùnrin',
    '👧' => 'ọmọbìrin',
    '🧑' => 'àgbà',
    '👱' => 'Eniyan Onirun funfun',
    '👨' => 'Ọkùnrin',
    '🧔' => 'apárí',
    '👩' => 'Obìnrin',
    '🧓' => 'àgbàlagbà',
    '👴' => 'Agbalagba Ọkunrin',
    '👵' => 'Agbalagba Obinrin',
    '🙍' => 'Ẹni N Bojujẹ',
    '🙎' => 'Ẹni Yahọn sita',
    '🙅' => 'Ẹni Nsọ RARA',
    '🙆' => 'Ẹni Nsọ O DARA',
    '💁' => 'Ẹni N Tọka Ọwọ',
    '🙋' => 'Ẹni N Nawọ Soke',
    '🧏' => 'odi',
    '🙇' => 'Ẹni N Tẹriba',
    '🤦' => 'Ẹni Fọwọ Boju',
    '🤷' => 'Ẹni N Gunpa',
    '👮' => 'Ọlọpa',
    '🕵' => 'ọ̀tẹlèmúyé',
    '💂' => 'Oluṣọ',
    '🥷' => 'nínjà',
    '👷' => 'Oṣiṣẹ Ikọle',
    '🫅' => 'ènìyàn pẹ̀lú adé',
    '🤴' => 'Ọmọkunrin Alade',
    '👸' => 'Ọmọbinrin Alade',
    '👳' => 'Ẹni wọ Lawani',
    '👲' => 'Ọkunrin Pẹlu Fila Ṣainisi',
    '🧕' => 'obinrin tó wé gèlè',
    '🤵' => 'Ọkunrin Pẹlu Kootu',
    '👰' => 'Iyawo Pẹlu Iboju',
    '🤰' => 'obinrin alaboyun',
    '🫃' => 'aláboyún ọkùnrin',
    '🫄' => 'aláboyún',
    '🤱' => 'ìfọ́mọlọ́yàn',
    '👼' => 'ángẹli ìkókó',
    '🎅' => 'Baba Keresi',
    '🤶' => 'Arabinrin Keresi',
    '🦸' => 'akọni alágbára',
    '🦹' => 'alátakọ̀ alágbára',
    '🧙' => 'onídán',
    '🧚' => 'Iwin',
    '🧛' => 'Fánpáyà',
    '🧜' => 'Yemọja ènìyàn',
    '🧝' => 'Egbére',
    '🧞' => 'Ànjọ̀nnú',
    '🧟' => 'Ẹbọra',
    '🧌' => 'iwin nlá',
    '🫈' => 'ẹ̀dá onírun',
    '💆' => 'ẹni N gba Ifọwọwọnilara',
    '💇' => 'Ẹni N Gẹrun',
    '🚶' => 'Ẹni N Rin',
    '🧍' => 'ènìyàn dídúró',
    '🧎' => 'ènìyàn kíkúnlẹ̀',
    '🏃' => 'Ẹni N Sare',
    '💃' => 'Obinrin Ti Njo',
    '🕺' => 'Ọkunrin Ti Njo',
    '🕴' => 'ọkùnrin nínu kóòtú òwò',
    '👯' => 'awọn eniyan eleti ehoro',
    '🧖' => 'Ènìyàn nínú Ìyàrá tó n gbóná',
    '🧗' => 'Ènìyàn tó n gòkè',
    '🤺' => 'Ẹni N Ja Pẹlu Ida',
    '🏇' => 'Ereje Ẹlẹsin',
    '⛷' => 'ẹni n síkì',
    '🏂' => 'Iṣere Ori Yiyin',
    '🏌' => 'ẹni gọ́ọ̀fù',
    '🏄' => 'Ẹni N Gun Iji',
    '🚣' => 'Ẹni N wa Ọkọ',
    '🏊' => 'Ẹni tí ń wẹdò',
    '⛹' => 'ẹni tà boun bọ́ọ̀lù',
    '🏋' => 'ẹni fa ìwọ̀n sókè',
    '🚴' => 'Ẹni N Gun Kẹkẹ',
    '🚵' => 'Ẹni N Gun Kẹkẹ Gun Apata',
    '🤸' => 'Ẹni Kawọ Tilẹ Kẹsẹ Soke',
    '🤼' => 'Awọn Onigidigbo',
    '🤽' => 'Ẹni N ṣere Olomi',
    '🤾' => 'Ẹni N Ṣere Bọọlu Ọlọwọ',
    '🤹' => 'Ẹni N ju Nnkan soke',
    '🧘' => 'Ènìyàn nípò ìgbàgbé',
    '🛀' => 'Ẹni Nwẹ',
    '🛌' => 'Ẹniyan Nibusun',
    '👭' => 'Obinrin Meji Ti O Dọwọ Ara Wọn Mu',
    '👫' => 'Ọkunrin Ati Obirin Ti O Dọwọ Ara Wọn Mu',
    '👬' => 'Ọkunrin Meji Ti O Dọwọ Ara Wọn Mu',
    '💏' => 'Ifẹnuko',
    '💑' => 'Lọkọlaya Pẹlu ọkan',
    '🗣' => 'orí tí ń sọ̀rọ̀',
    '👤' => 'Bujade Ni Biribiri',
    '👥' => 'Awọn Ibujade Ni Biribiri',
    '🫂' => 'àwọn ènìyàn tóndìmọ́ra',
    '👪' => 'Ẹbí',
    '👣' => 'Ipa ẹsẹ',
    '🫆' => 'ìtẹ̀ka',
    '🦰' => 'irun pupa',
    '🦱' => 'irun rírọ̀',
    '🦳' => 'irun funfun',
    '🦲' => 'orí pípá',
    '🐵' => 'Oju Ọbọ',
    '🐒' => 'Ọ̀bọ',
    '🦍' => 'Inaki',
    '🦧' => 'oraguta',
    '🐶' => 'Ojú ajá',
    '🐕' => 'Ajá',
    '🦮' => 'ajá ìtóni',
    '🐩' => 'Ajá kékeré',
    '🐺' => 'Ikooko',
    '🦊' => 'Kọlọkọlọ',
    '🦝' => 'rakumi',
    '🐱' => 'Ojú olóńgbò',
    '🐈' => 'Olóńgbò',
    '🦁' => 'Kiniun',
    '🐯' => 'Oju Ẹkùn',
    '🐅' => 'Ẹkùn',
    '🐆' => 'Àmọ̀tẹ́kùn',
    '🐴' => 'Oju Ẹṣin',
    '🫎' => 'ẹmọ́',
    '🫏' => 'kẹ́tẹ́kẹ́tẹ́',
    '🐎' => 'Ẹṣin',
    '🦄' => 'Oju Ẹṣin Oniwo',
    '🦓' => 'kẹ́tẹ́kẹ́tẹ́ abìla',
    '🦌' => 'Agbọnrin',
    '🦬' => 'bison',
    '🐮' => 'Oju Maalu',
    '🐂' => 'Ẹgbọrọ maalu',
    '🐃' => 'Ẹfọn Omi',
    '🐄' => 'Maalu',
    '🐷' => 'Oju Ẹlẹdẹ',
    '🐖' => 'Ẹlẹdẹ',
    '🐗' => 'Biari',
    '🐽' => 'Imu Ẹlẹdẹ',
    '🐏' => 'Agbo',
    '🐑' => 'abo àgùntàn',
    '🐐' => 'Ewúrẹ́',
    '🐪' => 'Kẹtẹkẹtẹ',
    '🐫' => 'Kẹtẹkẹtẹ Onike-Meji',
    '🦙' => 'llama',
    '🦒' => 'àgùfọn',
    '🐘' => 'Erin',
    '🦣' => 'mamotì',
    '🦏' => 'Ẹranko Imado',
    '🦛' => 'hipopotámọ́ọ̀sì',
    '🐭' => 'Ọju Eku',
    '🐁' => 'Eku',
    '🐀' => 'Ekute',
    '🐹' => 'Oju Eku Oko',
    '🐰' => 'Oju Ehoro',
    '🐇' => 'Ehoro',
    '🐿' => 'eku ńlá',
    '🦫' => 'bifa',
    '🦔' => 'hedgehog',
    '🦇' => 'Adan',
    '🐻' => 'Oju Biari',
    '🐨' => 'Koala',
    '🐼' => 'Oju Panda',
    '🦥' => 'àsẹ́wó',
    '🦦' => 'ota',
    '🦨' => 'Vote òkété igbó',
    '🦘' => 'kangaròó',
    '🦡' => 'bájà',
    '🐾' => 'Apa Eekan',
    '🦃' => 'Tólòtólò',
    '🐔' => 'Adìyẹ',
    '🐓' => 'Akukọ',
    '🐣' => 'Ọmọ Adiyẹ Pipa',
    '🐤' => 'Ọmọ Adiyẹ',
    '🐥' => 'Ọmọ Adiyẹ ti now Iwaju',
    '🐦' => 'Ẹyẹ',
    '🐧' => 'Ẹyẹ Oko',
    '🕊' => 'àdàbà',
    '🦅' => 'Àṣá',
    '🦆' => 'Pẹ́pẹ́yẹ',
    '🦢' => 'ẹyẹ swan',
    '🦉' => 'Owiwi',
    '🦤' => 'ẹyẹ dodo',
    '🪶' => 'ìyẹ́',
    '🦩' => 'Vote ẹyẹ flamingò',
    '🦚' => 'ọ̀kín',
    '🦜' => 'àparò',
    '🪽' => 'iye',
    '🪿' => 'tòlotòló',
    '🐸' => 'ọ̀pọ̀lọ́',
    '🐊' => 'Ọni',
    '🐢' => 'Adaba',
    '🦎' => 'Aláǹgba',
    '🐍' => 'Ejò',
    '🐲' => 'Oju Dragoni',
    '🐉' => 'Drágónì',
    '🦕' => 'sauropod',
    '🦖' => 'T-Rex',
    '🐳' => 'Ẹja Nla Atutọ',
    '🐋' => 'Ẹja Nla',
    '🐬' => 'Dọfini',
    '🫍' => 'òbéjé',
    '🦭' => 'alákàsà',
    '🐟' => 'Ẹja',
    '🐠' => 'Ẹja oorùn',
    '🐡' => 'Ẹja Awura',
    '🦈' => 'Ṣáàkì',
    '🐙' => 'Ẹja ẹlẹsẹ mẹjọ',
    '🐚' => 'Onikaraun Pinpin',
    '🪸' => 'kórà',
    '🪼' => 'ẹ̀ja jẹ́lì',
    '🦀' => 'Alákàn',
    '🦞' => 'akàn',
    '🦐' => 'Ede',
    '🦑' => 'Sikidi',
    '🦪' => 'alákàn ńlá',
    '🐌' => 'Ìgbín',
    '🦋' => 'Labalaba',
    '🐛' => 'Ìyanjú Àṣìṣe',
    '🐜' => 'Kokoro',
    '🐝' => 'Oyin',
    '🪲' => 'bítù',
    '🐞' => 'Yigbẹ-yigbẹ',
    '🦗' => 'tata gígùn',
    '🪳' => 'ayán',
    '🕷' => 'aláõtakùn',
    '🕸' => 'ìtakùnaláõtakùn',
    '🦂' => 'Àkekè',
    '🦟' => 'ẹ̀fọ́n',
    '🪰' => 'eṣinṣin',
    '🪱' => 'ekòló',
    '🦠' => 'maikirobu',
    '💐' => 'Àsè',
    '🌸' => 'Iruwe Ṣẹri',
    '💮' => 'Ododo Funfun',
    '🪷' => 'lotosi',
    '🏵' => 'Ohun Odòdó ọṣọ',
    '🌹' => 'Ododo',
    '🥀' => 'ododo witi',
    '🌺' => 'Ododo Ibisikọsi',
    '🌻' => 'Ìtàná',
    '🌼' => 'Iruwe',
    '🌷' => 'Tulipu',
    '🪻' => 'hayasinti',
    '🌱' => 'Ihoro eso',
    '🪴' => 'eso pootù',
    '🌲' => 'Igi Aruwe',
    '🌳' => 'Igi Igbo',
    '🌴' => 'Ọpẹ',
    '🌵' => 'Igi Ọrọ́',
    '🌾' => 'Idi Ti Irẹsi',
    '🌿' => 'Egbo Igi',
    '☘' => 'ṣámrọkì',
    '🍀' => 'Ahoro Elewe Merin',
    '🍁' => 'Ewe Mapulu',
    '🍂' => 'Irawe',
    '🍃' => 'Ewe Ti N Fanka Ninu Iji',
    '🪹' => 'ibi ìyéeyin òfìfo',
    '🪺' => 'ibi ìyéeyin pẹ̀lú ẹyin',
    '🍄' => 'Olu',
    '🪾' => 'igi tí kò léwẹ́',
    '🍇' => 'Girapu',
    '🍈' => 'Ẹ̀gúsí',
    '🍉' => 'Eso Bara',
    '🍊' => 'Tanjarini',
    '🍋' => 'Orombo-wẹwẹ Chiffon',
    '🍌' => 'Ọ̀gẹ̀dẹ̀',
    '🍍' => 'Ọpẹ-oyinbo',
    '🥭' => 'mángò',
    '🍎' => 'Apu Pupa',
    '🍏' => 'Apu Alawọ Ewe',
    '🍐' => 'Píà',
    '🍑' => 'Píísì',
    '🍒' => 'Ṣẹẹri',
    '🍓' => 'Eso dundun',
    '🫐' => 'bẹ́rì búlù',
    '🥝' => 'Eso Kiwi',
    '🍅' => 'Timati',
    '🫒' => 'Olifi',
    '🥥' => 'àgbọn',
    '🥑' => 'Afokado',
    '🍆' => 'Igba',
    '🥔' => 'Ànàmọ́',
    '🥕' => 'Kárọ̀tì',
    '🌽' => 'Agbado',
    '🌶' => 'ata gbígbónọ̀',
    '🫑' => 'tàtàsé',
    '🥒' => 'Kùkúmbà',
    '🥬' => 'ẹ̀fọ́',
    '🥦' => 'ewé ẹlẹ́fọ̀ọ́',
    '🧄' => 'gálíìkì',
    '🧅' => 'àlùbọ́sà',
    '🥜' => 'Ẹpa',
    '🫘' => 'ẹ̀wà',
    '🌰' => 'Kóró inú èso búránù',
    '🫚' => 'jínjà',
    '🫛' => 'eap',
    '🫜' => 'ohun ọ̀gbìn onígbòǹgbọ̀',
    '🍞' => 'Búrẹ́dì',
    '🥐' => 'Kurosanti',
    '🥖' => 'Burẹdi Baguette',
    '🫓' => 'búrẹ́ẹ̀dì pẹlẹpẹ',
    '🥨' => 'pretzel',
    '🥯' => 'bágẹ́lì',
    '🥞' => 'Atike Ikunju',
    '🧇' => 'wáfù',
    '🧀' => 'Waara Wedge',
    '🍖' => 'Ẹran Ara Egungun',
    '🍗' => 'Ẹsẹ Adiyẹ',
    '🥩' => 'ìgé ẹran',
    '🥓' => 'Ẹran Ẹlẹdẹ',
    '🍔' => 'Hamburger',
    '🍟' => 'Ounjẹ Ipanu Didun',
    '🍕' => 'Písà',
    '🌭' => 'Hot Dog',
    '🥪' => 'búrẹ́dì alákànpọ̀',
    '🌮' => 'Taco',
    '🌯' => 'Burito',
    '🫔' => 'tamalé',
    '🥙' => 'Burẹdi Afunpọ Pẹlẹbẹ',
    '🧆' => 'faláfẹ́l]i',
    '🥚' => 'Ẹyin',
    '🍳' => 'Dídáná',
    '🥘' => 'Paanu Ijẹun kekere',
    '🍲' => 'Ikoko Ounjẹ',
    '🫕' => 'fóndù',
    '🥣' => 'abọ́ pẹ̀lú ṣíbí',
    '🥗' => 'Saladi Elewe',
    '🍿' => 'Gúgúrú',
    '🧈' => 'bọ́tà',
    '🧂' => 'iyọ̀',
    '🥫' => 'ónjẹ inú agolo',
    '🍱' => 'Apoti Bento',
    '🍘' => 'Biskit Irẹsi',
    '🍙' => 'Irẹsi Roboto',
    '🍚' => 'Irẹsi Sise',
    '🍛' => 'irẹsi kọri',
    '🍜' => 'Abọ ibọhun',
    '🍝' => 'Spagẹti',
    '🍠' => 'Anamọ dindin',
    '🍢' => 'Oden',
    '🍣' => 'Sushi',
    '🍤' => 'Ede Dindin',
    '🍥' => 'Eja dindin Pẹlu Swirl',
    '🥮' => 'àkàrà òsùpá',
    '🍡' => 'Dango',
    '🥟' => 'ìgbẹ́',
    '🥠' => 'kúkì fortune',
    '🥡' => 'àpótí àgbéjáde',
    '🍦' => 'Wara Didi Rirọ',
    '🍧' => 'Yinyin Gige',
    '🍨' => 'Wara Didi',
    '🍩' => 'Dónọ́ọ̀tì',
    '🍪' => 'Kuki',
    '🎂' => 'Àkàrà òyìnbó ọjọ́ìbí',
    '🍰' => 'Akara kekere',
    '🧁' => 'akara oyinbo',
    '🥧' => 'róbótó',
    '🍫' => 'Ṣokoleti Didi',
    '🍬' => 'Kandi',
    '🍭' => 'Suuti Onigi',
    '🍮' => 'Kọ́sítàdì',
    '🍯' => 'Koko Oyin',
    '🍼' => 'Igo Ikoko',
    '🥛' => 'Ife Wara',
    '☕' => 'Tii Gbigbona',
    '🫖' => 'pọ́ọ̀tù tíì',
    '🍵' => 'Ife Tii laini Ọwọ',
    '🍶' => 'Sake',
    '🍾' => 'Igo Olori Yiyọ',
    '🍷' => 'Gilasi Waini',
    '🍸' => 'Gilasi Ounjẹ Amulumala',
    '🍹' => 'Ohun Mimu Akoko Oorun',
    '🍺' => 'Imuti',
    '🍻' => 'Imuti Dídún',
    '🥂' => 'Gilasi Didun',
    '🥃' => 'Gilasi Tọnbila',
    '🫗' => 'nǹkan olómi dídà',
    '🥤' => 'ife pẹ̀lú sírọ̀',
    '🧋' => 'tíì bọ́bù',
    '🧃' => 'àpótí ohun mímu',
    '🧉' => 'ẹgbẹ́',
    '🧊' => 'omi dídì',
    '🥢' => 'igi ìjẹun',
    '🍽' => 'fọ́ọ̀kì àti ọ̀bẹ pẹ̀lú àwo',
    '🍴' => 'Fọki Ati Ọbẹ',
    '🥄' => 'Ṣíbí',
    '🔪' => 'ọbẹ iyara-idana',
    '🫙' => 'ife nla',
    '🏺' => 'Amphora',
    '🌍' => 'Gulobu To N Ṣafihan Uropu-Afirika',
    '🌎' => 'Gulobu To N Ṣafihan Amẹrika',
    '🌏' => 'Gulobu To N Ṣafihan Aṣia-Ọsiteria',
    '🌐' => 'Gulobu Pẹlu Mẹridiani',
    '🗺' => 'máàpù àgbáyé',
    '🗾' => 'Maapu Ti Japanu',
    '🧭' => 'atọ́nà',
    '🏔' => 'òkè yìnyín',
    '⛰' => 'òkè',
    '🛘' => 'ìyẹ̀gẹ̀rẹ̀ ilẹ̀',
    '🌋' => 'Ifẹ-ilẹ',
    '🗻' => 'Oke Fuji',
    '🏕' => 'pípàgọ́',
    '🏖' => 'ọ̀sà pẹ̀lú agbòrùn',
    '🏜' => 'aṣálẹ̀',
    '🏝' => 'erékùṣù aṣálẹ̀',
    '🏞' => 'páàkì orílẹ̀',
    '🏟' => 'pápá ìṣeré',
    '🏛' => 'ilé tó kílásíkà',
    '🏗' => 'iṣẹ́ ọnà ilé',
    '🧱' => 'bíríkì',
    '🪨' => 'àpáta',
    '🪵' => 'igi',
    '🛖' => 'abà',
    '🏘' => 'àwọn ilé',
    '🏚' => 'ilé àìdára',
    '🏠' => 'Ilé',
    '🏡' => 'Ile Pelu Ọgba',
    '🏢' => 'Ile Ibi-iṣẹ',
    '🏣' => 'Ile-iṣẹ Ifiweranṣẹ Japani',
    '🏤' => 'Àpótí ÌfìwéRánṣẹ́',
    '🏥' => 'Ile-iwosan',
    '🏦' => 'Ile-ifowopamọsi',
    '🏨' => 'Ilé ìtura',
    '🏩' => 'Ilé ìtura Ifẹ',
    '🏪' => 'Ibi Itura',
    '🏫' => 'Ilé ìwé',
    '🏬' => 'ẹka itaja',
    '🏭' => 'Ilé-iṣẹ́',
    '🏯' => 'Ile Nla Japanisi',
    '🏰' => 'Ile Nla',
    '💒' => 'Ìgbéyàwó',
    '🗼' => 'Ile Iṣọ Tokiyo',
    '🗽' => 'Ere Ominira',
    '⛪' => 'Ṣọọṣi',
    '🕌' => 'Mọ́ṣáláṣí',
    '🛕' => 'ilé ìjọ́sìn Hindu',
    '🕍' => 'Sínágọ́gù',
    '⛩' => 'ilé òrìṣà ṣíntò',
    '🕋' => 'Kaaba',
    '⛲' => 'Orísun omi',
    '⛺' => 'Àgọ́',
    '🌁' => 'Ojuju',
    '🌃' => 'Aṣalẹ Pẹlu Awọn Irawọ',
    '🏙' => 'fífẹ̀ìlú',
    '🌄' => 'Lila Oorun Lori Awọn Oke',
    '🌅' => 'Ìlà oòrùn',
    '🌆' => 'Iwo Ilu Ni Aṣalẹ',
    '🌇' => 'Ìwọ̀ oòrùn',
    '🌉' => 'Afara Ni Aṣalẹ',
    '♨' => 'omi àtilẹ̀wá',
    '🎠' => 'Ẹṣin Aladun',
    '🛝' => 'ibi eré',
    '🎡' => 'Kẹ̀kẹ́ Ferris',
    '🎢' => 'Kẹkẹ Olobiri',
    '💈' => 'Opo Onigbajamọ',
    '🎪' => 'Aba Ere-idaraya',
    '🚂' => 'Yiyi',
    '🚃' => 'Ọkọ Oju-irin',
    '🚄' => 'Ọkọ oju-irin Alare',
    '🚅' => 'Ọkọ oju-irin Alare Pẹlu Imu Ọta',
    '🚆' => 'Ṣèdánilẹ́kọ̀ọ́',
    '🚇' => 'Àjà ilẹ̀',
    '🚈' => 'Ọkọ oju-irin kekere',
    '🚉' => 'Ibudo',
    '🚊' => 'Tiramu',
    '🚝' => 'Oju irin kan',
    '🚞' => 'Reluwe Oloke',
    '🚋' => 'Ọkọ Tiramu',
    '🚌' => 'Ọkọ Akero',
    '🚍' => 'Ọkọ Akero Ti Nbọ',
    '🚎' => 'Ọkọ Akero Oniwiwọ',
    '🚐' => 'Ọkọ Akero Kekere',
    '🚑' => 'Ọkọ Alaisan',
    '🚒' => 'Ẹnjini Onina',
    '🚓' => 'Ọkọ Ọlọpa',
    '🚔' => 'Ọkọ Ọlọpa Ti Nbọ',
    '🚕' => 'Taasi',
    '🚖' => 'Taasi Ti Nbọ',
    '🚗' => 'Ọko',
    '🚘' => 'Ọkọ Ti Nbọ',
    '🚙' => 'Ọkọ Agbafẹ Daradara',
    '🛻' => 'ọkọ̀ ńlá fún gbígbé nǹkan',
    '🚚' => 'Ọkọ Akẹru',
    '🚛' => 'Ọkọ Nla Akẹru',
    '🚜' => 'Katakata',
    '🏎' => 'ọkọ̀ ìdíje eré',
    '🏍' => 'alùpùpù',
    '🛵' => 'alupupu onimọto',
    '🦽' => 'aga ìgbérìn ọlọ́wọ́',
    '🦼' => 'àga ìgbérìn oníná',
    '🛺' => 'ẹ̀rọ ríìkì',
    '🚲' => 'Kẹ̀kẹ́',
    '🛴' => 'alupupu kekere',
    '🛹' => 'bọ́ọ̀dù ti síkéètì',
    '🛼' => 'síkéètì ti ó s;are',
    '🚏' => 'Ibudokọ',
    '🛣' => 'ojú ọ̀nà ọkọ̀',
    '🛤' => 'ọ̀nà ojú-irin',
    '🛢' => 'àgbá epo',
    '⛽' => 'pọ̀mpù epo',
    '🛞' => 'keke',
    '🚨' => 'Ina Ọkọ Ọlọpa',
    '🚥' => 'Ina Adariko Onidubu',
    '🚦' => 'Ina Adariko Olopo',
    '🛑' => 'Aami Idaduro',
    '🚧' => 'Iṣẹ́ ọnà',
    '⚓' => 'Ìdákòró',
    '🛟' => 'ríngì',
    '⛵' => 'Ọkọ kekere',
    '🛶' => 'obele',
    '🚤' => 'Ọkọ omi alare',
    '🛳' => 'ọkọ̀ ojú omi ńlá èrò',
    '⛴' => 'ferí',
    '🛥' => 'ọkọ̀ ojú omi tó ń lo ẹ̀rọ',
    '🚢' => 'Ọkọ̀ ojú omi ńlá',
    '✈' => 'bàlú òfurufú',
    '🛩' => 'bàlú òfurufú kékeré',
    '🛫' => 'Ibi Idagbere Baalu',
    '🛬' => 'Ibi Ikaabọ Baalu',
    '🪂' => 'páráṣútì',
    '💺' => 'Ìjòkó',
    '🚁' => 'Ẹlikọputa',
    '🚟' => 'Ọkọ oju irin Oloke',
    '🚠' => 'Ọkọ oniwaya Ori-oke',
    '🚡' => 'Tramway Eriali',
    '🛰' => 'alátagbà',
    '🚀' => 'Rọ́kẹ̀tì',
    '🛸' => 'àwọ kékeré tí ń fò',
    '🛎' => 'agogo alágbágbẹ́rùn ilé ìtura',
    '🧳' => 'ẹrù',
    '⌛' => 'Gilasiakoko',
    '⏳' => 'Gilasiakoko Pẹlu Iyẹpẹ Ti N fẹ',
    '⌚' => 'Ago',
    '⏰' => 'Ago Itaniji',
    '⏱' => 'ago aláfọwọ́yí',
    '⏲' => 'ago adíwọ̀n àkókò',
    '🕰' => 'ago àgbélẹ̀',
    '🕛' => 'Ago Mejila',
    '🕧' => 'Ago Mejila Aabọ',
    '🕐' => 'Ago Kan an',
    '🕜' => 'Ago kan an aabọ',
    '🕑' => 'Ago Meji',
    '🕝' => 'Ago Meji Aaabọ',
    '🕒' => 'Ago Mẹta',
    '🕞' => 'Ago Mẹta Aabọ',
    '🕓' => 'Ago Mẹrin',
    '🕟' => 'Ago Merin Aabọ',
    '🕔' => 'Ago Marun un',
    '🕠' => 'Ago Marun un Aabọ',
    '🕕' => 'Ago Mẹfa',
    '🕡' => 'Ago Mẹfa Aabọ',
    '🕖' => 'Ago Meje',
    '🕢' => 'Ago Meje Aabọ',
    '🕗' => 'Ago Mẹjọ',
    '🕣' => 'Ago Mejọ Aabọ',
    '🕘' => 'Ago Mẹsan an',
    '🕤' => 'Ago Mẹsan an Aabọ',
    '🕙' => 'Ago Mẹwa',
    '🕥' => 'Ago Mẹwa Aabọ',
    '🕚' => 'Ago Mọkanla',
    '🕦' => 'Ago Mọkanla Aabọ',
    '🌑' => 'Òṣùpá Tuntun',
    '🌒' => 'Yíyọ́ Ààbọ̀ Oṣùpá',
    '🌓' => 'Oṣùpá Ìlàrin Àkọ́kọ́',
    '🌔' => 'Yíyọ́ Kíkún Oṣùpá',
    '🌕' => 'Ẹ̀kúnrẹ́rẹ́ Òṣùpá',
    '🌖' => 'Títàn Kíkún Oṣùpá',
    '🌗' => 'Oṣùpá Ìlàrin Ìgbẹ̀yìn',
    '🌘' => 'Títàn Ààbọ̀ Oṣùpá',
    '🌙' => 'Ààbọ̀ Oṣùpá',
    '🌚' => 'Oju Òṣùpá Tuntun',
    '🌛' => 'Oṣùpá Ìlàrin Àkọ́kọ́ Pẹ̀lú Ojú',
    '🌜' => 'Oṣùpá Ìlàrin Ìgbẹ̀yìn Pẹ̀lú Ojú',
    '🌡' => 'òṣùwọ̀n ìgbóná',
    '☀' => 'òrùn',
    '🌝' => 'Ẹ̀kúnrẹ́rẹ́ Òṣùpá Pẹ̀lú Ojú',
    '🌞' => 'Oorun Pẹlu Oju',
    '🪐' => 'plánẹ́tì oiringì',
    '⭐' => 'Irawọ Alaabọ Funfun',
    '🌟' => 'Irawọ Titan',
    '🌠' => 'Irawọ Yiyọ',
    '🌌' => 'Ọna Oniwara',
    '☁' => 'òfurufú',
    '⛅' => 'Oorun Lẹhin Ofurufu',
    '⛈' => 'òfurufú pẹ̀lú ṣíṣáná àti òjò',
    '🌤' => 'òòrùn lẹ́yìn òfurufú kékeré',
    '🌥' => 'òòrùn lẹ́yìn òfurufú tó tóbi',
    '🌦' => 'òòrùn lẹ́yìn òfurufú òjò',
    '🌧' => 'òfurufú pẹ̀lú òjò',
    '🌨' => 'òfurufú pẹ̀lú yìnyín',
    '🌩' => 'òfurufú pẹlu ṣíṣáná',
    '🌪' => 'ìjì tó le',
    '🌫' => 'kùrukùru',
    '🌬' => 'ojú atẹ́gùn',
    '🌀' => 'Ẹfuufu',
    '🌈' => 'òṣùmarè',
    '🌂' => 'Agboorun Toti',
    '☂' => 'agbòrùn',
    '☔' => 'Agboorun Pẹlu Omi Ojo Kikan',
    '⛱' => 'agbòrùn ní ilẹ̀',
    '⚡' => 'Agbara Ina Giga',
    '❄' => 'ìdìjọ òjò yìnyín',
    '☃' => 'ọkùnrin yìnyín',
    '⛄' => 'Ọkunrin yinyin Laini Yinyin',
    '☄' => 'kamẹ́tì',
    '🔥' => 'Iná',
    '💧' => 'Drọ́púlẹ́ẹ̀tì',
    '🌊' => 'Iji Omi',
    '🎃' => 'Jack-o-Atupa',
    '🎄' => 'Igi Keresimesi',
    '🎆' => 'Iṣẹ́iná',
    '🎇' => 'Olutan',
    '🧨' => 'olufa iná',
    '✨' => 'Awọn Titan',
    '🎈' => 'Bàlúùnù',
    '🎉' => 'Ariwo Ayẹye',
    '🎊' => 'Bọọlu Kọnfẹti',
    '🎋' => 'Igi Tanabata',
    '🎍' => 'Ẹṣọ Ọpẹ oyinbo',
    '🎎' => 'Awọn Ere Japanisi',
    '🎏' => 'Olugekere Capu',
    '🎐' => 'Idun Iji',
    '🎑' => 'Wiwo Ayẹyẹ Oṣupa',
    '🧧' => 'akolẹ́tàsí pupa',
    '🎀' => 'Ríbìnnì',
    '🎁' => 'Ẹbun Didi',
    '🎗' => 'ríbínì ìránilétí',
    '🎟' => 'àwọn ìwọlé ìgbaniwọlé',
    '🎫' => 'Iwe Iwọle',
    '🎖' => 'fàdákà ológun',
    '🏆' => 'Ife',
    '🏅' => 'Fadaka Ere idaraya',
    '🥇' => 'Fadaka Ipo Akọkọ',
    '🥈' => 'Fadaka Ipo Ekeji',
    '🥉' => 'Fadaka Ipo Ẹkẹta',
    '⚽' => 'Bọọlu Afẹsẹgba',
    '⚾' => 'Bọ́ọ̀lùòkè',
    '🥎' => 'bọ́ọ̀lu olowo',
    '🏀' => 'Bọ́ọ̀lùalágbọ̀n',
    '🏐' => 'Folliboolu',
    '🏈' => 'Bọọlu Amẹrika',
    '🏉' => 'Bọọlu Rọgibi',
    '🎾' => 'Tẹnisi',
    '🥏' => 'disiki fifo',
    '🎳' => 'Bolin',
    '🏏' => 'eré bọ́ọ̀lù afi pátákó gbá',
    '🏑' => 'Họki Papa',
    '🏒' => 'Họki Yinyin',
    '🥍' => 'lákúrósè',
    '🏓' => 'Bọọlu Ori Tabili',
    '🏸' => 'Badimitin',
    '🥊' => 'gilofu ikanṣẹ',
    '🥋' => 'Aṣọ Ere Itapa',
    '🥅' => 'àwọ̀n góòlù',
    '⛳' => 'Asia Ninu Iho',
    '⛸' => 'yìnyín síkétì',
    '🎣' => 'Opo Ipẹja',
    '🤿' => 'iboju fifo',
    '🎽' => 'Ṣẹẹti Isare',
    '🎿' => 'Awọn Siki',
    '🛷' => 'sílẹ́dì',
    '🥌' => 'òkúta ìwọ́',
    '🎯' => 'Igba Taara',
    '🪀' => 'yóyò',
    '🪁' => 'káìtì',
    '🔫' => 'ibọn ilewọ',
    '🎱' => 'Bọọlu Odo 8',
    '🔮' => 'bọọlu aworawọ',
    '🪄' => 'idán',
    '🎮' => 'Ere-idaraya Fidio',
    '🕹' => 'ìdarí eré',
    '🎰' => 'Ẹrọ Ifisi',
    '🎲' => 'Ere-idaraya Ludo',
    '🧩' => 'ohun àdìtú',
    '🧸' => 'ekùn ifi',
    '🪅' => 'pinátà',
    '🪩' => 'bọ́ọ̀lu onijigí',
    '🪆' => 'dọ́lù ìsimi',
    '♠' => 'ìpín káàdì sípèdì',
    '♥' => 'ìpín káàdì ọkàn',
    '♦' => 'ìpín káàdì díámọ́ndì',
    '♣' => 'ìpín káàdì ewé',
    '♟' => 'pọ́nì Ṣẹ́ẹ̀sì',
    '🃏' => 'Joka',
    '🀄' => 'Dragoni Pupa Mahjong',
    '🎴' => 'Káàdì ìṣeré Olódòdó',
    '🎭' => 'Eré oríìtàgé',
    '🖼' => 'àwọrán inú férémù',
    '🎨' => 'Pẹpẹ Oṣere',
    '🧵' => 'òwú',
    '🪡' => 'òwú ìránṣọ',
    '🧶' => 'asọ',
    '🪢' => 'ìsopọ̀',
    '👓' => 'Dígí',
    '🕶' => 'gíláásì òrùn',
    '🥽' => 'gọ́gú',
    '🥼' => 'aṣọ ilé ìṣàyẹ̀wò',
    '🦺' => 'aṣọ àbò',
    '👔' => 'Okùnọrùn',
    '👕' => 'Ṣẹ́ẹ̀tì',
    '👖' => 'Jinsi',
    '🧣' => 'síkáfù',
    '🧤' => 'ìbọ̀wọ́',
    '🧥' => 'kóòtù',
    '🧦' => 'ìbọ̀sẹ̀',
    '👗' => 'Aṣọ',
    '👘' => 'Kimono',
    '🥻' => 'sari',
    '🩱' => 'aso ìwẹ̀',
    '🩲' => 'aṣọ kékeré',
    '🩳' => 'aṣọ pẹ́npé',
    '👙' => 'Pata obinrin',
    '👚' => 'Awọn Aṣọ Obinrin',
    '🪭' => 'fáànì ọlọ́wọ́',
    '👛' => 'Pọọsi',
    '👜' => 'Ìpamọ́wọ́',
    '👝' => 'Baagi Ipamọwọ',
    '🛍' => 'àwọn àpamọ́wọ́ ọjà',
    '🎒' => 'Baagi Ile-ẹkọ Agbekẹyin',
    '🩴' => 'salubata tongi',
    '👞' => 'Bata Ọkunrin',
    '👟' => 'Bata Isare',
    '🥾' => 'bóòtì ìgokè',
    '🥿' => 'bàtà pẹlẹbẹ',
    '👠' => 'Bata Gogoro',
    '👡' => 'Bata Obinrin pẹlẹbẹ',
    '🩰' => 'bàtà ijó',
    '👢' => 'Buutu Obinrin',
    '🪮' => 'ẹ̀sọ́ irun',
    '👑' => 'Ade',
    '👒' => 'Haati Obinrin',
    '🎩' => 'Haati Oke',
    '🎓' => 'Fila Aṣeyọri',
    '🧢' => 'fìla billed',
    '🪖' => 'ìbòrí ológun',
    '⛑' => 'koto òṣìṣẹ́ ìrànwọ́',
    '📿' => 'Ilẹkẹ Adura',
    '💄' => 'Ikun-ete',
    '💍' => 'Dún',
    '💎' => 'Okuta Iyebiye',
    '🔇' => 'Gbohungbohun ti ko Sọrọ',
    '🔈' => 'Gbohungbohun ti Ohun rẹ wa Labẹ',
    '🔉' => 'Gbohungbohun ti Ohun rẹ wa Laarin',
    '🔊' => 'Gbohungbohun ti Ohun rẹ lọSoke',
    '📢' => 'Gbohùngbohùn',
    '📣' => 'ẹ̀rọ gbohùngbohùn ńlá',
    '📯' => 'gbohùngbohùn ifiranṣẹ',
    '🔔' => 'agago',
    '🔕' => 'agogo pẹlu idinku',
    '🎼' => 'akọsilẹ orin',
    '🎵' => 'ọ̀rọ̀ orin',
    '🎶' => 'nóòtì orin',
    '🎙' => 'maikurofóònù sítúdíò',
    '🎚' => 'ìpele yíyò̩',
    '🎛' => 'kókó ibìdárí',
    '🎤' => 'ẹ̀rọ gbohùngbohùn kékeré',
    '🎧' => 'ẹ̀rọ àdágbórinsétí',
    '📻' => 'rédíò',
    '🎷' => 'ipè',
    '🎺' => 'kakaaki',
    '🪊' => 'kàkàkí',
    '🪗' => 'akodíà',
    '🎸' => 'jìtá',
    '🎹' => 'duuru orin',
    '🎻' => 'faolini',
    '🪕' => 'bánjò',
    '🥁' => 'Ìlù',
    '🪘' => 'ilu gigun',
    '🪇' => 'marakasi',
    '🪈' => 'fèrè',
    '🪉' => 'háàpù',
    '📱' => 'fóònù alágbèéká',
    '📲' => 'fóònù alágbèéká pẹ̀lú ofà',
    '☎' => 'tẹlifóònù',
    '📞' => 'olùgbà fóònù',
    '📟' => 'ẹ̀rọ atanilólobó',
    '📠' => 'ẹ̀rọ fákìsì',
    '🔋' => 'bátìrì',
    '🪫' => 'batírì kékeré',
    '🔌' => 'pulọgi onina',
    '💻' => 'kọ̀ǹpútà àgbélétan',
    '🖥' => 'kọ̀npútà a-gbé-lórí-tábílì',
    '🖨' => 'pínríntà',
    '⌨' => 'kííbọọ̀dù',
    '🖱' => 'máòsì kọ̀npútà',
    '🖲' => 'òntè̩ afinimọ̀nà',
    '💽' => 'dísìkì kọ̀ǹpútà',
    '💾' => 'dísìkì fílọ̀pì',
    '💿' => 'àwo aká-ọ̀rọ̀ aláfojúrí',
    '📀' => 'dvd',
    '🧮' => 'abakuọ́sì',
    '🎥' => 'kamẹra fíìmù',
    '🎞' => 'àwọn férémù fíìmù',
    '📽' => 'è̩rọ agbéwòrán jáde',
    '🎬' => 'pataki alapade',
    '📺' => 'àmóhùnmáwòrán',
    '📷' => 'kámẹ́rà',
    '📸' => 'kámẹ́rà pẹlu filaṣi',
    '📹' => 'ayàwòrán fídíò',
    '📼' => 'awọn kaadi ododo iṣere',
    '🔍' => 'gilasi itọka-osi amohun tobi',
    '🔎' => 'gilasi itọka-ọtun amohun tobi',
    '🕯' => 'kándúùlù',
    '💡' => 'gólòbù iná',
    '🔦' => 'iná fílásì',
    '🏮' => 'atupa iwe pupa',
    '🪔' => 'àtùpà díya',
    '📔' => 'àfikọ̀wé pẹ̀lú ẹ̀yìn ọlọ́ọ̀ṣó',
    '📕' => 'ìwé tó padé',
    '📖' => 'iwe ṣi silẹ',
    '📗' => 'iwe alawọ ewe',
    '📘' => 'iwe alawọ bulu',
    '📙' => 'iwe alawọ ọsan',
    '📚' => 'àwọn ìwé',
    '📓' => 'àfikọ̀wé',
    '📒' => 'lé̩jà',
    '📃' => 'oju-iwe pẹlu lilọ',
    '📜' => 'gbéjáde',
    '📄' => 'oju-iwe wa loke',
    '📰' => 'ìwé ìròyìn',
    '🗞' => 'ìwé ìròyìn aláyípọ̀',
    '📑' => 'àmì ìwé àwọn táàbù',
    '🔖' => 'àmì ìwé',
    '🏷' => 'àkọ́lé',
    '🪙' => 'koínì',
    '💰' => 'apo owo',
    '🪎' => 'àpótí ìṣura',
    '💴' => 'owo yen',
    '💵' => 'owo dọla',
    '💶' => 'owo uro',
    '💷' => 'owo pọun',
    '💸' => 'owo pẹlu awọn iyẹ',
    '💳' => 'káàdì ìsọdowó',
    '🧾' => 'ìwé owó',
    '💹' => 'àtẹ n pọsi pẹlu yẹn',
    '✉' => 'àpò ìwé',
    '📧' => 'í-meèlì',
    '📨' => 'apo iwe ti o nbọ',
    '📩' => 'apo iwe pelu ọfa',
    '📤' => 'tire àpótí ìgbọ́rọ̀jáde',
    '📥' => 'tire àpótí àgbàwọ́lé',
    '📦' => 'ṣí àkójọpọ̀',
    '📫' => 'àpótíméèlì ti a tipa pẹlu asia nina soke',
    '📪' => 'àpótíméèlì ti a tipa pẹlu asia nina walẹ',
    '📬' => 'àpótíméèlì ti a ṣi pẹlu asia nina soke',
    '📭' => 'àpótíméèlì ti a ṣi pẹlu asia nina wale',
    '📮' => 'apoti ifigba iwe iranṣẹ',
    '🗳' => 'àpótí ìdìbò pẹ̀lú ìwé ìdìbò',
    '✏' => 'pẹ́nsùlù',
    '✒' => 'góngó dúdú',
    '🖋' => 'gègé orísun',
    '🖊' => 'gègé pẹlu rogodo',
    '🖌' => 'búró̩sì ìkùndà',
    '🖍' => 'kereyọ́nù',
    '📝' => 'mẹ́mò',
    '💼' => 'àpamọ́wọ́',
    '📁' => 'fódà fáìlì',
    '📂' => 'fódà fáìlì ti o ṣi',
    '🗂' => 'ohun èlò ìpínyà àtòjọ atọ́ka-ọ̀rọ̀ káàdì',
    '📅' => 'kàlẹ́ndà',
    '📆' => 'kàlẹ́ndà ti a ya',
    '🗒' => 'nóòtì páàdì alákápò̩',
    '🗓' => 'kàlẹ́ndà alákápọ̀',
    '📇' => 'káàdì àtòjọ atọ́kà-ọ̀rọ̀',
    '📈' => 'àtẹ n pọsi',
    '📉' => 'àtẹ n dinku',
    '📊' => 'pẹpẹ ìwe àwòrán àfihàn',
    '📋' => 'aka ọlọ́pọ̀n',
    '📌' => 'abẹ́rẹ́ohunyíyà',
    '📍' => 'abẹ́rẹ́ohunyíyà roboto',
    '📎' => 'àfimúwèépọ̀',
    '🖇' => 'àsopọ̀ ìfimúwèépọ̀',
    '📏' => 'rula gbọọrọ',
    '📐' => 'rula onigun mẹta',
    '✂' => 'sísọ́ọ̀sì',
    '🗃' => 'àpótí káàdì fún fáìlì',
    '🗄' => 'àpótí fáàlì',
    '🗑' => 'apẹ̀rẹ̀ ìdalè̩sí',
    '🔒' => 'ti tìí',
    '🔓' => 'ti síi',
    '🔏' => 'ti tìí pẹlu pẹni',
    '🔐' => 'ti tìí pẹlu kọkọrọ',
    '🔑' => 'kọ́kọ́rọ́',
    '🗝' => 'kó̩kọ́ró̩ àtijó̩',
    '🔨' => 'oòlù',
    '🪓' => 'àáké',
    '⛏' => 'sà',
    '⚒' => 'òòlù àti ìsà',
    '🛠' => 'òòlù àti irinṣẹ́ afagbára dè',
    '🗡' => 'dágà',
    '⚔' => 'idà alágbèélèbú',
    '💣' => 'Bọmbu',
    '🪃' => 'ipadawa',
    '🏹' => 'ọkọ ati ọfa',
    '🛡' => 'ohun èlò àbò',
    '🪚' => 'sọ́ọ̀ káfíntà',
    '🔧' => 'oolu',
    '🪛' => 'elo ìtú ìdè',
    '🔩' => 'nọti ati botu',
    '⚙' => 'gíà',
    '🗜' => 'gbámú',
    '⚖' => 'ìwọ̀ntúnwọ̀nsí síkélì',
    '🦯' => 'egba funfun',
    '🔗' => 'ìtọ́kasí',
    '⛓' => 'àwọn ṣe̩kẹ́ṣẹkẹ̀',
    '🪝' => 'ako',
    '🧰' => 'nńkan èlo',
    '🧲' => 'lílẹ̀ mọ́',
    '🪜' => 'àkàbà',
    '🪏' => 'ṣọ́bìrì',
    '⚗' => 'àlẹ́mbìk',
    '🧪' => 'tubu ayewo',
    '🧫' => 'ounje',
    '🧬' => 'dínà',
    '🔬' => 'maikirosikopu',
    '🔭' => 'tẹlisikopu',
    '📡' => 'eria satalaiti',
    '💉' => 'abẹrẹ',
    '🩸' => 'ita ẹ̀jẹ̀',
    '💊' => 'pili',
    '🩹' => 'bándeèjì',
    '🩼' => 'igi ifirin',
    '🩺' => 'sitesitosikoop]u',
    '🩻' => 'aworan ayewo',
    '🚪' => 'Ìlẹ̀kùn',
    '🛗' => 'ohun ìgbésókè',
    '🪞' => 'jígí',
    '🪟' => 'fèrèsé',
    '🛏' => 'ibùsùn',
    '🛋' => 'ìjókò àti àtùpà',
    '🪑' => 'àga',
    '🚽' => 'Ilé ìgbẹ́',
    '🪠' => 'ohun iti',
    '🚿' => 'Ìwẹ̀',
    '🛁' => 'Àgbá ìwẹ̀',
    '🪤' => 'pánpẹ́ ẹmọ́',
    '🪒' => 'ọ̀bẹ́',
    '🧴' => 'ìgò ìpára',
    '🧷' => 'àbẹ́rẹ́ ààbò',
    '🧹' => 'ìgbálẹ̀',
    '🧺' => 'apẹ̀rẹ̀',
    '🧻' => 'bẹ́bà kíkà',
    '🪣' => 'bọ́kẹ́ẹ̀tì',
    '🧼' => 'ọṣẹ',
    '🫧' => 'àwọn bọ́bù',
    '🪥' => 'búrọ̀ọ́ṣì ìfọnu',
    '🧽' => 'kàyìnkàyìn',
    '🧯' => 'ohun ìpaná',
    '🛒' => 'Àtẹ Iraja',
    '🚬' => 'siga',
    '⚰' => 'pósí',
    '🪦' => 'okutaori',
    '⚱' => 'igbá ìsìnkú',
    '🧿' => 'amuleti ti nasari',
    '🪬' => 'mámúsà',
    '🗿' => 'moai',
    '🪧' => 'ohun ìkéde',
    '🪪' => 'káàdì ìdánimoọ̀',
    '🏧' => 'Aami ATM',
    '🚮' => 'idoti ninu aami idọti',
    '🚰' => 'omi aṣeegbe kiri',
    '♿' => 'àmì kẹkẹ ẹni-ẹsẹ-ndun',
    '🚹' => 'iyara awọn ọkunrin',
    '🚺' => 'iyara awọn obinrin',
    '🚻' => 'iléìyàgbẹ́',
    '🚼' => 'àmì ọmọ',
    '🚾' => 'iléìyàgbẹ́ olomi',
    '🛂' => 'iṣakoso aworan ori',
    '🛃' => 'awọn aṣọbode',
    '🛄' => 'igba ẹru ẹni',
    '🛅' => 'fifi ẹru silẹ',
    '⚠' => 'ìkìlọ̀',
    '🚸' => 'awọn ọmọde n sọda',
    '⛔' => 'kosi iwọle',
    '🚫' => 'kosaye',
    '🚳' => 'kosi awọn kẹkẹ',
    '🚭' => 'kosi mimu siga',
    '🚯' => 'kosi idahun-silẹ',
    '🚱' => 'omi ti koṣeemu',
    '🚷' => 'kosi olufẹsẹrin',
    '📵' => 'kosi awọn foonu alagbeka',
    '🔞' => 'kosi eniyan labẹ ejidinlogun',
    '☢' => 'rédíòátífù',
    '☣' => 'ewu ajẹmọ́nìyàn',
    '⬆' => 'àmì òkè ìtó̩sọ́nà o̩lọ́fà',
    '↗' => 'àmì òkè ìtó̩sọ́nà o̩lọ́fà apá ọ̀tún',
    '➡' => 'àmì ìtó̩sọ́nà o̩lọ́fà apá ọ̀tún',
    '↘' => 'àmì ilẹ̀ ìtó̩sọ́nà o̩lọ́fà apá ọ̀tún',
    '⬇' => 'àmì ilẹ̀ ìtó̩sọ́nà o̩lọ́fà',
    '↙' => 'àmì ilẹ̀ ìtó̩sọ́nà o̩lọ́fà apá òsì',
    '⬅' => 'àmì ìtó̩sọ́nà o̩lọ́fà apá òsì',
    '↖' => 'àmì òkè ìtó̩sọ́nà o̩lọ́fà apá òsì',
    '↕' => 'ọfà tòkètilẹ̀',
    '↔' => 'àmì ìtó̩sọ́nà o̩lọ́fà tọ̀tún-tòsì',
    '↩' => 'àmì ìtó̩sọ́nà o̩lọ́fà apá ọ̀tún onígun',
    '↪' => 'àmì ìtó̩sọ́nà o̩lọ́fà apá òsì onígun',
    '⤴' => 'àmì ìtó̩sọ́nà o̩lọ́fà apá ọ̀tún onígun òkè',
    '⤵' => 'àmì ìtó̩sọ́nà o̩lọ́fà apá ọ̀tún onígun ìsàlẹ̀',
    '🔃' => 'awọn ọfa yiyi ọna ago',
    '🔄' => 'bọtini awọn ọfa yiyi lodi sọna ago',
    '🔙' => 'Ọfa ẸYIN',
    '🔚' => 'Ọfa IPARI',
    '🔛' => 'Ọfa LORI!',
    '🔜' => 'Ọfa LAIPẸ',
    '🔝' => 'Ọfa LOKE',
    '🛐' => 'ibi ijọsin',
    '⚛' => 'àmì átọ́mù',
    '🕉' => 'om',
    '✡' => 'ìràwọ̀ Dáfídì',
    '☸' => 'kẹ̀ké̩ è̩sìn dáámà',
    '☯' => 'yínì yángì',
    '✝' => 'àgbélèbú látíìnì',
    '☦' => 'àgbélèbú àtijó',
    '☪' => 'ìràwọ̀ àti òṣùpá tí kò tí yọ tán',
    '☮' => 'àmì àláàáfíà',
    '🕎' => 'menorah',
    '🔯' => 'irawọ totooto oni-mẹfa',
    '🪯' => 'kandá',
    '♈' => 'Aries',
    '♉' => 'Taurus',
    '♊' => 'Gemini',
    '♋' => 'Cancer',
    '♌' => 'Leo',
    '♍' => 'Virgo',
    '♎' => 'Libra',
    '♏' => 'Scorpius',
    '♐' => 'Sagittarius',
    '♑' => 'Capricorn',
    '♒' => 'Aquarius',
    '♓' => 'Pisces',
    '⛎' => 'Ophiuchus',
    '🔀' => 'yiyọ bọtini tiraki',
    '🔁' => 'atunṣe bọtini',
    '🔂' => 'atunṣe bọtini ẹlẹyọ',
    '▶' => 'bọ́tínì píílè',
    '⏩' => 'mu bọtini sare lọwaju',
    '⏭' => 'bọ́tìnì tírákì tó kàn',
    '⏯' => 'bó̩tìnìpíílè tàbí ìdúró',
    '◀' => 'Bọ́tínì ìdápadà',
    '⏪' => 'mu bọtini sare rẹhin',
    '⏮' => 'Tíráàkì tó ké̩yìn',
    '🔼' => 'bọtini oke',
    '⏫' => 'bọtini imusoke kia',
    '🔽' => 'bọtini isalẹ',
    '⏬' => 'bọtini imussalẹ kia',
    '⏸' => 'bọ́tínì ìdánudúró fúngbà díẹ̀',
    '⏹' => 'bọ́tínì ìdànudúró',
    '⏺' => 'bọ́tínì agbohùnsílẹ̀',
    '⏏' => 'bó̩tínì àtẹ̀jáde',
    '🎦' => 'sinima',
    '🔅' => 'bọtini baibai',
    '🔆' => 'bọtini titan',
    '📶' => 'àwọn òpó antẹna',
    '🛜' => 'aini okun ina',
    '📳' => 'moodu gbigbọn',
    '📴' => 'pipa ẹ̀rọ ìbánisọ̀rọ̀ alágbèéká',
    '♀' => 'àmí obìnrin',
    '♂' => 'àmì ọkùnrin',
    '⚧' => 'ami ìyíeda',
    '✖' => 'ìsọdipúpò̩ tó nípọn x',
    '➕' => 'aami àròpọ̀ nla',
    '➖' => 'aami ayọkuro nla',
    '➗' => 'aami gige nla',
    '🟰' => 'ami jíje nlá',
    '♾' => 'ailopin',
    '‼' => 'àmì ìyanu oníbejì',
    '⁉' => 'àmì ìyanu oníbéèrè',
    '❓' => 'àmì ìbéèrè ìdàkodò',
    '❔' => 'aami ibeere funfun',
    '❕' => 'aami iyalẹnu funfun',
    '❗' => 'àmì ìyàlẹ́nu ìdàkodò',
    '〰' => 'dáàṣì onísàn omi',
    '💱' => 'paṣiparọ owo',
    '💲' => 'aami dọla nla',
    '⚕' => 'àmì egbògiogùn',
    '♻' => 'àmì àtúnrọ',
    '⚜' => 'fleur-de-lis',
    '🔱' => 'aami apẹẹrẹ trident',
    '📛' => 'orúkọ àmì',
    '🔰' => 'Àmì Japanisi fun olubẹre',
    '⭕' => 'roboto wiwo nla',
    '✅' => 'maaki iṣayewo funfun nla',
    '☑' => 'àyẹ̀wò àpótí ìdìbò',
    '✔' => 'fínnífínní',
    '❌' => 'aami idabu',
    '❎' => 'bọtini aami idabu',
    '➰' => 'iho wọlọwọlo',
    '➿' => 'iho wọlọwọlo meji',
    '〽' => 'ara máàkì ti a ti tọwó̩bọ̀',
    '✳' => 'àmì àkíyèsí onígbá-mé̩jọ',
    '✴' => 'àmì àkíyèsí onígun-mé̩jọ',
    '❇' => 'dán',
    '™' => 'àmì ìdánimọ̀ iléeṣẹ́',
    '🫟' => 'fọ́nká',
    '🔠' => 'ṣafikun latini ọ̀rọ̀ gbólóhùn ńlá',
    '🔡' => 'ṣafikun latini ọ̀rọ̀ gbólóhùn kékeré',
    '🔢' => 'ṣafikun awọn nọnba',
    '🔣' => 'ṣafikun awọn àmì',
    '🔤' => 'ṣafikun awọn lẹta latini',
    '🅰' => 'Bọ́tìnì A (irúfé̩ ẹ̀jẹ̀)',
    '🆎' => 'Bọtini AB (irufẹ ẹjẹ)',
    '🅱' => 'Bọ́tìnì B(irúfé̩ ẹ̀jẹ̀)',
    '🆑' => 'Bọtini CL',
    '🆒' => 'Bọtini KUULU',
    '🆓' => 'Bọtini ỌFẸ',
    'ℹ' => 'àlàyé',
    '🆔' => 'Bọtini ID',
    'Ⓜ' => 'M òdo',
    '🆕' => 'Bọtini TUNTUN',
    '🆖' => 'Bọtini NG',
    '🅾' => 'Bọ́tìnì O (irúfé̩ èjè)',
    '🆗' => 'Bọtini DARA',
    '🅿' => 'bó̩tìnì P',
    '🆘' => 'Bọtini SOS',
    '🆙' => 'Oke! Bọ̀tìnì',
    '🆚' => 'Bọtini VS',
    '🈁' => 'Bọtini Japanisi "nibi"',
    '🈂' => 'Bọ́tìnì Japanísì "ìdíyelé fún owó ọ̀yà"',
    '🈷' => 'Bó̩tìnì Japanisi "owó ìdíyelé oṣoòṣù"',
    '🈶' => 'Bọtini Japanisi "kosi lọfẹ"',
    '🈯' => 'Bọtini Japanisi "nipamọ"',
    '🉐' => 'Bọtini Japanisi "idunadura"',
    '🈹' => 'Bọtini Japanisi "ẹdinwo"',
    '🈚' => 'Bọtini Japanisi "lọ́fẹ̀é̩"',
    '🈲' => 'Bọtini Japanisi "ṣediwọ"',
    '🉑' => 'Bọtini "itẹwọgba" Japanisi',
    '🈸' => 'Bọtini "ohun elo" Japanisi',
    '🈴' => 'Bọtini "gbendeke iyege" Japanisi',
    '🈳' => 'Bọtini "aaye" Japanisi',
    '㊗' => 'Bó̩tìnì "kú oríre" Japanisi',
    '㊙' => 'Bó̩tìnì "àṣírí"Japanisi',
    '🈺' => 'Bọtini "ṣi fun okowo" Japanisi',
    '🈵' => 'Bọtini "kosi aaye" Japanisi',
    '🔴' => 'Rogodo Aláwọ̀ pupa',
    '🟠' => 'osan saku',
    '🟡' => 'saku yelo',
    '🟢' => 'saku girini',
    '🔵' => 'Rogodo Búlúù',
    '🟣' => 'pọ́pù rogodo',
    '🟤' => 'rogodo aláwọ igi',
    '⚫' => 'Rogodo Aláwọ̀ dúdú',
    '⚪' => 'Rogodo Funfun',
    '🟥' => 'síkúwẹ́ẹ̀ pupa',
    '🟧' => 'síkúwẹ́ẹ̀ orénjì',
    '🟨' => 'síkúwẹ́ẹ̀ yẹ́lọ̀',
    '🟩' => 'síkúwẹ́ẹ̀ aláwọ̀ ewé',
    '🟦' => 'síkúwẹ́ẹ̀ búlúù',
    '🟪' => 'síkúwẹ́ẹ̀ pọ́pù',
    '🟫' => 'síkúwẹ́ẹ̀ aláwọ̀ igi',
    '⬛' => 'onigunmẹrin dudu nla',
    '⬜' => 'onigunmẹrin funfun nla',
    '◼' => 'ilà onígun mé̩rin aláàárín dúdú',
    '◻' => 'ilà onígun mé̩rin aláàárín funfun',
    '◾' => 'onigunmẹrin idaji-kekere dudu',
    '◽' => 'onigunmẹrin idaji-kekere funfun',
    '▪' => 'kékeré onígun mẹ́rin dúdú',
    '▫' => 'kékeré onígun mẹ́rin funfun',
    '🔶' => 'diamọndi alawọ oronbo nla',
    '🔷' => 'diamọndi alawọ bulu nla',
    '🔸' => 'diamọndi alawọ oronbo kekere',
    '🔹' => 'diamọndi alawọ bulu kekere',
    '🔺' => 'Alawọ Pupa Onigun Mẹta Toka Soke',
    '🔻' => 'Alawọ Pupa Onigun Mẹta Toka Sisalẹ',
    '💠' => 'Diamọndi Pẹlu Dọti Kan',
    '🔘' => 'Bọ́tìnnì Rédíò',
    '🔳' => 'Bọtini Onigunmẹrin Funfun',
    '🔲' => 'Bọtini Onigunmẹrin Dudu',
    '🏁' => 'asia péńpé onílà',
    '🚩' => 'asia onigun mẹta',
    '🎌' => 'Awọn Asia Onidabu',
    '🏴' => 'asia dudu',
    '🏳' => 'àsíá funfun',
];
