<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'poljubac: odrasla osoba, odrasla osoba, svijetla boja kože i svijetlo maslinasta boja kože',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'poljubac: odrasla osoba, odrasla osoba, svijetla boja kože i maslinasta boja kože',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'poljubac: odrasla osoba, odrasla osoba, svijetla boja kože i smeđa boja kože',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'poljubac: odrasla osoba, odrasla osoba, svijetla boja kože i tamno smeđa boja kože',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'poljubac: odrasla osoba, odrasla osoba, svijetlo maslinasta boja kože i svijetla boja kože',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'poljubac: odrasla osoba, odrasla osoba, svijetlo maslinasta boja kože i maslinasta boja kože',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'poljubac: odrasla osoba, odrasla osoba, svijetlo maslinasta boja kože i smeđa boja kože',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'poljubac: odrasla osoba, odrasla osoba, svijetlo maslinasta boja kože i tamno smeđa boja kože',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'poljubac: odrasla osoba, odrasla osoba, maslinasta boja kože i svijetla boja kože',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'poljubac: odrasla osoba, odrasla osoba, maslinasta boja kože i svijetlo maslinasta boja kože',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'poljubac: odrasla osoba, odrasla osoba, maslinasta boja kože i smeđa boja kože',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'poljubac: odrasla osoba, odrasla osoba, maslinasta boja kože i tamno smeđa boja kože',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'poljubac: odrasla osoba, odrasla osoba, smeđa boja kože i svijetla boja kože',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'poljubac: odrasla osoba, odrasla osoba, smeđa boja kože i svijetlo maslinasta boja kože',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'poljubac: odrasla osoba, odrasla osoba, smeđa boja kože i maslinasta boja kože',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'poljubac: odrasla osoba, odrasla osoba, smeđa boja kože i tamno smeđa boja kože',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'poljubac: odrasla osoba, odrasla osoba, tamno smeđa boja kože i svijetla boja kože',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'poljubac: odrasla osoba, odrasla osoba, tamno smeđa boja kože i svijetlo maslinasta boja kože',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'poljubac: odrasla osoba, odrasla osoba, tamno smeđa boja kože i maslinasta boja kože',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'poljubac: odrasla osoba, odrasla osoba, tamno smeđa boja kože i smeđa boja kože',
    '👨🏻‍❤‍💋‍👨🏻' => 'poljubac: muškarac, muškarac i svijetla boja kože',
    '👨🏻‍❤‍💋‍👨🏼' => 'poljubac: muškarac, muškarac, svijetla boja kože i svijetlo maslinasta boja kože',
    '👨🏻‍❤‍💋‍👨🏽' => 'poljubac: muškarac, muškarac, svijetla boja kože i maslinasta boja kože',
    '👨🏻‍❤‍💋‍👨🏾' => 'poljubac: muškarac, muškarac, svijetla boja kože i smeđa boja kože',
    '👨🏻‍❤‍💋‍👨🏿' => 'poljubac: muškarac, muškarac, svijetla boja kože i tamno smeđa boja kože',
    '👨🏼‍❤‍💋‍👨🏻' => 'poljubac: muškarac, muškarac, svijetlo maslinasta boja kože i svijetla boja kože',
    '👨🏼‍❤‍💋‍👨🏼' => 'poljubac: muškarac, muškarac i svijetlo maslinasta boja kože',
    '👨🏼‍❤‍💋‍👨🏽' => 'poljubac: muškarac, muškarac, svijetlo maslinasta boja kože i maslinasta boja kože',
    '👨🏼‍❤‍💋‍👨🏾' => 'poljubac: muškarac, muškarac, svijetlo maslinasta boja kože i smeđa boja kože',
    '👨🏼‍❤‍💋‍👨🏿' => 'poljubac: muškarac, muškarac, svijetlo maslinasta boja kože i tamno smeđa boja kože',
    '👨🏽‍❤‍💋‍👨🏻' => 'poljubac: muškarac, muškarac, maslinasta boja kože i svijetla boja kože',
    '👨🏽‍❤‍💋‍👨🏼' => 'poljubac: muškarac, muškarac, maslinasta boja kože i svijetlo maslinasta boja kože',
    '👨🏽‍❤‍💋‍👨🏽' => 'poljubac: muškarac, muškarac i maslinasta boja kože',
    '👨🏽‍❤‍💋‍👨🏾' => 'poljubac: muškarac, muškarac, maslinasta boja kože i smeđa boja kože',
    '👨🏽‍❤‍💋‍👨🏿' => 'poljubac: muškarac, muškarac, maslinasta boja kože i tamno smeđa boja kože',
    '👨🏾‍❤‍💋‍👨🏻' => 'poljubac: muškarac, muškarac, smeđa boja kože i svijetla boja kože',
    '👨🏾‍❤‍💋‍👨🏼' => 'poljubac: muškarac, muškarac, smeđa boja kože i svijetlo maslinasta boja kože',
    '👨🏾‍❤‍💋‍👨🏽' => 'poljubac: muškarac, muškarac, smeđa boja kože i maslinasta boja kože',
    '👨🏾‍❤‍💋‍👨🏾' => 'poljubac: muškarac, muškarac i smeđa boja kože',
    '👨🏾‍❤‍💋‍👨🏿' => 'poljubac: muškarac, muškarac, smeđa boja kože i tamno smeđa boja kože',
    '👨🏿‍❤‍💋‍👨🏻' => 'poljubac: muškarac, muškarac, tamno smeđa boja kože i svijetla boja kože',
    '👨🏿‍❤‍💋‍👨🏼' => 'poljubac: muškarac, muškarac, tamno smeđa boja kože i svijetlo maslinasta boja kože',
    '👨🏿‍❤‍💋‍👨🏽' => 'poljubac: muškarac, muškarac, tamno smeđa boja kože i maslinasta boja kože',
    '👨🏿‍❤‍💋‍👨🏾' => 'poljubac: muškarac, muškarac, tamno smeđa boja kože i smeđa boja kože',
    '👨🏿‍❤‍💋‍👨🏿' => 'poljubac: muškarac, muškarac i tamno smeđa boja kože',
    '👩🏻‍❤‍💋‍👨🏻' => 'poljubac: žena, muškarac i svijetla boja kože',
    '👩🏻‍❤‍💋‍👨🏼' => 'poljubac: žena, muškarac, svijetla boja kože i svijetlo maslinasta boja kože',
    '👩🏻‍❤‍💋‍👨🏽' => 'poljubac: žena, muškarac, svijetla boja kože i maslinasta boja kože',
    '👩🏻‍❤‍💋‍👨🏾' => 'poljubac: žena, muškarac, svijetla boja kože i smeđa boja kože',
    '👩🏻‍❤‍💋‍👨🏿' => 'poljubac: žena, muškarac, svijetla boja kože i tamno smeđa boja kože',
    '👩🏼‍❤‍💋‍👨🏻' => 'poljubac: žena, muškarac, svijetlo maslinasta boja kože i svijetla boja kože',
    '👩🏼‍❤‍💋‍👨🏼' => 'poljubac: žena, muškarac i svijetlo maslinasta boja kože',
    '👩🏼‍❤‍💋‍👨🏽' => 'poljubac: žena, muškarac, svijetlo maslinasta boja kože i maslinasta boja kože',
    '👩🏼‍❤‍💋‍👨🏾' => 'poljubac: žena, muškarac, svijetlo maslinasta boja kože i smeđa boja kože',
    '👩🏼‍❤‍💋‍👨🏿' => 'poljubac: žena, muškarac, svijetlo maslinasta boja kože i tamno smeđa boja kože',
    '👩🏽‍❤‍💋‍👨🏻' => 'poljubac: žena, muškarac, maslinasta boja kože i svijetla boja kože',
    '👩🏽‍❤‍💋‍👨🏼' => 'poljubac: žena, muškarac, maslinasta boja kože i svijetlo maslinasta boja kože',
    '👩🏽‍❤‍💋‍👨🏽' => 'poljubac: žena, muškarac i maslinasta boja kože',
    '👩🏽‍❤‍💋‍👨🏾' => 'poljubac: žena, muškarac, maslinasta boja kože i smeđa boja kože',
    '👩🏽‍❤‍💋‍👨🏿' => 'poljubac: žena, muškarac, maslinasta boja kože i tamno smeđa boja kože',
    '👩🏾‍❤‍💋‍👨🏻' => 'poljubac: žena, muškarac, smeđa boja kože i svijetla boja kože',
    '👩🏾‍❤‍💋‍👨🏼' => 'poljubac: žena, muškarac, smeđa boja kože i svijetlo maslinasta boja kože',
    '👩🏾‍❤‍💋‍👨🏽' => 'poljubac: žena, muškarac, smeđa boja kože i maslinasta boja kože',
    '👩🏾‍❤‍💋‍👨🏾' => 'poljubac: žena, muškarac i smeđa boja kože',
    '👩🏾‍❤‍💋‍👨🏿' => 'poljubac: žena, muškarac, smeđa boja kože i tamno smeđa boja kože',
    '👩🏿‍❤‍💋‍👨🏻' => 'poljubac: žena, muškarac, tamno smeđa boja kože i svijetla boja kože',
    '👩🏿‍❤‍💋‍👨🏼' => 'poljubac: žena, muškarac, tamno smeđa boja kože i svijetlo maslinasta boja kože',
    '👩🏿‍❤‍💋‍👨🏽' => 'poljubac: žena, muškarac, tamno smeđa boja kože i maslinasta boja kože',
    '👩🏿‍❤‍💋‍👨🏾' => 'poljubac: žena, muškarac, tamno smeđa boja kože i smeđa boja kože',
    '👩🏿‍❤‍💋‍👨🏿' => 'poljubac: žena, muškarac i tamno smeđa boja kože',
    '👩🏻‍❤‍💋‍👩🏻' => 'poljubac: žena, žena i svijetla boja kože',
    '👩🏻‍❤‍💋‍👩🏼' => 'poljubac: žena, žena, svijetla boja kože i svijetlo maslinasta boja kože',
    '👩🏻‍❤‍💋‍👩🏽' => 'poljubac: žena, žena, svijetla boja kože i maslinasta boja kože',
    '👩🏻‍❤‍💋‍👩🏾' => 'poljubac: žena, žena, svijetla boja kože i smeđa boja kože',
    '👩🏻‍❤‍💋‍👩🏿' => 'poljubac: žena, žena, svijetla boja kože i tamno smeđa boja kože',
    '👩🏼‍❤‍💋‍👩🏻' => 'poljubac: žena, žena, svijetlo maslinasta boja kože i svijetla boja kože',
    '👩🏼‍❤‍💋‍👩🏼' => 'poljubac: žena, žena i svijetlo maslinasta boja kože',
    '👩🏼‍❤‍💋‍👩🏽' => 'poljubac: žena, žena, svijetlo maslinasta boja kože i maslinasta boja kože',
    '👩🏼‍❤‍💋‍👩🏾' => 'poljubac: žena, žena, svijetlo maslinasta boja kože i smeđa boja kože',
    '👩🏼‍❤‍💋‍👩🏿' => 'poljubac: žena, žena, svijetlo maslinasta boja kože i tamno smeđa boja kože',
    '👩🏽‍❤‍💋‍👩🏻' => 'poljubac: žena, žena, maslinasta boja kože i svijetla boja kože',
    '👩🏽‍❤‍💋‍👩🏼' => 'poljubac: žena, žena, maslinasta boja kože i svijetlo maslinasta boja kože',
    '👩🏽‍❤‍💋‍👩🏽' => 'poljubac: žena, žena i maslinasta boja kože',
    '👩🏽‍❤‍💋‍👩🏾' => 'poljubac: žena, žena, maslinasta boja kože i smeđa boja kože',
    '👩🏽‍❤‍💋‍👩🏿' => 'poljubac: žena, žena, maslinasta boja kože i tamno smeđa boja kože',
    '👩🏾‍❤‍💋‍👩🏻' => 'poljubac: žena, žena, smeđa boja kože i svijetla boja kože',
    '👩🏾‍❤‍💋‍👩🏼' => 'poljubac: žena, žena, smeđa boja kože i svijetlo maslinasta boja kože',
    '👩🏾‍❤‍💋‍👩🏽' => 'poljubac: žena, žena, smeđa boja kože i maslinasta boja kože',
    '👩🏾‍❤‍💋‍👩🏾' => 'poljubac: žena, žena i smeđa boja kože',
    '👩🏾‍❤‍💋‍👩🏿' => 'poljubac: žena, žena, smeđa boja kože i tamno smeđa boja kože',
    '👩🏿‍❤‍💋‍👩🏻' => 'poljubac: žena, žena, tamno smeđa boja kože i svijetla boja kože',
    '👩🏿‍❤‍💋‍👩🏼' => 'poljubac: žena, žena, tamno smeđa boja kože i svijetlo maslinasta boja kože',
    '👩🏿‍❤‍💋‍👩🏽' => 'poljubac: žena, žena, tamno smeđa boja kože i maslinasta boja kože',
    '👩🏿‍❤‍💋‍👩🏾' => 'poljubac: žena, žena, tamno smeđa boja kože i smeđa boja kože',
    '👩🏿‍❤‍💋‍👩🏿' => 'poljubac: žena, žena i tamno smeđa boja kože',
    '🧑🏻‍🫯‍🧑🏼' => 'osobe se hrvaju: svijetla boja kože i svijetlo maslinasta boja kože',
    '🧑🏻‍🫯‍🧑🏽' => 'osobe se hrvaju: svijetla boja kože i maslinasta boja kože',
    '🧑🏻‍🫯‍🧑🏾' => 'osobe se hrvaju: svijetla boja kože i smeđa boja kože',
    '🧑🏻‍🫯‍🧑🏿' => 'osobe se hrvaju: svijetla boja kože i tamno smeđa boja kože',
    '🧑🏼‍🫯‍🧑🏻' => 'osobe se hrvaju: svijetlo maslinasta boja kože i svijetla boja kože',
    '🧑🏼‍🫯‍🧑🏽' => 'osobe se hrvaju: svijetlo maslinasta boja kože i maslinasta boja kože',
    '🧑🏼‍🫯‍🧑🏾' => 'osobe se hrvaju: svijetlo maslinasta boja kože i smeđa boja kože',
    '🧑🏼‍🫯‍🧑🏿' => 'osobe se hrvaju: svijetlo maslinasta boja kože i tamno smeđa boja kože',
    '🧑🏽‍🫯‍🧑🏻' => 'osobe se hrvaju: maslinasta boja kože i svijetla boja kože',
    '🧑🏽‍🫯‍🧑🏼' => 'osobe se hrvaju: maslinasta boja kože i svijetlo maslinasta boja kože',
    '🧑🏽‍🫯‍🧑🏾' => 'osobe se hrvaju: maslinasta boja kože i smeđa boja kože',
    '🧑🏽‍🫯‍🧑🏿' => 'osobe se hrvaju: maslinasta boja kože i tamno smeđa boja kože',
    '🧑🏾‍🫯‍🧑🏻' => 'osobe se hrvaju: smeđa boja kože i svijetla boja kože',
    '🧑🏾‍🫯‍🧑🏼' => 'osobe se hrvaju: smeđa boja kože i svijetlo maslinasta boja kože',
    '🧑🏾‍🫯‍🧑🏽' => 'osobe se hrvaju: smeđa boja kože i maslinasta boja kože',
    '🧑🏾‍🫯‍🧑🏿' => 'osobe se hrvaju: smeđa boja kože i tamno smeđa boja kože',
    '🧑🏿‍🫯‍🧑🏻' => 'osobe se hrvaju: tamno smeđa boja kože i svijetla boja kože',
    '🧑🏿‍🫯‍🧑🏼' => 'osobe se hrvaju: tamno smeđa boja kože i svijetlo maslinasta boja kože',
    '🧑🏿‍🫯‍🧑🏽' => 'osobe se hrvaju: tamno smeđa boja kože i maslinasta boja kože',
    '🧑🏿‍🫯‍🧑🏾' => 'osobe se hrvaju: tamno smeđa boja kože i smeđa boja kože',
    '🧑🏻‍❤‍🧑🏼' => 'par sa srcem: odrasla osoba, odrasla osoba, svijetla boja kože i svijetlo maslinasta boja kože',
    '🧑🏻‍❤‍🧑🏽' => 'par sa srcem: odrasla osoba, odrasla osoba, svijetla boja kože i maslinasta boja kože',
    '🧑🏻‍❤‍🧑🏾' => 'par sa srcem: odrasla osoba, odrasla osoba, svijetla boja kože i smeđa boja kože',
    '🧑🏻‍❤‍🧑🏿' => 'par sa srcem: odrasla osoba, odrasla osoba, svijetla boja kože i tamno smeđa boja kože',
    '🧑🏼‍❤‍🧑🏻' => 'par sa srcem: odrasla osoba, odrasla osoba, svijetlo maslinasta boja kože i svijetla boja kože',
    '🧑🏼‍❤‍🧑🏽' => 'par sa srcem: odrasla osoba, odrasla osoba, svijetlo maslinasta boja kože i maslinasta boja kože',
    '🧑🏼‍❤‍🧑🏾' => 'par sa srcem: odrasla osoba, odrasla osoba, svijetlo maslinasta boja kože i smeđa boja kože',
    '🧑🏼‍❤‍🧑🏿' => 'par sa srcem: odrasla osoba, odrasla osoba, svijetlo maslinasta boja kože i tamno smeđa boja kože',
    '🧑🏽‍❤‍🧑🏻' => 'par sa srcem: odrasla osoba, odrasla osoba, maslinasta boja kože i svijetla boja kože',
    '🧑🏽‍❤‍🧑🏼' => 'par sa srcem: odrasla osoba, odrasla osoba, maslinasta boja kože i svijetlo maslinasta boja kože',
    '🧑🏽‍❤‍🧑🏾' => 'par sa srcem: odrasla osoba, odrasla osoba, maslinasta boja kože i smeđa boja kože',
    '🧑🏽‍❤‍🧑🏿' => 'par sa srcem: odrasla osoba, odrasla osoba, maslinasta boja kože i tamno smeđa boja kože',
    '🧑🏾‍❤‍🧑🏻' => 'par sa srcem: odrasla osoba, odrasla osoba, smeđa boja kože i svijetla boja kože',
    '🧑🏾‍❤‍🧑🏼' => 'par sa srcem: odrasla osoba, odrasla osoba, smeđa boja kože i svijetlo maslinasta boja kože',
    '🧑🏾‍❤‍🧑🏽' => 'par sa srcem: odrasla osoba, odrasla osoba, smeđa boja kože i maslinasta boja kože',
    '🧑🏾‍❤‍🧑🏿' => 'par sa srcem: odrasla osoba, odrasla osoba, smeđa boja kože i tamno smeđa boja kože',
    '🧑🏿‍❤‍🧑🏻' => 'par sa srcem: odrasla osoba, odrasla osoba, tamno smeđa boja kože i svijetla boja kože',
    '🧑🏿‍❤‍🧑🏼' => 'par sa srcem: odrasla osoba, odrasla osoba, tamno smeđa boja kože i svijetlo maslinasta boja kože',
    '🧑🏿‍❤‍🧑🏽' => 'par sa srcem: odrasla osoba, odrasla osoba, tamno smeđa boja kože i maslinasta boja kože',
    '🧑🏿‍❤‍🧑🏾' => 'par sa srcem: odrasla osoba, odrasla osoba, tamno smeđa boja kože i smeđa boja kože',
    '🧑🏻‍🐰‍🧑🏼' => 'osobe sa zečjim ušima: svijetla boja kože i svijetlo maslinasta boja kože',
    '🧑🏻‍🐰‍🧑🏽' => 'osobe sa zečjim ušima: svijetla boja kože i maslinasta boja kože',
    '🧑🏻‍🐰‍🧑🏾' => 'osobe sa zečjim ušima: svijetla boja kože i smeđa boja kože',
    '🧑🏻‍🐰‍🧑🏿' => 'osobe sa zečjim ušima: svijetla boja kože i tamno smeđa boja kože',
    '🧑🏼‍🐰‍🧑🏻' => 'osobe sa zečjim ušima: svijetlo maslinasta boja kože i svijetla boja kože',
    '🧑🏼‍🐰‍🧑🏽' => 'osobe sa zečjim ušima: svijetlo maslinasta boja kože i maslinasta boja kože',
    '🧑🏼‍🐰‍🧑🏾' => 'osobe sa zečjim ušima: svijetlo maslinasta boja kože i smeđa boja kože',
    '🧑🏼‍🐰‍🧑🏿' => 'osobe sa zečjim ušima: svijetlo maslinasta boja kože i tamno smeđa boja kože',
    '🧑🏽‍🐰‍🧑🏻' => 'osobe sa zečjim ušima: maslinasta boja kože i svijetla boja kože',
    '🧑🏽‍🐰‍🧑🏼' => 'osobe sa zečjim ušima: maslinasta boja kože i svijetlo maslinasta boja kože',
    '🧑🏽‍🐰‍🧑🏾' => 'osobe sa zečjim ušima: maslinasta boja kože i smeđa boja kože',
    '🧑🏽‍🐰‍🧑🏿' => 'osobe sa zečjim ušima: maslinasta boja kože i tamno smeđa boja kože',
    '🧑🏾‍🐰‍🧑🏻' => 'osobe sa zečjim ušima: smeđa boja kože i svijetla boja kože',
    '🧑🏾‍🐰‍🧑🏼' => 'osobe sa zečjim ušima: smeđa boja kože i svijetlo maslinasta boja kože',
    '🧑🏾‍🐰‍🧑🏽' => 'osobe sa zečjim ušima: smeđa boja kože i maslinasta boja kože',
    '🧑🏾‍🐰‍🧑🏿' => 'osobe sa zečjim ušima: smeđa boja kože i tamno smeđa boja kože',
    '🧑🏿‍🐰‍🧑🏻' => 'osobe sa zečjim ušima: tamno smeđa boja kože i svijetla boja kože',
    '🧑🏿‍🐰‍🧑🏼' => 'osobe sa zečjim ušima: tamno smeđa boja kože i svijetlo maslinasta boja kože',
    '🧑🏿‍🐰‍🧑🏽' => 'osobe sa zečjim ušima: tamno smeđa boja kože i maslinasta boja kože',
    '🧑🏿‍🐰‍🧑🏾' => 'osobe sa zečjim ušima: tamno smeđa boja kože i smeđa boja kože',
    '👨🏻‍🫯‍👨🏼' => 'muškarci se hrvaju: svijetla boja kože i svijetlo maslinasta boja kože',
    '👨🏻‍🫯‍👨🏽' => 'muškarci se hrvaju: svijetla boja kože i maslinasta boja kože',
    '👨🏻‍🫯‍👨🏾' => 'muškarci se hrvaju: svijetla boja kože i smeđa boja kože',
    '👨🏻‍🫯‍👨🏿' => 'muškarci se hrvaju: svijetla boja kože i tamno smeđa boja kože',
    '👨🏼‍🫯‍👨🏻' => 'muškarci se hrvaju: svijetlo maslinasta boja kože i svijetla boja kože',
    '👨🏼‍🫯‍👨🏽' => 'muškarci se hrvaju: svijetlo maslinasta boja kože i maslinasta boja kože',
    '👨🏼‍🫯‍👨🏾' => 'muškarci se hrvaju: svijetlo maslinasta boja kože i smeđa boja kože',
    '👨🏼‍🫯‍👨🏿' => 'muškarci se hrvaju: svijetlo maslinasta boja kože i tamno smeđa boja kože',
    '👨🏽‍🫯‍👨🏻' => 'muškarci se hrvaju: maslinasta boja kože i svijetla boja kože',
    '👨🏽‍🫯‍👨🏼' => 'muškarci se hrvaju: maslinasta boja kože i svijetlo maslinasta boja kože',
    '👨🏽‍🫯‍👨🏾' => 'muškarci se hrvaju: maslinasta boja kože i smeđa boja kože',
    '👨🏽‍🫯‍👨🏿' => 'muškarci se hrvaju: maslinasta boja kože i tamno smeđa boja kože',
    '👨🏾‍🫯‍👨🏻' => 'muškarci se hrvaju: smeđa boja kože i svijetla boja kože',
    '👨🏾‍🫯‍👨🏼' => 'muškarci se hrvaju: smeđa boja kože i svijetlo maslinasta boja kože',
    '👨🏾‍🫯‍👨🏽' => 'muškarci se hrvaju: smeđa boja kože i maslinasta boja kože',
    '👨🏾‍🫯‍👨🏿' => 'muškarci se hrvaju: smeđa boja kože i tamno smeđa boja kože',
    '👨🏿‍🫯‍👨🏻' => 'muškarci se hrvaju: tamno smeđa boja kože i svijetla boja kože',
    '👨🏿‍🫯‍👨🏼' => 'muškarci se hrvaju: tamno smeđa boja kože i svijetlo maslinasta boja kože',
    '👨🏿‍🫯‍👨🏽' => 'muškarci se hrvaju: tamno smeđa boja kože i maslinasta boja kože',
    '👨🏿‍🫯‍👨🏾' => 'muškarci se hrvaju: tamno smeđa boja kože i smeđa boja kože',
    '👨🏻‍❤‍👨🏻' => 'par sa srcem: muškarac, muškarac i svijetla boja kože',
    '👨🏻‍❤‍👨🏼' => 'par sa srcem: muškarac, muškarac, svijetla boja kože i svijetlo maslinasta boja kože',
    '👨🏻‍❤‍👨🏽' => 'par sa srcem: muškarac, muškarac, svijetla boja kože i maslinasta boja kože',
    '👨🏻‍❤‍👨🏾' => 'par sa srcem: muškarac, muškarac, svijetla boja kože i smeđa boja kože',
    '👨🏻‍❤‍👨🏿' => 'par sa srcem: muškarac, muškarac, svijetla boja kože i tamno smeđa boja kože',
    '👨🏼‍❤‍👨🏻' => 'par sa srcem: muškarac, muškarac, svijetlo maslinasta boja kože i svijetla boja kože',
    '👨🏼‍❤‍👨🏼' => 'par sa srcem: muškarac, muškarac i svijetlo maslinasta boja kože',
    '👨🏼‍❤‍👨🏽' => 'par sa srcem: muškarac, muškarac, svijetlo maslinasta boja kože i maslinasta boja kože',
    '👨🏼‍❤‍👨🏾' => 'par sa srcem: muškarac, muškarac, svijetlo maslinasta boja kože i smeđa boja kože',
    '👨🏼‍❤‍👨🏿' => 'par sa srcem: muškarac, muškarac, svijetlo maslinasta boja kože i tamno smeđa boja kože',
    '👨🏽‍❤‍👨🏻' => 'par sa srcem: muškarac, muškarac, maslinasta boja kože i svijetla boja kože',
    '👨🏽‍❤‍👨🏼' => 'par sa srcem: muškarac, muškarac, maslinasta boja kože i svijetlo maslinasta boja kože',
    '👨🏽‍❤‍👨🏽' => 'par sa srcem: muškarac, muškarac i maslinasta boja kože',
    '👨🏽‍❤‍👨🏾' => 'par sa srcem: muškarac, muškarac, maslinasta boja kože i smeđa boja kože',
    '👨🏽‍❤‍👨🏿' => 'par sa srcem: muškarac, muškarac, maslinasta boja kože i tamno smeđa boja kože',
    '👨🏾‍❤‍👨🏻' => 'par sa srcem: muškarac, muškarac, smeđa boja kože i svijetla boja kože',
    '👨🏾‍❤‍👨🏼' => 'par sa srcem: muškarac, muškarac, smeđa boja kože i svijetlo maslinasta boja kože',
    '👨🏾‍❤‍👨🏽' => 'par sa srcem: muškarac, muškarac, smeđa boja kože i maslinasta boja kože',
    '👨🏾‍❤‍👨🏾' => 'par sa srcem: muškarac, muškarac i smeđa boja kože',
    '👨🏾‍❤‍👨🏿' => 'par sa srcem: muškarac, muškarac, smeđa boja kože i tamno smeđa boja kože',
    '👨🏿‍❤‍👨🏻' => 'par sa srcem: muškarac, muškarac, tamno smeđa boja kože i svijetla boja kože',
    '👨🏿‍❤‍👨🏼' => 'par sa srcem: muškarac, muškarac, tamno smeđa boja kože i svijetlo maslinasta boja kože',
    '👨🏿‍❤‍👨🏽' => 'par sa srcem: muškarac, muškarac, tamno smeđa boja kože i maslinasta boja kože',
    '👨🏿‍❤‍👨🏾' => 'par sa srcem: muškarac, muškarac, tamno smeđa boja kože i smeđa boja kože',
    '👨🏿‍❤‍👨🏿' => 'par sa srcem: muškarac, muškarac i tamno smeđa boja kože',
    '👨🏻‍🐰‍👨🏼' => 'muškarci sa zečjim ušima: svijetla boja kože i svijetlo maslinasta boja kože',
    '👨🏻‍🐰‍👨🏽' => 'muškarci sa zečjim ušima: svijetla boja kože i maslinasta boja kože',
    '👨🏻‍🐰‍👨🏾' => 'muškarci sa zečjim ušima: svijetla boja kože i smeđa boja kože',
    '👨🏻‍🐰‍👨🏿' => 'muškarci sa zečjim ušima: svijetla boja kože i tamno smeđa boja kože',
    '👨🏼‍🐰‍👨🏻' => 'muškarci sa zečjim ušima: svijetlo maslinasta boja kože i svijetla boja kože',
    '👨🏼‍🐰‍👨🏽' => 'muškarci sa zečjim ušima: svijetlo maslinasta boja kože i maslinasta boja kože',
    '👨🏼‍🐰‍👨🏾' => 'muškarci sa zečjim ušima: svijetlo maslinasta boja kože i smeđa boja kože',
    '👨🏼‍🐰‍👨🏿' => 'muškarci sa zečjim ušima: svijetlo maslinasta boja kože i tamno smeđa boja kože',
    '👨🏽‍🐰‍👨🏻' => 'muškarci sa zečjim ušima: maslinasta boja kože i svijetla boja kože',
    '👨🏽‍🐰‍👨🏼' => 'muškarci sa zečjim ušima: maslinasta boja kože i svijetlo maslinasta boja kože',
    '👨🏽‍🐰‍👨🏾' => 'muškarci sa zečjim ušima: maslinasta boja kože i smeđa boja kože',
    '👨🏽‍🐰‍👨🏿' => 'muškarci sa zečjim ušima: maslinasta boja kože i tamno smeđa boja kože',
    '👨🏾‍🐰‍👨🏻' => 'muškarci sa zečjim ušima: smeđa boja kože i svijetla boja kože',
    '👨🏾‍🐰‍👨🏼' => 'muškarci sa zečjim ušima: smeđa boja kože i svijetlo maslinasta boja kože',
    '👨🏾‍🐰‍👨🏽' => 'muškarci sa zečjim ušima: smeđa boja kože i maslinasta boja kože',
    '👨🏾‍🐰‍👨🏿' => 'muškarci sa zečjim ušima: smeđa boja kože i tamno smeđa boja kože',
    '👨🏿‍🐰‍👨🏻' => 'muškarci sa zečjim ušima: tamno smeđa boja kože i svijetla boja kože',
    '👨🏿‍🐰‍👨🏼' => 'muškarci sa zečjim ušima: tamno smeđa boja kože i svijetlo maslinasta boja kože',
    '👨🏿‍🐰‍👨🏽' => 'muškarci sa zečjim ušima: tamno smeđa boja kože i maslinasta boja kože',
    '👨🏿‍🐰‍👨🏾' => 'muškarci sa zečjim ušima: tamno smeđa boja kože i smeđa boja kože',
    '👩🏻‍🫯‍👩🏼' => 'žene se hrvaju: svijetla boja kože i svijetlo maslinasta boja kože',
    '👩🏻‍🫯‍👩🏽' => 'žene se hrvaju: svijetla boja kože i maslinasta boja kože',
    '👩🏻‍🫯‍👩🏾' => 'žene se hrvaju: svijetla boja kože i smeđa boja kože',
    '👩🏻‍🫯‍👩🏿' => 'žene se hrvaju: svijetla boja kože i tamno smeđa boja kože',
    '👩🏼‍🫯‍👩🏻' => 'žene se hrvaju: svijetlo maslinasta boja kože i svijetla boja kože',
    '👩🏼‍🫯‍👩🏽' => 'žene se hrvaju: svijetlo maslinasta boja kože i maslinasta boja kože',
    '👩🏼‍🫯‍👩🏾' => 'žene se hrvaju: svijetlo maslinasta boja kože i smeđa boja kože',
    '👩🏼‍🫯‍👩🏿' => 'žene se hrvaju: svijetlo maslinasta boja kože i tamno smeđa boja kože',
    '👩🏽‍🫯‍👩🏻' => 'žene se hrvaju: maslinasta boja kože i svijetla boja kože',
    '👩🏽‍🫯‍👩🏼' => 'žene se hrvaju: maslinasta boja kože i svijetlo maslinasta boja kože',
    '👩🏽‍🫯‍👩🏾' => 'žene se hrvaju: maslinasta boja kože i smeđa boja kože',
    '👩🏽‍🫯‍👩🏿' => 'žene se hrvaju: maslinasta boja kože i tamno smeđa boja kože',
    '👩🏾‍🫯‍👩🏻' => 'žene se hrvaju: smeđa boja kože i svijetla boja kože',
    '👩🏾‍🫯‍👩🏼' => 'žene se hrvaju: smeđa boja kože i svijetlo maslinasta boja kože',
    '👩🏾‍🫯‍👩🏽' => 'žene se hrvaju: smeđa boja kože i maslinasta boja kože',
    '👩🏾‍🫯‍👩🏿' => 'žene se hrvaju: smeđa boja kože i tamno smeđa boja kože',
    '👩🏿‍🫯‍👩🏻' => 'žene se hrvaju: tamno smeđa boja kože i svijetla boja kože',
    '👩🏿‍🫯‍👩🏼' => 'žene se hrvaju: tamno smeđa boja kože i svijetlo maslinasta boja kože',
    '👩🏿‍🫯‍👩🏽' => 'žene se hrvaju: tamno smeđa boja kože i maslinasta boja kože',
    '👩🏿‍🫯‍👩🏾' => 'žene se hrvaju: tamno smeđa boja kože i smeđa boja kože',
    '👩🏻‍❤‍👨🏻' => 'par sa srcem: žena, muškarac i svijetla boja kože',
    '👩🏻‍❤‍👨🏼' => 'par sa srcem: žena, muškarac, svijetla boja kože i svijetlo maslinasta boja kože',
    '👩🏻‍❤‍👨🏽' => 'par sa srcem: žena, muškarac, svijetla boja kože i maslinasta boja kože',
    '👩🏻‍❤‍👨🏾' => 'par sa srcem: žena, muškarac, svijetla boja kože i smeđa boja kože',
    '👩🏻‍❤‍👨🏿' => 'par sa srcem: žena, muškarac, svijetla boja kože i tamno smeđa boja kože',
    '👩🏼‍❤‍👨🏻' => 'par sa srcem: žena, muškarac, svijetlo maslinasta boja kože i svijetla boja kože',
    '👩🏼‍❤‍👨🏼' => 'par sa srcem: žena, muškarac i svijetlo maslinasta boja kože',
    '👩🏼‍❤‍👨🏽' => 'par sa srcem: žena, muškarac, svijetlo maslinasta boja kože i maslinasta boja kože',
    '👩🏼‍❤‍👨🏾' => 'par sa srcem: žena, muškarac, svijetlo maslinasta boja kože i smeđa boja kože',
    '👩🏼‍❤‍👨🏿' => 'par sa srcem: žena, muškarac, svijetlo maslinasta boja kože i tamno smeđa boja kože',
    '👩🏽‍❤‍👨🏻' => 'par sa srcem: žena, muškarac, maslinasta boja kože i svijetla boja kože',
    '👩🏽‍❤‍👨🏼' => 'par sa srcem: žena, muškarac, maslinasta boja kože i svijetlo maslinasta boja kože',
    '👩🏽‍❤‍👨🏽' => 'par sa srcem: žena, muškarac i maslinasta boja kože',
    '👩🏽‍❤‍👨🏾' => 'par sa srcem: žena, muškarac, maslinasta boja kože i smeđa boja kože',
    '👩🏽‍❤‍👨🏿' => 'par sa srcem: žena, muškarac, maslinasta boja kože i tamno smeđa boja kože',
    '👩🏾‍❤‍👨🏻' => 'par sa srcem: žena, muškarac, smeđa boja kože i svijetla boja kože',
    '👩🏾‍❤‍👨🏼' => 'par sa srcem: žena, muškarac, smeđa boja kože i svijetlo maslinasta boja kože',
    '👩🏾‍❤‍👨🏽' => 'par sa srcem: žena, muškarac, smeđa boja kože i maslinasta boja kože',
    '👩🏾‍❤‍👨🏾' => 'par sa srcem: žena, muškarac i smeđa boja kože',
    '👩🏾‍❤‍👨🏿' => 'par sa srcem: žena, muškarac, smeđa boja kože i tamno smeđa boja kože',
    '👩🏿‍❤‍👨🏻' => 'par sa srcem: žena, muškarac, tamno smeđa boja kože i svijetla boja kože',
    '👩🏿‍❤‍👨🏼' => 'par sa srcem: žena, muškarac, tamno smeđa boja kože i svijetlo maslinasta boja kože',
    '👩🏿‍❤‍👨🏽' => 'par sa srcem: žena, muškarac, tamno smeđa boja kože i maslinasta boja kože',
    '👩🏿‍❤‍👨🏾' => 'par sa srcem: žena, muškarac, tamno smeđa boja kože i smeđa boja kože',
    '👩🏿‍❤‍👨🏿' => 'par sa srcem: žena, muškarac i tamno smeđa boja kože',
    '👩🏻‍❤‍👩🏻' => 'par sa srcem: žena, žena i svijetla boja kože',
    '👩🏻‍❤‍👩🏼' => 'par sa srcem: žena, žena, svijetla boja kože i svijetlo maslinasta boja kože',
    '👩🏻‍❤‍👩🏽' => 'par sa srcem: žena, žena, svijetla boja kože i maslinasta boja kože',
    '👩🏻‍❤‍👩🏾' => 'par sa srcem: žena, žena, svijetla boja kože i smeđa boja kože',
    '👩🏻‍❤‍👩🏿' => 'par sa srcem: žena, žena, svijetla boja kože i tamno smeđa boja kože',
    '👩🏼‍❤‍👩🏻' => 'par sa srcem: žena, žena, svijetlo maslinasta boja kože i svijetla boja kože',
    '👩🏼‍❤‍👩🏼' => 'par sa srcem: žena, žena i svijetlo maslinasta boja kože',
    '👩🏼‍❤‍👩🏽' => 'par sa srcem: žena, žena, svijetlo maslinasta boja kože i maslinasta boja kože',
    '👩🏼‍❤‍👩🏾' => 'par sa srcem: žena, žena, svijetlo maslinasta boja kože i smeđa boja kože',
    '👩🏼‍❤‍👩🏿' => 'par sa srcem: žena, žena, svijetlo maslinasta boja kože i tamno smeđa boja kože',
    '👩🏽‍❤‍👩🏻' => 'par sa srcem: žena, žena, maslinasta boja kože i svijetla boja kože',
    '👩🏽‍❤‍👩🏼' => 'par sa srcem: žena, žena, maslinasta boja kože i svijetlo maslinasta boja kože',
    '👩🏽‍❤‍👩🏽' => 'par sa srcem: žena, žena i maslinasta boja kože',
    '👩🏽‍❤‍👩🏾' => 'par sa srcem: žena, žena, maslinasta boja kože i smeđa boja kože',
    '👩🏽‍❤‍👩🏿' => 'par sa srcem: žena, žena, maslinasta boja kože i tamno smeđa boja kože',
    '👩🏾‍❤‍👩🏻' => 'par sa srcem: žena, žena, smeđa boja kože i svijetla boja kože',
    '👩🏾‍❤‍👩🏼' => 'par sa srcem: žena, žena, smeđa boja kože i svijetlo maslinasta boja kože',
    '👩🏾‍❤‍👩🏽' => 'par sa srcem: žena, žena, smeđa boja kože i maslinasta boja kože',
    '👩🏾‍❤‍👩🏾' => 'par sa srcem: žena, žena i smeđa boja kože',
    '👩🏾‍❤‍👩🏿' => 'par sa srcem: žena, žena, smeđa boja kože i tamno smeđa boja kože',
    '👩🏿‍❤‍👩🏻' => 'par sa srcem: žena, žena, tamno smeđa boja kože i svijetla boja kože',
    '👩🏿‍❤‍👩🏼' => 'par sa srcem: žena, žena, tamno smeđa boja kože i svijetlo maslinasta boja kože',
    '👩🏿‍❤‍👩🏽' => 'par sa srcem: žena, žena, tamno smeđa boja kože i maslinasta boja kože',
    '👩🏿‍❤‍👩🏾' => 'par sa srcem: žena, žena, tamno smeđa boja kože i smeđa boja kože',
    '👩🏿‍❤‍👩🏿' => 'par sa srcem: žena, žena i tamno smeđa boja kože',
    '👩🏻‍🐰‍👩🏼' => 'žene sa zečjim ušima: svijetla boja kože i svijetlo maslinasta boja kože',
    '👩🏻‍🐰‍👩🏽' => 'žene sa zečjim ušima: svijetla boja kože i maslinasta boja kože',
    '👩🏻‍🐰‍👩🏾' => 'žene sa zečjim ušima: svijetla boja kože i smeđa boja kože',
    '👩🏻‍🐰‍👩🏿' => 'žene sa zečjim ušima: svijetla boja kože i tamno smeđa boja kože',
    '👩🏼‍🐰‍👩🏻' => 'žene sa zečjim ušima: svijetlo maslinasta boja kože i svijetla boja kože',
    '👩🏼‍🐰‍👩🏽' => 'žene sa zečjim ušima: svijetlo maslinasta boja kože i maslinasta boja kože',
    '👩🏼‍🐰‍👩🏾' => 'žene sa zečjim ušima: svijetlo maslinasta boja kože i smeđa boja kože',
    '👩🏼‍🐰‍👩🏿' => 'žene sa zečjim ušima: svijetlo maslinasta boja kože i tamno smeđa boja kože',
    '👩🏽‍🐰‍👩🏻' => 'žene sa zečjim ušima: maslinasta boja kože i svijetla boja kože',
    '👩🏽‍🐰‍👩🏼' => 'žene sa zečjim ušima: maslinasta boja kože i svijetlo maslinasta boja kože',
    '👩🏽‍🐰‍👩🏾' => 'žene sa zečjim ušima: maslinasta boja kože i smeđa boja kože',
    '👩🏽‍🐰‍👩🏿' => 'žene sa zečjim ušima: maslinasta boja kože i tamno smeđa boja kože',
    '👩🏾‍🐰‍👩🏻' => 'žene sa zečjim ušima: smeđa boja kože i svijetla boja kože',
    '👩🏾‍🐰‍👩🏼' => 'žene sa zečjim ušima: smeđa boja kože i svijetlo maslinasta boja kože',
    '👩🏾‍🐰‍👩🏽' => 'žene sa zečjim ušima: smeđa boja kože i maslinasta boja kože',
    '👩🏾‍🐰‍👩🏿' => 'žene sa zečjim ušima: smeđa boja kože i tamno smeđa boja kože',
    '👩🏿‍🐰‍👩🏻' => 'žene sa zečjim ušima: tamno smeđa boja kože i svijetla boja kože',
    '👩🏿‍🐰‍👩🏼' => 'žene sa zečjim ušima: tamno smeđa boja kože i svijetlo maslinasta boja kože',
    '👩🏿‍🐰‍👩🏽' => 'žene sa zečjim ušima: tamno smeđa boja kože i maslinasta boja kože',
    '👩🏿‍🐰‍👩🏾' => 'žene sa zečjim ušima: tamno smeđa boja kože i smeđa boja kože',
    '🧑🏻‍🤝‍🧑🏻' => 'osobe koje se drže za ruke: svijetla boja kože',
    '🧑🏻‍🤝‍🧑🏼' => 'osobe koje se drže za ruke: svijetla boja kože i svijetlo maslinasta boja kože',
    '🧑🏻‍🤝‍🧑🏽' => 'osobe koje se drže za ruke: svijetla boja kože i maslinasta boja kože',
    '🧑🏻‍🤝‍🧑🏾' => 'osobe koje se drže za ruke: svijetla boja kože i smeđa boja kože',
    '🧑🏻‍🤝‍🧑🏿' => 'osobe koje se drže za ruke: svijetla boja kože i tamno smeđa boja kože',
    '🧑🏼‍🤝‍🧑🏻' => 'osobe koje se drže za ruke: svijetlo maslinasta boja kože i svijetla boja kože',
    '🧑🏼‍🤝‍🧑🏼' => 'osobe koje se drže za ruke: svijetlo maslinasta boja kože',
    '🧑🏼‍🤝‍🧑🏽' => 'osobe koje se drže za ruke: svijetlo maslinasta boja kože i maslinasta boja kože',
    '🧑🏼‍🤝‍🧑🏾' => 'osobe koje se drže za ruke: svijetlo maslinasta boja kože i smeđa boja kože',
    '🧑🏼‍🤝‍🧑🏿' => 'osobe koje se drže za ruke: svijetlo maslinasta boja kože i tamno smeđa boja kože',
    '🧑🏽‍🤝‍🧑🏻' => 'osobe koje se drže za ruke: maslinasta boja kože i svijetla boja kože',
    '🧑🏽‍🤝‍🧑🏼' => 'osobe koje se drže za ruke: maslinasta boja kože i svijetlo maslinasta boja kože',
    '🧑🏽‍🤝‍🧑🏽' => 'osobe koje se drže za ruke: maslinasta boja kože',
    '🧑🏽‍🤝‍🧑🏾' => 'osobe koje se drže za ruke: maslinasta boja kože i smeđa boja kože',
    '🧑🏽‍🤝‍🧑🏿' => 'osobe koje se drže za ruke: maslinasta boja kože i tamno smeđa boja kože',
    '🧑🏾‍🤝‍🧑🏻' => 'osobe koje se drže za ruke: smeđa boja kože i svijetla boja kože',
    '🧑🏾‍🤝‍🧑🏼' => 'osobe koje se drže za ruke: smeđa boja kože i svijetlo maslinasta boja kože',
    '🧑🏾‍🤝‍🧑🏽' => 'osobe koje se drže za ruke: smeđa boja kože i maslinasta boja kože',
    '🧑🏾‍🤝‍🧑🏾' => 'osobe koje se drže za ruke: smeđa boja kože',
    '🧑🏾‍🤝‍🧑🏿' => 'osobe koje se drže za ruke: smeđa boja kože i tamno smeđa boja kože',
    '🧑🏿‍🤝‍🧑🏻' => 'osobe koje se drže za ruke: tamno smeđa boja kože i svijetla boja kože',
    '🧑🏿‍🤝‍🧑🏼' => 'osobe koje se drže za ruke: tamno smeđa boja kože i svijetlo maslinasta boja kože',
    '🧑🏿‍🤝‍🧑🏽' => 'osobe koje se drže za ruke: tamno smeđa boja kože i maslinasta boja kože',
    '🧑🏿‍🤝‍🧑🏾' => 'osobe koje se drže za ruke: tamno smeđa boja kože i smeđa boja kože',
    '🧑🏿‍🤝‍🧑🏿' => 'osobe koje se drže za ruke: tamno smeđa boja kože',
    '👩🏻‍🤝‍👩🏼' => 'žene koje se drže za ruke: svijetla boja kože i svijetlo maslinasta boja kože',
    '👩🏻‍🤝‍👩🏽' => 'žene koje se drže za ruke: svijetla boja kože i maslinasta boja kože',
    '👩🏻‍🤝‍👩🏾' => 'žene koje se drže za ruke: svijetla boja kože i smeđa boja kože',
    '👩🏻‍🤝‍👩🏿' => 'žene koje se drže za ruke: svijetla boja kože i tamno smeđa boja kože',
    '👩🏼‍🤝‍👩🏻' => 'žene koje se drže za ruke: svijetlo maslinasta boja kože i svijetla boja kože',
    '👩🏼‍🤝‍👩🏽' => 'žene koje se drže za ruke: svijetlo maslinasta boja kože i maslinasta boja kože',
    '👩🏼‍🤝‍👩🏾' => 'žene koje se drže za ruke: svijetlo maslinasta boja kože i smeđa boja kože',
    '👩🏼‍🤝‍👩🏿' => 'žene koje se drže za ruke: svijetlo maslinasta boja kože i tamno smeđa boja kože',
    '👩🏽‍🤝‍👩🏻' => 'žene koje se drže za ruke: maslinasta boja kože i svijetla boja kože',
    '👩🏽‍🤝‍👩🏼' => 'žene koje se drže za ruke: maslinasta boja kože i svijetlo maslinasta boja kože',
    '👩🏽‍🤝‍👩🏾' => 'žene koje se drže za ruke: maslinasta boja kože i smeđa boja kože',
    '👩🏽‍🤝‍👩🏿' => 'žene koje se drže za ruke: maslinasta boja kože i tamno smeđa boja kože',
    '👩🏾‍🤝‍👩🏻' => 'žene koje se drže za ruke: smeđa boja kože i svijetla boja kože',
    '👩🏾‍🤝‍👩🏼' => 'žene koje se drže za ruke: smeđa boja kože i svijetlo maslinasta boja kože',
    '👩🏾‍🤝‍👩🏽' => 'žene koje se drže za ruke: smeđa boja kože i maslinasta boja kože',
    '👩🏾‍🤝‍👩🏿' => 'žene koje se drže za ruke: smeđa boja kože i tamno smeđa boja kože',
    '👩🏿‍🤝‍👩🏻' => 'žene koje se drže za ruke: tamno smeđa boja kože i svijetla boja kože',
    '👩🏿‍🤝‍👩🏼' => 'žene koje se drže za ruke: tamno smeđa boja kože i svijetlo maslinasta boja kože',
    '👩🏿‍🤝‍👩🏽' => 'žene koje se drže za ruke: tamno smeđa boja kože i maslinasta boja kože',
    '👩🏿‍🤝‍👩🏾' => 'žene koje se drže za ruke: tamno smeđa boja kože i smeđa boja kože',
    '👩🏻‍🤝‍👨🏼' => 'muškarac i žena koji se drže za ruke: svijetla boja kože i svijetlo maslinasta boja kože',
    '👩🏻‍🤝‍👨🏽' => 'muškarac i žena koji se drže za ruke: svijetla boja kože i maslinasta boja kože',
    '👩🏻‍🤝‍👨🏾' => 'muškarac i žena koji se drže za ruke: svijetla boja kože i smeđa boja kože',
    '👩🏻‍🤝‍👨🏿' => 'muškarac i žena koji se drže za ruke: svijetla boja kože i tamno smeđa boja kože',
    '👩🏼‍🤝‍👨🏻' => 'muškarac i žena koji se drže za ruke: svijetlo maslinasta boja kože i svijetla boja kože',
    '👩🏼‍🤝‍👨🏽' => 'muškarac i žena koji se drže za ruke: svijetlo maslinasta boja kože i maslinasta boja kože',
    '👩🏼‍🤝‍👨🏾' => 'muškarac i žena koji se drže za ruke: svijetlo maslinasta boja kože i smeđa boja kože',
    '👩🏼‍🤝‍👨🏿' => 'muškarac i žena koji se drže za ruke: svijetlo maslinasta boja kože i tamno smeđa boja kože',
    '👩🏽‍🤝‍👨🏻' => 'muškarac i žena koji se drže za ruke: maslinasta boja kože i svijetla boja kože',
    '👩🏽‍🤝‍👨🏼' => 'muškarac i žena koji se drže za ruke: maslinasta boja kože i svijetlo maslinasta boja kože',
    '👩🏽‍🤝‍👨🏾' => 'muškarac i žena koji se drže za ruke: maslinasta boja kože i smeđa boja kože',
    '👩🏽‍🤝‍👨🏿' => 'muškarac i žena koji se drže za ruke: maslinasta boja kože i tamno smeđa boja kože',
    '👩🏾‍🤝‍👨🏻' => 'muškarac i žena koji se drže za ruke: smeđa boja kože i svijetla boja kože',
    '👩🏾‍🤝‍👨🏼' => 'muškarac i žena koji se drže za ruke: smeđa boja kože i svijetlo maslinasta boja kože',
    '👩🏾‍🤝‍👨🏽' => 'muškarac i žena koji se drže za ruke: smeđa boja kože i maslinasta boja kože',
    '👩🏾‍🤝‍👨🏿' => 'muškarac i žena koji se drže za ruke: smeđa boja kože i tamno smeđa boja kože',
    '👩🏿‍🤝‍👨🏻' => 'muškarac i žena koji se drže za ruke: tamno smeđa boja kože i svijetla boja kože',
    '👩🏿‍🤝‍👨🏼' => 'muškarac i žena koji se drže za ruke: tamno smeđa boja kože i svijetlo maslinasta boja kože',
    '👩🏿‍🤝‍👨🏽' => 'muškarac i žena koji se drže za ruke: tamno smeđa boja kože i maslinasta boja kože',
    '👩🏿‍🤝‍👨🏾' => 'muškarac i žena koji se drže za ruke: tamno smeđa boja kože i smeđa boja kože',
    '👨🏻‍🤝‍👨🏼' => 'muškarci koji se drže za ruke: svijetla boja kože i svijetlo maslinasta boja kože',
    '👨🏻‍🤝‍👨🏽' => 'muškarci koji se drže za ruke: svijetla boja kože i maslinasta boja kože',
    '👨🏻‍🤝‍👨🏾' => 'muškarci koji se drže za ruke: svijetla boja kože i smeđa boja kože',
    '👨🏻‍🤝‍👨🏿' => 'muškarci koji se drže za ruke: svijetla boja kože i tamno smeđa boja kože',
    '👨🏼‍🤝‍👨🏻' => 'muškarci koji se drže za ruke: svijetlo maslinasta boja kože i svijetla boja kože',
    '👨🏼‍🤝‍👨🏽' => 'muškarci koji se drže za ruke: svijetlo maslinasta boja kože i maslinasta boja kože',
    '👨🏼‍🤝‍👨🏾' => 'muškarci koji se drže za ruke: svijetlo maslinasta boja kože i smeđa boja kože',
    '👨🏼‍🤝‍👨🏿' => 'muškarci koji se drže za ruke: svijetlo maslinasta boja kože i tamno smeđa boja kože',
    '👨🏽‍🤝‍👨🏻' => 'muškarci koji se drže za ruke: maslinasta boja kože i svijetla boja kože',
    '👨🏽‍🤝‍👨🏼' => 'muškarci koji se drže za ruke: maslinasta boja kože i svijetlo maslinasta boja kože',
    '👨🏽‍🤝‍👨🏾' => 'muškarci koji se drže za ruke: maslinasta boja kože i smeđa boja kože',
    '👨🏽‍🤝‍👨🏿' => 'muškarci koji se drže za ruke: maslinasta boja kože i tamno smeđa boja kože',
    '👨🏾‍🤝‍👨🏻' => 'muškarci koji se drže za ruke: smeđa boja kože i svijetla boja kože',
    '👨🏾‍🤝‍👨🏼' => 'muškarci koji se drže za ruke: smeđa boja kože i svijetlo maslinasta boja kože',
    '👨🏾‍🤝‍👨🏽' => 'muškarci koji se drže za ruke: smeđa boja kože i maslinasta boja kože',
    '👨🏾‍🤝‍👨🏿' => 'muškarci koji se drže za ruke: smeđa boja kože i tamno smeđa boja kože',
    '👨🏿‍🤝‍👨🏻' => 'muškarci koji se drže za ruke: tamno smeđa boja kože i svijetla boja kože',
    '👨🏿‍🤝‍👨🏼' => 'muškarci koji se drže za ruke: tamno smeđa boja kože i svijetlo maslinasta boja kože',
    '👨🏿‍🤝‍👨🏽' => 'muškarci koji se drže za ruke: tamno smeđa boja kože i maslinasta boja kože',
    '👨🏿‍🤝‍👨🏾' => 'muškarci koji se drže za ruke: tamno smeđa boja kože i smeđa boja kože',
    '👩‍❤‍💋‍👨' => 'poljubac: žena i muškarac',
    '👨‍❤‍💋‍👨' => 'poljubac: muškarac i muškarac',
    '👩‍❤‍💋‍👩' => 'poljubac: žena i žena',
    '👨‍👩‍👧‍👦' => 'obitelj: muškarac, žena, djevojčica i dječak',
    '👨‍👩‍👦‍👦' => 'obitelj: muškarac, žena, dječak i dječak',
    '👨‍👩‍👧‍👧' => 'obitelj: muškarac, žena, djevojčica i djevojčica',
    '👨‍👨‍👧‍👦' => 'obitelj: muškarac, muškarac, djevojčica i dječak',
    '👨‍👨‍👦‍👦' => 'obitelj: muškarac, muškarac, dječak i dječak',
    '👨‍👨‍👧‍👧' => 'obitelj: muškarac, muškarac, djevojčica i djevojčica',
    '👩‍👩‍👧‍👦' => 'obitelj: žena, žena, djevojčica i dječak',
    '👩‍👩‍👦‍👦' => 'obitelj: žena, žena, dječak i dječak',
    '👩‍👩‍👧‍👧' => 'obitelj: žena, žena, djevojčica i djevojčica',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'zastava: Engleska',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'zastava: Škotska',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'zastava: Wales',
    '🧑‍🧑‍🧒‍🧒' => 'obitelj: odrasla osoba, odrasla osoba, dijete, dijete',
    '🚶🏻‍♀‍➡' => 'žena hoda: svijetla boja kože i udesno',
    '🚶🏼‍♀‍➡' => 'žena hoda: svijetlo maslinasta boja kože i udesno',
    '🚶🏽‍♀‍➡' => 'žena hoda: maslinasta boja kože i udesno',
    '🚶🏾‍♀‍➡' => 'žena hoda: smeđa boja kože i udesno',
    '🚶🏿‍♀‍➡' => 'žena hoda: tamno smeđa boja kože i udesno',
    '🚶🏻‍♂‍➡' => 'muškarac hoda: svijetla boja kože i udesno',
    '🚶🏼‍♂‍➡' => 'muškarac hoda: svijetlo maslinasta boja kože i udesno',
    '🚶🏽‍♂‍➡' => 'muškarac hoda: maslinasta boja kože i udesno',
    '🚶🏾‍♂‍➡' => 'muškarac hoda: smeđa boja kože i udesno',
    '🚶🏿‍♂‍➡' => 'muškarac hoda: tamno smeđa boja kože i udesno',
    '🧎🏻‍♀‍➡' => 'žena kleči: svijetla boja kože i udesno',
    '🧎🏼‍♀‍➡' => 'žena kleči: svijetlo maslinasta boja kože i udesno',
    '🧎🏽‍♀‍➡' => 'žena kleči: maslinasta boja kože i udesno',
    '🧎🏾‍♀‍➡' => 'žena kleči: smeđa boja kože i udesno',
    '🧎🏿‍♀‍➡' => 'žena kleči: tamno smeđa boja kože i udesno',
    '🧎🏻‍♂‍➡' => 'muškarac kleči: svijetla boja kože i udesno',
    '🧎🏼‍♂‍➡' => 'muškarac kleči: svijetlo maslinasta boja kože i udesno',
    '🧎🏽‍♂‍➡' => 'muškarac kleči: maslinasta boja kože i udesno',
    '🧎🏾‍♂‍➡' => 'muškarac kleči: smeđa boja kože i udesno',
    '🧎🏿‍♂‍➡' => 'muškarac kleči: tamno smeđa boja kože i udesno',
    '🧑🏻‍🦯‍➡' => 'osoba s bijelim štapom: svijetla boja kože i udesno',
    '🧑🏼‍🦯‍➡' => 'osoba s bijelim štapom: svijetlo maslinasta boja kože i udesno',
    '🧑🏽‍🦯‍➡' => 'osoba s bijelim štapom: maslinasta boja kože i udesno',
    '🧑🏾‍🦯‍➡' => 'osoba s bijelim štapom: smeđa boja kože i udesno',
    '🧑🏿‍🦯‍➡' => 'osoba s bijelim štapom: tamno smeđa boja kože i udesno',
    '👨🏻‍🦯‍➡' => 'muškarac s bijelim štapom: svijetla boja kože i udesno',
    '👨🏼‍🦯‍➡' => 'muškarac s bijelim štapom: svijetlo maslinasta boja kože i udesno',
    '👨🏽‍🦯‍➡' => 'muškarac s bijelim štapom: maslinasta boja kože i udesno',
    '👨🏾‍🦯‍➡' => 'muškarac s bijelim štapom: smeđa boja kože i udesno',
    '👨🏿‍🦯‍➡' => 'muškarac s bijelim štapom: tamno smeđa boja kože i udesno',
    '👩🏻‍🦯‍➡' => 'žena s bijelim štapom: svijetla boja kože i udesno',
    '👩🏼‍🦯‍➡' => 'žena s bijelim štapom: svijetlo maslinasta boja kože i udesno',
    '👩🏽‍🦯‍➡' => 'žena s bijelim štapom: maslinasta boja kože i udesno',
    '👩🏾‍🦯‍➡' => 'žena s bijelim štapom: smeđa boja kože i udesno',
    '👩🏿‍🦯‍➡' => 'žena s bijelim štapom: tamno smeđa boja kože i udesno',
    '🧑🏻‍🦼‍➡' => 'osoba u invalidskim kolicima na motorni pogon: svijetla boja kože i udesno',
    '🧑🏼‍🦼‍➡' => 'osoba u invalidskim kolicima na motorni pogon: svijetlo maslinasta boja kože i udesno',
    '🧑🏽‍🦼‍➡' => 'osoba u invalidskim kolicima na motorni pogon: maslinasta boja kože i udesno',
    '🧑🏾‍🦼‍➡' => 'osoba u invalidskim kolicima na motorni pogon: smeđa boja kože i udesno',
    '🧑🏿‍🦼‍➡' => 'osoba u invalidskim kolicima na motorni pogon: tamno smeđa boja kože i udesno',
    '👨🏻‍🦼‍➡' => 'muškarac u motornim invalidskim kolicima: svijetla boja kože i udesno',
    '👨🏼‍🦼‍➡' => 'muškarac u motornim invalidskim kolicima: svijetlo maslinasta boja kože i udesno',
    '👨🏽‍🦼‍➡' => 'muškarac u motornim invalidskim kolicima: maslinasta boja kože i udesno',
    '👨🏾‍🦼‍➡' => 'muškarac u motornim invalidskim kolicima: smeđa boja kože i udesno',
    '👨🏿‍🦼‍➡' => 'muškarac u motornim invalidskim kolicima: tamno smeđa boja kože i udesno',
    '👩🏻‍🦼‍➡' => 'žena u motornim invalidskim kolicima: svijetla boja kože i udesno',
    '👩🏼‍🦼‍➡' => 'žena u motornim invalidskim kolicima: svijetlo maslinasta boja kože i udesno',
    '👩🏽‍🦼‍➡' => 'žena u motornim invalidskim kolicima: maslinasta boja kože i udesno',
    '👩🏾‍🦼‍➡' => 'žena u motornim invalidskim kolicima: smeđa boja kože i udesno',
    '👩🏿‍🦼‍➡' => 'žena u motornim invalidskim kolicima: tamno smeđa boja kože i udesno',
    '🧑🏻‍🦽‍➡' => 'osoba u invalidskim kolicima na ručni pogon: svijetla boja kože i udesno',
    '🧑🏼‍🦽‍➡' => 'osoba u invalidskim kolicima na ručni pogon: svijetlo maslinasta boja kože i udesno',
    '🧑🏽‍🦽‍➡' => 'osoba u invalidskim kolicima na ručni pogon: maslinasta boja kože i udesno',
    '🧑🏾‍🦽‍➡' => 'osoba u invalidskim kolicima na ručni pogon: smeđa boja kože i udesno',
    '🧑🏿‍🦽‍➡' => 'osoba u invalidskim kolicima na ručni pogon: tamno smeđa boja kože i udesno',
    '👨🏻‍🦽‍➡' => 'muškarac u invalidskim kolicima na ručni pogon: svijetla boja kože i udesno',
    '👨🏼‍🦽‍➡' => 'muškarac u invalidskim kolicima na ručni pogon: svijetlo maslinasta boja kože i udesno',
    '👨🏽‍🦽‍➡' => 'muškarac u invalidskim kolicima na ručni pogon: maslinasta boja kože i udesno',
    '👨🏾‍🦽‍➡' => 'muškarac u invalidskim kolicima na ručni pogon: smeđa boja kože i udesno',
    '👨🏿‍🦽‍➡' => 'muškarac u invalidskim kolicima na ručni pogon: tamno smeđa boja kože i udesno',
    '👩🏻‍🦽‍➡' => 'žena u invalidskim kolicima na ručni pogon: svijetla boja kože i udesno',
    '👩🏼‍🦽‍➡' => 'žena u invalidskim kolicima na ručni pogon: svijetlo maslinasta boja kože i udesno',
    '👩🏽‍🦽‍➡' => 'žena u invalidskim kolicima na ručni pogon: maslinasta boja kože i udesno',
    '👩🏾‍🦽‍➡' => 'žena u invalidskim kolicima na ručni pogon: smeđa boja kože i udesno',
    '👩🏿‍🦽‍➡' => 'žena u invalidskim kolicima na ručni pogon: tamno smeđa boja kože i udesno',
    '🏃🏻‍♀‍➡' => 'žena trči: svijetla boja kože i udesno',
    '🏃🏼‍♀‍➡' => 'žena trči: svijetlo maslinasta boja kože i udesno',
    '🏃🏽‍♀‍➡' => 'žena trči: maslinasta boja kože i udesno',
    '🏃🏾‍♀‍➡' => 'žena trči: smeđa boja kože i udesno',
    '🏃🏿‍♀‍➡' => 'žena trči: tamno smeđa boja kože i udesno',
    '🏃🏻‍♂‍➡' => 'muškarac trči: svijetla boja kože i udesno',
    '🏃🏼‍♂‍➡' => 'muškarac trči: svijetlo maslinasta boja kože i udesno',
    '🏃🏽‍♂‍➡' => 'muškarac trči: maslinasta boja kože i udesno',
    '🏃🏾‍♂‍➡' => 'muškarac trči: smeđa boja kože i udesno',
    '🏃🏿‍♂‍➡' => 'muškarac trči: tamno smeđa boja kože i udesno',
    '🫱🏻‍🫲🏼' => 'rukovanje: svijetla boja kože i svijetlo maslinasta boja kože',
    '🫱🏻‍🫲🏽' => 'rukovanje: svijetla boja kože i maslinasta boja kože',
    '🫱🏻‍🫲🏾' => 'rukovanje: svijetla boja kože i smeđa boja kože',
    '🫱🏻‍🫲🏿' => 'rukovanje: svijetla boja kože i tamno smeđa boja kože',
    '🫱🏼‍🫲🏻' => 'rukovanje: svijetlo maslinasta boja kože i svijetla boja kože',
    '🫱🏼‍🫲🏽' => 'rukovanje: svijetlo maslinasta boja kože i maslinasta boja kože',
    '🫱🏼‍🫲🏾' => 'rukovanje: svijetlo maslinasta boja kože i smeđa boja kože',
    '🫱🏼‍🫲🏿' => 'rukovanje: svijetlo maslinasta boja kože i tamno smeđa boja kože',
    '🫱🏽‍🫲🏻' => 'rukovanje: maslinasta boja kože i svijetla boja kože',
    '🫱🏽‍🫲🏼' => 'rukovanje: maslinasta boja kože i svijetlo maslinasta boja kože',
    '🫱🏽‍🫲🏾' => 'rukovanje: maslinasta boja kože i smeđa boja kože',
    '🫱🏽‍🫲🏿' => 'rukovanje: maslinasta boja kože i tamno smeđa boja kože',
    '🫱🏾‍🫲🏻' => 'rukovanje: smeđa boja kože i svijetla boja kože',
    '🫱🏾‍🫲🏼' => 'rukovanje: smeđa boja kože i svijetlo maslinasta boja kože',
    '🫱🏾‍🫲🏽' => 'rukovanje: smeđa boja kože i maslinasta boja kože',
    '🫱🏾‍🫲🏿' => 'rukovanje: smeđa boja kože i tamno smeđa boja kože',
    '🫱🏿‍🫲🏻' => 'rukovanje: tamno smeđa boja kože i svijetla boja kože',
    '🫱🏿‍🫲🏼' => 'rukovanje: tamno smeđa boja kože i svijetlo maslinasta boja kože',
    '🫱🏿‍🫲🏽' => 'rukovanje: tamno smeđa boja kože i maslinasta boja kože',
    '🫱🏿‍🫲🏾' => 'rukovanje: tamno smeđa boja kože i smeđa boja kože',
    '🚶‍♀‍➡' => 'žena hoda: udesno',
    '🚶‍♂‍➡' => 'muškarac hoda: udesno',
    '🧎‍♀‍➡' => 'žena kleči: udesno',
    '🧎‍♂‍➡' => 'muškarac kleči: udesno',
    '🧑‍🦯‍➡' => 'osoba s bijelim štapom: udesno',
    '👨‍🦯‍➡' => 'muškarac s bijelim štapom: udesno',
    '👩‍🦯‍➡' => 'žena s bijelim štapom: udesno',
    '🧑‍🦼‍➡' => 'osoba u invalidskim kolicima na motorni pogon: udesno',
    '👨‍🦼‍➡' => 'muškarac u motornim invalidskim kolicima: udesno',
    '👩‍🦼‍➡' => 'žena u motornim invalidskim kolicima: udesno',
    '🧑‍🦽‍➡' => 'osoba u invalidskim kolicima na ručni pogon: udesno',
    '👨‍🦽‍➡' => 'muškarac u invalidskim kolicima na ručni pogon: udesno',
    '👩‍🦽‍➡' => 'žena u invalidskim kolicima na ručni pogon: udesno',
    '🏃‍♀‍➡' => 'žena trči: udesno',
    '🏃‍♂‍➡' => 'muškarac trči: udesno',
    '👩‍❤‍👨' => 'par sa srcem: žena i muškarac',
    '👨‍❤‍👨' => 'par sa srcem: muškarac i muškarac',
    '👩‍❤‍👩' => 'par sa srcem: žena i žena',
    '👨‍👩‍👦' => 'obitelj: muškarac, žena i dječak',
    '👨‍👩‍👧' => 'obitelj: muškarac, žena i djevojčica',
    '👨‍👨‍👦' => 'obitelj: muškarac, muškarac i dječak',
    '👨‍👨‍👧' => 'obitelj: muškarac, muškarac i djevojčica',
    '👩‍👩‍👦' => 'obitelj: žena, žena i dječak',
    '👩‍👩‍👧' => 'obitelj: žena, žena i djevojčica',
    '👨‍👦‍👦' => 'obitelj: muškarac, dječak i dječak',
    '👨‍👧‍👦' => 'obitelj: muškarac, djevojčica i dječak',
    '👨‍👧‍👧' => 'obitelj: muškarac, djevojčica i djevojčica',
    '👩‍👦‍👦' => 'obitelj: žena, dječak i dječak',
    '👩‍👧‍👦' => 'obitelj: žena, djevojčica i dječak',
    '👩‍👧‍👧' => 'obitelj: žena, djevojčica i djevojčica',
    '🧑‍🤝‍🧑' => 'osobe koje se drže za ruke',
    '🧑‍🧑‍🧒' => 'obitelj: odrasla osoba, odrasla osoba, dijete',
    '🧑‍🧒‍🧒' => 'obitelj: odrasla osoba, dijete, dijete',
    '🧑🏻‍🦰' => 'odrasla osoba: svijetla boja kože i crvena kosa',
    '🧑🏼‍🦰' => 'odrasla osoba: svijetlo maslinasta boja kože i crvena kosa',
    '🧑🏽‍🦰' => 'odrasla osoba: maslinasta boja kože i crvena kosa',
    '🧑🏾‍🦰' => 'odrasla osoba: smeđa boja kože i crvena kosa',
    '🧑🏿‍🦰' => 'odrasla osoba: tamno smeđa boja kože i crvena kosa',
    '🧑🏻‍🦱' => 'odrasla osoba: svijetla boja kože i kovrčava kosa',
    '🧑🏼‍🦱' => 'odrasla osoba: svijetlo maslinasta boja kože i kovrčava kosa',
    '🧑🏽‍🦱' => 'odrasla osoba: maslinasta boja kože i kovrčava kosa',
    '🧑🏾‍🦱' => 'odrasla osoba: smeđa boja kože i kovrčava kosa',
    '🧑🏿‍🦱' => 'odrasla osoba: tamno smeđa boja kože i kovrčava kosa',
    '🧑🏻‍🦳' => 'odrasla osoba: svijetla boja kože i sijeda kosa',
    '🧑🏼‍🦳' => 'odrasla osoba: svijetlo maslinasta boja kože i sijeda kosa',
    '🧑🏽‍🦳' => 'odrasla osoba: maslinasta boja kože i sijeda kosa',
    '🧑🏾‍🦳' => 'odrasla osoba: smeđa boja kože i sijeda kosa',
    '🧑🏿‍🦳' => 'odrasla osoba: tamno smeđa boja kože i sijeda kosa',
    '🧑🏻‍🦲' => 'odrasla osoba: svijetla boja kože i bez kose',
    '🧑🏼‍🦲' => 'odrasla osoba: svijetlo maslinasta boja kože i bez kose',
    '🧑🏽‍🦲' => 'odrasla osoba: maslinasta boja kože i bez kose',
    '🧑🏾‍🦲' => 'odrasla osoba: smeđa boja kože i bez kose',
    '🧑🏿‍🦲' => 'odrasla osoba: tamno smeđa boja kože i bez kose',
    '🧑🏻‍🩰' => 'balerina: svijetla boja kože',
    '🧑🏼‍🩰' => 'balerina: svijetlo maslinasta boja kože',
    '🧑🏽‍🩰' => 'balerina: maslinasta boja kože',
    '🧑🏾‍🩰' => 'balerina: smeđa boja kože',
    '🧑🏿‍🩰' => 'balerina: tamno smeđa boja kože',
    '🧔🏻‍♂' => 'muškarac: svijetla boja kože i brada',
    '🧔🏼‍♂' => 'muškarac: svijetlo maslinasta boja kože i brada',
    '🧔🏽‍♂' => 'muškarac: maslinasta boja kože i brada',
    '🧔🏾‍♂' => 'muškarac: smeđa boja kože i brada',
    '🧔🏿‍♂' => 'muškarac: tamno smeđa boja kože i brada',
    '👱🏻‍♂' => 'plavokosi muškarac: svijetla boja kože',
    '👱🏼‍♂' => 'plavokosi muškarac: svijetlo maslinasta boja kože',
    '👱🏽‍♂' => 'plavokosi muškarac: maslinasta boja kože',
    '👱🏾‍♂' => 'plavokosi muškarac: smeđa boja kože',
    '👱🏿‍♂' => 'plavokosi muškarac: tamno smeđa boja kože',
    '👨🏻‍🦰' => 'muškarac: svijetla boja kože i crvena kosa',
    '👨🏼‍🦰' => 'muškarac: svijetlo maslinasta boja kože i crvena kosa',
    '👨🏽‍🦰' => 'muškarac: maslinasta boja kože i crvena kosa',
    '👨🏾‍🦰' => 'muškarac: smeđa boja kože i crvena kosa',
    '👨🏿‍🦰' => 'muškarac: tamno smeđa boja kože i crvena kosa',
    '👨🏻‍🦱' => 'muškarac: svijetla boja kože i kovrčava kosa',
    '👨🏼‍🦱' => 'muškarac: svijetlo maslinasta boja kože i kovrčava kosa',
    '👨🏽‍🦱' => 'muškarac: maslinasta boja kože i kovrčava kosa',
    '👨🏾‍🦱' => 'muškarac: smeđa boja kože i kovrčava kosa',
    '👨🏿‍🦱' => 'muškarac: tamno smeđa boja kože i kovrčava kosa',
    '👨🏻‍🦳' => 'muškarac: svijetla boja kože i sijeda kosa',
    '👨🏼‍🦳' => 'muškarac: svijetlo maslinasta boja kože i sijeda kosa',
    '👨🏽‍🦳' => 'muškarac: maslinasta boja kože i sijeda kosa',
    '👨🏾‍🦳' => 'muškarac: smeđa boja kože i sijeda kosa',
    '👨🏿‍🦳' => 'muškarac: tamno smeđa boja kože i sijeda kosa',
    '👨🏻‍🦲' => 'muškarac: svijetla boja kože i bez kose',
    '👨🏼‍🦲' => 'muškarac: svijetlo maslinasta boja kože i bez kose',
    '👨🏽‍🦲' => 'muškarac: maslinasta boja kože i bez kose',
    '👨🏾‍🦲' => 'muškarac: smeđa boja kože i bez kose',
    '👨🏿‍🦲' => 'muškarac: tamno smeđa boja kože i bez kose',
    '🧔🏻‍♀' => 'žena: svijetla boja kože i brada',
    '🧔🏼‍♀' => 'žena: svijetlo maslinasta boja kože i brada',
    '🧔🏽‍♀' => 'žena: maslinasta boja kože i brada',
    '🧔🏾‍♀' => 'žena: smeđa boja kože i brada',
    '🧔🏿‍♀' => 'žena: tamno smeđa boja kože i brada',
    '👱🏻‍♀' => 'plavokosa žena: svijetla boja kože',
    '👱🏼‍♀' => 'plavokosa žena: svijetlo maslinasta boja kože',
    '👱🏽‍♀' => 'plavokosa žena: maslinasta boja kože',
    '👱🏾‍♀' => 'plavokosa žena: smeđa boja kože',
    '👱🏿‍♀' => 'plavokosa žena: tamno smeđa boja kože',
    '👩🏻‍🦰' => 'žena: svijetla boja kože i crvena kosa',
    '👩🏼‍🦰' => 'žena: svijetlo maslinasta boja kože i crvena kosa',
    '👩🏽‍🦰' => 'žena: maslinasta boja kože i crvena kosa',
    '👩🏾‍🦰' => 'žena: smeđa boja kože i crvena kosa',
    '👩🏿‍🦰' => 'žena: tamno smeđa boja kože i crvena kosa',
    '👩🏻‍🦱' => 'žena: svijetla boja kože i kovrčava kosa',
    '👩🏼‍🦱' => 'žena: svijetlo maslinasta boja kože i kovrčava kosa',
    '👩🏽‍🦱' => 'žena: maslinasta boja kože i kovrčava kosa',
    '👩🏾‍🦱' => 'žena: smeđa boja kože i kovrčava kosa',
    '👩🏿‍🦱' => 'žena: tamno smeđa boja kože i kovrčava kosa',
    '👩🏻‍🦳' => 'žena: svijetla boja kože i sijeda kosa',
    '👩🏼‍🦳' => 'žena: svijetlo maslinasta boja kože i sijeda kosa',
    '👩🏽‍🦳' => 'žena: maslinasta boja kože i sijeda kosa',
    '👩🏾‍🦳' => 'žena: smeđa boja kože i sijeda kosa',
    '👩🏿‍🦳' => 'žena: tamno smeđa boja kože i sijeda kosa',
    '👩🏻‍🦲' => 'žena: svijetla boja kože i bez kose',
    '👩🏼‍🦲' => 'žena: svijetlo maslinasta boja kože i bez kose',
    '👩🏽‍🦲' => 'žena: maslinasta boja kože i bez kose',
    '👩🏾‍🦲' => 'žena: smeđa boja kože i bez kose',
    '👩🏿‍🦲' => 'žena: tamno smeđa boja kože i bez kose',
    '🙍🏻‍♂' => 'namršteni muškarac: svijetla boja kože',
    '🙍🏼‍♂' => 'namršteni muškarac: svijetlo maslinasta boja kože',
    '🙍🏽‍♂' => 'namršteni muškarac: maslinasta boja kože',
    '🙍🏾‍♂' => 'namršteni muškarac: smeđa boja kože',
    '🙍🏿‍♂' => 'namršteni muškarac: tamno smeđa boja kože',
    '🙍🏻‍♀' => 'namrštena žena: svijetla boja kože',
    '🙍🏼‍♀' => 'namrštena žena: svijetlo maslinasta boja kože',
    '🙍🏽‍♀' => 'namrštena žena: maslinasta boja kože',
    '🙍🏾‍♀' => 'namrštena žena: smeđa boja kože',
    '🙍🏿‍♀' => 'namrštena žena: tamno smeđa boja kože',
    '🙎🏻‍♂' => 'nadureni muškarac: svijetla boja kože',
    '🙎🏼‍♂' => 'nadureni muškarac: svijetlo maslinasta boja kože',
    '🙎🏽‍♂' => 'nadureni muškarac: maslinasta boja kože',
    '🙎🏾‍♂' => 'nadureni muškarac: smeđa boja kože',
    '🙎🏿‍♂' => 'nadureni muškarac: tamno smeđa boja kože',
    '🙎🏻‍♀' => 'nadurena žena: svijetla boja kože',
    '🙎🏼‍♀' => 'nadurena žena: svijetlo maslinasta boja kože',
    '🙎🏽‍♀' => 'nadurena žena: maslinasta boja kože',
    '🙎🏾‍♀' => 'nadurena žena: smeđa boja kože',
    '🙎🏿‍♀' => 'nadurena žena: tamno smeđa boja kože',
    '🙅🏻‍♂' => 'muškarac pokazuje "ne": svijetla boja kože',
    '🙅🏼‍♂' => 'muškarac pokazuje "ne": svijetlo maslinasta boja kože',
    '🙅🏽‍♂' => 'muškarac pokazuje "ne": maslinasta boja kože',
    '🙅🏾‍♂' => 'muškarac pokazuje "ne": smeđa boja kože',
    '🙅🏿‍♂' => 'muškarac pokazuje "ne": tamno smeđa boja kože',
    '🙅🏻‍♀' => 'žena pokazuje "ne": svijetla boja kože',
    '🙅🏼‍♀' => 'žena pokazuje "ne": svijetlo maslinasta boja kože',
    '🙅🏽‍♀' => 'žena pokazuje "ne": maslinasta boja kože',
    '🙅🏾‍♀' => 'žena pokazuje "ne": smeđa boja kože',
    '🙅🏿‍♀' => 'žena pokazuje "ne": tamno smeđa boja kože',
    '🙆🏻‍♂' => 'muškarac pokazuje "u redu": svijetla boja kože',
    '🙆🏼‍♂' => 'muškarac pokazuje "u redu": svijetlo maslinasta boja kože',
    '🙆🏽‍♂' => 'muškarac pokazuje "u redu": maslinasta boja kože',
    '🙆🏾‍♂' => 'muškarac pokazuje "u redu": smeđa boja kože',
    '🙆🏿‍♂' => 'muškarac pokazuje "u redu": tamno smeđa boja kože',
    '🙆🏻‍♀' => 'žena pokazuje "u redu": svijetla boja kože',
    '🙆🏼‍♀' => 'žena pokazuje "u redu": svijetlo maslinasta boja kože',
    '🙆🏽‍♀' => 'žena pokazuje "u redu": maslinasta boja kože',
    '🙆🏾‍♀' => 'žena pokazuje "u redu": smeđa boja kože',
    '🙆🏿‍♀' => 'žena pokazuje "u redu": tamno smeđa boja kože',
    '💁🏻‍♂' => 'muškarac s nagnutim dlanom: svijetla boja kože',
    '💁🏼‍♂' => 'muškarac s nagnutim dlanom: svijetlo maslinasta boja kože',
    '💁🏽‍♂' => 'muškarac s nagnutim dlanom: maslinasta boja kože',
    '💁🏾‍♂' => 'muškarac s nagnutim dlanom: smeđa boja kože',
    '💁🏿‍♂' => 'muškarac s nagnutim dlanom: tamno smeđa boja kože',
    '💁🏻‍♀' => 'žena s nagnutim dlanom: svijetla boja kože',
    '💁🏼‍♀' => 'žena s nagnutim dlanom: svijetlo maslinasta boja kože',
    '💁🏽‍♀' => 'žena s nagnutim dlanom: maslinasta boja kože',
    '💁🏾‍♀' => 'žena s nagnutim dlanom: smeđa boja kože',
    '💁🏿‍♀' => 'žena s nagnutim dlanom: tamno smeđa boja kože',
    '🙋🏻‍♂' => 'muškarac podiže ruku: svijetla boja kože',
    '🙋🏼‍♂' => 'muškarac podiže ruku: svijetlo maslinasta boja kože',
    '🙋🏽‍♂' => 'muškarac podiže ruku: maslinasta boja kože',
    '🙋🏾‍♂' => 'muškarac podiže ruku: smeđa boja kože',
    '🙋🏿‍♂' => 'muškarac podiže ruku: tamno smeđa boja kože',
    '🙋🏻‍♀' => 'žena podiže ruku: svijetla boja kože',
    '🙋🏼‍♀' => 'žena podiže ruku: svijetlo maslinasta boja kože',
    '🙋🏽‍♀' => 'žena podiže ruku: maslinasta boja kože',
    '🙋🏾‍♀' => 'žena podiže ruku: smeđa boja kože',
    '🙋🏿‍♀' => 'žena podiže ruku: tamno smeđa boja kože',
    '🧏🏻‍♂' => 'gluhi muškarac: svijetla boja kože',
    '🧏🏼‍♂' => 'gluhi muškarac: svijetlo maslinasta boja kože',
    '🧏🏽‍♂' => 'gluhi muškarac: maslinasta boja kože',
    '🧏🏾‍♂' => 'gluhi muškarac: smeđa boja kože',
    '🧏🏿‍♂' => 'gluhi muškarac: tamno smeđa boja kože',
    '🧏🏻‍♀' => 'gluha žena: svijetla boja kože',
    '🧏🏼‍♀' => 'gluha žena: svijetlo maslinasta boja kože',
    '🧏🏽‍♀' => 'gluha žena: maslinasta boja kože',
    '🧏🏾‍♀' => 'gluha žena: smeđa boja kože',
    '🧏🏿‍♀' => 'gluha žena: tamno smeđa boja kože',
    '🙇🏻‍♂' => 'muškarac u dubokom naklonu: svijetla boja kože',
    '🙇🏼‍♂' => 'muškarac u dubokom naklonu: svijetlo maslinasta boja kože',
    '🙇🏽‍♂' => 'muškarac u dubokom naklonu: maslinasta boja kože',
    '🙇🏾‍♂' => 'muškarac u dubokom naklonu: smeđa boja kože',
    '🙇🏿‍♂' => 'muškarac u dubokom naklonu: tamno smeđa boja kože',
    '🙇🏻‍♀' => 'žena u dubokom naklonu: svijetla boja kože',
    '🙇🏼‍♀' => 'žena u dubokom naklonu: svijetlo maslinasta boja kože',
    '🙇🏽‍♀' => 'žena u dubokom naklonu: maslinasta boja kože',
    '🙇🏾‍♀' => 'žena u dubokom naklonu: smeđa boja kože',
    '🙇🏿‍♀' => 'žena u dubokom naklonu: tamno smeđa boja kože',
    '🤦🏻‍♂' => 'muškarac lupa dlanom o čelo: svijetla boja kože',
    '🤦🏼‍♂' => 'muškarac lupa dlanom o čelo: svijetlo maslinasta boja kože',
    '🤦🏽‍♂' => 'muškarac lupa dlanom o čelo: maslinasta boja kože',
    '🤦🏾‍♂' => 'muškarac lupa dlanom o čelo: smeđa boja kože',
    '🤦🏿‍♂' => 'muškarac lupa dlanom o čelo: tamno smeđa boja kože',
    '🤦🏻‍♀' => 'žena lupa dlanom o čelo: svijetla boja kože',
    '🤦🏼‍♀' => 'žena lupa dlanom o čelo: svijetlo maslinasta boja kože',
    '🤦🏽‍♀' => 'žena lupa dlanom o čelo: maslinasta boja kože',
    '🤦🏾‍♀' => 'žena lupa dlanom o čelo: smeđa boja kože',
    '🤦🏿‍♀' => 'žena lupa dlanom o čelo: tamno smeđa boja kože',
    '🤷🏻‍♂' => 'muškarac sliježe ramenima: svijetla boja kože',
    '🤷🏼‍♂' => 'muškarac sliježe ramenima: svijetlo maslinasta boja kože',
    '🤷🏽‍♂' => 'muškarac sliježe ramenima: maslinasta boja kože',
    '🤷🏾‍♂' => 'muškarac sliježe ramenima: smeđa boja kože',
    '🤷🏿‍♂' => 'muškarac sliježe ramenima: tamno smeđa boja kože',
    '🤷🏻‍♀' => 'žena sliježe ramenima: svijetla boja kože',
    '🤷🏼‍♀' => 'žena sliježe ramenima: svijetlo maslinasta boja kože',
    '🤷🏽‍♀' => 'žena sliježe ramenima: maslinasta boja kože',
    '🤷🏾‍♀' => 'žena sliježe ramenima: smeđa boja kože',
    '🤷🏿‍♀' => 'žena sliježe ramenima: tamno smeđa boja kože',
    '🧑🏻‍⚕' => 'zdravstveni djelatnik: svijetla boja kože',
    '🧑🏼‍⚕' => 'zdravstveni djelatnik: svijetlo maslinasta boja kože',
    '🧑🏽‍⚕' => 'zdravstveni djelatnik: maslinasta boja kože',
    '🧑🏾‍⚕' => 'zdravstveni djelatnik: smeđa boja kože',
    '🧑🏿‍⚕' => 'zdravstveni djelatnik: tamno smeđa boja kože',
    '👨🏻‍⚕' => 'liječnik: svijetla boja kože',
    '👨🏼‍⚕' => 'liječnik: svijetlo maslinasta boja kože',
    '👨🏽‍⚕' => 'liječnik: maslinasta boja kože',
    '👨🏾‍⚕' => 'liječnik: smeđa boja kože',
    '👨🏿‍⚕' => 'liječnik: tamno smeđa boja kože',
    '👩🏻‍⚕' => 'liječnica: svijetla boja kože',
    '👩🏼‍⚕' => 'liječnica: svijetlo maslinasta boja kože',
    '👩🏽‍⚕' => 'liječnica: maslinasta boja kože',
    '👩🏾‍⚕' => 'liječnica: smeđa boja kože',
    '👩🏿‍⚕' => 'liječnica: tamno smeđa boja kože',
    '🧑🏻‍🎓' => 'diplomant: svijetla boja kože',
    '🧑🏼‍🎓' => 'diplomant: svijetlo maslinasta boja kože',
    '🧑🏽‍🎓' => 'diplomant: maslinasta boja kože',
    '🧑🏾‍🎓' => 'diplomant: smeđa boja kože',
    '🧑🏿‍🎓' => 'diplomant: tamno smeđa boja kože',
    '👨🏻‍🎓' => 'student: svijetla boja kože',
    '👨🏼‍🎓' => 'student: svijetlo maslinasta boja kože',
    '👨🏽‍🎓' => 'student: maslinasta boja kože',
    '👨🏾‍🎓' => 'student: smeđa boja kože',
    '👨🏿‍🎓' => 'student: tamno smeđa boja kože',
    '👩🏻‍🎓' => 'studentica: svijetla boja kože',
    '👩🏼‍🎓' => 'studentica: svijetlo maslinasta boja kože',
    '👩🏽‍🎓' => 'studentica: maslinasta boja kože',
    '👩🏾‍🎓' => 'studentica: smeđa boja kože',
    '👩🏿‍🎓' => 'studentica: tamno smeđa boja kože',
    '🧑🏻‍🏫' => 'profesor: svijetla boja kože',
    '🧑🏼‍🏫' => 'profesor: svijetlo maslinasta boja kože',
    '🧑🏽‍🏫' => 'profesor: maslinasta boja kože',
    '🧑🏾‍🏫' => 'profesor: smeđa boja kože',
    '🧑🏿‍🏫' => 'profesor: tamno smeđa boja kože',
    '👨🏻‍🏫' => 'učitelj: svijetla boja kože',
    '👨🏼‍🏫' => 'učitelj: svijetlo maslinasta boja kože',
    '👨🏽‍🏫' => 'učitelj: maslinasta boja kože',
    '👨🏾‍🏫' => 'učitelj: smeđa boja kože',
    '👨🏿‍🏫' => 'učitelj: tamno smeđa boja kože',
    '👩🏻‍🏫' => 'učiteljica: svijetla boja kože',
    '👩🏼‍🏫' => 'učiteljica: svijetlo maslinasta boja kože',
    '👩🏽‍🏫' => 'učiteljica: maslinasta boja kože',
    '👩🏾‍🏫' => 'učiteljica: smeđa boja kože',
    '👩🏿‍🏫' => 'učiteljica: tamno smeđa boja kože',
    '🧑🏻‍⚖' => 'arbitar: svijetla boja kože',
    '🧑🏼‍⚖' => 'arbitar: svijetlo maslinasta boja kože',
    '🧑🏽‍⚖' => 'arbitar: maslinasta boja kože',
    '🧑🏾‍⚖' => 'arbitar: smeđa boja kože',
    '🧑🏿‍⚖' => 'arbitar: tamno smeđa boja kože',
    '👨🏻‍⚖' => 'sudac: svijetla boja kože',
    '👨🏼‍⚖' => 'sudac: svijetlo maslinasta boja kože',
    '👨🏽‍⚖' => 'sudac: maslinasta boja kože',
    '👨🏾‍⚖' => 'sudac: smeđa boja kože',
    '👨🏿‍⚖' => 'sudac: tamno smeđa boja kože',
    '👩🏻‍⚖' => 'sutkinja: svijetla boja kože',
    '👩🏼‍⚖' => 'sutkinja: svijetlo maslinasta boja kože',
    '👩🏽‍⚖' => 'sutkinja: maslinasta boja kože',
    '👩🏾‍⚖' => 'sutkinja: smeđa boja kože',
    '👩🏿‍⚖' => 'sutkinja: tamno smeđa boja kože',
    '🧑🏻‍🌾' => 'farmer: svijetla boja kože',
    '🧑🏼‍🌾' => 'farmer: svijetlo maslinasta boja kože',
    '🧑🏽‍🌾' => 'farmer: maslinasta boja kože',
    '🧑🏾‍🌾' => 'farmer: smeđa boja kože',
    '🧑🏿‍🌾' => 'farmer: tamno smeđa boja kože',
    '👨🏻‍🌾' => 'poljoprivrednik: svijetla boja kože',
    '👨🏼‍🌾' => 'poljoprivrednik: svijetlo maslinasta boja kože',
    '👨🏽‍🌾' => 'poljoprivrednik: maslinasta boja kože',
    '👨🏾‍🌾' => 'poljoprivrednik: smeđa boja kože',
    '👨🏿‍🌾' => 'poljoprivrednik: tamno smeđa boja kože',
    '👩🏻‍🌾' => 'poljoprivrednica: svijetla boja kože',
    '👩🏼‍🌾' => 'poljoprivrednica: svijetlo maslinasta boja kože',
    '👩🏽‍🌾' => 'poljoprivrednica: maslinasta boja kože',
    '👩🏾‍🌾' => 'poljoprivrednica: smeđa boja kože',
    '👩🏿‍🌾' => 'poljoprivrednica: tamno smeđa boja kože',
    '🧑🏻‍🍳' => 'šef kuhinje: svijetla boja kože',
    '🧑🏼‍🍳' => 'šef kuhinje: svijetlo maslinasta boja kože',
    '🧑🏽‍🍳' => 'šef kuhinje: maslinasta boja kože',
    '🧑🏾‍🍳' => 'šef kuhinje: smeđa boja kože',
    '🧑🏿‍🍳' => 'šef kuhinje: tamno smeđa boja kože',
    '👨🏻‍🍳' => 'kuhar: svijetla boja kože',
    '👨🏼‍🍳' => 'kuhar: svijetlo maslinasta boja kože',
    '👨🏽‍🍳' => 'kuhar: maslinasta boja kože',
    '👨🏾‍🍳' => 'kuhar: smeđa boja kože',
    '👨🏿‍🍳' => 'kuhar: tamno smeđa boja kože',
    '👩🏻‍🍳' => 'kuharica: svijetla boja kože',
    '👩🏼‍🍳' => 'kuharica: svijetlo maslinasta boja kože',
    '👩🏽‍🍳' => 'kuharica: maslinasta boja kože',
    '👩🏾‍🍳' => 'kuharica: smeđa boja kože',
    '👩🏿‍🍳' => 'kuharica: tamno smeđa boja kože',
    '🧑🏻‍🔧' => 'serviser: svijetla boja kože',
    '🧑🏼‍🔧' => 'serviser: svijetlo maslinasta boja kože',
    '🧑🏽‍🔧' => 'serviser: maslinasta boja kože',
    '🧑🏾‍🔧' => 'serviser: smeđa boja kože',
    '🧑🏿‍🔧' => 'serviser: tamno smeđa boja kože',
    '👨🏻‍🔧' => 'mehaničar: svijetla boja kože',
    '👨🏼‍🔧' => 'mehaničar: svijetlo maslinasta boja kože',
    '👨🏽‍🔧' => 'mehaničar: maslinasta boja kože',
    '👨🏾‍🔧' => 'mehaničar: smeđa boja kože',
    '👨🏿‍🔧' => 'mehaničar: tamno smeđa boja kože',
    '👩🏻‍🔧' => 'mehaničarka: svijetla boja kože',
    '👩🏼‍🔧' => 'mehaničarka: svijetlo maslinasta boja kože',
    '👩🏽‍🔧' => 'mehaničarka: maslinasta boja kože',
    '👩🏾‍🔧' => 'mehaničarka: smeđa boja kože',
    '👩🏿‍🔧' => 'mehaničarka: tamno smeđa boja kože',
    '🧑🏻‍🏭' => 'radnik u tvornici: svijetla boja kože',
    '🧑🏼‍🏭' => 'radnik u tvornici: svijetlo maslinasta boja kože',
    '🧑🏽‍🏭' => 'radnik u tvornici: maslinasta boja kože',
    '🧑🏾‍🏭' => 'radnik u tvornici: smeđa boja kože',
    '🧑🏿‍🏭' => 'radnik u tvornici: tamno smeđa boja kože',
    '👨🏻‍🏭' => 'tvornički radnik: svijetla boja kože',
    '👨🏼‍🏭' => 'tvornički radnik: svijetlo maslinasta boja kože',
    '👨🏽‍🏭' => 'tvornički radnik: maslinasta boja kože',
    '👨🏾‍🏭' => 'tvornički radnik: smeđa boja kože',
    '👨🏿‍🏭' => 'tvornički radnik: tamno smeđa boja kože',
    '👩🏻‍🏭' => 'tvornička radnica: svijetla boja kože',
    '👩🏼‍🏭' => 'tvornička radnica: svijetlo maslinasta boja kože',
    '👩🏽‍🏭' => 'tvornička radnica: maslinasta boja kože',
    '👩🏾‍🏭' => 'tvornička radnica: smeđa boja kože',
    '👩🏿‍🏭' => 'tvornička radnica: tamno smeđa boja kože',
    '🧑🏻‍💼' => 'uredski djelatnik: svijetla boja kože',
    '🧑🏼‍💼' => 'uredski djelatnik: svijetlo maslinasta boja kože',
    '🧑🏽‍💼' => 'uredski djelatnik: maslinasta boja kože',
    '🧑🏾‍💼' => 'uredski djelatnik: smeđa boja kože',
    '🧑🏿‍💼' => 'uredski djelatnik: tamno smeđa boja kože',
    '👨🏻‍💼' => 'službenik: svijetla boja kože',
    '👨🏼‍💼' => 'službenik: svijetlo maslinasta boja kože',
    '👨🏽‍💼' => 'službenik: maslinasta boja kože',
    '👨🏾‍💼' => 'službenik: smeđa boja kože',
    '👨🏿‍💼' => 'službenik: tamno smeđa boja kože',
    '👩🏻‍💼' => 'službenica: svijetla boja kože',
    '👩🏼‍💼' => 'službenica: svijetlo maslinasta boja kože',
    '👩🏽‍💼' => 'službenica: maslinasta boja kože',
    '👩🏾‍💼' => 'službenica: smeđa boja kože',
    '👩🏿‍💼' => 'službenica: tamno smeđa boja kože',
    '🧑🏻‍🔬' => 'biokemičar: svijetla boja kože',
    '🧑🏼‍🔬' => 'biokemičar: svijetlo maslinasta boja kože',
    '🧑🏽‍🔬' => 'biokemičar: maslinasta boja kože',
    '🧑🏾‍🔬' => 'biokemičar: smeđa boja kože',
    '🧑🏿‍🔬' => 'biokemičar: tamno smeđa boja kože',
    '👨🏻‍🔬' => 'znanstvenik: svijetla boja kože',
    '👨🏼‍🔬' => 'znanstvenik: svijetlo maslinasta boja kože',
    '👨🏽‍🔬' => 'znanstvenik: maslinasta boja kože',
    '👨🏾‍🔬' => 'znanstvenik: smeđa boja kože',
    '👨🏿‍🔬' => 'znanstvenik: tamno smeđa boja kože',
    '👩🏻‍🔬' => 'znanstvenica: svijetla boja kože',
    '👩🏼‍🔬' => 'znanstvenica: svijetlo maslinasta boja kože',
    '👩🏽‍🔬' => 'znanstvenica: maslinasta boja kože',
    '👩🏾‍🔬' => 'znanstvenica: smeđa boja kože',
    '👩🏿‍🔬' => 'znanstvenica: tamno smeđa boja kože',
    '🧑🏻‍💻' => 'tehnološki djelatnik: svijetla boja kože',
    '🧑🏼‍💻' => 'tehnološki djelatnik: svijetlo maslinasta boja kože',
    '🧑🏽‍💻' => 'tehnološki djelatnik: maslinasta boja kože',
    '🧑🏾‍💻' => 'tehnološki djelatnik: smeđa boja kože',
    '🧑🏿‍💻' => 'tehnološki djelatnik: tamno smeđa boja kože',
    '👨🏻‍💻' => 'tehnološki inženjer: svijetla boja kože',
    '👨🏼‍💻' => 'tehnološki inženjer: svijetlo maslinasta boja kože',
    '👨🏽‍💻' => 'tehnološki inženjer: maslinasta boja kože',
    '👨🏾‍💻' => 'tehnološki inženjer: smeđa boja kože',
    '👨🏿‍💻' => 'tehnološki inženjer: tamno smeđa boja kože',
    '👩🏻‍💻' => 'tehnološka inženjerka: svijetla boja kože',
    '👩🏼‍💻' => 'tehnološka inženjerka: svijetlo maslinasta boja kože',
    '👩🏽‍💻' => 'tehnološka inženjerka: maslinasta boja kože',
    '👩🏾‍💻' => 'tehnološka inženjerka: smeđa boja kože',
    '👩🏿‍💻' => 'tehnološka inženjerka: tamno smeđa boja kože',
    '🧑🏻‍🎤' => 'izvođač: svijetla boja kože',
    '🧑🏼‍🎤' => 'izvođač: svijetlo maslinasta boja kože',
    '🧑🏽‍🎤' => 'izvođač: maslinasta boja kože',
    '🧑🏾‍🎤' => 'izvođač: smeđa boja kože',
    '🧑🏿‍🎤' => 'izvođač: tamno smeđa boja kože',
    '👨🏻‍🎤' => 'pjevač: svijetla boja kože',
    '👨🏼‍🎤' => 'pjevač: svijetlo maslinasta boja kože',
    '👨🏽‍🎤' => 'pjevač: maslinasta boja kože',
    '👨🏾‍🎤' => 'pjevač: smeđa boja kože',
    '👨🏿‍🎤' => 'pjevač: tamno smeđa boja kože',
    '👩🏻‍🎤' => 'pjevačica: svijetla boja kože',
    '👩🏼‍🎤' => 'pjevačica: svijetlo maslinasta boja kože',
    '👩🏽‍🎤' => 'pjevačica: maslinasta boja kože',
    '👩🏾‍🎤' => 'pjevačica: smeđa boja kože',
    '👩🏿‍🎤' => 'pjevačica: tamno smeđa boja kože',
    '🧑🏻‍🎨' => 'slikar: svijetla boja kože',
    '🧑🏼‍🎨' => 'slikar: svijetlo maslinasta boja kože',
    '🧑🏽‍🎨' => 'slikar: maslinasta boja kože',
    '🧑🏾‍🎨' => 'slikar: smeđa boja kože',
    '🧑🏿‍🎨' => 'slikar: tamno smeđa boja kože',
    '👨🏻‍🎨' => 'umjetnik: svijetla boja kože',
    '👨🏼‍🎨' => 'umjetnik: svijetlo maslinasta boja kože',
    '👨🏽‍🎨' => 'umjetnik: maslinasta boja kože',
    '👨🏾‍🎨' => 'umjetnik: smeđa boja kože',
    '👨🏿‍🎨' => 'umjetnik: tamno smeđa boja kože',
    '👩🏻‍🎨' => 'umjetnica: svijetla boja kože',
    '👩🏼‍🎨' => 'umjetnica: svijetlo maslinasta boja kože',
    '👩🏽‍🎨' => 'umjetnica: maslinasta boja kože',
    '👩🏾‍🎨' => 'umjetnica: smeđa boja kože',
    '👩🏿‍🎨' => 'umjetnica: tamno smeđa boja kože',
    '🧑🏻‍✈' => 'pilot zrakoplova: svijetla boja kože',
    '🧑🏼‍✈' => 'pilot zrakoplova: svijetlo maslinasta boja kože',
    '🧑🏽‍✈' => 'pilot zrakoplova: maslinasta boja kože',
    '🧑🏾‍✈' => 'pilot zrakoplova: smeđa boja kože',
    '🧑🏿‍✈' => 'pilot zrakoplova: tamno smeđa boja kože',
    '👨🏻‍✈' => 'pilot: svijetla boja kože',
    '👨🏼‍✈' => 'pilot: svijetlo maslinasta boja kože',
    '👨🏽‍✈' => 'pilot: maslinasta boja kože',
    '👨🏾‍✈' => 'pilot: smeđa boja kože',
    '👨🏿‍✈' => 'pilot: tamno smeđa boja kože',
    '👩🏻‍✈' => 'pilotkinja: svijetla boja kože',
    '👩🏼‍✈' => 'pilotkinja: svijetlo maslinasta boja kože',
    '👩🏽‍✈' => 'pilotkinja: maslinasta boja kože',
    '👩🏾‍✈' => 'pilotkinja: smeđa boja kože',
    '👩🏿‍✈' => 'pilotkinja: tamno smeđa boja kože',
    '🧑🏻‍🚀' => 'kozmonaut: svijetla boja kože',
    '🧑🏼‍🚀' => 'kozmonaut: svijetlo maslinasta boja kože',
    '🧑🏽‍🚀' => 'kozmonaut: maslinasta boja kože',
    '🧑🏾‍🚀' => 'kozmonaut: smeđa boja kože',
    '🧑🏿‍🚀' => 'kozmonaut: tamno smeđa boja kože',
    '👨🏻‍🚀' => 'astronaut: svijetla boja kože',
    '👨🏼‍🚀' => 'astronaut: svijetlo maslinasta boja kože',
    '👨🏽‍🚀' => 'astronaut: maslinasta boja kože',
    '👨🏾‍🚀' => 'astronaut: smeđa boja kože',
    '👨🏿‍🚀' => 'astronaut: tamno smeđa boja kože',
    '👩🏻‍🚀' => 'astronautkinja: svijetla boja kože',
    '👩🏼‍🚀' => 'astronautkinja: svijetlo maslinasta boja kože',
    '👩🏽‍🚀' => 'astronautkinja: maslinasta boja kože',
    '👩🏾‍🚀' => 'astronautkinja: smeđa boja kože',
    '👩🏿‍🚀' => 'astronautkinja: tamno smeđa boja kože',
    '🧑🏻‍🚒' => 'vatrogasni djelatnik: svijetla boja kože',
    '🧑🏼‍🚒' => 'vatrogasni djelatnik: svijetlo maslinasta boja kože',
    '🧑🏽‍🚒' => 'vatrogasni djelatnik: maslinasta boja kože',
    '🧑🏾‍🚒' => 'vatrogasni djelatnik: smeđa boja kože',
    '🧑🏿‍🚒' => 'vatrogasni djelatnik: tamno smeđa boja kože',
    '👨🏻‍🚒' => 'vatrogasac: svijetla boja kože',
    '👨🏼‍🚒' => 'vatrogasac: svijetlo maslinasta boja kože',
    '👨🏽‍🚒' => 'vatrogasac: maslinasta boja kože',
    '👨🏾‍🚒' => 'vatrogasac: smeđa boja kože',
    '👨🏿‍🚒' => 'vatrogasac: tamno smeđa boja kože',
    '👩🏻‍🚒' => 'vatrogaskinja: svijetla boja kože',
    '👩🏼‍🚒' => 'vatrogaskinja: svijetlo maslinasta boja kože',
    '👩🏽‍🚒' => 'vatrogaskinja: maslinasta boja kože',
    '👩🏾‍🚒' => 'vatrogaskinja: smeđa boja kože',
    '👩🏿‍🚒' => 'vatrogaskinja: tamno smeđa boja kože',
    '👮🏻‍♂' => 'policijski djelatnik: svijetla boja kože',
    '👮🏼‍♂' => 'policijski djelatnik: svijetlo maslinasta boja kože',
    '👮🏽‍♂' => 'policijski djelatnik: maslinasta boja kože',
    '👮🏾‍♂' => 'policijski djelatnik: smeđa boja kože',
    '👮🏿‍♂' => 'policijski djelatnik: tamno smeđa boja kože',
    '👮🏻‍♀' => 'policajka: svijetla boja kože',
    '👮🏼‍♀' => 'policajka: svijetlo maslinasta boja kože',
    '👮🏽‍♀' => 'policajka: maslinasta boja kože',
    '👮🏾‍♀' => 'policajka: smeđa boja kože',
    '👮🏿‍♀' => 'policajka: tamno smeđa boja kože',
    '🕵🏻‍♂' => 'istražitelj: svijetla boja kože',
    '🕵🏼‍♂' => 'istražitelj: svijetlo maslinasta boja kože',
    '🕵🏽‍♂' => 'istražitelj: maslinasta boja kože',
    '🕵🏾‍♂' => 'istražitelj: smeđa boja kože',
    '🕵🏿‍♂' => 'istražitelj: tamno smeđa boja kože',
    '🕵🏻‍♀' => 'istražiteljica: svijetla boja kože',
    '🕵🏼‍♀' => 'istražiteljica: svijetlo maslinasta boja kože',
    '🕵🏽‍♀' => 'istražiteljica: maslinasta boja kože',
    '🕵🏾‍♀' => 'istražiteljica: smeđa boja kože',
    '🕵🏿‍♀' => 'istražiteljica: tamno smeđa boja kože',
    '💂🏻‍♂' => 'stražar: svijetla boja kože',
    '💂🏼‍♂' => 'stražar: svijetlo maslinasta boja kože',
    '💂🏽‍♂' => 'stražar: maslinasta boja kože',
    '💂🏾‍♂' => 'stražar: smeđa boja kože',
    '💂🏿‍♂' => 'stražar: tamno smeđa boja kože',
    '💂🏻‍♀' => 'stražarica: svijetla boja kože',
    '💂🏼‍♀' => 'stražarica: svijetlo maslinasta boja kože',
    '💂🏽‍♀' => 'stražarica: maslinasta boja kože',
    '💂🏾‍♀' => 'stražarica: smeđa boja kože',
    '💂🏿‍♀' => 'stražarica: tamno smeđa boja kože',
    '👷🏻‍♂' => 'zidar: svijetla boja kože',
    '👷🏼‍♂' => 'zidar: svijetlo maslinasta boja kože',
    '👷🏽‍♂' => 'zidar: maslinasta boja kože',
    '👷🏾‍♂' => 'zidar: smeđa boja kože',
    '👷🏿‍♂' => 'zidar: tamno smeđa boja kože',
    '👷🏻‍♀' => 'zidarica: svijetla boja kože',
    '👷🏼‍♀' => 'zidarica: svijetlo maslinasta boja kože',
    '👷🏽‍♀' => 'zidarica: maslinasta boja kože',
    '👷🏾‍♀' => 'zidarica: smeđa boja kože',
    '👷🏿‍♀' => 'zidarica: tamno smeđa boja kože',
    '👳🏻‍♂' => 'muškarac s turbanom: svijetla boja kože',
    '👳🏼‍♂' => 'muškarac s turbanom: svijetlo maslinasta boja kože',
    '👳🏽‍♂' => 'muškarac s turbanom: maslinasta boja kože',
    '👳🏾‍♂' => 'muškarac s turbanom: smeđa boja kože',
    '👳🏿‍♂' => 'muškarac s turbanom: tamno smeđa boja kože',
    '👳🏻‍♀' => 'žena s turbanom: svijetla boja kože',
    '👳🏼‍♀' => 'žena s turbanom: svijetlo maslinasta boja kože',
    '👳🏽‍♀' => 'žena s turbanom: maslinasta boja kože',
    '👳🏾‍♀' => 'žena s turbanom: smeđa boja kože',
    '👳🏿‍♀' => 'žena s turbanom: tamno smeđa boja kože',
    '🤵🏻‍♂' => 'muškarac u smokingu: svijetla boja kože',
    '🤵🏼‍♂' => 'muškarac u smokingu: svijetlo maslinasta boja kože',
    '🤵🏽‍♂' => 'muškarac u smokingu: maslinasta boja kože',
    '🤵🏾‍♂' => 'muškarac u smokingu: smeđa boja kože',
    '🤵🏿‍♂' => 'muškarac u smokingu: tamno smeđa boja kože',
    '🤵🏻‍♀' => 'žena u smokingu: svijetla boja kože',
    '🤵🏼‍♀' => 'žena u smokingu: svijetlo maslinasta boja kože',
    '🤵🏽‍♀' => 'žena u smokingu: maslinasta boja kože',
    '🤵🏾‍♀' => 'žena u smokingu: smeđa boja kože',
    '🤵🏿‍♀' => 'žena u smokingu: tamno smeđa boja kože',
    '👰🏻‍♂' => 'muškarac s velom: svijetla boja kože',
    '👰🏼‍♂' => 'muškarac s velom: svijetlo maslinasta boja kože',
    '👰🏽‍♂' => 'muškarac s velom: maslinasta boja kože',
    '👰🏾‍♂' => 'muškarac s velom: smeđa boja kože',
    '👰🏿‍♂' => 'muškarac s velom: tamno smeđa boja kože',
    '👰🏻‍♀' => 'žena s velom: svijetla boja kože',
    '👰🏼‍♀' => 'žena s velom: svijetlo maslinasta boja kože',
    '👰🏽‍♀' => 'žena s velom: maslinasta boja kože',
    '👰🏾‍♀' => 'žena s velom: smeđa boja kože',
    '👰🏿‍♀' => 'žena s velom: tamno smeđa boja kože',
    '👩🏻‍🍼' => 'žena hrani bebu: svijetla boja kože',
    '👩🏼‍🍼' => 'žena hrani bebu: svijetlo maslinasta boja kože',
    '👩🏽‍🍼' => 'žena hrani bebu: maslinasta boja kože',
    '👩🏾‍🍼' => 'žena hrani bebu: smeđa boja kože',
    '👩🏿‍🍼' => 'žena hrani bebu: tamno smeđa boja kože',
    '👨🏻‍🍼' => 'muškarac hrani bebu: svijetla boja kože',
    '👨🏼‍🍼' => 'muškarac hrani bebu: svijetlo maslinasta boja kože',
    '👨🏽‍🍼' => 'muškarac hrani bebu: maslinasta boja kože',
    '👨🏾‍🍼' => 'muškarac hrani bebu: smeđa boja kože',
    '👨🏿‍🍼' => 'muškarac hrani bebu: tamno smeđa boja kože',
    '🧑🏻‍🍼' => 'osoba hrani bebu: svijetla boja kože',
    '🧑🏼‍🍼' => 'osoba hrani bebu: svijetlo maslinasta boja kože',
    '🧑🏽‍🍼' => 'osoba hrani bebu: maslinasta boja kože',
    '🧑🏾‍🍼' => 'osoba hrani bebu: smeđa boja kože',
    '🧑🏿‍🍼' => 'osoba hrani bebu: tamno smeđa boja kože',
    '🧑🏻‍🎄' => 'osoba Mraz: svijetla boja kože',
    '🧑🏼‍🎄' => 'osoba Mraz: svijetlo maslinasta boja kože',
    '🧑🏽‍🎄' => 'osoba Mraz: maslinasta boja kože',
    '🧑🏾‍🎄' => 'osoba Mraz: smeđa boja kože',
    '🧑🏿‍🎄' => 'osoba Mraz: tamno smeđa boja kože',
    '🦸🏻‍♂' => 'superjunak: svijetla boja kože',
    '🦸🏼‍♂' => 'superjunak: svijetlo maslinasta boja kože',
    '🦸🏽‍♂' => 'superjunak: maslinasta boja kože',
    '🦸🏾‍♂' => 'superjunak: smeđa boja kože',
    '🦸🏿‍♂' => 'superjunak: tamno smeđa boja kože',
    '🦸🏻‍♀' => 'superjunakinja: svijetla boja kože',
    '🦸🏼‍♀' => 'superjunakinja: svijetlo maslinasta boja kože',
    '🦸🏽‍♀' => 'superjunakinja: maslinasta boja kože',
    '🦸🏾‍♀' => 'superjunakinja: smeđa boja kože',
    '🦸🏿‍♀' => 'superjunakinja: tamno smeđa boja kože',
    '🦹🏻‍♂' => 'stripovski zločinac: svijetla boja kože',
    '🦹🏼‍♂' => 'stripovski zločinac: svijetlo maslinasta boja kože',
    '🦹🏽‍♂' => 'stripovski zločinac: maslinasta boja kože',
    '🦹🏾‍♂' => 'stripovski zločinac: smeđa boja kože',
    '🦹🏿‍♂' => 'stripovski zločinac: tamno smeđa boja kože',
    '🦹🏻‍♀' => 'stripovska zločinka: svijetla boja kože',
    '🦹🏼‍♀' => 'stripovska zločinka: svijetlo maslinasta boja kože',
    '🦹🏽‍♀' => 'stripovska zločinka: maslinasta boja kože',
    '🦹🏾‍♀' => 'stripovska zločinka: smeđa boja kože',
    '🦹🏿‍♀' => 'stripovska zločinka: tamno smeđa boja kože',
    '🧙🏻‍♂' => 'čarobnjak: svijetla boja kože',
    '🧙🏼‍♂' => 'čarobnjak: svijetlo maslinasta boja kože',
    '🧙🏽‍♂' => 'čarobnjak: maslinasta boja kože',
    '🧙🏾‍♂' => 'čarobnjak: smeđa boja kože',
    '🧙🏿‍♂' => 'čarobnjak: tamno smeđa boja kože',
    '🧙🏻‍♀' => 'čarobnica: svijetla boja kože',
    '🧙🏼‍♀' => 'čarobnica: svijetlo maslinasta boja kože',
    '🧙🏽‍♀' => 'čarobnica: maslinasta boja kože',
    '🧙🏾‍♀' => 'čarobnica: smeđa boja kože',
    '🧙🏿‍♀' => 'čarobnica: tamno smeđa boja kože',
    '🧚🏻‍♂' => 'kućni duh: svijetla boja kože',
    '🧚🏼‍♂' => 'kućni duh: svijetlo maslinasta boja kože',
    '🧚🏽‍♂' => 'kućni duh: maslinasta boja kože',
    '🧚🏾‍♂' => 'kućni duh: smeđa boja kože',
    '🧚🏿‍♂' => 'kućni duh: tamno smeđa boja kože',
    '🧚🏻‍♀' => 'vila: svijetla boja kože',
    '🧚🏼‍♀' => 'vila: svijetlo maslinasta boja kože',
    '🧚🏽‍♀' => 'vila: maslinasta boja kože',
    '🧚🏾‍♀' => 'vila: smeđa boja kože',
    '🧚🏿‍♀' => 'vila: tamno smeđa boja kože',
    '🧛🏻‍♂' => 'vampir: svijetla boja kože',
    '🧛🏼‍♂' => 'vampir: svijetlo maslinasta boja kože',
    '🧛🏽‍♂' => 'vampir: maslinasta boja kože',
    '🧛🏾‍♂' => 'vampir: smeđa boja kože',
    '🧛🏿‍♂' => 'vampir: tamno smeđa boja kože',
    '🧛🏻‍♀' => 'vampirica: svijetla boja kože',
    '🧛🏼‍♀' => 'vampirica: svijetlo maslinasta boja kože',
    '🧛🏽‍♀' => 'vampirica: maslinasta boja kože',
    '🧛🏾‍♀' => 'vampirica: smeđa boja kože',
    '🧛🏿‍♀' => 'vampirica: tamno smeđa boja kože',
    '🧜🏻‍♂' => 'muška sirena: svijetla boja kože',
    '🧜🏼‍♂' => 'muška sirena: svijetlo maslinasta boja kože',
    '🧜🏽‍♂' => 'muška sirena: maslinasta boja kože',
    '🧜🏾‍♂' => 'muška sirena: smeđa boja kože',
    '🧜🏿‍♂' => 'muška sirena: tamno smeđa boja kože',
    '🧜🏻‍♀' => 'sirena: svijetla boja kože',
    '🧜🏼‍♀' => 'sirena: svijetlo maslinasta boja kože',
    '🧜🏽‍♀' => 'sirena: maslinasta boja kože',
    '🧜🏾‍♀' => 'sirena: smeđa boja kože',
    '🧜🏿‍♀' => 'sirena: tamno smeđa boja kože',
    '🧝🏻‍♂' => 'vilenjak: svijetla boja kože',
    '🧝🏼‍♂' => 'vilenjak: svijetlo maslinasta boja kože',
    '🧝🏽‍♂' => 'vilenjak: maslinasta boja kože',
    '🧝🏾‍♂' => 'vilenjak: smeđa boja kože',
    '🧝🏿‍♂' => 'vilenjak: tamno smeđa boja kože',
    '🧝🏻‍♀' => 'vilenjakinja: svijetla boja kože',
    '🧝🏼‍♀' => 'vilenjakinja: svijetlo maslinasta boja kože',
    '🧝🏽‍♀' => 'vilenjakinja: maslinasta boja kože',
    '🧝🏾‍♀' => 'vilenjakinja: smeđa boja kože',
    '🧝🏿‍♀' => 'vilenjakinja: tamno smeđa boja kože',
    '💆🏻‍♂' => 'muškarac na masaži: svijetla boja kože',
    '💆🏼‍♂' => 'muškarac na masaži: svijetlo maslinasta boja kože',
    '💆🏽‍♂' => 'muškarac na masaži: maslinasta boja kože',
    '💆🏾‍♂' => 'muškarac na masaži: smeđa boja kože',
    '💆🏿‍♂' => 'muškarac na masaži: tamno smeđa boja kože',
    '💆🏻‍♀' => 'žena na masaži: svijetla boja kože',
    '💆🏼‍♀' => 'žena na masaži: svijetlo maslinasta boja kože',
    '💆🏽‍♀' => 'žena na masaži: maslinasta boja kože',
    '💆🏾‍♀' => 'žena na masaži: smeđa boja kože',
    '💆🏿‍♀' => 'žena na masaži: tamno smeđa boja kože',
    '💇🏻‍♂' => 'muškarac na šišanju: svijetla boja kože',
    '💇🏼‍♂' => 'muškarac na šišanju: svijetlo maslinasta boja kože',
    '💇🏽‍♂' => 'muškarac na šišanju: maslinasta boja kože',
    '💇🏾‍♂' => 'muškarac na šišanju: smeđa boja kože',
    '💇🏿‍♂' => 'muškarac na šišanju: tamno smeđa boja kože',
    '💇🏻‍♀' => 'žena na šišanju: svijetla boja kože',
    '💇🏼‍♀' => 'žena na šišanju: svijetlo maslinasta boja kože',
    '💇🏽‍♀' => 'žena na šišanju: maslinasta boja kože',
    '💇🏾‍♀' => 'žena na šišanju: smeđa boja kože',
    '💇🏿‍♀' => 'žena na šišanju: tamno smeđa boja kože',
    '🚶🏻‍♂' => 'muškarac hoda: svijetla boja kože',
    '🚶🏼‍♂' => 'muškarac hoda: svijetlo maslinasta boja kože',
    '🚶🏽‍♂' => 'muškarac hoda: maslinasta boja kože',
    '🚶🏾‍♂' => 'muškarac hoda: smeđa boja kože',
    '🚶🏿‍♂' => 'muškarac hoda: tamno smeđa boja kože',
    '🚶🏻‍♀' => 'žena hoda: svijetla boja kože',
    '🚶🏼‍♀' => 'žena hoda: svijetlo maslinasta boja kože',
    '🚶🏽‍♀' => 'žena hoda: maslinasta boja kože',
    '🚶🏾‍♀' => 'žena hoda: smeđa boja kože',
    '🚶🏿‍♀' => 'žena hoda: tamno smeđa boja kože',
    '🚶🏻‍➡' => 'pješak: svijetla boja kože i udesno',
    '🚶🏼‍➡' => 'pješak: svijetlo maslinasta boja kože i udesno',
    '🚶🏽‍➡' => 'pješak: maslinasta boja kože i udesno',
    '🚶🏾‍➡' => 'pješak: smeđa boja kože i udesno',
    '🚶🏿‍➡' => 'pješak: tamno smeđa boja kože i udesno',
    '🧍🏻‍♂' => 'muškarac stoji: svijetla boja kože',
    '🧍🏼‍♂' => 'muškarac stoji: svijetlo maslinasta boja kože',
    '🧍🏽‍♂' => 'muškarac stoji: maslinasta boja kože',
    '🧍🏾‍♂' => 'muškarac stoji: smeđa boja kože',
    '🧍🏿‍♂' => 'muškarac stoji: tamno smeđa boja kože',
    '🧍🏻‍♀' => 'žena stoji: svijetla boja kože',
    '🧍🏼‍♀' => 'žena stoji: svijetlo maslinasta boja kože',
    '🧍🏽‍♀' => 'žena stoji: maslinasta boja kože',
    '🧍🏾‍♀' => 'žena stoji: smeđa boja kože',
    '🧍🏿‍♀' => 'žena stoji: tamno smeđa boja kože',
    '🧎🏻‍♂' => 'muškarac kleči: svijetla boja kože',
    '🧎🏼‍♂' => 'muškarac kleči: svijetlo maslinasta boja kože',
    '🧎🏽‍♂' => 'muškarac kleči: maslinasta boja kože',
    '🧎🏾‍♂' => 'muškarac kleči: smeđa boja kože',
    '🧎🏿‍♂' => 'muškarac kleči: tamno smeđa boja kože',
    '🧎🏻‍♀' => 'žena kleči: svijetla boja kože',
    '🧎🏼‍♀' => 'žena kleči: svijetlo maslinasta boja kože',
    '🧎🏽‍♀' => 'žena kleči: maslinasta boja kože',
    '🧎🏾‍♀' => 'žena kleči: smeđa boja kože',
    '🧎🏿‍♀' => 'žena kleči: tamno smeđa boja kože',
    '🧎🏻‍➡' => 'osoba kleči: svijetla boja kože i udesno',
    '🧎🏼‍➡' => 'osoba kleči: svijetlo maslinasta boja kože i udesno',
    '🧎🏽‍➡' => 'osoba kleči: maslinasta boja kože i udesno',
    '🧎🏾‍➡' => 'osoba kleči: smeđa boja kože i udesno',
    '🧎🏿‍➡' => 'osoba kleči: tamno smeđa boja kože i udesno',
    '🧑🏻‍🦯' => 'osoba s bijelim štapom: svijetla boja kože',
    '🧑🏼‍🦯' => 'osoba s bijelim štapom: svijetlo maslinasta boja kože',
    '🧑🏽‍🦯' => 'osoba s bijelim štapom: maslinasta boja kože',
    '🧑🏾‍🦯' => 'osoba s bijelim štapom: smeđa boja kože',
    '🧑🏿‍🦯' => 'osoba s bijelim štapom: tamno smeđa boja kože',
    '👨🏻‍🦯' => 'muškarac s bijelim štapom: svijetla boja kože',
    '👨🏼‍🦯' => 'muškarac s bijelim štapom: svijetlo maslinasta boja kože',
    '👨🏽‍🦯' => 'muškarac s bijelim štapom: maslinasta boja kože',
    '👨🏾‍🦯' => 'muškarac s bijelim štapom: smeđa boja kože',
    '👨🏿‍🦯' => 'muškarac s bijelim štapom: tamno smeđa boja kože',
    '👩🏻‍🦯' => 'žena s bijelim štapom: svijetla boja kože',
    '👩🏼‍🦯' => 'žena s bijelim štapom: svijetlo maslinasta boja kože',
    '👩🏽‍🦯' => 'žena s bijelim štapom: maslinasta boja kože',
    '👩🏾‍🦯' => 'žena s bijelim štapom: smeđa boja kože',
    '👩🏿‍🦯' => 'žena s bijelim štapom: tamno smeđa boja kože',
    '🧑🏻‍🦼' => 'osoba u invalidskim kolicima na motorni pogon: svijetla boja kože',
    '🧑🏼‍🦼' => 'osoba u invalidskim kolicima na motorni pogon: svijetlo maslinasta boja kože',
    '🧑🏽‍🦼' => 'osoba u invalidskim kolicima na motorni pogon: maslinasta boja kože',
    '🧑🏾‍🦼' => 'osoba u invalidskim kolicima na motorni pogon: smeđa boja kože',
    '🧑🏿‍🦼' => 'osoba u invalidskim kolicima na motorni pogon: tamno smeđa boja kože',
    '👨🏻‍🦼' => 'muškarac u motornim invalidskim kolicima: svijetla boja kože',
    '👨🏼‍🦼' => 'muškarac u motornim invalidskim kolicima: svijetlo maslinasta boja kože',
    '👨🏽‍🦼' => 'muškarac u motornim invalidskim kolicima: maslinasta boja kože',
    '👨🏾‍🦼' => 'muškarac u motornim invalidskim kolicima: smeđa boja kože',
    '👨🏿‍🦼' => 'muškarac u motornim invalidskim kolicima: tamno smeđa boja kože',
    '👩🏻‍🦼' => 'žena u motornim invalidskim kolicima: svijetla boja kože',
    '👩🏼‍🦼' => 'žena u motornim invalidskim kolicima: svijetlo maslinasta boja kože',
    '👩🏽‍🦼' => 'žena u motornim invalidskim kolicima: maslinasta boja kože',
    '👩🏾‍🦼' => 'žena u motornim invalidskim kolicima: smeđa boja kože',
    '👩🏿‍🦼' => 'žena u motornim invalidskim kolicima: tamno smeđa boja kože',
    '🧑🏻‍🦽' => 'osoba u invalidskim kolicima na ručni pogon: svijetla boja kože',
    '🧑🏼‍🦽' => 'osoba u invalidskim kolicima na ručni pogon: svijetlo maslinasta boja kože',
    '🧑🏽‍🦽' => 'osoba u invalidskim kolicima na ručni pogon: maslinasta boja kože',
    '🧑🏾‍🦽' => 'osoba u invalidskim kolicima na ručni pogon: smeđa boja kože',
    '🧑🏿‍🦽' => 'osoba u invalidskim kolicima na ručni pogon: tamno smeđa boja kože',
    '👨🏻‍🦽' => 'muškarac u invalidskim kolicima na ručni pogon: svijetla boja kože',
    '👨🏼‍🦽' => 'muškarac u invalidskim kolicima na ručni pogon: svijetlo maslinasta boja kože',
    '👨🏽‍🦽' => 'muškarac u invalidskim kolicima na ručni pogon: maslinasta boja kože',
    '👨🏾‍🦽' => 'muškarac u invalidskim kolicima na ručni pogon: smeđa boja kože',
    '👨🏿‍🦽' => 'muškarac u invalidskim kolicima na ručni pogon: tamno smeđa boja kože',
    '👩🏻‍🦽' => 'žena u invalidskim kolicima na ručni pogon: svijetla boja kože',
    '👩🏼‍🦽' => 'žena u invalidskim kolicima na ručni pogon: svijetlo maslinasta boja kože',
    '👩🏽‍🦽' => 'žena u invalidskim kolicima na ručni pogon: maslinasta boja kože',
    '👩🏾‍🦽' => 'žena u invalidskim kolicima na ručni pogon: smeđa boja kože',
    '👩🏿‍🦽' => 'žena u invalidskim kolicima na ručni pogon: tamno smeđa boja kože',
    '🏃🏻‍♂' => 'muškarac trči: svijetla boja kože',
    '🏃🏼‍♂' => 'muškarac trči: svijetlo maslinasta boja kože',
    '🏃🏽‍♂' => 'muškarac trči: maslinasta boja kože',
    '🏃🏾‍♂' => 'muškarac trči: smeđa boja kože',
    '🏃🏿‍♂' => 'muškarac trči: tamno smeđa boja kože',
    '🏃🏻‍♀' => 'žena trči: svijetla boja kože',
    '🏃🏼‍♀' => 'žena trči: svijetlo maslinasta boja kože',
    '🏃🏽‍♀' => 'žena trči: maslinasta boja kože',
    '🏃🏾‍♀' => 'žena trči: smeđa boja kože',
    '🏃🏿‍♀' => 'žena trči: tamno smeđa boja kože',
    '🏃🏻‍➡' => 'osoba trči: svijetla boja kože i udesno',
    '🏃🏼‍➡' => 'osoba trči: svijetlo maslinasta boja kože i udesno',
    '🏃🏽‍➡' => 'osoba trči: maslinasta boja kože i udesno',
    '🏃🏾‍➡' => 'osoba trči: smeđa boja kože i udesno',
    '🏃🏿‍➡' => 'osoba trči: tamno smeđa boja kože i udesno',
    '👯🏻‍♀' => 'žene sa zečjim ušima: svijetla boja kože',
    '👯🏼‍♀' => 'žene sa zečjim ušima: svijetlo maslinasta boja kože',
    '👯🏽‍♀' => 'žene sa zečjim ušima: maslinasta boja kože',
    '👯🏾‍♀' => 'žene sa zečjim ušima: smeđa boja kože',
    '👯🏿‍♀' => 'žene sa zečjim ušima: tamno smeđa boja kože',
    '👯🏻‍♂' => 'muškarci sa zečjim ušima: svijetla boja kože',
    '👯🏼‍♂' => 'muškarci sa zečjim ušima: svijetlo maslinasta boja kože',
    '👯🏽‍♂' => 'muškarci sa zečjim ušima: maslinasta boja kože',
    '👯🏾‍♂' => 'muškarci sa zečjim ušima: smeđa boja kože',
    '👯🏿‍♂' => 'muškarci sa zečjim ušima: tamno smeđa boja kože',
    '🧖🏻‍♂' => 'muškarac u sauni: svijetla boja kože',
    '🧖🏼‍♂' => 'muškarac u sauni: svijetlo maslinasta boja kože',
    '🧖🏽‍♂' => 'muškarac u sauni: maslinasta boja kože',
    '🧖🏾‍♂' => 'muškarac u sauni: smeđa boja kože',
    '🧖🏿‍♂' => 'muškarac u sauni: tamno smeđa boja kože',
    '🧖🏻‍♀' => 'žena u sauni: svijetla boja kože',
    '🧖🏼‍♀' => 'žena u sauni: svijetlo maslinasta boja kože',
    '🧖🏽‍♀' => 'žena u sauni: maslinasta boja kože',
    '🧖🏾‍♀' => 'žena u sauni: smeđa boja kože',
    '🧖🏿‍♀' => 'žena u sauni: tamno smeđa boja kože',
    '🧗🏻‍♂' => 'muškarac se penje: svijetla boja kože',
    '🧗🏼‍♂' => 'muškarac se penje: svijetlo maslinasta boja kože',
    '🧗🏽‍♂' => 'muškarac se penje: maslinasta boja kože',
    '🧗🏾‍♂' => 'muškarac se penje: smeđa boja kože',
    '🧗🏿‍♂' => 'muškarac se penje: tamno smeđa boja kože',
    '🧗🏻‍♀' => 'žena se penje: svijetla boja kože',
    '🧗🏼‍♀' => 'žena se penje: svijetlo maslinasta boja kože',
    '🧗🏽‍♀' => 'žena se penje: maslinasta boja kože',
    '🧗🏾‍♀' => 'žena se penje: smeđa boja kože',
    '🧗🏿‍♀' => 'žena se penje: tamno smeđa boja kože',
    '🏌🏻‍♂' => 'muškarac igra golf: svijetla boja kože',
    '🏌🏼‍♂' => 'muškarac igra golf: svijetlo maslinasta boja kože',
    '🏌🏽‍♂' => 'muškarac igra golf: maslinasta boja kože',
    '🏌🏾‍♂' => 'muškarac igra golf: smeđa boja kože',
    '🏌🏿‍♂' => 'muškarac igra golf: tamno smeđa boja kože',
    '🏌🏻‍♀' => 'žena igra golf: svijetla boja kože',
    '🏌🏼‍♀' => 'žena igra golf: svijetlo maslinasta boja kože',
    '🏌🏽‍♀' => 'žena igra golf: maslinasta boja kože',
    '🏌🏾‍♀' => 'žena igra golf: smeđa boja kože',
    '🏌🏿‍♀' => 'žena igra golf: tamno smeđa boja kože',
    '🏄🏻‍♂' => 'muškarac surfa: svijetla boja kože',
    '🏄🏼‍♂' => 'muškarac surfa: svijetlo maslinasta boja kože',
    '🏄🏽‍♂' => 'muškarac surfa: maslinasta boja kože',
    '🏄🏾‍♂' => 'muškarac surfa: smeđa boja kože',
    '🏄🏿‍♂' => 'muškarac surfa: tamno smeđa boja kože',
    '🏄🏻‍♀' => 'žena surfa: svijetla boja kože',
    '🏄🏼‍♀' => 'žena surfa: svijetlo maslinasta boja kože',
    '🏄🏽‍♀' => 'žena surfa: maslinasta boja kože',
    '🏄🏾‍♀' => 'žena surfa: smeđa boja kože',
    '🏄🏿‍♀' => 'žena surfa: tamno smeđa boja kože',
    '🚣🏻‍♂' => 'muškarac vesla: svijetla boja kože',
    '🚣🏼‍♂' => 'muškarac vesla: svijetlo maslinasta boja kože',
    '🚣🏽‍♂' => 'muškarac vesla: maslinasta boja kože',
    '🚣🏾‍♂' => 'muškarac vesla: smeđa boja kože',
    '🚣🏿‍♂' => 'muškarac vesla: tamno smeđa boja kože',
    '🚣🏻‍♀' => 'žena vesla: svijetla boja kože',
    '🚣🏼‍♀' => 'žena vesla: svijetlo maslinasta boja kože',
    '🚣🏽‍♀' => 'žena vesla: maslinasta boja kože',
    '🚣🏾‍♀' => 'žena vesla: smeđa boja kože',
    '🚣🏿‍♀' => 'žena vesla: tamno smeđa boja kože',
    '🏊🏻‍♂' => 'muškarac pliva: svijetla boja kože',
    '🏊🏼‍♂' => 'muškarac pliva: svijetlo maslinasta boja kože',
    '🏊🏽‍♂' => 'muškarac pliva: maslinasta boja kože',
    '🏊🏾‍♂' => 'muškarac pliva: smeđa boja kože',
    '🏊🏿‍♂' => 'muškarac pliva: tamno smeđa boja kože',
    '🏊🏻‍♀' => 'žena pliva: svijetla boja kože',
    '🏊🏼‍♀' => 'žena pliva: svijetlo maslinasta boja kože',
    '🏊🏽‍♀' => 'žena pliva: maslinasta boja kože',
    '🏊🏾‍♀' => 'žena pliva: smeđa boja kože',
    '🏊🏿‍♀' => 'žena pliva: tamno smeđa boja kože',
    '⛹🏻‍♂' => 'muškarac vodi loptu: svijetla boja kože',
    '⛹🏼‍♂' => 'muškarac vodi loptu: svijetlo maslinasta boja kože',
    '⛹🏽‍♂' => 'muškarac vodi loptu: maslinasta boja kože',
    '⛹🏾‍♂' => 'muškarac vodi loptu: smeđa boja kože',
    '⛹🏿‍♂' => 'muškarac vodi loptu: tamno smeđa boja kože',
    '⛹🏻‍♀' => 'žena vodi loptu: svijetla boja kože',
    '⛹🏼‍♀' => 'žena vodi loptu: svijetlo maslinasta boja kože',
    '⛹🏽‍♀' => 'žena vodi loptu: maslinasta boja kože',
    '⛹🏾‍♀' => 'žena vodi loptu: smeđa boja kože',
    '⛹🏿‍♀' => 'žena vodi loptu: tamno smeđa boja kože',
    '🏋🏻‍♂' => 'muškarac diže utege: svijetla boja kože',
    '🏋🏼‍♂' => 'muškarac diže utege: svijetlo maslinasta boja kože',
    '🏋🏽‍♂' => 'muškarac diže utege: maslinasta boja kože',
    '🏋🏾‍♂' => 'muškarac diže utege: smeđa boja kože',
    '🏋🏿‍♂' => 'muškarac diže utege: tamno smeđa boja kože',
    '🏋🏻‍♀' => 'žena diže utege: svijetla boja kože',
    '🏋🏼‍♀' => 'žena diže utege: svijetlo maslinasta boja kože',
    '🏋🏽‍♀' => 'žena diže utege: maslinasta boja kože',
    '🏋🏾‍♀' => 'žena diže utege: smeđa boja kože',
    '🏋🏿‍♀' => 'žena diže utege: tamno smeđa boja kože',
    '🚴🏻‍♂' => 'muškarac vozi bicikl: svijetla boja kože',
    '🚴🏼‍♂' => 'muškarac vozi bicikl: svijetlo maslinasta boja kože',
    '🚴🏽‍♂' => 'muškarac vozi bicikl: maslinasta boja kože',
    '🚴🏾‍♂' => 'muškarac vozi bicikl: smeđa boja kože',
    '🚴🏿‍♂' => 'muškarac vozi bicikl: tamno smeđa boja kože',
    '🚴🏻‍♀' => 'žena vozi bicikl: svijetla boja kože',
    '🚴🏼‍♀' => 'žena vozi bicikl: svijetlo maslinasta boja kože',
    '🚴🏽‍♀' => 'žena vozi bicikl: maslinasta boja kože',
    '🚴🏾‍♀' => 'žena vozi bicikl: smeđa boja kože',
    '🚴🏿‍♀' => 'žena vozi bicikl: tamno smeđa boja kože',
    '🚵🏻‍♂' => 'muškarac vozi brdski bicikl: svijetla boja kože',
    '🚵🏼‍♂' => 'muškarac vozi brdski bicikl: svijetlo maslinasta boja kože',
    '🚵🏽‍♂' => 'muškarac vozi brdski bicikl: maslinasta boja kože',
    '🚵🏾‍♂' => 'muškarac vozi brdski bicikl: smeđa boja kože',
    '🚵🏿‍♂' => 'muškarac vozi brdski bicikl: tamno smeđa boja kože',
    '🚵🏻‍♀' => 'žena vozi brdski bicikl: svijetla boja kože',
    '🚵🏼‍♀' => 'žena vozi brdski bicikl: svijetlo maslinasta boja kože',
    '🚵🏽‍♀' => 'žena vozi brdski bicikl: maslinasta boja kože',
    '🚵🏾‍♀' => 'žena vozi brdski bicikl: smeđa boja kože',
    '🚵🏿‍♀' => 'žena vozi brdski bicikl: tamno smeđa boja kože',
    '🤸🏻‍♂' => 'muškarac izvodi zvijezdu: svijetla boja kože',
    '🤸🏼‍♂' => 'muškarac izvodi zvijezdu: svijetlo maslinasta boja kože',
    '🤸🏽‍♂' => 'muškarac izvodi zvijezdu: maslinasta boja kože',
    '🤸🏾‍♂' => 'muškarac izvodi zvijezdu: smeđa boja kože',
    '🤸🏿‍♂' => 'muškarac izvodi zvijezdu: tamno smeđa boja kože',
    '🤸🏻‍♀' => 'žena izvodi zvijezdu: svijetla boja kože',
    '🤸🏼‍♀' => 'žena izvodi zvijezdu: svijetlo maslinasta boja kože',
    '🤸🏽‍♀' => 'žena izvodi zvijezdu: maslinasta boja kože',
    '🤸🏾‍♀' => 'žena izvodi zvijezdu: smeđa boja kože',
    '🤸🏿‍♀' => 'žena izvodi zvijezdu: tamno smeđa boja kože',
    '🤼🏻‍♀' => 'žene se hrvaju: svijetla boja kože',
    '🤼🏼‍♀' => 'žene se hrvaju: svijetlo maslinasta boja kože',
    '🤼🏽‍♀' => 'žene se hrvaju: maslinasta boja kože',
    '🤼🏾‍♀' => 'žene se hrvaju: smeđa boja kože',
    '🤼🏿‍♀' => 'žene se hrvaju: tamno smeđa boja kože',
    '🤼🏻‍♂' => 'muškarci se hrvaju: svijetla boja kože',
    '🤼🏼‍♂' => 'muškarci se hrvaju: svijetlo maslinasta boja kože',
    '🤼🏽‍♂' => 'muškarci se hrvaju: maslinasta boja kože',
    '🤼🏾‍♂' => 'muškarci se hrvaju: smeđa boja kože',
    '🤼🏿‍♂' => 'muškarci se hrvaju: tamno smeđa boja kože',
    '🤽🏻‍♂' => 'muškarac igra vaterpolo: svijetla boja kože',
    '🤽🏼‍♂' => 'muškarac igra vaterpolo: svijetlo maslinasta boja kože',
    '🤽🏽‍♂' => 'muškarac igra vaterpolo: maslinasta boja kože',
    '🤽🏾‍♂' => 'muškarac igra vaterpolo: smeđa boja kože',
    '🤽🏿‍♂' => 'muškarac igra vaterpolo: tamno smeđa boja kože',
    '🤽🏻‍♀' => 'žena igra vaterpolo: svijetla boja kože',
    '🤽🏼‍♀' => 'žena igra vaterpolo: svijetlo maslinasta boja kože',
    '🤽🏽‍♀' => 'žena igra vaterpolo: maslinasta boja kože',
    '🤽🏾‍♀' => 'žena igra vaterpolo: smeđa boja kože',
    '🤽🏿‍♀' => 'žena igra vaterpolo: tamno smeđa boja kože',
    '🤾🏻‍♂' => 'muškarac igra rukomet: svijetla boja kože',
    '🤾🏼‍♂' => 'muškarac igra rukomet: svijetlo maslinasta boja kože',
    '🤾🏽‍♂' => 'muškarac igra rukomet: maslinasta boja kože',
    '🤾🏾‍♂' => 'muškarac igra rukomet: smeđa boja kože',
    '🤾🏿‍♂' => 'muškarac igra rukomet: tamno smeđa boja kože',
    '🤾🏻‍♀' => 'žena igra rukomet: svijetla boja kože',
    '🤾🏼‍♀' => 'žena igra rukomet: svijetlo maslinasta boja kože',
    '🤾🏽‍♀' => 'žena igra rukomet: maslinasta boja kože',
    '🤾🏾‍♀' => 'žena igra rukomet: smeđa boja kože',
    '🤾🏿‍♀' => 'žena igra rukomet: tamno smeđa boja kože',
    '🤹🏻‍♂' => 'muškarac žonglira: svijetla boja kože',
    '🤹🏼‍♂' => 'muškarac žonglira: svijetlo maslinasta boja kože',
    '🤹🏽‍♂' => 'muškarac žonglira: maslinasta boja kože',
    '🤹🏾‍♂' => 'muškarac žonglira: smeđa boja kože',
    '🤹🏿‍♂' => 'muškarac žonglira: tamno smeđa boja kože',
    '🤹🏻‍♀' => 'žena žonglira: svijetla boja kože',
    '🤹🏼‍♀' => 'žena žonglira: svijetlo maslinasta boja kože',
    '🤹🏽‍♀' => 'žena žonglira: maslinasta boja kože',
    '🤹🏾‍♀' => 'žena žonglira: smeđa boja kože',
    '🤹🏿‍♀' => 'žena žonglira: tamno smeđa boja kože',
    '🧘🏻‍♂' => 'muškarac u položaju lotosa: svijetla boja kože',
    '🧘🏼‍♂' => 'muškarac u položaju lotosa: svijetlo maslinasta boja kože',
    '🧘🏽‍♂' => 'muškarac u položaju lotosa: maslinasta boja kože',
    '🧘🏾‍♂' => 'muškarac u položaju lotosa: smeđa boja kože',
    '🧘🏿‍♂' => 'muškarac u položaju lotosa: tamno smeđa boja kože',
    '🧘🏻‍♀' => 'žena u položaju lotosa: svijetla boja kože',
    '🧘🏼‍♀' => 'žena u položaju lotosa: svijetlo maslinasta boja kože',
    '🧘🏽‍♀' => 'žena u položaju lotosa: maslinasta boja kože',
    '🧘🏾‍♀' => 'žena u položaju lotosa: smeđa boja kože',
    '🧘🏿‍♀' => 'žena u položaju lotosa: tamno smeđa boja kože',
    '🧑‍🦰' => 'odrasla osoba: crvena kosa',
    '🧑‍🦱' => 'odrasla osoba: kovrčava kosa',
    '🧑‍🦳' => 'odrasla osoba: sijeda kosa',
    '🧑‍🦲' => 'odrasla osoba: bez kose',
    '👨‍🦰' => 'muškarac: crvena kosa',
    '👨‍🦱' => 'muškarac: kovrčava kosa',
    '👨‍🦳' => 'muškarac: sijeda kosa',
    '👨‍🦲' => 'muškarac: bez kose',
    '👩‍🦰' => 'žena: crvena kosa',
    '👩‍🦱' => 'žena: kovrčava kosa',
    '👩‍🦳' => 'žena: sijeda kosa',
    '👩‍🦲' => 'žena: bez kose',
    '🚶‍➡' => 'pješak: udesno',
    '🧎‍➡' => 'osoba kleči: udesno',
    '🏃‍➡' => 'osoba trči: udesno',
    '👨‍👦' => 'obitelj: muškarac i dječak',
    '👨‍👧' => 'obitelj: muškarac i djevojčica',
    '👩‍👦' => 'obitelj: žena i dječak',
    '👩‍👧' => 'obitelj: žena i djevojčica',
    '😶‍🌫' => 'lice u oblacima',
    '😮‍💨' => 'lice koje izdiše',
    '🙂‍↕' => 'okomito klimanje glavom',
    '😵‍💫' => 'lice sa spiralnim očima',
    '❤‍🔥' => 'srce u plamenu',
    '❤‍🩹' => 'srce koje se liječi',
    '👁‍🗨' => 'oko u oblačiću',
    '🧔‍♂' => 'muškarac: brada',
    '👱‍♂' => 'plavokosi muškarac',
    '🧔‍♀' => 'žena: brada',
    '👱‍♀' => 'plavokosa žena',
    '🙍‍♂' => 'namršteni muškarac',
    '🙍‍♀' => 'namrštena žena',
    '🙎‍♂' => 'nadureni muškarac',
    '🙎‍♀' => 'nadurena žena',
    '🙅‍♂' => 'muškarac pokazuje "ne"',
    '🙅‍♀' => 'žena pokazuje "ne"',
    '🙆‍♂' => 'muškarac pokazuje "u redu"',
    '🙆‍♀' => 'žena pokazuje "u redu"',
    '💁‍♂' => 'muškarac s nagnutim dlanom',
    '💁‍♀' => 'žena s nagnutim dlanom',
    '🙋‍♂' => 'muškarac podiže ruku',
    '🙋‍♀' => 'žena podiže ruku',
    '🧏‍♂' => 'gluhi muškarac',
    '🧏‍♀' => 'gluha žena',
    '🙇‍♂' => 'muškarac u dubokom naklonu',
    '🙇‍♀' => 'žena u dubokom naklonu',
    '🤦‍♂' => 'muškarac lupa dlanom o čelo',
    '🤦‍♀' => 'žena lupa dlanom o čelo',
    '🤷‍♂' => 'muškarac sliježe ramenima',
    '🤷‍♀' => 'žena sliježe ramenima',
    '🧑‍⚕' => 'zdravstveni djelatnik',
    '👨‍⚕' => 'liječnik',
    '👩‍⚕' => 'liječnica',
    '🧑‍🎓' => 'diplomant',
    '👨‍🎓' => 'student',
    '👩‍🎓' => 'studentica',
    '🧑‍🏫' => 'profesor',
    '👨‍🏫' => 'učitelj',
    '👩‍🏫' => 'učiteljica',
    '🧑‍⚖' => 'arbitar',
    '👨‍⚖' => 'sudac',
    '👩‍⚖' => 'sutkinja',
    '🧑‍🌾' => 'farmer',
    '👨‍🌾' => 'poljoprivrednik',
    '👩‍🌾' => 'poljoprivrednica',
    '🧑‍🍳' => 'šef kuhinje',
    '👨‍🍳' => 'kuhar',
    '👩‍🍳' => 'kuharica',
    '🧑‍🔧' => 'serviser',
    '👨‍🔧' => 'mehaničar',
    '👩‍🔧' => 'mehaničarka',
    '🧑‍🏭' => 'radnik u tvornici',
    '👨‍🏭' => 'tvornički radnik',
    '👩‍🏭' => 'tvornička radnica',
    '🧑‍💼' => 'uredski djelatnik',
    '👨‍💼' => 'službenik',
    '👩‍💼' => 'službenica',
    '🧑‍🔬' => 'biokemičar',
    '👨‍🔬' => 'znanstvenik',
    '👩‍🔬' => 'znanstvenica',
    '🧑‍💻' => 'tehnološki djelatnik',
    '👨‍💻' => 'tehnološki inženjer',
    '👩‍💻' => 'tehnološka inženjerka',
    '🧑‍🎤' => 'izvođač',
    '👨‍🎤' => 'pjevač',
    '👩‍🎤' => 'pjevačica',
    '🧑‍🎨' => 'slikar',
    '👨‍🎨' => 'umjetnik',
    '👩‍🎨' => 'umjetnica',
    '🧑‍✈' => 'pilot zrakoplova',
    '👨‍✈' => 'pilot',
    '👩‍✈' => 'pilotkinja',
    '🧑‍🚀' => 'kozmonaut',
    '👨‍🚀' => 'astronaut',
    '👩‍🚀' => 'astronautkinja',
    '🧑‍🚒' => 'vatrogasni djelatnik',
    '👨‍🚒' => 'vatrogasac',
    '👩‍🚒' => 'vatrogaskinja',
    '👮‍♂' => 'policijski djelatnik',
    '👮‍♀' => 'policajka',
    '🕵‍♂' => 'istražitelj',
    '🕵‍♀' => 'istražiteljica',
    '💂‍♂' => 'stražar',
    '💂‍♀' => 'stražarica',
    '👷‍♂' => 'zidar',
    '👷‍♀' => 'zidarica',
    '👳‍♂' => 'muškarac s turbanom',
    '👳‍♀' => 'žena s turbanom',
    '🤵‍♂' => 'muškarac u smokingu',
    '🤵‍♀' => 'žena u smokingu',
    '👰‍♂' => 'muškarac s velom',
    '👰‍♀' => 'žena s velom',
    '👩‍🍼' => 'žena hrani bebu',
    '👨‍🍼' => 'muškarac hrani bebu',
    '🧑‍🍼' => 'osoba hrani bebu',
    '🧑‍🎄' => 'osoba Mraz',
    '🦸‍♂' => 'superjunak',
    '🦸‍♀' => 'superjunakinja',
    '🦹‍♂' => 'stripovski zločinac',
    '🦹‍♀' => 'stripovska zločinka',
    '🧙‍♂' => 'čarobnjak',
    '🧙‍♀' => 'čarobnica',
    '🧚‍♂' => 'kućni duh',
    '🧚‍♀' => 'vila',
    '🧛‍♂' => 'vampir',
    '🧛‍♀' => 'vampirica',
    '🧜‍♂' => 'muška sirena',
    '🧜‍♀' => 'sirena',
    '🧝‍♂' => 'vilenjak',
    '🧝‍♀' => 'vilenjakinja',
    '🧞‍♂' => 'muški džin',
    '🧞‍♀' => 'ženski džin',
    '🧟‍♂' => 'muški zombi',
    '🧟‍♀' => 'ženski zombi',
    '💆‍♂' => 'muškarac na masaži',
    '💆‍♀' => 'žena na masaži',
    '💇‍♂' => 'muškarac na šišanju',
    '💇‍♀' => 'žena na šišanju',
    '🚶‍♂' => 'muškarac hoda',
    '🚶‍♀' => 'žena hoda',
    '🧍‍♂' => 'muškarac stoji',
    '🧍‍♀' => 'žena stoji',
    '🧎‍♂' => 'muškarac kleči',
    '🧎‍♀' => 'žena kleči',
    '🧑‍🦯' => 'osoba s bijelim štapom',
    '👨‍🦯' => 'muškarac s bijelim štapom',
    '👩‍🦯' => 'žena s bijelim štapom',
    '🧑‍🦼' => 'osoba u invalidskim kolicima na motorni pogon',
    '👨‍🦼' => 'muškarac u motornim invalidskim kolicima',
    '👩‍🦼' => 'žena u motornim invalidskim kolicima',
    '🧑‍🦽' => 'osoba u invalidskim kolicima na ručni pogon',
    '👨‍🦽' => 'muškarac u invalidskim kolicima na ručni pogon',
    '👩‍🦽' => 'žena u invalidskim kolicima na ručni pogon',
    '🏃‍♂' => 'muškarac trči',
    '🏃‍♀' => 'žena trči',
    '🧑‍🩰' => 'balerina',
    '👯‍♂' => 'muškarci sa zečjim ušima',
    '👯‍♀' => 'žene sa zečjim ušima',
    '🧖‍♂' => 'muškarac u sauni',
    '🧖‍♀' => 'žena u sauni',
    '🧗‍♂' => 'muškarac se penje',
    '🧗‍♀' => 'žena se penje',
    '🏌‍♂' => 'muškarac igra golf',
    '🏌‍♀' => 'žena igra golf',
    '🏄‍♂' => 'muškarac surfa',
    '🏄‍♀' => 'žena surfa',
    '🚣‍♂' => 'muškarac vesla',
    '🚣‍♀' => 'žena vesla',
    '🏊‍♂' => 'muškarac pliva',
    '🏊‍♀' => 'žena pliva',
    '⛹‍♂' => 'muškarac vodi loptu',
    '⛹‍♀' => 'žena vodi loptu',
    '🏋‍♂' => 'muškarac diže utege',
    '🏋‍♀' => 'žena diže utege',
    '🚴‍♂' => 'muškarac vozi bicikl',
    '🚴‍♀' => 'žena vozi bicikl',
    '🚵‍♂' => 'muškarac vozi brdski bicikl',
    '🚵‍♀' => 'žena vozi brdski bicikl',
    '🤸‍♂' => 'muškarac izvodi zvijezdu',
    '🤸‍♀' => 'žena izvodi zvijezdu',
    '🤼‍♂' => 'muškarci se hrvaju',
    '🤼‍♀' => 'žene se hrvaju',
    '🤽‍♂' => 'muškarac igra vaterpolo',
    '🤽‍♀' => 'žena igra vaterpolo',
    '🤾‍♂' => 'muškarac igra rukomet',
    '🤾‍♀' => 'žena igra rukomet',
    '🤹‍♂' => 'muškarac žonglira',
    '🤹‍♀' => 'žena žonglira',
    '🧘‍♂' => 'muškarac u položaju lotosa',
    '🧘‍♀' => 'žena u položaju lotosa',
    '🧑‍🧒' => 'obitelj: odrasla osoba, dijete',
    '🐕‍🦺' => 'radni pas',
    '🐈‍⬛' => 'crna mačka',
    '🐻‍❄' => 'polarni medvjed',
    '🐦‍⬛' => 'crna ptica',
    '🐦‍🔥' => 'feniks',
    '🍋‍🟩' => 'limeta',
    '🍄‍🟫' => 'smeđa gljiva',
    '⛓‍💥' => 'slomljeni lanac',
    '🏳‍🌈' => 'zastava duginih boja',
    '🏳‍⚧' => 'zastava pokreta transrodnih osoba',
    '🏴‍☠' => 'gusarska zastava',
    '👋🏻' => 'ruka koja maše: svijetla boja kože',
    '👋🏼' => 'ruka koja maše: svijetlo maslinasta boja kože',
    '👋🏽' => 'ruka koja maše: maslinasta boja kože',
    '👋🏾' => 'ruka koja maše: smeđa boja kože',
    '👋🏿' => 'ruka koja maše: tamno smeđa boja kože',
    '🤚🏻' => 'ruka gore: svijetla boja kože',
    '🤚🏼' => 'ruka gore: svijetlo maslinasta boja kože',
    '🤚🏽' => 'ruka gore: maslinasta boja kože',
    '🤚🏾' => 'ruka gore: smeđa boja kože',
    '🤚🏿' => 'ruka gore: tamno smeđa boja kože',
    '🖐🏻' => 'podignuta ruka s raširenim prstima: svijetla boja kože',
    '🖐🏼' => 'podignuta ruka s raširenim prstima: svijetlo maslinasta boja kože',
    '🖐🏽' => 'podignuta ruka s raširenim prstima: maslinasta boja kože',
    '🖐🏾' => 'podignuta ruka s raširenim prstima: smeđa boja kože',
    '🖐🏿' => 'podignuta ruka s raširenim prstima: tamno smeđa boja kože',
    '✋🏻' => 'podignuta ruka: svijetla boja kože',
    '✋🏼' => 'podignuta ruka: svijetlo maslinasta boja kože',
    '✋🏽' => 'podignuta ruka: maslinasta boja kože',
    '✋🏾' => 'podignuta ruka: smeđa boja kože',
    '✋🏿' => 'podignuta ruka: tamno smeđa boja kože',
    '🖖🏻' => 'vulkanski pozdrav: svijetla boja kože',
    '🖖🏼' => 'vulkanski pozdrav: svijetlo maslinasta boja kože',
    '🖖🏽' => 'vulkanski pozdrav: maslinasta boja kože',
    '🖖🏾' => 'vulkanski pozdrav: smeđa boja kože',
    '🖖🏿' => 'vulkanski pozdrav: tamno smeđa boja kože',
    '🫱🏻' => 'ruka okrenuta udesno: svijetla boja kože',
    '🫱🏼' => 'ruka okrenuta udesno: svijetlo maslinasta boja kože',
    '🫱🏽' => 'ruka okrenuta udesno: maslinasta boja kože',
    '🫱🏾' => 'ruka okrenuta udesno: smeđa boja kože',
    '🫱🏿' => 'ruka okrenuta udesno: tamno smeđa boja kože',
    '🫲🏻' => 'ruka okrenuta ulijevo: svijetla boja kože',
    '🫲🏼' => 'ruka okrenuta ulijevo: svijetlo maslinasta boja kože',
    '🫲🏽' => 'ruka okrenuta ulijevo: maslinasta boja kože',
    '🫲🏾' => 'ruka okrenuta ulijevo: smeđa boja kože',
    '🫲🏿' => 'ruka okrenuta ulijevo: tamno smeđa boja kože',
    '🫳🏻' => 'ruka s dlanom okrenutim prema dolje: svijetla boja kože',
    '🫳🏼' => 'ruka s dlanom okrenutim prema dolje: svijetlo maslinasta boja kože',
    '🫳🏽' => 'ruka s dlanom okrenutim prema dolje: maslinasta boja kože',
    '🫳🏾' => 'ruka s dlanom okrenutim prema dolje: smeđa boja kože',
    '🫳🏿' => 'ruka s dlanom okrenutim prema dolje: tamno smeđa boja kože',
    '🫴🏻' => 'ruka s dlanom okrenutim prema gore: svijetla boja kože',
    '🫴🏼' => 'ruka s dlanom okrenutim prema gore: svijetlo maslinasta boja kože',
    '🫴🏽' => 'ruka s dlanom okrenutim prema gore: maslinasta boja kože',
    '🫴🏾' => 'ruka s dlanom okrenutim prema gore: smeđa boja kože',
    '🫴🏿' => 'ruka s dlanom okrenutim prema gore: tamno smeđa boja kože',
    '🫷🏻' => 'ruka koja gura ulijevo: svijetla boja kože',
    '🫷🏼' => 'ruka koja gura ulijevo: svijetlo maslinasta boja kože',
    '🫷🏽' => 'ruka koja gura ulijevo: maslinasta boja kože',
    '🫷🏾' => 'ruka koja gura ulijevo: smeđa boja kože',
    '🫷🏿' => 'ruka koja gura ulijevo: tamno smeđa boja kože',
    '🫸🏻' => 'ruka koja gura udesno: svijetla boja kože',
    '🫸🏼' => 'ruka koja gura udesno: svijetlo maslinasta boja kože',
    '🫸🏽' => 'ruka koja gura udesno: maslinasta boja kože',
    '🫸🏾' => 'ruka koja gura udesno: smeđa boja kože',
    '🫸🏿' => 'ruka koja gura udesno: tamno smeđa boja kože',
    '👌🏻' => 'znak rukom "u redu": svijetla boja kože',
    '👌🏼' => 'znak rukom "u redu": svijetlo maslinasta boja kože',
    '👌🏽' => 'znak rukom "u redu": maslinasta boja kože',
    '👌🏾' => 'znak rukom "u redu": smeđa boja kože',
    '👌🏿' => 'znak rukom "u redu": tamno smeđa boja kože',
    '🤌🏻' => 'skupljeni prsti: svijetla boja kože',
    '🤌🏼' => 'skupljeni prsti: svijetlo maslinasta boja kože',
    '🤌🏽' => 'skupljeni prsti: maslinasta boja kože',
    '🤌🏾' => 'skupljeni prsti: smeđa boja kože',
    '🤌🏿' => 'skupljeni prsti: tamno smeđa boja kože',
    '🤏🏻' => 'ruka koja štipa: svijetla boja kože',
    '🤏🏼' => 'ruka koja štipa: svijetlo maslinasta boja kože',
    '🤏🏽' => 'ruka koja štipa: maslinasta boja kože',
    '🤏🏾' => 'ruka koja štipa: smeđa boja kože',
    '🤏🏿' => 'ruka koja štipa: tamno smeđa boja kože',
    '✌🏻' => 'ruka sa znakom pobjede: svijetla boja kože',
    '✌🏼' => 'ruka sa znakom pobjede: svijetlo maslinasta boja kože',
    '✌🏽' => 'ruka sa znakom pobjede: maslinasta boja kože',
    '✌🏾' => 'ruka sa znakom pobjede: smeđa boja kože',
    '✌🏿' => 'ruka sa znakom pobjede: tamno smeđa boja kože',
    '🤞🏻' => 'prekriženi prsti: svijetla boja kože',
    '🤞🏼' => 'prekriženi prsti: svijetlo maslinasta boja kože',
    '🤞🏽' => 'prekriženi prsti: maslinasta boja kože',
    '🤞🏾' => 'prekriženi prsti: smeđa boja kože',
    '🤞🏿' => 'prekriženi prsti: tamno smeđa boja kože',
    '🫰🏻' => 'ruka s prekriženim palcem i kažiprstom: svijetla boja kože',
    '🫰🏼' => 'ruka s prekriženim palcem i kažiprstom: svijetlo maslinasta boja kože',
    '🫰🏽' => 'ruka s prekriženim palcem i kažiprstom: maslinasta boja kože',
    '🫰🏾' => 'ruka s prekriženim palcem i kažiprstom: smeđa boja kože',
    '🫰🏿' => 'ruka s prekriženim palcem i kažiprstom: tamno smeđa boja kože',
    '🤟🏻' => 'gesta "volim te": svijetla boja kože',
    '🤟🏼' => 'gesta "volim te": svijetlo maslinasta boja kože',
    '🤟🏽' => 'gesta "volim te": maslinasta boja kože',
    '🤟🏾' => 'gesta "volim te": smeđa boja kože',
    '🤟🏿' => 'gesta "volim te": tamno smeđa boja kože',
    '🤘🏻' => 'znak rogova: svijetla boja kože',
    '🤘🏼' => 'znak rogova: svijetlo maslinasta boja kože',
    '🤘🏽' => 'znak rogova: maslinasta boja kože',
    '🤘🏾' => 'znak rogova: smeđa boja kože',
    '🤘🏿' => 'znak rogova: tamno smeđa boja kože',
    '🤙🏻' => 'nazovi me: svijetla boja kože',
    '🤙🏼' => 'nazovi me: svijetlo maslinasta boja kože',
    '🤙🏽' => 'nazovi me: maslinasta boja kože',
    '🤙🏾' => 'nazovi me: smeđa boja kože',
    '🤙🏿' => 'nazovi me: tamno smeđa boja kože',
    '👈🏻' => 'kažiprst koji pokazuje ulijevo: svijetla boja kože',
    '👈🏼' => 'kažiprst koji pokazuje ulijevo: svijetlo maslinasta boja kože',
    '👈🏽' => 'kažiprst koji pokazuje ulijevo: maslinasta boja kože',
    '👈🏾' => 'kažiprst koji pokazuje ulijevo: smeđa boja kože',
    '👈🏿' => 'kažiprst koji pokazuje ulijevo: tamno smeđa boja kože',
    '👉🏻' => 'kažiprst koji pokazuje udesno: svijetla boja kože',
    '👉🏼' => 'kažiprst koji pokazuje udesno: svijetlo maslinasta boja kože',
    '👉🏽' => 'kažiprst koji pokazuje udesno: maslinasta boja kože',
    '👉🏾' => 'kažiprst koji pokazuje udesno: smeđa boja kože',
    '👉🏿' => 'kažiprst koji pokazuje udesno: tamno smeđa boja kože',
    '👆🏻' => 'kažiprst koji pokazuje prema gore: svijetla boja kože',
    '👆🏼' => 'kažiprst koji pokazuje prema gore: svijetlo maslinasta boja kože',
    '👆🏽' => 'kažiprst koji pokazuje prema gore: maslinasta boja kože',
    '👆🏾' => 'kažiprst koji pokazuje prema gore: smeđa boja kože',
    '👆🏿' => 'kažiprst koji pokazuje prema gore: tamno smeđa boja kože',
    '🖕🏻' => 'srednji prst: svijetla boja kože',
    '🖕🏼' => 'srednji prst: svijetlo maslinasta boja kože',
    '🖕🏽' => 'srednji prst: maslinasta boja kože',
    '🖕🏾' => 'srednji prst: smeđa boja kože',
    '🖕🏿' => 'srednji prst: tamno smeđa boja kože',
    '👇🏻' => 'kažiprst koji pokazuje prema dolje: svijetla boja kože',
    '👇🏼' => 'kažiprst koji pokazuje prema dolje: svijetlo maslinasta boja kože',
    '👇🏽' => 'kažiprst koji pokazuje prema dolje: maslinasta boja kože',
    '👇🏾' => 'kažiprst koji pokazuje prema dolje: smeđa boja kože',
    '👇🏿' => 'kažiprst koji pokazuje prema dolje: tamno smeđa boja kože',
    '☝🏻' => 'kažiprst pokazuje gore: svijetla boja kože',
    '☝🏼' => 'kažiprst pokazuje gore: svijetlo maslinasta boja kože',
    '☝🏽' => 'kažiprst pokazuje gore: maslinasta boja kože',
    '☝🏾' => 'kažiprst pokazuje gore: smeđa boja kože',
    '☝🏿' => 'kažiprst pokazuje gore: tamno smeđa boja kože',
    '🫵🏻' => 'kažiprst uperen prema gledatelju: svijetla boja kože',
    '🫵🏼' => 'kažiprst uperen prema gledatelju: svijetlo maslinasta boja kože',
    '🫵🏽' => 'kažiprst uperen prema gledatelju: maslinasta boja kože',
    '🫵🏾' => 'kažiprst uperen prema gledatelju: smeđa boja kože',
    '🫵🏿' => 'kažiprst uperen prema gledatelju: tamno smeđa boja kože',
    '👍🏻' => 'palac gore: svijetla boja kože',
    '👍🏼' => 'palac gore: svijetlo maslinasta boja kože',
    '👍🏽' => 'palac gore: maslinasta boja kože',
    '👍🏾' => 'palac gore: smeđa boja kože',
    '👍🏿' => 'palac gore: tamno smeđa boja kože',
    '👎🏻' => 'palac dolje: svijetla boja kože',
    '👎🏼' => 'palac dolje: svijetlo maslinasta boja kože',
    '👎🏽' => 'palac dolje: maslinasta boja kože',
    '👎🏾' => 'palac dolje: smeđa boja kože',
    '👎🏿' => 'palac dolje: tamno smeđa boja kože',
    '✊🏻' => 'podignuta šaka: svijetla boja kože',
    '✊🏼' => 'podignuta šaka: svijetlo maslinasta boja kože',
    '✊🏽' => 'podignuta šaka: maslinasta boja kože',
    '✊🏾' => 'podignuta šaka: smeđa boja kože',
    '✊🏿' => 'podignuta šaka: tamno smeđa boja kože',
    '👊🏻' => 'stisnuta šaka: svijetla boja kože',
    '👊🏼' => 'stisnuta šaka: svijetlo maslinasta boja kože',
    '👊🏽' => 'stisnuta šaka: maslinasta boja kože',
    '👊🏾' => 'stisnuta šaka: smeđa boja kože',
    '👊🏿' => 'stisnuta šaka: tamno smeđa boja kože',
    '🤛🏻' => 'šaka ulijevo: svijetla boja kože',
    '🤛🏼' => 'šaka ulijevo: svijetlo maslinasta boja kože',
    '🤛🏽' => 'šaka ulijevo: maslinasta boja kože',
    '🤛🏾' => 'šaka ulijevo: smeđa boja kože',
    '🤛🏿' => 'šaka ulijevo: tamno smeđa boja kože',
    '🤜🏻' => 'šaka udesno: svijetla boja kože',
    '🤜🏼' => 'šaka udesno: svijetlo maslinasta boja kože',
    '🤜🏽' => 'šaka udesno: maslinasta boja kože',
    '🤜🏾' => 'šaka udesno: smeđa boja kože',
    '🤜🏿' => 'šaka udesno: tamno smeđa boja kože',
    '👏🏻' => 'ruke koje plješću: svijetla boja kože',
    '👏🏼' => 'ruke koje plješću: svijetlo maslinasta boja kože',
    '👏🏽' => 'ruke koje plješću: maslinasta boja kože',
    '👏🏾' => 'ruke koje plješću: smeđa boja kože',
    '👏🏿' => 'ruke koje plješću: tamno smeđa boja kože',
    '🙌🏻' => 'podignute ruke: svijetla boja kože',
    '🙌🏼' => 'podignute ruke: svijetlo maslinasta boja kože',
    '🙌🏽' => 'podignute ruke: maslinasta boja kože',
    '🙌🏾' => 'podignute ruke: smeđa boja kože',
    '🙌🏿' => 'podignute ruke: tamno smeđa boja kože',
    '🫶🏻' => 'ruke koje tvore srce: svijetla boja kože',
    '🫶🏼' => 'ruke koje tvore srce: svijetlo maslinasta boja kože',
    '🫶🏽' => 'ruke koje tvore srce: maslinasta boja kože',
    '🫶🏾' => 'ruke koje tvore srce: smeđa boja kože',
    '🫶🏿' => 'ruke koje tvore srce: tamno smeđa boja kože',
    '👐🏻' => 'otvorene ruke: svijetla boja kože',
    '👐🏼' => 'otvorene ruke: svijetlo maslinasta boja kože',
    '👐🏽' => 'otvorene ruke: maslinasta boja kože',
    '👐🏾' => 'otvorene ruke: smeđa boja kože',
    '👐🏿' => 'otvorene ruke: tamno smeđa boja kože',
    '🤲🏻' => 'spojeni dlanovi: svijetla boja kože',
    '🤲🏼' => 'spojeni dlanovi: svijetlo maslinasta boja kože',
    '🤲🏽' => 'spojeni dlanovi: maslinasta boja kože',
    '🤲🏾' => 'spojeni dlanovi: smeđa boja kože',
    '🤲🏿' => 'spojeni dlanovi: tamno smeđa boja kože',
    '🤝🏻' => 'rukovanje: svijetla boja kože',
    '🤝🏼' => 'rukovanje: svijetlo maslinasta boja kože',
    '🤝🏽' => 'rukovanje: maslinasta boja kože',
    '🤝🏾' => 'rukovanje: smeđa boja kože',
    '🤝🏿' => 'rukovanje: tamno smeđa boja kože',
    '🙏🏻' => 'sklopljeni dlanovi: svijetla boja kože',
    '🙏🏼' => 'sklopljeni dlanovi: svijetlo maslinasta boja kože',
    '🙏🏽' => 'sklopljeni dlanovi: maslinasta boja kože',
    '🙏🏾' => 'sklopljeni dlanovi: smeđa boja kože',
    '🙏🏿' => 'sklopljeni dlanovi: tamno smeđa boja kože',
    '✍🏻' => 'ruka koja piše: svijetla boja kože',
    '✍🏼' => 'ruka koja piše: svijetlo maslinasta boja kože',
    '✍🏽' => 'ruka koja piše: maslinasta boja kože',
    '✍🏾' => 'ruka koja piše: smeđa boja kože',
    '✍🏿' => 'ruka koja piše: tamno smeđa boja kože',
    '💅🏻' => 'lak za nokte: svijetla boja kože',
    '💅🏼' => 'lak za nokte: svijetlo maslinasta boja kože',
    '💅🏽' => 'lak za nokte: maslinasta boja kože',
    '💅🏾' => 'lak za nokte: smeđa boja kože',
    '💅🏿' => 'lak za nokte: tamno smeđa boja kože',
    '🤳🏻' => 'selfie: svijetla boja kože',
    '🤳🏼' => 'selfie: svijetlo maslinasta boja kože',
    '🤳🏽' => 'selfie: maslinasta boja kože',
    '🤳🏾' => 'selfie: smeđa boja kože',
    '🤳🏿' => 'selfie: tamno smeđa boja kože',
    '💪🏻' => 'stegnuti biceps: svijetla boja kože',
    '💪🏼' => 'stegnuti biceps: svijetlo maslinasta boja kože',
    '💪🏽' => 'stegnuti biceps: maslinasta boja kože',
    '💪🏾' => 'stegnuti biceps: smeđa boja kože',
    '💪🏿' => 'stegnuti biceps: tamno smeđa boja kože',
    '🦵🏻' => 'noga: svijetla boja kože',
    '🦵🏼' => 'noga: svijetlo maslinasta boja kože',
    '🦵🏽' => 'noga: maslinasta boja kože',
    '🦵🏾' => 'noga: smeđa boja kože',
    '🦵🏿' => 'noga: tamno smeđa boja kože',
    '🦶🏻' => 'stopalo: svijetla boja kože',
    '🦶🏼' => 'stopalo: svijetlo maslinasta boja kože',
    '🦶🏽' => 'stopalo: maslinasta boja kože',
    '🦶🏾' => 'stopalo: smeđa boja kože',
    '🦶🏿' => 'stopalo: tamno smeđa boja kože',
    '👂🏻' => 'uho: svijetla boja kože',
    '👂🏼' => 'uho: svijetlo maslinasta boja kože',
    '👂🏽' => 'uho: maslinasta boja kože',
    '👂🏾' => 'uho: smeđa boja kože',
    '👂🏿' => 'uho: tamno smeđa boja kože',
    '🦻🏻' => 'uho sa slušnim aparatom: svijetla boja kože',
    '🦻🏼' => 'uho sa slušnim aparatom: svijetlo maslinasta boja kože',
    '🦻🏽' => 'uho sa slušnim aparatom: maslinasta boja kože',
    '🦻🏾' => 'uho sa slušnim aparatom: smeđa boja kože',
    '🦻🏿' => 'uho sa slušnim aparatom: tamno smeđa boja kože',
    '👃🏻' => 'nos: svijetla boja kože',
    '👃🏼' => 'nos: svijetlo maslinasta boja kože',
    '👃🏽' => 'nos: maslinasta boja kože',
    '👃🏾' => 'nos: smeđa boja kože',
    '👃🏿' => 'nos: tamno smeđa boja kože',
    '👶🏻' => 'beba: svijetla boja kože',
    '👶🏼' => 'beba: svijetlo maslinasta boja kože',
    '👶🏽' => 'beba: maslinasta boja kože',
    '👶🏾' => 'beba: smeđa boja kože',
    '👶🏿' => 'beba: tamno smeđa boja kože',
    '🧒🏻' => 'dijete: svijetla boja kože',
    '🧒🏼' => 'dijete: svijetlo maslinasta boja kože',
    '🧒🏽' => 'dijete: maslinasta boja kože',
    '🧒🏾' => 'dijete: smeđa boja kože',
    '🧒🏿' => 'dijete: tamno smeđa boja kože',
    '👦🏻' => 'dječak: svijetla boja kože',
    '👦🏼' => 'dječak: svijetlo maslinasta boja kože',
    '👦🏽' => 'dječak: maslinasta boja kože',
    '👦🏾' => 'dječak: smeđa boja kože',
    '👦🏿' => 'dječak: tamno smeđa boja kože',
    '👧🏻' => 'djevojčica: svijetla boja kože',
    '👧🏼' => 'djevojčica: svijetlo maslinasta boja kože',
    '👧🏽' => 'djevojčica: maslinasta boja kože',
    '👧🏾' => 'djevojčica: smeđa boja kože',
    '👧🏿' => 'djevojčica: tamno smeđa boja kože',
    '🧑🏻' => 'odrasla osoba: svijetla boja kože',
    '🧑🏼' => 'odrasla osoba: svijetlo maslinasta boja kože',
    '🧑🏽' => 'odrasla osoba: maslinasta boja kože',
    '🧑🏾' => 'odrasla osoba: smeđa boja kože',
    '🧑🏿' => 'odrasla osoba: tamno smeđa boja kože',
    '👱🏻' => 'plavokosa osoba: svijetla boja kože',
    '👱🏼' => 'plavokosa osoba: svijetlo maslinasta boja kože',
    '👱🏽' => 'plavokosa osoba: maslinasta boja kože',
    '👱🏾' => 'plavokosa osoba: smeđa boja kože',
    '👱🏿' => 'plavokosa osoba: tamno smeđa boja kože',
    '👨🏻' => 'muškarac: svijetla boja kože',
    '👨🏼' => 'muškarac: svijetlo maslinasta boja kože',
    '👨🏽' => 'muškarac: maslinasta boja kože',
    '👨🏾' => 'muškarac: smeđa boja kože',
    '👨🏿' => 'muškarac: tamno smeđa boja kože',
    '🧔🏻' => 'muškarac s bradom: svijetla boja kože',
    '🧔🏼' => 'muškarac s bradom: svijetlo maslinasta boja kože',
    '🧔🏽' => 'muškarac s bradom: maslinasta boja kože',
    '🧔🏾' => 'muškarac s bradom: smeđa boja kože',
    '🧔🏿' => 'muškarac s bradom: tamno smeđa boja kože',
    '👩🏻' => 'žena: svijetla boja kože',
    '👩🏼' => 'žena: svijetlo maslinasta boja kože',
    '👩🏽' => 'žena: maslinasta boja kože',
    '👩🏾' => 'žena: smeđa boja kože',
    '👩🏿' => 'žena: tamno smeđa boja kože',
    '🧓🏻' => 'starija osoba: svijetla boja kože',
    '🧓🏼' => 'starija osoba: svijetlo maslinasta boja kože',
    '🧓🏽' => 'starija osoba: maslinasta boja kože',
    '🧓🏾' => 'starija osoba: smeđa boja kože',
    '🧓🏿' => 'starija osoba: tamno smeđa boja kože',
    '👴🏻' => 'starac: svijetla boja kože',
    '👴🏼' => 'starac: svijetlo maslinasta boja kože',
    '👴🏽' => 'starac: maslinasta boja kože',
    '👴🏾' => 'starac: smeđa boja kože',
    '👴🏿' => 'starac: tamno smeđa boja kože',
    '👵🏻' => 'starica: svijetla boja kože',
    '👵🏼' => 'starica: svijetlo maslinasta boja kože',
    '👵🏽' => 'starica: maslinasta boja kože',
    '👵🏾' => 'starica: smeđa boja kože',
    '👵🏿' => 'starica: tamno smeđa boja kože',
    '🙍🏻' => 'osoba koja se mršti: svijetla boja kože',
    '🙍🏼' => 'osoba koja se mršti: svijetlo maslinasta boja kože',
    '🙍🏽' => 'osoba koja se mršti: maslinasta boja kože',
    '🙍🏾' => 'osoba koja se mršti: smeđa boja kože',
    '🙍🏿' => 'osoba koja se mršti: tamno smeđa boja kože',
    '🙎🏻' => 'osoba koja se duri: svijetla boja kože',
    '🙎🏼' => 'osoba koja se duri: svijetlo maslinasta boja kože',
    '🙎🏽' => 'osoba koja se duri: maslinasta boja kože',
    '🙎🏾' => 'osoba koja se duri: smeđa boja kože',
    '🙎🏿' => 'osoba koja se duri: tamno smeđa boja kože',
    '🙅🏻' => 'osoba pokazuje "ne": svijetla boja kože',
    '🙅🏼' => 'osoba pokazuje "ne": svijetlo maslinasta boja kože',
    '🙅🏽' => 'osoba pokazuje "ne": maslinasta boja kože',
    '🙅🏾' => 'osoba pokazuje "ne": smeđa boja kože',
    '🙅🏿' => 'osoba pokazuje "ne": tamno smeđa boja kože',
    '🙆🏻' => 'osoba pokazuje "u redu": svijetla boja kože',
    '🙆🏼' => 'osoba pokazuje "u redu": svijetlo maslinasta boja kože',
    '🙆🏽' => 'osoba pokazuje "u redu": maslinasta boja kože',
    '🙆🏾' => 'osoba pokazuje "u redu": smeđa boja kože',
    '🙆🏿' => 'osoba pokazuje "u redu": tamno smeđa boja kože',
    '💁🏻' => 'osoba s nagnutim dlanom: svijetla boja kože',
    '💁🏼' => 'osoba s nagnutim dlanom: svijetlo maslinasta boja kože',
    '💁🏽' => 'osoba s nagnutim dlanom: maslinasta boja kože',
    '💁🏾' => 'osoba s nagnutim dlanom: smeđa boja kože',
    '💁🏿' => 'osoba s nagnutim dlanom: tamno smeđa boja kože',
    '🙋🏻' => 'osoba s podignutom rukom: svijetla boja kože',
    '🙋🏼' => 'osoba s podignutom rukom: svijetlo maslinasta boja kože',
    '🙋🏽' => 'osoba s podignutom rukom: maslinasta boja kože',
    '🙋🏾' => 'osoba s podignutom rukom: smeđa boja kože',
    '🙋🏿' => 'osoba s podignutom rukom: tamno smeđa boja kože',
    '🧏🏻' => 'gluha osoba: svijetla boja kože',
    '🧏🏼' => 'gluha osoba: svijetlo maslinasta boja kože',
    '🧏🏽' => 'gluha osoba: maslinasta boja kože',
    '🧏🏾' => 'gluha osoba: smeđa boja kože',
    '🧏🏿' => 'gluha osoba: tamno smeđa boja kože',
    '🙇🏻' => 'osoba koja se klanja: svijetla boja kože',
    '🙇🏼' => 'osoba koja se klanja: svijetlo maslinasta boja kože',
    '🙇🏽' => 'osoba koja se klanja: maslinasta boja kože',
    '🙇🏾' => 'osoba koja se klanja: smeđa boja kože',
    '🙇🏿' => 'osoba koja se klanja: tamno smeđa boja kože',
    '🤦🏻' => 'lupanje dlanom o čelo: svijetla boja kože',
    '🤦🏼' => 'lupanje dlanom o čelo: svijetlo maslinasta boja kože',
    '🤦🏽' => 'lupanje dlanom o čelo: maslinasta boja kože',
    '🤦🏾' => 'lupanje dlanom o čelo: smeđa boja kože',
    '🤦🏿' => 'lupanje dlanom o čelo: tamno smeđa boja kože',
    '🤷🏻' => 'slijeganje ramenima: svijetla boja kože',
    '🤷🏼' => 'slijeganje ramenima: svijetlo maslinasta boja kože',
    '🤷🏽' => 'slijeganje ramenima: maslinasta boja kože',
    '🤷🏾' => 'slijeganje ramenima: smeđa boja kože',
    '🤷🏿' => 'slijeganje ramenima: tamno smeđa boja kože',
    '👮🏻' => 'policajac: svijetla boja kože',
    '👮🏼' => 'policajac: svijetlo maslinasta boja kože',
    '👮🏽' => 'policajac: maslinasta boja kože',
    '👮🏾' => 'policajac: smeđa boja kože',
    '👮🏿' => 'policajac: tamno smeđa boja kože',
    '🕵🏻' => 'detektiv: svijetla boja kože',
    '🕵🏼' => 'detektiv: svijetlo maslinasta boja kože',
    '🕵🏽' => 'detektiv: maslinasta boja kože',
    '🕵🏾' => 'detektiv: smeđa boja kože',
    '🕵🏿' => 'detektiv: tamno smeđa boja kože',
    '💂🏻' => 'čuvar: svijetla boja kože',
    '💂🏼' => 'čuvar: svijetlo maslinasta boja kože',
    '💂🏽' => 'čuvar: maslinasta boja kože',
    '💂🏾' => 'čuvar: smeđa boja kože',
    '💂🏿' => 'čuvar: tamno smeđa boja kože',
    '🥷🏻' => 'nindža: svijetla boja kože',
    '🥷🏼' => 'nindža: svijetlo maslinasta boja kože',
    '🥷🏽' => 'nindža: maslinasta boja kože',
    '🥷🏾' => 'nindža: smeđa boja kože',
    '🥷🏿' => 'nindža: tamno smeđa boja kože',
    '👷🏻' => 'građevinski radnik: svijetla boja kože',
    '👷🏼' => 'građevinski radnik: svijetlo maslinasta boja kože',
    '👷🏽' => 'građevinski radnik: maslinasta boja kože',
    '👷🏾' => 'građevinski radnik: smeđa boja kože',
    '👷🏿' => 'građevinski radnik: tamno smeđa boja kože',
    '🫅🏻' => 'osoba s krunom: svijetla boja kože',
    '🫅🏼' => 'osoba s krunom: svijetlo maslinasta boja kože',
    '🫅🏽' => 'osoba s krunom: maslinasta boja kože',
    '🫅🏾' => 'osoba s krunom: smeđa boja kože',
    '🫅🏿' => 'osoba s krunom: tamno smeđa boja kože',
    '🤴🏻' => 'princ: svijetla boja kože',
    '🤴🏼' => 'princ: svijetlo maslinasta boja kože',
    '🤴🏽' => 'princ: maslinasta boja kože',
    '🤴🏾' => 'princ: smeđa boja kože',
    '🤴🏿' => 'princ: tamno smeđa boja kože',
    '👸🏻' => 'princeza: svijetla boja kože',
    '👸🏼' => 'princeza: svijetlo maslinasta boja kože',
    '👸🏽' => 'princeza: maslinasta boja kože',
    '👸🏾' => 'princeza: smeđa boja kože',
    '👸🏿' => 'princeza: tamno smeđa boja kože',
    '👳🏻' => 'osoba s turbanom: svijetla boja kože',
    '👳🏼' => 'osoba s turbanom: svijetlo maslinasta boja kože',
    '👳🏽' => 'osoba s turbanom: maslinasta boja kože',
    '👳🏾' => 'osoba s turbanom: smeđa boja kože',
    '👳🏿' => 'osoba s turbanom: tamno smeđa boja kože',
    '👲🏻' => 'muškarac s kineskom kapom: svijetla boja kože',
    '👲🏼' => 'muškarac s kineskom kapom: svijetlo maslinasta boja kože',
    '👲🏽' => 'muškarac s kineskom kapom: maslinasta boja kože',
    '👲🏾' => 'muškarac s kineskom kapom: smeđa boja kože',
    '👲🏿' => 'muškarac s kineskom kapom: tamno smeđa boja kože',
    '🧕🏻' => 'žena s maramom: svijetla boja kože',
    '🧕🏼' => 'žena s maramom: svijetlo maslinasta boja kože',
    '🧕🏽' => 'žena s maramom: maslinasta boja kože',
    '🧕🏾' => 'žena s maramom: smeđa boja kože',
    '🧕🏿' => 'žena s maramom: tamno smeđa boja kože',
    '🤵🏻' => 'osoba u smokingu: svijetla boja kože',
    '🤵🏼' => 'osoba u smokingu: svijetlo maslinasta boja kože',
    '🤵🏽' => 'osoba u smokingu: maslinasta boja kože',
    '🤵🏾' => 'osoba u smokingu: smeđa boja kože',
    '🤵🏿' => 'osoba u smokingu: tamno smeđa boja kože',
    '👰🏻' => 'nevjesta s velom: svijetla boja kože',
    '👰🏼' => 'nevjesta s velom: svijetlo maslinasta boja kože',
    '👰🏽' => 'nevjesta s velom: maslinasta boja kože',
    '👰🏾' => 'nevjesta s velom: smeđa boja kože',
    '👰🏿' => 'nevjesta s velom: tamno smeđa boja kože',
    '🤰🏻' => 'trudnica: svijetla boja kože',
    '🤰🏼' => 'trudnica: svijetlo maslinasta boja kože',
    '🤰🏽' => 'trudnica: maslinasta boja kože',
    '🤰🏾' => 'trudnica: smeđa boja kože',
    '🤰🏿' => 'trudnica: tamno smeđa boja kože',
    '🫃🏻' => 'trudni muškarac: svijetla boja kože',
    '🫃🏼' => 'trudni muškarac: svijetlo maslinasta boja kože',
    '🫃🏽' => 'trudni muškarac: maslinasta boja kože',
    '🫃🏾' => 'trudni muškarac: smeđa boja kože',
    '🫃🏿' => 'trudni muškarac: tamno smeđa boja kože',
    '🫄🏻' => 'trudna osoba: svijetla boja kože',
    '🫄🏼' => 'trudna osoba: svijetlo maslinasta boja kože',
    '🫄🏽' => 'trudna osoba: maslinasta boja kože',
    '🫄🏾' => 'trudna osoba: smeđa boja kože',
    '🫄🏿' => 'trudna osoba: tamno smeđa boja kože',
    '🤱🏻' => 'dojenje: svijetla boja kože',
    '🤱🏼' => 'dojenje: svijetlo maslinasta boja kože',
    '🤱🏽' => 'dojenje: maslinasta boja kože',
    '🤱🏾' => 'dojenje: smeđa boja kože',
    '🤱🏿' => 'dojenje: tamno smeđa boja kože',
    '👼🏻' => 'beba anđeo: svijetla boja kože',
    '👼🏼' => 'beba anđeo: svijetlo maslinasta boja kože',
    '👼🏽' => 'beba anđeo: maslinasta boja kože',
    '👼🏾' => 'beba anđeo: smeđa boja kože',
    '👼🏿' => 'beba anđeo: tamno smeđa boja kože',
    '🎅🏻' => 'Djed Božićnjak: svijetla boja kože',
    '🎅🏼' => 'Djed Božićnjak: svijetlo maslinasta boja kože',
    '🎅🏽' => 'Djed Božićnjak: maslinasta boja kože',
    '🎅🏾' => 'Djed Božićnjak: smeđa boja kože',
    '🎅🏿' => 'Djed Božićnjak: tamno smeđa boja kože',
    '🤶🏻' => 'Baka Mraz: svijetla boja kože',
    '🤶🏼' => 'Baka Mraz: svijetlo maslinasta boja kože',
    '🤶🏽' => 'Baka Mraz: maslinasta boja kože',
    '🤶🏾' => 'Baka Mraz: smeđa boja kože',
    '🤶🏿' => 'Baka Mraz: tamno smeđa boja kože',
    '🦸🏻' => 'superheroj: svijetla boja kože',
    '🦸🏼' => 'superheroj: svijetlo maslinasta boja kože',
    '🦸🏽' => 'superheroj: maslinasta boja kože',
    '🦸🏾' => 'superheroj: smeđa boja kože',
    '🦸🏿' => 'superheroj: tamno smeđa boja kože',
    '🦹🏻' => 'zločinac: svijetla boja kože',
    '🦹🏼' => 'zločinac: svijetlo maslinasta boja kože',
    '🦹🏽' => 'zločinac: maslinasta boja kože',
    '🦹🏾' => 'zločinac: smeđa boja kože',
    '🦹🏿' => 'zločinac: tamno smeđa boja kože',
    '🧙🏻' => 'magičar: svijetla boja kože',
    '🧙🏼' => 'magičar: svijetlo maslinasta boja kože',
    '🧙🏽' => 'magičar: maslinasta boja kože',
    '🧙🏾' => 'magičar: smeđa boja kože',
    '🧙🏿' => 'magičar: tamno smeđa boja kože',
    '🧚🏻' => 'vilinsko biće: svijetla boja kože',
    '🧚🏼' => 'vilinsko biće: svijetlo maslinasta boja kože',
    '🧚🏽' => 'vilinsko biće: maslinasta boja kože',
    '🧚🏾' => 'vilinsko biće: smeđa boja kože',
    '🧚🏿' => 'vilinsko biće: tamno smeđa boja kože',
    '🧛🏻' => 'neživa osoba: svijetla boja kože',
    '🧛🏼' => 'neživa osoba: svijetlo maslinasta boja kože',
    '🧛🏽' => 'neživa osoba: maslinasta boja kože',
    '🧛🏾' => 'neživa osoba: smeđa boja kože',
    '🧛🏿' => 'neživa osoba: tamno smeđa boja kože',
    '🧜🏻' => 'morska sirena: svijetla boja kože',
    '🧜🏼' => 'morska sirena: svijetlo maslinasta boja kože',
    '🧜🏽' => 'morska sirena: maslinasta boja kože',
    '🧜🏾' => 'morska sirena: smeđa boja kože',
    '🧜🏿' => 'morska sirena: tamno smeđa boja kože',
    '🧝🏻' => 'šumski vilenjak: svijetla boja kože',
    '🧝🏼' => 'šumski vilenjak: svijetlo maslinasta boja kože',
    '🧝🏽' => 'šumski vilenjak: maslinasta boja kože',
    '🧝🏾' => 'šumski vilenjak: smeđa boja kože',
    '🧝🏿' => 'šumski vilenjak: tamno smeđa boja kože',
    '💆🏻' => 'osoba na masaži: svijetla boja kože',
    '💆🏼' => 'osoba na masaži: svijetlo maslinasta boja kože',
    '💆🏽' => 'osoba na masaži: maslinasta boja kože',
    '💆🏾' => 'osoba na masaži: smeđa boja kože',
    '💆🏿' => 'osoba na masaži: tamno smeđa boja kože',
    '💇🏻' => 'šišanje: svijetla boja kože',
    '💇🏼' => 'šišanje: svijetlo maslinasta boja kože',
    '💇🏽' => 'šišanje: maslinasta boja kože',
    '💇🏾' => 'šišanje: smeđa boja kože',
    '💇🏿' => 'šišanje: tamno smeđa boja kože',
    '🚶🏻' => 'pješak: svijetla boja kože',
    '🚶🏼' => 'pješak: svijetlo maslinasta boja kože',
    '🚶🏽' => 'pješak: maslinasta boja kože',
    '🚶🏾' => 'pješak: smeđa boja kože',
    '🚶🏿' => 'pješak: tamno smeđa boja kože',
    '🧍🏻' => 'osoba stoji: svijetla boja kože',
    '🧍🏼' => 'osoba stoji: svijetlo maslinasta boja kože',
    '🧍🏽' => 'osoba stoji: maslinasta boja kože',
    '🧍🏾' => 'osoba stoji: smeđa boja kože',
    '🧍🏿' => 'osoba stoji: tamno smeđa boja kože',
    '🧎🏻' => 'osoba kleči: svijetla boja kože',
    '🧎🏼' => 'osoba kleči: svijetlo maslinasta boja kože',
    '🧎🏽' => 'osoba kleči: maslinasta boja kože',
    '🧎🏾' => 'osoba kleči: smeđa boja kože',
    '🧎🏿' => 'osoba kleči: tamno smeđa boja kože',
    '🏃🏻' => 'osoba trči: svijetla boja kože',
    '🏃🏼' => 'osoba trči: svijetlo maslinasta boja kože',
    '🏃🏽' => 'osoba trči: maslinasta boja kože',
    '🏃🏾' => 'osoba trči: smeđa boja kože',
    '🏃🏿' => 'osoba trči: tamno smeđa boja kože',
    '💃🏻' => 'žena pleše: svijetla boja kože',
    '💃🏼' => 'žena pleše: svijetlo maslinasta boja kože',
    '💃🏽' => 'žena pleše: maslinasta boja kože',
    '💃🏾' => 'žena pleše: smeđa boja kože',
    '💃🏿' => 'žena pleše: tamno smeđa boja kože',
    '🕺🏻' => 'muškarac pleše: svijetla boja kože',
    '🕺🏼' => 'muškarac pleše: svijetlo maslinasta boja kože',
    '🕺🏽' => 'muškarac pleše: maslinasta boja kože',
    '🕺🏾' => 'muškarac pleše: smeđa boja kože',
    '🕺🏿' => 'muškarac pleše: tamno smeđa boja kože',
    '🕴🏻' => 'muškarac u poslovnom odijelu koji levitira: svijetla boja kože',
    '🕴🏼' => 'muškarac u poslovnom odijelu koji levitira: svijetlo maslinasta boja kože',
    '🕴🏽' => 'muškarac u poslovnom odijelu koji levitira: maslinasta boja kože',
    '🕴🏾' => 'muškarac u poslovnom odijelu koji levitira: smeđa boja kože',
    '🕴🏿' => 'muškarac u poslovnom odijelu koji levitira: tamno smeđa boja kože',
    '👯🏻' => 'osobe sa zečjim ušima: svijetla boja kože',
    '👯🏼' => 'osobe sa zečjim ušima: svijetlo maslinasta boja kože',
    '👯🏽' => 'osobe sa zečjim ušima: maslinasta boja kože',
    '👯🏾' => 'osobe sa zečjim ušima: smeđa boja kože',
    '👯🏿' => 'osobe sa zečjim ušima: tamno smeđa boja kože',
    '🧖🏻' => 'osoba u sauni: svijetla boja kože',
    '🧖🏼' => 'osoba u sauni: svijetlo maslinasta boja kože',
    '🧖🏽' => 'osoba u sauni: maslinasta boja kože',
    '🧖🏾' => 'osoba u sauni: smeđa boja kože',
    '🧖🏿' => 'osoba u sauni: tamno smeđa boja kože',
    '🧗🏻' => 'osoba se penje: svijetla boja kože',
    '🧗🏼' => 'osoba se penje: svijetlo maslinasta boja kože',
    '🧗🏽' => 'osoba se penje: maslinasta boja kože',
    '🧗🏾' => 'osoba se penje: smeđa boja kože',
    '🧗🏿' => 'osoba se penje: tamno smeđa boja kože',
    '🏇🏻' => 'konjičke utrke: svijetla boja kože',
    '🏇🏼' => 'konjičke utrke: svijetlo maslinasta boja kože',
    '🏇🏽' => 'konjičke utrke: maslinasta boja kože',
    '🏇🏾' => 'konjičke utrke: smeđa boja kože',
    '🏇🏿' => 'konjičke utrke: tamno smeđa boja kože',
    '🏂🏻' => 'snowboarder: svijetla boja kože',
    '🏂🏼' => 'snowboarder: svijetlo maslinasta boja kože',
    '🏂🏽' => 'snowboarder: maslinasta boja kože',
    '🏂🏾' => 'snowboarder: smeđa boja kože',
    '🏂🏿' => 'snowboarder: tamno smeđa boja kože',
    '🏌🏻' => 'osoba igra golf: svijetla boja kože',
    '🏌🏼' => 'osoba igra golf: svijetlo maslinasta boja kože',
    '🏌🏽' => 'osoba igra golf: maslinasta boja kože',
    '🏌🏾' => 'osoba igra golf: smeđa boja kože',
    '🏌🏿' => 'osoba igra golf: tamno smeđa boja kože',
    '🏄🏻' => 'surfer: svijetla boja kože',
    '🏄🏼' => 'surfer: svijetlo maslinasta boja kože',
    '🏄🏽' => 'surfer: maslinasta boja kože',
    '🏄🏾' => 'surfer: smeđa boja kože',
    '🏄🏿' => 'surfer: tamno smeđa boja kože',
    '🚣🏻' => 'osoba vesla: svijetla boja kože',
    '🚣🏼' => 'osoba vesla: svijetlo maslinasta boja kože',
    '🚣🏽' => 'osoba vesla: maslinasta boja kože',
    '🚣🏾' => 'osoba vesla: smeđa boja kože',
    '🚣🏿' => 'osoba vesla: tamno smeđa boja kože',
    '🏊🏻' => 'osoba pliva: svijetla boja kože',
    '🏊🏼' => 'osoba pliva: svijetlo maslinasta boja kože',
    '🏊🏽' => 'osoba pliva: maslinasta boja kože',
    '🏊🏾' => 'osoba pliva: smeđa boja kože',
    '🏊🏿' => 'osoba pliva: tamno smeđa boja kože',
    '⛹🏻' => 'osoba vodi loptu: svijetla boja kože',
    '⛹🏼' => 'osoba vodi loptu: svijetlo maslinasta boja kože',
    '⛹🏽' => 'osoba vodi loptu: maslinasta boja kože',
    '⛹🏾' => 'osoba vodi loptu: smeđa boja kože',
    '⛹🏿' => 'osoba vodi loptu: tamno smeđa boja kože',
    '🏋🏻' => 'osoba diže utege: svijetla boja kože',
    '🏋🏼' => 'osoba diže utege: svijetlo maslinasta boja kože',
    '🏋🏽' => 'osoba diže utege: maslinasta boja kože',
    '🏋🏾' => 'osoba diže utege: smeđa boja kože',
    '🏋🏿' => 'osoba diže utege: tamno smeđa boja kože',
    '🚴🏻' => 'osoba vozi bicikl: svijetla boja kože',
    '🚴🏼' => 'osoba vozi bicikl: svijetlo maslinasta boja kože',
    '🚴🏽' => 'osoba vozi bicikl: maslinasta boja kože',
    '🚴🏾' => 'osoba vozi bicikl: smeđa boja kože',
    '🚴🏿' => 'osoba vozi bicikl: tamno smeđa boja kože',
    '🚵🏻' => 'osoba vozi brdski bicikl: svijetla boja kože',
    '🚵🏼' => 'osoba vozi brdski bicikl: svijetlo maslinasta boja kože',
    '🚵🏽' => 'osoba vozi brdski bicikl: maslinasta boja kože',
    '🚵🏾' => 'osoba vozi brdski bicikl: smeđa boja kože',
    '🚵🏿' => 'osoba vozi brdski bicikl: tamno smeđa boja kože',
    '🤸🏻' => 'osoba izvodi zvijezdu: svijetla boja kože',
    '🤸🏼' => 'osoba izvodi zvijezdu: svijetlo maslinasta boja kože',
    '🤸🏽' => 'osoba izvodi zvijezdu: maslinasta boja kože',
    '🤸🏾' => 'osoba izvodi zvijezdu: smeđa boja kože',
    '🤸🏿' => 'osoba izvodi zvijezdu: tamno smeđa boja kože',
    '🤼🏻' => 'osobe se hrvaju: svijetla boja kože',
    '🤼🏼' => 'osobe se hrvaju: svijetlo maslinasta boja kože',
    '🤼🏽' => 'osobe se hrvaju: maslinasta boja kože',
    '🤼🏾' => 'osobe se hrvaju: smeđa boja kože',
    '🤼🏿' => 'osobe se hrvaju: tamno smeđa boja kože',
    '🤽🏻' => 'osobe igraju vaterpolo: svijetla boja kože',
    '🤽🏼' => 'osobe igraju vaterpolo: svijetlo maslinasta boja kože',
    '🤽🏽' => 'osobe igraju vaterpolo: maslinasta boja kože',
    '🤽🏾' => 'osobe igraju vaterpolo: smeđa boja kože',
    '🤽🏿' => 'osobe igraju vaterpolo: tamno smeđa boja kože',
    '🤾🏻' => 'osoba igra rukomet: svijetla boja kože',
    '🤾🏼' => 'osoba igra rukomet: svijetlo maslinasta boja kože',
    '🤾🏽' => 'osoba igra rukomet: maslinasta boja kože',
    '🤾🏾' => 'osoba igra rukomet: smeđa boja kože',
    '🤾🏿' => 'osoba igra rukomet: tamno smeđa boja kože',
    '🤹🏻' => 'osoba žonglira: svijetla boja kože',
    '🤹🏼' => 'osoba žonglira: svijetlo maslinasta boja kože',
    '🤹🏽' => 'osoba žonglira: maslinasta boja kože',
    '🤹🏾' => 'osoba žonglira: smeđa boja kože',
    '🤹🏿' => 'osoba žonglira: tamno smeđa boja kože',
    '🧘🏻' => 'osoba u položaju lotosa: svijetla boja kože',
    '🧘🏼' => 'osoba u položaju lotosa: svijetlo maslinasta boja kože',
    '🧘🏽' => 'osoba u položaju lotosa: maslinasta boja kože',
    '🧘🏾' => 'osoba u položaju lotosa: smeđa boja kože',
    '🧘🏿' => 'osoba u položaju lotosa: tamno smeđa boja kože',
    '🛀🏻' => 'osoba koja se kupa u kadi: svijetla boja kože',
    '🛀🏼' => 'osoba koja se kupa u kadi: svijetlo maslinasta boja kože',
    '🛀🏽' => 'osoba koja se kupa u kadi: maslinasta boja kože',
    '🛀🏾' => 'osoba koja se kupa u kadi: smeđa boja kože',
    '🛀🏿' => 'osoba koja se kupa u kadi: tamno smeđa boja kože',
    '🛌🏻' => 'osoba u krevetu: svijetla boja kože',
    '🛌🏼' => 'osoba u krevetu: svijetlo maslinasta boja kože',
    '🛌🏽' => 'osoba u krevetu: maslinasta boja kože',
    '🛌🏾' => 'osoba u krevetu: smeđa boja kože',
    '🛌🏿' => 'osoba u krevetu: tamno smeđa boja kože',
    '👭🏻' => 'žene koje se drže za ruke: svijetla boja kože',
    '👭🏼' => 'žene koje se drže za ruke: svijetlo maslinasta boja kože',
    '👭🏽' => 'žene koje se drže za ruke: maslinasta boja kože',
    '👭🏾' => 'žene koje se drže za ruke: smeđa boja kože',
    '👭🏿' => 'žene koje se drže za ruke: tamno smeđa boja kože',
    '👫🏻' => 'muškarac i žena koji se drže za ruke: svijetla boja kože',
    '👫🏼' => 'muškarac i žena koji se drže za ruke: svijetlo maslinasta boja kože',
    '👫🏽' => 'muškarac i žena koji se drže za ruke: maslinasta boja kože',
    '👫🏾' => 'muškarac i žena koji se drže za ruke: smeđa boja kože',
    '👫🏿' => 'muškarac i žena koji se drže za ruke: tamno smeđa boja kože',
    '👬🏻' => 'muškarci koji se drže za ruke: svijetla boja kože',
    '👬🏼' => 'muškarci koji se drže za ruke: svijetlo maslinasta boja kože',
    '👬🏽' => 'muškarci koji se drže za ruke: maslinasta boja kože',
    '👬🏾' => 'muškarci koji se drže za ruke: smeđa boja kože',
    '👬🏿' => 'muškarci koji se drže za ruke: tamno smeđa boja kože',
    '💏🏻' => 'poljubac: svijetla boja kože',
    '💏🏼' => 'poljubac: svijetlo maslinasta boja kože',
    '💏🏽' => 'poljubac: maslinasta boja kože',
    '💏🏾' => 'poljubac: smeđa boja kože',
    '💏🏿' => 'poljubac: tamno smeđa boja kože',
    '💑🏻' => 'par sa srcem: svijetla boja kože',
    '💑🏼' => 'par sa srcem: svijetlo maslinasta boja kože',
    '💑🏽' => 'par sa srcem: maslinasta boja kože',
    '💑🏾' => 'par sa srcem: smeđa boja kože',
    '💑🏿' => 'par sa srcem: tamno smeđa boja kože',
    '🇦🇨' => 'zastava: Otok Uzašašća',
    '🇦🇩' => 'zastava: Andora',
    '🇦🇪' => 'zastava: Ujedinjeni Arapski Emirati',
    '🇦🇫' => 'zastava: Afganistan',
    '🇦🇬' => 'zastava: Antigva i Barbuda',
    '🇦🇮' => 'zastava: Angvila',
    '🇦🇱' => 'zastava: Albanija',
    '🇦🇲' => 'zastava: Armenija',
    '🇦🇴' => 'zastava: Angola',
    '🇦🇶' => 'zastava: Antarktika',
    '🇦🇷' => 'zastava: Argentina',
    '🇦🇸' => 'zastava: Američka Samoa',
    '🇦🇹' => 'zastava: Austrija',
    '🇦🇺' => 'zastava: Australija',
    '🇦🇼' => 'zastava: Aruba',
    '🇦🇽' => 'zastava: Ålandski otoci',
    '🇦🇿' => 'zastava: Azerbajdžan',
    '🇧🇦' => 'zastava: Bosna i Hercegovina',
    '🇧🇧' => 'zastava: Barbados',
    '🇧🇩' => 'zastava: Bangladeš',
    '🇧🇪' => 'zastava: Belgija',
    '🇧🇫' => 'zastava: Burkina Faso',
    '🇧🇬' => 'zastava: Bugarska',
    '🇧🇭' => 'zastava: Bahrein',
    '🇧🇮' => 'zastava: Burundi',
    '🇧🇯' => 'zastava: Benin',
    '🇧🇱' => 'zastava: Saint Barthélemy',
    '🇧🇲' => 'zastava: Bermudi',
    '🇧🇳' => 'zastava: Brunej',
    '🇧🇴' => 'zastava: Bolivija',
    '🇧🇶' => 'zastava: Karipski otoci Nizozemske',
    '🇧🇷' => 'zastava: Brazil',
    '🇧🇸' => 'zastava: Bahami',
    '🇧🇹' => 'zastava: Butan',
    '🇧🇻' => 'zastava: Otok Bouvet',
    '🇧🇼' => 'zastava: Bocvana',
    '🇧🇾' => 'zastava: Bjelorusija',
    '🇧🇿' => 'zastava: Belize',
    '🇨🇦' => 'zastava: Kanada',
    '🇨🇨' => 'zastava: Kokosovi (Keelingovi) Otoci',
    '🇨🇩' => 'zastava: Kongo - Kinshasa',
    '🇨🇫' => 'zastava: Srednjoafrička Republika',
    '🇨🇬' => 'zastava: Kongo - Brazzaville',
    '🇨🇭' => 'zastava: Švicarska',
    '🇨🇮' => 'zastava: Obala Bjelokosti',
    '🇨🇰' => 'zastava: Cookovi Otoci',
    '🇨🇱' => 'zastava: Čile',
    '🇨🇲' => 'zastava: Kamerun',
    '🇨🇳' => 'zastava: Kina',
    '🇨🇴' => 'zastava: Kolumbija',
    '🇨🇵' => 'zastava: Otok Clipperton',
    '🇨🇶' => 'zastava: Sark',
    '🇨🇷' => 'zastava: Kostarika',
    '🇨🇺' => 'zastava: Kuba',
    '🇨🇻' => 'zastava: Zelenortska Republika',
    '🇨🇼' => 'zastava: Curaçao',
    '🇨🇽' => 'zastava: Božićni Otok',
    '🇨🇾' => 'zastava: Cipar',
    '🇨🇿' => 'zastava: Češka',
    '🇩🇪' => 'zastava: Njemačka',
    '🇩🇬' => 'zastava: Diego Garcia',
    '🇩🇯' => 'zastava: Džibuti',
    '🇩🇰' => 'zastava: Danska',
    '🇩🇲' => 'zastava: Dominika',
    '🇩🇴' => 'zastava: Dominikanska Republika',
    '🇩🇿' => 'zastava: Alžir',
    '🇪🇦' => 'zastava: Ceuta i Melilla',
    '🇪🇨' => 'zastava: Ekvador',
    '🇪🇪' => 'zastava: Estonija',
    '🇪🇬' => 'zastava: Egipat',
    '🇪🇭' => 'zastava: Zapadna Sahara',
    '🇪🇷' => 'zastava: Eritreja',
    '🇪🇸' => 'zastava: Španjolska',
    '🇪🇹' => 'zastava: Etiopija',
    '🇪🇺' => 'zastava: Europska unija',
    '🇫🇮' => 'zastava: Finska',
    '🇫🇯' => 'zastava: Fidži',
    '🇫🇰' => 'zastava: Falklandski Otoci',
    '🇫🇲' => 'zastava: Mikronezija',
    '🇫🇴' => 'zastava: Farski Otoci',
    '🇫🇷' => 'zastava: Francuska',
    '🇬🇦' => 'zastava: Gabon',
    '🇬🇧' => 'zastava: Ujedinjeno Kraljevstvo',
    '🇬🇩' => 'zastava: Grenada',
    '🇬🇪' => 'zastava: Gruzija',
    '🇬🇫' => 'zastava: Francuska Gijana',
    '🇬🇬' => 'zastava: Guernsey',
    '🇬🇭' => 'zastava: Gana',
    '🇬🇮' => 'zastava: Gibraltar',
    '🇬🇱' => 'zastava: Grenland',
    '🇬🇲' => 'zastava: Gambija',
    '🇬🇳' => 'zastava: Gvineja',
    '🇬🇵' => 'zastava: Guadalupe',
    '🇬🇶' => 'zastava: Ekvatorska Gvineja',
    '🇬🇷' => 'zastava: Grčka',
    '🇬🇸' => 'zastava: Južna Georgia i Otoci Južni Sandwich',
    '🇬🇹' => 'zastava: Gvatemala',
    '🇬🇺' => 'zastava: Guam',
    '🇬🇼' => 'zastava: Gvineja Bisau',
    '🇬🇾' => 'zastava: Gvajana',
    '🇭🇰' => 'zastava: PUP Hong Kong Kina',
    '🇭🇲' => 'zastava: Otoci Heard i McDonald',
    '🇭🇳' => 'zastava: Honduras',
    '🇭🇷' => 'zastava: Hrvatska',
    '🇭🇹' => 'zastava: Haiti',
    '🇭🇺' => 'zastava: Mađarska',
    '🇮🇨' => 'zastava: Kanari',
    '🇮🇩' => 'zastava: Indonezija',
    '🇮🇪' => 'zastava: Irska',
    '🇮🇱' => 'zastava: Izrael',
    '🇮🇲' => 'zastava: Otok Man',
    '🇮🇳' => 'zastava: Indija',
    '🇮🇴' => 'zastava: Britanski Indijskooceanski Teritorij',
    '🇮🇶' => 'zastava: Irak',
    '🇮🇷' => 'zastava: Iran',
    '🇮🇸' => 'zastava: Island',
    '🇮🇹' => 'zastava: Italija',
    '🇯🇪' => 'zastava: Jersey',
    '🇯🇲' => 'zastava: Jamajka',
    '🇯🇴' => 'zastava: Jordan',
    '🇯🇵' => 'zastava: Japan',
    '🇰🇪' => 'zastava: Kenija',
    '🇰🇬' => 'zastava: Kirgistan',
    '🇰🇭' => 'zastava: Kambodža',
    '🇰🇮' => 'zastava: Kiribati',
    '🇰🇲' => 'zastava: Komori',
    '🇰🇳' => 'zastava: Sveti Kristofor i Nevis',
    '🇰🇵' => 'zastava: Sjeverna Koreja',
    '🇰🇷' => 'zastava: Južna Koreja',
    '🇰🇼' => 'zastava: Kuvajt',
    '🇰🇾' => 'zastava: Kajmanski Otoci',
    '🇰🇿' => 'zastava: Kazahstan',
    '🇱🇦' => 'zastava: Laos',
    '🇱🇧' => 'zastava: Libanon',
    '🇱🇨' => 'zastava: Sveta Lucija',
    '🇱🇮' => 'zastava: Lihtenštajn',
    '🇱🇰' => 'zastava: Šri Lanka',
    '🇱🇷' => 'zastava: Liberija',
    '🇱🇸' => 'zastava: Lesoto',
    '🇱🇹' => 'zastava: Litva',
    '🇱🇺' => 'zastava: Luksemburg',
    '🇱🇻' => 'zastava: Latvija',
    '🇱🇾' => 'zastava: Libija',
    '🇲🇦' => 'zastava: Maroko',
    '🇲🇨' => 'zastava: Monako',
    '🇲🇩' => 'zastava: Moldavija',
    '🇲🇪' => 'zastava: Crna Gora',
    '🇲🇫' => 'zastava: Saint Martin',
    '🇲🇬' => 'zastava: Madagaskar',
    '🇲🇭' => 'zastava: Maršalovi Otoci',
    '🇲🇰' => 'zastava: Sjeverna Makedonija',
    '🇲🇱' => 'zastava: Mali',
    '🇲🇲' => 'zastava: Mjanmar (Burma)',
    '🇲🇳' => 'zastava: Mongolija',
    '🇲🇴' => 'zastava: PUP Makao Kina',
    '🇲🇵' => 'zastava: Sjevernomarijanski Otoci',
    '🇲🇶' => 'zastava: Martinik',
    '🇲🇷' => 'zastava: Mauretanija',
    '🇲🇸' => 'zastava: Montserrat',
    '🇲🇹' => 'zastava: Malta',
    '🇲🇺' => 'zastava: Mauricijus',
    '🇲🇻' => 'zastava: Maldivi',
    '🇲🇼' => 'zastava: Malavi',
    '🇲🇽' => 'zastava: Meksiko',
    '🇲🇾' => 'zastava: Malezija',
    '🇲🇿' => 'zastava: Mozambik',
    '🇳🇦' => 'zastava: Namibija',
    '🇳🇨' => 'zastava: Nova Kaledonija',
    '🇳🇪' => 'zastava: Niger',
    '🇳🇫' => 'zastava: Otok Norfolk',
    '🇳🇬' => 'zastava: Nigerija',
    '🇳🇮' => 'zastava: Nikaragva',
    '🇳🇱' => 'zastava: Nizozemska',
    '🇳🇴' => 'zastava: Norveška',
    '🇳🇵' => 'zastava: Nepal',
    '🇳🇷' => 'zastava: Nauru',
    '🇳🇺' => 'zastava: Niue',
    '🇳🇿' => 'zastava: Novi Zeland',
    '🇴🇲' => 'zastava: Oman',
    '🇵🇦' => 'zastava: Panama',
    '🇵🇪' => 'zastava: Peru',
    '🇵🇫' => 'zastava: Francuska Polinezija',
    '🇵🇬' => 'zastava: Papua Nova Gvineja',
    '🇵🇭' => 'zastava: Filipini',
    '🇵🇰' => 'zastava: Pakistan',
    '🇵🇱' => 'zastava: Poljska',
    '🇵🇲' => 'zastava: Sveti Petar i Mikelon',
    '🇵🇳' => 'zastava: Pitcairnovi Otoci',
    '🇵🇷' => 'zastava: Portoriko',
    '🇵🇸' => 'zastava: Palestinsko područje',
    '🇵🇹' => 'zastava: Portugal',
    '🇵🇼' => 'zastava: Palau',
    '🇵🇾' => 'zastava: Paragvaj',
    '🇶🇦' => 'zastava: Katar',
    '🇷🇪' => 'zastava: Réunion',
    '🇷🇴' => 'zastava: Rumunjska',
    '🇷🇸' => 'zastava: Srbija',
    '🇷🇺' => 'zastava: Rusija',
    '🇷🇼' => 'zastava: Ruanda',
    '🇸🇦' => 'zastava: Saudijska Arabija',
    '🇸🇧' => 'zastava: Salomonovi Otoci',
    '🇸🇨' => 'zastava: Sejšeli',
    '🇸🇩' => 'zastava: Sudan',
    '🇸🇪' => 'zastava: Švedska',
    '🇸🇬' => 'zastava: Singapur',
    '🇸🇭' => 'zastava: Sveta Helena',
    '🇸🇮' => 'zastava: Slovenija',
    '🇸🇯' => 'zastava: Svalbard i Jan Mayen',
    '🇸🇰' => 'zastava: Slovačka',
    '🇸🇱' => 'zastava: Sijera Leone',
    '🇸🇲' => 'zastava: San Marino',
    '🇸🇳' => 'zastava: Senegal',
    '🇸🇴' => 'zastava: Somalija',
    '🇸🇷' => 'zastava: Surinam',
    '🇸🇸' => 'zastava: Južni Sudan',
    '🇸🇹' => 'zastava: Sveti Toma i Princip',
    '🇸🇻' => 'zastava: Salvador',
    '🇸🇽' => 'zastava: Sint Maarten',
    '🇸🇾' => 'zastava: Sirija',
    '🇸🇿' => 'zastava: Esvatini',
    '🇹🇦' => 'zastava: Tristan da Cunha',
    '🇹🇨' => 'zastava: Otoci Turks i Caicos',
    '🇹🇩' => 'zastava: Čad',
    '🇹🇫' => 'zastava: Francuski Južni Teritoriji',
    '🇹🇬' => 'zastava: Togo',
    '🇹🇭' => 'zastava: Tajland',
    '🇹🇯' => 'zastava: Tadžikistan',
    '🇹🇰' => 'zastava: Tokelau',
    '🇹🇱' => 'zastava: Timor-Leste',
    '🇹🇲' => 'zastava: Turkmenistan',
    '🇹🇳' => 'zastava: Tunis',
    '🇹🇴' => 'zastava: Tonga',
    '🇹🇷' => 'zastava: Turska',
    '🇹🇹' => 'zastava: Trinidad i Tobago',
    '🇹🇻' => 'zastava: Tuvalu',
    '🇹🇼' => 'zastava: Tajvan',
    '🇹🇿' => 'zastava: Tanzanija',
    '🇺🇦' => 'zastava: Ukrajina',
    '🇺🇬' => 'zastava: Uganda',
    '🇺🇲' => 'zastava: Mali udaljeni otoci SAD-a',
    '🇺🇳' => 'zastava: Ujedinjeni narodi',
    '🇺🇸' => 'zastava: Sjedinjene Američke Države',
    '🇺🇾' => 'zastava: Urugvaj',
    '🇺🇿' => 'zastava: Uzbekistan',
    '🇻🇦' => 'zastava: Vatikan',
    '🇻🇨' => 'zastava: Sveti Vincent i Grenadini',
    '🇻🇪' => 'zastava: Venezuela',
    '🇻🇬' => 'zastava: Britanski Djevičanski Otoci',
    '🇻🇮' => 'zastava: Američki Djevičanski Otoci',
    '🇻🇳' => 'zastava: Vijetnam',
    '🇻🇺' => 'zastava: Vanuatu',
    '🇼🇫' => 'zastava: Wallis i Futuna',
    '🇼🇸' => 'zastava: Samoa',
    '🇽🇰' => 'zastava: Kosovo',
    '🇾🇪' => 'zastava: Jemen',
    '🇾🇹' => 'zastava: Mayotte',
    '🇿🇦' => 'zastava: Južnoafrička Republika',
    '🇿🇲' => 'zastava: Zambija',
    '🇿🇼' => 'zastava: Zimbabve',
    '🔟' => 'tipka: 10',
    '🏻' => 'svijetla boja kože',
    '🏼' => 'svijetlo maslinasta boja kože',
    '🏽' => 'maslinasta boja kože',
    '🏾' => 'smeđa boja kože',
    '🏿' => 'tamno smeđa boja kože',
    '😀' => 'nasmijano lice',
    '😃' => 'nasmijano lice s velikim očima',
    '😄' => 'nasmijano lice s nasmiješenim očima',
    '😁' => 'sretno lice s nasmiješenim očima',
    '😆' => 'nasmijano lice s čvrsto zatvorenim očima',
    '😅' => 'nasmijano lice s kapljicom znoja',
    '🤣' => 'valjanje od smijeha',
    '😂' => 'lice sa suzama radosnicama',
    '🙂' => 'blago nasmiješeno lice',
    '🙃' => 'naopačke okrenuto lice',
    '🫠' => 'lice koje se topi',
    '😉' => 'lice koje namiguje',
    '😊' => 'nasmiješeno lice s nasmiješenim očima',
    '😇' => 'nasmiješeno lice s aureolom',
    '🥰' => 'nasmijano lice sa srcima',
    '😍' => 'nasmiješeno lice s očima u obliku srca',
    '🤩' => 'lice s očima u obliku zvijezda',
    '😘' => 'lice koje šalje poljubac',
    '😗' => 'lice koje ljubi',
    '☺' => 'nasmiješeno lice',
    '😚' => 'lice koje ljubi zatvorenih očiju',
    '😙' => 'lice koje ljubi s nasmiješenim očima',
    '🥲' => 'nasmiješeno lice sa suzom',
    '😋' => 'lice koje uživa u hrani',
    '😛' => 'lice s isplaženim jezikom',
    '😜' => 'lice s isplaženim jezikom koje namiguje',
    '🤪' => 'ludo lice',
    '😝' => 'lice s isplaženim jezikom i zatvorenim očima',
    '🤑' => 'pohlepno lice',
    '🤗' => 'lice koje grli',
    '🤭' => 'lice s rukom preko usta',
    '🫢' => 'lice s otvorenim očima i rukom preko usta',
    '🫣' => 'virenje na jedno oko',
    '🤫' => 'lice koje ušutkava',
    '🤔' => 'lice koje razmišlja',
    '🫡' => 'lice koje salutira',
    '🤐' => 'lice s patentnim zatvaračem preko usta',
    '🤨' => 'lice s podignutom obrvom',
    '😐' => 'neutralno lice',
    '😑' => 'bezizražajno lice',
    '😶' => 'lice bez usta',
    '🫥' => 'lice obrubljeno točkastom crtom',
    '😏' => 'lice koje se smijulji',
    '😒' => 'lice s izrazom dosade',
    '🙄' => 'lice s kolutajućim očima',
    '😬' => 'lice s grimasom',
    '🤥' => 'lice koje laže',
    '🫨' => 'drhteće lice',
    '😌' => 'lice s izrazom olakšanja',
    '😔' => 'zamišljeno lice',
    '😪' => 'pospano lice',
    '🤤' => 'lice koje slini',
    '😴' => 'lice koje spava',
    '🫩' => 'lice s podočnjacima',
    '😷' => 'lice s medicinskom maskom',
    '🤒' => 'lice s toplomjerom',
    '🤕' => 'lice sa zavojem',
    '🤢' => 'lice kojem je pozlilo',
    '🤮' => 'lice koje povraća',
    '🤧' => 'lice koje kiše',
    '🥵' => 'pregrijano lice',
    '🥶' => 'zamrznuto lice',
    '🥴' => 'ošamućeno lice',
    '😵' => 'lice s vrtoglavicom',
    '🤯' => 'eksplodirajuća glava',
    '🤠' => 'kauboj sa šeširom',
    '🥳' => 'lice koje se zabavlja',
    '🥸' => 'prerušeno lice',
    '😎' => 'nasmiješeno lice sa sunčanim naočalama',
    '🤓' => 'štrebersko lice',
    '🧐' => 'lice s monoklom',
    '😕' => 'zbunjeno lice',
    '🫤' => 'lice s nakošenim ustima',
    '😟' => 'zabrinuto lice',
    '🙁' => 'blago namrgođeno lice',
    '☹' => 'namrgođeno lice',
    '😮' => 'lice s otvorenim ustima',
    '😯' => 'iznenađeno lice',
    '😲' => 'zapanjeno lice',
    '😳' => 'zarumenjeno lice',
    '🫪' => 'izobličeno lice',
    '🥺' => 'molećivo lice',
    '🥹' => 'lice koje se suzdržava od suza',
    '😦' => 'namrgođeno lice s otvorenim ustima',
    '😧' => 'izmučeno lice',
    '😨' => 'preplašeno lice',
    '😰' => 'anksiozno lice s kapljicom znoja',
    '😥' => 'tužno lice, ali s izrazom olakšanja',
    '😢' => 'lice koje plače',
    '😭' => 'lice koje glasno plače',
    '😱' => 'lice koje vrišti od straha',
    '😖' => 'smeteno lice',
    '😣' => 'odlučno lice',
    '😞' => 'razočarano lice',
    '😓' => 'tužno lice s kapljicom znoja',
    '😩' => 'tegobno lice',
    '😫' => 'umorno lice',
    '🥱' => 'zijevajuće lice',
    '😤' => 'lice kojem ide para na nos',
    '😡' => 'lice koje se duri',
    '😠' => 'ljutito lice',
    '🤬' => 'lice sa simbolima na ustima',
    '😈' => 'nasmiješeno lice s rogovima',
    '👿' => 'vražićak',
    '💀' => 'lubanja',
    '☠' => 'lubanja i prekrižene kosti',
    '💩' => 'hrpica izmeta',
    '🤡' => 'lice klauna',
    '👹' => 'japanski div',
    '👺' => 'goblin',
    '👻' => 'duh',
    '👽' => 'izvanzemaljac',
    '👾' => 'izvanzemaljsko čudovište',
    '🤖' => 'robot',
    '😺' => 'nasmijana mačka',
    '😸' => 'nasmijana mačka s nasmiješenim očima',
    '😹' => 'mačka sa suzama radosnicama',
    '😻' => 'nasmiješena mačka s očima u obliku srca',
    '😼' => 'mačka s kiselim osmijehom',
    '😽' => 'mačka koja ljubi',
    '🙀' => 'izbezumljena mačka',
    '😿' => 'uplakana mačka',
    '😾' => 'mačka koja se duri',
    '🙈' => 'majmun koji ne vidi ništa loše',
    '🙉' => 'majmun koji ne čuje ništa loše',
    '🙊' => 'majmun koji ne govori ništa loše',
    '💌' => 'ljubavno pismo',
    '💘' => 'srce sa strelicom',
    '💝' => 'srce s trakom',
    '💖' => 'svjetlucavo srce',
    '💗' => 'srce koje raste',
    '💓' => 'srce koje kuca',
    '💞' => 'srca koja se vrte u krug',
    '💕' => 'dva srca',
    '💟' => 'ukras srca',
    '❣' => 'uskličnik u obliku srca',
    '💔' => 'slomljeno srce',
    '❤' => 'crveno srce',
    '🩷' => 'ružičasto srce',
    '🧡' => 'narančasto srce',
    '💛' => 'žuto srce',
    '💚' => 'zeleno srce',
    '💙' => 'plavo srce',
    '🩵' => 'svjetloplavo srce',
    '💜' => 'ljubičasto srce',
    '🤎' => 'smeđe srce',
    '🖤' => 'crno srce',
    '🩶' => 'sivo srce',
    '🤍' => 'bijelo srce',
    '💋' => 'otisak usana',
    '💯' => 'sto bodova',
    '💢' => 'simbol ljutnje',
    '🫯' => 'borba u oblaku',
    '💥' => 'sudar',
    '💫' => 'vrtoglavica',
    '💦' => 'kapljice znoja',
    '💨' => 'bježanje',
    '🕳' => 'rupa',
    '💬' => 'govorni oblačić',
    '🗨' => 'lijevi govorni oblačić',
    '🗯' => 'desni ljuti govorni oblačić',
    '💭' => 'oblačić za misao',
    '💤' => 'zzz',
    '👋' => 'ruka koja maše',
    '🤚' => 'ruka gore',
    '🖐' => 'podignuta ruka s raširenim prstima',
    '✋' => 'podignuta ruka',
    '🖖' => 'vulkanski pozdrav',
    '🫱' => 'ruka okrenuta udesno',
    '🫲' => 'ruka okrenuta ulijevo',
    '🫳' => 'ruka s dlanom okrenutim prema dolje',
    '🫴' => 'ruka s dlanom okrenutim prema gore',
    '🫷' => 'ruka koja gura ulijevo',
    '🫸' => 'ruka koja gura udesno',
    '👌' => 'znak rukom "u redu"',
    '🤌' => 'skupljeni prsti',
    '🤏' => 'ruka koja štipa',
    '✌' => 'ruka sa znakom pobjede',
    '🤞' => 'prekriženi prsti',
    '🫰' => 'ruka s prekriženim palcem i kažiprstom',
    '🤟' => 'gesta "volim te"',
    '🤘' => 'znak rogova',
    '🤙' => 'nazovi me',
    '👈' => 'kažiprst koji pokazuje ulijevo',
    '👉' => 'kažiprst koji pokazuje udesno',
    '👆' => 'kažiprst koji pokazuje prema gore',
    '🖕' => 'srednji prst',
    '👇' => 'kažiprst koji pokazuje prema dolje',
    '☝' => 'kažiprst pokazuje gore',
    '🫵' => 'kažiprst uperen prema gledatelju',
    '👍' => 'palac gore',
    '👎' => 'palac dolje',
    '✊' => 'podignuta šaka',
    '👊' => 'stisnuta šaka',
    '🤛' => 'šaka ulijevo',
    '🤜' => 'šaka udesno',
    '👏' => 'ruke koje plješću',
    '🙌' => 'podignute ruke',
    '🫶' => 'ruke koje tvore srce',
    '👐' => 'otvorene ruke',
    '🤲' => 'spojeni dlanovi',
    '🤝' => 'rukovanje',
    '🙏' => 'sklopljeni dlanovi',
    '✍' => 'ruka koja piše',
    '💅' => 'lak za nokte',
    '🤳' => 'selfie',
    '💪' => 'stegnuti biceps',
    '🦾' => 'mehanička ruka',
    '🦿' => 'mehanička noga',
    '🦵' => 'noga',
    '🦶' => 'stopalo',
    '👂' => 'uho',
    '🦻' => 'uho sa slušnim aparatom',
    '👃' => 'nos',
    '🧠' => 'mozak',
    '🫀' => 'anatomsko srce',
    '🫁' => 'pluća',
    '🦷' => 'zub',
    '🦴' => 'kost',
    '👀' => 'oči',
    '👁' => 'oko',
    '👅' => 'jezik',
    '👄' => 'usta',
    '🫦' => 'ugriz usne',
    '👶' => 'beba',
    '🧒' => 'dijete',
    '👦' => 'dječak',
    '👧' => 'djevojčica',
    '🧑' => 'odrasla osoba',
    '👱' => 'plavokosa osoba',
    '👨' => 'muškarac',
    '🧔' => 'muškarac s bradom',
    '👩' => 'žena',
    '🧓' => 'starija osoba',
    '👴' => 'starac',
    '👵' => 'starica',
    '🙍' => 'osoba koja se mršti',
    '🙎' => 'osoba koja se duri',
    '🙅' => 'osoba pokazuje "ne"',
    '🙆' => 'osoba pokazuje "u redu"',
    '💁' => 'osoba s nagnutim dlanom',
    '🙋' => 'osoba s podignutom rukom',
    '🧏' => 'gluha osoba',
    '🙇' => 'osoba koja se klanja',
    '🤦' => 'lupanje dlanom o čelo',
    '🤷' => 'slijeganje ramenima',
    '👮' => 'policajac',
    '🕵' => 'detektiv',
    '💂' => 'čuvar',
    '🥷' => 'nindža',
    '👷' => 'građevinski radnik',
    '🫅' => 'osoba s krunom',
    '🤴' => 'princ',
    '👸' => 'princeza',
    '👳' => 'osoba s turbanom',
    '👲' => 'muškarac s kineskom kapom',
    '🧕' => 'žena s maramom',
    '🤵' => 'osoba u smokingu',
    '👰' => 'nevjesta s velom',
    '🤰' => 'trudnica',
    '🫃' => 'trudni muškarac',
    '🫄' => 'trudna osoba',
    '🤱' => 'dojenje',
    '👼' => 'beba anđeo',
    '🎅' => 'Djed Božićnjak',
    '🤶' => 'Baka Mraz',
    '🦸' => 'superheroj',
    '🦹' => 'zločinac',
    '🧙' => 'magičar',
    '🧚' => 'vilinsko biće',
    '🧛' => 'neživa osoba',
    '🧜' => 'morska sirena',
    '🧝' => 'šumski vilenjak',
    '🧞' => 'džin',
    '🧟' => 'zombi',
    '🧌' => 'trol',
    '🫈' => 'dlakavo stvorenje',
    '💆' => 'osoba na masaži',
    '💇' => 'šišanje',
    '🚶' => 'pješak',
    '🧍' => 'osoba stoji',
    '🧎' => 'osoba kleči',
    '🏃' => 'osoba trči',
    '💃' => 'žena pleše',
    '🕺' => 'muškarac pleše',
    '🕴' => 'muškarac u poslovnom odijelu koji levitira',
    '👯' => 'osobe sa zečjim ušima',
    '🧖' => 'osoba u sauni',
    '🧗' => 'osoba se penje',
    '🤺' => 'osoba se mačuje',
    '🏇' => 'konjičke utrke',
    '⛷' => 'skijaš',
    '🏂' => 'snowboarder',
    '🏌' => 'osoba igra golf',
    '🏄' => 'surfer',
    '🚣' => 'osoba vesla',
    '🏊' => 'osoba pliva',
    '⛹' => 'osoba vodi loptu',
    '🏋' => 'osoba diže utege',
    '🚴' => 'osoba vozi bicikl',
    '🚵' => 'osoba vozi brdski bicikl',
    '🤸' => 'osoba izvodi zvijezdu',
    '🤼' => 'osobe se hrvaju',
    '🤽' => 'osobe igraju vaterpolo',
    '🤾' => 'osoba igra rukomet',
    '🤹' => 'osoba žonglira',
    '🧘' => 'osoba u položaju lotosa',
    '🛀' => 'osoba koja se kupa u kadi',
    '🛌' => 'osoba u krevetu',
    '👭' => 'žene koje se drže za ruke',
    '👫' => 'muškarac i žena koji se drže za ruke',
    '👬' => 'muškarci koji se drže za ruke',
    '💏' => 'poljubac',
    '💑' => 'par sa srcem',
    '🗣' => 'glava koja govori',
    '👤' => 'poprsje u silueti',
    '👥' => 'poprsja u silueti',
    '🫂' => 'osobe koje se grle',
    '👪' => 'obitelj',
    '👣' => 'otisci stopala',
    '🫆' => 'otisak prsta',
    '🦰' => 'crvena kosa',
    '🦱' => 'kovrčava kosa',
    '🦳' => 'sijeda kosa',
    '🦲' => 'bez kose',
    '🐵' => 'lice majmuna',
    '🐒' => 'majmun',
    '🦍' => 'gorila',
    '🦧' => 'orangutan',
    '🐶' => 'lice psa',
    '🐕' => 'pas',
    '🦮' => 'pas vodič',
    '🐩' => 'pudl',
    '🐺' => 'vuk',
    '🦊' => 'lisica',
    '🦝' => 'rakun',
    '🐱' => 'lice mačke',
    '🐈' => 'mačka',
    '🦁' => 'lav',
    '🐯' => 'lice tigra',
    '🐅' => 'tigar',
    '🐆' => 'leopard',
    '🐴' => 'lice konja',
    '🫎' => 'los',
    '🫏' => 'magarac',
    '🐎' => 'konj',
    '🦄' => 'jednorog',
    '🦓' => 'zebra',
    '🦌' => 'jelen',
    '🦬' => 'bizon',
    '🐮' => 'lice krave',
    '🐂' => 'vol',
    '🐃' => 'vodeni bivol',
    '🐄' => 'krava',
    '🐷' => 'lice svinje',
    '🐖' => 'svinja',
    '🐗' => 'vepar',
    '🐽' => 'njuška svinje',
    '🐏' => 'ovan',
    '🐑' => 'ovca',
    '🐐' => 'koza',
    '🐪' => 'deva',
    '🐫' => 'dvogrba deva',
    '🦙' => 'ljama',
    '🦒' => 'žirafa',
    '🐘' => 'slon',
    '🦣' => 'mamut',
    '🦏' => 'nosorog',
    '🦛' => 'vodenkonj',
    '🐭' => 'lice miša',
    '🐁' => 'miš',
    '🐀' => 'štakor',
    '🐹' => 'hrčak',
    '🐰' => 'lice zeca',
    '🐇' => 'zec',
    '🐿' => 'vjeverica',
    '🦫' => 'dabar',
    '🦔' => 'jež',
    '🦇' => 'šišmiš',
    '🐻' => 'medvjed',
    '🐨' => 'koala',
    '🐼' => 'panda',
    '🦥' => 'ljenjivac',
    '🦦' => 'vidra',
    '🦨' => 'tvor',
    '🦘' => 'klokan',
    '🦡' => 'jazavac',
    '🐾' => 'tragovi šapa',
    '🦃' => 'puran',
    '🐔' => 'kokoš',
    '🐓' => 'pijetao',
    '🐣' => 'pile izleglo iz jajeta',
    '🐤' => 'pile',
    '🐥' => 'pile sprijeda',
    '🐦' => 'ptica',
    '🐧' => 'pingvin',
    '🕊' => 'golubica',
    '🦅' => 'orao',
    '🦆' => 'patka',
    '🦢' => 'labud',
    '🦉' => 'sova',
    '🦤' => 'dodo',
    '🪶' => 'pero',
    '🦩' => 'plamenac',
    '🦚' => 'paun',
    '🦜' => 'papiga',
    '🪽' => 'krilo',
    '🪿' => 'guska',
    '🐸' => 'žaba',
    '🐊' => 'krokodil',
    '🐢' => 'kornjača',
    '🦎' => 'gušter',
    '🐍' => 'zmija',
    '🐲' => 'lice zmaja',
    '🐉' => 'zmaj',
    '🦕' => 'sauropod',
    '🦖' => 'tiranosaur',
    '🐳' => 'kit koji izbacuje mlaz vode',
    '🐋' => 'kit',
    '🐬' => 'dupin',
    '🫍' => 'orka',
    '🦭' => 'tuljan',
    '🐟' => 'riba',
    '🐠' => 'tropska ribica',
    '🐡' => 'riba napuhača',
    '🦈' => 'morski pas',
    '🐙' => 'hobotnica',
    '🐚' => 'spiralna školjka',
    '🪸' => 'koralj',
    '🪼' => 'meduza',
    '🦀' => 'rak',
    '🦞' => 'jastog',
    '🦐' => 'škamp',
    '🦑' => 'lignja',
    '🦪' => 'kamenica',
    '🐌' => 'puž',
    '🦋' => 'leptir',
    '🐛' => 'gusjenica',
    '🐜' => 'mrav',
    '🐝' => 'pčela',
    '🪲' => 'buba',
    '🐞' => 'bubamara',
    '🦗' => 'cvrčak',
    '🪳' => 'žohar',
    '🕷' => 'pauk',
    '🕸' => 'paukova mreža',
    '🦂' => 'škorpion',
    '🦟' => 'komarac',
    '🪰' => 'muha',
    '🪱' => 'crv',
    '🦠' => 'mikrob',
    '💐' => 'buket',
    '🌸' => 'trešnjin cvijet',
    '💮' => 'bijeli cvijet',
    '🪷' => 'lotus',
    '🏵' => 'rozeta',
    '🌹' => 'ruža',
    '🥀' => 'uveo cvijet',
    '🌺' => 'hibiskus',
    '🌻' => 'suncokret',
    '🌼' => 'cvjetanje',
    '🌷' => 'tulipan',
    '🪻' => 'zumbul',
    '🌱' => 'sadnica',
    '🪴' => 'biljka u tegli',
    '🌲' => 'zimzeleno drvo',
    '🌳' => 'listopadno drvo',
    '🌴' => 'palma',
    '🌵' => 'kaktus',
    '🌾' => 'klas riže',
    '🌿' => 'biljka',
    '☘' => 'djetelina',
    '🍀' => 'četverolisna djetelina',
    '🍁' => 'javorov list',
    '🍂' => 'otpali list',
    '🍃' => 'list koji treperi na vjetru',
    '🪹' => 'prazno gnijezdo',
    '🪺' => 'gnijezdo s jajima',
    '🍄' => 'gljiva',
    '🪾' => 'stablo bez lišća',
    '🍇' => 'grožđe',
    '🍈' => 'dinja',
    '🍉' => 'lubenica',
    '🍊' => 'mandarina',
    '🍋' => 'limun',
    '🍌' => 'banana',
    '🍍' => 'ananas',
    '🥭' => 'mango',
    '🍎' => 'crvena jabuka',
    '🍏' => 'zelena jabuka',
    '🍐' => 'kruška',
    '🍑' => 'breskva',
    '🍒' => 'trešnje',
    '🍓' => 'jagoda',
    '🫐' => 'borovnice',
    '🥝' => 'kivi',
    '🍅' => 'rajčica',
    '🫒' => 'maslina',
    '🥥' => 'kokos',
    '🥑' => 'avokado',
    '🍆' => 'patlidžan',
    '🥔' => 'krumpir',
    '🥕' => 'mrkva',
    '🌽' => 'klip kukuruza',
    '🌶' => 'ljuta papričica',
    '🫑' => 'paprika',
    '🥒' => 'krastavac',
    '🥬' => 'lisnato povrće',
    '🥦' => 'brokula',
    '🧄' => 'češnjak',
    '🧅' => 'luk',
    '🥜' => 'kikiriki',
    '🫘' => 'grah',
    '🌰' => 'kesten',
    '🫚' => 'đumbir',
    '🫛' => 'mahuna graška',
    '🫜' => 'korjenasto povrće',
    '🍞' => 'kruh',
    '🥐' => 'kroasan',
    '🥖' => 'baget',
    '🫓' => 'lepinja',
    '🥨' => 'perec',
    '🥯' => 'pecivo',
    '🥞' => 'palačinke',
    '🧇' => 'vafel',
    '🧀' => 'komad sira',
    '🍖' => 'meso na kosti',
    '🍗' => 'batak',
    '🥩' => 'odrezak',
    '🥓' => 'slanina',
    '🍔' => 'hamburger',
    '🍟' => 'pomfrit',
    '🍕' => 'pizza',
    '🌭' => 'hot dog',
    '🥪' => 'sendvič',
    '🌮' => 'taco',
    '🌯' => 'burrito',
    '🫔' => 'tamal',
    '🥙' => 'kebab',
    '🧆' => 'falafel',
    '🥚' => 'jaje',
    '🍳' => 'kuhanje',
    '🥘' => 'posuda s hranom',
    '🍲' => 'lonac s hranom',
    '🫕' => 'fondi',
    '🥣' => 'zdjelica sa žlicom',
    '🥗' => 'zelena salata',
    '🍿' => 'kokice',
    '🧈' => 'maslac',
    '🧂' => 'sol',
    '🥫' => 'konzerva',
    '🍱' => 'bento kutija',
    '🍘' => 'keks od riže',
    '🍙' => 'kuglica od riže',
    '🍚' => 'kuhana riža',
    '🍛' => 'curry riža',
    '🍜' => 'kipuća zdjelica',
    '🍝' => 'špageti',
    '🍠' => 'pečeni batat',
    '🍢' => 'oden',
    '🍣' => 'sushi',
    '🍤' => 'prženi račić',
    '🍥' => 'riblji kolač s motivom spirale',
    '🥮' => 'mjesečev kolač',
    '🍡' => 'dango',
    '🥟' => 'okruglica',
    '🥠' => 'kolačić sreće',
    '🥡' => 'kutija za dostavu',
    '🍦' => 'meki sladoled',
    '🍧' => 'sladoled s komadićima leda',
    '🍨' => 'sladoled',
    '🍩' => 'krafna',
    '🍪' => 'keks',
    '🎂' => 'rođendanska torta',
    '🍰' => 'komad kolača',
    '🧁' => 'muffin',
    '🥧' => 'pita',
    '🍫' => 'tabla čokolade',
    '🍬' => 'bombon',
    '🍭' => 'lizalica',
    '🍮' => 'krema od jaja',
    '🍯' => 'tegla meda',
    '🍼' => 'bočica za bebe',
    '🥛' => 'čaša mlijeka',
    '☕' => 'vrući napitak',
    '🫖' => 'čajnik',
    '🍵' => 'šalica za čaj bez ručke',
    '🍶' => 'sake',
    '🍾' => 'boca iz koje izlijeće čep',
    '🍷' => 'čaša za vino',
    '🍸' => 'čaša za koktel',
    '🍹' => 'tropsko piće',
    '🍺' => 'krigla za pivo',
    '🍻' => 'zdravica kriglama piva',
    '🥂' => 'zdravica',
    '🥃' => 'žestoko piće',
    '🫗' => 'izlijevanje tekućine',
    '🥤' => 'čaša sa slamkom',
    '🧋' => 'mjehuričasti čaj',
    '🧃' => 'sok u tetrapaku',
    '🧉' => 'mate',
    '🧊' => 'kocka leda',
    '🥢' => 'štapići',
    '🍽' => 'vilica i nož s tanjurom',
    '🍴' => 'vilica i nož',
    '🥄' => 'žlica',
    '🔪' => 'kuhinjski nož',
    '🫙' => 'staklenka',
    '🏺' => 'amfora',
    '🌍' => 'globus s prikazom Europe i Afrike',
    '🌎' => 'globus s prikazom Amerika',
    '🌏' => 'globus s prikazom Azije i Australije',
    '🌐' => 'globus s meridijanima',
    '🗺' => 'karta svijeta',
    '🗾' => 'karta Japana',
    '🧭' => 'kompas',
    '🏔' => 'planina sa snježnim vrhovima',
    '⛰' => 'planina',
    '🛘' => 'odron',
    '🌋' => 'vulkan',
    '🗻' => 'planina Fuji',
    '🏕' => 'kampiranje',
    '🏖' => 'plaža sa suncobranom',
    '🏜' => 'pustinja',
    '🏝' => 'pusti otok',
    '🏞' => 'nacionalni park',
    '🏟' => 'stadion',
    '🏛' => 'antička građevina',
    '🏗' => 'gradilište',
    '🧱' => 'cigle',
    '🪨' => 'kamen',
    '🪵' => 'drvo',
    '🛖' => 'koliba',
    '🏘' => 'kuće',
    '🏚' => 'zapuštena kuća',
    '🏠' => 'kuća',
    '🏡' => 'kuća s vrtom',
    '🏢' => 'poslovna zgrada',
    '🏣' => 'japanski poštanski ured',
    '🏤' => 'poštanski ured',
    '🏥' => 'bolnica',
    '🏦' => 'banka',
    '🏨' => 'hotel',
    '🏩' => 'ljubavni hotel',
    '🏪' => 'trgovina mješovitom robom',
    '🏫' => 'škola',
    '🏬' => 'robna kuća',
    '🏭' => 'tvornica',
    '🏯' => 'japanski dvorac',
    '🏰' => 'dvorac',
    '💒' => 'vjenčanje',
    '🗼' => 'tokijski toranj',
    '🗽' => 'kip slobode',
    '⛪' => 'crkva',
    '🕌' => 'džamija',
    '🛕' => 'hinduski hram',
    '🕍' => 'sinagoga',
    '⛩' => 'šintoistički hram',
    '🕋' => 'kaba',
    '⛲' => 'fontana',
    '⛺' => 'šator',
    '🌁' => 'maglovito',
    '🌃' => 'zvjezdana noć',
    '🏙' => 'panorama grada',
    '🌄' => 'izlazak sunca iznad planina',
    '🌅' => 'izlazak sunca',
    '🌆' => 'panorama grada u sumrak',
    '🌇' => 'zalazak sunca',
    '🌉' => 'most noću',
    '♨' => 'termalni izvori',
    '🎠' => 'konjić na vrtuljku',
    '🛝' => 'dječji tobogan',
    '🎡' => 'panoramski kotač',
    '🎢' => 'vlak smrti',
    '💈' => 'stup koji označava brijačnicu',
    '🎪' => 'cirkuski šator',
    '🚂' => 'lokomotiva',
    '🚃' => 'vagon',
    '🚄' => 'brzi vlak',
    '🚅' => 'japanski brzi vlak shinkansen',
    '🚆' => 'vlak',
    '🚇' => 'podzemna željeznica',
    '🚈' => 'laka željeznica',
    '🚉' => 'postaja',
    '🚊' => 'tramvaj',
    '🚝' => 'jednotračna željeznica',
    '🚞' => 'planinska željeznica',
    '🚋' => 'tramvajska kola',
    '🚌' => 'autobus',
    '🚍' => 'autobus u dolasku',
    '🚎' => 'trolejbus',
    '🚐' => 'minibus',
    '🚑' => 'ambulantno vozilo',
    '🚒' => 'vatrogasno vozilo',
    '🚓' => 'policijski automobil',
    '🚔' => 'policijski automobil u dolasku',
    '🚕' => 'taksi',
    '🚖' => 'taksi u dolasku',
    '🚗' => 'automobil',
    '🚘' => 'automobil u dolasku',
    '🚙' => 'rekreacijsko vozilo',
    '🛻' => 'kamionet',
    '🚚' => 'dostavni kamion',
    '🚛' => 'zglobni kamion',
    '🚜' => 'traktor',
    '🏎' => 'trkaći automobil',
    '🏍' => 'motocikl',
    '🛵' => 'skuter',
    '🦽' => 'invalidska kolica na ručni pogon',
    '🦼' => 'invalidska kolica na motorni pogon',
    '🛺' => 'rikša',
    '🚲' => 'bicikl',
    '🛴' => 'romobil',
    '🛹' => 'skateboard',
    '🛼' => 'koturaljka',
    '🚏' => 'autobusna stanica',
    '🛣' => 'autocesta',
    '🛤' => 'željeznička pruga',
    '🛢' => 'bačva za naftu',
    '⛽' => 'pumpa za gorivo',
    '🛞' => 'kotač',
    '🚨' => 'policijska rotirka',
    '🚥' => 'vodoravni semafor',
    '🚦' => 'okomiti semafor',
    '🛑' => 'znak stop',
    '🚧' => 'znak radova',
    '⚓' => 'sidro',
    '🛟' => 'kolut za spašavanje',
    '⛵' => 'jedrilica',
    '🛶' => 'kanu',
    '🚤' => 'gliser',
    '🛳' => 'putnički brod',
    '⛴' => 'trajekt',
    '🛥' => 'motorni čamac',
    '🚢' => 'brod',
    '✈' => 'zrakoplov',
    '🛩' => 'mali zrakoplov',
    '🛫' => 'polijetanje zrakoplova',
    '🛬' => 'slijetanje zrakoplova',
    '🪂' => 'padobran',
    '💺' => 'sjedalo',
    '🚁' => 'helikopter',
    '🚟' => 'viseća željeznica',
    '🚠' => 'žičara',
    '🚡' => 'zračni tramvaj',
    '🛰' => 'satelit',
    '🚀' => 'raketa',
    '🛸' => 'leteći tanjur',
    '🛎' => 'zvono za recepciju',
    '🧳' => 'putna torba',
    '⌛' => 'pješčani sat',
    '⏳' => 'pješčani sat s pijeskom koji curi',
    '⌚' => 'ručni sat',
    '⏰' => 'budilica',
    '⏱' => 'štoperica',
    '⏲' => 'tajmer',
    '🕰' => 'stolni sat',
    '🕛' => 'dvanaest sati',
    '🕧' => 'dvanaest i trideset',
    '🕐' => 'jedan sat',
    '🕜' => 'jedan i trideset',
    '🕑' => 'dva sata',
    '🕝' => 'dva i trideset',
    '🕒' => 'tri sata',
    '🕞' => 'tri i trideset',
    '🕓' => 'četiri sata',
    '🕟' => 'četiri i trideset',
    '🕔' => 'pet sati',
    '🕠' => 'pet i trideset',
    '🕕' => 'šest sati',
    '🕡' => 'šest i trideset',
    '🕖' => 'sedam sati',
    '🕢' => 'sedam i trideset',
    '🕗' => 'osam sati',
    '🕣' => 'osam i trideset',
    '🕘' => 'devet sati',
    '🕤' => 'devet i trideset',
    '🕙' => 'deset sati',
    '🕥' => 'deset i trideset',
    '🕚' => 'jedanaest sati',
    '🕦' => 'jedanaest i trideset',
    '🌑' => 'mlađak',
    '🌒' => 'polumjesec prve četvrti',
    '🌓' => 'mjesec prve četvrti',
    '🌔' => 'rastući izbočeni mjesec',
    '🌕' => 'puni mjesec',
    '🌖' => 'padajući izbočeni mjesec',
    '🌗' => 'mjesec posljednje četvrti',
    '🌘' => 'polumjesec posljednje četvrti',
    '🌙' => 'polumjesec',
    '🌚' => 'mlađak s licem',
    '🌛' => 'mjesec prve četvrti s licem',
    '🌜' => 'mjesec posljednje četvrti s licem',
    '🌡' => 'termometar',
    '☀' => 'sunce',
    '🌝' => 'puni mjesec s licem',
    '🌞' => 'sunce s licem',
    '🪐' => 'planet s prstenom',
    '⭐' => 'zvijezda',
    '🌟' => 'zvijezda koja sjaji',
    '🌠' => 'zvijezda padalica',
    '🌌' => 'Mliječna staza',
    '☁' => 'oblak',
    '⛅' => 'sunce iza oblaka',
    '⛈' => 'oblak s grmljavinom i kišom',
    '🌤' => 'sunce iza malog oblaka',
    '🌥' => 'sunce iza velikog oblaka',
    '🌦' => 'sunce iza kišnog oblaka',
    '🌧' => 'oblak s kišom',
    '🌨' => 'oblak sa snijegom',
    '🌩' => 'oblak s grmljavinom',
    '🌪' => 'tornado',
    '🌫' => 'magla',
    '🌬' => 'lice vjetra',
    '🌀' => 'ciklona',
    '🌈' => 'duga',
    '🌂' => 'zatvoreni kišobran',
    '☂' => 'kišobran',
    '☔' => 'kišobran s kapima kiše',
    '⛱' => 'suncobran',
    '⚡' => 'visoki napon',
    '❄' => 'snježna pahulja',
    '☃' => 'snjegović',
    '⛄' => 'snjegović bez snijega',
    '☄' => 'komet',
    '🔥' => 'vatra',
    '💧' => 'kapljica',
    '🌊' => 'vodeni val',
    '🎃' => 'izrezbarena bundeva',
    '🎄' => 'božićno drvce',
    '🎆' => 'vatromet',
    '🎇' => 'prskalica',
    '🧨' => 'petarda',
    '✨' => 'iskre',
    '🎈' => 'balon',
    '🎉' => 'ispaljivač konfeta',
    '🎊' => 'kugla s konfetima',
    '🎋' => 'drvo tanabata',
    '🎍' => 'ukras od češera',
    '🎎' => 'japanske lutke',
    '🎏' => 'cjevasti zmaj u obliku ribe',
    '🎐' => 'vjetreno zvono',
    '🎑' => 'mjesečeva svečanost',
    '🧧' => 'crvena omotnica',
    '🎀' => 'mašna',
    '🎁' => 'umotani poklon',
    '🎗' => 'spomen-traka',
    '🎟' => 'ulaznice',
    '🎫' => 'ulaznica',
    '🎖' => 'vojno odličje',
    '🏆' => 'trofej',
    '🏅' => 'sportska medalja',
    '🥇' => 'zlatna medalja',
    '🥈' => 'srebrna medalja',
    '🥉' => 'brončana medalja',
    '⚽' => 'nogometna lopta',
    '⚾' => 'lopta za bejzbol',
    '🥎' => 'lopta za softball',
    '🏀' => 'košarkaška lopta',
    '🏐' => 'odbojkaška lopta',
    '🏈' => 'američki nogomet',
    '🏉' => 'ragbi',
    '🎾' => 'tenis',
    '🥏' => 'frizbi',
    '🎳' => 'kuglanje',
    '🏏' => 'kriket',
    '🏑' => 'hokej na travi',
    '🏒' => 'palica i pak za hokej na ledu',
    '🥍' => 'lacrosse',
    '🏓' => 'stolni tenis',
    '🏸' => 'badminton',
    '🥊' => 'boksačka rukavica',
    '🥋' => 'uniforma za borilačke vještine',
    '🥅' => 'gol',
    '⛳' => 'zastavica u rupi',
    '⛸' => 'klizaljka',
    '🎣' => 'ribički štap',
    '🤿' => 'maska za ronjenje',
    '🎽' => 'majica za trčanje',
    '🎿' => 'skije',
    '🛷' => 'sanjke',
    '🥌' => 'kamen za karling',
    '🎯' => 'pogodak u sredinu',
    '🪀' => 'jo-jo',
    '🪁' => 'papirnati zmaj',
    '🔫' => 'pištolj na vodu',
    '🎱' => 'biljarske kugle',
    '🔮' => 'kristalna kugla',
    '🪄' => 'čarobni štapić',
    '🎮' => 'videoigrica',
    '🕹' => 'igraća palica',
    '🎰' => 'jednoruki jack',
    '🎲' => 'igraća kocka',
    '🧩' => 'slagalica',
    '🧸' => 'medvjedić',
    '🪅' => 'pinjata',
    '🪩' => 'disko kugla',
    '🪆' => 'babuška',
    '♠' => 'pik',
    '♥' => 'herc',
    '♦' => 'karo',
    '♣' => 'tref',
    '♟' => 'šahovski pješak',
    '🃏' => 'džoker',
    '🀄' => 'mahjong crveni zmaj',
    '🎴' => 'igraće karte s cvijećem',
    '🎭' => 'izvedbene umjetnosti',
    '🖼' => 'uokvirena slika',
    '🎨' => 'slikarska paleta',
    '🧵' => 'konac',
    '🪡' => 'šivaća igla',
    '🧶' => 'klupko vune',
    '🪢' => 'čvor',
    '👓' => 'naočale',
    '🕶' => 'sunčane naočale',
    '🥽' => 'zaštitne naočale',
    '🥼' => 'laboratorijska kuta',
    '🦺' => 'sigurnosni prsluk',
    '👔' => 'kravata',
    '👕' => 'majica kratkih rukava',
    '👖' => 'traperice',
    '🧣' => 'šal',
    '🧤' => 'rukavice',
    '🧥' => 'kaput',
    '🧦' => 'čarape',
    '👗' => 'haljina',
    '👘' => 'kimono',
    '🥻' => 'sari',
    '🩱' => 'jednodijelni kupaći kostim',
    '🩲' => 'gaćice',
    '🩳' => 'kratke hlače',
    '👙' => 'bikini',
    '👚' => 'ženska odjeća',
    '🪭' => 'sklopiva lepeza',
    '👛' => 'novčanik',
    '👜' => 'ručna torbica',
    '👝' => 'torbica',
    '🛍' => 'vrećice za kupovinu',
    '🎒' => 'školski ruksak',
    '🩴' => 'japanka',
    '👞' => 'muška cipela',
    '👟' => 'tenisica',
    '🥾' => 'gojzerica',
    '🥿' => 'balerinka',
    '👠' => 'cipela s visokom potpeticom',
    '👡' => 'ženska sandala',
    '🩰' => 'baletne papučice',
    '👢' => 'ženska čizma',
    '🪮' => 'češljić',
    '👑' => 'kruna',
    '👒' => 'ženski šešir',
    '🎩' => 'cilindar',
    '🎓' => 'maturalna kapa',
    '🧢' => 'šilterica',
    '🪖' => 'vojni šljem',
    '⛑' => 'šljem s bijelim križem',
    '📿' => 'brojanica',
    '💄' => 'ruž za usne',
    '💍' => 'prsten',
    '💎' => 'dragulj',
    '🔇' => 'isključen zvučnik',
    '🔈' => 'stišan zvučnik',
    '🔉' => 'srednje glasan zvučnik',
    '🔊' => 'glasan zvučnik',
    '📢' => 'razglas',
    '📣' => 'megafon',
    '📯' => 'poštanski rog',
    '🔔' => 'zvono',
    '🔕' => 'prekriženo zvono',
    '🎼' => 'notno crtovlje',
    '🎵' => 'glazbena nota',
    '🎶' => 'glazbene note',
    '🎙' => 'studijski mikrofon',
    '🎚' => 'kliznik za podešavanje',
    '🎛' => 'kontrolni gumbi',
    '🎤' => 'mikrofon',
    '🎧' => 'slušalice',
    '📻' => 'radio',
    '🎷' => 'saksofon',
    '🎺' => 'truba',
    '🪊' => 'trombon',
    '🪗' => 'harmonika',
    '🎸' => 'gitara',
    '🎹' => 'klavijatura',
    '🎻' => 'violina',
    '🪕' => 'bendžo',
    '🥁' => 'bubanj',
    '🪘' => 'visoki bubanj',
    '🪇' => 'marakasi',
    '🪈' => 'flauta',
    '🪉' => 'harfa',
    '📱' => 'mobilni telefon',
    '📲' => 'mobilni telefon sa strelicom',
    '☎' => 'telefon',
    '📞' => 'telefonska slušalica',
    '📟' => 'dojavljivač',
    '📠' => 'faks',
    '🔋' => 'baterija',
    '🪫' => 'baterija s niskom razinom napunjenosti',
    '🔌' => 'strujni utikač',
    '💻' => 'prijenosno računalo',
    '🖥' => 'stolno računalo',
    '🖨' => 'pisač',
    '⌨' => 'tipkovnica',
    '🖱' => 'računalni miš',
    '🖲' => 'upravljačka kuglica',
    '💽' => 'minidisk',
    '💾' => 'disketa',
    '💿' => 'optički disk',
    '📀' => 'dvd',
    '🧮' => 'abakus',
    '🎥' => 'filmska kamera',
    '🎞' => 'filmska vrpca',
    '📽' => 'filmski projektor',
    '🎬' => 'klapa',
    '📺' => 'televizor',
    '📷' => 'fotoaparat',
    '📸' => 'fotoaparat s bljeskalicom',
    '📹' => 'videokamera',
    '📼' => 'videokaseta',
    '🔍' => 'povećalo nagnuto ulijevo',
    '🔎' => 'povećalo nagnuto udesno',
    '🕯' => 'svijeća',
    '💡' => 'žarulja',
    '🔦' => 'ručna svjetiljka',
    '🏮' => 'crveni lampion',
    '🪔' => 'diya lampa',
    '📔' => 'bilježnica s ukrasnim omotom',
    '📕' => 'zatvorena knjiga',
    '📖' => 'otvorena knjiga',
    '📗' => 'zelena knjiga',
    '📘' => 'plava knjiga',
    '📙' => 'narančasta knjiga',
    '📚' => 'knjige',
    '📓' => 'bilježnica',
    '📒' => 'računovodstvena knjiga',
    '📃' => 'savinuta stranica',
    '📜' => 'svitak',
    '📄' => 'stranica okrenuta prema gore',
    '📰' => 'novine',
    '🗞' => 'zarolane novine',
    '📑' => 'kartice knjižnih oznaka',
    '🔖' => 'knjižna oznaka',
    '🏷' => 'oznaka',
    '🪙' => 'kovanica',
    '💰' => 'vreća s novcem',
    '🪎' => 'škrinja s blagom',
    '💴' => 'novčanica sa znakom jena',
    '💵' => 'novčanica sa znakom dolara',
    '💶' => 'novčanica sa znakom eura',
    '💷' => 'novčanica sa znakom funte',
    '💸' => 'novac s krilima',
    '💳' => 'kreditna kartica',
    '🧾' => 'račun',
    '💹' => 'grafikon rastućeg trenda sa znakom jena',
    '✉' => 'omotnica',
    '📧' => 'e-pošta',
    '📨' => 'omotnica dolazne pošte',
    '📩' => 'omotnica sa strelicom',
    '📤' => 'ladica odlazne pošte',
    '📥' => 'ladica dolazne pošte',
    '📦' => 'paket',
    '📫' => 'zatvoreni sandučić s podignutom zastavicom',
    '📪' => 'zatvoreni sandučić sa spuštenom zastavicom',
    '📬' => 'otvoreni sandučić s podignutom zastavicom',
    '📭' => 'otvoreni sandučić sa spuštenom zastavicom',
    '📮' => 'poštanski sandučić',
    '🗳' => 'glasačka kutija s glasačkim listićem',
    '✏' => 'olovka',
    '✒' => 'crno pero',
    '🖋' => 'nalivpero',
    '🖊' => 'penkala',
    '🖌' => 'kist',
    '🖍' => 'bojica',
    '📝' => 'bilješka',
    '💼' => 'aktovka',
    '📁' => 'mapa',
    '📂' => 'otvorena mapa',
    '🗂' => 'razdjelnici',
    '📅' => 'kalendar',
    '📆' => 'kalendar na trganje',
    '🗒' => 'spiralni notes',
    '🗓' => 'spiralni kalendar',
    '📇' => 'kartoteka',
    '📈' => 'grafikon uzlaznog trenda',
    '📉' => 'grafikon silaznog trenda',
    '📊' => 'trakasti grafikon',
    '📋' => 'držač spisa',
    '📌' => 'pribadača',
    '📍' => 'zaobljena pribadača',
    '📎' => 'spajalica',
    '🖇' => 'spojene spajalice',
    '📏' => 'ravnalo',
    '📐' => 'trokut',
    '✂' => 'škare',
    '🗃' => 'kartotečna kutija',
    '🗄' => 'kartotečni ladičar',
    '🗑' => 'koš za smeće',
    '🔒' => 'zaključano',
    '🔓' => 'otključano',
    '🔏' => 'zatvoreni lokot s nalivperom',
    '🔐' => 'zatvoreni lokot s ključem',
    '🔑' => 'ključ',
    '🗝' => 'starinski ključ',
    '🔨' => 'čekić',
    '🪓' => 'sjekira',
    '⛏' => 'pijuk',
    '⚒' => 'čekić i pijuk',
    '🛠' => 'čekić i francuski ključ',
    '🗡' => 'bodež',
    '⚔' => 'prekriženi mačevi',
    '💣' => 'bomba',
    '🪃' => 'bumerang',
    '🏹' => 'luk i strijela',
    '🛡' => 'štit',
    '🪚' => 'ručna pila',
    '🔧' => 'francuski ključ',
    '🪛' => 'odvijač',
    '🔩' => 'vijak i matica',
    '⚙' => 'zupčanik',
    '🗜' => 'škrip',
    '⚖' => 'vaga',
    '🦯' => 'bijeli štap',
    '🔗' => 'karika',
    '⛓' => 'lanci',
    '🪝' => 'udica',
    '🧰' => 'kutija za alat',
    '🧲' => 'magnet',
    '🪜' => 'ljestve',
    '🪏' => 'lopata',
    '⚗' => 'retorta',
    '🧪' => 'epruveta',
    '🧫' => 'petrijeva zdjelica',
    '🧬' => 'dnk',
    '🔬' => 'mikroskop',
    '🔭' => 'teleskop',
    '📡' => 'satelitska antena',
    '💉' => 'šprica',
    '🩸' => 'kap krvi',
    '💊' => 'pilula',
    '🩹' => 'flaster',
    '🩼' => 'štaka',
    '🩺' => 'stetoskop',
    '🩻' => 'rendgenska snimka',
    '🚪' => 'vrata',
    '🛗' => 'dizalo',
    '🪞' => 'zrcalo',
    '🪟' => 'prozor',
    '🛏' => 'krevet',
    '🛋' => 'kauč i svjetiljka',
    '🪑' => 'stolica',
    '🚽' => 'WC školjka',
    '🪠' => 'odčepljivač',
    '🚿' => 'tuš',
    '🛁' => 'kada',
    '🪤' => 'mišolovka',
    '🪒' => 'britva',
    '🧴' => 'bočica losiona',
    '🧷' => 'sigurnica',
    '🧹' => 'metla',
    '🧺' => 'košara',
    '🧻' => 'rola papira',
    '🪣' => 'kanta',
    '🧼' => 'sapun',
    '🫧' => 'mjehurići',
    '🪥' => 'četkica za zube',
    '🧽' => 'spužva',
    '🧯' => 'vatrogasni aparat',
    '🛒' => 'kolica za kupnju',
    '🚬' => 'cigareta',
    '⚰' => 'lijes',
    '🪦' => 'nadgrobni spomenik',
    '⚱' => 'urna',
    '🧿' => 'nazar perlica',
    '🪬' => 'hamsa',
    '🗿' => 'moai',
    '🪧' => 'transparent',
    '🪪' => 'osobna iskaznica',
    '🏧' => 'znak za bankomat',
    '🚮' => 'znak za koš za smeće',
    '🚰' => 'pitka voda',
    '♿' => 'invalidska kolica',
    '🚹' => 'muški toalet',
    '🚺' => 'ženski toalet',
    '🚻' => 'toalet',
    '🚼' => 'simbol bebe',
    '🚾' => 'nužnik',
    '🛂' => 'kontrola putovnica',
    '🛃' => 'carina',
    '🛄' => 'preuzimanje prtljage',
    '🛅' => 'odlaganje prtljage',
    '⚠' => 'upozorenje',
    '🚸' => 'pješački prijelaz za djecu',
    '⛔' => 'zabrana ulaza',
    '🚫' => 'zabranjeno',
    '🚳' => 'zabranjeno za bicikle',
    '🚭' => 'zabranjeno pušenje',
    '🚯' => 'zabranjeno bacanje otpadaka',
    '🚱' => 'voda nije za piće',
    '🚷' => 'zabranjeno za pješake',
    '📵' => 'zabranjena uporaba mobilnih telefona',
    '🔞' => 'zabranjeno za mlađe od osamnaest',
    '☢' => 'radioaktivnost',
    '☣' => 'biološka opasnost',
    '⬆' => 'strelica prema gore',
    '↗' => 'strelica prema gore-desno',
    '➡' => 'strelica prema desno',
    '↘' => 'strelica prema dolje-desno',
    '⬇' => 'strelica prema dolje',
    '↙' => 'strelica prema dolje-lijevo',
    '⬅' => 'strelica prema lijevo',
    '↖' => 'strelica prema gore-lijevo',
    '↕' => 'strelica gore-dolje',
    '↔' => 'strelica lijevo-desno',
    '↩' => 'desna strelica koja se zakrivljuje ulijevo',
    '↪' => 'lijeva strelica koja se zakrivljuje udesno',
    '⤴' => 'desna strelica koja se zakrivljuje prema gore',
    '⤵' => 'desna strelica koja se zakrivljuje prema dolje',
    '🔃' => 'okomite strelice u smjeru kazaljki na satu',
    '🔄' => 'tipka sa strelicama ulijevo',
    '🔙' => 'strelica s natpisom "back"',
    '🔚' => 'strelica s natpisom "end"',
    '🔛' => 'strelica s natpisom "on!"',
    '🔜' => 'strelica s natpisom "soon"',
    '🔝' => 'strelica s natpisom "top"',
    '🛐' => 'mjesto za bogoslužje',
    '⚛' => 'simbol atoma',
    '🕉' => 'om',
    '✡' => 'davidova zvijezda',
    '☸' => 'kotač dharme',
    '☯' => 'jin i jang',
    '✝' => 'latinski križ',
    '☦' => 'pravoslavni križ',
    '☪' => 'zvijezda i polumjesec',
    '☮' => 'simbol mira',
    '🕎' => 'menora',
    '🔯' => 'šesterokraka zvijezda s točkom',
    '🪯' => 'khanda',
    '♈' => 'astrološki znak ovna',
    '♉' => 'astrološki znak bika',
    '♊' => 'astrološki znak blizanaca',
    '♋' => 'astrološki znak raka',
    '♌' => 'astrološki znak lava',
    '♍' => 'astrološki znak djevice',
    '♎' => 'astrološki znak vage',
    '♏' => 'astrološki znak škorpiona',
    '♐' => 'astrološki znak strijelca',
    '♑' => 'astrološki znak jarca',
    '♒' => 'astrološki znak vodenjaka',
    '♓' => 'astrološki znak riba',
    '⛎' => 'astrološki znak zmijonosca',
    '🔀' => 'tipka za nasumičnu reprodukciju pjesama',
    '🔁' => 'tipka za ponavljanje',
    '🔂' => 'tipka za ponavljanje jedne pjesme',
    '▶' => 'tipka za reprodukciju',
    '⏩' => 'tipka za pretraživanje unaprijed',
    '⏭' => 'tipka za sljedeću pjesmu',
    '⏯' => 'tipka za reprodukciju ili pauzu',
    '◀' => 'tipka za pretraživanje unatrag',
    '⏪' => 'tipka za brzo pretraživanje unatrag',
    '⏮' => 'tipka za posljednju pjesmu',
    '🔼' => 'tipka prema gore',
    '⏫' => 'tipka za brzo kretanje prema gore',
    '🔽' => 'tipka prema dolje',
    '⏬' => 'tipka za brzo kretanje prema dolje',
    '⏸' => 'tipka za pauzu',
    '⏹' => 'tipka za zaustavljanje',
    '⏺' => 'tipka za snimanje',
    '⏏' => 'tipka za izbacivanje',
    '🎦' => 'kino',
    '🔅' => 'tipka za smanjivanje svjetline',
    '🔆' => 'tipka za povećanje svjetline',
    '📶' => 'crtice jačine signala',
    '🛜' => 'bežična mreža',
    '📳' => 'način vibracije',
    '📴' => 'isključen mobilni telefon',
    '♀' => 'ženski simbol',
    '♂' => 'muški simbol',
    '⚧' => 'simbol transrodnosti',
    '✖' => 'množenje',
    '➕' => 'plus',
    '➖' => 'minus',
    '➗' => 'znak dijeljenja',
    '🟰' => 'podebljani znak jednakosti',
    '♾' => 'beskonačnost',
    '‼' => 'dvostruki uskličnik',
    '⁉' => 'uskličnik-upitnik',
    '❓' => 'crveni upitnik',
    '❔' => 'bijeli upitnik',
    '❕' => 'bijeli uskličnik',
    '❗' => 'crveni uskličnik',
    '〰' => 'valovita crta',
    '💱' => 'mjenjačnica',
    '💲' => 'masno otisnut znak dolara',
    '⚕' => 'simbol medicine',
    '♻' => 'simbol recikliranja',
    '⚜' => 'heraldički ljiljan',
    '🔱' => 'znak trozupca',
    '📛' => 'bedž s imenom',
    '🔰' => 'japanski simbol za početnika',
    '⭕' => 'crveni krug s rupom',
    '✅' => 'tipka s kvačicom',
    '☑' => 'potvrdni okvir s kvačicom',
    '✔' => 'kvačica',
    '❌' => 'križić',
    '❎' => 'tipka s oznakom križića',
    '➰' => 'vitičasta petlja',
    '➿' => 'dvostruka vitičasta petlja',
    '〽' => 'oznaka djelomične alternacije',
    '✳' => 'osmerokraka zvjezdica',
    '✴' => 'osmerokraka zvijezda',
    '❇' => 'iskra',
    '™' => 'zaštitni znak tm',
    '🫟' => 'mrlja',
    '🔠' => 'unos velikih latiničnih slova',
    '🔡' => 'unos malih latiničnih slova',
    '🔢' => 'unos brojeva',
    '🔣' => 'unos simbola',
    '🔤' => 'unos latiničnih slova',
    '🅰' => 'tipka krvne grupe A',
    '🆎' => 'tipka krvne grupe AB',
    '🅱' => 'tipka krvne grupe B',
    '🆑' => 'tipka CL',
    '🆒' => 'tipka COOL',
    '🆓' => 'tipka FREE',
    'ℹ' => 'izvor informacija',
    '🆔' => 'tipka ID',
    'Ⓜ' => 'slovo m u krugu',
    '🆕' => 'tipka NEW',
    '🆖' => 'tipka NG',
    '🅾' => 'tipka krvne grupe 0',
    '🆗' => 'tipka OK',
    '🅿' => 'tipka P',
    '🆘' => 'tipka SOS',
    '🆙' => 'tipka UP!',
    '🆚' => 'tipka VS',
    '🈁' => 'tipka s ideogramom "ovdje"',
    '🈂' => 'tipka s ideogramom "naplata usluge"',
    '🈷' => 'tipka s ideogramom "mjesečni iznos"',
    '🈶' => 'tipka s ideogramom "nije besplatno"',
    '🈯' => 'tipka s ideogramom "rezervirano"',
    '🉐' => 'tipka s ideogramom "povoljno"',
    '🈹' => 'tipka s ideogramom "popust"',
    '🈚' => 'tipka s ideogramom "besplatno"',
    '🈲' => 'tipka s ideogramom "zabranjeno"',
    '🉑' => 'tipka s ideogramom "prihvatljivo"',
    '🈸' => 'tipka s ideogramom "zahtjev"',
    '🈴' => 'tipka s ideogramom "prolazna ocjena"',
    '🈳' => 'tipka s ideogramom "ima slobodnih mjesta"',
    '㊗' => 'tipka s ideogramom "čestitke"',
    '㊙' => 'tipka s ideogramom "tajna"',
    '🈺' => 'tipka s ideogramom "otvoreno"',
    '🈵' => 'tipka s ideogramom "popunjeno"',
    '🔴' => 'crveni krug',
    '🟠' => 'narančasti krug',
    '🟡' => 'žuti krug',
    '🟢' => 'zeleni krug',
    '🔵' => 'plavi krug',
    '🟣' => 'ljubičasti krug',
    '🟤' => 'smeđi krug',
    '⚫' => 'crni krug',
    '⚪' => 'bijeli krug',
    '🟥' => 'crveni kvadrat',
    '🟧' => 'narančasti kvadrat',
    '🟨' => 'žuti kvadrat',
    '🟩' => 'zeleni kvadrat',
    '🟦' => 'plavi kvadrat',
    '🟪' => 'ljubičasti kvadrat',
    '🟫' => 'smeđi kvadrat',
    '⬛' => 'veliki crni kvadrat',
    '⬜' => 'veliki bijeli kvadrat',
    '◼' => 'srednji crni kvadrat',
    '◻' => 'srednji bijeli kvadrat',
    '◾' => 'srednje mali crni kvadrat',
    '◽' => 'srednje mali bijeli kvadrat',
    '▪' => 'mali crni kvadrat',
    '▫' => 'mali bijeli kvadrat',
    '🔶' => 'veliki narančasti romb',
    '🔷' => 'veliki plavi romb',
    '🔸' => 'mali narančasti romb',
    '🔹' => 'mali plavi romb',
    '🔺' => 'crveni trokut usmjeren prema gore',
    '🔻' => 'crveni trokut usmjeren prema dolje',
    '💠' => 'romb s točkom',
    '🔘' => 'kružić za označavanje',
    '🔳' => 'bijela uglata tipka',
    '🔲' => 'crna uglata tipka',
    '🏁' => 'zastava s crno-bijelom šahovnicom',
    '🚩' => 'trokutasta zastava',
    '🎌' => 'prekrižene zastave',
    '🏴' => 'crna zastava',
    '🏳' => 'bijela zastava',
];
