<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'tvey íð mussast: persónur, persónur, ljósur húðarlitur, miðalljósur húðarlitur',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'tvey íð mussast: persónur, persónur, ljósur húðarlitur, miðal húðarlitur',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'tvey íð mussast: persónur, persónur, ljósur húðarlitur, miðalmyrkur húðarlitur',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'tvey íð mussast: persónur, persónur, ljósur húðarlitur, myrkur húðarlitur',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'tvey íð mussast: persónur, persónur, miðalljósur húðarlitur, ljósur húðarlitur',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'tvey íð mussast: persónur, persónur, miðalljósur húðarlitur, miðal húðarlitur',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'tvey íð mussast: persónur, persónur, miðalljósur húðarlitur, miðalmyrkur húðarlitur',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'tvey íð mussast: persónur, persónur, miðalljósur húðarlitur, myrkur húðarlitur',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'tvey íð mussast: persónur, persónur, miðal húðarlitur, ljósur húðarlitur',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'tvey íð mussast: persónur, persónur, miðal húðarlitur, miðalljósur húðarlitur',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'tvey íð mussast: persónur, persónur, miðal húðarlitur, miðalmyrkur húðarlitur',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'tvey íð mussast: persónur, persónur, miðal húðarlitur, myrkur húðarlitur',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'tvey íð mussast: persónur, persónur, miðalmyrkur húðarlitur, ljósur húðarlitur',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'tvey íð mussast: persónur, persónur, miðalmyrkur húðarlitur, miðalljósur húðarlitur',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'tvey íð mussast: persónur, persónur, miðalmyrkur húðarlitur, miðal húðarlitur',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'tvey íð mussast: persónur, persónur, miðalmyrkur húðarlitur, myrkur húðarlitur',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'tvey íð mussast: persónur, persónur, myrkur húðarlitur, ljósur húðarlitur',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'tvey íð mussast: persónur, persónur, myrkur húðarlitur, miðalljósur húðarlitur',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'tvey íð mussast: persónur, persónur, myrkur húðarlitur, miðal húðarlitur',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'tvey íð mussast: persónur, persónur, myrkur húðarlitur, miðalmyrkur húðarlitur',
    '👨🏻‍❤‍💋‍👨🏻' => 'tvey íð mussast: maður, maður, ljósur húðarlitur',
    '👨🏻‍❤‍💋‍👨🏼' => 'tvey íð mussast: maður, maður, ljósur húðarlitur, miðalljósur húðarlitur',
    '👨🏻‍❤‍💋‍👨🏽' => 'tvey íð mussast: maður, maður, ljósur húðarlitur, miðal húðarlitur',
    '👨🏻‍❤‍💋‍👨🏾' => 'tvey íð mussast: maður, maður, ljósur húðarlitur, miðalmyrkur húðarlitur',
    '👨🏻‍❤‍💋‍👨🏿' => 'tvey íð mussast: maður, maður, ljósur húðarlitur, myrkur húðarlitur',
    '👨🏼‍❤‍💋‍👨🏻' => 'tvey íð mussast: maður, maður, miðalljósur húðarlitur, ljósur húðarlitur',
    '👨🏼‍❤‍💋‍👨🏼' => 'tvey íð mussast: maður, maður, miðalljósur húðarlitur',
    '👨🏼‍❤‍💋‍👨🏽' => 'tvey íð mussast: maður, maður, miðalljósur húðarlitur, miðal húðarlitur',
    '👨🏼‍❤‍💋‍👨🏾' => 'tvey íð mussast: maður, maður, miðalljósur húðarlitur, miðalmyrkur húðarlitur',
    '👨🏼‍❤‍💋‍👨🏿' => 'tvey íð mussast: maður, maður, miðalljósur húðarlitur, myrkur húðarlitur',
    '👨🏽‍❤‍💋‍👨🏻' => 'tvey íð mussast: maður, maður, miðal húðarlitur, ljósur húðarlitur',
    '👨🏽‍❤‍💋‍👨🏼' => 'tvey íð mussast: maður, maður, miðal húðarlitur, miðalljósur húðarlitur',
    '👨🏽‍❤‍💋‍👨🏽' => 'tvey íð mussast: maður, maður, miðal húðarlitur',
    '👨🏽‍❤‍💋‍👨🏾' => 'tvey íð mussast: maður, maður, miðal húðarlitur, miðalmyrkur húðarlitur',
    '👨🏽‍❤‍💋‍👨🏿' => 'tvey íð mussast: maður, maður, miðal húðarlitur, myrkur húðarlitur',
    '👨🏾‍❤‍💋‍👨🏻' => 'tvey íð mussast: maður, maður, miðalmyrkur húðarlitur, ljósur húðarlitur',
    '👨🏾‍❤‍💋‍👨🏼' => 'tvey íð mussast: maður, maður, miðalmyrkur húðarlitur, miðalljósur húðarlitur',
    '👨🏾‍❤‍💋‍👨🏽' => 'tvey íð mussast: maður, maður, miðalmyrkur húðarlitur, miðal húðarlitur',
    '👨🏾‍❤‍💋‍👨🏾' => 'tvey íð mussast: maður, maður, miðalmyrkur húðarlitur',
    '👨🏾‍❤‍💋‍👨🏿' => 'tvey íð mussast: maður, maður, miðalmyrkur húðarlitur, myrkur húðarlitur',
    '👨🏿‍❤‍💋‍👨🏻' => 'tvey íð mussast: maður, maður, myrkur húðarlitur, ljósur húðarlitur',
    '👨🏿‍❤‍💋‍👨🏼' => 'tvey íð mussast: maður, maður, myrkur húðarlitur, miðalljósur húðarlitur',
    '👨🏿‍❤‍💋‍👨🏽' => 'tvey íð mussast: maður, maður, myrkur húðarlitur, miðal húðarlitur',
    '👨🏿‍❤‍💋‍👨🏾' => 'tvey íð mussast: maður, maður, myrkur húðarlitur, miðalmyrkur húðarlitur',
    '👨🏿‍❤‍💋‍👨🏿' => 'tvey íð mussast: maður, maður, myrkur húðarlitur',
    '👩🏻‍❤‍💋‍👨🏻' => 'tvey íð mussast: kona, maður, ljósur húðarlitur',
    '👩🏻‍❤‍💋‍👨🏼' => 'tvey íð mussast: kona, maður, ljósur húðarlitur, miðalljósur húðarlitur',
    '👩🏻‍❤‍💋‍👨🏽' => 'tvey íð mussast: kona, maður, ljósur húðarlitur, miðal húðarlitur',
    '👩🏻‍❤‍💋‍👨🏾' => 'tvey íð mussast: kona, maður, ljósur húðarlitur, miðalmyrkur húðarlitur',
    '👩🏻‍❤‍💋‍👨🏿' => 'tvey íð mussast: kona, maður, ljósur húðarlitur, myrkur húðarlitur',
    '👩🏼‍❤‍💋‍👨🏻' => 'tvey íð mussast: kona, maður, miðalljósur húðarlitur, ljósur húðarlitur',
    '👩🏼‍❤‍💋‍👨🏼' => 'tvey íð mussast: kona, maður, miðalljósur húðarlitur',
    '👩🏼‍❤‍💋‍👨🏽' => 'tvey íð mussast: kona, maður, miðalljósur húðarlitur, miðal húðarlitur',
    '👩🏼‍❤‍💋‍👨🏾' => 'tvey íð mussast: kona, maður, miðalljósur húðarlitur, miðalmyrkur húðarlitur',
    '👩🏼‍❤‍💋‍👨🏿' => 'tvey íð mussast: kona, maður, miðalljósur húðarlitur, myrkur húðarlitur',
    '👩🏽‍❤‍💋‍👨🏻' => 'tvey íð mussast: kona, maður, miðal húðarlitur, ljósur húðarlitur',
    '👩🏽‍❤‍💋‍👨🏼' => 'tvey íð mussast: kona, maður, miðal húðarlitur, miðalljósur húðarlitur',
    '👩🏽‍❤‍💋‍👨🏽' => 'tvey íð mussast: kona, maður, miðal húðarlitur',
    '👩🏽‍❤‍💋‍👨🏾' => 'tvey íð mussast: kona, maður, miðal húðarlitur, miðalmyrkur húðarlitur',
    '👩🏽‍❤‍💋‍👨🏿' => 'tvey íð mussast: kona, maður, miðal húðarlitur, myrkur húðarlitur',
    '👩🏾‍❤‍💋‍👨🏻' => 'tvey íð mussast: kona, maður, miðalmyrkur húðarlitur, ljósur húðarlitur',
    '👩🏾‍❤‍💋‍👨🏼' => 'tvey íð mussast: kona, maður, miðalmyrkur húðarlitur, miðalljósur húðarlitur',
    '👩🏾‍❤‍💋‍👨🏽' => 'tvey íð mussast: kona, maður, miðalmyrkur húðarlitur, miðal húðarlitur',
    '👩🏾‍❤‍💋‍👨🏾' => 'tvey íð mussast: kona, maður, miðalmyrkur húðarlitur',
    '👩🏾‍❤‍💋‍👨🏿' => 'tvey íð mussast: kona, maður, miðalmyrkur húðarlitur, myrkur húðarlitur',
    '👩🏿‍❤‍💋‍👨🏻' => 'tvey íð mussast: kona, maður, myrkur húðarlitur, ljósur húðarlitur',
    '👩🏿‍❤‍💋‍👨🏼' => 'tvey íð mussast: kona, maður, myrkur húðarlitur, miðalljósur húðarlitur',
    '👩🏿‍❤‍💋‍👨🏽' => 'tvey íð mussast: kona, maður, myrkur húðarlitur, miðal húðarlitur',
    '👩🏿‍❤‍💋‍👨🏾' => 'tvey íð mussast: kona, maður, myrkur húðarlitur, miðalmyrkur húðarlitur',
    '👩🏿‍❤‍💋‍👨🏿' => 'tvey íð mussast: kona, maður, myrkur húðarlitur',
    '👩🏻‍❤‍💋‍👩🏻' => 'tvey íð mussast: kona, kona, ljósur húðarlitur',
    '👩🏻‍❤‍💋‍👩🏼' => 'tvey íð mussast: kona, kona, ljósur húðarlitur, miðalljósur húðarlitur',
    '👩🏻‍❤‍💋‍👩🏽' => 'tvey íð mussast: kona, kona, ljósur húðarlitur, miðal húðarlitur',
    '👩🏻‍❤‍💋‍👩🏾' => 'tvey íð mussast: kona, kona, ljósur húðarlitur, miðalmyrkur húðarlitur',
    '👩🏻‍❤‍💋‍👩🏿' => 'tvey íð mussast: kona, kona, ljósur húðarlitur, myrkur húðarlitur',
    '👩🏼‍❤‍💋‍👩🏻' => 'tvey íð mussast: kona, kona, miðalljósur húðarlitur, ljósur húðarlitur',
    '👩🏼‍❤‍💋‍👩🏼' => 'tvey íð mussast: kona, kona, miðalljósur húðarlitur',
    '👩🏼‍❤‍💋‍👩🏽' => 'tvey íð mussast: kona, kona, miðalljósur húðarlitur, miðal húðarlitur',
    '👩🏼‍❤‍💋‍👩🏾' => 'tvey íð mussast: kona, kona, miðalljósur húðarlitur, miðalmyrkur húðarlitur',
    '👩🏼‍❤‍💋‍👩🏿' => 'tvey íð mussast: kona, kona, miðalljósur húðarlitur, myrkur húðarlitur',
    '👩🏽‍❤‍💋‍👩🏻' => 'tvey íð mussast: kona, kona, miðal húðarlitur, ljósur húðarlitur',
    '👩🏽‍❤‍💋‍👩🏼' => 'tvey íð mussast: kona, kona, miðal húðarlitur, miðalljósur húðarlitur',
    '👩🏽‍❤‍💋‍👩🏽' => 'tvey íð mussast: kona, kona, miðal húðarlitur',
    '👩🏽‍❤‍💋‍👩🏾' => 'tvey íð mussast: kona, kona, miðal húðarlitur, miðalmyrkur húðarlitur',
    '👩🏽‍❤‍💋‍👩🏿' => 'tvey íð mussast: kona, kona, miðal húðarlitur, myrkur húðarlitur',
    '👩🏾‍❤‍💋‍👩🏻' => 'tvey íð mussast: kona, kona, miðalmyrkur húðarlitur, ljósur húðarlitur',
    '👩🏾‍❤‍💋‍👩🏼' => 'tvey íð mussast: kona, kona, miðalmyrkur húðarlitur, miðalljósur húðarlitur',
    '👩🏾‍❤‍💋‍👩🏽' => 'tvey íð mussast: kona, kona, miðalmyrkur húðarlitur, miðal húðarlitur',
    '👩🏾‍❤‍💋‍👩🏾' => 'tvey íð mussast: kona, kona, miðalmyrkur húðarlitur',
    '👩🏾‍❤‍💋‍👩🏿' => 'tvey íð mussast: kona, kona, miðalmyrkur húðarlitur, myrkur húðarlitur',
    '👩🏿‍❤‍💋‍👩🏻' => 'tvey íð mussast: kona, kona, myrkur húðarlitur, ljósur húðarlitur',
    '👩🏿‍❤‍💋‍👩🏼' => 'tvey íð mussast: kona, kona, myrkur húðarlitur, miðalljósur húðarlitur',
    '👩🏿‍❤‍💋‍👩🏽' => 'tvey íð mussast: kona, kona, myrkur húðarlitur, miðal húðarlitur',
    '👩🏿‍❤‍💋‍👩🏾' => 'tvey íð mussast: kona, kona, myrkur húðarlitur, miðalmyrkur húðarlitur',
    '👩🏿‍❤‍💋‍👩🏿' => 'tvey íð mussast: kona, kona, myrkur húðarlitur',
    '🧑🏻‍🫯‍🧑🏼' => 'glímingardystur: ljósur húðarlitur, miðalljósur húðarlitur',
    '🧑🏻‍🫯‍🧑🏽' => 'glímingardystur: ljósur húðarlitur, miðal húðarlitur',
    '🧑🏻‍🫯‍🧑🏾' => 'glímingardystur: ljósur húðarlitur, miðalmyrkur húðarlitur',
    '🧑🏻‍🫯‍🧑🏿' => 'glímingardystur: ljósur húðarlitur, myrkur húðarlitur',
    '🧑🏼‍🫯‍🧑🏻' => 'glímingardystur: miðalljósur húðarlitur, ljósur húðarlitur',
    '🧑🏼‍🫯‍🧑🏽' => 'glímingardystur: miðalljósur húðarlitur, miðal húðarlitur',
    '🧑🏼‍🫯‍🧑🏾' => 'glímingardystur: miðalljósur húðarlitur, miðalmyrkur húðarlitur',
    '🧑🏼‍🫯‍🧑🏿' => 'glímingardystur: miðalljósur húðarlitur, myrkur húðarlitur',
    '🧑🏽‍🫯‍🧑🏻' => 'glímingardystur: miðal húðarlitur, ljósur húðarlitur',
    '🧑🏽‍🫯‍🧑🏼' => 'glímingardystur: miðal húðarlitur, miðalljósur húðarlitur',
    '🧑🏽‍🫯‍🧑🏾' => 'glímingardystur: miðal húðarlitur, miðalmyrkur húðarlitur',
    '🧑🏽‍🫯‍🧑🏿' => 'glímingardystur: miðal húðarlitur, myrkur húðarlitur',
    '🧑🏾‍🫯‍🧑🏻' => 'glímingardystur: miðalmyrkur húðarlitur, ljósur húðarlitur',
    '🧑🏾‍🫯‍🧑🏼' => 'glímingardystur: miðalmyrkur húðarlitur, miðalljósur húðarlitur',
    '🧑🏾‍🫯‍🧑🏽' => 'glímingardystur: miðalmyrkur húðarlitur, miðal húðarlitur',
    '🧑🏾‍🫯‍🧑🏿' => 'glímingardystur: miðalmyrkur húðarlitur, myrkur húðarlitur',
    '🧑🏿‍🫯‍🧑🏻' => 'glímingardystur: myrkur húðarlitur, ljósur húðarlitur',
    '🧑🏿‍🫯‍🧑🏼' => 'glímingardystur: myrkur húðarlitur, miðalljósur húðarlitur',
    '🧑🏿‍🫯‍🧑🏽' => 'glímingardystur: myrkur húðarlitur, miðal húðarlitur',
    '🧑🏿‍🫯‍🧑🏾' => 'glímingardystur: myrkur húðarlitur, miðalmyrkur húðarlitur',
    '🧑🏻‍❤‍🧑🏼' => 'par og hjarta: persónur, persónur, ljósur húðarlitur, miðalljósur húðarlitur',
    '🧑🏻‍❤‍🧑🏽' => 'par og hjarta: persónur, persónur, ljósur húðarlitur, miðal húðarlitur',
    '🧑🏻‍❤‍🧑🏾' => 'par og hjarta: persónur, persónur, ljósur húðarlitur, miðalmyrkur húðarlitur',
    '🧑🏻‍❤‍🧑🏿' => 'par og hjarta: persónur, persónur, ljósur húðarlitur, myrkur húðarlitur',
    '🧑🏼‍❤‍🧑🏻' => 'par og hjarta: persónur, persónur, miðalljósur húðarlitur, ljósur húðarlitur',
    '🧑🏼‍❤‍🧑🏽' => 'par og hjarta: persónur, persónur, miðalljósur húðarlitur, miðal húðarlitur',
    '🧑🏼‍❤‍🧑🏾' => 'par og hjarta: persónur, persónur, miðalljósur húðarlitur, miðalmyrkur húðarlitur',
    '🧑🏼‍❤‍🧑🏿' => 'par og hjarta: persónur, persónur, miðalljósur húðarlitur, myrkur húðarlitur',
    '🧑🏽‍❤‍🧑🏻' => 'par og hjarta: persónur, persónur, miðal húðarlitur, ljósur húðarlitur',
    '🧑🏽‍❤‍🧑🏼' => 'par og hjarta: persónur, persónur, miðal húðarlitur, miðalljósur húðarlitur',
    '🧑🏽‍❤‍🧑🏾' => 'par og hjarta: persónur, persónur, miðal húðarlitur, miðalmyrkur húðarlitur',
    '🧑🏽‍❤‍🧑🏿' => 'par og hjarta: persónur, persónur, miðal húðarlitur, myrkur húðarlitur',
    '🧑🏾‍❤‍🧑🏻' => 'par og hjarta: persónur, persónur, miðalmyrkur húðarlitur, ljósur húðarlitur',
    '🧑🏾‍❤‍🧑🏼' => 'par og hjarta: persónur, persónur, miðalmyrkur húðarlitur, miðalljósur húðarlitur',
    '🧑🏾‍❤‍🧑🏽' => 'par og hjarta: persónur, persónur, miðalmyrkur húðarlitur, miðal húðarlitur',
    '🧑🏾‍❤‍🧑🏿' => 'par og hjarta: persónur, persónur, miðalmyrkur húðarlitur, myrkur húðarlitur',
    '🧑🏿‍❤‍🧑🏻' => 'par og hjarta: persónur, persónur, myrkur húðarlitur, ljósur húðarlitur',
    '🧑🏿‍❤‍🧑🏼' => 'par og hjarta: persónur, persónur, myrkur húðarlitur, miðalljósur húðarlitur',
    '🧑🏿‍❤‍🧑🏽' => 'par og hjarta: persónur, persónur, myrkur húðarlitur, miðal húðarlitur',
    '🧑🏿‍❤‍🧑🏾' => 'par og hjarta: persónur, persónur, myrkur húðarlitur, miðalmyrkur húðarlitur',
    '🧑🏻‍🐰‍🧑🏼' => 'fólk við haruoyrum: ljósur húðarlitur, miðalljósur húðarlitur',
    '🧑🏻‍🐰‍🧑🏽' => 'fólk við haruoyrum: ljósur húðarlitur, miðal húðarlitur',
    '🧑🏻‍🐰‍🧑🏾' => 'fólk við haruoyrum: ljósur húðarlitur, miðalmyrkur húðarlitur',
    '🧑🏻‍🐰‍🧑🏿' => 'fólk við haruoyrum: ljósur húðarlitur, myrkur húðarlitur',
    '🧑🏼‍🐰‍🧑🏻' => 'fólk við haruoyrum: miðalljósur húðarlitur, ljósur húðarlitur',
    '🧑🏼‍🐰‍🧑🏽' => 'fólk við haruoyrum: miðalljósur húðarlitur, miðal húðarlitur',
    '🧑🏼‍🐰‍🧑🏾' => 'fólk við haruoyrum: miðalljósur húðarlitur, miðalmyrkur húðarlitur',
    '🧑🏼‍🐰‍🧑🏿' => 'fólk við haruoyrum: miðalljósur húðarlitur, myrkur húðarlitur',
    '🧑🏽‍🐰‍🧑🏻' => 'fólk við haruoyrum: miðal húðarlitur, ljósur húðarlitur',
    '🧑🏽‍🐰‍🧑🏼' => 'fólk við haruoyrum: miðal húðarlitur, miðalljósur húðarlitur',
    '🧑🏽‍🐰‍🧑🏾' => 'fólk við haruoyrum: miðal húðarlitur, miðalmyrkur húðarlitur',
    '🧑🏽‍🐰‍🧑🏿' => 'fólk við haruoyrum: miðal húðarlitur, myrkur húðarlitur',
    '🧑🏾‍🐰‍🧑🏻' => 'fólk við haruoyrum: miðalmyrkur húðarlitur, ljósur húðarlitur',
    '🧑🏾‍🐰‍🧑🏼' => 'fólk við haruoyrum: miðalmyrkur húðarlitur, miðalljósur húðarlitur',
    '🧑🏾‍🐰‍🧑🏽' => 'fólk við haruoyrum: miðalmyrkur húðarlitur, miðal húðarlitur',
    '🧑🏾‍🐰‍🧑🏿' => 'fólk við haruoyrum: miðalmyrkur húðarlitur, myrkur húðarlitur',
    '🧑🏿‍🐰‍🧑🏻' => 'fólk við haruoyrum: myrkur húðarlitur, ljósur húðarlitur',
    '🧑🏿‍🐰‍🧑🏼' => 'fólk við haruoyrum: myrkur húðarlitur, miðalljósur húðarlitur',
    '🧑🏿‍🐰‍🧑🏽' => 'fólk við haruoyrum: myrkur húðarlitur, miðal húðarlitur',
    '🧑🏿‍🐰‍🧑🏾' => 'fólk við haruoyrum: myrkur húðarlitur, miðalmyrkur húðarlitur',
    '👨🏻‍🫯‍👨🏼' => 'mannligur glímingardystur: ljósur húðarlitur, miðalljósur húðarlitur',
    '👨🏻‍🫯‍👨🏽' => 'mannligur glímingardystur: ljósur húðarlitur, miðal húðarlitur',
    '👨🏻‍🫯‍👨🏾' => 'mannligur glímingardystur: ljósur húðarlitur, miðalmyrkur húðarlitur',
    '👨🏻‍🫯‍👨🏿' => 'mannligur glímingardystur: ljósur húðarlitur, myrkur húðarlitur',
    '👨🏼‍🫯‍👨🏻' => 'mannligur glímingardystur: miðalljósur húðarlitur, ljósur húðarlitur',
    '👨🏼‍🫯‍👨🏽' => 'mannligur glímingardystur: miðalljósur húðarlitur, miðal húðarlitur',
    '👨🏼‍🫯‍👨🏾' => 'mannligur glímingardystur: miðalljósur húðarlitur, miðalmyrkur húðarlitur',
    '👨🏼‍🫯‍👨🏿' => 'mannligur glímingardystur: miðalljósur húðarlitur, myrkur húðarlitur',
    '👨🏽‍🫯‍👨🏻' => 'mannligur glímingardystur: miðal húðarlitur, ljósur húðarlitur',
    '👨🏽‍🫯‍👨🏼' => 'mannligur glímingardystur: miðal húðarlitur, miðalljósur húðarlitur',
    '👨🏽‍🫯‍👨🏾' => 'mannligur glímingardystur: miðal húðarlitur, miðalmyrkur húðarlitur',
    '👨🏽‍🫯‍👨🏿' => 'mannligur glímingardystur: miðal húðarlitur, myrkur húðarlitur',
    '👨🏾‍🫯‍👨🏻' => 'mannligur glímingardystur: miðalmyrkur húðarlitur, ljósur húðarlitur',
    '👨🏾‍🫯‍👨🏼' => 'mannligur glímingardystur: miðalmyrkur húðarlitur, miðalljósur húðarlitur',
    '👨🏾‍🫯‍👨🏽' => 'mannligur glímingardystur: miðalmyrkur húðarlitur, miðal húðarlitur',
    '👨🏾‍🫯‍👨🏿' => 'mannligur glímingardystur: miðalmyrkur húðarlitur, myrkur húðarlitur',
    '👨🏿‍🫯‍👨🏻' => 'mannligur glímingardystur: myrkur húðarlitur, ljósur húðarlitur',
    '👨🏿‍🫯‍👨🏼' => 'mannligur glímingardystur: myrkur húðarlitur, miðalljósur húðarlitur',
    '👨🏿‍🫯‍👨🏽' => 'mannligur glímingardystur: myrkur húðarlitur, miðal húðarlitur',
    '👨🏿‍🫯‍👨🏾' => 'mannligur glímingardystur: myrkur húðarlitur, miðalmyrkur húðarlitur',
    '👨🏻‍❤‍👨🏻' => 'par og hjarta: maður, maður, ljósur húðarlitur',
    '👨🏻‍❤‍👨🏼' => 'par og hjarta: maður, maður, ljósur húðarlitur, miðalljósur húðarlitur',
    '👨🏻‍❤‍👨🏽' => 'par og hjarta: maður, maður, ljósur húðarlitur, miðal húðarlitur',
    '👨🏻‍❤‍👨🏾' => 'par og hjarta: maður, maður, ljósur húðarlitur, miðalmyrkur húðarlitur',
    '👨🏻‍❤‍👨🏿' => 'par og hjarta: maður, maður, ljósur húðarlitur, myrkur húðarlitur',
    '👨🏼‍❤‍👨🏻' => 'par og hjarta: maður, maður, miðalljósur húðarlitur, ljósur húðarlitur',
    '👨🏼‍❤‍👨🏼' => 'par og hjarta: maður, maður, miðalljósur húðarlitur',
    '👨🏼‍❤‍👨🏽' => 'par og hjarta: maður, maður, miðalljósur húðarlitur, miðal húðarlitur',
    '👨🏼‍❤‍👨🏾' => 'par og hjarta: maður, maður, miðalljósur húðarlitur, miðalmyrkur húðarlitur',
    '👨🏼‍❤‍👨🏿' => 'par og hjarta: maður, maður, miðalljósur húðarlitur, myrkur húðarlitur',
    '👨🏽‍❤‍👨🏻' => 'par og hjarta: maður, maður, miðal húðarlitur, ljósur húðarlitur',
    '👨🏽‍❤‍👨🏼' => 'par og hjarta: maður, maður, miðal húðarlitur, miðalljósur húðarlitur',
    '👨🏽‍❤‍👨🏽' => 'par og hjarta: maður, maður, miðal húðarlitur',
    '👨🏽‍❤‍👨🏾' => 'par og hjarta: maður, maður, miðal húðarlitur, miðalmyrkur húðarlitur',
    '👨🏽‍❤‍👨🏿' => 'par og hjarta: maður, maður, miðal húðarlitur, myrkur húðarlitur',
    '👨🏾‍❤‍👨🏻' => 'par og hjarta: maður, maður, miðalmyrkur húðarlitur, ljósur húðarlitur',
    '👨🏾‍❤‍👨🏼' => 'par og hjarta: maður, maður, miðalmyrkur húðarlitur, miðalljósur húðarlitur',
    '👨🏾‍❤‍👨🏽' => 'par og hjarta: maður, maður, miðalmyrkur húðarlitur, miðal húðarlitur',
    '👨🏾‍❤‍👨🏾' => 'par og hjarta: maður, maður, miðalmyrkur húðarlitur',
    '👨🏾‍❤‍👨🏿' => 'par og hjarta: maður, maður, miðalmyrkur húðarlitur, myrkur húðarlitur',
    '👨🏿‍❤‍👨🏻' => 'par og hjarta: maður, maður, myrkur húðarlitur, ljósur húðarlitur',
    '👨🏿‍❤‍👨🏼' => 'par og hjarta: maður, maður, myrkur húðarlitur, miðalljósur húðarlitur',
    '👨🏿‍❤‍👨🏽' => 'par og hjarta: maður, maður, myrkur húðarlitur, miðal húðarlitur',
    '👨🏿‍❤‍👨🏾' => 'par og hjarta: maður, maður, myrkur húðarlitur, miðalmyrkur húðarlitur',
    '👨🏿‍❤‍👨🏿' => 'par og hjarta: maður, maður, myrkur húðarlitur',
    '👨🏻‍🐰‍👨🏼' => 'menn við haruoyrum: ljósur húðarlitur, miðalljósur húðarlitur',
    '👨🏻‍🐰‍👨🏽' => 'menn við haruoyrum: ljósur húðarlitur, miðal húðarlitur',
    '👨🏻‍🐰‍👨🏾' => 'menn við haruoyrum: ljósur húðarlitur, miðalmyrkur húðarlitur',
    '👨🏻‍🐰‍👨🏿' => 'menn við haruoyrum: ljósur húðarlitur, myrkur húðarlitur',
    '👨🏼‍🐰‍👨🏻' => 'menn við haruoyrum: miðalljósur húðarlitur, ljósur húðarlitur',
    '👨🏼‍🐰‍👨🏽' => 'menn við haruoyrum: miðalljósur húðarlitur, miðal húðarlitur',
    '👨🏼‍🐰‍👨🏾' => 'menn við haruoyrum: miðalljósur húðarlitur, miðalmyrkur húðarlitur',
    '👨🏼‍🐰‍👨🏿' => 'menn við haruoyrum: miðalljósur húðarlitur, myrkur húðarlitur',
    '👨🏽‍🐰‍👨🏻' => 'menn við haruoyrum: miðal húðarlitur, ljósur húðarlitur',
    '👨🏽‍🐰‍👨🏼' => 'menn við haruoyrum: miðal húðarlitur, miðalljósur húðarlitur',
    '👨🏽‍🐰‍👨🏾' => 'menn við haruoyrum: miðal húðarlitur, miðalmyrkur húðarlitur',
    '👨🏽‍🐰‍👨🏿' => 'menn við haruoyrum: miðal húðarlitur, myrkur húðarlitur',
    '👨🏾‍🐰‍👨🏻' => 'menn við haruoyrum: miðalmyrkur húðarlitur, ljósur húðarlitur',
    '👨🏾‍🐰‍👨🏼' => 'menn við haruoyrum: miðalmyrkur húðarlitur, miðalljósur húðarlitur',
    '👨🏾‍🐰‍👨🏽' => 'menn við haruoyrum: miðalmyrkur húðarlitur, miðal húðarlitur',
    '👨🏾‍🐰‍👨🏿' => 'menn við haruoyrum: miðalmyrkur húðarlitur, myrkur húðarlitur',
    '👨🏿‍🐰‍👨🏻' => 'menn við haruoyrum: myrkur húðarlitur, ljósur húðarlitur',
    '👨🏿‍🐰‍👨🏼' => 'menn við haruoyrum: myrkur húðarlitur, miðalljósur húðarlitur',
    '👨🏿‍🐰‍👨🏽' => 'menn við haruoyrum: myrkur húðarlitur, miðal húðarlitur',
    '👨🏿‍🐰‍👨🏾' => 'menn við haruoyrum: myrkur húðarlitur, miðalmyrkur húðarlitur',
    '👩🏻‍🫯‍👩🏼' => 'kvinnuligur glímingardystur: ljósur húðarlitur, miðalljósur húðarlitur',
    '👩🏻‍🫯‍👩🏽' => 'kvinnuligur glímingardystur: ljósur húðarlitur, miðal húðarlitur',
    '👩🏻‍🫯‍👩🏾' => 'kvinnuligur glímingardystur: ljósur húðarlitur, miðalmyrkur húðarlitur',
    '👩🏻‍🫯‍👩🏿' => 'kvinnuligur glímingardystur: ljósur húðarlitur, myrkur húðarlitur',
    '👩🏼‍🫯‍👩🏻' => 'kvinnuligur glímingardystur: miðalljósur húðarlitur, ljósur húðarlitur',
    '👩🏼‍🫯‍👩🏽' => 'kvinnuligur glímingardystur: miðalljósur húðarlitur, miðal húðarlitur',
    '👩🏼‍🫯‍👩🏾' => 'kvinnuligur glímingardystur: miðalljósur húðarlitur, miðalmyrkur húðarlitur',
    '👩🏼‍🫯‍👩🏿' => 'kvinnuligur glímingardystur: miðalljósur húðarlitur, myrkur húðarlitur',
    '👩🏽‍🫯‍👩🏻' => 'kvinnuligur glímingardystur: miðal húðarlitur, ljósur húðarlitur',
    '👩🏽‍🫯‍👩🏼' => 'kvinnuligur glímingardystur: miðal húðarlitur, miðalljósur húðarlitur',
    '👩🏽‍🫯‍👩🏾' => 'kvinnuligur glímingardystur: miðal húðarlitur, miðalmyrkur húðarlitur',
    '👩🏽‍🫯‍👩🏿' => 'kvinnuligur glímingardystur: miðal húðarlitur, myrkur húðarlitur',
    '👩🏾‍🫯‍👩🏻' => 'kvinnuligur glímingardystur: miðalmyrkur húðarlitur, ljósur húðarlitur',
    '👩🏾‍🫯‍👩🏼' => 'kvinnuligur glímingardystur: miðalmyrkur húðarlitur, miðalljósur húðarlitur',
    '👩🏾‍🫯‍👩🏽' => 'kvinnuligur glímingardystur: miðalmyrkur húðarlitur, miðal húðarlitur',
    '👩🏾‍🫯‍👩🏿' => 'kvinnuligur glímingardystur: miðalmyrkur húðarlitur, myrkur húðarlitur',
    '👩🏿‍🫯‍👩🏻' => 'kvinnuligur glímingardystur: myrkur húðarlitur, ljósur húðarlitur',
    '👩🏿‍🫯‍👩🏼' => 'kvinnuligur glímingardystur: myrkur húðarlitur, miðalljósur húðarlitur',
    '👩🏿‍🫯‍👩🏽' => 'kvinnuligur glímingardystur: myrkur húðarlitur, miðal húðarlitur',
    '👩🏿‍🫯‍👩🏾' => 'kvinnuligur glímingardystur: myrkur húðarlitur, miðalmyrkur húðarlitur',
    '👩🏻‍❤‍👨🏻' => 'par og hjarta: kona, maður, ljósur húðarlitur',
    '👩🏻‍❤‍👨🏼' => 'par og hjarta: kona, maður, ljósur húðarlitur, miðalljósur húðarlitur',
    '👩🏻‍❤‍👨🏽' => 'par og hjarta: kona, maður, ljósur húðarlitur, miðal húðarlitur',
    '👩🏻‍❤‍👨🏾' => 'par og hjarta: kona, maður, ljósur húðarlitur, miðalmyrkur húðarlitur',
    '👩🏻‍❤‍👨🏿' => 'par og hjarta: kona, maður, ljósur húðarlitur, myrkur húðarlitur',
    '👩🏼‍❤‍👨🏻' => 'par og hjarta: kona, maður, miðalljósur húðarlitur, ljósur húðarlitur',
    '👩🏼‍❤‍👨🏼' => 'par og hjarta: kona, maður, miðalljósur húðarlitur',
    '👩🏼‍❤‍👨🏽' => 'par og hjarta: kona, maður, miðalljósur húðarlitur, miðal húðarlitur',
    '👩🏼‍❤‍👨🏾' => 'par og hjarta: kona, maður, miðalljósur húðarlitur, miðalmyrkur húðarlitur',
    '👩🏼‍❤‍👨🏿' => 'par og hjarta: kona, maður, miðalljósur húðarlitur, myrkur húðarlitur',
    '👩🏽‍❤‍👨🏻' => 'par og hjarta: kona, maður, miðal húðarlitur, ljósur húðarlitur',
    '👩🏽‍❤‍👨🏼' => 'par og hjarta: kona, maður, miðal húðarlitur, miðalljósur húðarlitur',
    '👩🏽‍❤‍👨🏽' => 'par og hjarta: kona, maður, miðal húðarlitur',
    '👩🏽‍❤‍👨🏾' => 'par og hjarta: kona, maður, miðal húðarlitur, miðalmyrkur húðarlitur',
    '👩🏽‍❤‍👨🏿' => 'par og hjarta: kona, maður, miðal húðarlitur, myrkur húðarlitur',
    '👩🏾‍❤‍👨🏻' => 'par og hjarta: kona, maður, miðalmyrkur húðarlitur, ljósur húðarlitur',
    '👩🏾‍❤‍👨🏼' => 'par og hjarta: kona, maður, miðalmyrkur húðarlitur, miðalljósur húðarlitur',
    '👩🏾‍❤‍👨🏽' => 'par og hjarta: kona, maður, miðalmyrkur húðarlitur, miðal húðarlitur',
    '👩🏾‍❤‍👨🏾' => 'par og hjarta: kona, maður, miðalmyrkur húðarlitur',
    '👩🏾‍❤‍👨🏿' => 'par og hjarta: kona, maður, miðalmyrkur húðarlitur, myrkur húðarlitur',
    '👩🏿‍❤‍👨🏻' => 'par og hjarta: kona, maður, myrkur húðarlitur, ljósur húðarlitur',
    '👩🏿‍❤‍👨🏼' => 'par og hjarta: kona, maður, myrkur húðarlitur, miðalljósur húðarlitur',
    '👩🏿‍❤‍👨🏽' => 'par og hjarta: kona, maður, myrkur húðarlitur, miðal húðarlitur',
    '👩🏿‍❤‍👨🏾' => 'par og hjarta: kona, maður, myrkur húðarlitur, miðalmyrkur húðarlitur',
    '👩🏿‍❤‍👨🏿' => 'par og hjarta: kona, maður, myrkur húðarlitur',
    '👩🏻‍❤‍👩🏻' => 'par og hjarta: kona, kona, ljósur húðarlitur',
    '👩🏻‍❤‍👩🏼' => 'par og hjarta: kona, kona, ljósur húðarlitur, miðalljósur húðarlitur',
    '👩🏻‍❤‍👩🏽' => 'par og hjarta: kona, kona, ljósur húðarlitur, miðal húðarlitur',
    '👩🏻‍❤‍👩🏾' => 'par og hjarta: kona, kona, ljósur húðarlitur, miðalmyrkur húðarlitur',
    '👩🏻‍❤‍👩🏿' => 'par og hjarta: kona, kona, ljósur húðarlitur, myrkur húðarlitur',
    '👩🏼‍❤‍👩🏻' => 'par og hjarta: kona, kona, miðalljósur húðarlitur, ljósur húðarlitur',
    '👩🏼‍❤‍👩🏼' => 'par og hjarta: kona, kona, miðalljósur húðarlitur',
    '👩🏼‍❤‍👩🏽' => 'par og hjarta: kona, kona, miðalljósur húðarlitur, miðal húðarlitur',
    '👩🏼‍❤‍👩🏾' => 'par og hjarta: kona, kona, miðalljósur húðarlitur, miðalmyrkur húðarlitur',
    '👩🏼‍❤‍👩🏿' => 'par og hjarta: kona, kona, miðalljósur húðarlitur, myrkur húðarlitur',
    '👩🏽‍❤‍👩🏻' => 'par og hjarta: kona, kona, miðal húðarlitur, ljósur húðarlitur',
    '👩🏽‍❤‍👩🏼' => 'par og hjarta: kona, kona, miðal húðarlitur, miðalljósur húðarlitur',
    '👩🏽‍❤‍👩🏽' => 'par og hjarta: kona, kona, miðal húðarlitur',
    '👩🏽‍❤‍👩🏾' => 'par og hjarta: kona, kona, miðal húðarlitur, miðalmyrkur húðarlitur',
    '👩🏽‍❤‍👩🏿' => 'par og hjarta: kona, kona, miðal húðarlitur, myrkur húðarlitur',
    '👩🏾‍❤‍👩🏻' => 'par og hjarta: kona, kona, miðalmyrkur húðarlitur, ljósur húðarlitur',
    '👩🏾‍❤‍👩🏼' => 'par og hjarta: kona, kona, miðalmyrkur húðarlitur, miðalljósur húðarlitur',
    '👩🏾‍❤‍👩🏽' => 'par og hjarta: kona, kona, miðalmyrkur húðarlitur, miðal húðarlitur',
    '👩🏾‍❤‍👩🏾' => 'par og hjarta: kona, kona, miðalmyrkur húðarlitur',
    '👩🏾‍❤‍👩🏿' => 'par og hjarta: kona, kona, miðalmyrkur húðarlitur, myrkur húðarlitur',
    '👩🏿‍❤‍👩🏻' => 'par og hjarta: kona, kona, myrkur húðarlitur, ljósur húðarlitur',
    '👩🏿‍❤‍👩🏼' => 'par og hjarta: kona, kona, myrkur húðarlitur, miðalljósur húðarlitur',
    '👩🏿‍❤‍👩🏽' => 'par og hjarta: kona, kona, myrkur húðarlitur, miðal húðarlitur',
    '👩🏿‍❤‍👩🏾' => 'par og hjarta: kona, kona, myrkur húðarlitur, miðalmyrkur húðarlitur',
    '👩🏿‍❤‍👩🏿' => 'par og hjarta: kona, kona, myrkur húðarlitur',
    '👩🏻‍🐰‍👩🏼' => 'kvinnur við haruoyrum: ljósur húðarlitur, miðalljósur húðarlitur',
    '👩🏻‍🐰‍👩🏽' => 'kvinnur við haruoyrum: ljósur húðarlitur, miðal húðarlitur',
    '👩🏻‍🐰‍👩🏾' => 'kvinnur við haruoyrum: ljósur húðarlitur, miðalmyrkur húðarlitur',
    '👩🏻‍🐰‍👩🏿' => 'kvinnur við haruoyrum: ljósur húðarlitur, myrkur húðarlitur',
    '👩🏼‍🐰‍👩🏻' => 'kvinnur við haruoyrum: miðalljósur húðarlitur, ljósur húðarlitur',
    '👩🏼‍🐰‍👩🏽' => 'kvinnur við haruoyrum: miðalljósur húðarlitur, miðal húðarlitur',
    '👩🏼‍🐰‍👩🏾' => 'kvinnur við haruoyrum: miðalljósur húðarlitur, miðalmyrkur húðarlitur',
    '👩🏼‍🐰‍👩🏿' => 'kvinnur við haruoyrum: miðalljósur húðarlitur, myrkur húðarlitur',
    '👩🏽‍🐰‍👩🏻' => 'kvinnur við haruoyrum: miðal húðarlitur, ljósur húðarlitur',
    '👩🏽‍🐰‍👩🏼' => 'kvinnur við haruoyrum: miðal húðarlitur, miðalljósur húðarlitur',
    '👩🏽‍🐰‍👩🏾' => 'kvinnur við haruoyrum: miðal húðarlitur, miðalmyrkur húðarlitur',
    '👩🏽‍🐰‍👩🏿' => 'kvinnur við haruoyrum: miðal húðarlitur, myrkur húðarlitur',
    '👩🏾‍🐰‍👩🏻' => 'kvinnur við haruoyrum: miðalmyrkur húðarlitur, ljósur húðarlitur',
    '👩🏾‍🐰‍👩🏼' => 'kvinnur við haruoyrum: miðalmyrkur húðarlitur, miðalljósur húðarlitur',
    '👩🏾‍🐰‍👩🏽' => 'kvinnur við haruoyrum: miðalmyrkur húðarlitur, miðal húðarlitur',
    '👩🏾‍🐰‍👩🏿' => 'kvinnur við haruoyrum: miðalmyrkur húðarlitur, myrkur húðarlitur',
    '👩🏿‍🐰‍👩🏻' => 'kvinnur við haruoyrum: myrkur húðarlitur, ljósur húðarlitur',
    '👩🏿‍🐰‍👩🏼' => 'kvinnur við haruoyrum: myrkur húðarlitur, miðalljósur húðarlitur',
    '👩🏿‍🐰‍👩🏽' => 'kvinnur við haruoyrum: myrkur húðarlitur, miðal húðarlitur',
    '👩🏿‍🐰‍👩🏾' => 'kvinnur við haruoyrum: myrkur húðarlitur, miðalmyrkur húðarlitur',
    '🧑🏻‍🤝‍🧑🏻' => 'fólk leiðast: ljósur húðarlitur',
    '🧑🏻‍🤝‍🧑🏼' => 'fólk leiðast: ljósur húðarlitur, miðalljósur húðarlitur',
    '🧑🏻‍🤝‍🧑🏽' => 'fólk leiðast: ljósur húðarlitur, miðal húðarlitur',
    '🧑🏻‍🤝‍🧑🏾' => 'fólk leiðast: ljósur húðarlitur, miðalmyrkur húðarlitur',
    '🧑🏻‍🤝‍🧑🏿' => 'fólk leiðast: ljósur húðarlitur, myrkur húðarlitur',
    '🧑🏼‍🤝‍🧑🏻' => 'fólk leiðast: miðalljósur húðarlitur, ljósur húðarlitur',
    '🧑🏼‍🤝‍🧑🏼' => 'fólk leiðast: miðalljósur húðarlitur',
    '🧑🏼‍🤝‍🧑🏽' => 'fólk leiðast: miðalljósur húðarlitur, miðal húðarlitur',
    '🧑🏼‍🤝‍🧑🏾' => 'fólk leiðast: miðalljósur húðarlitur, miðalmyrkur húðarlitur',
    '🧑🏼‍🤝‍🧑🏿' => 'fólk leiðast: miðalljósur húðarlitur, myrkur húðarlitur',
    '🧑🏽‍🤝‍🧑🏻' => 'fólk leiðast: miðal húðarlitur, ljósur húðarlitur',
    '🧑🏽‍🤝‍🧑🏼' => 'fólk leiðast: miðal húðarlitur, miðalljósur húðarlitur',
    '🧑🏽‍🤝‍🧑🏽' => 'fólk leiðast: miðal húðarlitur',
    '🧑🏽‍🤝‍🧑🏾' => 'fólk leiðast: miðal húðarlitur, miðalmyrkur húðarlitur',
    '🧑🏽‍🤝‍🧑🏿' => 'fólk leiðast: miðal húðarlitur, myrkur húðarlitur',
    '🧑🏾‍🤝‍🧑🏻' => 'fólk leiðast: miðalmyrkur húðarlitur, ljósur húðarlitur',
    '🧑🏾‍🤝‍🧑🏼' => 'fólk leiðast: miðalmyrkur húðarlitur, miðalljósur húðarlitur',
    '🧑🏾‍🤝‍🧑🏽' => 'fólk leiðast: miðalmyrkur húðarlitur, miðal húðarlitur',
    '🧑🏾‍🤝‍🧑🏾' => 'fólk leiðast: miðalmyrkur húðarlitur',
    '🧑🏾‍🤝‍🧑🏿' => 'fólk leiðast: miðalmyrkur húðarlitur, myrkur húðarlitur',
    '🧑🏿‍🤝‍🧑🏻' => 'fólk leiðast: myrkur húðarlitur, ljósur húðarlitur',
    '🧑🏿‍🤝‍🧑🏼' => 'fólk leiðast: myrkur húðarlitur, miðalljósur húðarlitur',
    '🧑🏿‍🤝‍🧑🏽' => 'fólk leiðast: myrkur húðarlitur, miðal húðarlitur',
    '🧑🏿‍🤝‍🧑🏾' => 'fólk leiðast: myrkur húðarlitur, miðalmyrkur húðarlitur',
    '🧑🏿‍🤝‍🧑🏿' => 'fólk leiðast: myrkur húðarlitur',
    '👩🏻‍🤝‍👩🏼' => 'kvinnur leiðast: ljósur húðarlitur, miðalljósur húðarlitur',
    '👩🏻‍🤝‍👩🏽' => 'kvinnur leiðast: ljósur húðarlitur, miðal húðarlitur',
    '👩🏻‍🤝‍👩🏾' => 'kvinnur leiðast: ljósur húðarlitur, miðalmyrkur húðarlitur',
    '👩🏻‍🤝‍👩🏿' => 'kvinnur leiðast: ljósur húðarlitur, myrkur húðarlitur',
    '👩🏼‍🤝‍👩🏻' => 'kvinnur leiðast: miðalljósur húðarlitur, ljósur húðarlitur',
    '👩🏼‍🤝‍👩🏽' => 'kvinnur leiðast: miðalljósur húðarlitur, miðal húðarlitur',
    '👩🏼‍🤝‍👩🏾' => 'kvinnur leiðast: miðalljósur húðarlitur, miðalmyrkur húðarlitur',
    '👩🏼‍🤝‍👩🏿' => 'kvinnur leiðast: miðalljósur húðarlitur, myrkur húðarlitur',
    '👩🏽‍🤝‍👩🏻' => 'kvinnur leiðast: miðal húðarlitur, ljósur húðarlitur',
    '👩🏽‍🤝‍👩🏼' => 'kvinnur leiðast: miðal húðarlitur, miðalljósur húðarlitur',
    '👩🏽‍🤝‍👩🏾' => 'kvinnur leiðast: miðal húðarlitur, miðalmyrkur húðarlitur',
    '👩🏽‍🤝‍👩🏿' => 'kvinnur leiðast: miðal húðarlitur, myrkur húðarlitur',
    '👩🏾‍🤝‍👩🏻' => 'kvinnur leiðast: miðalmyrkur húðarlitur, ljósur húðarlitur',
    '👩🏾‍🤝‍👩🏼' => 'kvinnur leiðast: miðalmyrkur húðarlitur, miðalljósur húðarlitur',
    '👩🏾‍🤝‍👩🏽' => 'kvinnur leiðast: miðalmyrkur húðarlitur, miðal húðarlitur',
    '👩🏾‍🤝‍👩🏿' => 'kvinnur leiðast: miðalmyrkur húðarlitur, myrkur húðarlitur',
    '👩🏿‍🤝‍👩🏻' => 'kvinnur leiðast: myrkur húðarlitur, ljósur húðarlitur',
    '👩🏿‍🤝‍👩🏼' => 'kvinnur leiðast: myrkur húðarlitur, miðalljósur húðarlitur',
    '👩🏿‍🤝‍👩🏽' => 'kvinnur leiðast: myrkur húðarlitur, miðal húðarlitur',
    '👩🏿‍🤝‍👩🏾' => 'kvinnur leiðast: myrkur húðarlitur, miðalmyrkur húðarlitur',
    '👩🏻‍🤝‍👨🏼' => 'kvinna or maður leiðast: ljósur húðarlitur, miðalljósur húðarlitur',
    '👩🏻‍🤝‍👨🏽' => 'kvinna or maður leiðast: ljósur húðarlitur, miðal húðarlitur',
    '👩🏻‍🤝‍👨🏾' => 'kvinna or maður leiðast: ljósur húðarlitur, miðalmyrkur húðarlitur',
    '👩🏻‍🤝‍👨🏿' => 'kvinna or maður leiðast: ljósur húðarlitur, myrkur húðarlitur',
    '👩🏼‍🤝‍👨🏻' => 'kvinna or maður leiðast: miðalljósur húðarlitur, ljósur húðarlitur',
    '👩🏼‍🤝‍👨🏽' => 'kvinna or maður leiðast: miðalljósur húðarlitur, miðal húðarlitur',
    '👩🏼‍🤝‍👨🏾' => 'kvinna or maður leiðast: miðalljósur húðarlitur, miðalmyrkur húðarlitur',
    '👩🏼‍🤝‍👨🏿' => 'kvinna or maður leiðast: miðalljósur húðarlitur, myrkur húðarlitur',
    '👩🏽‍🤝‍👨🏻' => 'kvinna or maður leiðast: miðal húðarlitur, ljósur húðarlitur',
    '👩🏽‍🤝‍👨🏼' => 'kvinna or maður leiðast: miðal húðarlitur, miðalljósur húðarlitur',
    '👩🏽‍🤝‍👨🏾' => 'kvinna or maður leiðast: miðal húðarlitur, miðalmyrkur húðarlitur',
    '👩🏽‍🤝‍👨🏿' => 'kvinna or maður leiðast: miðal húðarlitur, myrkur húðarlitur',
    '👩🏾‍🤝‍👨🏻' => 'kvinna or maður leiðast: miðalmyrkur húðarlitur, ljósur húðarlitur',
    '👩🏾‍🤝‍👨🏼' => 'kvinna or maður leiðast: miðalmyrkur húðarlitur, miðalljósur húðarlitur',
    '👩🏾‍🤝‍👨🏽' => 'kvinna or maður leiðast: miðalmyrkur húðarlitur, miðal húðarlitur',
    '👩🏾‍🤝‍👨🏿' => 'kvinna or maður leiðast: miðalmyrkur húðarlitur, myrkur húðarlitur',
    '👩🏿‍🤝‍👨🏻' => 'kvinna or maður leiðast: myrkur húðarlitur, ljósur húðarlitur',
    '👩🏿‍🤝‍👨🏼' => 'kvinna or maður leiðast: myrkur húðarlitur, miðalljósur húðarlitur',
    '👩🏿‍🤝‍👨🏽' => 'kvinna or maður leiðast: myrkur húðarlitur, miðal húðarlitur',
    '👩🏿‍🤝‍👨🏾' => 'kvinna or maður leiðast: myrkur húðarlitur, miðalmyrkur húðarlitur',
    '👨🏻‍🤝‍👨🏼' => 'menn leiðast: ljósur húðarlitur, miðalljósur húðarlitur',
    '👨🏻‍🤝‍👨🏽' => 'menn leiðast: ljósur húðarlitur, miðal húðarlitur',
    '👨🏻‍🤝‍👨🏾' => 'menn leiðast: ljósur húðarlitur, miðalmyrkur húðarlitur',
    '👨🏻‍🤝‍👨🏿' => 'menn leiðast: ljósur húðarlitur, myrkur húðarlitur',
    '👨🏼‍🤝‍👨🏻' => 'menn leiðast: miðalljósur húðarlitur, ljósur húðarlitur',
    '👨🏼‍🤝‍👨🏽' => 'menn leiðast: miðalljósur húðarlitur, miðal húðarlitur',
    '👨🏼‍🤝‍👨🏾' => 'menn leiðast: miðalljósur húðarlitur, miðalmyrkur húðarlitur',
    '👨🏼‍🤝‍👨🏿' => 'menn leiðast: miðalljósur húðarlitur, myrkur húðarlitur',
    '👨🏽‍🤝‍👨🏻' => 'menn leiðast: miðal húðarlitur, ljósur húðarlitur',
    '👨🏽‍🤝‍👨🏼' => 'menn leiðast: miðal húðarlitur, miðalljósur húðarlitur',
    '👨🏽‍🤝‍👨🏾' => 'menn leiðast: miðal húðarlitur, miðalmyrkur húðarlitur',
    '👨🏽‍🤝‍👨🏿' => 'menn leiðast: miðal húðarlitur, myrkur húðarlitur',
    '👨🏾‍🤝‍👨🏻' => 'menn leiðast: miðalmyrkur húðarlitur, ljósur húðarlitur',
    '👨🏾‍🤝‍👨🏼' => 'menn leiðast: miðalmyrkur húðarlitur, miðalljósur húðarlitur',
    '👨🏾‍🤝‍👨🏽' => 'menn leiðast: miðalmyrkur húðarlitur, miðal húðarlitur',
    '👨🏾‍🤝‍👨🏿' => 'menn leiðast: miðalmyrkur húðarlitur, myrkur húðarlitur',
    '👨🏿‍🤝‍👨🏻' => 'menn leiðast: myrkur húðarlitur, ljósur húðarlitur',
    '👨🏿‍🤝‍👨🏼' => 'menn leiðast: myrkur húðarlitur, miðalljósur húðarlitur',
    '👨🏿‍🤝‍👨🏽' => 'menn leiðast: myrkur húðarlitur, miðal húðarlitur',
    '👨🏿‍🤝‍👨🏾' => 'menn leiðast: myrkur húðarlitur, miðalmyrkur húðarlitur',
    '👩‍❤‍💋‍👨' => 'tvey íð mussast: kona, maður',
    '👨‍❤‍💋‍👨' => 'tvey íð mussast: maður, maður',
    '👩‍❤‍💋‍👩' => 'tvey íð mussast: kona, kona',
    '👨‍👩‍👧‍👦' => 'familja: maður, kona, genta, drongur',
    '👨‍👩‍👦‍👦' => 'familja: maður, kona, drongur, drongur',
    '👨‍👩‍👧‍👧' => 'familja: maður, kona, genta, genta',
    '👨‍👨‍👧‍👦' => 'familja: maður, maður, genta, drongur',
    '👨‍👨‍👦‍👦' => 'familja: maður, maður, drongur, drongur',
    '👨‍👨‍👧‍👧' => 'familja: maður, maður, genta, genta',
    '👩‍👩‍👧‍👦' => 'familja: kona, kona, genta, drongur',
    '👩‍👩‍👦‍👦' => 'familja: kona, kona, drongur, drongur',
    '👩‍👩‍👧‍👧' => 'familja: kona, kona, genta, genta',
    '🧑‍🧑‍🧒‍🧒' => 'familja: vaksin, vaksin, barn, barn',
    '🚶🏻‍♀‍➡' => 'kvinna sum gongur: ljósur húðarlitur, til høgru',
    '🚶🏼‍♀‍➡' => 'kvinna sum gongur: miðalljósur húðarlitur, til høgru',
    '🚶🏽‍♀‍➡' => 'kvinna sum gongur: miðal húðarlitur, til høgru',
    '🚶🏾‍♀‍➡' => 'kvinna sum gongur: miðalmyrkur húðarlitur, til høgru',
    '🚶🏿‍♀‍➡' => 'kvinna sum gongur: myrkur húðarlitur, til høgru',
    '🚶🏻‍♂‍➡' => 'maður sum gongur: ljósur húðarlitur, til høgru',
    '🚶🏼‍♂‍➡' => 'maður sum gongur: miðalljósur húðarlitur, til høgru',
    '🚶🏽‍♂‍➡' => 'maður sum gongur: miðal húðarlitur, til høgru',
    '🚶🏾‍♂‍➡' => 'maður sum gongur: miðalmyrkur húðarlitur, til høgru',
    '🚶🏿‍♂‍➡' => 'maður sum gongur: myrkur húðarlitur, til høgru',
    '🧎🏻‍♀‍➡' => 'kvinna á knæ: ljósur húðarlitur, til høgru',
    '🧎🏼‍♀‍➡' => 'kvinna á knæ: miðalljósur húðarlitur, til høgru',
    '🧎🏽‍♀‍➡' => 'kvinna á knæ: miðal húðarlitur, til høgru',
    '🧎🏾‍♀‍➡' => 'kvinna á knæ: miðalmyrkur húðarlitur, til høgru',
    '🧎🏿‍♀‍➡' => 'kvinna á knæ: myrkur húðarlitur, til høgru',
    '🧎🏻‍♂‍➡' => 'maður á knæ: ljósur húðarlitur, til høgru',
    '🧎🏼‍♂‍➡' => 'maður á knæ: miðalljósur húðarlitur, til høgru',
    '🧎🏽‍♂‍➡' => 'maður á knæ: miðal húðarlitur, til høgru',
    '🧎🏾‍♂‍➡' => 'maður á knæ: miðalmyrkur húðarlitur, til høgru',
    '🧎🏿‍♂‍➡' => 'maður á knæ: myrkur húðarlitur, til høgru',
    '🧑🏻‍🦯‍➡' => 'persónur við blindastavi: ljósur húðarlitur, til høgru',
    '🧑🏼‍🦯‍➡' => 'persónur við blindastavi: miðalljósur húðarlitur, til høgru',
    '🧑🏽‍🦯‍➡' => 'persónur við blindastavi: miðal húðarlitur, til høgru',
    '🧑🏾‍🦯‍➡' => 'persónur við blindastavi: miðalmyrkur húðarlitur, til høgru',
    '🧑🏿‍🦯‍➡' => 'persónur við blindastavi: myrkur húðarlitur, til høgru',
    '👨🏻‍🦯‍➡' => 'maður við blindastavi: ljósur húðarlitur, til høgru',
    '👨🏼‍🦯‍➡' => 'maður við blindastavi: miðalljósur húðarlitur, til høgru',
    '👨🏽‍🦯‍➡' => 'maður við blindastavi: miðal húðarlitur, til høgru',
    '👨🏾‍🦯‍➡' => 'maður við blindastavi: miðalmyrkur húðarlitur, til høgru',
    '👨🏿‍🦯‍➡' => 'maður við blindastavi: myrkur húðarlitur, til høgru',
    '👩🏻‍🦯‍➡' => 'kvinna við blindastavi: ljósur húðarlitur, til høgru',
    '👩🏼‍🦯‍➡' => 'kvinna við blindastavi: miðalljósur húðarlitur, til høgru',
    '👩🏽‍🦯‍➡' => 'kvinna við blindastavi: miðal húðarlitur, til høgru',
    '👩🏾‍🦯‍➡' => 'kvinna við blindastavi: miðalmyrkur húðarlitur, til høgru',
    '👩🏿‍🦯‍➡' => 'kvinna við blindastavi: myrkur húðarlitur, til høgru',
    '🧑🏻‍🦼‍➡' => 'persónur í motorkoyristóli: ljósur húðarlitur, til høgru',
    '🧑🏼‍🦼‍➡' => 'persónur í motorkoyristóli: miðalljósur húðarlitur, til høgru',
    '🧑🏽‍🦼‍➡' => 'persónur í motorkoyristóli: miðal húðarlitur, til høgru',
    '🧑🏾‍🦼‍➡' => 'persónur í motorkoyristóli: miðalmyrkur húðarlitur, til høgru',
    '🧑🏿‍🦼‍➡' => 'persónur í motorkoyristóli: myrkur húðarlitur, til høgru',
    '👨🏻‍🦼‍➡' => 'maður í motorkoyristóli: ljósur húðarlitur, til høgru',
    '👨🏼‍🦼‍➡' => 'maður í motorkoyristóli: miðalljósur húðarlitur, til høgru',
    '👨🏽‍🦼‍➡' => 'maður í motorkoyristóli: miðal húðarlitur, til høgru',
    '👨🏾‍🦼‍➡' => 'maður í motorkoyristóli: miðalmyrkur húðarlitur, til høgru',
    '👨🏿‍🦼‍➡' => 'maður í motorkoyristóli: myrkur húðarlitur, til høgru',
    '👩🏻‍🦼‍➡' => 'kvinna í motorkoyristóli: ljósur húðarlitur, til høgru',
    '👩🏼‍🦼‍➡' => 'kvinna í motorkoyristóli: miðalljósur húðarlitur, til høgru',
    '👩🏽‍🦼‍➡' => 'kvinna í motorkoyristóli: miðal húðarlitur, til høgru',
    '👩🏾‍🦼‍➡' => 'kvinna í motorkoyristóli: miðalmyrkur húðarlitur, til høgru',
    '👩🏿‍🦼‍➡' => 'kvinna í motorkoyristóli: myrkur húðarlitur, til høgru',
    '🧑🏻‍🦽‍➡' => 'persónur í koyristóli: ljósur húðarlitur, til høgru',
    '🧑🏼‍🦽‍➡' => 'persónur í koyristóli: miðalljósur húðarlitur, til høgru',
    '🧑🏽‍🦽‍➡' => 'persónur í koyristóli: miðal húðarlitur, til høgru',
    '🧑🏾‍🦽‍➡' => 'persónur í koyristóli: miðalmyrkur húðarlitur, til høgru',
    '🧑🏿‍🦽‍➡' => 'persónur í koyristóli: myrkur húðarlitur, til høgru',
    '👨🏻‍🦽‍➡' => 'maður í koyristóli: ljósur húðarlitur, til høgru',
    '👨🏼‍🦽‍➡' => 'maður í koyristóli: miðalljósur húðarlitur, til høgru',
    '👨🏽‍🦽‍➡' => 'maður í koyristóli: miðal húðarlitur, til høgru',
    '👨🏾‍🦽‍➡' => 'maður í koyristóli: miðalmyrkur húðarlitur, til høgru',
    '👨🏿‍🦽‍➡' => 'maður í koyristóli: myrkur húðarlitur, til høgru',
    '👩🏻‍🦽‍➡' => 'kvinna í koyristóli: ljósur húðarlitur, til høgru',
    '👩🏼‍🦽‍➡' => 'kvinna í koyristóli: miðalljósur húðarlitur, til høgru',
    '👩🏽‍🦽‍➡' => 'kvinna í koyristóli: miðal húðarlitur, til høgru',
    '👩🏾‍🦽‍➡' => 'kvinna í koyristóli: miðalmyrkur húðarlitur, til høgru',
    '👩🏿‍🦽‍➡' => 'kvinna í koyristóli: myrkur húðarlitur, til høgru',
    '🏃🏻‍♀‍➡' => 'kvinna sum rennur: ljósur húðarlitur, til høgru',
    '🏃🏼‍♀‍➡' => 'kvinna sum rennur: miðalljósur húðarlitur, til høgru',
    '🏃🏽‍♀‍➡' => 'kvinna sum rennur: miðal húðarlitur, til høgru',
    '🏃🏾‍♀‍➡' => 'kvinna sum rennur: miðalmyrkur húðarlitur, til høgru',
    '🏃🏿‍♀‍➡' => 'kvinna sum rennur: myrkur húðarlitur, til høgru',
    '🏃🏻‍♂‍➡' => 'maður sum rennur: ljósur húðarlitur, til høgru',
    '🏃🏼‍♂‍➡' => 'maður sum rennur: miðalljósur húðarlitur, til høgru',
    '🏃🏽‍♂‍➡' => 'maður sum rennur: miðal húðarlitur, til høgru',
    '🏃🏾‍♂‍➡' => 'maður sum rennur: miðalmyrkur húðarlitur, til høgru',
    '🏃🏿‍♂‍➡' => 'maður sum rennur: myrkur húðarlitur, til høgru',
    '🫱🏻‍🫲🏼' => 'lógvatak: ljósur húðarlitur, miðalljósur húðarlitur',
    '🫱🏻‍🫲🏽' => 'lógvatak: ljósur húðarlitur, miðal húðarlitur',
    '🫱🏻‍🫲🏾' => 'lógvatak: ljósur húðarlitur, miðalmyrkur húðarlitur',
    '🫱🏻‍🫲🏿' => 'lógvatak: ljósur húðarlitur, myrkur húðarlitur',
    '🫱🏼‍🫲🏻' => 'lógvatak: miðalljósur húðarlitur, ljósur húðarlitur',
    '🫱🏼‍🫲🏽' => 'lógvatak: miðalljósur húðarlitur, miðal húðarlitur',
    '🫱🏼‍🫲🏾' => 'lógvatak: miðalljósur húðarlitur, miðalmyrkur húðarlitur',
    '🫱🏼‍🫲🏿' => 'lógvatak: miðalljósur húðarlitur, myrkur húðarlitur',
    '🫱🏽‍🫲🏻' => 'lógvatak: miðal húðarlitur, ljósur húðarlitur',
    '🫱🏽‍🫲🏼' => 'lógvatak: miðal húðarlitur, miðalljósur húðarlitur',
    '🫱🏽‍🫲🏾' => 'lógvatak: miðal húðarlitur, miðalmyrkur húðarlitur',
    '🫱🏽‍🫲🏿' => 'lógvatak: miðal húðarlitur, myrkur húðarlitur',
    '🫱🏾‍🫲🏻' => 'lógvatak: miðalmyrkur húðarlitur, ljósur húðarlitur',
    '🫱🏾‍🫲🏼' => 'lógvatak: miðalmyrkur húðarlitur, miðalljósur húðarlitur',
    '🫱🏾‍🫲🏽' => 'lógvatak: miðalmyrkur húðarlitur, miðal húðarlitur',
    '🫱🏾‍🫲🏿' => 'lógvatak: miðalmyrkur húðarlitur, myrkur húðarlitur',
    '🫱🏿‍🫲🏻' => 'lógvatak: myrkur húðarlitur, ljósur húðarlitur',
    '🫱🏿‍🫲🏼' => 'lógvatak: myrkur húðarlitur, miðalljósur húðarlitur',
    '🫱🏿‍🫲🏽' => 'lógvatak: myrkur húðarlitur, miðal húðarlitur',
    '🫱🏿‍🫲🏾' => 'lógvatak: myrkur húðarlitur, miðalmyrkur húðarlitur',
    '🚶‍♀‍➡' => 'kvinna sum gongur: til høgru',
    '🚶‍♂‍➡' => 'maður sum gongur: til høgru',
    '🧎‍♀‍➡' => 'kvinna á knæ: til høgru',
    '🧎‍♂‍➡' => 'maður á knæ: til høgru',
    '🧑‍🦯‍➡' => 'persónur við blindastavi: til høgru',
    '👨‍🦯‍➡' => 'maður við blindastavi: til høgru',
    '👩‍🦯‍➡' => 'kvinna við blindastavi: til høgru',
    '🧑‍🦼‍➡' => 'persónur í motorkoyristóli: til høgru',
    '👨‍🦼‍➡' => 'maður í motorkoyristóli: til høgru',
    '👩‍🦼‍➡' => 'kvinna í motorkoyristóli: til høgru',
    '🧑‍🦽‍➡' => 'persónur í koyristóli: til høgru',
    '👨‍🦽‍➡' => 'maður í koyristóli: til høgru',
    '👩‍🦽‍➡' => 'kvinna í koyristóli: til høgru',
    '🏃‍♀‍➡' => 'kvinna sum rennur: til høgru',
    '🏃‍♂‍➡' => 'maður sum rennur: til høgru',
    '👩‍❤‍👨' => 'par og hjarta: kona, maður',
    '👨‍❤‍👨' => 'par og hjarta: maður, maður',
    '👩‍❤‍👩' => 'par og hjarta: kona, kona',
    '👨‍👩‍👦' => 'familja: maður, kona, drongur',
    '👨‍👩‍👧' => 'familja: maður, kona, genta',
    '👨‍👨‍👦' => 'familja: maður, maður, drongur',
    '👨‍👨‍👧' => 'familja: maður, maður, genta',
    '👩‍👩‍👦' => 'familja: kona, kona, drongur',
    '👩‍👩‍👧' => 'familja: kona, kona, genta',
    '👨‍👦‍👦' => 'familja: maður, drongur, drongur',
    '👨‍👧‍👦' => 'familja: maður, genta, drongur',
    '👨‍👧‍👧' => 'familja: maður, genta, genta',
    '👩‍👦‍👦' => 'familja: kona, drongur, drongur',
    '👩‍👧‍👦' => 'familja: kona, genta, drongur',
    '👩‍👧‍👧' => 'familja: kona, genta, genta',
    '🧑‍🤝‍🧑' => 'fólk leiðast',
    '🧑‍🧑‍🧒' => 'familja: vaksin, vaksin, barn',
    '🧑‍🧒‍🧒' => 'familja: vaksin, barn, barn',
    '🧑🏻‍🦰' => 'persónur: ljósur húðarlitur, reytt hár',
    '🧑🏼‍🦰' => 'persónur: miðalljósur húðarlitur, reytt hár',
    '🧑🏽‍🦰' => 'persónur: miðal húðarlitur, reytt hár',
    '🧑🏾‍🦰' => 'persónur: miðalmyrkur húðarlitur, reytt hár',
    '🧑🏿‍🦰' => 'persónur: myrkur húðarlitur, reytt hár',
    '🧑🏻‍🦱' => 'persónur: ljósur húðarlitur, purlut hár',
    '🧑🏼‍🦱' => 'persónur: miðalljósur húðarlitur, purlut hár',
    '🧑🏽‍🦱' => 'persónur: miðal húðarlitur, purlut hár',
    '🧑🏾‍🦱' => 'persónur: miðalmyrkur húðarlitur, purlut hár',
    '🧑🏿‍🦱' => 'persónur: myrkur húðarlitur, purlut hár',
    '🧑🏻‍🦳' => 'persónur: ljósur húðarlitur, hvítt hár',
    '🧑🏼‍🦳' => 'persónur: miðalljósur húðarlitur, hvítt hár',
    '🧑🏽‍🦳' => 'persónur: miðal húðarlitur, hvítt hár',
    '🧑🏾‍🦳' => 'persónur: miðalmyrkur húðarlitur, hvítt hár',
    '🧑🏿‍🦳' => 'persónur: myrkur húðarlitur, hvítt hár',
    '🧑🏻‍🦲' => 'persónur: ljósur húðarlitur, skallutur',
    '🧑🏼‍🦲' => 'persónur: miðalljósur húðarlitur, skallutur',
    '🧑🏽‍🦲' => 'persónur: miðal húðarlitur, skallutur',
    '🧑🏾‍🦲' => 'persónur: miðalmyrkur húðarlitur, skallutur',
    '🧑🏿‍🦲' => 'persónur: myrkur húðarlitur, skallutur',
    '🧔🏻‍♂' => 'maður við skeggi: ljósur húðarlitur',
    '🧔🏼‍♂' => 'maður við skeggi: miðalljósur húðarlitur',
    '🧔🏽‍♂' => 'maður við skeggi: miðal húðarlitur',
    '🧔🏾‍♂' => 'maður við skeggi: miðalmyrkur húðarlitur',
    '🧔🏿‍♂' => 'maður við skeggi: myrkur húðarlitur',
    '👱🏻‍♂' => 'ljóshærdur maður: ljósur húðarlitur',
    '👱🏼‍♂' => 'ljóshærdur maður: miðalljósur húðarlitur',
    '👱🏽‍♂' => 'ljóshærdur maður: miðal húðarlitur',
    '👱🏾‍♂' => 'ljóshærdur maður: miðalmyrkur húðarlitur',
    '👱🏿‍♂' => 'ljóshærdur maður: myrkur húðarlitur',
    '👨🏻‍🦰' => 'maður: ljósur húðarlitur, reytt hár',
    '👨🏼‍🦰' => 'maður: miðalljósur húðarlitur, reytt hár',
    '👨🏽‍🦰' => 'maður: miðal húðarlitur, reytt hár',
    '👨🏾‍🦰' => 'maður: miðalmyrkur húðarlitur, reytt hár',
    '👨🏿‍🦰' => 'maður: myrkur húðarlitur, reytt hár',
    '👨🏻‍🦱' => 'maður: ljósur húðarlitur, purlut hár',
    '👨🏼‍🦱' => 'maður: miðalljósur húðarlitur, purlut hár',
    '👨🏽‍🦱' => 'maður: miðal húðarlitur, purlut hár',
    '👨🏾‍🦱' => 'maður: miðalmyrkur húðarlitur, purlut hár',
    '👨🏿‍🦱' => 'maður: myrkur húðarlitur, purlut hár',
    '👨🏻‍🦳' => 'maður: ljósur húðarlitur, hvítt hár',
    '👨🏼‍🦳' => 'maður: miðalljósur húðarlitur, hvítt hár',
    '👨🏽‍🦳' => 'maður: miðal húðarlitur, hvítt hár',
    '👨🏾‍🦳' => 'maður: miðalmyrkur húðarlitur, hvítt hár',
    '👨🏿‍🦳' => 'maður: myrkur húðarlitur, hvítt hár',
    '👨🏻‍🦲' => 'maður: ljósur húðarlitur, skallutur',
    '👨🏼‍🦲' => 'maður: miðalljósur húðarlitur, skallutur',
    '👨🏽‍🦲' => 'maður: miðal húðarlitur, skallutur',
    '👨🏾‍🦲' => 'maður: miðalmyrkur húðarlitur, skallutur',
    '👨🏿‍🦲' => 'maður: myrkur húðarlitur, skallutur',
    '🧔🏻‍♀' => 'kona við skeggi: ljósur húðarlitur',
    '🧔🏼‍♀' => 'kona við skeggi: miðalljósur húðarlitur',
    '🧔🏽‍♀' => 'kona við skeggi: miðal húðarlitur',
    '🧔🏾‍♀' => 'kona við skeggi: miðalmyrkur húðarlitur',
    '🧔🏿‍♀' => 'kona við skeggi: myrkur húðarlitur',
    '👱🏻‍♀' => 'ljóshærd kvinna: ljósur húðarlitur',
    '👱🏼‍♀' => 'ljóshærd kvinna: miðalljósur húðarlitur',
    '👱🏽‍♀' => 'ljóshærd kvinna: miðal húðarlitur',
    '👱🏾‍♀' => 'ljóshærd kvinna: miðalmyrkur húðarlitur',
    '👱🏿‍♀' => 'ljóshærd kvinna: myrkur húðarlitur',
    '👩🏻‍🦰' => 'kona: ljósur húðarlitur, reytt hár',
    '👩🏼‍🦰' => 'kona: miðalljósur húðarlitur, reytt hár',
    '👩🏽‍🦰' => 'kona: miðal húðarlitur, reytt hár',
    '👩🏾‍🦰' => 'kona: miðalmyrkur húðarlitur, reytt hár',
    '👩🏿‍🦰' => 'kona: myrkur húðarlitur, reytt hár',
    '👩🏻‍🦱' => 'kona: ljósur húðarlitur, purlut hár',
    '👩🏼‍🦱' => 'kona: miðalljósur húðarlitur, purlut hár',
    '👩🏽‍🦱' => 'kona: miðal húðarlitur, purlut hár',
    '👩🏾‍🦱' => 'kona: miðalmyrkur húðarlitur, purlut hár',
    '👩🏿‍🦱' => 'kona: myrkur húðarlitur, purlut hár',
    '👩🏻‍🦳' => 'kona: ljósur húðarlitur, hvítt hár',
    '👩🏼‍🦳' => 'kona: miðalljósur húðarlitur, hvítt hár',
    '👩🏽‍🦳' => 'kona: miðal húðarlitur, hvítt hár',
    '👩🏾‍🦳' => 'kona: miðalmyrkur húðarlitur, hvítt hár',
    '👩🏿‍🦳' => 'kona: myrkur húðarlitur, hvítt hár',
    '👩🏻‍🦲' => 'kona: ljósur húðarlitur, skallutur',
    '👩🏼‍🦲' => 'kona: miðalljósur húðarlitur, skallutur',
    '👩🏽‍🦲' => 'kona: miðal húðarlitur, skallutur',
    '👩🏾‍🦲' => 'kona: miðalmyrkur húðarlitur, skallutur',
    '👩🏿‍🦲' => 'kona: myrkur húðarlitur, skallutur',
    '🙍🏻‍♂' => 'illbrýntur maður: ljósur húðarlitur',
    '🙍🏼‍♂' => 'illbrýntur maður: miðalljósur húðarlitur',
    '🙍🏽‍♂' => 'illbrýntur maður: miðal húðarlitur',
    '🙍🏾‍♂' => 'illbrýntur maður: miðalmyrkur húðarlitur',
    '🙍🏿‍♂' => 'illbrýntur maður: myrkur húðarlitur',
    '🙍🏻‍♀' => 'illbrýnt kvinna: ljósur húðarlitur',
    '🙍🏼‍♀' => 'illbrýnt kvinna: miðalljósur húðarlitur',
    '🙍🏽‍♀' => 'illbrýnt kvinna: miðal húðarlitur',
    '🙍🏾‍♀' => 'illbrýnt kvinna: miðalmyrkur húðarlitur',
    '🙍🏿‍♀' => 'illbrýnt kvinna: myrkur húðarlitur',
    '🙎🏻‍♂' => 'maður við gron: ljósur húðarlitur',
    '🙎🏼‍♂' => 'maður við gron: miðalljósur húðarlitur',
    '🙎🏽‍♂' => 'maður við gron: miðal húðarlitur',
    '🙎🏾‍♂' => 'maður við gron: miðalmyrkur húðarlitur',
    '🙎🏿‍♂' => 'maður við gron: myrkur húðarlitur',
    '🙎🏻‍♀' => 'kvinna við gron: ljósur húðarlitur',
    '🙎🏼‍♀' => 'kvinna við gron: miðalljósur húðarlitur',
    '🙎🏽‍♀' => 'kvinna við gron: miðal húðarlitur',
    '🙎🏾‍♀' => 'kvinna við gron: miðalmyrkur húðarlitur',
    '🙎🏿‍♀' => 'kvinna við gron: myrkur húðarlitur',
    '🙅🏻‍♂' => 'maður sum veipar nei: ljósur húðarlitur',
    '🙅🏼‍♂' => 'maður sum veipar nei: miðalljósur húðarlitur',
    '🙅🏽‍♂' => 'maður sum veipar nei: miðal húðarlitur',
    '🙅🏾‍♂' => 'maður sum veipar nei: miðalmyrkur húðarlitur',
    '🙅🏿‍♂' => 'maður sum veipar nei: myrkur húðarlitur',
    '🙅🏻‍♀' => 'kvinna sum veipar nei: ljósur húðarlitur',
    '🙅🏼‍♀' => 'kvinna sum veipar nei: miðalljósur húðarlitur',
    '🙅🏽‍♀' => 'kvinna sum veipar nei: miðal húðarlitur',
    '🙅🏾‍♀' => 'kvinna sum veipar nei: miðalmyrkur húðarlitur',
    '🙅🏿‍♀' => 'kvinna sum veipar nei: myrkur húðarlitur',
    '🙆🏻‍♂' => 'maður sum veipar ok: ljósur húðarlitur',
    '🙆🏼‍♂' => 'maður sum veipar ok: miðalljósur húðarlitur',
    '🙆🏽‍♂' => 'maður sum veipar ok: miðal húðarlitur',
    '🙆🏾‍♂' => 'maður sum veipar ok: miðalmyrkur húðarlitur',
    '🙆🏿‍♂' => 'maður sum veipar ok: myrkur húðarlitur',
    '🙆🏻‍♀' => 'kvinna sum veipar ok: ljósur húðarlitur',
    '🙆🏼‍♀' => 'kvinna sum veipar ok: miðalljósur húðarlitur',
    '🙆🏽‍♀' => 'kvinna sum veipar ok: miðal húðarlitur',
    '🙆🏾‍♀' => 'kvinna sum veipar ok: miðalmyrkur húðarlitur',
    '🙆🏿‍♀' => 'kvinna sum veipar ok: myrkur húðarlitur',
    '💁🏻‍♂' => 'maður sum nertir við: ljósur húðarlitur',
    '💁🏼‍♂' => 'maður sum nertir við: miðalljósur húðarlitur',
    '💁🏽‍♂' => 'maður sum nertir við: miðal húðarlitur',
    '💁🏾‍♂' => 'maður sum nertir við: miðalmyrkur húðarlitur',
    '💁🏿‍♂' => 'maður sum nertir við: myrkur húðarlitur',
    '💁🏻‍♀' => 'kvinna sum nertir við: ljósur húðarlitur',
    '💁🏼‍♀' => 'kvinna sum nertir við: miðalljósur húðarlitur',
    '💁🏽‍♀' => 'kvinna sum nertir við: miðal húðarlitur',
    '💁🏾‍♀' => 'kvinna sum nertir við: miðalmyrkur húðarlitur',
    '💁🏿‍♀' => 'kvinna sum nertir við: myrkur húðarlitur',
    '🙋🏻‍♂' => 'maður sum lyftur hondina upp: ljósur húðarlitur',
    '🙋🏼‍♂' => 'maður sum lyftur hondina upp: miðalljósur húðarlitur',
    '🙋🏽‍♂' => 'maður sum lyftur hondina upp: miðal húðarlitur',
    '🙋🏾‍♂' => 'maður sum lyftur hondina upp: miðalmyrkur húðarlitur',
    '🙋🏿‍♂' => 'maður sum lyftur hondina upp: myrkur húðarlitur',
    '🙋🏻‍♀' => 'kvinna sum lyftur hondina upp: ljósur húðarlitur',
    '🙋🏼‍♀' => 'kvinna sum lyftur hondina upp: miðalljósur húðarlitur',
    '🙋🏽‍♀' => 'kvinna sum lyftur hondina upp: miðal húðarlitur',
    '🙋🏾‍♀' => 'kvinna sum lyftur hondina upp: miðalmyrkur húðarlitur',
    '🙋🏿‍♀' => 'kvinna sum lyftur hondina upp: myrkur húðarlitur',
    '🧏🏻‍♂' => 'deyvur maður: ljósur húðarlitur',
    '🧏🏼‍♂' => 'deyvur maður: miðalljósur húðarlitur',
    '🧏🏽‍♂' => 'deyvur maður: miðal húðarlitur',
    '🧏🏾‍♂' => 'deyvur maður: miðalmyrkur húðarlitur',
    '🧏🏿‍♂' => 'deyvur maður: myrkur húðarlitur',
    '🧏🏻‍♀' => 'deyv kvinna: ljósur húðarlitur',
    '🧏🏼‍♀' => 'deyv kvinna: miðalljósur húðarlitur',
    '🧏🏽‍♀' => 'deyv kvinna: miðal húðarlitur',
    '🧏🏾‍♀' => 'deyv kvinna: miðalmyrkur húðarlitur',
    '🧏🏿‍♀' => 'deyv kvinna: myrkur húðarlitur',
    '🙇🏻‍♂' => 'maður sum bukkar: ljósur húðarlitur',
    '🙇🏼‍♂' => 'maður sum bukkar: miðalljósur húðarlitur',
    '🙇🏽‍♂' => 'maður sum bukkar: miðal húðarlitur',
    '🙇🏾‍♂' => 'maður sum bukkar: miðalmyrkur húðarlitur',
    '🙇🏿‍♂' => 'maður sum bukkar: myrkur húðarlitur',
    '🙇🏻‍♀' => 'kvinna sum bukkar: ljósur húðarlitur',
    '🙇🏼‍♀' => 'kvinna sum bukkar: miðalljósur húðarlitur',
    '🙇🏽‍♀' => 'kvinna sum bukkar: miðal húðarlitur',
    '🙇🏾‍♀' => 'kvinna sum bukkar: miðalmyrkur húðarlitur',
    '🙇🏿‍♀' => 'kvinna sum bukkar: myrkur húðarlitur',
    '🤦🏻‍♂' => 'vónbrotin maður: ljósur húðarlitur',
    '🤦🏼‍♂' => 'vónbrotin maður: miðalljósur húðarlitur',
    '🤦🏽‍♂' => 'vónbrotin maður: miðal húðarlitur',
    '🤦🏾‍♂' => 'vónbrotin maður: miðalmyrkur húðarlitur',
    '🤦🏿‍♂' => 'vónbrotin maður: myrkur húðarlitur',
    '🤦🏻‍♀' => 'vónbrotin kvinna: ljósur húðarlitur',
    '🤦🏼‍♀' => 'vónbrotin kvinna: miðalljósur húðarlitur',
    '🤦🏽‍♀' => 'vónbrotin kvinna: miðal húðarlitur',
    '🤦🏾‍♀' => 'vónbrotin kvinna: miðalmyrkur húðarlitur',
    '🤦🏿‍♀' => 'vónbrotin kvinna: myrkur húðarlitur',
    '🤷🏻‍♂' => 'maður um yppur øksl: ljósur húðarlitur',
    '🤷🏼‍♂' => 'maður um yppur øksl: miðalljósur húðarlitur',
    '🤷🏽‍♂' => 'maður um yppur øksl: miðal húðarlitur',
    '🤷🏾‍♂' => 'maður um yppur øksl: miðalmyrkur húðarlitur',
    '🤷🏿‍♂' => 'maður um yppur øksl: myrkur húðarlitur',
    '🤷🏻‍♀' => 'kvinna um yppur øksl: ljósur húðarlitur',
    '🤷🏼‍♀' => 'kvinna um yppur øksl: miðalljósur húðarlitur',
    '🤷🏽‍♀' => 'kvinna um yppur øksl: miðal húðarlitur',
    '🤷🏾‍♀' => 'kvinna um yppur øksl: miðalmyrkur húðarlitur',
    '🤷🏿‍♀' => 'kvinna um yppur øksl: myrkur húðarlitur',
    '🧑🏻‍⚕' => 'heilsuverkfrøðingur: ljósur húðarlitur',
    '🧑🏼‍⚕' => 'heilsuverkfrøðingur: miðalljósur húðarlitur',
    '🧑🏽‍⚕' => 'heilsuverkfrøðingur: miðal húðarlitur',
    '🧑🏾‍⚕' => 'heilsuverkfrøðingur: miðalmyrkur húðarlitur',
    '🧑🏿‍⚕' => 'heilsuverkfrøðingur: myrkur húðarlitur',
    '👨🏻‍⚕' => 'mannligur lækni: ljósur húðarlitur',
    '👨🏼‍⚕' => 'mannligur lækni: miðalljósur húðarlitur',
    '👨🏽‍⚕' => 'mannligur lækni: miðal húðarlitur',
    '👨🏾‍⚕' => 'mannligur lækni: miðalmyrkur húðarlitur',
    '👨🏿‍⚕' => 'mannligur lækni: myrkur húðarlitur',
    '👩🏻‍⚕' => 'kvinnuligur lækni: ljósur húðarlitur',
    '👩🏼‍⚕' => 'kvinnuligur lækni: miðalljósur húðarlitur',
    '👩🏽‍⚕' => 'kvinnuligur lækni: miðal húðarlitur',
    '👩🏾‍⚕' => 'kvinnuligur lækni: miðalmyrkur húðarlitur',
    '👩🏿‍⚕' => 'kvinnuligur lækni: myrkur húðarlitur',
    '🧑🏻‍🎓' => 'studentur: ljósur húðarlitur',
    '🧑🏼‍🎓' => 'studentur: miðalljósur húðarlitur',
    '🧑🏽‍🎓' => 'studentur: miðal húðarlitur',
    '🧑🏾‍🎓' => 'studentur: miðalmyrkur húðarlitur',
    '🧑🏿‍🎓' => 'studentur: myrkur húðarlitur',
    '👨🏻‍🎓' => 'mannligur studentur: ljósur húðarlitur',
    '👨🏼‍🎓' => 'mannligur studentur: miðalljósur húðarlitur',
    '👨🏽‍🎓' => 'mannligur studentur: miðal húðarlitur',
    '👨🏾‍🎓' => 'mannligur studentur: miðalmyrkur húðarlitur',
    '👨🏿‍🎓' => 'mannligur studentur: myrkur húðarlitur',
    '👩🏻‍🎓' => 'kvinnuligur studentur: ljósur húðarlitur',
    '👩🏼‍🎓' => 'kvinnuligur studentur: miðalljósur húðarlitur',
    '👩🏽‍🎓' => 'kvinnuligur studentur: miðal húðarlitur',
    '👩🏾‍🎓' => 'kvinnuligur studentur: miðalmyrkur húðarlitur',
    '👩🏿‍🎓' => 'kvinnuligur studentur: myrkur húðarlitur',
    '🧑🏻‍🏫' => 'lærari: ljósur húðarlitur',
    '🧑🏼‍🏫' => 'lærari: miðalljósur húðarlitur',
    '🧑🏽‍🏫' => 'lærari: miðal húðarlitur',
    '🧑🏾‍🏫' => 'lærari: miðalmyrkur húðarlitur',
    '🧑🏿‍🏫' => 'lærari: myrkur húðarlitur',
    '👨🏻‍🏫' => 'mannligur lærari: ljósur húðarlitur',
    '👨🏼‍🏫' => 'mannligur lærari: miðalljósur húðarlitur',
    '👨🏽‍🏫' => 'mannligur lærari: miðal húðarlitur',
    '👨🏾‍🏫' => 'mannligur lærari: miðalmyrkur húðarlitur',
    '👨🏿‍🏫' => 'mannligur lærari: myrkur húðarlitur',
    '👩🏻‍🏫' => 'kvinnuligur lærari: ljósur húðarlitur',
    '👩🏼‍🏫' => 'kvinnuligur lærari: miðalljósur húðarlitur',
    '👩🏽‍🏫' => 'kvinnuligur lærari: miðal húðarlitur',
    '👩🏾‍🏫' => 'kvinnuligur lærari: miðalmyrkur húðarlitur',
    '👩🏿‍🏫' => 'kvinnuligur lærari: myrkur húðarlitur',
    '🧑🏻‍⚖' => 'dómari: ljósur húðarlitur',
    '🧑🏼‍⚖' => 'dómari: miðalljósur húðarlitur',
    '🧑🏽‍⚖' => 'dómari: miðal húðarlitur',
    '🧑🏾‍⚖' => 'dómari: miðalmyrkur húðarlitur',
    '🧑🏿‍⚖' => 'dómari: myrkur húðarlitur',
    '👨🏻‍⚖' => 'mannligur dómari: ljósur húðarlitur',
    '👨🏼‍⚖' => 'mannligur dómari: miðalljósur húðarlitur',
    '👨🏽‍⚖' => 'mannligur dómari: miðal húðarlitur',
    '👨🏾‍⚖' => 'mannligur dómari: miðalmyrkur húðarlitur',
    '👨🏿‍⚖' => 'mannligur dómari: myrkur húðarlitur',
    '👩🏻‍⚖' => 'kvinnuligur dómari: ljósur húðarlitur',
    '👩🏼‍⚖' => 'kvinnuligur dómari: miðalljósur húðarlitur',
    '👩🏽‍⚖' => 'kvinnuligur dómari: miðal húðarlitur',
    '👩🏾‍⚖' => 'kvinnuligur dómari: miðalmyrkur húðarlitur',
    '👩🏿‍⚖' => 'kvinnuligur dómari: myrkur húðarlitur',
    '🧑🏻‍🌾' => 'bóndi: ljósur húðarlitur',
    '🧑🏼‍🌾' => 'bóndi: miðalljósur húðarlitur',
    '🧑🏽‍🌾' => 'bóndi: miðal húðarlitur',
    '🧑🏾‍🌾' => 'bóndi: miðalmyrkur húðarlitur',
    '🧑🏿‍🌾' => 'bóndi: myrkur húðarlitur',
    '👨🏻‍🌾' => 'mannligur bóndi: ljósur húðarlitur',
    '👨🏼‍🌾' => 'mannligur bóndi: miðalljósur húðarlitur',
    '👨🏽‍🌾' => 'mannligur bóndi: miðal húðarlitur',
    '👨🏾‍🌾' => 'mannligur bóndi: miðalmyrkur húðarlitur',
    '👨🏿‍🌾' => 'mannligur bóndi: myrkur húðarlitur',
    '👩🏻‍🌾' => 'kvinnuligur bóndi: ljósur húðarlitur',
    '👩🏼‍🌾' => 'kvinnuligur bóndi: miðalljósur húðarlitur',
    '👩🏽‍🌾' => 'kvinnuligur bóndi: miðal húðarlitur',
    '👩🏾‍🌾' => 'kvinnuligur bóndi: miðalmyrkur húðarlitur',
    '👩🏿‍🌾' => 'kvinnuligur bóndi: myrkur húðarlitur',
    '🧑🏻‍🍳' => 'kokkur: ljósur húðarlitur',
    '🧑🏼‍🍳' => 'kokkur: miðalljósur húðarlitur',
    '🧑🏽‍🍳' => 'kokkur: miðal húðarlitur',
    '🧑🏾‍🍳' => 'kokkur: miðalmyrkur húðarlitur',
    '🧑🏿‍🍳' => 'kokkur: myrkur húðarlitur',
    '👨🏻‍🍳' => 'mannligur kokkur: ljósur húðarlitur',
    '👨🏼‍🍳' => 'mannligur kokkur: miðalljósur húðarlitur',
    '👨🏽‍🍳' => 'mannligur kokkur: miðal húðarlitur',
    '👨🏾‍🍳' => 'mannligur kokkur: miðalmyrkur húðarlitur',
    '👨🏿‍🍳' => 'mannligur kokkur: myrkur húðarlitur',
    '👩🏻‍🍳' => 'kvinnuligur kokkur: ljósur húðarlitur',
    '👩🏼‍🍳' => 'kvinnuligur kokkur: miðalljósur húðarlitur',
    '👩🏽‍🍳' => 'kvinnuligur kokkur: miðal húðarlitur',
    '👩🏾‍🍳' => 'kvinnuligur kokkur: miðalmyrkur húðarlitur',
    '👩🏿‍🍳' => 'kvinnuligur kokkur: myrkur húðarlitur',
    '🧑🏻‍🔧' => 'mekanikari: ljósur húðarlitur',
    '🧑🏼‍🔧' => 'mekanikari: miðalljósur húðarlitur',
    '🧑🏽‍🔧' => 'mekanikari: miðal húðarlitur',
    '🧑🏾‍🔧' => 'mekanikari: miðalmyrkur húðarlitur',
    '🧑🏿‍🔧' => 'mekanikari: myrkur húðarlitur',
    '👨🏻‍🔧' => 'mannligur mekanikari: ljósur húðarlitur',
    '👨🏼‍🔧' => 'mannligur mekanikari: miðalljósur húðarlitur',
    '👨🏽‍🔧' => 'mannligur mekanikari: miðal húðarlitur',
    '👨🏾‍🔧' => 'mannligur mekanikari: miðalmyrkur húðarlitur',
    '👨🏿‍🔧' => 'mannligur mekanikari: myrkur húðarlitur',
    '👩🏻‍🔧' => 'kvinnuligur mekanikari: ljósur húðarlitur',
    '👩🏼‍🔧' => 'kvinnuligur mekanikari: miðalljósur húðarlitur',
    '👩🏽‍🔧' => 'kvinnuligur mekanikari: miðal húðarlitur',
    '👩🏾‍🔧' => 'kvinnuligur mekanikari: miðalmyrkur húðarlitur',
    '👩🏿‍🔧' => 'kvinnuligur mekanikari: myrkur húðarlitur',
    '🧑🏻‍🏭' => 'sveisari: ljósur húðarlitur',
    '🧑🏼‍🏭' => 'sveisari: miðalljósur húðarlitur',
    '🧑🏽‍🏭' => 'sveisari: miðal húðarlitur',
    '🧑🏾‍🏭' => 'sveisari: miðalmyrkur húðarlitur',
    '🧑🏿‍🏭' => 'sveisari: myrkur húðarlitur',
    '👨🏻‍🏭' => 'mannligur sveisari: ljósur húðarlitur',
    '👨🏼‍🏭' => 'mannligur sveisari: miðalljósur húðarlitur',
    '👨🏽‍🏭' => 'mannligur sveisari: miðal húðarlitur',
    '👨🏾‍🏭' => 'mannligur sveisari: miðalmyrkur húðarlitur',
    '👨🏿‍🏭' => 'mannligur sveisari: myrkur húðarlitur',
    '👩🏻‍🏭' => 'kvinnuligur sveisari: ljósur húðarlitur',
    '👩🏼‍🏭' => 'kvinnuligur sveisari: miðalljósur húðarlitur',
    '👩🏽‍🏭' => 'kvinnuligur sveisari: miðal húðarlitur',
    '👩🏾‍🏭' => 'kvinnuligur sveisari: miðalmyrkur húðarlitur',
    '👩🏿‍🏭' => 'kvinnuligur sveisari: myrkur húðarlitur',
    '🧑🏻‍💼' => 'skrivstovufólk: ljósur húðarlitur',
    '🧑🏼‍💼' => 'skrivstovufólk: miðalljósur húðarlitur',
    '🧑🏽‍💼' => 'skrivstovufólk: miðal húðarlitur',
    '🧑🏾‍💼' => 'skrivstovufólk: miðalmyrkur húðarlitur',
    '🧑🏿‍💼' => 'skrivstovufólk: myrkur húðarlitur',
    '👨🏻‍💼' => 'skrivstovumaður: ljósur húðarlitur',
    '👨🏼‍💼' => 'skrivstovumaður: miðalljósur húðarlitur',
    '👨🏽‍💼' => 'skrivstovumaður: miðal húðarlitur',
    '👨🏾‍💼' => 'skrivstovumaður: miðalmyrkur húðarlitur',
    '👨🏿‍💼' => 'skrivstovumaður: myrkur húðarlitur',
    '👩🏻‍💼' => 'skrivstovukvinna: ljósur húðarlitur',
    '👩🏼‍💼' => 'skrivstovukvinna: miðalljósur húðarlitur',
    '👩🏽‍💼' => 'skrivstovukvinna: miðal húðarlitur',
    '👩🏾‍💼' => 'skrivstovukvinna: miðalmyrkur húðarlitur',
    '👩🏿‍💼' => 'skrivstovukvinna: myrkur húðarlitur',
    '🧑🏻‍🔬' => 'náttúruvísindafólk: ljósur húðarlitur',
    '🧑🏼‍🔬' => 'náttúruvísindafólk: miðalljósur húðarlitur',
    '🧑🏽‍🔬' => 'náttúruvísindafólk: miðal húðarlitur',
    '🧑🏾‍🔬' => 'náttúruvísindafólk: miðalmyrkur húðarlitur',
    '🧑🏿‍🔬' => 'náttúruvísindafólk: myrkur húðarlitur',
    '👨🏻‍🔬' => 'vísindamaður: ljósur húðarlitur',
    '👨🏼‍🔬' => 'vísindamaður: miðalljósur húðarlitur',
    '👨🏽‍🔬' => 'vísindamaður: miðal húðarlitur',
    '👨🏾‍🔬' => 'vísindamaður: miðalmyrkur húðarlitur',
    '👨🏿‍🔬' => 'vísindamaður: myrkur húðarlitur',
    '👩🏻‍🔬' => 'vísindakvinna: ljósur húðarlitur',
    '👩🏼‍🔬' => 'vísindakvinna: miðalljósur húðarlitur',
    '👩🏽‍🔬' => 'vísindakvinna: miðal húðarlitur',
    '👩🏾‍🔬' => 'vísindakvinna: miðalmyrkur húðarlitur',
    '👩🏿‍🔬' => 'vísindakvinna: myrkur húðarlitur',
    '🧑🏻‍💻' => 'tøknifrøðingur: ljósur húðarlitur',
    '🧑🏼‍💻' => 'tøknifrøðingur: miðalljósur húðarlitur',
    '🧑🏽‍💻' => 'tøknifrøðingur: miðal húðarlitur',
    '🧑🏾‍💻' => 'tøknifrøðingur: miðalmyrkur húðarlitur',
    '🧑🏿‍💻' => 'tøknifrøðingur: myrkur húðarlitur',
    '👨🏻‍💻' => 'mannligur tøknifrøðingur: ljósur húðarlitur',
    '👨🏼‍💻' => 'mannligur tøknifrøðingur: miðalljósur húðarlitur',
    '👨🏽‍💻' => 'mannligur tøknifrøðingur: miðal húðarlitur',
    '👨🏾‍💻' => 'mannligur tøknifrøðingur: miðalmyrkur húðarlitur',
    '👨🏿‍💻' => 'mannligur tøknifrøðingur: myrkur húðarlitur',
    '👩🏻‍💻' => 'kvinnuligur tøknifrøðingur: ljósur húðarlitur',
    '👩🏼‍💻' => 'kvinnuligur tøknifrøðingur: miðalljósur húðarlitur',
    '👩🏽‍💻' => 'kvinnuligur tøknifrøðingur: miðal húðarlitur',
    '👩🏾‍💻' => 'kvinnuligur tøknifrøðingur: miðalmyrkur húðarlitur',
    '👩🏿‍💻' => 'kvinnuligur tøknifrøðingur: myrkur húðarlitur',
    '🧑🏻‍🎤' => 'sangari: ljósur húðarlitur',
    '🧑🏼‍🎤' => 'sangari: miðalljósur húðarlitur',
    '🧑🏽‍🎤' => 'sangari: miðal húðarlitur',
    '🧑🏾‍🎤' => 'sangari: miðalmyrkur húðarlitur',
    '🧑🏿‍🎤' => 'sangari: myrkur húðarlitur',
    '👨🏻‍🎤' => 'mannligur sangari: ljósur húðarlitur',
    '👨🏼‍🎤' => 'mannligur sangari: miðalljósur húðarlitur',
    '👨🏽‍🎤' => 'mannligur sangari: miðal húðarlitur',
    '👨🏾‍🎤' => 'mannligur sangari: miðalmyrkur húðarlitur',
    '👨🏿‍🎤' => 'mannligur sangari: myrkur húðarlitur',
    '👩🏻‍🎤' => 'kvinnuligur sangari: ljósur húðarlitur',
    '👩🏼‍🎤' => 'kvinnuligur sangari: miðalljósur húðarlitur',
    '👩🏽‍🎤' => 'kvinnuligur sangari: miðal húðarlitur',
    '👩🏾‍🎤' => 'kvinnuligur sangari: miðalmyrkur húðarlitur',
    '👩🏿‍🎤' => 'kvinnuligur sangari: myrkur húðarlitur',
    '🧑🏻‍🎨' => 'listafólk: ljósur húðarlitur',
    '🧑🏼‍🎨' => 'listafólk: miðalljósur húðarlitur',
    '🧑🏽‍🎨' => 'listafólk: miðal húðarlitur',
    '🧑🏾‍🎨' => 'listafólk: miðalmyrkur húðarlitur',
    '🧑🏿‍🎨' => 'listafólk: myrkur húðarlitur',
    '👨🏻‍🎨' => 'listamaður: ljósur húðarlitur',
    '👨🏼‍🎨' => 'listamaður: miðalljósur húðarlitur',
    '👨🏽‍🎨' => 'listamaður: miðal húðarlitur',
    '👨🏾‍🎨' => 'listamaður: miðalmyrkur húðarlitur',
    '👨🏿‍🎨' => 'listamaður: myrkur húðarlitur',
    '👩🏻‍🎨' => 'listakona: ljósur húðarlitur',
    '👩🏼‍🎨' => 'listakona: miðalljósur húðarlitur',
    '👩🏽‍🎨' => 'listakona: miðal húðarlitur',
    '👩🏾‍🎨' => 'listakona: miðalmyrkur húðarlitur',
    '👩🏿‍🎨' => 'listakona: myrkur húðarlitur',
    '🧑🏻‍✈' => 'flogskipari: ljósur húðarlitur',
    '🧑🏼‍✈' => 'flogskipari: miðalljósur húðarlitur',
    '🧑🏽‍✈' => 'flogskipari: miðal húðarlitur',
    '🧑🏾‍✈' => 'flogskipari: miðalmyrkur húðarlitur',
    '🧑🏿‍✈' => 'flogskipari: myrkur húðarlitur',
    '👨🏻‍✈' => 'mannligur flogskipari: ljósur húðarlitur',
    '👨🏼‍✈' => 'mannligur flogskipari: miðalljósur húðarlitur',
    '👨🏽‍✈' => 'mannligur flogskipari: miðal húðarlitur',
    '👨🏾‍✈' => 'mannligur flogskipari: miðalmyrkur húðarlitur',
    '👨🏿‍✈' => 'mannligur flogskipari: myrkur húðarlitur',
    '👩🏻‍✈' => 'kvinnuligur flogskipari: ljósur húðarlitur',
    '👩🏼‍✈' => 'kvinnuligur flogskipari: miðalljósur húðarlitur',
    '👩🏽‍✈' => 'kvinnuligur flogskipari: miðal húðarlitur',
    '👩🏾‍✈' => 'kvinnuligur flogskipari: miðalmyrkur húðarlitur',
    '👩🏿‍✈' => 'kvinnuligur flogskipari: myrkur húðarlitur',
    '🧑🏻‍🚀' => 'astronautur: ljósur húðarlitur',
    '🧑🏼‍🚀' => 'astronautur: miðalljósur húðarlitur',
    '🧑🏽‍🚀' => 'astronautur: miðal húðarlitur',
    '🧑🏾‍🚀' => 'astronautur: miðalmyrkur húðarlitur',
    '🧑🏿‍🚀' => 'astronautur: myrkur húðarlitur',
    '👨🏻‍🚀' => 'mannligur astronautur: ljósur húðarlitur',
    '👨🏼‍🚀' => 'mannligur astronautur: miðalljósur húðarlitur',
    '👨🏽‍🚀' => 'mannligur astronautur: miðal húðarlitur',
    '👨🏾‍🚀' => 'mannligur astronautur: miðalmyrkur húðarlitur',
    '👨🏿‍🚀' => 'mannligur astronautur: myrkur húðarlitur',
    '👩🏻‍🚀' => 'kvinnuligur astronautur: ljósur húðarlitur',
    '👩🏼‍🚀' => 'kvinnuligur astronautur: miðalljósur húðarlitur',
    '👩🏽‍🚀' => 'kvinnuligur astronautur: miðal húðarlitur',
    '👩🏾‍🚀' => 'kvinnuligur astronautur: miðalmyrkur húðarlitur',
    '👩🏿‍🚀' => 'kvinnuligur astronautur: myrkur húðarlitur',
    '🧑🏻‍🚒' => 'sløkkiliðsfólk: ljósur húðarlitur',
    '🧑🏼‍🚒' => 'sløkkiliðsfólk: miðalljósur húðarlitur',
    '🧑🏽‍🚒' => 'sløkkiliðsfólk: miðal húðarlitur',
    '🧑🏾‍🚒' => 'sløkkiliðsfólk: miðalmyrkur húðarlitur',
    '🧑🏿‍🚒' => 'sløkkiliðsfólk: myrkur húðarlitur',
    '👨🏻‍🚒' => 'sløkkiliðsmaður: ljósur húðarlitur',
    '👨🏼‍🚒' => 'sløkkiliðsmaður: miðalljósur húðarlitur',
    '👨🏽‍🚒' => 'sløkkiliðsmaður: miðal húðarlitur',
    '👨🏾‍🚒' => 'sløkkiliðsmaður: miðalmyrkur húðarlitur',
    '👨🏿‍🚒' => 'sløkkiliðsmaður: myrkur húðarlitur',
    '👩🏻‍🚒' => 'sløkkiliðskvinna: ljósur húðarlitur',
    '👩🏼‍🚒' => 'sløkkiliðskvinna: miðalljósur húðarlitur',
    '👩🏽‍🚒' => 'sløkkiliðskvinna: miðal húðarlitur',
    '👩🏾‍🚒' => 'sløkkiliðskvinna: miðalmyrkur húðarlitur',
    '👩🏿‍🚒' => 'sløkkiliðskvinna: myrkur húðarlitur',
    '👮🏻‍♂' => 'løgreglumaður: ljósur húðarlitur',
    '👮🏼‍♂' => 'løgreglumaður: miðalljósur húðarlitur',
    '👮🏽‍♂' => 'løgreglumaður: miðal húðarlitur',
    '👮🏾‍♂' => 'løgreglumaður: miðalmyrkur húðarlitur',
    '👮🏿‍♂' => 'løgreglumaður: myrkur húðarlitur',
    '👮🏻‍♀' => 'løgreglukvinna: ljósur húðarlitur',
    '👮🏼‍♀' => 'løgreglukvinna: miðalljósur húðarlitur',
    '👮🏽‍♀' => 'løgreglukvinna: miðal húðarlitur',
    '👮🏾‍♀' => 'løgreglukvinna: miðalmyrkur húðarlitur',
    '👮🏿‍♀' => 'løgreglukvinna: myrkur húðarlitur',
    '🕵🏻‍♂' => 'mannligur detektivur: ljósur húðarlitur',
    '🕵🏼‍♂' => 'mannligur detektivur: miðalljósur húðarlitur',
    '🕵🏽‍♂' => 'mannligur detektivur: miðal húðarlitur',
    '🕵🏾‍♂' => 'mannligur detektivur: miðalmyrkur húðarlitur',
    '🕵🏿‍♂' => 'mannligur detektivur: myrkur húðarlitur',
    '🕵🏻‍♀' => 'kvinnuligur detektivur: ljósur húðarlitur',
    '🕵🏼‍♀' => 'kvinnuligur detektivur: miðalljósur húðarlitur',
    '🕵🏽‍♀' => 'kvinnuligur detektivur: miðal húðarlitur',
    '🕵🏾‍♀' => 'kvinnuligur detektivur: miðalmyrkur húðarlitur',
    '🕵🏿‍♀' => 'kvinnuligur detektivur: myrkur húðarlitur',
    '💂🏻‍♂' => 'vaktarmaður: ljósur húðarlitur',
    '💂🏼‍♂' => 'vaktarmaður: miðalljósur húðarlitur',
    '💂🏽‍♂' => 'vaktarmaður: miðal húðarlitur',
    '💂🏾‍♂' => 'vaktarmaður: miðalmyrkur húðarlitur',
    '💂🏿‍♂' => 'vaktarmaður: myrkur húðarlitur',
    '💂🏻‍♀' => 'vaktarkvinna: ljósur húðarlitur',
    '💂🏼‍♀' => 'vaktarkvinna: miðalljósur húðarlitur',
    '💂🏽‍♀' => 'vaktarkvinna: miðal húðarlitur',
    '💂🏾‍♀' => 'vaktarkvinna: miðalmyrkur húðarlitur',
    '💂🏿‍♀' => 'vaktarkvinna: myrkur húðarlitur',
    '👷🏻‍♂' => 'mannligur byggiverkfrøðingur: ljósur húðarlitur',
    '👷🏼‍♂' => 'mannligur byggiverkfrøðingur: miðalljósur húðarlitur',
    '👷🏽‍♂' => 'mannligur byggiverkfrøðingur: miðal húðarlitur',
    '👷🏾‍♂' => 'mannligur byggiverkfrøðingur: miðalmyrkur húðarlitur',
    '👷🏿‍♂' => 'mannligur byggiverkfrøðingur: myrkur húðarlitur',
    '👷🏻‍♀' => 'kvinnuligur byggiverkfrøðingur: ljósur húðarlitur',
    '👷🏼‍♀' => 'kvinnuligur byggiverkfrøðingur: miðalljósur húðarlitur',
    '👷🏽‍♀' => 'kvinnuligur byggiverkfrøðingur: miðal húðarlitur',
    '👷🏾‍♀' => 'kvinnuligur byggiverkfrøðingur: miðalmyrkur húðarlitur',
    '👷🏿‍♀' => 'kvinnuligur byggiverkfrøðingur: myrkur húðarlitur',
    '👳🏻‍♂' => 'maður við turban: ljósur húðarlitur',
    '👳🏼‍♂' => 'maður við turban: miðalljósur húðarlitur',
    '👳🏽‍♂' => 'maður við turban: miðal húðarlitur',
    '👳🏾‍♂' => 'maður við turban: miðalmyrkur húðarlitur',
    '👳🏿‍♂' => 'maður við turban: myrkur húðarlitur',
    '👳🏻‍♀' => 'kvinna við turban: ljósur húðarlitur',
    '👳🏼‍♀' => 'kvinna við turban: miðalljósur húðarlitur',
    '👳🏽‍♀' => 'kvinna við turban: miðal húðarlitur',
    '👳🏾‍♀' => 'kvinna við turban: miðalmyrkur húðarlitur',
    '👳🏿‍♀' => 'kvinna við turban: myrkur húðarlitur',
    '🤵🏻‍♂' => 'maður í smoking: ljósur húðarlitur',
    '🤵🏼‍♂' => 'maður í smoking: miðalljósur húðarlitur',
    '🤵🏽‍♂' => 'maður í smoking: miðal húðarlitur',
    '🤵🏾‍♂' => 'maður í smoking: miðalmyrkur húðarlitur',
    '🤵🏿‍♂' => 'maður í smoking: myrkur húðarlitur',
    '🤵🏻‍♀' => 'kona í smoking: ljósur húðarlitur',
    '🤵🏼‍♀' => 'kona í smoking: miðalljósur húðarlitur',
    '🤵🏽‍♀' => 'kona í smoking: miðal húðarlitur',
    '🤵🏾‍♀' => 'kona í smoking: miðalmyrkur húðarlitur',
    '🤵🏿‍♀' => 'kona í smoking: myrkur húðarlitur',
    '👰🏻‍♂' => 'maður í sløri: ljósur húðarlitur',
    '👰🏼‍♂' => 'maður í sløri: miðalljósur húðarlitur',
    '👰🏽‍♂' => 'maður í sløri: miðal húðarlitur',
    '👰🏾‍♂' => 'maður í sløri: miðalmyrkur húðarlitur',
    '👰🏿‍♂' => 'maður í sløri: myrkur húðarlitur',
    '👰🏻‍♀' => 'kona í sløri: ljósur húðarlitur',
    '👰🏼‍♀' => 'kona í sløri: miðalljósur húðarlitur',
    '👰🏽‍♀' => 'kona í sløri: miðal húðarlitur',
    '👰🏾‍♀' => 'kona í sløri: miðalmyrkur húðarlitur',
    '👰🏿‍♀' => 'kona í sløri: myrkur húðarlitur',
    '👩🏻‍🍼' => 'kvinna gevur fløsku: ljósur húðarlitur',
    '👩🏼‍🍼' => 'kvinna gevur fløsku: miðalljósur húðarlitur',
    '👩🏽‍🍼' => 'kvinna gevur fløsku: miðal húðarlitur',
    '👩🏾‍🍼' => 'kvinna gevur fløsku: miðalmyrkur húðarlitur',
    '👩🏿‍🍼' => 'kvinna gevur fløsku: myrkur húðarlitur',
    '👨🏻‍🍼' => 'maður gevur fløsku: ljósur húðarlitur',
    '👨🏼‍🍼' => 'maður gevur fløsku: miðalljósur húðarlitur',
    '👨🏽‍🍼' => 'maður gevur fløsku: miðal húðarlitur',
    '👨🏾‍🍼' => 'maður gevur fløsku: miðalmyrkur húðarlitur',
    '👨🏿‍🍼' => 'maður gevur fløsku: myrkur húðarlitur',
    '🧑🏻‍🍼' => 'persónur gevur fløsku: ljósur húðarlitur',
    '🧑🏼‍🍼' => 'persónur gevur fløsku: miðalljósur húðarlitur',
    '🧑🏽‍🍼' => 'persónur gevur fløsku: miðal húðarlitur',
    '🧑🏾‍🍼' => 'persónur gevur fløsku: miðalmyrkur húðarlitur',
    '🧑🏿‍🍼' => 'persónur gevur fløsku: myrkur húðarlitur',
    '🧑🏻‍🎄' => 'jólafólk: ljósur húðarlitur',
    '🧑🏼‍🎄' => 'jólafólk: miðalljósur húðarlitur',
    '🧑🏽‍🎄' => 'jólafólk: miðal húðarlitur',
    '🧑🏾‍🎄' => 'jólafólk: miðalmyrkur húðarlitur',
    '🧑🏿‍🎄' => 'jólafólk: myrkur húðarlitur',
    '🦸🏻‍♂' => 'mannlig superhetja: ljósur húðarlitur',
    '🦸🏼‍♂' => 'mannlig superhetja: miðalljósur húðarlitur',
    '🦸🏽‍♂' => 'mannlig superhetja: miðal húðarlitur',
    '🦸🏾‍♂' => 'mannlig superhetja: miðalmyrkur húðarlitur',
    '🦸🏿‍♂' => 'mannlig superhetja: myrkur húðarlitur',
    '🦸🏻‍♀' => 'kvinnulig superhetja: ljósur húðarlitur',
    '🦸🏼‍♀' => 'kvinnulig superhetja: miðalljósur húðarlitur',
    '🦸🏽‍♀' => 'kvinnulig superhetja: miðal húðarlitur',
    '🦸🏾‍♀' => 'kvinnulig superhetja: miðalmyrkur húðarlitur',
    '🦸🏿‍♀' => 'kvinnulig superhetja: myrkur húðarlitur',
    '🦹🏻‍♂' => 'mannligur superskálkur: ljósur húðarlitur',
    '🦹🏼‍♂' => 'mannligur superskálkur: miðalljósur húðarlitur',
    '🦹🏽‍♂' => 'mannligur superskálkur: miðal húðarlitur',
    '🦹🏾‍♂' => 'mannligur superskálkur: miðalmyrkur húðarlitur',
    '🦹🏿‍♂' => 'mannligur superskálkur: myrkur húðarlitur',
    '🦹🏻‍♀' => 'kvinnuligur superskálkur: ljósur húðarlitur',
    '🦹🏼‍♀' => 'kvinnuligur superskálkur: miðalljósur húðarlitur',
    '🦹🏽‍♀' => 'kvinnuligur superskálkur: miðal húðarlitur',
    '🦹🏾‍♀' => 'kvinnuligur superskálkur: miðalmyrkur húðarlitur',
    '🦹🏿‍♀' => 'kvinnuligur superskálkur: myrkur húðarlitur',
    '🧙🏻‍♂' => 'gandakallur: ljósur húðarlitur',
    '🧙🏼‍♂' => 'gandakallur: miðalljósur húðarlitur',
    '🧙🏽‍♂' => 'gandakallur: miðal húðarlitur',
    '🧙🏾‍♂' => 'gandakallur: miðalmyrkur húðarlitur',
    '🧙🏿‍♂' => 'gandakallur: myrkur húðarlitur',
    '🧙🏻‍♀' => 'gandakelling: ljósur húðarlitur',
    '🧙🏼‍♀' => 'gandakelling: miðalljósur húðarlitur',
    '🧙🏽‍♀' => 'gandakelling: miðal húðarlitur',
    '🧙🏾‍♀' => 'gandakelling: miðalmyrkur húðarlitur',
    '🧙🏿‍♀' => 'gandakelling: myrkur húðarlitur',
    '🧚🏻‍♂' => 'mannligur álvur: ljósur húðarlitur',
    '🧚🏼‍♂' => 'mannligur álvur: miðalljósur húðarlitur',
    '🧚🏽‍♂' => 'mannligur álvur: miðal húðarlitur',
    '🧚🏾‍♂' => 'mannligur álvur: miðalmyrkur húðarlitur',
    '🧚🏿‍♂' => 'mannligur álvur: myrkur húðarlitur',
    '🧚🏻‍♀' => 'kvinnulig álva: ljósur húðarlitur',
    '🧚🏼‍♀' => 'kvinnulig álva: miðalljósur húðarlitur',
    '🧚🏽‍♀' => 'kvinnulig álva: miðal húðarlitur',
    '🧚🏾‍♀' => 'kvinnulig álva: miðalmyrkur húðarlitur',
    '🧚🏿‍♀' => 'kvinnulig álva: myrkur húðarlitur',
    '🧛🏻‍♂' => 'mannligur vampýrur: ljósur húðarlitur',
    '🧛🏼‍♂' => 'mannligur vampýrur: miðalljósur húðarlitur',
    '🧛🏽‍♂' => 'mannligur vampýrur: miðal húðarlitur',
    '🧛🏾‍♂' => 'mannligur vampýrur: miðalmyrkur húðarlitur',
    '🧛🏿‍♂' => 'mannligur vampýrur: myrkur húðarlitur',
    '🧛🏻‍♀' => 'kvinnuligur vampýrur: ljósur húðarlitur',
    '🧛🏼‍♀' => 'kvinnuligur vampýrur: miðalljósur húðarlitur',
    '🧛🏽‍♀' => 'kvinnuligur vampýrur: miðal húðarlitur',
    '🧛🏾‍♀' => 'kvinnuligur vampýrur: miðalmyrkur húðarlitur',
    '🧛🏿‍♀' => 'kvinnuligur vampýrur: myrkur húðarlitur',
    '🧜🏻‍♂' => 'havmaður: ljósur húðarlitur',
    '🧜🏼‍♂' => 'havmaður: miðalljósur húðarlitur',
    '🧜🏽‍♂' => 'havmaður: miðal húðarlitur',
    '🧜🏾‍♂' => 'havmaður: miðalmyrkur húðarlitur',
    '🧜🏿‍♂' => 'havmaður: myrkur húðarlitur',
    '🧜🏻‍♀' => 'havfrúgv: ljósur húðarlitur',
    '🧜🏼‍♀' => 'havfrúgv: miðalljósur húðarlitur',
    '🧜🏽‍♀' => 'havfrúgv: miðal húðarlitur',
    '🧜🏾‍♀' => 'havfrúgv: miðalmyrkur húðarlitur',
    '🧜🏿‍♀' => 'havfrúgv: myrkur húðarlitur',
    '🧝🏻‍♂' => 'mannfólka álvur: ljósur húðarlitur',
    '🧝🏼‍♂' => 'mannfólka álvur: miðalljósur húðarlitur',
    '🧝🏽‍♂' => 'mannfólka álvur: miðal húðarlitur',
    '🧝🏾‍♂' => 'mannfólka álvur: miðalmyrkur húðarlitur',
    '🧝🏿‍♂' => 'mannfólka álvur: myrkur húðarlitur',
    '🧝🏻‍♀' => 'konufólka álva: ljósur húðarlitur',
    '🧝🏼‍♀' => 'konufólka álva: miðalljósur húðarlitur',
    '🧝🏽‍♀' => 'konufólka álva: miðal húðarlitur',
    '🧝🏾‍♀' => 'konufólka álva: miðalmyrkur húðarlitur',
    '🧝🏿‍♀' => 'konufólka álva: myrkur húðarlitur',
    '💆🏻‍♂' => 'maður sum fær massasju: ljósur húðarlitur',
    '💆🏼‍♂' => 'maður sum fær massasju: miðalljósur húðarlitur',
    '💆🏽‍♂' => 'maður sum fær massasju: miðal húðarlitur',
    '💆🏾‍♂' => 'maður sum fær massasju: miðalmyrkur húðarlitur',
    '💆🏿‍♂' => 'maður sum fær massasju: myrkur húðarlitur',
    '💆🏻‍♀' => 'kvinna sum fær massasju: ljósur húðarlitur',
    '💆🏼‍♀' => 'kvinna sum fær massasju: miðalljósur húðarlitur',
    '💆🏽‍♀' => 'kvinna sum fær massasju: miðal húðarlitur',
    '💆🏾‍♀' => 'kvinna sum fær massasju: miðalmyrkur húðarlitur',
    '💆🏿‍♀' => 'kvinna sum fær massasju: myrkur húðarlitur',
    '💇🏻‍♂' => 'maður sum fær klipt hári: ljósur húðarlitur',
    '💇🏼‍♂' => 'maður sum fær klipt hári: miðalljósur húðarlitur',
    '💇🏽‍♂' => 'maður sum fær klipt hári: miðal húðarlitur',
    '💇🏾‍♂' => 'maður sum fær klipt hári: miðalmyrkur húðarlitur',
    '💇🏿‍♂' => 'maður sum fær klipt hári: myrkur húðarlitur',
    '💇🏻‍♀' => 'kvinna sum fær klipt hári: ljósur húðarlitur',
    '💇🏼‍♀' => 'kvinna sum fær klipt hári: miðalljósur húðarlitur',
    '💇🏽‍♀' => 'kvinna sum fær klipt hári: miðal húðarlitur',
    '💇🏾‍♀' => 'kvinna sum fær klipt hári: miðalmyrkur húðarlitur',
    '💇🏿‍♀' => 'kvinna sum fær klipt hári: myrkur húðarlitur',
    '🚶🏻‍♂' => 'maður sum gongur: ljósur húðarlitur',
    '🚶🏼‍♂' => 'maður sum gongur: miðalljósur húðarlitur',
    '🚶🏽‍♂' => 'maður sum gongur: miðal húðarlitur',
    '🚶🏾‍♂' => 'maður sum gongur: miðalmyrkur húðarlitur',
    '🚶🏿‍♂' => 'maður sum gongur: myrkur húðarlitur',
    '🚶🏻‍♀' => 'kvinna sum gongur: ljósur húðarlitur',
    '🚶🏼‍♀' => 'kvinna sum gongur: miðalljósur húðarlitur',
    '🚶🏽‍♀' => 'kvinna sum gongur: miðal húðarlitur',
    '🚶🏾‍♀' => 'kvinna sum gongur: miðalmyrkur húðarlitur',
    '🚶🏿‍♀' => 'kvinna sum gongur: myrkur húðarlitur',
    '🚶🏻‍➡' => 'persónur sum gongur: ljósur húðarlitur, til høgru',
    '🚶🏼‍➡' => 'persónur sum gongur: miðalljósur húðarlitur, til høgru',
    '🚶🏽‍➡' => 'persónur sum gongur: miðal húðarlitur, til høgru',
    '🚶🏾‍➡' => 'persónur sum gongur: miðalmyrkur húðarlitur, til høgru',
    '🚶🏿‍➡' => 'persónur sum gongur: myrkur húðarlitur, til høgru',
    '🧍🏻‍♂' => 'maður ið stendur: ljósur húðarlitur',
    '🧍🏼‍♂' => 'maður ið stendur: miðalljósur húðarlitur',
    '🧍🏽‍♂' => 'maður ið stendur: miðal húðarlitur',
    '🧍🏾‍♂' => 'maður ið stendur: miðalmyrkur húðarlitur',
    '🧍🏿‍♂' => 'maður ið stendur: myrkur húðarlitur',
    '🧍🏻‍♀' => 'kvinna ið stendur: ljósur húðarlitur',
    '🧍🏼‍♀' => 'kvinna ið stendur: miðalljósur húðarlitur',
    '🧍🏽‍♀' => 'kvinna ið stendur: miðal húðarlitur',
    '🧍🏾‍♀' => 'kvinna ið stendur: miðalmyrkur húðarlitur',
    '🧍🏿‍♀' => 'kvinna ið stendur: myrkur húðarlitur',
    '🧎🏻‍♂' => 'maður á knæ: ljósur húðarlitur',
    '🧎🏼‍♂' => 'maður á knæ: miðalljósur húðarlitur',
    '🧎🏽‍♂' => 'maður á knæ: miðal húðarlitur',
    '🧎🏾‍♂' => 'maður á knæ: miðalmyrkur húðarlitur',
    '🧎🏿‍♂' => 'maður á knæ: myrkur húðarlitur',
    '🧎🏻‍♀' => 'kvinna á knæ: ljósur húðarlitur',
    '🧎🏼‍♀' => 'kvinna á knæ: miðalljósur húðarlitur',
    '🧎🏽‍♀' => 'kvinna á knæ: miðal húðarlitur',
    '🧎🏾‍♀' => 'kvinna á knæ: miðalmyrkur húðarlitur',
    '🧎🏿‍♀' => 'kvinna á knæ: myrkur húðarlitur',
    '🧎🏻‍➡' => 'persónur á knæ: ljósur húðarlitur, til høgru',
    '🧎🏼‍➡' => 'persónur á knæ: miðalljósur húðarlitur, til høgru',
    '🧎🏽‍➡' => 'persónur á knæ: miðal húðarlitur, til høgru',
    '🧎🏾‍➡' => 'persónur á knæ: miðalmyrkur húðarlitur, til høgru',
    '🧎🏿‍➡' => 'persónur á knæ: myrkur húðarlitur, til høgru',
    '🧑🏻‍🦯' => 'persónur við blindastavi: ljósur húðarlitur',
    '🧑🏼‍🦯' => 'persónur við blindastavi: miðalljósur húðarlitur',
    '🧑🏽‍🦯' => 'persónur við blindastavi: miðal húðarlitur',
    '🧑🏾‍🦯' => 'persónur við blindastavi: miðalmyrkur húðarlitur',
    '🧑🏿‍🦯' => 'persónur við blindastavi: myrkur húðarlitur',
    '👨🏻‍🦯' => 'maður við blindastavi: ljósur húðarlitur',
    '👨🏼‍🦯' => 'maður við blindastavi: miðalljósur húðarlitur',
    '👨🏽‍🦯' => 'maður við blindastavi: miðal húðarlitur',
    '👨🏾‍🦯' => 'maður við blindastavi: miðalmyrkur húðarlitur',
    '👨🏿‍🦯' => 'maður við blindastavi: myrkur húðarlitur',
    '👩🏻‍🦯' => 'kvinna við blindastavi: ljósur húðarlitur',
    '👩🏼‍🦯' => 'kvinna við blindastavi: miðalljósur húðarlitur',
    '👩🏽‍🦯' => 'kvinna við blindastavi: miðal húðarlitur',
    '👩🏾‍🦯' => 'kvinna við blindastavi: miðalmyrkur húðarlitur',
    '👩🏿‍🦯' => 'kvinna við blindastavi: myrkur húðarlitur',
    '🧑🏻‍🦼' => 'persónur í motorkoyristóli: ljósur húðarlitur',
    '🧑🏼‍🦼' => 'persónur í motorkoyristóli: miðalljósur húðarlitur',
    '🧑🏽‍🦼' => 'persónur í motorkoyristóli: miðal húðarlitur',
    '🧑🏾‍🦼' => 'persónur í motorkoyristóli: miðalmyrkur húðarlitur',
    '🧑🏿‍🦼' => 'persónur í motorkoyristóli: myrkur húðarlitur',
    '👨🏻‍🦼' => 'maður í motorkoyristóli: ljósur húðarlitur',
    '👨🏼‍🦼' => 'maður í motorkoyristóli: miðalljósur húðarlitur',
    '👨🏽‍🦼' => 'maður í motorkoyristóli: miðal húðarlitur',
    '👨🏾‍🦼' => 'maður í motorkoyristóli: miðalmyrkur húðarlitur',
    '👨🏿‍🦼' => 'maður í motorkoyristóli: myrkur húðarlitur',
    '👩🏻‍🦼' => 'kvinna í motorkoyristóli: ljósur húðarlitur',
    '👩🏼‍🦼' => 'kvinna í motorkoyristóli: miðalljósur húðarlitur',
    '👩🏽‍🦼' => 'kvinna í motorkoyristóli: miðal húðarlitur',
    '👩🏾‍🦼' => 'kvinna í motorkoyristóli: miðalmyrkur húðarlitur',
    '👩🏿‍🦼' => 'kvinna í motorkoyristóli: myrkur húðarlitur',
    '🧑🏻‍🦽' => 'persónur í koyristóli: ljósur húðarlitur',
    '🧑🏼‍🦽' => 'persónur í koyristóli: miðalljósur húðarlitur',
    '🧑🏽‍🦽' => 'persónur í koyristóli: miðal húðarlitur',
    '🧑🏾‍🦽' => 'persónur í koyristóli: miðalmyrkur húðarlitur',
    '🧑🏿‍🦽' => 'persónur í koyristóli: myrkur húðarlitur',
    '👨🏻‍🦽' => 'maður í koyristóli: ljósur húðarlitur',
    '👨🏼‍🦽' => 'maður í koyristóli: miðalljósur húðarlitur',
    '👨🏽‍🦽' => 'maður í koyristóli: miðal húðarlitur',
    '👨🏾‍🦽' => 'maður í koyristóli: miðalmyrkur húðarlitur',
    '👨🏿‍🦽' => 'maður í koyristóli: myrkur húðarlitur',
    '👩🏻‍🦽' => 'kvinna í koyristóli: ljósur húðarlitur',
    '👩🏼‍🦽' => 'kvinna í koyristóli: miðalljósur húðarlitur',
    '👩🏽‍🦽' => 'kvinna í koyristóli: miðal húðarlitur',
    '👩🏾‍🦽' => 'kvinna í koyristóli: miðalmyrkur húðarlitur',
    '👩🏿‍🦽' => 'kvinna í koyristóli: myrkur húðarlitur',
    '🏃🏻‍♂' => 'maður sum rennur: ljósur húðarlitur',
    '🏃🏼‍♂' => 'maður sum rennur: miðalljósur húðarlitur',
    '🏃🏽‍♂' => 'maður sum rennur: miðal húðarlitur',
    '🏃🏾‍♂' => 'maður sum rennur: miðalmyrkur húðarlitur',
    '🏃🏿‍♂' => 'maður sum rennur: myrkur húðarlitur',
    '🏃🏻‍♀' => 'kvinna sum rennur: ljósur húðarlitur',
    '🏃🏼‍♀' => 'kvinna sum rennur: miðalljósur húðarlitur',
    '🏃🏽‍♀' => 'kvinna sum rennur: miðal húðarlitur',
    '🏃🏾‍♀' => 'kvinna sum rennur: miðalmyrkur húðarlitur',
    '🏃🏿‍♀' => 'kvinna sum rennur: myrkur húðarlitur',
    '🏃🏻‍➡' => 'persónur sum rennur: ljósur húðarlitur, til høgru',
    '🏃🏼‍➡' => 'persónur sum rennur: miðalljósur húðarlitur, til høgru',
    '🏃🏽‍➡' => 'persónur sum rennur: miðal húðarlitur, til høgru',
    '🏃🏾‍➡' => 'persónur sum rennur: miðalmyrkur húðarlitur, til høgru',
    '🏃🏿‍➡' => 'persónur sum rennur: myrkur húðarlitur, til høgru',
    '👯🏻‍♀' => 'kvinnur við haruoyrum: ljósur húðarlitur',
    '👯🏼‍♀' => 'kvinnur við haruoyrum: miðalljósur húðarlitur',
    '👯🏽‍♀' => 'kvinnur við haruoyrum: miðal húðarlitur',
    '👯🏾‍♀' => 'kvinnur við haruoyrum: miðalmyrkur húðarlitur',
    '👯🏿‍♀' => 'kvinnur við haruoyrum: myrkur húðarlitur',
    '👯🏻‍♂' => 'menn við haruoyrum: ljósur húðarlitur',
    '👯🏼‍♂' => 'menn við haruoyrum: miðalljósur húðarlitur',
    '👯🏽‍♂' => 'menn við haruoyrum: miðal húðarlitur',
    '👯🏾‍♂' => 'menn við haruoyrum: miðalmyrkur húðarlitur',
    '👯🏿‍♂' => 'menn við haruoyrum: myrkur húðarlitur',
    '🧖🏻‍♂' => 'maður í sauna: ljósur húðarlitur',
    '🧖🏼‍♂' => 'maður í sauna: miðalljósur húðarlitur',
    '🧖🏽‍♂' => 'maður í sauna: miðal húðarlitur',
    '🧖🏾‍♂' => 'maður í sauna: miðalmyrkur húðarlitur',
    '🧖🏿‍♂' => 'maður í sauna: myrkur húðarlitur',
    '🧖🏻‍♀' => 'kvinna í sauna: ljósur húðarlitur',
    '🧖🏼‍♀' => 'kvinna í sauna: miðalljósur húðarlitur',
    '🧖🏽‍♀' => 'kvinna í sauna: miðal húðarlitur',
    '🧖🏾‍♀' => 'kvinna í sauna: miðalmyrkur húðarlitur',
    '🧖🏿‍♀' => 'kvinna í sauna: myrkur húðarlitur',
    '🧗🏻‍♂' => 'maður sum klatrar: ljósur húðarlitur',
    '🧗🏼‍♂' => 'maður sum klatrar: miðalljósur húðarlitur',
    '🧗🏽‍♂' => 'maður sum klatrar: miðal húðarlitur',
    '🧗🏾‍♂' => 'maður sum klatrar: miðalmyrkur húðarlitur',
    '🧗🏿‍♂' => 'maður sum klatrar: myrkur húðarlitur',
    '🧗🏻‍♀' => 'kvinna sum klatrar: ljósur húðarlitur',
    '🧗🏼‍♀' => 'kvinna sum klatrar: miðalljósur húðarlitur',
    '🧗🏽‍♀' => 'kvinna sum klatrar: miðal húðarlitur',
    '🧗🏾‍♀' => 'kvinna sum klatrar: miðalmyrkur húðarlitur',
    '🧗🏿‍♀' => 'kvinna sum klatrar: myrkur húðarlitur',
    '🏌🏻‍♂' => 'maður sum spælir golf: ljósur húðarlitur',
    '🏌🏼‍♂' => 'maður sum spælir golf: miðalljósur húðarlitur',
    '🏌🏽‍♂' => 'maður sum spælir golf: miðal húðarlitur',
    '🏌🏾‍♂' => 'maður sum spælir golf: miðalmyrkur húðarlitur',
    '🏌🏿‍♂' => 'maður sum spælir golf: myrkur húðarlitur',
    '🏌🏻‍♀' => 'kona sum spælir golf: ljósur húðarlitur',
    '🏌🏼‍♀' => 'kona sum spælir golf: miðalljósur húðarlitur',
    '🏌🏽‍♀' => 'kona sum spælir golf: miðal húðarlitur',
    '🏌🏾‍♀' => 'kona sum spælir golf: miðalmyrkur húðarlitur',
    '🏌🏿‍♀' => 'kona sum spælir golf: myrkur húðarlitur',
    '🏄🏻‍♂' => 'maður sum skreiður á brimfjøl: ljósur húðarlitur',
    '🏄🏼‍♂' => 'maður sum skreiður á brimfjøl: miðalljósur húðarlitur',
    '🏄🏽‍♂' => 'maður sum skreiður á brimfjøl: miðal húðarlitur',
    '🏄🏾‍♂' => 'maður sum skreiður á brimfjøl: miðalmyrkur húðarlitur',
    '🏄🏿‍♂' => 'maður sum skreiður á brimfjøl: myrkur húðarlitur',
    '🏄🏻‍♀' => 'kona sum skreiður á brimfjøl: ljósur húðarlitur',
    '🏄🏼‍♀' => 'kona sum skreiður á brimfjøl: miðalljósur húðarlitur',
    '🏄🏽‍♀' => 'kona sum skreiður á brimfjøl: miðal húðarlitur',
    '🏄🏾‍♀' => 'kona sum skreiður á brimfjøl: miðalmyrkur húðarlitur',
    '🏄🏿‍♀' => 'kona sum skreiður á brimfjøl: myrkur húðarlitur',
    '🚣🏻‍♂' => 'maður í árabáti: ljósur húðarlitur',
    '🚣🏼‍♂' => 'maður í árabáti: miðalljósur húðarlitur',
    '🚣🏽‍♂' => 'maður í árabáti: miðal húðarlitur',
    '🚣🏾‍♂' => 'maður í árabáti: miðalmyrkur húðarlitur',
    '🚣🏿‍♂' => 'maður í árabáti: myrkur húðarlitur',
    '🚣🏻‍♀' => 'kvinna í árabáti: ljósur húðarlitur',
    '🚣🏼‍♀' => 'kvinna í árabáti: miðalljósur húðarlitur',
    '🚣🏽‍♀' => 'kvinna í árabáti: miðal húðarlitur',
    '🚣🏾‍♀' => 'kvinna í árabáti: miðalmyrkur húðarlitur',
    '🚣🏿‍♀' => 'kvinna í árabáti: myrkur húðarlitur',
    '🏊🏻‍♂' => 'maður sum svimur: ljósur húðarlitur',
    '🏊🏼‍♂' => 'maður sum svimur: miðalljósur húðarlitur',
    '🏊🏽‍♂' => 'maður sum svimur: miðal húðarlitur',
    '🏊🏾‍♂' => 'maður sum svimur: miðalmyrkur húðarlitur',
    '🏊🏿‍♂' => 'maður sum svimur: myrkur húðarlitur',
    '🏊🏻‍♀' => 'kvinna sum svimur: ljósur húðarlitur',
    '🏊🏼‍♀' => 'kvinna sum svimur: miðalljósur húðarlitur',
    '🏊🏽‍♀' => 'kvinna sum svimur: miðal húðarlitur',
    '🏊🏾‍♀' => 'kvinna sum svimur: miðalmyrkur húðarlitur',
    '🏊🏿‍♀' => 'kvinna sum svimur: myrkur húðarlitur',
    '⛹🏻‍♂' => 'maður sum spælir kurvabólt: ljósur húðarlitur',
    '⛹🏼‍♂' => 'maður sum spælir kurvabólt: miðalljósur húðarlitur',
    '⛹🏽‍♂' => 'maður sum spælir kurvabólt: miðal húðarlitur',
    '⛹🏾‍♂' => 'maður sum spælir kurvabólt: miðalmyrkur húðarlitur',
    '⛹🏿‍♂' => 'maður sum spælir kurvabólt: myrkur húðarlitur',
    '⛹🏻‍♀' => 'kvinna sum spælir kurvabólt: ljósur húðarlitur',
    '⛹🏼‍♀' => 'kvinna sum spælir kurvabólt: miðalljósur húðarlitur',
    '⛹🏽‍♀' => 'kvinna sum spælir kurvabólt: miðal húðarlitur',
    '⛹🏾‍♀' => 'kvinna sum spælir kurvabólt: miðalmyrkur húðarlitur',
    '⛹🏿‍♀' => 'kvinna sum spælir kurvabólt: myrkur húðarlitur',
    '🏋🏻‍♂' => 'mannligur vektlyftari: ljósur húðarlitur',
    '🏋🏼‍♂' => 'mannligur vektlyftari: miðalljósur húðarlitur',
    '🏋🏽‍♂' => 'mannligur vektlyftari: miðal húðarlitur',
    '🏋🏾‍♂' => 'mannligur vektlyftari: miðalmyrkur húðarlitur',
    '🏋🏿‍♂' => 'mannligur vektlyftari: myrkur húðarlitur',
    '🏋🏻‍♀' => 'kvinnuligur vektlyftari: ljósur húðarlitur',
    '🏋🏼‍♀' => 'kvinnuligur vektlyftari: miðalljósur húðarlitur',
    '🏋🏽‍♀' => 'kvinnuligur vektlyftari: miðal húðarlitur',
    '🏋🏾‍♀' => 'kvinnuligur vektlyftari: miðalmyrkur húðarlitur',
    '🏋🏿‍♀' => 'kvinnuligur vektlyftari: myrkur húðarlitur',
    '🚴🏻‍♂' => 'maður sum súkklar: ljósur húðarlitur',
    '🚴🏼‍♂' => 'maður sum súkklar: miðalljósur húðarlitur',
    '🚴🏽‍♂' => 'maður sum súkklar: miðal húðarlitur',
    '🚴🏾‍♂' => 'maður sum súkklar: miðalmyrkur húðarlitur',
    '🚴🏿‍♂' => 'maður sum súkklar: myrkur húðarlitur',
    '🚴🏻‍♀' => 'kvinna sum súkklar: ljósur húðarlitur',
    '🚴🏼‍♀' => 'kvinna sum súkklar: miðalljósur húðarlitur',
    '🚴🏽‍♀' => 'kvinna sum súkklar: miðal húðarlitur',
    '🚴🏾‍♀' => 'kvinna sum súkklar: miðalmyrkur húðarlitur',
    '🚴🏿‍♀' => 'kvinna sum súkklar: myrkur húðarlitur',
    '🚵🏻‍♂' => 'maður á fjallasúkklu: ljósur húðarlitur',
    '🚵🏼‍♂' => 'maður á fjallasúkklu: miðalljósur húðarlitur',
    '🚵🏽‍♂' => 'maður á fjallasúkklu: miðal húðarlitur',
    '🚵🏾‍♂' => 'maður á fjallasúkklu: miðalmyrkur húðarlitur',
    '🚵🏿‍♂' => 'maður á fjallasúkklu: myrkur húðarlitur',
    '🚵🏻‍♀' => 'kvinna á fjallasúkklu: ljósur húðarlitur',
    '🚵🏼‍♀' => 'kvinna á fjallasúkklu: miðalljósur húðarlitur',
    '🚵🏽‍♀' => 'kvinna á fjallasúkklu: miðal húðarlitur',
    '🚵🏾‍♀' => 'kvinna á fjallasúkklu: miðalmyrkur húðarlitur',
    '🚵🏿‍♀' => 'kvinna á fjallasúkklu: myrkur húðarlitur',
    '🤸🏻‍♂' => 'maður sum ger myllulop: ljósur húðarlitur',
    '🤸🏼‍♂' => 'maður sum ger myllulop: miðalljósur húðarlitur',
    '🤸🏽‍♂' => 'maður sum ger myllulop: miðal húðarlitur',
    '🤸🏾‍♂' => 'maður sum ger myllulop: miðalmyrkur húðarlitur',
    '🤸🏿‍♂' => 'maður sum ger myllulop: myrkur húðarlitur',
    '🤸🏻‍♀' => 'kvinna sum ger myllulop: ljósur húðarlitur',
    '🤸🏼‍♀' => 'kvinna sum ger myllulop: miðalljósur húðarlitur',
    '🤸🏽‍♀' => 'kvinna sum ger myllulop: miðal húðarlitur',
    '🤸🏾‍♀' => 'kvinna sum ger myllulop: miðalmyrkur húðarlitur',
    '🤸🏿‍♀' => 'kvinna sum ger myllulop: myrkur húðarlitur',
    '🤼🏻‍♀' => 'kvinnuligur glímingardystur: ljósur húðarlitur',
    '🤼🏼‍♀' => 'kvinnuligur glímingardystur: miðalljósur húðarlitur',
    '🤼🏽‍♀' => 'kvinnuligur glímingardystur: miðal húðarlitur',
    '🤼🏾‍♀' => 'kvinnuligur glímingardystur: miðalmyrkur húðarlitur',
    '🤼🏿‍♀' => 'kvinnuligur glímingardystur: myrkur húðarlitur',
    '🤼🏻‍♂' => 'mannligur glímingardystur: ljósur húðarlitur',
    '🤼🏼‍♂' => 'mannligur glímingardystur: miðalljósur húðarlitur',
    '🤼🏽‍♂' => 'mannligur glímingardystur: miðal húðarlitur',
    '🤼🏾‍♂' => 'mannligur glímingardystur: miðalmyrkur húðarlitur',
    '🤼🏿‍♂' => 'mannligur glímingardystur: myrkur húðarlitur',
    '🤽🏻‍♂' => 'maður sum spælir vatnpolo: ljósur húðarlitur',
    '🤽🏼‍♂' => 'maður sum spælir vatnpolo: miðalljósur húðarlitur',
    '🤽🏽‍♂' => 'maður sum spælir vatnpolo: miðal húðarlitur',
    '🤽🏾‍♂' => 'maður sum spælir vatnpolo: miðalmyrkur húðarlitur',
    '🤽🏿‍♂' => 'maður sum spælir vatnpolo: myrkur húðarlitur',
    '🤽🏻‍♀' => 'kona sum spælir vatnpolo: ljósur húðarlitur',
    '🤽🏼‍♀' => 'kona sum spælir vatnpolo: miðalljósur húðarlitur',
    '🤽🏽‍♀' => 'kona sum spælir vatnpolo: miðal húðarlitur',
    '🤽🏾‍♀' => 'kona sum spælir vatnpolo: miðalmyrkur húðarlitur',
    '🤽🏿‍♀' => 'kona sum spælir vatnpolo: myrkur húðarlitur',
    '🤾🏻‍♂' => 'maður sum spælir hondbólt: ljósur húðarlitur',
    '🤾🏼‍♂' => 'maður sum spælir hondbólt: miðalljósur húðarlitur',
    '🤾🏽‍♂' => 'maður sum spælir hondbólt: miðal húðarlitur',
    '🤾🏾‍♂' => 'maður sum spælir hondbólt: miðalmyrkur húðarlitur',
    '🤾🏿‍♂' => 'maður sum spælir hondbólt: myrkur húðarlitur',
    '🤾🏻‍♀' => 'kvinna sum spælir hondbólt: ljósur húðarlitur',
    '🤾🏼‍♀' => 'kvinna sum spælir hondbólt: miðalljósur húðarlitur',
    '🤾🏽‍♀' => 'kvinna sum spælir hondbólt: miðal húðarlitur',
    '🤾🏾‍♀' => 'kvinna sum spælir hondbólt: miðalmyrkur húðarlitur',
    '🤾🏿‍♀' => 'kvinna sum spælir hondbólt: myrkur húðarlitur',
    '🤹🏻‍♂' => 'maður sum fimlar: ljósur húðarlitur',
    '🤹🏼‍♂' => 'maður sum fimlar: miðalljósur húðarlitur',
    '🤹🏽‍♂' => 'maður sum fimlar: miðal húðarlitur',
    '🤹🏾‍♂' => 'maður sum fimlar: miðalmyrkur húðarlitur',
    '🤹🏿‍♂' => 'maður sum fimlar: myrkur húðarlitur',
    '🤹🏻‍♀' => 'kvinna sum fimlar: ljósur húðarlitur',
    '🤹🏼‍♀' => 'kvinna sum fimlar: miðalljósur húðarlitur',
    '🤹🏽‍♀' => 'kvinna sum fimlar: miðal húðarlitur',
    '🤹🏾‍♀' => 'kvinna sum fimlar: miðalmyrkur húðarlitur',
    '🤹🏿‍♀' => 'kvinna sum fimlar: myrkur húðarlitur',
    '🧘🏻‍♂' => 'maður í lotusstøðu: ljósur húðarlitur',
    '🧘🏼‍♂' => 'maður í lotusstøðu: miðalljósur húðarlitur',
    '🧘🏽‍♂' => 'maður í lotusstøðu: miðal húðarlitur',
    '🧘🏾‍♂' => 'maður í lotusstøðu: miðalmyrkur húðarlitur',
    '🧘🏿‍♂' => 'maður í lotusstøðu: myrkur húðarlitur',
    '🧘🏻‍♀' => 'kvinna í lotusstøðu: ljósur húðarlitur',
    '🧘🏼‍♀' => 'kvinna í lotusstøðu: miðalljósur húðarlitur',
    '🧘🏽‍♀' => 'kvinna í lotusstøðu: miðal húðarlitur',
    '🧘🏾‍♀' => 'kvinna í lotusstøðu: miðalmyrkur húðarlitur',
    '🧘🏿‍♀' => 'kvinna í lotusstøðu: myrkur húðarlitur',
    '🧑‍🦰' => 'persónur: reytt hár',
    '🧑‍🦱' => 'persónur: purlut hár',
    '🧑‍🦳' => 'persónur: hvítt hár',
    '🧑‍🦲' => 'persónur: skallutur',
    '👨‍🦰' => 'maður: reytt hár',
    '👨‍🦱' => 'maður: purlut hár',
    '👨‍🦳' => 'maður: hvítt hár',
    '👨‍🦲' => 'maður: skallutur',
    '👩‍🦰' => 'kona: reytt hár',
    '👩‍🦱' => 'kona: purlut hár',
    '👩‍🦳' => 'kona: hvítt hár',
    '👩‍🦲' => 'kona: skallutur',
    '🚶‍➡' => 'persónur sum gongur: til høgru',
    '🧎‍➡' => 'persónur á knæ: til høgru',
    '🏃‍➡' => 'persónur sum rennur: til høgru',
    '👨‍👦' => 'familja: maður, drongur',
    '👨‍👧' => 'familja: maður, genta',
    '👩‍👦' => 'familja: kona, drongur',
    '👩‍👧' => 'familja: kona, genta',
    '😶‍🌫' => 'andlit í skýggjum',
    '😮‍💨' => 'andlit andar út',
    '🙂‍↕' => 'nikkandi andlit',
    '😵‍💫' => 'andlit við snyril eygum',
    '❤‍🔥' => 'hjarta sum brennur',
    '❤‍🩹' => 'hjarta sum er lappa',
    '👁‍🗨' => 'eyga í talubløðru',
    '🧔‍♂' => 'maður við skeggi',
    '👱‍♂' => 'ljóshærdur maður',
    '🧔‍♀' => 'kona við skeggi',
    '👱‍♀' => 'ljóshærd kvinna',
    '🙍‍♂' => 'illbrýntur maður',
    '🙍‍♀' => 'illbrýnt kvinna',
    '🙎‍♂' => 'maður við gron',
    '🙎‍♀' => 'kvinna við gron',
    '🙅‍♂' => 'maður sum veipar nei',
    '🙅‍♀' => 'kvinna sum veipar nei',
    '🙆‍♂' => 'maður sum veipar ok',
    '🙆‍♀' => 'kvinna sum veipar ok',
    '💁‍♂' => 'maður sum nertir við',
    '💁‍♀' => 'kvinna sum nertir við',
    '🙋‍♂' => 'maður sum lyftur hondina upp',
    '🙋‍♀' => 'kvinna sum lyftur hondina upp',
    '🧏‍♂' => 'deyvur maður',
    '🧏‍♀' => 'deyv kvinna',
    '🙇‍♂' => 'maður sum bukkar',
    '🙇‍♀' => 'kvinna sum bukkar',
    '🤦‍♂' => 'vónbrotin maður',
    '🤦‍♀' => 'vónbrotin kvinna',
    '🤷‍♂' => 'maður um yppur øksl',
    '🤷‍♀' => 'kvinna um yppur øksl',
    '🧑‍⚕' => 'heilsuverkfrøðingur',
    '👨‍⚕' => 'mannligur lækni',
    '👩‍⚕' => 'kvinnuligur lækni',
    '🧑‍🎓' => 'studentur',
    '👨‍🎓' => 'mannligur studentur',
    '👩‍🎓' => 'kvinnuligur studentur',
    '🧑‍🏫' => 'lærari',
    '👨‍🏫' => 'mannligur lærari',
    '👩‍🏫' => 'kvinnuligur lærari',
    '🧑‍⚖' => 'dómari',
    '👨‍⚖' => 'mannligur dómari',
    '👩‍⚖' => 'kvinnuligur dómari',
    '🧑‍🌾' => 'bóndi',
    '👨‍🌾' => 'mannligur bóndi',
    '👩‍🌾' => 'kvinnuligur bóndi',
    '🧑‍🍳' => 'kokkur',
    '👨‍🍳' => 'mannligur kokkur',
    '👩‍🍳' => 'kvinnuligur kokkur',
    '🧑‍🔧' => 'mekanikari',
    '👨‍🔧' => 'mannligur mekanikari',
    '👩‍🔧' => 'kvinnuligur mekanikari',
    '🧑‍🏭' => 'sveisari',
    '👨‍🏭' => 'mannligur sveisari',
    '👩‍🏭' => 'kvinnuligur sveisari',
    '🧑‍💼' => 'skrivstovufólk',
    '👨‍💼' => 'skrivstovumaður',
    '👩‍💼' => 'skrivstovukvinna',
    '🧑‍🔬' => 'náttúruvísindafólk',
    '👨‍🔬' => 'vísindamaður',
    '👩‍🔬' => 'vísindakvinna',
    '🧑‍💻' => 'tøknifrøðingur',
    '👨‍💻' => 'mannligur tøknifrøðingur',
    '👩‍💻' => 'kvinnuligur tøknifrøðingur',
    '🧑‍🎤' => 'sangari',
    '👨‍🎤' => 'mannligur sangari',
    '👩‍🎤' => 'kvinnuligur sangari',
    '🧑‍🎨' => 'listafólk',
    '👨‍🎨' => 'listamaður',
    '👩‍🎨' => 'listakona',
    '🧑‍✈' => 'flogskipari',
    '👨‍✈' => 'mannligur flogskipari',
    '👩‍✈' => 'kvinnuligur flogskipari',
    '🧑‍🚀' => 'astronautur',
    '👨‍🚀' => 'mannligur astronautur',
    '👩‍🚀' => 'kvinnuligur astronautur',
    '🧑‍🚒' => 'sløkkiliðsfólk',
    '👨‍🚒' => 'sløkkiliðsmaður',
    '👩‍🚒' => 'sløkkiliðskvinna',
    '👮‍♂' => 'løgreglumaður',
    '👮‍♀' => 'løgreglukvinna',
    '🕵‍♂' => 'mannligur detektivur',
    '🕵‍♀' => 'kvinnuligur detektivur',
    '💂‍♂' => 'vaktarmaður',
    '💂‍♀' => 'vaktarkvinna',
    '👷‍♂' => 'mannligur byggiverkfrøðingur',
    '👷‍♀' => 'kvinnuligur byggiverkfrøðingur',
    '👳‍♂' => 'maður við turban',
    '👳‍♀' => 'kvinna við turban',
    '🤵‍♂' => 'maður í smoking',
    '🤵‍♀' => 'kona í smoking',
    '👰‍♂' => 'maður í sløri',
    '👰‍♀' => 'kona í sløri',
    '👩‍🍼' => 'kvinna gevur fløsku',
    '👨‍🍼' => 'maður gevur fløsku',
    '🧑‍🍼' => 'persónur gevur fløsku',
    '🧑‍🎄' => 'jólafólk',
    '🦸‍♂' => 'mannlig superhetja',
    '🦸‍♀' => 'kvinnulig superhetja',
    '🦹‍♂' => 'mannligur superskálkur',
    '🦹‍♀' => 'kvinnuligur superskálkur',
    '🧙‍♂' => 'gandakallur',
    '🧙‍♀' => 'gandakelling',
    '🧚‍♂' => 'mannligur álvur',
    '🧚‍♀' => 'kvinnulig álva',
    '🧛‍♂' => 'mannligur vampýrur',
    '🧛‍♀' => 'kvinnuligur vampýrur',
    '🧜‍♂' => 'havmaður',
    '🧜‍♀' => 'havfrúgv',
    '🧝‍♂' => 'mannfólka álvur',
    '🧝‍♀' => 'konufólka álva',
    '🧞‍♂' => 'mannligur andi',
    '🧞‍♀' => 'kvinnuligur andi',
    '🧟‍♂' => 'mannligur sombi',
    '🧟‍♀' => 'kvinnuligur sombi',
    '💆‍♂' => 'maður sum fær massasju',
    '💆‍♀' => 'kvinna sum fær massasju',
    '💇‍♂' => 'maður sum fær klipt hári',
    '💇‍♀' => 'kvinna sum fær klipt hári',
    '🚶‍♂' => 'maður sum gongur',
    '🚶‍♀' => 'kvinna sum gongur',
    '🧍‍♂' => 'maður ið stendur',
    '🧍‍♀' => 'kvinna ið stendur',
    '🧎‍♂' => 'maður á knæ',
    '🧎‍♀' => 'kvinna á knæ',
    '🧑‍🦯' => 'persónur við blindastavi',
    '👨‍🦯' => 'maður við blindastavi',
    '👩‍🦯' => 'kvinna við blindastavi',
    '🧑‍🦼' => 'persónur í motorkoyristóli',
    '👨‍🦼' => 'maður í motorkoyristóli',
    '👩‍🦼' => 'kvinna í motorkoyristóli',
    '🧑‍🦽' => 'persónur í koyristóli',
    '👨‍🦽' => 'maður í koyristóli',
    '👩‍🦽' => 'kvinna í koyristóli',
    '🏃‍♂' => 'maður sum rennur',
    '🏃‍♀' => 'kvinna sum rennur',
    '👯‍♂' => 'menn við haruoyrum',
    '👯‍♀' => 'kvinnur við haruoyrum',
    '🧖‍♂' => 'maður í sauna',
    '🧖‍♀' => 'kvinna í sauna',
    '🧗‍♂' => 'maður sum klatrar',
    '🧗‍♀' => 'kvinna sum klatrar',
    '🏌‍♂' => 'maður sum spælir golf',
    '🏌‍♀' => 'kona sum spælir golf',
    '🏄‍♂' => 'maður sum skreiður á brimfjøl',
    '🏄‍♀' => 'kona sum skreiður á brimfjøl',
    '🚣‍♂' => 'maður í árabáti',
    '🚣‍♀' => 'kvinna í árabáti',
    '🏊‍♂' => 'maður sum svimur',
    '🏊‍♀' => 'kvinna sum svimur',
    '⛹‍♂' => 'maður sum spælir kurvabólt',
    '⛹‍♀' => 'kvinna sum spælir kurvabólt',
    '🏋‍♂' => 'mannligur vektlyftari',
    '🏋‍♀' => 'kvinnuligur vektlyftari',
    '🚴‍♂' => 'maður sum súkklar',
    '🚴‍♀' => 'kvinna sum súkklar',
    '🚵‍♂' => 'maður á fjallasúkklu',
    '🚵‍♀' => 'kvinna á fjallasúkklu',
    '🤸‍♂' => 'maður sum ger myllulop',
    '🤸‍♀' => 'kvinna sum ger myllulop',
    '🤼‍♂' => 'mannligur glímingardystur',
    '🤼‍♀' => 'kvinnuligur glímingardystur',
    '🤽‍♂' => 'maður sum spælir vatnpolo',
    '🤽‍♀' => 'kona sum spælir vatnpolo',
    '🤾‍♂' => 'maður sum spælir hondbólt',
    '🤾‍♀' => 'kvinna sum spælir hondbólt',
    '🤹‍♂' => 'maður sum fimlar',
    '🤹‍♀' => 'kvinna sum fimlar',
    '🧘‍♂' => 'maður í lotusstøðu',
    '🧘‍♀' => 'kvinna í lotusstøðu',
    '🧑‍🧒' => 'familja: vaksin, barn',
    '🐕‍🦺' => 'tænastuhundur',
    '🐈‍⬛' => 'svørt ketta',
    '🐻‍❄' => 'hvítabjørn',
    '🐦‍⬛' => 'svartur fuglur',
    '🐦‍🔥' => 'føniks',
    '🍋‍🟩' => 'súraldin',
    '🍄‍🟫' => 'brúnur soppur',
    '⛓‍💥' => 'brotin keta',
    '🏳‍🌈' => 'ælaboga flagg',
    '🏳‍⚧' => 'tvørkynd flagg',
    '🏴‍☠' => 'sjórænaraflagg',
    '👋🏻' => 'veitrandi hond: ljósur húðarlitur',
    '👋🏼' => 'veitrandi hond: miðalljósur húðarlitur',
    '👋🏽' => 'veitrandi hond: miðal húðarlitur',
    '👋🏾' => 'veitrandi hond: miðalmyrkur húðarlitur',
    '👋🏿' => 'veitrandi hond: myrkur húðarlitur',
    '🤚🏻' => 'handarbak: ljósur húðarlitur',
    '🤚🏼' => 'handarbak: miðalljósur húðarlitur',
    '🤚🏽' => 'handarbak: miðal húðarlitur',
    '🤚🏾' => 'handarbak: miðalmyrkur húðarlitur',
    '🤚🏿' => 'handarbak: myrkur húðarlitur',
    '🖐🏻' => 'fimm fingrar: ljósur húðarlitur',
    '🖐🏼' => 'fimm fingrar: miðalljósur húðarlitur',
    '🖐🏽' => 'fimm fingrar: miðal húðarlitur',
    '🖐🏾' => 'fimm fingrar: miðalmyrkur húðarlitur',
    '🖐🏿' => 'fimm fingrar: myrkur húðarlitur',
    '✋🏻' => 'hond: ljósur húðarlitur',
    '✋🏼' => 'hond: miðalljósur húðarlitur',
    '✋🏽' => 'hond: miðal húðarlitur',
    '✋🏾' => 'hond: miðalmyrkur húðarlitur',
    '✋🏿' => 'hond: myrkur húðarlitur',
    '🖖🏻' => 'vulkan heilsan: ljósur húðarlitur',
    '🖖🏼' => 'vulkan heilsan: miðalljósur húðarlitur',
    '🖖🏽' => 'vulkan heilsan: miðal húðarlitur',
    '🖖🏾' => 'vulkan heilsan: miðalmyrkur húðarlitur',
    '🖖🏿' => 'vulkan heilsan: myrkur húðarlitur',
    '🫱🏻' => 'hond til høgru: ljósur húðarlitur',
    '🫱🏼' => 'hond til høgru: miðalljósur húðarlitur',
    '🫱🏽' => 'hond til høgru: miðal húðarlitur',
    '🫱🏾' => 'hond til høgru: miðalmyrkur húðarlitur',
    '🫱🏿' => 'hond til høgru: myrkur húðarlitur',
    '🫲🏻' => 'hond til vinstru: ljósur húðarlitur',
    '🫲🏼' => 'hond til vinstru: miðalljósur húðarlitur',
    '🫲🏽' => 'hond til vinstru: miðal húðarlitur',
    '🫲🏾' => 'hond til vinstru: miðalmyrkur húðarlitur',
    '🫲🏿' => 'hond til vinstru: myrkur húðarlitur',
    '🫳🏻' => 'lógvi niðureftir: ljósur húðarlitur',
    '🫳🏼' => 'lógvi niðureftir: miðalljósur húðarlitur',
    '🫳🏽' => 'lógvi niðureftir: miðal húðarlitur',
    '🫳🏾' => 'lógvi niðureftir: miðalmyrkur húðarlitur',
    '🫳🏿' => 'lógvi niðureftir: myrkur húðarlitur',
    '🫴🏻' => 'lógvi uppeftir: ljósur húðarlitur',
    '🫴🏼' => 'lógvi uppeftir: miðalljósur húðarlitur',
    '🫴🏽' => 'lógvi uppeftir: miðal húðarlitur',
    '🫴🏾' => 'lógvi uppeftir: miðalmyrkur húðarlitur',
    '🫴🏿' => 'lógvi uppeftir: myrkur húðarlitur',
    '🫷🏻' => 'hond skumpar til vinstru: ljósur húðarlitur',
    '🫷🏼' => 'hond skumpar til vinstru: miðalljósur húðarlitur',
    '🫷🏽' => 'hond skumpar til vinstru: miðal húðarlitur',
    '🫷🏾' => 'hond skumpar til vinstru: miðalmyrkur húðarlitur',
    '🫷🏿' => 'hond skumpar til vinstru: myrkur húðarlitur',
    '🫸🏻' => 'hond skumpar til høgru: ljósur húðarlitur',
    '🫸🏼' => 'hond skumpar til høgru: miðalljósur húðarlitur',
    '🫸🏽' => 'hond skumpar til høgru: miðal húðarlitur',
    '🫸🏾' => 'hond skumpar til høgru: miðalmyrkur húðarlitur',
    '🫸🏿' => 'hond skumpar til høgru: myrkur húðarlitur',
    '👌🏻' => 'ok tekin: ljósur húðarlitur',
    '👌🏼' => 'ok tekin: miðalljósur húðarlitur',
    '👌🏽' => 'ok tekin: miðal húðarlitur',
    '👌🏾' => 'ok tekin: miðalmyrkur húðarlitur',
    '👌🏿' => 'ok tekin: myrkur húðarlitur',
    '🤌🏻' => 'samlaðir fingrar: ljósur húðarlitur',
    '🤌🏼' => 'samlaðir fingrar: miðalljósur húðarlitur',
    '🤌🏽' => 'samlaðir fingrar: miðal húðarlitur',
    '🤌🏾' => 'samlaðir fingrar: miðalmyrkur húðarlitur',
    '🤌🏿' => 'samlaðir fingrar: myrkur húðarlitur',
    '🤏🏻' => 'fingrar sum vísa ikki nógv: ljósur húðarlitur',
    '🤏🏼' => 'fingrar sum vísa ikki nógv: miðalljósur húðarlitur',
    '🤏🏽' => 'fingrar sum vísa ikki nógv: miðal húðarlitur',
    '🤏🏾' => 'fingrar sum vísa ikki nógv: miðalmyrkur húðarlitur',
    '🤏🏿' => 'fingrar sum vísa ikki nógv: myrkur húðarlitur',
    '✌🏻' => 'sigurstekin: ljósur húðarlitur',
    '✌🏼' => 'sigurstekin: miðalljósur húðarlitur',
    '✌🏽' => 'sigurstekin: miðal húðarlitur',
    '✌🏾' => 'sigurstekin: miðalmyrkur húðarlitur',
    '✌🏿' => 'sigurstekin: myrkur húðarlitur',
    '🤞🏻' => 'krossaðir fingrar: ljósur húðarlitur',
    '🤞🏼' => 'krossaðir fingrar: miðalljósur húðarlitur',
    '🤞🏽' => 'krossaðir fingrar: miðal húðarlitur',
    '🤞🏾' => 'krossaðir fingrar: miðalmyrkur húðarlitur',
    '🤞🏿' => 'krossaðir fingrar: myrkur húðarlitur',
    '🫰🏻' => 'krossa tummil og peikifingur: ljósur húðarlitur',
    '🫰🏼' => 'krossa tummil og peikifingur: miðalljósur húðarlitur',
    '🫰🏽' => 'krossa tummil og peikifingur: miðal húðarlitur',
    '🫰🏾' => 'krossa tummil og peikifingur: miðalmyrkur húðarlitur',
    '🫰🏿' => 'krossa tummil og peikifingur: myrkur húðarlitur',
    '🤟🏻' => 'kærleikshandabragd: ljósur húðarlitur',
    '🤟🏼' => 'kærleikshandabragd: miðalljósur húðarlitur',
    '🤟🏽' => 'kærleikshandabragd: miðal húðarlitur',
    '🤟🏾' => 'kærleikshandabragd: miðalmyrkur húðarlitur',
    '🤟🏿' => 'kærleikshandabragd: myrkur húðarlitur',
    '🤘🏻' => 'horntekin: ljósur húðarlitur',
    '🤘🏼' => 'horntekin: miðalljósur húðarlitur',
    '🤘🏽' => 'horntekin: miðal húðarlitur',
    '🤘🏾' => 'horntekin: miðalmyrkur húðarlitur',
    '🤘🏿' => 'horntekin: myrkur húðarlitur',
    '🤙🏻' => 'telefontekin: ljósur húðarlitur',
    '🤙🏼' => 'telefontekin: miðalljósur húðarlitur',
    '🤙🏽' => 'telefontekin: miðal húðarlitur',
    '🤙🏾' => 'telefontekin: miðalmyrkur húðarlitur',
    '🤙🏿' => 'telefontekin: myrkur húðarlitur',
    '👈🏻' => 'fremstifingur peikar til vinstru: ljósur húðarlitur',
    '👈🏼' => 'fremstifingur peikar til vinstru: miðalljósur húðarlitur',
    '👈🏽' => 'fremstifingur peikar til vinstru: miðal húðarlitur',
    '👈🏾' => 'fremstifingur peikar til vinstru: miðalmyrkur húðarlitur',
    '👈🏿' => 'fremstifingur peikar til vinstru: myrkur húðarlitur',
    '👉🏻' => 'fremstifingur peikar til høgru: ljósur húðarlitur',
    '👉🏼' => 'fremstifingur peikar til høgru: miðalljósur húðarlitur',
    '👉🏽' => 'fremstifingur peikar til høgru: miðal húðarlitur',
    '👉🏾' => 'fremstifingur peikar til høgru: miðalmyrkur húðarlitur',
    '👉🏿' => 'fremstifingur peikar til høgru: myrkur húðarlitur',
    '👆🏻' => 'fremstifingur peikar uppeftir: ljósur húðarlitur',
    '👆🏼' => 'fremstifingur peikar uppeftir: miðalljósur húðarlitur',
    '👆🏽' => 'fremstifingur peikar uppeftir: miðal húðarlitur',
    '👆🏾' => 'fremstifingur peikar uppeftir: miðalmyrkur húðarlitur',
    '👆🏿' => 'fremstifingur peikar uppeftir: myrkur húðarlitur',
    '🖕🏻' => 'longutong peikar uppeftir: ljósur húðarlitur',
    '🖕🏼' => 'longutong peikar uppeftir: miðalljósur húðarlitur',
    '🖕🏽' => 'longutong peikar uppeftir: miðal húðarlitur',
    '🖕🏾' => 'longutong peikar uppeftir: miðalmyrkur húðarlitur',
    '🖕🏿' => 'longutong peikar uppeftir: myrkur húðarlitur',
    '👇🏻' => 'longutong peikar niðureftir: ljósur húðarlitur',
    '👇🏼' => 'longutong peikar niðureftir: miðalljósur húðarlitur',
    '👇🏽' => 'longutong peikar niðureftir: miðal húðarlitur',
    '👇🏾' => 'longutong peikar niðureftir: miðalmyrkur húðarlitur',
    '👇🏿' => 'longutong peikar niðureftir: myrkur húðarlitur',
    '☝🏻' => 'lógvi og fremstifingur peikar uppeftir: ljósur húðarlitur',
    '☝🏼' => 'lógvi og fremstifingur peikar uppeftir: miðalljósur húðarlitur',
    '☝🏽' => 'lógvi og fremstifingur peikar uppeftir: miðal húðarlitur',
    '☝🏾' => 'lógvi og fremstifingur peikar uppeftir: miðalmyrkur húðarlitur',
    '☝🏿' => 'lógvi og fremstifingur peikar uppeftir: myrkur húðarlitur',
    '🫵🏻' => 'peikar eftir tær: ljósur húðarlitur',
    '🫵🏼' => 'peikar eftir tær: miðalljósur húðarlitur',
    '🫵🏽' => 'peikar eftir tær: miðal húðarlitur',
    '🫵🏾' => 'peikar eftir tær: miðalmyrkur húðarlitur',
    '🫵🏿' => 'peikar eftir tær: myrkur húðarlitur',
    '👍🏻' => 'tummil upp: ljósur húðarlitur',
    '👍🏼' => 'tummil upp: miðalljósur húðarlitur',
    '👍🏽' => 'tummil upp: miðal húðarlitur',
    '👍🏾' => 'tummil upp: miðalmyrkur húðarlitur',
    '👍🏿' => 'tummil upp: myrkur húðarlitur',
    '👎🏻' => 'tummil niður: ljósur húðarlitur',
    '👎🏼' => 'tummil niður: miðalljósur húðarlitur',
    '👎🏽' => 'tummil niður: miðal húðarlitur',
    '👎🏾' => 'tummil niður: miðalmyrkur húðarlitur',
    '👎🏿' => 'tummil niður: myrkur húðarlitur',
    '✊🏻' => 'knýttur nevi: ljósur húðarlitur',
    '✊🏼' => 'knýttur nevi: miðalljósur húðarlitur',
    '✊🏽' => 'knýttur nevi: miðal húðarlitur',
    '✊🏾' => 'knýttur nevi: miðalmyrkur húðarlitur',
    '✊🏿' => 'knýttur nevi: myrkur húðarlitur',
    '👊🏻' => 'sláandi knýttur nevi: ljósur húðarlitur',
    '👊🏼' => 'sláandi knýttur nevi: miðalljósur húðarlitur',
    '👊🏽' => 'sláandi knýttur nevi: miðal húðarlitur',
    '👊🏾' => 'sláandi knýttur nevi: miðalmyrkur húðarlitur',
    '👊🏿' => 'sláandi knýttur nevi: myrkur húðarlitur',
    '🤛🏻' => 'nevi í vendur til vinstru: ljósur húðarlitur',
    '🤛🏼' => 'nevi í vendur til vinstru: miðalljósur húðarlitur',
    '🤛🏽' => 'nevi í vendur til vinstru: miðal húðarlitur',
    '🤛🏾' => 'nevi í vendur til vinstru: miðalmyrkur húðarlitur',
    '🤛🏿' => 'nevi í vendur til vinstru: myrkur húðarlitur',
    '🤜🏻' => 'nevi í vendur til høgru: ljósur húðarlitur',
    '🤜🏼' => 'nevi í vendur til høgru: miðalljósur húðarlitur',
    '🤜🏽' => 'nevi í vendur til høgru: miðal húðarlitur',
    '🤜🏾' => 'nevi í vendur til høgru: miðalmyrkur húðarlitur',
    '🤜🏿' => 'nevi í vendur til høgru: myrkur húðarlitur',
    '👏🏻' => 'klappandi hendur: ljósur húðarlitur',
    '👏🏼' => 'klappandi hendur: miðalljósur húðarlitur',
    '👏🏽' => 'klappandi hendur: miðal húðarlitur',
    '👏🏾' => 'klappandi hendur: miðalmyrkur húðarlitur',
    '👏🏿' => 'klappandi hendur: myrkur húðarlitur',
    '🙌🏻' => 'upplyftar hendur: ljósur húðarlitur',
    '🙌🏼' => 'upplyftar hendur: miðalljósur húðarlitur',
    '🙌🏽' => 'upplyftar hendur: miðal húðarlitur',
    '🙌🏾' => 'upplyftar hendur: miðalmyrkur húðarlitur',
    '🙌🏿' => 'upplyftar hendur: myrkur húðarlitur',
    '🫶🏻' => 'hjarta hendur: ljósur húðarlitur',
    '🫶🏼' => 'hjarta hendur: miðalljósur húðarlitur',
    '🫶🏽' => 'hjarta hendur: miðal húðarlitur',
    '🫶🏾' => 'hjarta hendur: miðalmyrkur húðarlitur',
    '🫶🏿' => 'hjarta hendur: myrkur húðarlitur',
    '👐🏻' => 'opnar hendur: ljósur húðarlitur',
    '👐🏼' => 'opnar hendur: miðalljósur húðarlitur',
    '👐🏽' => 'opnar hendur: miðal húðarlitur',
    '👐🏾' => 'opnar hendur: miðalmyrkur húðarlitur',
    '👐🏿' => 'opnar hendur: myrkur húðarlitur',
    '🤲🏻' => 'lógvar sum eru saman: ljósur húðarlitur',
    '🤲🏼' => 'lógvar sum eru saman: miðalljósur húðarlitur',
    '🤲🏽' => 'lógvar sum eru saman: miðal húðarlitur',
    '🤲🏾' => 'lógvar sum eru saman: miðalmyrkur húðarlitur',
    '🤲🏿' => 'lógvar sum eru saman: myrkur húðarlitur',
    '🤝🏻' => 'lógvatak: ljósur húðarlitur',
    '🤝🏼' => 'lógvatak: miðalljósur húðarlitur',
    '🤝🏽' => 'lógvatak: miðal húðarlitur',
    '🤝🏾' => 'lógvatak: miðalmyrkur húðarlitur',
    '🤝🏿' => 'lógvatak: myrkur húðarlitur',
    '🙏🏻' => 'falda hendur: ljósur húðarlitur',
    '🙏🏼' => 'falda hendur: miðalljósur húðarlitur',
    '🙏🏽' => 'falda hendur: miðal húðarlitur',
    '🙏🏾' => 'falda hendur: miðalmyrkur húðarlitur',
    '🙏🏿' => 'falda hendur: myrkur húðarlitur',
    '✍🏻' => 'skrivandi hond: ljósur húðarlitur',
    '✍🏼' => 'skrivandi hond: miðalljósur húðarlitur',
    '✍🏽' => 'skrivandi hond: miðal húðarlitur',
    '✍🏾' => 'skrivandi hond: miðalmyrkur húðarlitur',
    '✍🏿' => 'skrivandi hond: myrkur húðarlitur',
    '💅🏻' => 'neglalakk: ljósur húðarlitur',
    '💅🏼' => 'neglalakk: miðalljósur húðarlitur',
    '💅🏽' => 'neglalakk: miðal húðarlitur',
    '💅🏾' => 'neglalakk: miðalmyrkur húðarlitur',
    '💅🏿' => 'neglalakk: myrkur húðarlitur',
    '🤳🏻' => 'sjálvsmynd: ljósur húðarlitur',
    '🤳🏼' => 'sjálvsmynd: miðalljósur húðarlitur',
    '🤳🏽' => 'sjálvsmynd: miðal húðarlitur',
    '🤳🏾' => 'sjálvsmynd: miðalmyrkur húðarlitur',
    '🤳🏿' => 'sjálvsmynd: myrkur húðarlitur',
    '💪🏻' => 'spentur biseps: ljósur húðarlitur',
    '💪🏼' => 'spentur biseps: miðalljósur húðarlitur',
    '💪🏽' => 'spentur biseps: miðal húðarlitur',
    '💪🏾' => 'spentur biseps: miðalmyrkur húðarlitur',
    '💪🏿' => 'spentur biseps: myrkur húðarlitur',
    '🦵🏻' => 'bein: ljósur húðarlitur',
    '🦵🏼' => 'bein: miðalljósur húðarlitur',
    '🦵🏽' => 'bein: miðal húðarlitur',
    '🦵🏾' => 'bein: miðalmyrkur húðarlitur',
    '🦵🏿' => 'bein: myrkur húðarlitur',
    '🦶🏻' => 'fótur: ljósur húðarlitur',
    '🦶🏼' => 'fótur: miðalljósur húðarlitur',
    '🦶🏽' => 'fótur: miðal húðarlitur',
    '🦶🏾' => 'fótur: miðalmyrkur húðarlitur',
    '🦶🏿' => 'fótur: myrkur húðarlitur',
    '👂🏻' => 'oyra: ljósur húðarlitur',
    '👂🏼' => 'oyra: miðalljósur húðarlitur',
    '👂🏽' => 'oyra: miðal húðarlitur',
    '👂🏾' => 'oyra: miðalmyrkur húðarlitur',
    '👂🏿' => 'oyra: myrkur húðarlitur',
    '🦻🏻' => 'oyra við hoyritólið: ljósur húðarlitur',
    '🦻🏼' => 'oyra við hoyritólið: miðalljósur húðarlitur',
    '🦻🏽' => 'oyra við hoyritólið: miðal húðarlitur',
    '🦻🏾' => 'oyra við hoyritólið: miðalmyrkur húðarlitur',
    '🦻🏿' => 'oyra við hoyritólið: myrkur húðarlitur',
    '👃🏻' => 'nøs: ljósur húðarlitur',
    '👃🏼' => 'nøs: miðalljósur húðarlitur',
    '👃🏽' => 'nøs: miðal húðarlitur',
    '👃🏾' => 'nøs: miðalmyrkur húðarlitur',
    '👃🏿' => 'nøs: myrkur húðarlitur',
    '👶🏻' => 'pinkubarn: ljósur húðarlitur',
    '👶🏼' => 'pinkubarn: miðalljósur húðarlitur',
    '👶🏽' => 'pinkubarn: miðal húðarlitur',
    '👶🏾' => 'pinkubarn: miðalmyrkur húðarlitur',
    '👶🏿' => 'pinkubarn: myrkur húðarlitur',
    '🧒🏻' => 'barn: ljósur húðarlitur',
    '🧒🏼' => 'barn: miðalljósur húðarlitur',
    '🧒🏽' => 'barn: miðal húðarlitur',
    '🧒🏾' => 'barn: miðalmyrkur húðarlitur',
    '🧒🏿' => 'barn: myrkur húðarlitur',
    '👦🏻' => 'drongur: ljósur húðarlitur',
    '👦🏼' => 'drongur: miðalljósur húðarlitur',
    '👦🏽' => 'drongur: miðal húðarlitur',
    '👦🏾' => 'drongur: miðalmyrkur húðarlitur',
    '👦🏿' => 'drongur: myrkur húðarlitur',
    '👧🏻' => 'genta: ljósur húðarlitur',
    '👧🏼' => 'genta: miðalljósur húðarlitur',
    '👧🏽' => 'genta: miðal húðarlitur',
    '👧🏾' => 'genta: miðalmyrkur húðarlitur',
    '👧🏿' => 'genta: myrkur húðarlitur',
    '🧑🏻' => 'persónur: ljósur húðarlitur',
    '🧑🏼' => 'persónur: miðalljósur húðarlitur',
    '🧑🏽' => 'persónur: miðal húðarlitur',
    '🧑🏾' => 'persónur: miðalmyrkur húðarlitur',
    '🧑🏿' => 'persónur: myrkur húðarlitur',
    '👱🏻' => 'ljóshærdur persónur: ljósur húðarlitur',
    '👱🏼' => 'ljóshærdur persónur: miðalljósur húðarlitur',
    '👱🏽' => 'ljóshærdur persónur: miðal húðarlitur',
    '👱🏾' => 'ljóshærdur persónur: miðalmyrkur húðarlitur',
    '👱🏿' => 'ljóshærdur persónur: myrkur húðarlitur',
    '👨🏻' => 'maður: ljósur húðarlitur',
    '👨🏼' => 'maður: miðalljósur húðarlitur',
    '👨🏽' => 'maður: miðal húðarlitur',
    '👨🏾' => 'maður: miðalmyrkur húðarlitur',
    '👨🏿' => 'maður: myrkur húðarlitur',
    '🧔🏻' => 'persónur við skeggi: ljósur húðarlitur',
    '🧔🏼' => 'persónur við skeggi: miðalljósur húðarlitur',
    '🧔🏽' => 'persónur við skeggi: miðal húðarlitur',
    '🧔🏾' => 'persónur við skeggi: miðalmyrkur húðarlitur',
    '🧔🏿' => 'persónur við skeggi: myrkur húðarlitur',
    '👩🏻' => 'kona: ljósur húðarlitur',
    '👩🏼' => 'kona: miðalljósur húðarlitur',
    '👩🏽' => 'kona: miðal húðarlitur',
    '👩🏾' => 'kona: miðalmyrkur húðarlitur',
    '👩🏿' => 'kona: myrkur húðarlitur',
    '🧓🏻' => 'tilkomin: ljósur húðarlitur',
    '🧓🏼' => 'tilkomin: miðalljósur húðarlitur',
    '🧓🏽' => 'tilkomin: miðal húðarlitur',
    '🧓🏾' => 'tilkomin: miðalmyrkur húðarlitur',
    '🧓🏿' => 'tilkomin: myrkur húðarlitur',
    '👴🏻' => 'gamal maður: ljósur húðarlitur',
    '👴🏼' => 'gamal maður: miðalljósur húðarlitur',
    '👴🏽' => 'gamal maður: miðal húðarlitur',
    '👴🏾' => 'gamal maður: miðalmyrkur húðarlitur',
    '👴🏿' => 'gamal maður: myrkur húðarlitur',
    '👵🏻' => 'gomul kona: ljósur húðarlitur',
    '👵🏼' => 'gomul kona: miðalljósur húðarlitur',
    '👵🏽' => 'gomul kona: miðal húðarlitur',
    '👵🏾' => 'gomul kona: miðalmyrkur húðarlitur',
    '👵🏿' => 'gomul kona: myrkur húðarlitur',
    '🙍🏻' => 'illbrýntur persónur: ljósur húðarlitur',
    '🙍🏼' => 'illbrýntur persónur: miðalljósur húðarlitur',
    '🙍🏽' => 'illbrýntur persónur: miðal húðarlitur',
    '🙍🏾' => 'illbrýntur persónur: miðalmyrkur húðarlitur',
    '🙍🏿' => 'illbrýntur persónur: myrkur húðarlitur',
    '🙎🏻' => 'persónur við gron: ljósur húðarlitur',
    '🙎🏼' => 'persónur við gron: miðalljósur húðarlitur',
    '🙎🏽' => 'persónur við gron: miðal húðarlitur',
    '🙎🏾' => 'persónur við gron: miðalmyrkur húðarlitur',
    '🙎🏿' => 'persónur við gron: myrkur húðarlitur',
    '🙅🏻' => 'persónur sum veipar nei: ljósur húðarlitur',
    '🙅🏼' => 'persónur sum veipar nei: miðalljósur húðarlitur',
    '🙅🏽' => 'persónur sum veipar nei: miðal húðarlitur',
    '🙅🏾' => 'persónur sum veipar nei: miðalmyrkur húðarlitur',
    '🙅🏿' => 'persónur sum veipar nei: myrkur húðarlitur',
    '🙆🏻' => 'persónur sum veipar ok: ljósur húðarlitur',
    '🙆🏼' => 'persónur sum veipar ok: miðalljósur húðarlitur',
    '🙆🏽' => 'persónur sum veipar ok: miðal húðarlitur',
    '🙆🏾' => 'persónur sum veipar ok: miðalmyrkur húðarlitur',
    '🙆🏿' => 'persónur sum veipar ok: myrkur húðarlitur',
    '💁🏻' => 'persónur sum nertir við: ljósur húðarlitur',
    '💁🏼' => 'persónur sum nertir við: miðalljósur húðarlitur',
    '💁🏽' => 'persónur sum nertir við: miðal húðarlitur',
    '💁🏾' => 'persónur sum nertir við: miðalmyrkur húðarlitur',
    '💁🏿' => 'persónur sum nertir við: myrkur húðarlitur',
    '🙋🏻' => 'persónur sum lyftur hondina upp: ljósur húðarlitur',
    '🙋🏼' => 'persónur sum lyftur hondina upp: miðalljósur húðarlitur',
    '🙋🏽' => 'persónur sum lyftur hondina upp: miðal húðarlitur',
    '🙋🏾' => 'persónur sum lyftur hondina upp: miðalmyrkur húðarlitur',
    '🙋🏿' => 'persónur sum lyftur hondina upp: myrkur húðarlitur',
    '🧏🏻' => 'deyvur persónur: ljósur húðarlitur',
    '🧏🏼' => 'deyvur persónur: miðalljósur húðarlitur',
    '🧏🏽' => 'deyvur persónur: miðal húðarlitur',
    '🧏🏾' => 'deyvur persónur: miðalmyrkur húðarlitur',
    '🧏🏿' => 'deyvur persónur: myrkur húðarlitur',
    '🙇🏻' => 'persónur sum bukkar: ljósur húðarlitur',
    '🙇🏼' => 'persónur sum bukkar: miðalljósur húðarlitur',
    '🙇🏽' => 'persónur sum bukkar: miðal húðarlitur',
    '🙇🏾' => 'persónur sum bukkar: miðalmyrkur húðarlitur',
    '🙇🏿' => 'persónur sum bukkar: myrkur húðarlitur',
    '🤦🏻' => 'vónbrotin persónur: ljósur húðarlitur',
    '🤦🏼' => 'vónbrotin persónur: miðalljósur húðarlitur',
    '🤦🏽' => 'vónbrotin persónur: miðal húðarlitur',
    '🤦🏾' => 'vónbrotin persónur: miðalmyrkur húðarlitur',
    '🤦🏿' => 'vónbrotin persónur: myrkur húðarlitur',
    '🤷🏻' => 'persónur sum yppur øksl: ljósur húðarlitur',
    '🤷🏼' => 'persónur sum yppur øksl: miðalljósur húðarlitur',
    '🤷🏽' => 'persónur sum yppur øksl: miðal húðarlitur',
    '🤷🏾' => 'persónur sum yppur øksl: miðalmyrkur húðarlitur',
    '🤷🏿' => 'persónur sum yppur øksl: myrkur húðarlitur',
    '👮🏻' => 'politistur: ljósur húðarlitur',
    '👮🏼' => 'politistur: miðalljósur húðarlitur',
    '👮🏽' => 'politistur: miðal húðarlitur',
    '👮🏾' => 'politistur: miðalmyrkur húðarlitur',
    '👮🏿' => 'politistur: myrkur húðarlitur',
    '🕵🏻' => 'detektivur: ljósur húðarlitur',
    '🕵🏼' => 'detektivur: miðalljósur húðarlitur',
    '🕵🏽' => 'detektivur: miðal húðarlitur',
    '🕵🏾' => 'detektivur: miðalmyrkur húðarlitur',
    '🕵🏿' => 'detektivur: myrkur húðarlitur',
    '💂🏻' => 'vaktur: ljósur húðarlitur',
    '💂🏼' => 'vaktur: miðalljósur húðarlitur',
    '💂🏽' => 'vaktur: miðal húðarlitur',
    '💂🏾' => 'vaktur: miðalmyrkur húðarlitur',
    '💂🏿' => 'vaktur: myrkur húðarlitur',
    '🥷🏻' => 'ninja andlit: ljósur húðarlitur',
    '🥷🏼' => 'ninja andlit: miðalljósur húðarlitur',
    '🥷🏽' => 'ninja andlit: miðal húðarlitur',
    '🥷🏾' => 'ninja andlit: miðalmyrkur húðarlitur',
    '🥷🏿' => 'ninja andlit: myrkur húðarlitur',
    '👷🏻' => 'byggiverkfrøðingur: ljósur húðarlitur',
    '👷🏼' => 'byggiverkfrøðingur: miðalljósur húðarlitur',
    '👷🏽' => 'byggiverkfrøðingur: miðal húðarlitur',
    '👷🏾' => 'byggiverkfrøðingur: miðalmyrkur húðarlitur',
    '👷🏿' => 'byggiverkfrøðingur: myrkur húðarlitur',
    '🫅🏻' => 'persónur við krúnu: ljósur húðarlitur',
    '🫅🏼' => 'persónur við krúnu: miðalljósur húðarlitur',
    '🫅🏽' => 'persónur við krúnu: miðal húðarlitur',
    '🫅🏾' => 'persónur við krúnu: miðalmyrkur húðarlitur',
    '🫅🏿' => 'persónur við krúnu: myrkur húðarlitur',
    '🤴🏻' => 'prinsur: ljósur húðarlitur',
    '🤴🏼' => 'prinsur: miðalljósur húðarlitur',
    '🤴🏽' => 'prinsur: miðal húðarlitur',
    '🤴🏾' => 'prinsur: miðalmyrkur húðarlitur',
    '🤴🏿' => 'prinsur: myrkur húðarlitur',
    '👸🏻' => 'prinsessa: ljósur húðarlitur',
    '👸🏼' => 'prinsessa: miðalljósur húðarlitur',
    '👸🏽' => 'prinsessa: miðal húðarlitur',
    '👸🏾' => 'prinsessa: miðalmyrkur húðarlitur',
    '👸🏿' => 'prinsessa: myrkur húðarlitur',
    '👳🏻' => 'persónur við turban: ljósur húðarlitur',
    '👳🏼' => 'persónur við turban: miðalljósur húðarlitur',
    '👳🏽' => 'persónur við turban: miðal húðarlitur',
    '👳🏾' => 'persónur við turban: miðalmyrkur húðarlitur',
    '👳🏿' => 'persónur við turban: myrkur húðarlitur',
    '👲🏻' => 'persónur við kinesiskari húgvu: ljósur húðarlitur',
    '👲🏼' => 'persónur við kinesiskari húgvu: miðalljósur húðarlitur',
    '👲🏽' => 'persónur við kinesiskari húgvu: miðal húðarlitur',
    '👲🏾' => 'persónur við kinesiskari húgvu: miðalmyrkur húðarlitur',
    '👲🏿' => 'persónur við kinesiskari húgvu: myrkur húðarlitur',
    '🧕🏻' => 'kvinna við turriklæði: ljósur húðarlitur',
    '🧕🏼' => 'kvinna við turriklæði: miðalljósur húðarlitur',
    '🧕🏽' => 'kvinna við turriklæði: miðal húðarlitur',
    '🧕🏾' => 'kvinna við turriklæði: miðalmyrkur húðarlitur',
    '🧕🏿' => 'kvinna við turriklæði: myrkur húðarlitur',
    '🤵🏻' => 'persónur í smoking: ljósur húðarlitur',
    '🤵🏼' => 'persónur í smoking: miðalljósur húðarlitur',
    '🤵🏽' => 'persónur í smoking: miðal húðarlitur',
    '🤵🏾' => 'persónur í smoking: miðalmyrkur húðarlitur',
    '🤵🏿' => 'persónur í smoking: myrkur húðarlitur',
    '👰🏻' => 'persónur í sløri: ljósur húðarlitur',
    '👰🏼' => 'persónur í sløri: miðalljósur húðarlitur',
    '👰🏽' => 'persónur í sløri: miðal húðarlitur',
    '👰🏾' => 'persónur í sløri: miðalmyrkur húðarlitur',
    '👰🏿' => 'persónur í sløri: myrkur húðarlitur',
    '🤰🏻' => 'kvinna við barn: ljósur húðarlitur',
    '🤰🏼' => 'kvinna við barn: miðalljósur húðarlitur',
    '🤰🏽' => 'kvinna við barn: miðal húðarlitur',
    '🤰🏾' => 'kvinna við barn: miðalmyrkur húðarlitur',
    '🤰🏿' => 'kvinna við barn: myrkur húðarlitur',
    '🫃🏻' => 'maður við barn: ljósur húðarlitur',
    '🫃🏼' => 'maður við barn: miðalljósur húðarlitur',
    '🫃🏽' => 'maður við barn: miðal húðarlitur',
    '🫃🏾' => 'maður við barn: miðalmyrkur húðarlitur',
    '🫃🏿' => 'maður við barn: myrkur húðarlitur',
    '🫄🏻' => 'persónur við barn: ljósur húðarlitur',
    '🫄🏼' => 'persónur við barn: miðalljósur húðarlitur',
    '🫄🏽' => 'persónur við barn: miðal húðarlitur',
    '🫄🏾' => 'persónur við barn: miðalmyrkur húðarlitur',
    '🫄🏿' => 'persónur við barn: myrkur húðarlitur',
    '🤱🏻' => 'geva bróst: ljósur húðarlitur',
    '🤱🏼' => 'geva bróst: miðalljósur húðarlitur',
    '🤱🏽' => 'geva bróst: miðal húðarlitur',
    '🤱🏾' => 'geva bróst: miðalmyrkur húðarlitur',
    '🤱🏿' => 'geva bróst: myrkur húðarlitur',
    '👼🏻' => 'pinkabarnaeingil: ljósur húðarlitur',
    '👼🏼' => 'pinkabarnaeingil: miðalljósur húðarlitur',
    '👼🏽' => 'pinkabarnaeingil: miðal húðarlitur',
    '👼🏾' => 'pinkabarnaeingil: miðalmyrkur húðarlitur',
    '👼🏿' => 'pinkabarnaeingil: myrkur húðarlitur',
    '🎅🏻' => 'jólamaðurin: ljósur húðarlitur',
    '🎅🏼' => 'jólamaðurin: miðalljósur húðarlitur',
    '🎅🏽' => 'jólamaðurin: miðal húðarlitur',
    '🎅🏾' => 'jólamaðurin: miðalmyrkur húðarlitur',
    '🎅🏿' => 'jólamaðurin: myrkur húðarlitur',
    '🤶🏻' => 'jólakonan: ljósur húðarlitur',
    '🤶🏼' => 'jólakonan: miðalljósur húðarlitur',
    '🤶🏽' => 'jólakonan: miðal húðarlitur',
    '🤶🏾' => 'jólakonan: miðalmyrkur húðarlitur',
    '🤶🏿' => 'jólakonan: myrkur húðarlitur',
    '🦸🏻' => 'superhetja: ljósur húðarlitur',
    '🦸🏼' => 'superhetja: miðalljósur húðarlitur',
    '🦸🏽' => 'superhetja: miðal húðarlitur',
    '🦸🏾' => 'superhetja: miðalmyrkur húðarlitur',
    '🦸🏿' => 'superhetja: myrkur húðarlitur',
    '🦹🏻' => 'superskálkur: ljósur húðarlitur',
    '🦹🏼' => 'superskálkur: miðalljósur húðarlitur',
    '🦹🏽' => 'superskálkur: miðal húðarlitur',
    '🦹🏾' => 'superskálkur: miðalmyrkur húðarlitur',
    '🦹🏿' => 'superskálkur: myrkur húðarlitur',
    '🧙🏻' => 'persónur sum dugir gand: ljósur húðarlitur',
    '🧙🏼' => 'persónur sum dugir gand: miðalljósur húðarlitur',
    '🧙🏽' => 'persónur sum dugir gand: miðal húðarlitur',
    '🧙🏾' => 'persónur sum dugir gand: miðalmyrkur húðarlitur',
    '🧙🏿' => 'persónur sum dugir gand: myrkur húðarlitur',
    '🧚🏻' => 'álva: ljósur húðarlitur',
    '🧚🏼' => 'álva: miðalljósur húðarlitur',
    '🧚🏽' => 'álva: miðal húðarlitur',
    '🧚🏾' => 'álva: miðalmyrkur húðarlitur',
    '🧚🏿' => 'álva: myrkur húðarlitur',
    '🧛🏻' => 'vampýrur: ljósur húðarlitur',
    '🧛🏼' => 'vampýrur: miðalljósur húðarlitur',
    '🧛🏽' => 'vampýrur: miðal húðarlitur',
    '🧛🏾' => 'vampýrur: miðalmyrkur húðarlitur',
    '🧛🏿' => 'vampýrur: myrkur húðarlitur',
    '🧜🏻' => 'havfólk: ljósur húðarlitur',
    '🧜🏼' => 'havfólk: miðalljósur húðarlitur',
    '🧜🏽' => 'havfólk: miðal húðarlitur',
    '🧜🏾' => 'havfólk: miðalmyrkur húðarlitur',
    '🧜🏿' => 'havfólk: myrkur húðarlitur',
    '🧝🏻' => 'álvur: ljósur húðarlitur',
    '🧝🏼' => 'álvur: miðalljósur húðarlitur',
    '🧝🏽' => 'álvur: miðal húðarlitur',
    '🧝🏾' => 'álvur: miðalmyrkur húðarlitur',
    '🧝🏿' => 'álvur: myrkur húðarlitur',
    '💆🏻' => 'persónur sum fær massasju: ljósur húðarlitur',
    '💆🏼' => 'persónur sum fær massasju: miðalljósur húðarlitur',
    '💆🏽' => 'persónur sum fær massasju: miðal húðarlitur',
    '💆🏾' => 'persónur sum fær massasju: miðalmyrkur húðarlitur',
    '💆🏿' => 'persónur sum fær massasju: myrkur húðarlitur',
    '💇🏻' => 'persónur sum fær klipt hári: ljósur húðarlitur',
    '💇🏼' => 'persónur sum fær klipt hári: miðalljósur húðarlitur',
    '💇🏽' => 'persónur sum fær klipt hári: miðal húðarlitur',
    '💇🏾' => 'persónur sum fær klipt hári: miðalmyrkur húðarlitur',
    '💇🏿' => 'persónur sum fær klipt hári: myrkur húðarlitur',
    '🚶🏻' => 'persónur sum gongur: ljósur húðarlitur',
    '🚶🏼' => 'persónur sum gongur: miðalljósur húðarlitur',
    '🚶🏽' => 'persónur sum gongur: miðal húðarlitur',
    '🚶🏾' => 'persónur sum gongur: miðalmyrkur húðarlitur',
    '🚶🏿' => 'persónur sum gongur: myrkur húðarlitur',
    '🧍🏻' => 'persónur ið stendur: ljósur húðarlitur',
    '🧍🏼' => 'persónur ið stendur: miðalljósur húðarlitur',
    '🧍🏽' => 'persónur ið stendur: miðal húðarlitur',
    '🧍🏾' => 'persónur ið stendur: miðalmyrkur húðarlitur',
    '🧍🏿' => 'persónur ið stendur: myrkur húðarlitur',
    '🧎🏻' => 'persónur á knæ: ljósur húðarlitur',
    '🧎🏼' => 'persónur á knæ: miðalljósur húðarlitur',
    '🧎🏽' => 'persónur á knæ: miðal húðarlitur',
    '🧎🏾' => 'persónur á knæ: miðalmyrkur húðarlitur',
    '🧎🏿' => 'persónur á knæ: myrkur húðarlitur',
    '🏃🏻' => 'persónur sum rennur: ljósur húðarlitur',
    '🏃🏼' => 'persónur sum rennur: miðalljósur húðarlitur',
    '🏃🏽' => 'persónur sum rennur: miðal húðarlitur',
    '🏃🏾' => 'persónur sum rennur: miðalmyrkur húðarlitur',
    '🏃🏿' => 'persónur sum rennur: myrkur húðarlitur',
    '💃🏻' => 'kvinna sum dansar: ljósur húðarlitur',
    '💃🏼' => 'kvinna sum dansar: miðalljósur húðarlitur',
    '💃🏽' => 'kvinna sum dansar: miðal húðarlitur',
    '💃🏾' => 'kvinna sum dansar: miðalmyrkur húðarlitur',
    '💃🏿' => 'kvinna sum dansar: myrkur húðarlitur',
    '🕺🏻' => 'maður sum dansar: ljósur húðarlitur',
    '🕺🏼' => 'maður sum dansar: miðalljósur húðarlitur',
    '🕺🏽' => 'maður sum dansar: miðal húðarlitur',
    '🕺🏾' => 'maður sum dansar: miðalmyrkur húðarlitur',
    '🕺🏿' => 'maður sum dansar: myrkur húðarlitur',
    '🕴🏻' => 'maður í klædningi sveimar: ljósur húðarlitur',
    '🕴🏼' => 'maður í klædningi sveimar: miðalljósur húðarlitur',
    '🕴🏽' => 'maður í klædningi sveimar: miðal húðarlitur',
    '🕴🏾' => 'maður í klædningi sveimar: miðalmyrkur húðarlitur',
    '🕴🏿' => 'maður í klædningi sveimar: myrkur húðarlitur',
    '👯🏻' => 'fólk við haruoyrum: ljósur húðarlitur',
    '👯🏼' => 'fólk við haruoyrum: miðalljósur húðarlitur',
    '👯🏽' => 'fólk við haruoyrum: miðal húðarlitur',
    '👯🏾' => 'fólk við haruoyrum: miðalmyrkur húðarlitur',
    '👯🏿' => 'fólk við haruoyrum: myrkur húðarlitur',
    '🧖🏻' => 'persónur í sauna: ljósur húðarlitur',
    '🧖🏼' => 'persónur í sauna: miðalljósur húðarlitur',
    '🧖🏽' => 'persónur í sauna: miðal húðarlitur',
    '🧖🏾' => 'persónur í sauna: miðalmyrkur húðarlitur',
    '🧖🏿' => 'persónur í sauna: myrkur húðarlitur',
    '🧗🏻' => 'persónur sum klatrar: ljósur húðarlitur',
    '🧗🏼' => 'persónur sum klatrar: miðalljósur húðarlitur',
    '🧗🏽' => 'persónur sum klatrar: miðal húðarlitur',
    '🧗🏾' => 'persónur sum klatrar: miðalmyrkur húðarlitur',
    '🧗🏿' => 'persónur sum klatrar: myrkur húðarlitur',
    '🏇🏻' => 'kappríðing: ljósur húðarlitur',
    '🏇🏼' => 'kappríðing: miðalljósur húðarlitur',
    '🏇🏽' => 'kappríðing: miðal húðarlitur',
    '🏇🏾' => 'kappríðing: miðalmyrkur húðarlitur',
    '🏇🏿' => 'kappríðing: myrkur húðarlitur',
    '🏂🏻' => 'persónur sum stendur á snjófjøl: ljósur húðarlitur',
    '🏂🏼' => 'persónur sum stendur á snjófjøl: miðalljósur húðarlitur',
    '🏂🏽' => 'persónur sum stendur á snjófjøl: miðal húðarlitur',
    '🏂🏾' => 'persónur sum stendur á snjófjøl: miðalmyrkur húðarlitur',
    '🏂🏿' => 'persónur sum stendur á snjófjøl: myrkur húðarlitur',
    '🏌🏻' => 'persónur sum spælir golf: ljósur húðarlitur',
    '🏌🏼' => 'persónur sum spælir golf: miðalljósur húðarlitur',
    '🏌🏽' => 'persónur sum spælir golf: miðal húðarlitur',
    '🏌🏾' => 'persónur sum spælir golf: miðalmyrkur húðarlitur',
    '🏌🏿' => 'persónur sum spælir golf: myrkur húðarlitur',
    '🏄🏻' => 'persónur sum skreiður á brimfjøl: ljósur húðarlitur',
    '🏄🏼' => 'persónur sum skreiður á brimfjøl: miðalljósur húðarlitur',
    '🏄🏽' => 'persónur sum skreiður á brimfjøl: miðal húðarlitur',
    '🏄🏾' => 'persónur sum skreiður á brimfjøl: miðalmyrkur húðarlitur',
    '🏄🏿' => 'persónur sum skreiður á brimfjøl: myrkur húðarlitur',
    '🚣🏻' => 'persónur í árabáti: ljósur húðarlitur',
    '🚣🏼' => 'persónur í árabáti: miðalljósur húðarlitur',
    '🚣🏽' => 'persónur í árabáti: miðal húðarlitur',
    '🚣🏾' => 'persónur í árabáti: miðalmyrkur húðarlitur',
    '🚣🏿' => 'persónur í árabáti: myrkur húðarlitur',
    '🏊🏻' => 'persónur sum svimur: ljósur húðarlitur',
    '🏊🏼' => 'persónur sum svimur: miðalljósur húðarlitur',
    '🏊🏽' => 'persónur sum svimur: miðal húðarlitur',
    '🏊🏾' => 'persónur sum svimur: miðalmyrkur húðarlitur',
    '🏊🏿' => 'persónur sum svimur: myrkur húðarlitur',
    '⛹🏻' => 'persónur sum spælir kurvabólt: ljósur húðarlitur',
    '⛹🏼' => 'persónur sum spælir kurvabólt: miðalljósur húðarlitur',
    '⛹🏽' => 'persónur sum spælir kurvabólt: miðal húðarlitur',
    '⛹🏾' => 'persónur sum spælir kurvabólt: miðalmyrkur húðarlitur',
    '⛹🏿' => 'persónur sum spælir kurvabólt: myrkur húðarlitur',
    '🏋🏻' => 'vektlyftari: ljósur húðarlitur',
    '🏋🏼' => 'vektlyftari: miðalljósur húðarlitur',
    '🏋🏽' => 'vektlyftari: miðal húðarlitur',
    '🏋🏾' => 'vektlyftari: miðalmyrkur húðarlitur',
    '🏋🏿' => 'vektlyftari: myrkur húðarlitur',
    '🚴🏻' => 'persónur sum súkklar: ljósur húðarlitur',
    '🚴🏼' => 'persónur sum súkklar: miðalljósur húðarlitur',
    '🚴🏽' => 'persónur sum súkklar: miðal húðarlitur',
    '🚴🏾' => 'persónur sum súkklar: miðalmyrkur húðarlitur',
    '🚴🏿' => 'persónur sum súkklar: myrkur húðarlitur',
    '🚵🏻' => 'persónur á fjallasúkklu: ljósur húðarlitur',
    '🚵🏼' => 'persónur á fjallasúkklu: miðalljósur húðarlitur',
    '🚵🏽' => 'persónur á fjallasúkklu: miðal húðarlitur',
    '🚵🏾' => 'persónur á fjallasúkklu: miðalmyrkur húðarlitur',
    '🚵🏿' => 'persónur á fjallasúkklu: myrkur húðarlitur',
    '🤸🏻' => 'persónur sum ger myllulop: ljósur húðarlitur',
    '🤸🏼' => 'persónur sum ger myllulop: miðalljósur húðarlitur',
    '🤸🏽' => 'persónur sum ger myllulop: miðal húðarlitur',
    '🤸🏾' => 'persónur sum ger myllulop: miðalmyrkur húðarlitur',
    '🤸🏿' => 'persónur sum ger myllulop: myrkur húðarlitur',
    '🤼🏻' => 'glímingardystur: ljósur húðarlitur',
    '🤼🏼' => 'glímingardystur: miðalljósur húðarlitur',
    '🤼🏽' => 'glímingardystur: miðal húðarlitur',
    '🤼🏾' => 'glímingardystur: miðalmyrkur húðarlitur',
    '🤼🏿' => 'glímingardystur: myrkur húðarlitur',
    '🤽🏻' => 'persónur sum spælir vatnpolo: ljósur húðarlitur',
    '🤽🏼' => 'persónur sum spælir vatnpolo: miðalljósur húðarlitur',
    '🤽🏽' => 'persónur sum spælir vatnpolo: miðal húðarlitur',
    '🤽🏾' => 'persónur sum spælir vatnpolo: miðalmyrkur húðarlitur',
    '🤽🏿' => 'persónur sum spælir vatnpolo: myrkur húðarlitur',
    '🤾🏻' => 'persónur sum spælir hondbólt: ljósur húðarlitur',
    '🤾🏼' => 'persónur sum spælir hondbólt: miðalljósur húðarlitur',
    '🤾🏽' => 'persónur sum spælir hondbólt: miðal húðarlitur',
    '🤾🏾' => 'persónur sum spælir hondbólt: miðalmyrkur húðarlitur',
    '🤾🏿' => 'persónur sum spælir hondbólt: myrkur húðarlitur',
    '🤹🏻' => 'persónur sum fimlar: ljósur húðarlitur',
    '🤹🏼' => 'persónur sum fimlar: miðalljósur húðarlitur',
    '🤹🏽' => 'persónur sum fimlar: miðal húðarlitur',
    '🤹🏾' => 'persónur sum fimlar: miðalmyrkur húðarlitur',
    '🤹🏿' => 'persónur sum fimlar: myrkur húðarlitur',
    '🧘🏻' => 'persónur í lotusstøðu: ljósur húðarlitur',
    '🧘🏼' => 'persónur í lotusstøðu: miðalljósur húðarlitur',
    '🧘🏽' => 'persónur í lotusstøðu: miðal húðarlitur',
    '🧘🏾' => 'persónur í lotusstøðu: miðalmyrkur húðarlitur',
    '🧘🏿' => 'persónur í lotusstøðu: myrkur húðarlitur',
    '🛀🏻' => 'persónur í baðikari: ljósur húðarlitur',
    '🛀🏼' => 'persónur í baðikari: miðalljósur húðarlitur',
    '🛀🏽' => 'persónur í baðikari: miðal húðarlitur',
    '🛀🏾' => 'persónur í baðikari: miðalmyrkur húðarlitur',
    '🛀🏿' => 'persónur í baðikari: myrkur húðarlitur',
    '🛌🏻' => 'persónur í song: ljósur húðarlitur',
    '🛌🏼' => 'persónur í song: miðalljósur húðarlitur',
    '🛌🏽' => 'persónur í song: miðal húðarlitur',
    '🛌🏾' => 'persónur í song: miðalmyrkur húðarlitur',
    '🛌🏿' => 'persónur í song: myrkur húðarlitur',
    '👭🏻' => 'kvinnur leiðast: ljósur húðarlitur',
    '👭🏼' => 'kvinnur leiðast: miðalljósur húðarlitur',
    '👭🏽' => 'kvinnur leiðast: miðal húðarlitur',
    '👭🏾' => 'kvinnur leiðast: miðalmyrkur húðarlitur',
    '👭🏿' => 'kvinnur leiðast: myrkur húðarlitur',
    '👫🏻' => 'kvinna or maður leiðast: ljósur húðarlitur',
    '👫🏼' => 'kvinna or maður leiðast: miðalljósur húðarlitur',
    '👫🏽' => 'kvinna or maður leiðast: miðal húðarlitur',
    '👫🏾' => 'kvinna or maður leiðast: miðalmyrkur húðarlitur',
    '👫🏿' => 'kvinna or maður leiðast: myrkur húðarlitur',
    '👬🏻' => 'menn leiðast: ljósur húðarlitur',
    '👬🏼' => 'menn leiðast: miðalljósur húðarlitur',
    '👬🏽' => 'menn leiðast: miðal húðarlitur',
    '👬🏾' => 'menn leiðast: miðalmyrkur húðarlitur',
    '👬🏿' => 'menn leiðast: myrkur húðarlitur',
    '💏🏻' => 'tvey íð mussast: ljósur húðarlitur',
    '💏🏼' => 'tvey íð mussast: miðalljósur húðarlitur',
    '💏🏽' => 'tvey íð mussast: miðal húðarlitur',
    '💏🏾' => 'tvey íð mussast: miðalmyrkur húðarlitur',
    '💏🏿' => 'tvey íð mussast: myrkur húðarlitur',
    '💑🏻' => 'par og hjarta: ljósur húðarlitur',
    '💑🏼' => 'par og hjarta: miðalljósur húðarlitur',
    '💑🏽' => 'par og hjarta: miðal húðarlitur',
    '💑🏾' => 'par og hjarta: miðalmyrkur húðarlitur',
    '💑🏿' => 'par og hjarta: myrkur húðarlitur',
    '🇦🇨' => 'Flagg: Ascension',
    '🇦🇩' => 'Flagg: Andorra',
    '🇦🇪' => 'Flagg: Sameindu Emirríkini',
    '🇦🇫' => 'Flagg: Afganistan',
    '🇦🇬' => 'Flagg: Antigua & Barbuda',
    '🇦🇮' => 'Flagg: Anguilla',
    '🇦🇱' => 'Flagg: Albania',
    '🇦🇲' => 'Flagg: Armenia',
    '🇦🇴' => 'Flagg: Angola',
    '🇦🇶' => 'Flagg: Antarktis',
    '🇦🇷' => 'Flagg: Argentina',
    '🇦🇸' => 'Flagg: Amerikanska Samoa',
    '🇦🇹' => 'Flagg: Eysturríki',
    '🇦🇺' => 'Flagg: Avstralia',
    '🇦🇼' => 'Flagg: Aruba',
    '🇦🇽' => 'Flagg: Áland',
    '🇦🇿' => 'Flagg: Aserbadjan',
    '🇧🇦' => 'Flagg: Bosnia-Hersegovina',
    '🇧🇧' => 'Flagg: Barbados',
    '🇧🇩' => 'Flagg: Bangladesj',
    '🇧🇪' => 'Flagg: Belgia',
    '🇧🇫' => 'Flagg: Burkina Faso',
    '🇧🇬' => 'Flagg: Bulgaria',
    '🇧🇭' => 'Flagg: Barein',
    '🇧🇮' => 'Flagg: Burundi',
    '🇧🇯' => 'Flagg: Benin',
    '🇧🇱' => 'Flagg: St. Barthélemy',
    '🇧🇲' => 'Flagg: Bermuda',
    '🇧🇳' => 'Flagg: Brunei',
    '🇧🇴' => 'Flagg: Bolivia',
    '🇧🇶' => 'Flagg: Niðurlonds Karibia',
    '🇧🇷' => 'Flagg: Brasil',
    '🇧🇸' => 'Flagg: Bahamaoyggjar',
    '🇧🇹' => 'Flagg: Butan',
    '🇧🇻' => 'Flagg: Bouvetoyggj',
    '🇧🇼' => 'Flagg: Botsvana',
    '🇧🇾' => 'Flagg: Hvítarussland',
    '🇧🇿' => 'Flagg: Belis',
    '🇨🇦' => 'Flagg: Kanada',
    '🇨🇨' => 'Flagg: Kokosoyggjar',
    '🇨🇩' => 'Flagg: Kongo, Dem. Lýðveldið',
    '🇨🇫' => 'Flagg: Miðafrikalýðveldið',
    '🇨🇬' => 'Flagg: Kongo',
    '🇨🇭' => 'Flagg: Sveis',
    '🇨🇮' => 'Flagg: Fílabeinsstrondin',
    '🇨🇰' => 'Flagg: Cooksoyggjar',
    '🇨🇱' => 'Flagg: Kili',
    '🇨🇲' => 'Flagg: Kamerun',
    '🇨🇳' => 'Flagg: Kina',
    '🇨🇴' => 'Flagg: Kolombia',
    '🇨🇵' => 'Flagg: Clipperton',
    '🇨🇶' => 'Flagg: Sark',
    '🇨🇷' => 'Flagg: Kosta Rika',
    '🇨🇺' => 'Flagg: Kuba',
    '🇨🇻' => 'Flagg: Grønhøvdaoyggjar',
    '🇨🇼' => 'Flagg: Curaçao',
    '🇨🇽' => 'Flagg: Jólaoyggjin',
    '🇨🇾' => 'Flagg: Kýpros',
    '🇨🇿' => 'Flagg: Kekkia',
    '🇩🇪' => 'Flagg: Týskland',
    '🇩🇬' => 'Flagg: Diego Garcia',
    '🇩🇯' => 'Flagg: Djibuti',
    '🇩🇰' => 'Flagg: Danmark',
    '🇩🇲' => 'Flagg: Dominika',
    '🇩🇴' => 'Flagg: Dominikalýðveldið',
    '🇩🇿' => 'Flagg: Algeria',
    '🇪🇦' => 'Flagg: Ceuta & Melilla',
    '🇪🇨' => 'Flagg: Ekvador',
    '🇪🇪' => 'Flagg: Estland',
    '🇪🇬' => 'Flagg: Egyptaland',
    '🇪🇭' => 'Flagg: Vestursahara',
    '🇪🇷' => 'Flagg: Eritrea',
    '🇪🇸' => 'Flagg: Spania',
    '🇪🇹' => 'Flagg: Etiopia',
    '🇪🇺' => 'Flagg: Evropasamveldið',
    '🇫🇮' => 'Flagg: Finnland',
    '🇫🇯' => 'Flagg: Fiji',
    '🇫🇰' => 'Flagg: Falklandsoyggjar',
    '🇫🇲' => 'Flagg: Mikronesiasamveldið',
    '🇫🇴' => 'Flagg: Føroyar',
    '🇫🇷' => 'Flagg: Frakland',
    '🇬🇦' => 'Flagg: Gabon',
    '🇬🇧' => 'Flagg: Stórabretland',
    '🇬🇩' => 'Flagg: Grenada',
    '🇬🇪' => 'Flagg: Georgia',
    '🇬🇫' => 'Flagg: Franska Gujana',
    '🇬🇬' => 'Flagg: Guernsey',
    '🇬🇭' => 'Flagg: Gana',
    '🇬🇮' => 'Flagg: Gibraltar',
    '🇬🇱' => 'Flagg: Grønland',
    '🇬🇲' => 'Flagg: Gambia',
    '🇬🇳' => 'Flagg: Guinea',
    '🇬🇵' => 'Flagg: Guadeloupe',
    '🇬🇶' => 'Flagg: Ekvatorguinea',
    '🇬🇷' => 'Flagg: Grikkaland',
    '🇬🇸' => 'Flagg: Suðurgeorgia og Suðursandwichoyggjar',
    '🇬🇹' => 'Flagg: Guatemala',
    '🇬🇺' => 'Flagg: Guam',
    '🇬🇼' => 'Flagg: Guinea-Bissau',
    '🇬🇾' => 'Flagg: Gujana',
    '🇭🇰' => 'Flagg: Hong Kong SAR Kina',
    '🇭🇲' => 'Flagg: Heard og McDonaldoyggjar',
    '🇭🇳' => 'Flagg: Honduras',
    '🇭🇷' => 'Flagg: Kroatia',
    '🇭🇹' => 'Flagg: Haiti',
    '🇭🇺' => 'Flagg: Ungarn',
    '🇮🇨' => 'Flagg: Kanariuoyggjar',
    '🇮🇩' => 'Flagg: Indonesia',
    '🇮🇪' => 'Flagg: Írland',
    '🇮🇱' => 'Flagg: Ísrael',
    '🇮🇲' => 'Flagg: Isle of Man',
    '🇮🇳' => 'Flagg: India',
    '🇮🇴' => 'Flagg: Stóra Bretlands Indiahavoyggjar',
    '🇮🇶' => 'Flagg: Irak',
    '🇮🇷' => 'Flagg: Iran',
    '🇮🇸' => 'Flagg: Ísland',
    '🇮🇹' => 'Flagg: Italia',
    '🇯🇪' => 'Flagg: Jersey',
    '🇯🇲' => 'Flagg: Jamaika',
    '🇯🇴' => 'Flagg: Jordan',
    '🇯🇵' => 'Flagg: Japan',
    '🇰🇪' => 'Flagg: Kenja',
    '🇰🇬' => 'Flagg: Kirgisia',
    '🇰🇭' => 'Flagg: Kambodja',
    '🇰🇮' => 'Flagg: Kiribati',
    '🇰🇲' => 'Flagg: Komoroyggjar',
    '🇰🇳' => 'Flagg: St. Kitts & Nevis',
    '🇰🇵' => 'Flagg: Norðurkorea',
    '🇰🇷' => 'Flagg: Suðurkorea',
    '🇰🇼' => 'Flagg: Kuvait',
    '🇰🇾' => 'Flagg: Caymanoyggjar',
    '🇰🇿' => 'Flagg: Kasakstan',
    '🇱🇦' => 'Flagg: Laos',
    '🇱🇧' => 'Flagg: Libanon',
    '🇱🇨' => 'Flagg: St. Lusia',
    '🇱🇮' => 'Flagg: Liktinstein',
    '🇱🇰' => 'Flagg: Sri Lanka',
    '🇱🇷' => 'Flagg: Liberia',
    '🇱🇸' => 'Flagg: Lesoto',
    '🇱🇹' => 'Flagg: Litava',
    '🇱🇺' => 'Flagg: Luksemborg',
    '🇱🇻' => 'Flagg: Lettland',
    '🇱🇾' => 'Flagg: Libya',
    '🇲🇦' => 'Flagg: Marokko',
    '🇲🇨' => 'Flagg: Monako',
    '🇲🇩' => 'Flagg: Moldova',
    '🇲🇪' => 'Flagg: Montenegro',
    '🇲🇫' => 'Flagg: St-Martin',
    '🇲🇬' => 'Flagg: Madagaskar',
    '🇲🇭' => 'Flagg: Marshalloyggjar',
    '🇲🇰' => 'Flagg: Norður Makedónia',
    '🇲🇱' => 'Flagg: Mali',
    '🇲🇲' => 'Flagg: Myanmar (Burma)',
    '🇲🇳' => 'Flagg: Mongolia',
    '🇲🇴' => 'Flagg: Makao SAR Kina',
    '🇲🇵' => 'Flagg: Norðaru Mariuoyggjar',
    '🇲🇶' => 'Flagg: Martinique',
    '🇲🇷' => 'Flagg: Móritania',
    '🇲🇸' => 'Flagg: Montserrat',
    '🇲🇹' => 'Flagg: Malta',
    '🇲🇺' => 'Flagg: Móritius',
    '🇲🇻' => 'Flagg: Maldivoyggjar',
    '🇲🇼' => 'Flagg: Malavi',
    '🇲🇽' => 'Flagg: Meksiko',
    '🇲🇾' => 'Flagg: Malaisia',
    '🇲🇿' => 'Flagg: Mosambik',
    '🇳🇦' => 'Flagg: Namibia',
    '🇳🇨' => 'Flagg: Nýkaledónia',
    '🇳🇪' => 'Flagg: Niger',
    '🇳🇫' => 'Flagg: Norfolksoyggj',
    '🇳🇬' => 'Flagg: Nigeria',
    '🇳🇮' => 'Flagg: Nikaragua',
    '🇳🇱' => 'Flagg: Niðurlond',
    '🇳🇴' => 'Flagg: Noreg',
    '🇳🇵' => 'Flagg: Nepal',
    '🇳🇷' => 'Flagg: Nauru',
    '🇳🇺' => 'Flagg: Niue',
    '🇳🇿' => 'Flagg: Nýsæland',
    '🇴🇲' => 'Flagg: Oman',
    '🇵🇦' => 'Flagg: Panama',
    '🇵🇪' => 'Flagg: Peru',
    '🇵🇫' => 'Flagg: Franska Polynesia',
    '🇵🇬' => 'Flagg: Papua Nýguinea',
    '🇵🇭' => 'Flagg: Filipsoyggjar',
    '🇵🇰' => 'Flagg: Pakistan',
    '🇵🇱' => 'Flagg: Pólland',
    '🇵🇲' => 'Flagg: Saint Pierre & Miquelon',
    '🇵🇳' => 'Flagg: Pitcairnoyggjar',
    '🇵🇷' => 'Flagg: Puerto Riko',
    '🇵🇸' => 'Flagg: Palestinskt landøki',
    '🇵🇹' => 'Flagg: Portugal',
    '🇵🇼' => 'Flagg: Palau',
    '🇵🇾' => 'Flagg: Paraguai',
    '🇶🇦' => 'Flagg: Katar',
    '🇷🇪' => 'Flagg: Réunion',
    '🇷🇴' => 'Flagg: Rumenia',
    '🇷🇸' => 'Flagg: Serbia',
    '🇷🇺' => 'Flagg: Russland',
    '🇷🇼' => 'Flagg: Ruanda',
    '🇸🇦' => 'Flagg: Saudiarabia',
    '🇸🇧' => 'Flagg: Salomonoyggjar',
    '🇸🇨' => 'Flagg: Seyskelloyggjar',
    '🇸🇩' => 'Flagg: Sudan',
    '🇸🇪' => 'Flagg: Svøríki',
    '🇸🇬' => 'Flagg: Singapor',
    '🇸🇭' => 'Flagg: St. Helena',
    '🇸🇮' => 'Flagg: Slovenia',
    '🇸🇯' => 'Flagg: Svalbard & Jan Mayen',
    '🇸🇰' => 'Flagg: Slovakia',
    '🇸🇱' => 'Flagg: Sierra Leona',
    '🇸🇲' => 'Flagg: San Marino',
    '🇸🇳' => 'Flagg: Senegal',
    '🇸🇴' => 'Flagg: Somalia',
    '🇸🇷' => 'Flagg: Surinam',
    '🇸🇸' => 'Flagg: Suðursudan',
    '🇸🇹' => 'Flagg: Sao Tome & Prinsipi',
    '🇸🇻' => 'Flagg: El Salvador',
    '🇸🇽' => 'Flagg: Sint Maarten',
    '🇸🇾' => 'Flagg: Sýria',
    '🇸🇿' => 'Flagg: Esvatini',
    '🇹🇦' => 'Flagg: Tristan da Cunha',
    '🇹🇨' => 'Flagg: Turks- og Caicosoyggjar',
    '🇹🇩' => 'Flagg: Kjad',
    '🇹🇫' => 'Flagg: Fronsku sunnaru landaøki',
    '🇹🇬' => 'Flagg: Togo',
    '🇹🇭' => 'Flagg: Tailand',
    '🇹🇯' => 'Flagg: Tadsjikistan',
    '🇹🇰' => 'Flagg: Tokelau',
    '🇹🇱' => 'Flagg: Eysturtimor',
    '🇹🇲' => 'Flagg: Turkmenistan',
    '🇹🇳' => 'Flagg: Tunesia',
    '🇹🇴' => 'Flagg: Tonga',
    '🇹🇷' => 'Flagg: Turkaland',
    '🇹🇹' => 'Flagg: Trinidad & Tobago',
    '🇹🇻' => 'Flagg: Tuvalu',
    '🇹🇼' => 'Flagg: Taivan',
    '🇹🇿' => 'Flagg: Tansania',
    '🇺🇦' => 'Flagg: Ukraina',
    '🇺🇬' => 'Flagg: Uganda',
    '🇺🇲' => 'Flagg: Sambandsríki Amerikas fjarskotnu oyggjar',
    '🇺🇳' => 'Flagg: Sameindu Tjóðir',
    '🇺🇸' => 'Flagg: Sambandsríki Amerika',
    '🇺🇾' => 'Flagg: Uruguai',
    '🇺🇿' => 'Flagg: Usbekistan',
    '🇻🇦' => 'Flagg: Vatikanbýur',
    '🇻🇨' => 'Flagg: St. Vinsent & Grenadinoyggjar',
    '🇻🇪' => 'Flagg: Venesuela',
    '🇻🇬' => 'Flagg: Stóra Bretlands Jomfrúoyggjar',
    '🇻🇮' => 'Flagg: Sambandsríki Amerikas Jomfrúoyggjar',
    '🇻🇳' => 'Flagg: Vjetnam',
    '🇻🇺' => 'Flagg: Vanuatu',
    '🇼🇫' => 'Flagg: Wallis- og Futunaoyggjar',
    '🇼🇸' => 'Flagg: Samoa',
    '🇽🇰' => 'Flagg: Kosovo',
    '🇾🇪' => 'Flagg: Jemen',
    '🇾🇹' => 'Flagg: Mayotte',
    '🇿🇦' => 'Flagg: Suðurafrika',
    '🇿🇲' => 'Flagg: Sambia',
    '🇿🇼' => 'Flagg: Simbabvi',
    '🔟' => 'Knappahetta: 10',
    '🏻' => 'ljósur húðarlitur',
    '🏼' => 'miðalljósur húðarlitur',
    '🏽' => 'miðal húðarlitur',
    '🏾' => 'miðalmyrkur húðarlitur',
    '🏿' => 'myrkur húðarlitur',
    '😀' => 'grínandi andlit',
    '😃' => 'grínandi andlit við stórum eygum',
    '😄' => 'grínandi andlit við brosandi eygum',
    '😁' => 'strálandi andlit við brosandi eygum',
    '😆' => 'grínandi andlit við krympaðum eygum',
    '😅' => 'grínandi andlit við sveitta',
    '🤣' => 'tárandi flennandi andlit',
    '😂' => 'andlit við gleðistárum',
    '🙂' => 'andlit ið smílur eitt sindur',
    '🙃' => 'andlit ið vendur á høvdinum',
    '🫠' => 'smelta andlit',
    '😉' => 'andlit við blunkandi eyga',
    '😊' => 'brosandi andlit við brosandi eygum',
    '😇' => 'brosandi andlit við halgiboga',
    '🥰' => 'smílandi andlit við hjørtum',
    '😍' => 'smílandi andlit við hjarta eygum',
    '🤩' => 'stjørnuandlit',
    '😘' => 'andlit ið sendur hjarta koss',
    '😗' => 'mussandi andlit',
    '☺' => 'brosandi andlit',
    '😚' => 'mussandi andlit við afturlatnum eygum',
    '😙' => 'mussandi andlit við brosandi eygum',
    '🥲' => 'smílandi andlit ið tárar',
    '😋' => 'andlit við matarlystið',
    '😛' => 'gálvandi andlit',
    '😜' => 'gálvandi andlit við blunkandi eyga',
    '🤪' => 'svakt andlit',
    '😝' => 'gálvandi andlit við krympaðum eygum',
    '🤑' => 'peningaandlit',
    '🤗' => 'klemmandi andlit',
    '🤭' => 'andlit við hond yvir munnin',
    '🫢' => 'andlit við opnum eygum og við hond yvir munnin',
    '🫣' => 'lúrandi andlit',
    '🤫' => 'hússjandi andlit',
    '🤔' => 'hugsandi andlit',
    '🫡' => 'heilsandi andlit',
    '🤐' => 'lýnlás andlit',
    '🤨' => 'andlit við upplyftum eygnabrúni',
    '😐' => 'nevtralt andlit',
    '😑' => 'kensluleyst andlit',
    '😶' => 'andlit uttan munn',
    '🫥' => 'prikka andlit',
    '😏' => 'lúrt andlit',
    '😒' => 'ikki stuttligt andlit',
    '🙄' => 'andlit við rullandi eygum',
    '😬' => 'andlit ið vísur tenn',
    '🤥' => 'andlit sum lýgur',
    '🫨' => 'skelvandi andlit',
    '😌' => 'lætna andlit',
    '😔' => 'grundandi andlit',
    '😪' => 'lint andlit',
    '🤤' => 'slevandi andlit',
    '😴' => 'sovandi andlit',
    '🫩' => 'andlit við posum undir eygunum',
    '😷' => 'andlit við masku',
    '🤒' => 'andlit við fepurstokkið',
    '🤕' => 'andlit við bind um høvdið',
    '🤢' => 'andlit ið vil spýggja',
    '🤮' => 'spýggjandi andlit',
    '🤧' => 'njósandi andlit',
    '🥵' => 'heitt andlit',
    '🥶' => 'kalt andlit',
    '🥴' => 'í ørviti andlit',
    '😵' => 'svimbult andlit',
    '🤯' => 'andlit í brestur',
    '🤠' => 'andlit við cowboyhatti',
    '🥳' => 'veitslu andlit',
    '🥸' => 'grýlu andlit',
    '😎' => 'smílandi andlit við sólbrillum',
    '🤓' => 'nørd andlit',
    '🧐' => 'andlit við einglesi',
    '😕' => 'forvirra andlit',
    '🫤' => 'ivingarsamt andlit',
    '😟' => 'stúrt andlit',
    '🙁' => 'eitt sindur illbrýnt andlit',
    '☹' => 'illbrýnt andlit',
    '😮' => 'andlit við opnum munni',
    '😯' => 'bilsi andlit',
    '😲' => 'ovfari andlit',
    '😳' => 'rodna andlit',
    '🥺' => 'biðjandi andlit',
    '🥹' => 'andlit við gleðitárum',
    '😦' => 'skelka andlit',
    '😧' => 'pínt andlit',
    '😨' => 'bangi andlit',
    '😰' => 'bangi andlit við sveitta',
    '😥' => 'sorgarbundi andlit og tár',
    '😢' => 'andlit ið grætur',
    '😭' => 'andlit sum grætur nógv',
    '😱' => 'skríggjandi andlit',
    '😖' => 'sera illbrýnt andlit',
    '😣' => 'ágrýti andlit',
    '😞' => 'skuffa andlit',
    '😓' => 'sveittandi andlit ið hyggur niðureftir',
    '😩' => 'pøst andlit',
    '😫' => 'troytt andlit',
    '🥱' => 'geispandi andlit',
    '😤' => 'andlit við royki úr nøsuni',
    '😡' => 'sera hóttandi andlit',
    '😠' => 'hóttandi andlit',
    '🤬' => 'bannandi andlit',
    '😈' => 'brosandi andlit við hornum',
    '👿' => 'hóttandi andlit við hornum',
    '💀' => 'skøltur',
    '☠' => 'skøltur og krossleggir',
    '💩' => 'kukkur',
    '🤡' => 'klovn andlit',
    '👹' => 'skrímsl',
    '👺' => 'vættur',
    '👻' => 'gálvandi spøkilsi',
    '👽' => 'rúmdarvera',
    '👾' => 'rúmdarvera skrímsl',
    '🤖' => 'robottandlit',
    '😺' => 'brosandi kettuandlit',
    '😸' => 'brosandi kettuandlit við smílandi eygum',
    '😹' => 'kettuandlit sum fellur gleðist´´ár',
    '😻' => 'brosandi kettuandlit við hjartaeygum',
    '😼' => 'kettuandlit við speiskum smíli',
    '😽' => 'mussandi kettuandlit',
    '🙀' => 'bilsi kettuandlit',
    '😿' => 'grátandi kettuandlit',
    '😾' => 'kettuandlit við gron',
    '🙈' => 'apuandlit við hondunum yvir eygunum',
    '🙉' => 'apuandlit við hondunum yvir oyrunum',
    '🙊' => 'apuandlit við hondunum yvir munninum',
    '💌' => 'kærleiksbræv',
    '💘' => 'pílur ígjøgnum hjarta',
    '💝' => 'hjarta við bandi',
    '💖' => 'glitrandi hjarta',
    '💗' => 'glógvandi hjarta',
    '💓' => 'bankandi hjarta',
    '💞' => 'hjørtu sum mela í klingur',
    '💕' => 'tvey hjørtu',
    '💟' => 'hjarta pynt',
    '❣' => 'hjarta rópitekn',
    '💔' => 'brotið hjarta',
    '❤' => 'reytt hjarta',
    '🩷' => 'ljósareytt hjarta',
    '🧡' => 'appilsingult hjarta',
    '💛' => 'gult hjarta',
    '💚' => 'grønt hjarta',
    '💙' => 'blátt hjarta',
    '🩵' => 'ljósablátt hjarta',
    '💜' => 'korkalitt hjarta',
    '🤎' => 'brúnt hjarta',
    '🖤' => 'svart hjarta',
    '🩶' => 'grátt hjarta',
    '🤍' => 'hvítt hjarta',
    '💋' => 'muss merki',
    '💯' => 'hundrað stig',
    '💢' => 'vreiði tekin',
    '💥' => 'samanstoytur',
    '💫' => 'svimbul',
    '💦' => 'dropar',
    '💨' => 'fok',
    '🕳' => 'hol',
    '💬' => 'talubløðra',
    '🗨' => 'svørt talubløðra',
    '🗯' => 'átalandi talubløðra',
    '💭' => 'tankabløðra',
    '💤' => 'zzz',
    '👋' => 'veitrandi hond',
    '🤚' => 'handarbak',
    '🖐' => 'fimm fingrar',
    '✋' => 'hond',
    '🖖' => 'vulkan heilsan',
    '🫱' => 'hond til høgru',
    '🫲' => 'hond til vinstru',
    '🫳' => 'lógvi niðureftir',
    '🫴' => 'lógvi uppeftir',
    '🫷' => 'hond skumpar til vinstru',
    '🫸' => 'hond skumpar til høgru',
    '👌' => 'ok tekin',
    '🤌' => 'samlaðir fingrar',
    '🤏' => 'fingrar sum vísa ikki nógv',
    '✌' => 'sigurstekin',
    '🤞' => 'krossaðir fingrar',
    '🫰' => 'krossa tummil og peikifingur',
    '🤟' => 'kærleikshandabragd',
    '🤘' => 'horntekin',
    '🤙' => 'telefontekin',
    '👈' => 'fremstifingur peikar til vinstru',
    '👉' => 'fremstifingur peikar til høgru',
    '👆' => 'fremstifingur peikar uppeftir',
    '🖕' => 'longutong peikar uppeftir',
    '👇' => 'longutong peikar niðureftir',
    '☝' => 'lógvi og fremstifingur peikar uppeftir',
    '🫵' => 'peikar eftir tær',
    '👍' => 'tummil upp',
    '👎' => 'tummil niður',
    '✊' => 'knýttur nevi',
    '👊' => 'sláandi knýttur nevi',
    '🤛' => 'nevi í vendur til vinstru',
    '🤜' => 'nevi í vendur til høgru',
    '👏' => 'klappandi hendur',
    '🙌' => 'upplyftar hendur',
    '🫶' => 'hjarta hendur',
    '👐' => 'opnar hendur',
    '🤲' => 'lógvar sum eru saman',
    '🤝' => 'lógvatak',
    '🙏' => 'falda hendur',
    '✍' => 'skrivandi hond',
    '💅' => 'neglalakk',
    '🤳' => 'sjálvsmynd',
    '💪' => 'spentur biseps',
    '🦾' => 'kunstigur armur',
    '🦿' => 'kunstigt bein',
    '🦵' => 'bein',
    '🦶' => 'fótur',
    '👂' => 'oyra',
    '🦻' => 'oyra við hoyritólið',
    '👃' => 'nøs',
    '🧠' => 'heili',
    '🫀' => 'hjarta',
    '🫁' => 'lungur',
    '🦷' => 'tonn',
    '🦴' => 'kjøtbein',
    '👀' => 'eygu',
    '👁' => 'eyga',
    '👅' => 'tunga',
    '👄' => 'munnur',
    '🫦' => 'bíta í vørruna',
    '👶' => 'pinkubarn',
    '🧒' => 'barn',
    '👦' => 'drongur',
    '👧' => 'genta',
    '🧑' => 'persónur',
    '👱' => 'ljóshærdur persónur',
    '👨' => 'maður',
    '🧔' => 'persónur við skeggi',
    '👩' => 'kona',
    '🧓' => 'tilkomin',
    '👴' => 'gamal maður',
    '👵' => 'gomul kona',
    '🙍' => 'illbrýntur persónur',
    '🙎' => 'persónur við gron',
    '🙅' => 'persónur sum veipar nei',
    '🙆' => 'persónur sum veipar ok',
    '💁' => 'persónur sum nertir við',
    '🙋' => 'persónur sum lyftur hondina upp',
    '🧏' => 'deyvur persónur',
    '🙇' => 'persónur sum bukkar',
    '🤦' => 'vónbrotin persónur',
    '🤷' => 'persónur sum yppur øksl',
    '👮' => 'politistur',
    '🕵' => 'detektivur',
    '💂' => 'vaktur',
    '🥷' => 'ninja andlit',
    '👷' => 'byggiverkfrøðingur',
    '🫅' => 'persónur við krúnu',
    '🤴' => 'prinsur',
    '👸' => 'prinsessa',
    '👳' => 'persónur við turban',
    '👲' => 'persónur við kinesiskari húgvu',
    '🧕' => 'kvinna við turriklæði',
    '🤵' => 'persónur í smoking',
    '👰' => 'persónur í sløri',
    '🤰' => 'kvinna við barn',
    '🫃' => 'maður við barn',
    '🫄' => 'persónur við barn',
    '🤱' => 'geva bróst',
    '👼' => 'pinkabarnaeingil',
    '🎅' => 'jólamaðurin',
    '🤶' => 'jólakonan',
    '🦸' => 'superhetja',
    '🦹' => 'superskálkur',
    '🧙' => 'persónur sum dugir gand',
    '🧚' => 'álva',
    '🧛' => 'vampýrur',
    '🧜' => 'havfólk',
    '🧝' => 'álvur',
    '🧞' => 'andi',
    '🧟' => 'sombi',
    '🧌' => 'trøll',
    '💆' => 'persónur sum fær massasju',
    '💇' => 'persónur sum fær klipt hári',
    '🚶' => 'persónur sum gongur',
    '🧍' => 'persónur ið stendur',
    '🧎' => 'persónur á knæ',
    '🏃' => 'persónur sum rennur',
    '💃' => 'kvinna sum dansar',
    '🕺' => 'maður sum dansar',
    '🕴' => 'maður í klædningi sveimar',
    '👯' => 'fólk við haruoyrum',
    '🧖' => 'persónur í sauna',
    '🧗' => 'persónur sum klatrar',
    '🤺' => 'fektari',
    '🏇' => 'kappríðing',
    '⛷' => 'skíðrennari',
    '🏂' => 'persónur sum stendur á snjófjøl',
    '🏌' => 'persónur sum spælir golf',
    '🏄' => 'persónur sum skreiður á brimfjøl',
    '🚣' => 'persónur í árabáti',
    '🏊' => 'persónur sum svimur',
    '⛹' => 'persónur sum spælir kurvabólt',
    '🏋' => 'vektlyftari',
    '🚴' => 'persónur sum súkklar',
    '🚵' => 'persónur á fjallasúkklu',
    '🤸' => 'persónur sum ger myllulop',
    '🤼' => 'glímingardystur',
    '🤽' => 'persónur sum spælir vatnpolo',
    '🤾' => 'persónur sum spælir hondbólt',
    '🤹' => 'persónur sum fimlar',
    '🧘' => 'persónur í lotusstøðu',
    '🛀' => 'persónur í baðikari',
    '🛌' => 'persónur í song',
    '👭' => 'kvinnur leiðast',
    '👫' => 'kvinna or maður leiðast',
    '👬' => 'menn leiðast',
    '💏' => 'tvey íð mussast',
    '💑' => 'par og hjarta',
    '🗣' => 'høvd sum prátar',
    '👤' => 'skuggamynd av bringumynd',
    '👥' => 'skuggamynd av bringumyndum',
    '🫂' => 'fólk sum klemmast',
    '👪' => 'familja',
    '👣' => 'fótaspor',
    '🫆' => 'fingramerki',
    '🦰' => 'reytt hár',
    '🦱' => 'purlut hár',
    '🦳' => 'hvítt hár',
    '🦲' => 'skallutur',
    '🐵' => 'apuandlit',
    '🐒' => 'apa',
    '🦍' => 'gorilla',
    '🦧' => 'orangutang',
    '🐶' => 'hundaandlit',
    '🐕' => 'hundur',
    '🦮' => 'førarahundur',
    '🐩' => 'puddilhundur',
    '🐺' => 'úlvur',
    '🦊' => 'revaandlit',
    '🦝' => 'tváttarbjørn',
    '🐱' => 'kettuandlit',
    '🐈' => 'ketta',
    '🦁' => 'leyvuandlit',
    '🐯' => 'tikaraandlit',
    '🐅' => 'tikari',
    '🐆' => 'leopardur',
    '🐴' => 'rossaandlit',
    '🫎' => 'elgsdýr',
    '🫏' => 'esil',
    '🐎' => 'hestur',
    '🦄' => 'einhyrningaandlit',
    '🦓' => 'sebra',
    '🦌' => 'hjørtur',
    '🦬' => 'bisonur',
    '🐮' => 'kúgvaandlit',
    '🐂' => 'oksi',
    '🐃' => 'búffil',
    '🐄' => 'kúgv',
    '🐷' => 'grísaandlit',
    '🐖' => 'grísur',
    '🐗' => 'villsvínaandlit',
    '🐽' => 'grísasnúti',
    '🐏' => 'veðrur',
    '🐑' => 'ær',
    '🐐' => 'geit',
    '🐪' => 'dromedárur',
    '🐫' => 'kamelur',
    '🦙' => 'lama',
    '🦒' => 'giraffur',
    '🐘' => 'fílur',
    '🦣' => 'mammuttur',
    '🦏' => 'nashyrningur',
    '🦛' => 'áarross',
    '🐭' => 'músaandlit',
    '🐁' => 'mús',
    '🐀' => 'rotta',
    '🐹' => 'hamstaraandlit',
    '🐰' => 'kaninandlit',
    '🐇' => 'kanin',
    '🐿' => 'jarðaríkorn',
    '🦫' => 'bævur',
    '🦔' => 'tindasvín',
    '🦇' => 'flogmús',
    '🐻' => 'bjarnarandlit',
    '🐨' => 'koalaandlit',
    '🐼' => 'pandaandlit',
    '🦥' => 'letidýr',
    '🦦' => 'otur',
    '🦨' => 'stinkdýr',
    '🦘' => 'kenguru',
    '🦡' => 'grevlingur',
    '🐾' => 'labbaspor',
    '🦃' => 'kalkun',
    '🐔' => 'hønuandlit',
    '🐓' => 'hani',
    '🐣' => 'høsnarungi í eggjaskali',
    '🐤' => 'høsnarungaandlit',
    '🐥' => 'høsnarungi',
    '🐦' => 'fuglaandlit',
    '🐧' => 'pingvinandlit',
    '🕊' => 'dúgva við oljugrein',
    '🦅' => 'ørn',
    '🦆' => 'dunna',
    '🦢' => 'svanur',
    '🦉' => 'ugla',
    '🦤' => 'dronta',
    '🪶' => 'fjøður',
    '🦩' => 'flamingo',
    '🦚' => 'páfuglur',
    '🦜' => 'pappageykur',
    '🪽' => 'vongur',
    '🪿' => 'gás',
    '🐸' => 'froskaandlit',
    '🐊' => 'krokodilla',
    '🐢' => 'skjaldbøka',
    '🦎' => 'oydla',
    '🐍' => 'slanga',
    '🐲' => 'andlit á dreka',
    '🐉' => 'dreki',
    '🦕' => 'Brontosaurus',
    '🦖' => 'T-rex',
    '🐳' => 'hvalur sum sprænur',
    '🐋' => 'hvalur',
    '🐬' => 'delfin',
    '🦭' => 'kópur',
    '🐟' => 'fiskur',
    '🐠' => 'tropiskur fiskur',
    '🐡' => 'ígulfiskur',
    '🦈' => 'hávur',
    '🐙' => 'høgguslokkur við átta ørmum',
    '🐚' => 'skel',
    '🪸' => 'korallur',
    '🪼' => 'hvalspýggja',
    '🦀' => 'krabbi',
    '🦞' => 'hummari',
    '🦐' => 'rækja',
    '🦑' => 'høgguslokkur',
    '🦪' => 'ostra',
    '🐌' => 'snigil',
    '🦋' => 'firvaldur',
    '🐛' => 'skordýr',
    '🐜' => 'meyra',
    '🐝' => 'býfluga',
    '🪲' => 'klukka',
    '🐞' => 'mariubjalla',
    '🦗' => 'veggjasmiður',
    '🪳' => 'kakkulakkur',
    '🕷' => 'eiturkoppur',
    '🕸' => 'eiturkoppanót',
    '🦂' => 'skorpión',
    '🦟' => 'mýggjabiti',
    '🪰' => 'fluga',
    '🪱' => 'maðkur',
    '🦠' => 'smávera',
    '💐' => 'blómutyssi',
    '🌸' => 'kirsuberblóma',
    '💮' => 'hvít blóma',
    '🪷' => 'nyksblóma',
    '🏵' => 'rósuprýði',
    '🌹' => 'rósa',
    '🥀' => 'følna blóma',
    '🌺' => 'hawaiiblóma',
    '🌻' => 'sólblóma',
    '🌼' => 'blóma',
    '🌷' => 'tulipán',
    '🪻' => 'hýasint',
    '🌱' => 'fræplanta',
    '🪴' => 'urtapottur',
    '🌲' => 'veturgrønt træ',
    '🌳' => 'træ sum fellir bløðini',
    '🌴' => 'plámatræ',
    '🌵' => 'kaktus',
    '🌾' => 'ríshólgi',
    '🌿' => 'urt',
    '☘' => 'smæra',
    '🍀' => 'smæra við fýra',
    '🍁' => 'ahornsblað',
    '🍂' => 'fallið blað',
    '🍃' => 'flagsandi bløð',
    '🪹' => 'tómt reiður',
    '🪺' => 'reiður við eggum',
    '🍄' => 'soppur',
    '🪾' => 'blaðleyst træ',
    '🍇' => 'víndrúvur',
    '🍈' => 'melón',
    '🍉' => 'vatnmelón',
    '🍊' => 'mandarin',
    '🍋' => 'sitrón',
    '🍌' => 'banan',
    '🍍' => 'ananas',
    '🥭' => 'mangofrukt',
    '🍎' => 'reytt súrepli',
    '🍏' => 'grønt súrepli',
    '🍐' => 'pera',
    '🍑' => 'ferska',
    '🍒' => 'kirsuber',
    '🍓' => 'jarðber',
    '🫐' => 'bláber',
    '🥝' => 'kivi',
    '🍅' => 'tomat',
    '🫒' => 'oljuber',
    '🥥' => 'kokusnøt',
    '🥑' => 'avokado',
    '🍆' => 'aubergina',
    '🥔' => 'epli',
    '🥕' => 'gularót',
    '🌽' => 'maiskolba',
    '🌶' => 'sterkt pipar',
    '🫑' => 'piparfrukt',
    '🥒' => 'agurk',
    '🥬' => 'salatblað',
    '🥦' => 'brokkoli',
    '🧄' => 'hvítleykur',
    '🧅' => 'leykur',
    '🥜' => 'jarðnøtur',
    '🫘' => 'bønur',
    '🌰' => 'kastanja',
    '🫚' => 'ingifer',
    '🫛' => 'ertnabjølg',
    '🫜' => 'rótfrukt',
    '🍞' => 'breyð',
    '🥐' => 'horn',
    '🥖' => 'flute',
    '🫓' => 'flatbreyð',
    '🥨' => 'saltkringla',
    '🥯' => 'bagel',
    '🥞' => 'pannukaka',
    '🧇' => 'vafla',
    '🧀' => 'osta stykki',
    '🍖' => 'kjøt á beini',
    '🍗' => 'høsnaungalær',
    '🥩' => 'kotelett',
    '🥓' => 'flesk',
    '🍔' => 'burgari',
    '🍟' => 'kips',
    '🍕' => 'pitsaflís',
    '🌭' => 'hotdog',
    '🥪' => 'tvíflís',
    '🌮' => 'tako',
    '🌯' => 'burrito',
    '🫔' => 'tamales',
    '🥙' => 'fylt flatbreyð',
    '🧆' => 'falafel',
    '🥚' => 'egg',
    '🍳' => 'matgerð',
    '🥘' => 'grýturættur',
    '🍲' => 'djúpur tallerkur við mati',
    '🫕' => 'fondue',
    '🥣' => 'bolli við skeið',
    '🥗' => 'salat',
    '🍿' => 'poppkorn',
    '🧈' => 'smør',
    '🧂' => 'salt',
    '🥫' => 'dósamatur',
    '🍱' => 'bento matpakki',
    '🍘' => 'ríssmákaka',
    '🍙' => 'rísbolli',
    '🍚' => 'kókarís',
    '🍛' => 'karryrís',
    '🍜' => 'nudlur',
    '🍝' => 'spaghetti',
    '🍠' => 'søtt epli',
    '🍢' => 'matpinnur',
    '🍣' => 'sushi',
    '🍤' => 'steikt rækja',
    '🍥' => 'kamaboko',
    '🥮' => 'mánakaka',
    '🍡' => 'dango',
    '🥟' => 'hveitibolli',
    '🥠' => 'eydnukaka',
    '🥡' => 'tak við heim boks',
    '🍦' => 'kramarhúsísur',
    '🍧' => 'ísur í skál',
    '🍨' => 'rómaísur í skál',
    '🍩' => 'berlinarbolli',
    '🍪' => 'smákaka',
    '🎂' => 'føðingardagskaka',
    '🍰' => 'kakustykki',
    '🧁' => 'koppakaka',
    '🥧' => 'pai',
    '🍫' => 'sjokulátapláta',
    '🍬' => 'bomm',
    '🍭' => 'sleikisneis',
    '🍮' => 'lagkøka',
    '🍯' => 'hunangur',
    '🍼' => 'boppufløska',
    '🥛' => 'glas av mjólk',
    '☕' => 'heitur drykkur',
    '🫖' => 'tekanna',
    '🍵' => 'koppur uttan handtak',
    '🍶' => 'sake',
    '🍾' => 'fløska við tundurproppi',
    '🍷' => 'vínglas',
    '🍸' => 'vínblandglas',
    '🍹' => 'tropiskurdrykkur',
    '🍺' => 'ølkrúss',
    '🍻' => 'ølkrúss sum skála',
    '🥂' => 'gløs sum skála',
    '🥃' => 'whiskyglas',
    '🫗' => 'stoyta niður',
    '🥤' => 'koppur við súgvirøri',
    '🧋' => 'boba te',
    '🧃' => 'sunkist',
    '🧉' => 'mate',
    '🧊' => 'ísterningur',
    '🥢' => 'etingarpinnar',
    '🍽' => 'gaffil knívur og talerkur',
    '🍴' => 'gaffil og knívur',
    '🥄' => 'skeið',
    '🔪' => 'køksknívur',
    '🫙' => 'glas',
    '🏺' => 'amfora',
    '🌍' => 'globus har Evropa og Afrika síggjast',
    '🌎' => 'globus har Amerika sæst',
    '🌏' => 'globus har Asia og Avstralia síggjast',
    '🌐' => 'globus við longdarstigum',
    '🗺' => 'verðinskort',
    '🗾' => 'kort av Japan',
    '🧭' => 'kumpass',
    '🏔' => 'fjall við kava á toppinum',
    '⛰' => 'fjall',
    '🌋' => 'gosfjall',
    '🗻' => 'fuji',
    '🏕' => 'tjaldstaður',
    '🏖' => 'sólskjól á strond',
    '🏜' => 'oyðimørk',
    '🏝' => 'oyðin oyggj',
    '🏞' => 'tjóðarpark',
    '🏟' => 'ítróttastaður',
    '🏛' => 'klassiskur bygningur',
    '🏗' => 'byggipláss',
    '🧱' => 'múrsteinur',
    '🪨' => 'steinur',
    '🪵' => 'viður',
    '🛖' => 'smátta',
    '🏘' => 'fleiri hús',
    '🏚' => 'vanrøkt hús',
    '🏠' => 'hús',
    '🏡' => 'hús við hava',
    '🏢' => 'skrivstovubygningur',
    '🏣' => 'japanskt posthús',
    '🏤' => 'posthús',
    '🏥' => 'sjúkrahús',
    '🏦' => 'banki',
    '🏨' => 'hotell',
    '🏩' => 'kærleikshotell',
    '🏪' => 'nærhandil',
    '🏫' => 'skúli',
    '🏬' => 'vøruhús',
    '🏭' => 'verksmiðja',
    '🏯' => 'japanskt slott',
    '🏰' => 'slott',
    '💒' => 'brúdleypshús',
    '🗼' => 'torn í Tokyo',
    '🗽' => 'Frælsisgudinnan',
    '⛪' => 'kirkja',
    '🕌' => 'moska',
    '🛕' => 'hinduitempul',
    '🕍' => 'synagoga',
    '⛩' => 'shinto altar',
    '🕋' => 'Kaaba',
    '⛲' => 'gosvatn',
    '⛺' => 'tjald',
    '🌁' => 'fjallatoppur og mjørki',
    '🌃' => 'nátt við stjørnum',
    '🏙' => 'stórbýur',
    '🌄' => 'sólarris ímillum fjøll',
    '🌅' => 'sólarris',
    '🌆' => 'skýming í stórbýi',
    '🌇' => 'sólsetur',
    '🌉' => 'brúgv á nátt',
    '♨' => 'heit kelda',
    '🎠' => 'karusellhestur',
    '🛝' => 'glíðibreyt',
    '🎡' => 'parísarhjól',
    '🎢' => 'russjibani',
    '💈' => 'hárskeraskelti',
    '🎪' => 'sirkustjald',
    '🚂' => 'lokomotiv',
    '🚃' => 'jarnbreytarvognur',
    '🚄' => 'háferðartok',
    '🚅' => 'snartok',
    '🚆' => 'tok',
    '🚇' => 'undirgrundarbreyt',
    '🚈' => 'nærtok',
    '🚉' => 'jarnbreytarstøð',
    '🚊' => 'gron á sporvogni',
    '🚝' => 'einsporað jarnbreyt',
    '🚞' => 'fjallajarnbreyt',
    '🚋' => 'sporvognur',
    '🚌' => 'bussur',
    '🚍' => 'gron á bussi',
    '🚎' => 'tráðbussur',
    '🚐' => 'minibussur',
    '🚑' => 'sjúkrabilur',
    '🚒' => 'sløkkibilur',
    '🚓' => 'løgreglubilur',
    '🚔' => 'gron á løgreglubili',
    '🚕' => 'taxabilur',
    '🚖' => 'gron á taxabili',
    '🚗' => 'bilur',
    '🚘' => 'bilgron',
    '🚙' => 'húsbilur',
    '🛻' => 'opin vørubilur',
    '🚚' => 'vøruvognur',
    '🚛' => 'liðlastbilur',
    '🚜' => 'traktorur',
    '🏎' => 'rasarabilur',
    '🏍' => 'motorsúkkla',
    '🛵' => 'skutari',
    '🦽' => 'koyristólur',
    '🦼' => 'motorkoyristólur',
    '🛺' => 'motor rickshaw',
    '🚲' => 'súkkla',
    '🛴' => 'rennihjól',
    '🛹' => 'rennifjøl',
    '🛼' => 'rulluskoyta',
    '🚏' => 'busssteðgipláss',
    '🛣' => 'motorvegur',
    '🛤' => 'jarnbreyt',
    '🛢' => 'oljutunna',
    '⛽' => 'brennievnispumpa',
    '🛞' => 'hjól',
    '🚨' => 'blunkljós',
    '🚥' => 'vatnrætt ferðsluljós',
    '🚦' => 'ferðsluljós',
    '🛑' => 'stoppskelti',
    '🚧' => 'byrging',
    '⚓' => 'akker',
    '🛟' => 'bjargingarringur',
    '⛵' => 'seglbátur',
    '🛶' => 'kano',
    '🚤' => 'rasarabátur',
    '🛳' => 'ferðamannaskip',
    '⛴' => 'ferja',
    '🛥' => 'maskinbátur',
    '🚢' => 'skip',
    '✈' => 'flogfar',
    '🛩' => 'lítið flogfar',
    '🛫' => 'farandi flogfar',
    '🛬' => 'komandi flogfar',
    '🪂' => 'fallskíggi',
    '💺' => 'setur',
    '🚁' => 'tyrla',
    '🚟' => 'heingijarnbreyt',
    '🚠' => 'fjallarennistrongur',
    '🚡' => 'rennistrongur',
    '🛰' => 'fylgisveinur',
    '🚀' => 'rakett',
    '🛸' => 'flúgvandi diskur',
    '🛎' => 'piccoloklokka',
    '🧳' => 'viðføri',
    '⌛' => 'runnið tímaglas',
    '⏳' => 'hálvrunnið tímaglas',
    '⌚' => 'ur',
    '⏰' => 'vekjari',
    '⏱' => 'stoppur',
    '⏲' => 'eggjaur',
    '🕰' => 'eldstaðarhillklokka',
    '🕛' => 'klokkan tólv',
    '🕧' => 'hálvgun eitt',
    '🕐' => 'klokkan eitt',
    '🕜' => 'hálvgun tvey',
    '🕑' => 'klokkan tvey',
    '🕝' => 'hálvgun trý',
    '🕒' => 'klokkan trý',
    '🕞' => 'hálvgun fýra',
    '🕓' => 'klokkan fýra',
    '🕟' => 'hálvgun fimm',
    '🕔' => 'klokkan fimm',
    '🕠' => 'hálvgun seks',
    '🕕' => 'klokkan seks',
    '🕡' => 'hálvgun sjey',
    '🕖' => 'klokkan sjey',
    '🕢' => 'hálvgun átta',
    '🕗' => 'klokkan átta',
    '🕣' => 'hálvgun níggju',
    '🕘' => 'klokkan níggju',
    '🕤' => 'hálvgun tíggju',
    '🕙' => 'klokkan tíggju',
    '🕥' => 'hálvgun ellivu',
    '🕚' => 'klokkan ellivu',
    '🕦' => 'hálvgun tólv',
    '🌑' => 'nýmáni',
    '🌒' => 'lítil vaksandi hálvmáni',
    '🌓' => 'vaksandi hálvmáni',
    '🌔' => 'stórur vaksandi hálvmáni',
    '🌕' => 'fullmáni',
    '🌖' => 'stórur minkandi hálvmáni',
    '🌗' => 'minkandi hálvmáni',
    '🌘' => 'lítil minkandi hálvmáni',
    '🌙' => 'hálvmáni',
    '🌚' => 'andlit á nýmána',
    '🌛' => 'andlit á vaksandi mána',
    '🌜' => 'andlit á minkandi mána',
    '🌡' => 'termometur',
    '☀' => 'sól',
    '🌝' => 'andlit á fullmána',
    '🌞' => 'andlit á sól',
    '🪐' => 'gongustjørna við ringi',
    '⭐' => 'hvit og gul stjørna',
    '🌟' => 'glógvandi stjørna',
    '🌠' => 'stjørnuskot',
    '🌌' => 'vetrarbreytin',
    '☁' => 'skýggj',
    '⛅' => 'sólin aftanfyri skyggj',
    '⛈' => 'skýggj við regni og snarljósi',
    '🌤' => 'sólin aftanfyri eitt lítið skýggj',
    '🌥' => 'sólin aftanfyri eitt stórt skýggj',
    '🌦' => 'sólin aftanfyri eitt regnskýggj',
    '🌧' => 'skýggj og regn',
    '🌨' => 'skýggj og kavi',
    '🌩' => 'skýggj og snarljós',
    '🌪' => 'melduródn',
    '🌫' => 'mjørki',
    '🌬' => 'andlit sum blæsur vind',
    '🌀' => 'meldurhvirla',
    '🌈' => 'ælabogi',
    '🌂' => 'afturlatin paraplý',
    '☂' => 'paraplý',
    '☔' => 'paraplý og regndropar',
    '⛱' => 'sólskjól',
    '⚡' => 'snarljós',
    '❄' => 'kavaflykra',
    '☃' => 'kavamaður',
    '⛄' => 'kavamaður við hatti',
    '☄' => 'komet',
    '🔥' => 'eldur',
    '💧' => 'dropi',
    '🌊' => 'alda',
    '🎃' => 'graskarhøvd',
    '🎄' => 'jólatræ',
    '🎆' => 'fýrverk',
    '🎇' => 'stjørnukastari',
    '🧨' => 'kinesari',
    '✨' => 'neistafok',
    '🎈' => 'ballón',
    '🎉' => 'borðbumba',
    '🎊' => 'konfetti',
    '🎋' => 'tanabata træ',
    '🎍' => 'kadomatsu',
    '🎎' => 'japanskar dukkur',
    '🎏' => 'Koinobori',
    '🎐' => 'vindharpa',
    '🎑' => 'tsukimi',
    '🧧' => 'reyður brævbjálvi',
    '🎀' => 'band',
    '🎁' => 'gáva',
    '🎗' => 'eftirtektarband',
    '🎟' => 'atgongumerki',
    '🎫' => 'farseðil',
    '🎖' => 'hernaðarmedalja',
    '🏆' => 'steyp',
    '🏅' => 'ítróttamedalja',
    '🥇' => 'gullmedalja',
    '🥈' => 'silvurmedalja',
    '🥉' => 'bronsumedalja',
    '⚽' => 'fótbóltur',
    '⚾' => 'baseball',
    '🥎' => 'softball',
    '🏀' => 'kurvabóltur',
    '🏐' => 'flogbóltur',
    '🏈' => 'amerikanskur fótbóltur',
    '🏉' => 'rugbybóltur',
    '🎾' => 'tennisbóltur',
    '🥏' => 'frisbee',
    '🎳' => 'bowling',
    '🏏' => 'krikket',
    '🏑' => 'hokki',
    '🏒' => 'íshokki',
    '🥍' => 'lacrosse',
    '🏓' => 'borðtennis',
    '🏸' => 'badminton',
    '🥊' => 'boksihandski',
    '🥋' => 'stríðsítróttarbúni',
    '🥅' => 'mál',
    '⛳' => 'golf',
    '⛸' => 'skoyta',
    '🎣' => 'tráða',
    '🤿' => 'kavaramaska',
    '🎽' => 'ítróttatroyggja',
    '🎿' => 'skíð',
    '🛷' => 'sleta',
    '🥌' => 'curling',
    '🎯' => 'dart',
    '🪀' => 'jojo',
    '🪁' => 'flúgvandi dreki',
    '🔫' => 'pistólur',
    '🎱' => 'pul',
    '🔮' => 'krystalkúla',
    '🪄' => 'gandastavur',
    '🎮' => 'kontrollari',
    '🕹' => 'stýripinnur',
    '🎰' => 'spæliautomat',
    '🎲' => 'terningur',
    '🧩' => 'putlispælbrot',
    '🧸' => 'bamsa',
    '🪅' => 'pinata',
    '🪩' => 'diskokúla',
    '🪆' => 'babusjka',
    '♠' => 'spaðari',
    '♥' => 'hjartari',
    '♦' => 'rútari',
    '♣' => 'kleyvari',
    '♟' => 'finna',
    '🃏' => 'jokari',
    '🀄' => 'mah-jong',
    '🎴' => 'hanafuda',
    '🎭' => 'útinnandi leiklistir',
    '🖼' => 'innrammað mynd',
    '🎨' => 'litafjøl',
    '🧵' => 'tráður',
    '🪡' => 'nál',
    '🧶' => 'tógv',
    '🪢' => 'knútur',
    '👓' => 'brillur',
    '🕶' => 'sólbrillur',
    '🥽' => 'verjubrillur',
    '🥼' => 'kittil',
    '🦺' => 'trygdarvestur',
    '👔' => 'slips',
    '👕' => 't-shirt',
    '👖' => 'cowboybuksur',
    '🧣' => 'hálsturriklæði',
    '🧤' => 'handskar',
    '🧥' => 'jakki',
    '🧦' => 'sokkar',
    '👗' => 'kjóli',
    '👘' => 'kimono',
    '🥻' => 'sari',
    '🩱' => 'svimjibúni',
    '🩲' => 'trussur',
    '🩳' => 'shorts',
    '👙' => 'bikini',
    '👚' => 'konufólkaklæðir',
    '🪭' => 'vifta',
    '👛' => 'pungur',
    '👜' => 'handtaska',
    '👝' => 'taska',
    '🛍' => 'keypstaskur',
    '🎒' => 'skúlataska',
    '🩴' => 'sandála',
    '👞' => 'mannfólkaskógvur',
    '👟' => 'renniskógvur',
    '🥾' => 'gangistilvi',
    '🥿' => 'flatbotnaður skógvur',
    '👠' => 'høghælaður skógvur',
    '👡' => 'konufólkasandála',
    '🩰' => 'balletskógvar',
    '👢' => 'konufólkastilvi',
    '🪮' => 'kambur',
    '👑' => 'krúna',
    '👒' => 'konufólkahattur',
    '🎩' => 'høgur hattur',
    '🎓' => 'fráfaringarhúgva',
    '🧢' => 'keppur',
    '🪖' => 'herhjálmur',
    '⛑' => 'bjargingarhjálmur',
    '📿' => 'biðikransur',
    '💄' => 'varrastift',
    '💍' => 'ringur',
    '💎' => 'gimsteinur',
    '🔇' => 'doyvdur hátalari',
    '🔈' => 'lág ljóðstyrki á hátalara',
    '🔉' => 'miðal ljóðstyrki á hátalara',
    '🔊' => 'høg ljóðstyrki á hátalara',
    '📢' => 'rópari',
    '📣' => 'megafon',
    '📯' => 'posthorn',
    '🔔' => 'klokka',
    '🔕' => 'klokka við skrástriku',
    '🎼' => 'fjølrøddabók',
    '🎵' => 'nóti',
    '🎶' => 'nótar',
    '🎙' => 'ljóðstovumikrofon',
    '🎚' => 'dragil',
    '🎛' => 'stýringsknøttar',
    '🎤' => 'mikrofon',
    '🎧' => 'høvuðsett',
    '📻' => 'útvarp',
    '🎷' => 'saksofon',
    '🎺' => 'trompet',
    '🪗' => 'harmonika',
    '🎸' => 'gittari',
    '🎹' => 'ljómborð',
    '🎻' => 'violin',
    '🪕' => 'banjo',
    '🥁' => 'trumma',
    '🪘' => 'long trumma',
    '🪇' => 'marakas',
    '🪈' => 'floyta',
    '🪉' => 'harpa',
    '📱' => 'fartelefon',
    '📲' => 'fartelefon við píli',
    '☎' => 'telefon',
    '📞' => 'horn á telefon',
    '📟' => 'persónleitari',
    '📠' => 'telefaks',
    '🔋' => 'battarí',
    '🪫' => 'lágt battarí',
    '🔌' => 'stikkari',
    '💻' => 'fartelda',
    '🖥' => 'telda',
    '🖨' => 'prentari',
    '⌨' => 'knappaborð',
    '🖱' => 'teldumús',
    '🖲' => 'stýrikúla',
    '💽' => 'teldudiskur',
    '💾' => 'diskil',
    '💿' => 'sjónbandsfløga',
    '📀' => 'margfløga',
    '🧮' => 'kúluramma',
    '🎥' => 'filmstól',
    '🎞' => 'filmstrimmil',
    '📽' => 'ljósvørpa',
    '🎬' => 'klapptræ',
    '📺' => 'sjónvarp',
    '📷' => 'myndatól',
    '📸' => 'myndatól við blits',
    '📹' => 'sjónupptøkutól',
    '📼' => 'sjónband',
    '🔍' => 'luppur á skák til vinstru',
    '🔎' => 'luppur á skák til høgru',
    '🕯' => 'livandi ljós',
    '💡' => 'ljóspera',
    '🔦' => 'lummalykt',
    '🏮' => 'reyð pappírlanterna',
    '🪔' => 'diyalampa',
    '📔' => 'lummabók við prýðiligari perma',
    '📕' => 'afturlatin bók',
    '📖' => 'opin bók',
    '📗' => 'grøn bók',
    '📘' => 'blá bók',
    '📙' => 'appilsingul bók',
    '📚' => 'bøkur',
    '📓' => 'lummabók',
    '📒' => 'høvuðsbók',
    '📃' => 'krúlla pappír',
    '📜' => 'skriftrulla',
    '📄' => 'pappír sum vendur uppeftir',
    '📰' => 'tíðindablað',
    '🗞' => 'samanrulla tíðindablað',
    '📑' => 'bókamerkir',
    '🔖' => 'bókamerki',
    '🏷' => 'merkiseðil',
    '🪙' => 'myntur',
    '💰' => 'pengasekkur',
    '💴' => 'jenn pengaseðil',
    '💵' => 'dollari pengaseðil',
    '💶' => 'evra pengaseðil',
    '💷' => 'pund pengaseðil',
    '💸' => 'pengar við veingjum',
    '💳' => 'kredittkort',
    '🧾' => 'kvittan',
    '💹' => 'strikumynd við jenn tekni',
    '✉' => 'brævbjálvi',
    '📧' => 'teldupostur',
    '📨' => 'innkomandi brævbjálvi',
    '📩' => 'brævbjálvi og pílur',
    '📤' => 'útgangandi brævabakki',
    '📥' => 'innkomandi brævabakki',
    '📦' => 'pakki',
    '📫' => 'afturlatin postkassi við standandi flaggi',
    '📪' => 'afturlatin postkassi við liggjandi flaggi',
    '📬' => 'opin postkassi við standandi flaggi',
    '📭' => 'opin postkassi við liggjandi flaggi',
    '📮' => 'postkassi',
    '🗳' => 'atkvøðukassi',
    '✏' => 'blýantur',
    '✒' => 'svarur oddur á penni',
    '🖋' => 'fyllipennur',
    '🖊' => 'pennur',
    '🖌' => 'pensil',
    '🖍' => 'litblýantur',
    '📝' => 'skrivlig viðmerking',
    '💼' => 'skjalamappa',
    '📁' => 'skjalalummi',
    '📂' => 'opin skjalalummi',
    '🗂' => 'seðlaskrábókamerki',
    '📅' => 'kalendari',
    '📆' => 'kalendari sum kann skræðast úr',
    '🗒' => 'spiralheftur skriviblokkur',
    '🗓' => 'spiralheftur kalendari',
    '📇' => 'kartotek',
    '📈' => 'strikumynd við vøkstri',
    '📉' => 'strikumynd við lækking',
    '📊' => 'stabbamynd',
    '📋' => 'klemmuspjald',
    '📌' => 'nipsnál',
    '📍' => 'rund nipsnál',
    '📎' => 'klips',
    '🖇' => 'klips sum hanga saman',
    '📏' => 'lineal',
    '📐' => 'tríkanta lineal',
    '✂' => 'saksur',
    '🗃' => 'savnskassi',
    '🗄' => 'savnsskáp',
    '🗑' => 'pappírskurv',
    '🔒' => 'læst heingilás',
    '🔓' => 'opi heingilás',
    '🔏' => 'lás og fyllipennur',
    '🔐' => 'heingilás og lykil',
    '🔑' => 'lykil',
    '🗝' => 'gamal lykil',
    '🔨' => 'hamari',
    '🪓' => 'øks',
    '⛏' => 'hakkari',
    '⚒' => 'hamari og hakkari',
    '🛠' => 'hamari og skrúvulykil',
    '🗡' => 'stutt svørð',
    '⚔' => 'krossa svørð',
    '💣' => 'bumba',
    '🪃' => 'boomerang',
    '🏹' => 'bogi of pílur',
    '🛡' => 'skjøldur',
    '🪚' => 'sag',
    '🔧' => 'skrúvulykil',
    '🪛' => 'skrúvublað',
    '🔩' => 'møtrikkur og boltur',
    '⚙' => 'tannhjól',
    '🗜' => 'skrúvutvinga',
    '⚖' => 'vágskál',
    '🦯' => 'blindastavur',
    '🔗' => 'liður',
    '⛓' => 'keta',
    '🪝' => 'krókur',
    '🧰' => 'amboðskassi',
    '🧲' => 'magnet',
    '🪜' => 'stigi',
    '🪏' => 'spaki',
    '⚗' => 'dropadríva',
    '🧪' => 'royndarglas',
    '🧫' => 'petriskál',
    '🧬' => 'dna',
    '🔬' => 'mikroskop',
    '🔭' => 'stjørnukikari',
    '📡' => 'parabolur',
    '💉' => 'sproyta',
    '🩸' => 'blóðdropi',
    '💊' => 'pillari',
    '🩹' => 'heftiplástur',
    '🩼' => 'høkja',
    '🩺' => 'stetoskop',
    '🩻' => 'røntgenmynd',
    '🚪' => 'hurð',
    '🛗' => 'lyfta',
    '🪞' => 'spegil',
    '🪟' => 'vindeyga',
    '🛏' => 'song',
    '🛋' => 'sofa og lampa',
    '🪑' => 'stólur',
    '🚽' => 'ves',
    '🪠' => 'súgvari',
    '🚿' => 'brúsubað',
    '🛁' => 'baðikar',
    '🪤' => 'músafella',
    '🪒' => 'rakiknívur',
    '🧴' => 'lotiónfløska',
    '🧷' => 'trygdarnál',
    '🧹' => 'kustur',
    '🧺' => 'kurv',
    '🧻' => 'vesipappír',
    '🪣' => 'spann',
    '🧼' => 'hondsápa',
    '🫧' => 'bløðrur',
    '🪥' => 'tannbust',
    '🧽' => 'svampur',
    '🧯' => 'eldskøkkjari',
    '🛒' => 'innkeypsvognur',
    '🚬' => 'tendra sigarett',
    '⚰' => 'líkkista',
    '🪦' => 'gravsteinur',
    '⚱' => 'øskukrukka',
    '🧿' => 'nasaramulett',
    '🪬' => 'hamsa',
    '🗿' => 'moai',
    '🪧' => 'skelti',
    '🪪' => 'samleikakort',
    '🏧' => 'sjálvtøkuskeltið',
    '🚮' => 'ruskílatskelti',
    '🚰' => 'drekkivatn',
    '♿' => 'koyristólur symbol',
    '🚹' => 'mannfólkaves',
    '🚺' => 'konufólkaves',
    '🚻' => 'ves symbol',
    '🚼' => 'pinkubarna symbol',
    '🚾' => 'wc symbol',
    '🛂' => 'passeftirlit',
    '🛃' => 'tolleftirlit',
    '🛄' => 'viðførisútflýggjan',
    '🛅' => 'gloymt viðføri',
    '⚠' => 'ávaring',
    '🚸' => 'barnagonguteigur',
    '⛔' => 'innkoyring forboðið',
    '🚫' => 'bannað',
    '🚳' => 'ongar súkklur',
    '🚭' => 'royking bannað',
    '🚯' => 'ikki tveita burturkast',
    '🚱' => 'ikki drekkandi vatn',
    '🚷' => 'bannað fyri gangandi fólki',
    '📵' => 'fartelefon ikki loyvd',
    '🔞' => 'átjanára aldursmark',
    '☢' => 'geislavirki',
    '☣' => 'lívfrøðiligur vandi',
    '⬆' => 'pílur sum peikar uppeftir',
    '↗' => 'pílur sum peikar uppeftir og til høgru',
    '➡' => 'pílur sum peikar til høgru',
    '↘' => 'pílur sum peikar niðureftir og til høgru',
    '⬇' => 'pílur sum peikar niðureftir',
    '↙' => 'pílur sum peikar niðureftir og til vinstru',
    '⬅' => 'pílur sum peikar til vinstru',
    '↖' => 'pílur sum peikar uppeftir og til vinstru',
    '↕' => 'pílur sum peikar upp og niður',
    '↔' => 'pílur sum peikar til høgru og vinstu',
    '↩' => 'bogin pílur sum peikar til vinstru',
    '↪' => 'bogin pílur sum peikar til høgru',
    '⤴' => 'bogin pílur sum peikar uppeftir',
    '⤵' => 'bogin pílur sum peikar niðureftir',
    '🔃' => 'loddrættir pílar sum ganga við urinum',
    '🔄' => 'vatnrættir pílar sum ganga ímóti urinum',
    '🔙' => 'BACK pílur',
    '🔚' => 'END pílur',
    '🔛' => 'ON! pílur',
    '🔜' => 'SOON pílur',
    '🔝' => 'TOP pílur',
    '🛐' => 'bønarstað',
    '⚛' => 'atom symbol',
    '🕉' => 'aúm',
    '✡' => 'dávidsstjørna',
    '☸' => 'dharmahjól',
    '☯' => 'jin yang',
    '✝' => 'latínskur krossur',
    '☦' => 'ortodoksur krossur',
    '☪' => 'stjørna og hálvmáni',
    '☮' => 'friðarsymbol',
    '🕎' => 'menorah',
    '🔯' => 'stjørna við seks spískum',
    '🪯' => 'khanda',
    '♈' => 'Veðrurin',
    '♉' => 'Tarvurin',
    '♊' => 'Tvíburarnir',
    '♋' => 'Krabbin',
    '♌' => 'Ljónið',
    '♍' => 'Moyggin',
    '♎' => 'Vágin',
    '♏' => 'Sporðdrekin',
    '♐' => 'Bogamaðurin',
    '♑' => 'Steingeitin',
    '♒' => 'Vatnberin',
    '♓' => 'Fiskarnir',
    '⛎' => 'Ormberin',
    '🔀' => 'blanda knappur',
    '🔁' => 'endurtak knappur',
    '🔂' => 'endurtak einaferð knappur',
    '▶' => 'spæl knappur',
    '⏩' => 'spola skjótt fram knappur',
    '⏭' => 'næsta knappur',
    '⏯' => 'spæl ella pausa knappur',
    '◀' => 'spola aftur knappur',
    '⏪' => 'spola skjótt aftur knappur',
    '⏮' => 'undanfari knappur',
    '🔼' => 'upp knappur',
    '⏫' => 'skjótt upp knappur',
    '🔽' => 'niður knappur',
    '⏬' => 'skjótt niður knappur',
    '⏸' => 'pausaknappur',
    '⏹' => 'steðgiknappur',
    '⏺' => 'upptøkuknappur',
    '⏏' => 'varpa út knappur',
    '🎦' => 'biograf',
    '🔅' => 'dimma knappur',
    '🔆' => 'ger ljósari knappur',
    '📶' => 'antennstabbar',
    '🛜' => 'tráðleyst',
    '📳' => 'vibratiónstøða',
    '📴' => 'sløk fartelefonina',
    '♀' => 'konufólkatekin',
    '♂' => 'mannfólkatekin',
    '⚧' => 'tvørkyndtekin',
    '✖' => 'falda',
    '➕' => 'pluss',
    '➖' => 'minus',
    '➗' => 'deila',
    '🟰' => 'tjúkt javnatekn',
    '♾' => 'óendaligt',
    '‼' => 'dupult rópitekn',
    '⁉' => 'rópitekn og spurnartekn',
    '❓' => 'reytt spurnartekn',
    '❔' => 'hvítt spurnartekn',
    '❕' => 'hvítt rópitekn',
    '❗' => 'reytt rópitekn',
    '〰' => 'aldandi tankastrika',
    '💱' => 'gjaldoyraveksil',
    '💲' => 'stórt dollartekn',
    '⚕' => 'læknavísind symbol',
    '♻' => 'endurnýtslasymbol',
    '⚜' => 'liljumynd sum skjaldarmerki',
    '🔱' => 'trítindað kvísl',
    '📛' => 'navnaspjaldur',
    '🔰' => 'japanskt symbol fyri byrjandi',
    '⭕' => 'innanopin reyður sirkul',
    '✅' => 'hvítt tjúkt flugubein',
    '☑' => 'flugubein í fýrakanti',
    '✔' => 'tjúkt flugubein',
    '❌' => 'kross symbol',
    '❎' => 'kross symbol knappur',
    '➰' => 'bukt',
    '➿' => 'dupult bukt',
    '〽' => 'umskiftistekn',
    '✳' => 'áttatinda stjørna',
    '✴' => 'áttaspíska stjørna',
    '❇' => 'glampi',
    '™' => 'virkisrættindi',
    '🫟' => 'sprutt',
    '🔠' => 'stórir bókstavir',
    '🔡' => 'smáir bókstavir',
    '🔢' => 'tøl',
    '🔣' => 'symbol',
    '🔤' => 'bókstavir',
    '🅰' => 'A knappur (blóðflokkur)',
    '🆎' => 'AB knappur (blóðflokkur)',
    '🅱' => 'B knappur (blóðflokkur)',
    '🆑' => 'CL knappur',
    '🆒' => 'COOL knappur',
    '🆓' => 'FREE knappur',
    'ℹ' => 'kunning',
    '🆔' => 'ID knappur',
    'Ⓜ' => 'M í sirkuli',
    '🆕' => 'NEW knappur',
    '🆖' => 'NG knappur',
    '🅾' => 'O knappur (blóðflokkur)',
    '🆗' => 'OK knappur',
    '🅿' => 'P knappur',
    '🆘' => 'SOS knappur',
    '🆙' => 'UP! knappur',
    '🆚' => 'VS knappur',
    '🈁' => 'japanskur "her" knappur',
    '🈂' => 'japanskur "avgreiðslugjald" knappur',
    '🈷' => 'japanskur "mánaðarlig upphædd" knappur',
    '🈶' => 'japanskur "ikki ókeypis" knappur',
    '🈯' => 'japanskur "bílagt" knappur',
    '🉐' => 'japanskur "kvett" knappur',
    '🈹' => 'japanskur "avsláttur" knappur',
    '🈚' => 'japanskur "ókeypis" knappur',
    '🈲' => 'japanskur "bannað" knappur',
    '🉑' => 'japanskur "hóskandi" knappur',
    '🈸' => 'japanskur "umsókn" knappur',
    '🈴' => 'japanskur "nøktandi avrik" knappur',
    '🈳' => 'japanskur "leyst" knappur',
    '㊗' => 'japanskur "lukkuynsking" knappur',
    '㊙' => 'japanskur "loyndarmál" knappur',
    '🈺' => 'japanskur "opið" knappur',
    '🈵' => 'japanskur "einki leyst" knappur',
    '🔴' => 'reyður sirkul',
    '🟠' => 'appilsingulur sirkul',
    '🟡' => 'gulur sirkul',
    '🟢' => 'grønur sirkul',
    '🔵' => 'bláur sirkul',
    '🟣' => 'lillafarvaður sirkul',
    '🟤' => 'brúnur sirkul',
    '⚫' => 'svartur sirkul',
    '⚪' => 'hvítur sirkul',
    '🟥' => 'reyður fýrakantur',
    '🟧' => 'appilsingulur fýrakantur',
    '🟨' => 'gulur fýrakantur',
    '🟩' => 'grønur fýrakantur',
    '🟦' => 'blaúr fýrakantur',
    '🟪' => 'lillafarvaður fýrakantur',
    '🟫' => 'brúnur fýrakantur',
    '⬛' => 'stórur svartur fýrakantur',
    '⬜' => 'stórur hvítur fýrakantur',
    '◼' => 'svartur fýrakantur',
    '◻' => 'hvítur fýrakantur',
    '◾' => 'svartur miðalstórur fýrakantur',
    '◽' => 'hvítur miðalstórur fýrakantur',
    '▪' => 'lítil svartur fýrakantur',
    '▫' => 'lítil hvítur fýrakantur',
    '🔶' => 'stórur appilsingulur diamantur',
    '🔷' => 'stórur bláur diamantur',
    '🔸' => 'lítil appilsingulur diamantur',
    '🔹' => 'lítil bláur diamantur',
    '🔺' => 'reyður tríkantur sum peikar uppeftir',
    '🔻' => 'reyður tríkantur sum peikar niðureftir',
    '💠' => 'krossaður diamantur',
    '🔘' => 'radioknappur',
    '🔳' => 'hvítur fýrakantaður karmur',
    '🔲' => 'svartur fýrakantaður karmur',
    '🏁' => 'puntut flagg',
    '🚩' => 'tríkanta flagg',
    '🎌' => 'krossa fløgg',
    '🏴' => 'svart flagg',
    '🏳' => 'hvítt flagg',
];
