<?php

// autoload_static.php @generated by Composer

namespace Composer\Autoload;

class ComposerStaticInit507d84c131cfddd27aaafdb45bfc7db8
{
    public static $files = array (
        '6e3fae29631ef280660b3cdad06f25a8' => __DIR__ . '/..' . '/symfony/deprecation-contracts/function.php',
        '0e6d7bf4a5811bfa5cf40c5ccd6fae6a' => __DIR__ . '/..' . '/symfony/polyfill-mbstring/bootstrap.php',
        '7b11c4dc42b3b3023073cb14e519683c' => __DIR__ . '/..' . '/ralouphie/getallheaders/src/getallheaders.php',
        'a4a119a56e50fbb293281d9a48007e0e' => __DIR__ . '/..' . '/symfony/polyfill-php80/bootstrap.php',
        '320cde22f66dd4f5d3fd621d3e88b98f' => __DIR__ . '/..' . '/symfony/polyfill-ctype/bootstrap.php',
        '662a729f963d39afe703c9d9b7ab4a8c' => __DIR__ . '/..' . '/symfony/polyfill-php83/bootstrap.php',
        '667aeda72477189d0494fecd327c3641' => __DIR__ . '/..' . '/symfony/var-dumper/Resources/functions/dump.php',
        '8825ede83f2f289127722d4e842cf7e8' => __DIR__ . '/..' . '/symfony/polyfill-intl-grapheme/bootstrap.php',
        'e69f7f6ee287b969198c3c9d6777bd38' => __DIR__ . '/..' . '/symfony/polyfill-intl-normalizer/bootstrap.php',
        '89efb1254ef2d1c5d80096acd12c4098' => __DIR__ . '/..' . '/twig/twig/src/Resources/core.php',
        'ffecb95d45175fd40f75be8a23b34f90' => __DIR__ . '/..' . '/twig/twig/src/Resources/debug.php',
        'c7baa00073ee9c61edf148c51917cfb4' => __DIR__ . '/..' . '/twig/twig/src/Resources/escaper.php',
        'f844ccf1d25df8663951193c3fc307c8' => __DIR__ . '/..' . '/twig/twig/src/Resources/string_loader.php',
        'b6b991a57620e2fb6b2f66f03fe9ddc2' => __DIR__ . '/..' . '/symfony/string/Resources/functions.php',
        '6a47392539ca2329373e0d33e1dba053' => __DIR__ . '/..' . '/symfony/polyfill-intl-icu/bootstrap.php',
        '334983c1b64a31de3c73827b7a6a1e88' => __DIR__ . '/../..' . '/src/_autoload_modules.php',
    );

    public static $prefixLengthsPsr4 = array (
        'W' =>
        array (
            'Webmozart\\Assert\\' => 17,
        ),
        'T' =>
        array (
            'Twig\\Extra\\Intl\\' => 16,
            'Twig\\' => 5,
        ),
        'S' =>
        array (
            'Symfony\\Polyfill\\Php83\\' => 23,
            'Symfony\\Polyfill\\Php80\\' => 23,
            'Symfony\\Polyfill\\Mbstring\\' => 26,
            'Symfony\\Polyfill\\Intl\\Normalizer\\' => 33,
            'Symfony\\Polyfill\\Intl\\Icu\\' => 26,
            'Symfony\\Polyfill\\Intl\\Grapheme\\' => 31,
            'Symfony\\Polyfill\\Ctype\\' => 23,
            'Symfony\\Contracts\\Translation\\' => 30,
            'Symfony\\Contracts\\Service\\' => 26,
            'Symfony\\Contracts\\EventDispatcher\\' => 34,
            'Symfony\\Contracts\\Cache\\' => 24,
            'Symfony\\Component\\Yaml\\' => 23,
            'Symfony\\Component\\VarExporter\\' => 30,
            'Symfony\\Component\\VarDumper\\' => 28,
            'Symfony\\Component\\String\\' => 25,
            'Symfony\\Component\\Routing\\' => 26,
            'Symfony\\Component\\PasswordHasher\\' => 33,
            'Symfony\\Component\\Intl\\' => 23,
            'Symfony\\Component\\HttpKernel\\' => 29,
            'Symfony\\Component\\HttpFoundation\\' => 33,
            'Symfony\\Component\\Finder\\' => 25,
            'Symfony\\Component\\Filesystem\\' => 29,
            'Symfony\\Component\\ExpressionLanguage\\' => 37,
            'Symfony\\Component\\EventDispatcher\\' => 34,
            'Symfony\\Component\\ErrorHandler\\' => 31,
            'Symfony\\Component\\DependencyInjection\\' => 38,
            'Symfony\\Component\\Console\\' => 26,
            'Symfony\\Component\\Config\\' => 25,
            'Symfony\\Component\\Cache\\' => 24,
            'Symfony\\Bundle\\FrameworkBundle\\' => 31,
            'Symfony\\Bridge\\Twig\\' => 20,
            'SimpleSAML\\XML\\' => 15,
            'SimpleSAML\\XMLSecurity\\' => 23,
            'SimpleSAML\\SOAP\\' => 16,
            'SimpleSAML\\SAML2\\' => 17,
            'SimpleSAML\\Module\\saml\\' => 23,
            'SimpleSAML\\Module\\multiauth\\' => 28,
            'SimpleSAML\\Module\\exampleauth\\' => 30,
            'SimpleSAML\\Module\\cron\\' => 23,
            'SimpleSAML\\Module\\core\\' => 23,
            'SimpleSAML\\Module\\admin\\' => 24,
            'SimpleSAML\\Composer\\XMLProvider\\' => 32,
            'SimpleSAML\\Composer\\' => 20,
            'SimpleSAML\\Assert\\' => 18,
            'SimpleSAML\\' => 11,
            'SAML2\\' => 6,
        ),
        'R' =>
        array (
            'RobRichards\\XMLSecLibs\\' => 23,
        ),
        'P' =>
        array (
            'Psr\\Log\\' => 8,
            'Psr\\Http\\Message\\' => 17,
            'Psr\\EventDispatcher\\' => 20,
            'Psr\\Container\\' => 14,
            'Psr\\Clock\\' => 10,
            'Psr\\Cache\\' => 10,
            'PHPMailer\\PHPMailer\\' => 20,
        ),
        'N' =>
        array (
            'Nyholm\\Psr7\\' => 12,
        ),
        'G' =>
        array (
            'GuzzleHttp\\Psr7\\' => 16,
            'Gettext\\Languages\\' => 18,
            'Gettext\\' => 8,
        ),
    );

    public static $prefixDirsPsr4 = array (
        'Webmozart\\Assert\\' =>
        array (
            0 => __DIR__ . '/..' . '/webmozart/assert/src',
        ),
        'Twig\\Extra\\Intl\\' =>
        array (
            0 => __DIR__ . '/..' . '/twig/intl-extra',
        ),
        'Twig\\' =>
        array (
            0 => __DIR__ . '/..' . '/twig/twig/src',
        ),
        'Symfony\\Polyfill\\Php83\\' =>
        array (
            0 => __DIR__ . '/..' . '/symfony/polyfill-php83',
        ),
        'Symfony\\Polyfill\\Php80\\' =>
        array (
            0 => __DIR__ . '/..' . '/symfony/polyfill-php80',
        ),
        'Symfony\\Polyfill\\Mbstring\\' =>
        array (
            0 => __DIR__ . '/..' . '/symfony/polyfill-mbstring',
        ),
        'Symfony\\Polyfill\\Intl\\Normalizer\\' =>
        array (
            0 => __DIR__ . '/..' . '/symfony/polyfill-intl-normalizer',
        ),
        'Symfony\\Polyfill\\Intl\\Icu\\' =>
        array (
            0 => __DIR__ . '/..' . '/symfony/polyfill-intl-icu',
        ),
        'Symfony\\Polyfill\\Intl\\Grapheme\\' =>
        array (
            0 => __DIR__ . '/..' . '/symfony/polyfill-intl-grapheme',
        ),
        'Symfony\\Polyfill\\Ctype\\' =>
        array (
            0 => __DIR__ . '/..' . '/symfony/polyfill-ctype',
        ),
        'Symfony\\Contracts\\Translation\\' =>
        array (
            0 => __DIR__ . '/..' . '/symfony/translation-contracts',
        ),
        'Symfony\\Contracts\\Service\\' =>
        array (
            0 => __DIR__ . '/..' . '/symfony/service-contracts',
        ),
        'Symfony\\Contracts\\EventDispatcher\\' =>
        array (
            0 => __DIR__ . '/..' . '/symfony/event-dispatcher-contracts',
        ),
        'Symfony\\Contracts\\Cache\\' =>
        array (
            0 => __DIR__ . '/..' . '/symfony/cache-contracts',
        ),
        'Symfony\\Component\\Yaml\\' =>
        array (
            0 => __DIR__ . '/..' . '/symfony/yaml',
        ),
        'Symfony\\Component\\VarExporter\\' =>
        array (
            0 => __DIR__ . '/..' . '/symfony/var-exporter',
        ),
        'Symfony\\Component\\VarDumper\\' =>
        array (
            0 => __DIR__ . '/..' . '/symfony/var-dumper',
        ),
        'Symfony\\Component\\String\\' =>
        array (
            0 => __DIR__ . '/..' . '/symfony/string',
        ),
        'Symfony\\Component\\Routing\\' =>
        array (
            0 => __DIR__ . '/..' . '/symfony/routing',
        ),
        'Symfony\\Component\\PasswordHasher\\' =>
        array (
            0 => __DIR__ . '/..' . '/symfony/password-hasher',
        ),
        'Symfony\\Component\\Intl\\' =>
        array (
            0 => __DIR__ . '/..' . '/symfony/intl',
        ),
        'Symfony\\Component\\HttpKernel\\' =>
        array (
            0 => __DIR__ . '/..' . '/symfony/http-kernel',
        ),
        'Symfony\\Component\\HttpFoundation\\' =>
        array (
            0 => __DIR__ . '/..' . '/symfony/http-foundation',
        ),
        'Symfony\\Component\\Finder\\' =>
        array (
            0 => __DIR__ . '/..' . '/symfony/finder',
        ),
        'Symfony\\Component\\Filesystem\\' =>
        array (
            0 => __DIR__ . '/..' . '/symfony/filesystem',
        ),
        'Symfony\\Component\\ExpressionLanguage\\' =>
        array (
            0 => __DIR__ . '/..' . '/symfony/expression-language',
        ),
        'Symfony\\Component\\EventDispatcher\\' =>
        array (
            0 => __DIR__ . '/..' . '/symfony/event-dispatcher',
        ),
        'Symfony\\Component\\ErrorHandler\\' =>
        array (
            0 => __DIR__ . '/..' . '/symfony/error-handler',
        ),
        'Symfony\\Component\\DependencyInjection\\' =>
        array (
            0 => __DIR__ . '/..' . '/symfony/dependency-injection',
        ),
        'Symfony\\Component\\Console\\' =>
        array (
            0 => __DIR__ . '/..' . '/symfony/console',
        ),
        'Symfony\\Component\\Config\\' =>
        array (
            0 => __DIR__ . '/..' . '/symfony/config',
        ),
        'Symfony\\Component\\Cache\\' =>
        array (
            0 => __DIR__ . '/..' . '/symfony/cache',
        ),
        'Symfony\\Bundle\\FrameworkBundle\\' =>
        array (
            0 => __DIR__ . '/..' . '/symfony/framework-bundle',
        ),
        'Symfony\\Bridge\\Twig\\' =>
        array (
            0 => __DIR__ . '/..' . '/symfony/twig-bridge',
        ),
        'SimpleSAML\\XML\\' =>
        array (
            0 => __DIR__ . '/..' . '/simplesamlphp/xml-common/src',
        ),
        'SimpleSAML\\XMLSecurity\\' =>
        array (
            0 => __DIR__ . '/..' . '/simplesamlphp/xml-security/src',
        ),
        'SimpleSAML\\SOAP\\' =>
        array (
            0 => __DIR__ . '/..' . '/simplesamlphp/xml-soap/src',
        ),
        'SimpleSAML\\SAML2\\' =>
        array (
            0 => __DIR__ . '/..' . '/simplesamlphp/saml2/src',
        ),
        'SimpleSAML\\Module\\saml\\' =>
        array (
            0 => __DIR__ . '/../..' . '/modules/saml/src',
        ),
        'SimpleSAML\\Module\\multiauth\\' =>
        array (
            0 => __DIR__ . '/../..' . '/modules/multiauth/src',
        ),
        'SimpleSAML\\Module\\exampleauth\\' =>
        array (
            0 => __DIR__ . '/../..' . '/modules/exampleauth/src',
        ),
        'SimpleSAML\\Module\\cron\\' =>
        array (
            0 => __DIR__ . '/../..' . '/modules/cron/src',
        ),
        'SimpleSAML\\Module\\core\\' =>
        array (
            0 => __DIR__ . '/../..' . '/modules/core/src',
        ),
        'SimpleSAML\\Module\\admin\\' =>
        array (
            0 => __DIR__ . '/../..' . '/modules/admin/src',
        ),
        'SimpleSAML\\Composer\\XMLProvider\\' =>
        array (
            0 => __DIR__ . '/..' . '/simplesamlphp/composer-xmlprovider-installer/src',
        ),
        'SimpleSAML\\Composer\\' =>
        array (
            0 => __DIR__ . '/..' . '/simplesamlphp/composer-module-installer/src',
        ),
        'SimpleSAML\\Assert\\' =>
        array (
            0 => __DIR__ . '/..' . '/simplesamlphp/assert/src',
        ),
        'SimpleSAML\\' =>
        array (
            0 => __DIR__ . '/../..' . '/src/SimpleSAML',
        ),
        'SAML2\\' =>
        array (
            0 => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2',
        ),
        'RobRichards\\XMLSecLibs\\' =>
        array (
            0 => __DIR__ . '/..' . '/robrichards/xmlseclibs/src',
        ),
        'Psr\\Log\\' =>
        array (
            0 => __DIR__ . '/..' . '/psr/log/src',
        ),
        'Psr\\Http\\Message\\' =>
        array (
            0 => __DIR__ . '/..' . '/psr/http-factory/src',
            1 => __DIR__ . '/..' . '/psr/http-message/src',
        ),
        'Psr\\EventDispatcher\\' =>
        array (
            0 => __DIR__ . '/..' . '/psr/event-dispatcher/src',
        ),
        'Psr\\Container\\' =>
        array (
            0 => __DIR__ . '/..' . '/psr/container/src',
        ),
        'Psr\\Clock\\' =>
        array (
            0 => __DIR__ . '/..' . '/psr/clock/src',
        ),
        'Psr\\Cache\\' =>
        array (
            0 => __DIR__ . '/..' . '/psr/cache/src',
        ),
        'PHPMailer\\PHPMailer\\' =>
        array (
            0 => __DIR__ . '/..' . '/phpmailer/phpmailer/src',
        ),
        'Nyholm\\Psr7\\' =>
        array (
            0 => __DIR__ . '/..' . '/nyholm/psr7/src',
        ),
        'GuzzleHttp\\Psr7\\' =>
        array (
            0 => __DIR__ . '/..' . '/guzzlehttp/psr7/src',
        ),
        'Gettext\\Languages\\' =>
        array (
            0 => __DIR__ . '/..' . '/gettext/languages/src',
        ),
        'Gettext\\' =>
        array (
            0 => __DIR__ . '/..' . '/gettext/translator/src',
            1 => __DIR__ . '/..' . '/gettext/gettext/src',
        ),
    );

    public static $classMap = array (
        'Attribute' => __DIR__ . '/..' . '/symfony/polyfill-php80/Resources/stubs/Attribute.php',
        'Collator' => __DIR__ . '/..' . '/symfony/polyfill-intl-icu/Resources/stubs/Collator.php',
        'Composer\\InstalledVersions' => __DIR__ . '/..' . '/composer/InstalledVersions.php',
        'DateError' => __DIR__ . '/..' . '/symfony/polyfill-php83/Resources/stubs/DateError.php',
        'DateException' => __DIR__ . '/..' . '/symfony/polyfill-php83/Resources/stubs/DateException.php',
        'DateInvalidOperationException' => __DIR__ . '/..' . '/symfony/polyfill-php83/Resources/stubs/DateInvalidOperationException.php',
        'DateInvalidTimeZoneException' => __DIR__ . '/..' . '/symfony/polyfill-php83/Resources/stubs/DateInvalidTimeZoneException.php',
        'DateMalformedIntervalStringException' => __DIR__ . '/..' . '/symfony/polyfill-php83/Resources/stubs/DateMalformedIntervalStringException.php',
        'DateMalformedPeriodStringException' => __DIR__ . '/..' . '/symfony/polyfill-php83/Resources/stubs/DateMalformedPeriodStringException.php',
        'DateMalformedStringException' => __DIR__ . '/..' . '/symfony/polyfill-php83/Resources/stubs/DateMalformedStringException.php',
        'DateObjectError' => __DIR__ . '/..' . '/symfony/polyfill-php83/Resources/stubs/DateObjectError.php',
        'DateRangeError' => __DIR__ . '/..' . '/symfony/polyfill-php83/Resources/stubs/DateRangeError.php',
        'Gettext\\Comments' => __DIR__ . '/..' . '/gettext/gettext/src/Comments.php',
        'Gettext\\Flags' => __DIR__ . '/..' . '/gettext/gettext/src/Flags.php',
        'Gettext\\Formatter' => __DIR__ . '/..' . '/gettext/translator/src/Formatter.php',
        'Gettext\\FormatterInterface' => __DIR__ . '/..' . '/gettext/translator/src/FormatterInterface.php',
        'Gettext\\Generator\\ArrayGenerator' => __DIR__ . '/..' . '/gettext/translator/src/Generator/ArrayGenerator.php',
        'Gettext\\Generator\\Generator' => __DIR__ . '/..' . '/gettext/gettext/src/Generator/Generator.php',
        'Gettext\\Generator\\GeneratorInterface' => __DIR__ . '/..' . '/gettext/gettext/src/Generator/GeneratorInterface.php',
        'Gettext\\Generator\\MoGenerator' => __DIR__ . '/..' . '/gettext/gettext/src/Generator/MoGenerator.php',
        'Gettext\\Generator\\PoGenerator' => __DIR__ . '/..' . '/gettext/gettext/src/Generator/PoGenerator.php',
        'Gettext\\GettextTranslator' => __DIR__ . '/..' . '/gettext/translator/src/GettextTranslator.php',
        'Gettext\\Headers' => __DIR__ . '/..' . '/gettext/gettext/src/Headers.php',
        'Gettext\\Languages\\Category' => __DIR__ . '/..' . '/gettext/languages/src/Category.php',
        'Gettext\\Languages\\CldrData' => __DIR__ . '/..' . '/gettext/languages/src/CldrData.php',
        'Gettext\\Languages\\Exporter\\Exporter' => __DIR__ . '/..' . '/gettext/languages/src/Exporter/Exporter.php',
        'Gettext\\Languages\\Exporter\\Html' => __DIR__ . '/..' . '/gettext/languages/src/Exporter/Html.php',
        'Gettext\\Languages\\Exporter\\Json' => __DIR__ . '/..' . '/gettext/languages/src/Exporter/Json.php',
        'Gettext\\Languages\\Exporter\\Php' => __DIR__ . '/..' . '/gettext/languages/src/Exporter/Php.php',
        'Gettext\\Languages\\Exporter\\Po' => __DIR__ . '/..' . '/gettext/languages/src/Exporter/Po.php',
        'Gettext\\Languages\\Exporter\\Prettyjson' => __DIR__ . '/..' . '/gettext/languages/src/Exporter/Prettyjson.php',
        'Gettext\\Languages\\Exporter\\Ruby' => __DIR__ . '/..' . '/gettext/languages/src/Exporter/Ruby.php',
        'Gettext\\Languages\\Exporter\\Xml' => __DIR__ . '/..' . '/gettext/languages/src/Exporter/Xml.php',
        'Gettext\\Languages\\FormulaConverter' => __DIR__ . '/..' . '/gettext/languages/src/FormulaConverter.php',
        'Gettext\\Languages\\Language' => __DIR__ . '/..' . '/gettext/languages/src/Language.php',
        'Gettext\\Loader\\ArrayLoader' => __DIR__ . '/..' . '/gettext/translator/src/Loader/ArrayLoader.php',
        'Gettext\\Loader\\Loader' => __DIR__ . '/..' . '/gettext/gettext/src/Loader/Loader.php',
        'Gettext\\Loader\\LoaderInterface' => __DIR__ . '/..' . '/gettext/gettext/src/Loader/LoaderInterface.php',
        'Gettext\\Loader\\MoLoader' => __DIR__ . '/..' . '/gettext/gettext/src/Loader/MoLoader.php',
        'Gettext\\Loader\\PoLoader' => __DIR__ . '/..' . '/gettext/gettext/src/Loader/PoLoader.php',
        'Gettext\\Loader\\StrictPoLoader' => __DIR__ . '/..' . '/gettext/gettext/src/Loader/StrictPoLoader.php',
        'Gettext\\Merge' => __DIR__ . '/..' . '/gettext/gettext/src/Merge.php',
        'Gettext\\References' => __DIR__ . '/..' . '/gettext/gettext/src/References.php',
        'Gettext\\Scanner\\CodeScanner' => __DIR__ . '/..' . '/gettext/gettext/src/Scanner/CodeScanner.php',
        'Gettext\\Scanner\\FunctionsHandlersTrait' => __DIR__ . '/..' . '/gettext/gettext/src/Scanner/FunctionsHandlersTrait.php',
        'Gettext\\Scanner\\FunctionsScannerInterface' => __DIR__ . '/..' . '/gettext/gettext/src/Scanner/FunctionsScannerInterface.php',
        'Gettext\\Scanner\\ParsedFunction' => __DIR__ . '/..' . '/gettext/gettext/src/Scanner/ParsedFunction.php',
        'Gettext\\Scanner\\Scanner' => __DIR__ . '/..' . '/gettext/gettext/src/Scanner/Scanner.php',
        'Gettext\\Scanner\\ScannerInterface' => __DIR__ . '/..' . '/gettext/gettext/src/Scanner/ScannerInterface.php',
        'Gettext\\Translation' => __DIR__ . '/..' . '/gettext/gettext/src/Translation.php',
        'Gettext\\Translations' => __DIR__ . '/..' . '/gettext/gettext/src/Translations.php',
        'Gettext\\Translator' => __DIR__ . '/..' . '/gettext/translator/src/Translator.php',
        'Gettext\\TranslatorFunctions' => __DIR__ . '/..' . '/gettext/translator/src/TranslatorFunctions.php',
        'Gettext\\TranslatorInterface' => __DIR__ . '/..' . '/gettext/translator/src/TranslatorInterface.php',
        'GuzzleHttp\\Psr7\\AppendStream' => __DIR__ . '/..' . '/guzzlehttp/psr7/src/AppendStream.php',
        'GuzzleHttp\\Psr7\\BufferStream' => __DIR__ . '/..' . '/guzzlehttp/psr7/src/BufferStream.php',
        'GuzzleHttp\\Psr7\\CachingStream' => __DIR__ . '/..' . '/guzzlehttp/psr7/src/CachingStream.php',
        'GuzzleHttp\\Psr7\\DroppingStream' => __DIR__ . '/..' . '/guzzlehttp/psr7/src/DroppingStream.php',
        'GuzzleHttp\\Psr7\\Exception\\MalformedUriException' => __DIR__ . '/..' . '/guzzlehttp/psr7/src/Exception/MalformedUriException.php',
        'GuzzleHttp\\Psr7\\FnStream' => __DIR__ . '/..' . '/guzzlehttp/psr7/src/FnStream.php',
        'GuzzleHttp\\Psr7\\Header' => __DIR__ . '/..' . '/guzzlehttp/psr7/src/Header.php',
        'GuzzleHttp\\Psr7\\HttpFactory' => __DIR__ . '/..' . '/guzzlehttp/psr7/src/HttpFactory.php',
        'GuzzleHttp\\Psr7\\InflateStream' => __DIR__ . '/..' . '/guzzlehttp/psr7/src/InflateStream.php',
        'GuzzleHttp\\Psr7\\LazyOpenStream' => __DIR__ . '/..' . '/guzzlehttp/psr7/src/LazyOpenStream.php',
        'GuzzleHttp\\Psr7\\LimitStream' => __DIR__ . '/..' . '/guzzlehttp/psr7/src/LimitStream.php',
        'GuzzleHttp\\Psr7\\Message' => __DIR__ . '/..' . '/guzzlehttp/psr7/src/Message.php',
        'GuzzleHttp\\Psr7\\MessageTrait' => __DIR__ . '/..' . '/guzzlehttp/psr7/src/MessageTrait.php',
        'GuzzleHttp\\Psr7\\MimeType' => __DIR__ . '/..' . '/guzzlehttp/psr7/src/MimeType.php',
        'GuzzleHttp\\Psr7\\MultipartStream' => __DIR__ . '/..' . '/guzzlehttp/psr7/src/MultipartStream.php',
        'GuzzleHttp\\Psr7\\NoSeekStream' => __DIR__ . '/..' . '/guzzlehttp/psr7/src/NoSeekStream.php',
        'GuzzleHttp\\Psr7\\PumpStream' => __DIR__ . '/..' . '/guzzlehttp/psr7/src/PumpStream.php',
        'GuzzleHttp\\Psr7\\Query' => __DIR__ . '/..' . '/guzzlehttp/psr7/src/Query.php',
        'GuzzleHttp\\Psr7\\Request' => __DIR__ . '/..' . '/guzzlehttp/psr7/src/Request.php',
        'GuzzleHttp\\Psr7\\Response' => __DIR__ . '/..' . '/guzzlehttp/psr7/src/Response.php',
        'GuzzleHttp\\Psr7\\Rfc3986' => __DIR__ . '/..' . '/guzzlehttp/psr7/src/Rfc3986.php',
        'GuzzleHttp\\Psr7\\Rfc7230' => __DIR__ . '/..' . '/guzzlehttp/psr7/src/Rfc7230.php',
        'GuzzleHttp\\Psr7\\ServerRequest' => __DIR__ . '/..' . '/guzzlehttp/psr7/src/ServerRequest.php',
        'GuzzleHttp\\Psr7\\Stream' => __DIR__ . '/..' . '/guzzlehttp/psr7/src/Stream.php',
        'GuzzleHttp\\Psr7\\StreamDecoratorTrait' => __DIR__ . '/..' . '/guzzlehttp/psr7/src/StreamDecoratorTrait.php',
        'GuzzleHttp\\Psr7\\StreamWrapper' => __DIR__ . '/..' . '/guzzlehttp/psr7/src/StreamWrapper.php',
        'GuzzleHttp\\Psr7\\UploadedFile' => __DIR__ . '/..' . '/guzzlehttp/psr7/src/UploadedFile.php',
        'GuzzleHttp\\Psr7\\Uri' => __DIR__ . '/..' . '/guzzlehttp/psr7/src/Uri.php',
        'GuzzleHttp\\Psr7\\UriComparator' => __DIR__ . '/..' . '/guzzlehttp/psr7/src/UriComparator.php',
        'GuzzleHttp\\Psr7\\UriNormalizer' => __DIR__ . '/..' . '/guzzlehttp/psr7/src/UriNormalizer.php',
        'GuzzleHttp\\Psr7\\UriResolver' => __DIR__ . '/..' . '/guzzlehttp/psr7/src/UriResolver.php',
        'GuzzleHttp\\Psr7\\Utils' => __DIR__ . '/..' . '/guzzlehttp/psr7/src/Utils.php',
        'IntlDateFormatter' => __DIR__ . '/..' . '/symfony/polyfill-intl-icu/Resources/stubs/IntlDateFormatter.php',
        'IntlListFormatter' => __DIR__ . '/..' . '/symfony/polyfill-intl-icu/Resources/stubs/IntlListFormatter.php',
        'Locale' => __DIR__ . '/..' . '/symfony/polyfill-intl-icu/Resources/stubs/Locale.php',
        'Normalizer' => __DIR__ . '/..' . '/symfony/polyfill-intl-normalizer/Resources/stubs/Normalizer.php',
        'NumberFormatter' => __DIR__ . '/..' . '/symfony/polyfill-intl-icu/Resources/stubs/NumberFormatter.php',
        'Nyholm\\Psr7\\Factory\\HttplugFactory' => __DIR__ . '/..' . '/nyholm/psr7/src/Factory/HttplugFactory.php',
        'Nyholm\\Psr7\\Factory\\Psr17Factory' => __DIR__ . '/..' . '/nyholm/psr7/src/Factory/Psr17Factory.php',
        'Nyholm\\Psr7\\MessageTrait' => __DIR__ . '/..' . '/nyholm/psr7/src/MessageTrait.php',
        'Nyholm\\Psr7\\Request' => __DIR__ . '/..' . '/nyholm/psr7/src/Request.php',
        'Nyholm\\Psr7\\RequestTrait' => __DIR__ . '/..' . '/nyholm/psr7/src/RequestTrait.php',
        'Nyholm\\Psr7\\Response' => __DIR__ . '/..' . '/nyholm/psr7/src/Response.php',
        'Nyholm\\Psr7\\ServerRequest' => __DIR__ . '/..' . '/nyholm/psr7/src/ServerRequest.php',
        'Nyholm\\Psr7\\Stream' => __DIR__ . '/..' . '/nyholm/psr7/src/Stream.php',
        'Nyholm\\Psr7\\StreamTrait' => __DIR__ . '/..' . '/nyholm/psr7/src/StreamTrait.php',
        'Nyholm\\Psr7\\UploadedFile' => __DIR__ . '/..' . '/nyholm/psr7/src/UploadedFile.php',
        'Nyholm\\Psr7\\Uri' => __DIR__ . '/..' . '/nyholm/psr7/src/Uri.php',
        'Override' => __DIR__ . '/..' . '/symfony/polyfill-php83/Resources/stubs/Override.php',
        'PHPMailer\\PHPMailer\\DSNConfigurator' => __DIR__ . '/..' . '/phpmailer/phpmailer/src/DSNConfigurator.php',
        'PHPMailer\\PHPMailer\\Exception' => __DIR__ . '/..' . '/phpmailer/phpmailer/src/Exception.php',
        'PHPMailer\\PHPMailer\\OAuth' => __DIR__ . '/..' . '/phpmailer/phpmailer/src/OAuth.php',
        'PHPMailer\\PHPMailer\\OAuthTokenProvider' => __DIR__ . '/..' . '/phpmailer/phpmailer/src/OAuthTokenProvider.php',
        'PHPMailer\\PHPMailer\\PHPMailer' => __DIR__ . '/..' . '/phpmailer/phpmailer/src/PHPMailer.php',
        'PHPMailer\\PHPMailer\\POP3' => __DIR__ . '/..' . '/phpmailer/phpmailer/src/POP3.php',
        'PHPMailer\\PHPMailer\\SMTP' => __DIR__ . '/..' . '/phpmailer/phpmailer/src/SMTP.php',
        'PhpToken' => __DIR__ . '/..' . '/symfony/polyfill-php80/Resources/stubs/PhpToken.php',
        'Psr\\Cache\\CacheException' => __DIR__ . '/..' . '/psr/cache/src/CacheException.php',
        'Psr\\Cache\\CacheItemInterface' => __DIR__ . '/..' . '/psr/cache/src/CacheItemInterface.php',
        'Psr\\Cache\\CacheItemPoolInterface' => __DIR__ . '/..' . '/psr/cache/src/CacheItemPoolInterface.php',
        'Psr\\Cache\\InvalidArgumentException' => __DIR__ . '/..' . '/psr/cache/src/InvalidArgumentException.php',
        'Psr\\Clock\\ClockInterface' => __DIR__ . '/..' . '/psr/clock/src/ClockInterface.php',
        'Psr\\Container\\ContainerExceptionInterface' => __DIR__ . '/..' . '/psr/container/src/ContainerExceptionInterface.php',
        'Psr\\Container\\ContainerInterface' => __DIR__ . '/..' . '/psr/container/src/ContainerInterface.php',
        'Psr\\Container\\NotFoundExceptionInterface' => __DIR__ . '/..' . '/psr/container/src/NotFoundExceptionInterface.php',
        'Psr\\EventDispatcher\\EventDispatcherInterface' => __DIR__ . '/..' . '/psr/event-dispatcher/src/EventDispatcherInterface.php',
        'Psr\\EventDispatcher\\ListenerProviderInterface' => __DIR__ . '/..' . '/psr/event-dispatcher/src/ListenerProviderInterface.php',
        'Psr\\EventDispatcher\\StoppableEventInterface' => __DIR__ . '/..' . '/psr/event-dispatcher/src/StoppableEventInterface.php',
        'Psr\\Http\\Message\\MessageInterface' => __DIR__ . '/..' . '/psr/http-message/src/MessageInterface.php',
        'Psr\\Http\\Message\\RequestFactoryInterface' => __DIR__ . '/..' . '/psr/http-factory/src/RequestFactoryInterface.php',
        'Psr\\Http\\Message\\RequestInterface' => __DIR__ . '/..' . '/psr/http-message/src/RequestInterface.php',
        'Psr\\Http\\Message\\ResponseFactoryInterface' => __DIR__ . '/..' . '/psr/http-factory/src/ResponseFactoryInterface.php',
        'Psr\\Http\\Message\\ResponseInterface' => __DIR__ . '/..' . '/psr/http-message/src/ResponseInterface.php',
        'Psr\\Http\\Message\\ServerRequestFactoryInterface' => __DIR__ . '/..' . '/psr/http-factory/src/ServerRequestFactoryInterface.php',
        'Psr\\Http\\Message\\ServerRequestInterface' => __DIR__ . '/..' . '/psr/http-message/src/ServerRequestInterface.php',
        'Psr\\Http\\Message\\StreamFactoryInterface' => __DIR__ . '/..' . '/psr/http-factory/src/StreamFactoryInterface.php',
        'Psr\\Http\\Message\\StreamInterface' => __DIR__ . '/..' . '/psr/http-message/src/StreamInterface.php',
        'Psr\\Http\\Message\\UploadedFileFactoryInterface' => __DIR__ . '/..' . '/psr/http-factory/src/UploadedFileFactoryInterface.php',
        'Psr\\Http\\Message\\UploadedFileInterface' => __DIR__ . '/..' . '/psr/http-message/src/UploadedFileInterface.php',
        'Psr\\Http\\Message\\UriFactoryInterface' => __DIR__ . '/..' . '/psr/http-factory/src/UriFactoryInterface.php',
        'Psr\\Http\\Message\\UriInterface' => __DIR__ . '/..' . '/psr/http-message/src/UriInterface.php',
        'Psr\\Log\\AbstractLogger' => __DIR__ . '/..' . '/psr/log/src/AbstractLogger.php',
        'Psr\\Log\\InvalidArgumentException' => __DIR__ . '/..' . '/psr/log/src/InvalidArgumentException.php',
        'Psr\\Log\\LogLevel' => __DIR__ . '/..' . '/psr/log/src/LogLevel.php',
        'Psr\\Log\\LoggerAwareInterface' => __DIR__ . '/..' . '/psr/log/src/LoggerAwareInterface.php',
        'Psr\\Log\\LoggerAwareTrait' => __DIR__ . '/..' . '/psr/log/src/LoggerAwareTrait.php',
        'Psr\\Log\\LoggerInterface' => __DIR__ . '/..' . '/psr/log/src/LoggerInterface.php',
        'Psr\\Log\\LoggerTrait' => __DIR__ . '/..' . '/psr/log/src/LoggerTrait.php',
        'Psr\\Log\\NullLogger' => __DIR__ . '/..' . '/psr/log/src/NullLogger.php',
        'RobRichards\\XMLSecLibs\\Utils\\XPath' => __DIR__ . '/..' . '/robrichards/xmlseclibs/src/Utils/XPath.php',
        'RobRichards\\XMLSecLibs\\XMLSecEnc' => __DIR__ . '/..' . '/robrichards/xmlseclibs/src/XMLSecEnc.php',
        'RobRichards\\XMLSecLibs\\XMLSecurityDSig' => __DIR__ . '/..' . '/robrichards/xmlseclibs/src/XMLSecurityDSig.php',
        'RobRichards\\XMLSecLibs\\XMLSecurityKey' => __DIR__ . '/..' . '/robrichards/xmlseclibs/src/XMLSecurityKey.php',
        'SAML2\\ArtifactResolve' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/ArtifactResolve.php',
        'SAML2\\ArtifactResponse' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/ArtifactResponse.php',
        'SAML2\\Assertion' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Assertion.php',
        'SAML2\\Assertion\\Decrypter' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Assertion/Decrypter.php',
        'SAML2\\Assertion\\Exception\\InvalidAssertionException' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Assertion/Exception/InvalidAssertionException.php',
        'SAML2\\Assertion\\Exception\\InvalidSubjectConfirmationException' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Assertion/Exception/InvalidSubjectConfirmationException.php',
        'SAML2\\Assertion\\Exception\\NotDecryptedException' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Assertion/Exception/NotDecryptedException.php',
        'SAML2\\Assertion\\Processor' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Assertion/Processor.php',
        'SAML2\\Assertion\\ProcessorBuilder' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Assertion/ProcessorBuilder.php',
        'SAML2\\Assertion\\Transformer\\DecodeBase64Transformer' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Assertion/Transformer/DecodeBase64Transformer.php',
        'SAML2\\Assertion\\Transformer\\NameIdDecryptionTransformer' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Assertion/Transformer/NameIdDecryptionTransformer.php',
        'SAML2\\Assertion\\Transformer\\Transformer' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Assertion/Transformer/Transformer.php',
        'SAML2\\Assertion\\Transformer\\TransformerChain' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Assertion/Transformer/TransformerChain.php',
        'SAML2\\Assertion\\Validation\\AssertionConstraintValidator' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Assertion/Validation/AssertionConstraintValidator.php',
        'SAML2\\Assertion\\Validation\\AssertionValidator' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Assertion/Validation/AssertionValidator.php',
        'SAML2\\Assertion\\Validation\\ConstraintValidator\\NotBefore' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Assertion/Validation/ConstraintValidator/NotBefore.php',
        'SAML2\\Assertion\\Validation\\ConstraintValidator\\NotOnOrAfter' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Assertion/Validation/ConstraintValidator/NotOnOrAfter.php',
        'SAML2\\Assertion\\Validation\\ConstraintValidator\\SessionNotOnOrAfter' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Assertion/Validation/ConstraintValidator/SessionNotOnOrAfter.php',
        'SAML2\\Assertion\\Validation\\ConstraintValidator\\SpIsValidAudience' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Assertion/Validation/ConstraintValidator/SpIsValidAudience.php',
        'SAML2\\Assertion\\Validation\\ConstraintValidator\\SubjectConfirmationMethod' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Assertion/Validation/ConstraintValidator/SubjectConfirmationMethod.php',
        'SAML2\\Assertion\\Validation\\ConstraintValidator\\SubjectConfirmationNotBefore' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Assertion/Validation/ConstraintValidator/SubjectConfirmationNotBefore.php',
        'SAML2\\Assertion\\Validation\\ConstraintValidator\\SubjectConfirmationNotOnOrAfter' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Assertion/Validation/ConstraintValidator/SubjectConfirmationNotOnOrAfter.php',
        'SAML2\\Assertion\\Validation\\ConstraintValidator\\SubjectConfirmationRecipientMatches' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Assertion/Validation/ConstraintValidator/SubjectConfirmationRecipientMatches.php',
        'SAML2\\Assertion\\Validation\\ConstraintValidator\\SubjectConfirmationResponseToMatches' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Assertion/Validation/ConstraintValidator/SubjectConfirmationResponseToMatches.php',
        'SAML2\\Assertion\\Validation\\Result' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Assertion/Validation/Result.php',
        'SAML2\\Assertion\\Validation\\SubjectConfirmationConstraintValidator' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Assertion/Validation/SubjectConfirmationConstraintValidator.php',
        'SAML2\\Assertion\\Validation\\SubjectConfirmationValidator' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Assertion/Validation/SubjectConfirmationValidator.php',
        'SAML2\\AttributeQuery' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/AttributeQuery.php',
        'SAML2\\AuthnRequest' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/AuthnRequest.php',
        'SAML2\\Binding' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Binding.php',
        'SAML2\\Certificate\\Exception\\InvalidCertificateStructureException' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Certificate/Exception/InvalidCertificateStructureException.php',
        'SAML2\\Certificate\\Exception\\InvalidKeyUsageException' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Certificate/Exception/InvalidKeyUsageException.php',
        'SAML2\\Certificate\\Exception\\NoKeysFoundException' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Certificate/Exception/NoKeysFoundException.php',
        'SAML2\\Certificate\\Key' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Certificate/Key.php',
        'SAML2\\Certificate\\KeyCollection' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Certificate/KeyCollection.php',
        'SAML2\\Certificate\\KeyLoader' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Certificate/KeyLoader.php',
        'SAML2\\Certificate\\PrivateKey' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Certificate/PrivateKey.php',
        'SAML2\\Certificate\\PrivateKeyLoader' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Certificate/PrivateKeyLoader.php',
        'SAML2\\Certificate\\X509' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Certificate/X509.php',
        'SAML2\\Compat\\AbstractContainer' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Compat/AbstractContainer.php',
        'SAML2\\Compat\\ContainerSingleton' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Compat/ContainerSingleton.php',
        'SAML2\\Compat\\MockContainer' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Compat/MockContainer.php',
        'SAML2\\Compat\\Ssp\\Container' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Compat/Ssp/Container.php',
        'SAML2\\Compat\\Ssp\\Logger' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Compat/Ssp/Logger.php',
        'SAML2\\Configuration\\ArrayAdapter' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Configuration/ArrayAdapter.php',
        'SAML2\\Configuration\\CertificateProvider' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Configuration/CertificateProvider.php',
        'SAML2\\Configuration\\DecryptionProvider' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Configuration/DecryptionProvider.php',
        'SAML2\\Configuration\\Destination' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Configuration/Destination.php',
        'SAML2\\Configuration\\EntityIdProvider' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Configuration/EntityIdProvider.php',
        'SAML2\\Configuration\\IdentityProvider' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Configuration/IdentityProvider.php',
        'SAML2\\Configuration\\IdentityProviderAware' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Configuration/IdentityProviderAware.php',
        'SAML2\\Configuration\\PrivateKey' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Configuration/PrivateKey.php',
        'SAML2\\Configuration\\Queryable' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Configuration/Queryable.php',
        'SAML2\\Configuration\\ServiceProvider' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Configuration/ServiceProvider.php',
        'SAML2\\Configuration\\ServiceProviderAware' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Configuration/ServiceProviderAware.php',
        'SAML2\\Configuration\\SimpleSAMLConverter' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Configuration/SimpleSAMLConverter.php',
        'SAML2\\Constants' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Constants.php',
        'SAML2\\DOMDocumentFactory' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/DOMDocumentFactory.php',
        'SAML2\\EncryptedAssertion' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/EncryptedAssertion.php',
        'SAML2\\Exception\\InvalidArgumentException' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Exception/InvalidArgumentException.php',
        'SAML2\\Exception\\MetadataExpiredException' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Exception/MetadataExpiredException.php',
        'SAML2\\Exception\\ProtocolViolationException' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Exception/ProtocolViolationException.php',
        'SAML2\\Exception\\Protocol\\AuthnFailedException' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Exception/Protocol/AuthnFailedException.php',
        'SAML2\\Exception\\Protocol\\InvalidAttrNameOrValueException' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Exception/Protocol/InvalidAttrNameOrValueException.php',
        'SAML2\\Exception\\Protocol\\InvalidNameIDPolicyException' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Exception/Protocol/InvalidNameIDPolicyException.php',
        'SAML2\\Exception\\Protocol\\NoAuthnContextException' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Exception/Protocol/NoAuthnContextException.php',
        'SAML2\\Exception\\Protocol\\NoAvailableIDPException' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Exception/Protocol/NoAvailableIDPException.php',
        'SAML2\\Exception\\Protocol\\NoPassiveException' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Exception/Protocol/NoPassiveException.php',
        'SAML2\\Exception\\Protocol\\NoSupportedIDPException' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Exception/Protocol/NoSupportedIDPException.php',
        'SAML2\\Exception\\Protocol\\PartialLogoutException' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Exception/Protocol/PartialLogoutException.php',
        'SAML2\\Exception\\Protocol\\ProxyCountExceededException' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Exception/Protocol/ProxyCountExceededException.php',
        'SAML2\\Exception\\Protocol\\RequestDeniedException' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Exception/Protocol/RequestDeniedException.php',
        'SAML2\\Exception\\Protocol\\RequestUnsupportedException' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Exception/Protocol/RequestUnsupportedException.php',
        'SAML2\\Exception\\Protocol\\RequestVersionDeprecatedException' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Exception/Protocol/RequestVersionDeprecatedException.php',
        'SAML2\\Exception\\Protocol\\RequestVersionTooHighException' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Exception/Protocol/RequestVersionTooHighException.php',
        'SAML2\\Exception\\Protocol\\RequestVersionTooLowException' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Exception/Protocol/RequestVersionTooLowException.php',
        'SAML2\\Exception\\Protocol\\ResourceNotRecognizedException' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Exception/Protocol/ResourceNotRecognizedException.php',
        'SAML2\\Exception\\Protocol\\TooManyResponsesException' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Exception/Protocol/TooManyResponsesException.php',
        'SAML2\\Exception\\Protocol\\UnknownAttrProfileException' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Exception/Protocol/UnknownAttrProfileException.php',
        'SAML2\\Exception\\Protocol\\UnknownPrincipalException' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Exception/Protocol/UnknownPrincipalException.php',
        'SAML2\\Exception\\Protocol\\UnsupportedBindingException' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Exception/Protocol/UnsupportedBindingException.php',
        'SAML2\\Exception\\RuntimeException' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Exception/RuntimeException.php',
        'SAML2\\Exception\\Throwable' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Exception/Throwable.php',
        'SAML2\\Exception\\UnparseableXmlException' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Exception/UnparseableXmlException.php',
        'SAML2\\HTTPArtifact' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/HTTPArtifact.php',
        'SAML2\\HTTPPost' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/HTTPPost.php',
        'SAML2\\HTTPRedirect' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/HTTPRedirect.php',
        'SAML2\\LogoutRequest' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/LogoutRequest.php',
        'SAML2\\LogoutResponse' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/LogoutResponse.php',
        'SAML2\\Message' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Message.php',
        'SAML2\\Request' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Request.php',
        'SAML2\\Response' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Response.php',
        'SAML2\\Response\\Exception\\InvalidResponseException' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Response/Exception/InvalidResponseException.php',
        'SAML2\\Response\\Exception\\InvalidSignatureException' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Response/Exception/InvalidSignatureException.php',
        'SAML2\\Response\\Exception\\NoAssertionsFoundException' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Response/Exception/NoAssertionsFoundException.php',
        'SAML2\\Response\\Exception\\PreconditionNotMetException' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Response/Exception/PreconditionNotMetException.php',
        'SAML2\\Response\\Exception\\UnencryptedAssertionFoundException' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Response/Exception/UnencryptedAssertionFoundException.php',
        'SAML2\\Response\\Exception\\UnsignedResponseException' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Response/Exception/UnsignedResponseException.php',
        'SAML2\\Response\\Processor' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Response/Processor.php',
        'SAML2\\Response\\Validation\\ConstraintValidator' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Response/Validation/ConstraintValidator.php',
        'SAML2\\Response\\Validation\\ConstraintValidator\\DestinationMatches' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Response/Validation/ConstraintValidator/DestinationMatches.php',
        'SAML2\\Response\\Validation\\ConstraintValidator\\IsSuccessful' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Response/Validation/ConstraintValidator/IsSuccessful.php',
        'SAML2\\Response\\Validation\\PreconditionValidator' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Response/Validation/PreconditionValidator.php',
        'SAML2\\Response\\Validation\\Result' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Response/Validation/Result.php',
        'SAML2\\Response\\Validation\\Validator' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Response/Validation/Validator.php',
        'SAML2\\SOAP' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/SOAP.php',
        'SAML2\\SOAPClient' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/SOAPClient.php',
        'SAML2\\Signature\\AbstractChainedValidator' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Signature/AbstractChainedValidator.php',
        'SAML2\\Signature\\ChainedValidator' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Signature/ChainedValidator.php',
        'SAML2\\Signature\\MissingConfigurationException' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Signature/MissingConfigurationException.php',
        'SAML2\\Signature\\PublicKeyValidator' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Signature/PublicKeyValidator.php',
        'SAML2\\Signature\\Validator' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Signature/Validator.php',
        'SAML2\\Signature\\ValidatorChain' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Signature/ValidatorChain.php',
        'SAML2\\Signature\\ValidatorInterface' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Signature/ValidatorInterface.php',
        'SAML2\\SignedElement' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/SignedElement.php',
        'SAML2\\SignedElementHelper' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/SignedElementHelper.php',
        'SAML2\\StatusResponse' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/StatusResponse.php',
        'SAML2\\SubjectQuery' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/SubjectQuery.php',
        'SAML2\\Utilities\\ArrayCollection' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Utilities/ArrayCollection.php',
        'SAML2\\Utilities\\Certificate' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Utilities/Certificate.php',
        'SAML2\\Utilities\\Collection' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Utilities/Collection.php',
        'SAML2\\Utilities\\File' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Utilities/File.php',
        'SAML2\\Utilities\\Temporal' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Utilities/Temporal.php',
        'SAML2\\Utils' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/Utils.php',
        'SAML2\\XML\\Chunk' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/Chunk.php',
        'SAML2\\XML\\alg\\Common' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/alg/Common.php',
        'SAML2\\XML\\alg\\DigestMethod' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/alg/DigestMethod.php',
        'SAML2\\XML\\alg\\SigningMethod' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/alg/SigningMethod.php',
        'SAML2\\XML\\ds\\KeyInfo' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/ds/KeyInfo.php',
        'SAML2\\XML\\ds\\KeyName' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/ds/KeyName.php',
        'SAML2\\XML\\ds\\X509Certificate' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/ds/X509Certificate.php',
        'SAML2\\XML\\ds\\X509Data' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/ds/X509Data.php',
        'SAML2\\XML\\ecp\\Response' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/ecp/Response.php',
        'SAML2\\XML\\idpdisc\\DiscoveryResponse' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/idpdisc/DiscoveryResponse.php',
        'SAML2\\XML\\md\\AdditionalMetadataLocation' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/md/AdditionalMetadataLocation.php',
        'SAML2\\XML\\md\\AffiliationDescriptor' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/md/AffiliationDescriptor.php',
        'SAML2\\XML\\md\\AttributeAuthorityDescriptor' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/md/AttributeAuthorityDescriptor.php',
        'SAML2\\XML\\md\\AttributeConsumingService' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/md/AttributeConsumingService.php',
        'SAML2\\XML\\md\\AuthnAuthorityDescriptor' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/md/AuthnAuthorityDescriptor.php',
        'SAML2\\XML\\md\\ContactPerson' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/md/ContactPerson.php',
        'SAML2\\XML\\md\\EndpointType' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/md/EndpointType.php',
        'SAML2\\XML\\md\\EntitiesDescriptor' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/md/EntitiesDescriptor.php',
        'SAML2\\XML\\md\\EntityDescriptor' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/md/EntityDescriptor.php',
        'SAML2\\XML\\md\\Extensions' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/md/Extensions.php',
        'SAML2\\XML\\md\\IDPSSODescriptor' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/md/IDPSSODescriptor.php',
        'SAML2\\XML\\md\\IndexedEndpointType' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/md/IndexedEndpointType.php',
        'SAML2\\XML\\md\\KeyDescriptor' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/md/KeyDescriptor.php',
        'SAML2\\XML\\md\\Organization' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/md/Organization.php',
        'SAML2\\XML\\md\\PDPDescriptor' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/md/PDPDescriptor.php',
        'SAML2\\XML\\md\\RequestedAttribute' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/md/RequestedAttribute.php',
        'SAML2\\XML\\md\\RoleDescriptor' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/md/RoleDescriptor.php',
        'SAML2\\XML\\md\\SPSSODescriptor' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/md/SPSSODescriptor.php',
        'SAML2\\XML\\md\\SSODescriptorType' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/md/SSODescriptorType.php',
        'SAML2\\XML\\md\\UnknownRoleDescriptor' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/md/UnknownRoleDescriptor.php',
        'SAML2\\XML\\mdattr\\EntityAttributes' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/mdattr/EntityAttributes.php',
        'SAML2\\XML\\mdrpi\\Common' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/mdrpi/Common.php',
        'SAML2\\XML\\mdrpi\\PublicationInfo' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/mdrpi/PublicationInfo.php',
        'SAML2\\XML\\mdrpi\\RegistrationInfo' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/mdrpi/RegistrationInfo.php',
        'SAML2\\XML\\mdui\\Common' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/mdui/Common.php',
        'SAML2\\XML\\mdui\\DiscoHints' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/mdui/DiscoHints.php',
        'SAML2\\XML\\mdui\\Keywords' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/mdui/Keywords.php',
        'SAML2\\XML\\mdui\\Logo' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/mdui/Logo.php',
        'SAML2\\XML\\mdui\\UIInfo' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/mdui/UIInfo.php',
        'SAML2\\XML\\saml\\Attribute' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/saml/Attribute.php',
        'SAML2\\XML\\saml\\AttributeValue' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/saml/AttributeValue.php',
        'SAML2\\XML\\saml\\BaseIDType' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/saml/BaseIDType.php',
        'SAML2\\XML\\saml\\IDNameQualifiersTrait' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/saml/IDNameQualifiersTrait.php',
        'SAML2\\XML\\saml\\Issuer' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/saml/Issuer.php',
        'SAML2\\XML\\saml\\NameID' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/saml/NameID.php',
        'SAML2\\XML\\saml\\NameIDType' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/saml/NameIDType.php',
        'SAML2\\XML\\saml\\SubjectConfirmation' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/saml/SubjectConfirmation.php',
        'SAML2\\XML\\saml\\SubjectConfirmationData' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/saml/SubjectConfirmationData.php',
        'SAML2\\XML\\samlp\\Extensions' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/samlp/Extensions.php',
        'SAML2\\XML\\shibmd\\Scope' => __DIR__ . '/..' . '/simplesamlphp/saml2-legacy/src/SAML2/XML/shibmd/Scope.php',
        'SQLite3Exception' => __DIR__ . '/..' . '/symfony/polyfill-php83/Resources/stubs/SQLite3Exception.php',
        'SimpleSAML\\Assert\\Assert' => __DIR__ . '/..' . '/simplesamlphp/assert/src/Assert.php',
        'SimpleSAML\\Assert\\AssertionFailedException' => __DIR__ . '/..' . '/simplesamlphp/assert/src/AssertionFailedException.php',
        'SimpleSAML\\Assert\\Base64Trait' => __DIR__ . '/..' . '/simplesamlphp/assert/src/Base64Trait.php',
        'SimpleSAML\\Assert\\NotInArrayTrait' => __DIR__ . '/..' . '/simplesamlphp/assert/src/NotInArrayTrait.php',
        'SimpleSAML\\Assert\\URITrait' => __DIR__ . '/..' . '/simplesamlphp/assert/src/URITrait.php',
        'SimpleSAML\\Auth\\AuthenticationFactory' => __DIR__ . '/../..' . '/src/SimpleSAML/Auth/AuthenticationFactory.php',
        'SimpleSAML\\Auth\\ProcessingChain' => __DIR__ . '/../..' . '/src/SimpleSAML/Auth/ProcessingChain.php',
        'SimpleSAML\\Auth\\ProcessingFilter' => __DIR__ . '/../..' . '/src/SimpleSAML/Auth/ProcessingFilter.php',
        'SimpleSAML\\Auth\\Simple' => __DIR__ . '/../..' . '/src/SimpleSAML/Auth/Simple.php',
        'SimpleSAML\\Auth\\Source' => __DIR__ . '/../..' . '/src/SimpleSAML/Auth/Source.php',
        'SimpleSAML\\Auth\\SourceFactory' => __DIR__ . '/../..' . '/src/SimpleSAML/Auth/SourceFactory.php',
        'SimpleSAML\\Auth\\State' => __DIR__ . '/../..' . '/src/SimpleSAML/Auth/State.php',
        'SimpleSAML\\Command\\RouterDebugCommand' => __DIR__ . '/../..' . '/src/SimpleSAML/Command/RouterDebugCommand.php',
        'SimpleSAML\\Command\\SspCacheClearCommand' => __DIR__ . '/../..' . '/src/SimpleSAML/Command/SspCacheClearCommand.php',
        'SimpleSAML\\Command\\UnusedTranslatableStringsCommand' => __DIR__ . '/../..' . '/src/SimpleSAML/Command/UnusedTranslatableStringsCommand.php',
        'SimpleSAML\\Command\\UpdateTranslatableStringsCommand' => __DIR__ . '/../..' . '/src/SimpleSAML/Command/UpdateTranslatableStringsCommand.php',
        'SimpleSAML\\Compat\\Logger' => __DIR__ . '/../..' . '/src/SimpleSAML/Compat/Logger.php',
        'SimpleSAML\\Compat\\SspContainer' => __DIR__ . '/../..' . '/src/SimpleSAML/Compat/SspContainer.php',
        'SimpleSAML\\Composer\\ModuleInstaller' => __DIR__ . '/..' . '/simplesamlphp/composer-module-installer/src/ModuleInstaller.php',
        'SimpleSAML\\Composer\\ModuleInstallerPlugin' => __DIR__ . '/..' . '/simplesamlphp/composer-module-installer/src/ModuleInstallerPlugin.php',
        'SimpleSAML\\Composer\\XMLProvider\\XMLProviderInstaller' => __DIR__ . '/..' . '/simplesamlphp/composer-xmlprovider-installer/src/XMLProviderInstaller.php',
        'SimpleSAML\\Composer\\XMLProvider\\XMLProviderInstallerPlugin' => __DIR__ . '/..' . '/simplesamlphp/composer-xmlprovider-installer/src/XMLProviderInstallerPlugin.php',
        'SimpleSAML\\Configuration' => __DIR__ . '/../..' . '/src/SimpleSAML/Configuration.php',
        'SimpleSAML\\Console\\Application' => __DIR__ . '/../..' . '/src/SimpleSAML/Console/Application.php',
        'SimpleSAML\\Database' => __DIR__ . '/../..' . '/src/SimpleSAML/Database.php',
        'SimpleSAML\\Error\\AuthSource' => __DIR__ . '/../..' . '/src/SimpleSAML/Error/AuthSource.php',
        'SimpleSAML\\Error\\BadRequest' => __DIR__ . '/../..' . '/src/SimpleSAML/Error/BadRequest.php',
        'SimpleSAML\\Error\\BadUserInput' => __DIR__ . '/../..' . '/src/SimpleSAML/Error/BadUserInput.php',
        'SimpleSAML\\Error\\CannotSetCookie' => __DIR__ . '/../..' . '/src/SimpleSAML/Error/CannotSetCookie.php',
        'SimpleSAML\\Error\\ConfigurationError' => __DIR__ . '/../..' . '/src/SimpleSAML/Error/ConfigurationError.php',
        'SimpleSAML\\Error\\CriticalConfigurationError' => __DIR__ . '/../..' . '/src/SimpleSAML/Error/CriticalConfigurationError.php',
        'SimpleSAML\\Error\\Error' => __DIR__ . '/../..' . '/src/SimpleSAML/Error/Error.php',
        'SimpleSAML\\Error\\ErrorCodes' => __DIR__ . '/../..' . '/src/SimpleSAML/Error/ErrorCodes.php',
        'SimpleSAML\\Error\\ErrorHandler' => __DIR__ . '/../..' . '/src/SimpleSAML/Error/ErrorHandler.php',
        'SimpleSAML\\Error\\Exception' => __DIR__ . '/../..' . '/src/SimpleSAML/Error/Exception.php',
        'SimpleSAML\\Error\\ExceptionHandler' => __DIR__ . '/../..' . '/src/SimpleSAML/Error/ExceptionHandler.php',
        'SimpleSAML\\Error\\InvalidCredential' => __DIR__ . '/../..' . '/src/SimpleSAML/Error/InvalidCredential.php',
        'SimpleSAML\\Error\\MetadataNotFound' => __DIR__ . '/../..' . '/src/SimpleSAML/Error/MetadataNotFound.php',
        'SimpleSAML\\Error\\MethodNotAllowed' => __DIR__ . '/../..' . '/src/SimpleSAML/Error/MethodNotAllowed.php',
        'SimpleSAML\\Error\\NoState' => __DIR__ . '/../..' . '/src/SimpleSAML/Error/NoState.php',
        'SimpleSAML\\Error\\NotFound' => __DIR__ . '/../..' . '/src/SimpleSAML/Error/NotFound.php',
        'SimpleSAML\\Error\\UnserializableException' => __DIR__ . '/../..' . '/src/SimpleSAML/Error/UnserializableException.php',
        'SimpleSAML\\Error\\User' => __DIR__ . '/../..' . '/src/SimpleSAML/Error/User.php',
        'SimpleSAML\\Error\\UserAborted' => __DIR__ . '/../..' . '/src/SimpleSAML/Error/UserAborted.php',
        'SimpleSAML\\Error\\UserNotFound' => __DIR__ . '/../..' . '/src/SimpleSAML/Error/UserNotFound.php',
        'SimpleSAML\\HTTP\\RunnableResponse' => __DIR__ . '/../..' . '/src/SimpleSAML/HTTP/RunnableResponse.php',
        'SimpleSAML\\IdP' => __DIR__ . '/../..' . '/src/SimpleSAML/IdP.php',
        'SimpleSAML\\IdP\\IFrameLogoutHandler' => __DIR__ . '/../..' . '/src/SimpleSAML/IdP/IFrameLogoutHandler.php',
        'SimpleSAML\\IdP\\LogoutHandlerInterface' => __DIR__ . '/../..' . '/src/SimpleSAML/IdP/LogoutHandlerInterface.php',
        'SimpleSAML\\IdP\\TraditionalLogoutHandler' => __DIR__ . '/../..' . '/src/SimpleSAML/IdP/TraditionalLogoutHandler.php',
        'SimpleSAML\\Kernel' => __DIR__ . '/../..' . '/src/SimpleSAML/Kernel.php',
        'SimpleSAML\\Locale\\Language' => __DIR__ . '/../..' . '/src/SimpleSAML/Locale/Language.php',
        'SimpleSAML\\Locale\\Localization' => __DIR__ . '/../..' . '/src/SimpleSAML/Locale/Localization.php',
        'SimpleSAML\\Locale\\Translate' => __DIR__ . '/../..' . '/src/SimpleSAML/Locale/Translate.php',
        'SimpleSAML\\Locale\\TwigTranslator' => __DIR__ . '/../..' . '/src/SimpleSAML/Locale/TwigTranslator.php',
        'SimpleSAML\\Logger' => __DIR__ . '/../..' . '/src/SimpleSAML/Logger.php',
        'SimpleSAML\\Logger\\ErrorLogLoggingHandler' => __DIR__ . '/../..' . '/src/SimpleSAML/Logger/ErrorLogLoggingHandler.php',
        'SimpleSAML\\Logger\\FileLoggingHandler' => __DIR__ . '/../..' . '/src/SimpleSAML/Logger/FileLoggingHandler.php',
        'SimpleSAML\\Logger\\LoggingHandlerInterface' => __DIR__ . '/../..' . '/src/SimpleSAML/Logger/LoggingHandlerInterface.php',
        'SimpleSAML\\Logger\\StandardErrorLoggingHandler' => __DIR__ . '/../..' . '/src/SimpleSAML/Logger/StandardErrorLoggingHandler.php',
        'SimpleSAML\\Logger\\SyslogLoggingHandler' => __DIR__ . '/../..' . '/src/SimpleSAML/Logger/SyslogLoggingHandler.php',
        'SimpleSAML\\Memcache' => __DIR__ . '/../..' . '/src/SimpleSAML/Memcache.php',
        'SimpleSAML\\Metadata\\MetaDataStorageHandler' => __DIR__ . '/../..' . '/src/SimpleSAML/Metadata/MetaDataStorageHandler.php',
        'SimpleSAML\\Metadata\\MetaDataStorageHandlerDirectory' => __DIR__ . '/../..' . '/src/SimpleSAML/Metadata/MetaDataStorageHandlerDirectory.php',
        'SimpleSAML\\Metadata\\MetaDataStorageHandlerFlatFile' => __DIR__ . '/../..' . '/src/SimpleSAML/Metadata/MetaDataStorageHandlerFlatFile.php',
        'SimpleSAML\\Metadata\\MetaDataStorageHandlerPdo' => __DIR__ . '/../..' . '/src/SimpleSAML/Metadata/MetaDataStorageHandlerPdo.php',
        'SimpleSAML\\Metadata\\MetaDataStorageHandlerSerialize' => __DIR__ . '/../..' . '/src/SimpleSAML/Metadata/MetaDataStorageHandlerSerialize.php',
        'SimpleSAML\\Metadata\\MetaDataStorageHandlerXML' => __DIR__ . '/../..' . '/src/SimpleSAML/Metadata/MetaDataStorageHandlerXML.php',
        'SimpleSAML\\Metadata\\MetaDataStorageSource' => __DIR__ . '/../..' . '/src/SimpleSAML/Metadata/MetaDataStorageSource.php',
        'SimpleSAML\\Metadata\\SAMLBuilder' => __DIR__ . '/../..' . '/src/SimpleSAML/Metadata/SAMLBuilder.php',
        'SimpleSAML\\Metadata\\SAMLParser' => __DIR__ . '/../..' . '/src/SimpleSAML/Metadata/SAMLParser.php',
        'SimpleSAML\\Metadata\\Signer' => __DIR__ . '/../..' . '/src/SimpleSAML/Metadata/Signer.php',
        'SimpleSAML\\Metadata\\Sources\\MDQ' => __DIR__ . '/../..' . '/src/SimpleSAML/Metadata/Sources/MDQ.php',
        'SimpleSAML\\Module' => __DIR__ . '/../..' . '/src/SimpleSAML/Module.php',
        'SimpleSAML\\Module\\admin\\Controller\\Config' => __DIR__ . '/../..' . '/modules/admin/src/Controller/Config.php',
        'SimpleSAML\\Module\\admin\\Controller\\Federation' => __DIR__ . '/../..' . '/modules/admin/src/Controller/Federation.php',
        'SimpleSAML\\Module\\admin\\Controller\\Menu' => __DIR__ . '/../..' . '/modules/admin/src/Controller/Menu.php',
        'SimpleSAML\\Module\\admin\\Controller\\Sandbox' => __DIR__ . '/../..' . '/modules/admin/src/Controller/Sandbox.php',
        'SimpleSAML\\Module\\admin\\Controller\\Test' => __DIR__ . '/../..' . '/modules/admin/src/Controller/Test.php',
        'SimpleSAML\\Module\\core\\Auth\\Process\\AttributeAdd' => __DIR__ . '/../..' . '/modules/core/src/Auth/Process/AttributeAdd.php',
        'SimpleSAML\\Module\\core\\Auth\\Process\\AttributeAlter' => __DIR__ . '/../..' . '/modules/core/src/Auth/Process/AttributeAlter.php',
        'SimpleSAML\\Module\\core\\Auth\\Process\\AttributeCopy' => __DIR__ . '/../..' . '/modules/core/src/Auth/Process/AttributeCopy.php',
        'SimpleSAML\\Module\\core\\Auth\\Process\\AttributeLimit' => __DIR__ . '/../..' . '/modules/core/src/Auth/Process/AttributeLimit.php',
        'SimpleSAML\\Module\\core\\Auth\\Process\\AttributeMap' => __DIR__ . '/../..' . '/modules/core/src/Auth/Process/AttributeMap.php',
        'SimpleSAML\\Module\\core\\Auth\\Process\\AttributeValueMap' => __DIR__ . '/../..' . '/modules/core/src/Auth/Process/AttributeValueMap.php',
        'SimpleSAML\\Module\\core\\Auth\\Process\\Cardinality' => __DIR__ . '/../..' . '/modules/core/src/Auth/Process/Cardinality.php',
        'SimpleSAML\\Module\\core\\Auth\\Process\\CardinalitySingle' => __DIR__ . '/../..' . '/modules/core/src/Auth/Process/CardinalitySingle.php',
        'SimpleSAML\\Module\\core\\Auth\\Process\\ExtendIdPSession' => __DIR__ . '/../..' . '/modules/core/src/Auth/Process/ExtendIdPSession.php',
        'SimpleSAML\\Module\\core\\Auth\\Process\\GenerateGroups' => __DIR__ . '/../..' . '/modules/core/src/Auth/Process/GenerateGroups.php',
        'SimpleSAML\\Module\\core\\Auth\\Process\\LanguageAdaptor' => __DIR__ . '/../..' . '/modules/core/src/Auth/Process/LanguageAdaptor.php',
        'SimpleSAML\\Module\\core\\Auth\\Process\\PHP' => __DIR__ . '/../..' . '/modules/core/src/Auth/Process/PHP.php',
        'SimpleSAML\\Module\\core\\Auth\\Process\\ScopeAttribute' => __DIR__ . '/../..' . '/modules/core/src/Auth/Process/ScopeAttribute.php',
        'SimpleSAML\\Module\\core\\Auth\\Process\\ScopeFromAttribute' => __DIR__ . '/../..' . '/modules/core/src/Auth/Process/ScopeFromAttribute.php',
        'SimpleSAML\\Module\\core\\Auth\\Process\\TargetedID' => __DIR__ . '/../..' . '/modules/core/src/Auth/Process/TargetedID.php',
        'SimpleSAML\\Module\\core\\Auth\\Process\\WarnShortSSOInterval' => __DIR__ . '/../..' . '/modules/core/src/Auth/Process/WarnShortSSOInterval.php',
        'SimpleSAML\\Module\\core\\Auth\\Source\\AbstractSourceSelector' => __DIR__ . '/../..' . '/modules/core/src/Auth/Source/AbstractSourceSelector.php',
        'SimpleSAML\\Module\\core\\Auth\\Source\\AdminPassword' => __DIR__ . '/../..' . '/modules/core/src/Auth/Source/AdminPassword.php',
        'SimpleSAML\\Module\\core\\Auth\\Source\\RequestedAuthnContextSelector' => __DIR__ . '/../..' . '/modules/core/src/Auth/Source/RequestedAuthnContextSelector.php',
        'SimpleSAML\\Module\\core\\Auth\\Source\\SourceIPSelector' => __DIR__ . '/../..' . '/modules/core/src/Auth/Source/SourceIPSelector.php',
        'SimpleSAML\\Module\\core\\Auth\\UserPassBase' => __DIR__ . '/../..' . '/modules/core/src/Auth/UserPassBase.php',
        'SimpleSAML\\Module\\core\\Auth\\UserPassOrgBase' => __DIR__ . '/../..' . '/modules/core/src/Auth/UserPassOrgBase.php',
        'SimpleSAML\\Module\\core\\Controller\\ErrorReport' => __DIR__ . '/../..' . '/modules/core/src/Controller/ErrorReport.php',
        'SimpleSAML\\Module\\core\\Controller\\Exception' => __DIR__ . '/../..' . '/modules/core/src/Controller/Exception.php',
        'SimpleSAML\\Module\\core\\Controller\\Login' => __DIR__ . '/../..' . '/modules/core/src/Controller/Login.php',
        'SimpleSAML\\Module\\core\\Controller\\Logout' => __DIR__ . '/../..' . '/modules/core/src/Controller/Logout.php',
        'SimpleSAML\\Module\\core\\Controller\\Redirection' => __DIR__ . '/../..' . '/modules/core/src/Controller/Redirection.php',
        'SimpleSAML\\Module\\core\\Stats\\Output\\File' => __DIR__ . '/../..' . '/modules/core/src/Stats/Output/File.php',
        'SimpleSAML\\Module\\core\\Stats\\Output\\Log' => __DIR__ . '/../..' . '/modules/core/src/Stats/Output/Log.php',
        'SimpleSAML\\Module\\core\\Storage\\SQLPermanentStorage' => __DIR__ . '/../..' . '/modules/core/src/Storage/SQLPermanentStorage.php',
        'SimpleSAML\\Module\\cron\\Controller\\Cron' => __DIR__ . '/../..' . '/modules/cron/src/Controller/Cron.php',
        'SimpleSAML\\Module\\cron\\Cron' => __DIR__ . '/../..' . '/modules/cron/src/Cron.php',
        'SimpleSAML\\Module\\exampleauth\\Auth\\Process\\RedirectTest' => __DIR__ . '/../..' . '/modules/exampleauth/src/Auth/Process/RedirectTest.php',
        'SimpleSAML\\Module\\exampleauth\\Auth\\Source\\External' => __DIR__ . '/../..' . '/modules/exampleauth/src/Auth/Source/External.php',
        'SimpleSAML\\Module\\exampleauth\\Auth\\Source\\StaticSource' => __DIR__ . '/../..' . '/modules/exampleauth/src/Auth/Source/StaticSource.php',
        'SimpleSAML\\Module\\exampleauth\\Auth\\Source\\UserPass' => __DIR__ . '/../..' . '/modules/exampleauth/src/Auth/Source/UserPass.php',
        'SimpleSAML\\Module\\exampleauth\\Controller\\ExampleAuth' => __DIR__ . '/../..' . '/modules/exampleauth/src/Controller/ExampleAuth.php',
        'SimpleSAML\\Module\\multiauth\\Auth\\Source\\MultiAuth' => __DIR__ . '/../..' . '/modules/multiauth/src/Auth/Source/MultiAuth.php',
        'SimpleSAML\\Module\\multiauth\\Controller\\DiscoController' => __DIR__ . '/../..' . '/modules/multiauth/src/Controller/DiscoController.php',
        'SimpleSAML\\Module\\saml\\Auth\\Process\\AttributeNameID' => __DIR__ . '/../..' . '/modules/saml/src/Auth/Process/AttributeNameID.php',
        'SimpleSAML\\Module\\saml\\Auth\\Process\\AuthnContextClassRef' => __DIR__ . '/../..' . '/modules/saml/src/Auth/Process/AuthnContextClassRef.php',
        'SimpleSAML\\Module\\saml\\Auth\\Process\\ExpectedAuthnContextClassRef' => __DIR__ . '/../..' . '/modules/saml/src/Auth/Process/ExpectedAuthnContextClassRef.php',
        'SimpleSAML\\Module\\saml\\Auth\\Process\\FilterScopes' => __DIR__ . '/../..' . '/modules/saml/src/Auth/Process/FilterScopes.php',
        'SimpleSAML\\Module\\saml\\Auth\\Process\\NameIDAttribute' => __DIR__ . '/../..' . '/modules/saml/src/Auth/Process/NameIDAttribute.php',
        'SimpleSAML\\Module\\saml\\Auth\\Process\\PairwiseID' => __DIR__ . '/../..' . '/modules/saml/src/Auth/Process/PairwiseID.php',
        'SimpleSAML\\Module\\saml\\Auth\\Process\\PersistentNameID' => __DIR__ . '/../..' . '/modules/saml/src/Auth/Process/PersistentNameID.php',
        'SimpleSAML\\Module\\saml\\Auth\\Process\\PersistentNameID2TargetedID' => __DIR__ . '/../..' . '/modules/saml/src/Auth/Process/PersistentNameID2TargetedID.php',
        'SimpleSAML\\Module\\saml\\Auth\\Process\\SQLPersistentNameID' => __DIR__ . '/../..' . '/modules/saml/src/Auth/Process/SQLPersistentNameID.php',
        'SimpleSAML\\Module\\saml\\Auth\\Process\\ScopedIssuer' => __DIR__ . '/../..' . '/modules/saml/src/Auth/Process/ScopedIssuer.php',
        'SimpleSAML\\Module\\saml\\Auth\\Process\\SubjectID' => __DIR__ . '/../..' . '/modules/saml/src/Auth/Process/SubjectID.php',
        'SimpleSAML\\Module\\saml\\Auth\\Process\\TransientNameID' => __DIR__ . '/../..' . '/modules/saml/src/Auth/Process/TransientNameID.php',
        'SimpleSAML\\Module\\saml\\Auth\\Source\\SP' => __DIR__ . '/../..' . '/modules/saml/src/Auth/Source/SP.php',
        'SimpleSAML\\Module\\saml\\BaseNameIDGenerator' => __DIR__ . '/../..' . '/modules/saml/src/BaseNameIDGenerator.php',
        'SimpleSAML\\Module\\saml\\Controller\\Disco' => __DIR__ . '/../..' . '/modules/saml/src/Controller/Disco.php',
        'SimpleSAML\\Module\\saml\\Controller\\Exception' => __DIR__ . '/../..' . '/modules/saml/src/Controller/Exception.php',
        'SimpleSAML\\Module\\saml\\Controller\\Metadata' => __DIR__ . '/../..' . '/modules/saml/src/Controller/Metadata.php',
        'SimpleSAML\\Module\\saml\\Controller\\Proxy' => __DIR__ . '/../..' . '/modules/saml/src/Controller/Proxy.php',
        'SimpleSAML\\Module\\saml\\Controller\\ServiceProvider' => __DIR__ . '/../..' . '/modules/saml/src/Controller/ServiceProvider.php',
        'SimpleSAML\\Module\\saml\\Controller\\SingleLogout' => __DIR__ . '/../..' . '/modules/saml/src/Controller/SingleLogout.php',
        'SimpleSAML\\Module\\saml\\Controller\\WebBrowserSingleSignOn' => __DIR__ . '/../..' . '/modules/saml/src/Controller/WebBrowserSingleSignOn.php',
        'SimpleSAML\\Module\\saml\\Error' => __DIR__ . '/../..' . '/modules/saml/src/Error.php',
        'SimpleSAML\\Module\\saml\\Error\\NoAuthnContext' => __DIR__ . '/../..' . '/modules/saml/src/Error/NoAuthnContext.php',
        'SimpleSAML\\Module\\saml\\Error\\NoAvailableIDP' => __DIR__ . '/../..' . '/modules/saml/src/Error/NoAvailableIDP.php',
        'SimpleSAML\\Module\\saml\\Error\\NoPassive' => __DIR__ . '/../..' . '/modules/saml/src/Error/NoPassive.php',
        'SimpleSAML\\Module\\saml\\Error\\NoSupportedIDP' => __DIR__ . '/../..' . '/modules/saml/src/Error/NoSupportedIDP.php',
        'SimpleSAML\\Module\\saml\\Error\\ProxyCountExceeded' => __DIR__ . '/../..' . '/modules/saml/src/Error/ProxyCountExceeded.php',
        'SimpleSAML\\Module\\saml\\IdP\\SAML2' => __DIR__ . '/../..' . '/modules/saml/src/IdP/SAML2.php',
        'SimpleSAML\\Module\\saml\\IdP\\SQLNameID' => __DIR__ . '/../..' . '/modules/saml/src/IdP/SQLNameID.php',
        'SimpleSAML\\Module\\saml\\Message' => __DIR__ . '/../..' . '/modules/saml/src/Message.php',
        'SimpleSAML\\Module\\saml\\SP\\LogoutStore' => __DIR__ . '/../..' . '/modules/saml/src/SP/LogoutStore.php',
        'SimpleSAML\\SAML2\\Assert\\Assert' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Assert/Assert.php',
        'SimpleSAML\\SAML2\\Assert\\CustomAssertionTrait' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Assert/CustomAssertionTrait.php',
        'SimpleSAML\\SAML2\\Assert\\RelayStateTrait' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Assert/RelayStateTrait.php',
        'SimpleSAML\\SAML2\\Assertion\\Decrypter' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Assertion/Decrypter.php',
        'SimpleSAML\\SAML2\\Assertion\\Exception\\InvalidAssertionException' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Assertion/Exception/InvalidAssertionException.php',
        'SimpleSAML\\SAML2\\Assertion\\Exception\\InvalidSubjectConfirmationException' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Assertion/Exception/InvalidSubjectConfirmationException.php',
        'SimpleSAML\\SAML2\\Assertion\\Exception\\NotDecryptedException' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Assertion/Exception/NotDecryptedException.php',
        'SimpleSAML\\SAML2\\Assertion\\Processor' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Assertion/Processor.php',
        'SimpleSAML\\SAML2\\Assertion\\ProcessorBuilder' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Assertion/ProcessorBuilder.php',
        'SimpleSAML\\SAML2\\Assertion\\Transformer\\NameIdDecryptionTransformer' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Assertion/Transformer/NameIdDecryptionTransformer.php',
        'SimpleSAML\\SAML2\\Assertion\\Transformer\\TransformerChain' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Assertion/Transformer/TransformerChain.php',
        'SimpleSAML\\SAML2\\Assertion\\Transformer\\TransformerInterface' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Assertion/Transformer/TransformerInterface.php',
        'SimpleSAML\\SAML2\\Assertion\\Validation\\AssertionConstraintValidator' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Assertion/Validation/AssertionConstraintValidator.php',
        'SimpleSAML\\SAML2\\Assertion\\Validation\\AssertionValidator' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Assertion/Validation/AssertionValidator.php',
        'SimpleSAML\\SAML2\\Assertion\\Validation\\ConstraintValidator\\NotBefore' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Assertion/Validation/ConstraintValidator/NotBefore.php',
        'SimpleSAML\\SAML2\\Assertion\\Validation\\ConstraintValidator\\NotOnOrAfter' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Assertion/Validation/ConstraintValidator/NotOnOrAfter.php',
        'SimpleSAML\\SAML2\\Assertion\\Validation\\ConstraintValidator\\SessionNotOnOrAfter' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Assertion/Validation/ConstraintValidator/SessionNotOnOrAfter.php',
        'SimpleSAML\\SAML2\\Assertion\\Validation\\ConstraintValidator\\SpIsValidAudience' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Assertion/Validation/ConstraintValidator/SpIsValidAudience.php',
        'SimpleSAML\\SAML2\\Assertion\\Validation\\ConstraintValidator\\SubjectConfirmationMethod' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Assertion/Validation/ConstraintValidator/SubjectConfirmationMethod.php',
        'SimpleSAML\\SAML2\\Assertion\\Validation\\ConstraintValidator\\SubjectConfirmationNotBefore' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Assertion/Validation/ConstraintValidator/SubjectConfirmationNotBefore.php',
        'SimpleSAML\\SAML2\\Assertion\\Validation\\ConstraintValidator\\SubjectConfirmationNotOnOrAfter' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Assertion/Validation/ConstraintValidator/SubjectConfirmationNotOnOrAfter.php',
        'SimpleSAML\\SAML2\\Assertion\\Validation\\ConstraintValidator\\SubjectConfirmationRecipientMatches' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Assertion/Validation/ConstraintValidator/SubjectConfirmationRecipientMatches.php',
        'SimpleSAML\\SAML2\\Assertion\\Validation\\ConstraintValidator\\SubjectConfirmationResponseToMatches' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Assertion/Validation/ConstraintValidator/SubjectConfirmationResponseToMatches.php',
        'SimpleSAML\\SAML2\\Assertion\\Validation\\Result' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Assertion/Validation/Result.php',
        'SimpleSAML\\SAML2\\Assertion\\Validation\\SubjectConfirmationConstraintValidator' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Assertion/Validation/SubjectConfirmationConstraintValidator.php',
        'SimpleSAML\\SAML2\\Assertion\\Validation\\SubjectConfirmationValidator' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Assertion/Validation/SubjectConfirmationValidator.php',
        'SimpleSAML\\SAML2\\Binding' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Binding.php',
        'SimpleSAML\\SAML2\\Binding\\AsynchronousBindingInterface' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Binding/AsynchronousBindingInterface.php',
        'SimpleSAML\\SAML2\\Binding\\HTTPArtifact' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Binding/HTTPArtifact.php',
        'SimpleSAML\\SAML2\\Binding\\HTTPPost' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Binding/HTTPPost.php',
        'SimpleSAML\\SAML2\\Binding\\HTTPRedirect' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Binding/HTTPRedirect.php',
        'SimpleSAML\\SAML2\\Binding\\RelayStateInterface' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Binding/RelayStateInterface.php',
        'SimpleSAML\\SAML2\\Binding\\RelayStateTrait' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Binding/RelayStateTrait.php',
        'SimpleSAML\\SAML2\\Binding\\SOAP' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Binding/SOAP.php',
        'SimpleSAML\\SAML2\\Binding\\SynchronousBindingInterface' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Binding/SynchronousBindingInterface.php',
        'SimpleSAML\\SAML2\\Certificate\\Exception\\InvalidCertificateStructureException' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Certificate/Exception/InvalidCertificateStructureException.php',
        'SimpleSAML\\SAML2\\Certificate\\Exception\\InvalidKeyUsageException' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Certificate/Exception/InvalidKeyUsageException.php',
        'SimpleSAML\\SAML2\\Certificate\\Exception\\NoKeysFoundException' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Certificate/Exception/NoKeysFoundException.php',
        'SimpleSAML\\SAML2\\Certificate\\Key' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Certificate/Key.php',
        'SimpleSAML\\SAML2\\Certificate\\KeyCollection' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Certificate/KeyCollection.php',
        'SimpleSAML\\SAML2\\Certificate\\KeyLoader' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Certificate/KeyLoader.php',
        'SimpleSAML\\SAML2\\Certificate\\PrivateKey' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Certificate/PrivateKey.php',
        'SimpleSAML\\SAML2\\Certificate\\PrivateKeyLoader' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Certificate/PrivateKeyLoader.php',
        'SimpleSAML\\SAML2\\Certificate\\X509' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Certificate/X509.php',
        'SimpleSAML\\SAML2\\Compat\\AbstractContainer' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Compat/AbstractContainer.php',
        'SimpleSAML\\SAML2\\Compat\\ContainerSingleton' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Compat/ContainerSingleton.php',
        'SimpleSAML\\SAML2\\Compat\\MockContainer' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Compat/MockContainer.php',
        'SimpleSAML\\SAML2\\Configuration\\ArrayAdapter' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Configuration/ArrayAdapter.php',
        'SimpleSAML\\SAML2\\Configuration\\CertificateProvider' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Configuration/CertificateProvider.php',
        'SimpleSAML\\SAML2\\Configuration\\DecryptionProvider' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Configuration/DecryptionProvider.php',
        'SimpleSAML\\SAML2\\Configuration\\Destination' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Configuration/Destination.php',
        'SimpleSAML\\SAML2\\Configuration\\EntityIdProvider' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Configuration/EntityIdProvider.php',
        'SimpleSAML\\SAML2\\Configuration\\IdentityProvider' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Configuration/IdentityProvider.php',
        'SimpleSAML\\SAML2\\Configuration\\IdentityProviderAware' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Configuration/IdentityProviderAware.php',
        'SimpleSAML\\SAML2\\Configuration\\PrivateKey' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Configuration/PrivateKey.php',
        'SimpleSAML\\SAML2\\Configuration\\Queryable' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Configuration/Queryable.php',
        'SimpleSAML\\SAML2\\Configuration\\ServiceProvider' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Configuration/ServiceProvider.php',
        'SimpleSAML\\SAML2\\Configuration\\ServiceProviderAware' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Configuration/ServiceProviderAware.php',
        'SimpleSAML\\SAML2\\Configuration\\SimpleSAMLConverter' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Configuration/SimpleSAMLConverter.php',
        'SimpleSAML\\SAML2\\Constants' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Constants.php',
        'SimpleSAML\\SAML2\\Exception\\ArrayValidationException' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Exception/ArrayValidationException.php',
        'SimpleSAML\\SAML2\\Exception\\InvalidArgumentException' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Exception/InvalidArgumentException.php',
        'SimpleSAML\\SAML2\\Exception\\MetadataExpiredException' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Exception/MetadataExpiredException.php',
        'SimpleSAML\\SAML2\\Exception\\ProtocolViolationException' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Exception/ProtocolViolationException.php',
        'SimpleSAML\\SAML2\\Exception\\Protocol\\AuthnFailedException' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Exception/Protocol/AuthnFailedException.php',
        'SimpleSAML\\SAML2\\Exception\\Protocol\\InvalidAttrNameOrValueException' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Exception/Protocol/InvalidAttrNameOrValueException.php',
        'SimpleSAML\\SAML2\\Exception\\Protocol\\InvalidNameIDPolicyException' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Exception/Protocol/InvalidNameIDPolicyException.php',
        'SimpleSAML\\SAML2\\Exception\\Protocol\\NoAuthnContextException' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Exception/Protocol/NoAuthnContextException.php',
        'SimpleSAML\\SAML2\\Exception\\Protocol\\NoAvailableIDPException' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Exception/Protocol/NoAvailableIDPException.php',
        'SimpleSAML\\SAML2\\Exception\\Protocol\\NoPassiveException' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Exception/Protocol/NoPassiveException.php',
        'SimpleSAML\\SAML2\\Exception\\Protocol\\NoSupportedIDPException' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Exception/Protocol/NoSupportedIDPException.php',
        'SimpleSAML\\SAML2\\Exception\\Protocol\\PartialLogoutException' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Exception/Protocol/PartialLogoutException.php',
        'SimpleSAML\\SAML2\\Exception\\Protocol\\ProxyCountExceededException' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Exception/Protocol/ProxyCountExceededException.php',
        'SimpleSAML\\SAML2\\Exception\\Protocol\\RequestDeniedException' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Exception/Protocol/RequestDeniedException.php',
        'SimpleSAML\\SAML2\\Exception\\Protocol\\RequestUnsupportedException' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Exception/Protocol/RequestUnsupportedException.php',
        'SimpleSAML\\SAML2\\Exception\\Protocol\\RequestVersionDeprecatedException' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Exception/Protocol/RequestVersionDeprecatedException.php',
        'SimpleSAML\\SAML2\\Exception\\Protocol\\RequestVersionTooHighException' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Exception/Protocol/RequestVersionTooHighException.php',
        'SimpleSAML\\SAML2\\Exception\\Protocol\\RequestVersionTooLowException' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Exception/Protocol/RequestVersionTooLowException.php',
        'SimpleSAML\\SAML2\\Exception\\Protocol\\ResourceNotRecognizedException' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Exception/Protocol/ResourceNotRecognizedException.php',
        'SimpleSAML\\SAML2\\Exception\\Protocol\\TooManyResponsesException' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Exception/Protocol/TooManyResponsesException.php',
        'SimpleSAML\\SAML2\\Exception\\Protocol\\UnknownAttrProfileException' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Exception/Protocol/UnknownAttrProfileException.php',
        'SimpleSAML\\SAML2\\Exception\\Protocol\\UnknownPrincipalException' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Exception/Protocol/UnknownPrincipalException.php',
        'SimpleSAML\\SAML2\\Exception\\Protocol\\UnsupportedBindingException' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Exception/Protocol/UnsupportedBindingException.php',
        'SimpleSAML\\SAML2\\Exception\\RuntimeException' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Exception/RuntimeException.php',
        'SimpleSAML\\SAML2\\Response\\Exception\\InvalidResponseException' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Response/Exception/InvalidResponseException.php',
        'SimpleSAML\\SAML2\\Response\\Exception\\InvalidSignatureException' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Response/Exception/InvalidSignatureException.php',
        'SimpleSAML\\SAML2\\Response\\Exception\\NoAssertionsFoundException' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Response/Exception/NoAssertionsFoundException.php',
        'SimpleSAML\\SAML2\\Response\\Exception\\PreconditionNotMetException' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Response/Exception/PreconditionNotMetException.php',
        'SimpleSAML\\SAML2\\Response\\Exception\\UnencryptedAssertionFoundException' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Response/Exception/UnencryptedAssertionFoundException.php',
        'SimpleSAML\\SAML2\\Response\\Exception\\UnsignedResponseException' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Response/Exception/UnsignedResponseException.php',
        'SimpleSAML\\SAML2\\Response\\Processor' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Response/Processor.php',
        'SimpleSAML\\SAML2\\Response\\Validation\\ConstraintValidator' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Response/Validation/ConstraintValidator.php',
        'SimpleSAML\\SAML2\\Response\\Validation\\ConstraintValidator\\DestinationMatches' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Response/Validation/ConstraintValidator/DestinationMatches.php',
        'SimpleSAML\\SAML2\\Response\\Validation\\ConstraintValidator\\IsSuccessful' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Response/Validation/ConstraintValidator/IsSuccessful.php',
        'SimpleSAML\\SAML2\\Response\\Validation\\PreconditionValidator' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Response/Validation/PreconditionValidator.php',
        'SimpleSAML\\SAML2\\Response\\Validation\\Result' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Response/Validation/Result.php',
        'SimpleSAML\\SAML2\\Response\\Validation\\Validator' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Response/Validation/Validator.php',
        'SimpleSAML\\SAML2\\SOAPClient' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/SOAPClient.php',
        'SimpleSAML\\SAML2\\Signature\\AbstractChainedValidator' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Signature/AbstractChainedValidator.php',
        'SimpleSAML\\SAML2\\Signature\\ChainedValidator' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Signature/ChainedValidator.php',
        'SimpleSAML\\SAML2\\Signature\\MissingConfigurationException' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Signature/MissingConfigurationException.php',
        'SimpleSAML\\SAML2\\Signature\\PublicKeyValidator' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Signature/PublicKeyValidator.php',
        'SimpleSAML\\SAML2\\Signature\\Validator' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Signature/Validator.php',
        'SimpleSAML\\SAML2\\Signature\\ValidatorChain' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Signature/ValidatorChain.php',
        'SimpleSAML\\SAML2\\Signature\\ValidatorInterface' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Signature/ValidatorInterface.php',
        'SimpleSAML\\SAML2\\Utilities\\ArrayCollection' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Utilities/ArrayCollection.php',
        'SimpleSAML\\SAML2\\Utilities\\Collection' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Utilities/Collection.php',
        'SimpleSAML\\SAML2\\Utilities\\File' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Utilities/File.php',
        'SimpleSAML\\SAML2\\Utils' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Utils.php',
        'SimpleSAML\\SAML2\\Utils\\XPath' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/Utils/XPath.php',
        'SimpleSAML\\SAML2\\XML\\Comparison' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/Comparison.php',
        'SimpleSAML\\SAML2\\XML\\Decision' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/Decision.php',
        'SimpleSAML\\SAML2\\XML\\EncryptableElementTrait' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/EncryptableElementTrait.php',
        'SimpleSAML\\SAML2\\XML\\EncryptedElementTrait' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/EncryptedElementTrait.php',
        'SimpleSAML\\SAML2\\XML\\ExtendableElementTrait' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/ExtendableElementTrait.php',
        'SimpleSAML\\SAML2\\XML\\ExtensionPointInterface' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/ExtensionPointInterface.php',
        'SimpleSAML\\SAML2\\XML\\ExtensionPointTrait' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/ExtensionPointTrait.php',
        'SimpleSAML\\SAML2\\XML\\ExtensionsTrait' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/ExtensionsTrait.php',
        'SimpleSAML\\SAML2\\XML\\IdentifierTrait' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/IdentifierTrait.php',
        'SimpleSAML\\SAML2\\XML\\SignableElementTrait' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/SignableElementTrait.php',
        'SimpleSAML\\SAML2\\XML\\SignedElementTrait' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/SignedElementTrait.php',
        'SimpleSAML\\SAML2\\XML\\StringElementTrait' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/StringElementTrait.php',
        'SimpleSAML\\SAML2\\XML\\URIElementTrait' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/URIElementTrait.php',
        'SimpleSAML\\SAML2\\XML\\alg\\AbstractAlgElement' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/alg/AbstractAlgElement.php',
        'SimpleSAML\\SAML2\\XML\\alg\\DigestMethod' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/alg/DigestMethod.php',
        'SimpleSAML\\SAML2\\XML\\alg\\SigningMethod' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/alg/SigningMethod.php',
        'SimpleSAML\\SAML2\\XML\\ecp\\AbstractEcpElement' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/ecp/AbstractEcpElement.php',
        'SimpleSAML\\SAML2\\XML\\ecp\\RelayState' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/ecp/RelayState.php',
        'SimpleSAML\\SAML2\\XML\\ecp\\Request' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/ecp/Request.php',
        'SimpleSAML\\SAML2\\XML\\ecp\\RequestAuthenticated' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/ecp/RequestAuthenticated.php',
        'SimpleSAML\\SAML2\\XML\\ecp\\Response' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/ecp/Response.php',
        'SimpleSAML\\SAML2\\XML\\ecp\\SubjectConfirmation' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/ecp/SubjectConfirmation.php',
        'SimpleSAML\\SAML2\\XML\\emd\\AbstractEmdElement' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/emd/AbstractEmdElement.php',
        'SimpleSAML\\SAML2\\XML\\emd\\RepublishRequest' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/emd/RepublishRequest.php',
        'SimpleSAML\\SAML2\\XML\\emd\\RepublishTarget' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/emd/RepublishTarget.php',
        'SimpleSAML\\SAML2\\XML\\idpdisc\\DiscoveryResponse' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/idpdisc/DiscoveryResponse.php',
        'SimpleSAML\\SAML2\\XML\\init\\RequestInitiator' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/init/RequestInitiator.php',
        'SimpleSAML\\SAML2\\XML\\md\\AbstractEndpointType' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/AbstractEndpointType.php',
        'SimpleSAML\\SAML2\\XML\\md\\AbstractIndexedEndpointType' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/AbstractIndexedEndpointType.php',
        'SimpleSAML\\SAML2\\XML\\md\\AbstractLocalizedName' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/AbstractLocalizedName.php',
        'SimpleSAML\\SAML2\\XML\\md\\AbstractLocalizedURI' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/AbstractLocalizedURI.php',
        'SimpleSAML\\SAML2\\XML\\md\\AbstractMdElement' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/AbstractMdElement.php',
        'SimpleSAML\\SAML2\\XML\\md\\AbstractMetadataDocument' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/AbstractMetadataDocument.php',
        'SimpleSAML\\SAML2\\XML\\md\\AbstractRoleDescriptor' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/AbstractRoleDescriptor.php',
        'SimpleSAML\\SAML2\\XML\\md\\AbstractRoleDescriptorType' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/AbstractRoleDescriptorType.php',
        'SimpleSAML\\SAML2\\XML\\md\\AbstractSSODescriptor' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/AbstractSSODescriptor.php',
        'SimpleSAML\\SAML2\\XML\\md\\AbstractSignedMdElement' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/AbstractSignedMdElement.php',
        'SimpleSAML\\SAML2\\XML\\md\\AdditionalMetadataLocation' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/AdditionalMetadataLocation.php',
        'SimpleSAML\\SAML2\\XML\\md\\AffiliateMember' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/AffiliateMember.php',
        'SimpleSAML\\SAML2\\XML\\md\\AffiliationDescriptor' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/AffiliationDescriptor.php',
        'SimpleSAML\\SAML2\\XML\\md\\ArtifactResolutionService' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/ArtifactResolutionService.php',
        'SimpleSAML\\SAML2\\XML\\md\\AssertionConsumerService' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/AssertionConsumerService.php',
        'SimpleSAML\\SAML2\\XML\\md\\AssertionIDRequestService' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/AssertionIDRequestService.php',
        'SimpleSAML\\SAML2\\XML\\md\\AttributeAuthorityDescriptor' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/AttributeAuthorityDescriptor.php',
        'SimpleSAML\\SAML2\\XML\\md\\AttributeConsumingService' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/AttributeConsumingService.php',
        'SimpleSAML\\SAML2\\XML\\md\\AttributeProfile' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/AttributeProfile.php',
        'SimpleSAML\\SAML2\\XML\\md\\AttributeService' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/AttributeService.php',
        'SimpleSAML\\SAML2\\XML\\md\\AuthnAuthorityDescriptor' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/AuthnAuthorityDescriptor.php',
        'SimpleSAML\\SAML2\\XML\\md\\AuthnQueryService' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/AuthnQueryService.php',
        'SimpleSAML\\SAML2\\XML\\md\\AuthzService' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/AuthzService.php',
        'SimpleSAML\\SAML2\\XML\\md\\Company' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/Company.php',
        'SimpleSAML\\SAML2\\XML\\md\\ContactPerson' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/ContactPerson.php',
        'SimpleSAML\\SAML2\\XML\\md\\EmailAddress' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/EmailAddress.php',
        'SimpleSAML\\SAML2\\XML\\md\\EncryptionMethod' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/EncryptionMethod.php',
        'SimpleSAML\\SAML2\\XML\\md\\EntitiesDescriptor' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/EntitiesDescriptor.php',
        'SimpleSAML\\SAML2\\XML\\md\\EntityDescriptor' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/EntityDescriptor.php',
        'SimpleSAML\\SAML2\\XML\\md\\Extensions' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/Extensions.php',
        'SimpleSAML\\SAML2\\XML\\md\\GivenName' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/GivenName.php',
        'SimpleSAML\\SAML2\\XML\\md\\IDPSSODescriptor' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/IDPSSODescriptor.php',
        'SimpleSAML\\SAML2\\XML\\md\\IndexedElementTrait' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/IndexedElementTrait.php',
        'SimpleSAML\\SAML2\\XML\\md\\KeyDescriptor' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/KeyDescriptor.php',
        'SimpleSAML\\SAML2\\XML\\md\\ManageNameIDService' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/ManageNameIDService.php',
        'SimpleSAML\\SAML2\\XML\\md\\NameIDFormat' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/NameIDFormat.php',
        'SimpleSAML\\SAML2\\XML\\md\\NameIDMappingService' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/NameIDMappingService.php',
        'SimpleSAML\\SAML2\\XML\\md\\Organization' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/Organization.php',
        'SimpleSAML\\SAML2\\XML\\md\\OrganizationDisplayName' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/OrganizationDisplayName.php',
        'SimpleSAML\\SAML2\\XML\\md\\OrganizationName' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/OrganizationName.php',
        'SimpleSAML\\SAML2\\XML\\md\\OrganizationURL' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/OrganizationURL.php',
        'SimpleSAML\\SAML2\\XML\\md\\PDPDescriptor' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/PDPDescriptor.php',
        'SimpleSAML\\SAML2\\XML\\md\\RequestedAttribute' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/RequestedAttribute.php',
        'SimpleSAML\\SAML2\\XML\\md\\SPSSODescriptor' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/SPSSODescriptor.php',
        'SimpleSAML\\SAML2\\XML\\md\\ServiceDescription' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/ServiceDescription.php',
        'SimpleSAML\\SAML2\\XML\\md\\ServiceName' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/ServiceName.php',
        'SimpleSAML\\SAML2\\XML\\md\\SingleLogoutService' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/SingleLogoutService.php',
        'SimpleSAML\\SAML2\\XML\\md\\SingleSignOnService' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/SingleSignOnService.php',
        'SimpleSAML\\SAML2\\XML\\md\\SurName' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/SurName.php',
        'SimpleSAML\\SAML2\\XML\\md\\TelephoneNumber' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/TelephoneNumber.php',
        'SimpleSAML\\SAML2\\XML\\md\\UnknownRoleDescriptor' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/md/UnknownRoleDescriptor.php',
        'SimpleSAML\\SAML2\\XML\\mdattr\\AbstractMdattrElement' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/mdattr/AbstractMdattrElement.php',
        'SimpleSAML\\SAML2\\XML\\mdattr\\EntityAttributes' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/mdattr/EntityAttributes.php',
        'SimpleSAML\\SAML2\\XML\\mdrpi\\AbstractMdrpiElement' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/mdrpi/AbstractMdrpiElement.php',
        'SimpleSAML\\SAML2\\XML\\mdrpi\\Publication' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/mdrpi/Publication.php',
        'SimpleSAML\\SAML2\\XML\\mdrpi\\PublicationInfo' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/mdrpi/PublicationInfo.php',
        'SimpleSAML\\SAML2\\XML\\mdrpi\\PublicationPath' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/mdrpi/PublicationPath.php',
        'SimpleSAML\\SAML2\\XML\\mdrpi\\RegistrationInfo' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/mdrpi/RegistrationInfo.php',
        'SimpleSAML\\SAML2\\XML\\mdrpi\\RegistrationPolicy' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/mdrpi/RegistrationPolicy.php',
        'SimpleSAML\\SAML2\\XML\\mdrpi\\UsagePolicy' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/mdrpi/UsagePolicy.php',
        'SimpleSAML\\SAML2\\XML\\mdui\\AbstractMduiElement' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/mdui/AbstractMduiElement.php',
        'SimpleSAML\\SAML2\\XML\\mdui\\Description' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/mdui/Description.php',
        'SimpleSAML\\SAML2\\XML\\mdui\\DiscoHints' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/mdui/DiscoHints.php',
        'SimpleSAML\\SAML2\\XML\\mdui\\DisplayName' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/mdui/DisplayName.php',
        'SimpleSAML\\SAML2\\XML\\mdui\\DomainHint' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/mdui/DomainHint.php',
        'SimpleSAML\\SAML2\\XML\\mdui\\GeolocationHint' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/mdui/GeolocationHint.php',
        'SimpleSAML\\SAML2\\XML\\mdui\\IPHint' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/mdui/IPHint.php',
        'SimpleSAML\\SAML2\\XML\\mdui\\InformationURL' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/mdui/InformationURL.php',
        'SimpleSAML\\SAML2\\XML\\mdui\\Keywords' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/mdui/Keywords.php',
        'SimpleSAML\\SAML2\\XML\\mdui\\Logo' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/mdui/Logo.php',
        'SimpleSAML\\SAML2\\XML\\mdui\\PrivacyStatementURL' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/mdui/PrivacyStatementURL.php',
        'SimpleSAML\\SAML2\\XML\\mdui\\UIInfo' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/mdui/UIInfo.php',
        'SimpleSAML\\SAML2\\XML\\saml\\AbstractBaseID' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/saml/AbstractBaseID.php',
        'SimpleSAML\\SAML2\\XML\\saml\\AbstractBaseIDType' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/saml/AbstractBaseIDType.php',
        'SimpleSAML\\SAML2\\XML\\saml\\AbstractCondition' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/saml/AbstractCondition.php',
        'SimpleSAML\\SAML2\\XML\\saml\\AbstractConditionType' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/saml/AbstractConditionType.php',
        'SimpleSAML\\SAML2\\XML\\saml\\AbstractSamlElement' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/saml/AbstractSamlElement.php',
        'SimpleSAML\\SAML2\\XML\\saml\\AbstractStatement' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/saml/AbstractStatement.php',
        'SimpleSAML\\SAML2\\XML\\saml\\AbstractStatementType' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/saml/AbstractStatementType.php',
        'SimpleSAML\\SAML2\\XML\\saml\\Action' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/saml/Action.php',
        'SimpleSAML\\SAML2\\XML\\saml\\Advice' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/saml/Advice.php',
        'SimpleSAML\\SAML2\\XML\\saml\\Assertion' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/saml/Assertion.php',
        'SimpleSAML\\SAML2\\XML\\saml\\AssertionIDRef' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/saml/AssertionIDRef.php',
        'SimpleSAML\\SAML2\\XML\\saml\\AssertionURIRef' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/saml/AssertionURIRef.php',
        'SimpleSAML\\SAML2\\XML\\saml\\Attribute' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/saml/Attribute.php',
        'SimpleSAML\\SAML2\\XML\\saml\\AttributeStatement' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/saml/AttributeStatement.php',
        'SimpleSAML\\SAML2\\XML\\saml\\AttributeValue' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/saml/AttributeValue.php',
        'SimpleSAML\\SAML2\\XML\\saml\\Audience' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/saml/Audience.php',
        'SimpleSAML\\SAML2\\XML\\saml\\AudienceRestriction' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/saml/AudienceRestriction.php',
        'SimpleSAML\\SAML2\\XML\\saml\\AuthenticatingAuthority' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/saml/AuthenticatingAuthority.php',
        'SimpleSAML\\SAML2\\XML\\saml\\AuthnContext' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/saml/AuthnContext.php',
        'SimpleSAML\\SAML2\\XML\\saml\\AuthnContextClassRef' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/saml/AuthnContextClassRef.php',
        'SimpleSAML\\SAML2\\XML\\saml\\AuthnContextDecl' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/saml/AuthnContextDecl.php',
        'SimpleSAML\\SAML2\\XML\\saml\\AuthnContextDeclRef' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/saml/AuthnContextDeclRef.php',
        'SimpleSAML\\SAML2\\XML\\saml\\AuthnStatement' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/saml/AuthnStatement.php',
        'SimpleSAML\\SAML2\\XML\\saml\\AuthzDecisionStatement' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/saml/AuthzDecisionStatement.php',
        'SimpleSAML\\SAML2\\XML\\saml\\BaseIdentifierInterface' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/saml/BaseIdentifierInterface.php',
        'SimpleSAML\\SAML2\\XML\\saml\\Conditions' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/saml/Conditions.php',
        'SimpleSAML\\SAML2\\XML\\saml\\EncryptedAssertion' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/saml/EncryptedAssertion.php',
        'SimpleSAML\\SAML2\\XML\\saml\\EncryptedAttribute' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/saml/EncryptedAttribute.php',
        'SimpleSAML\\SAML2\\XML\\saml\\EncryptedID' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/saml/EncryptedID.php',
        'SimpleSAML\\SAML2\\XML\\saml\\Evidence' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/saml/Evidence.php',
        'SimpleSAML\\SAML2\\XML\\saml\\IDNameQualifiersTrait' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/saml/IDNameQualifiersTrait.php',
        'SimpleSAML\\SAML2\\XML\\saml\\IdentifierInterface' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/saml/IdentifierInterface.php',
        'SimpleSAML\\SAML2\\XML\\saml\\Issuer' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/saml/Issuer.php',
        'SimpleSAML\\SAML2\\XML\\saml\\NameID' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/saml/NameID.php',
        'SimpleSAML\\SAML2\\XML\\saml\\NameIDType' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/saml/NameIDType.php',
        'SimpleSAML\\SAML2\\XML\\saml\\OneTimeUse' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/saml/OneTimeUse.php',
        'SimpleSAML\\SAML2\\XML\\saml\\ProxyRestriction' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/saml/ProxyRestriction.php',
        'SimpleSAML\\SAML2\\XML\\saml\\Subject' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/saml/Subject.php',
        'SimpleSAML\\SAML2\\XML\\saml\\SubjectConfirmation' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/saml/SubjectConfirmation.php',
        'SimpleSAML\\SAML2\\XML\\saml\\SubjectConfirmationData' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/saml/SubjectConfirmationData.php',
        'SimpleSAML\\SAML2\\XML\\saml\\SubjectLocality' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/saml/SubjectLocality.php',
        'SimpleSAML\\SAML2\\XML\\saml\\UnknownCondition' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/saml/UnknownCondition.php',
        'SimpleSAML\\SAML2\\XML\\saml\\UnknownID' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/saml/UnknownID.php',
        'SimpleSAML\\SAML2\\XML\\saml\\UnknownStatement' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/saml/UnknownStatement.php',
        'SimpleSAML\\SAML2\\XML\\samlp\\AbstractMessage' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/samlp/AbstractMessage.php',
        'SimpleSAML\\SAML2\\XML\\samlp\\AbstractRequest' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/samlp/AbstractRequest.php',
        'SimpleSAML\\SAML2\\XML\\samlp\\AbstractSamlpElement' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/samlp/AbstractSamlpElement.php',
        'SimpleSAML\\SAML2\\XML\\samlp\\AbstractStatusResponse' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/samlp/AbstractStatusResponse.php',
        'SimpleSAML\\SAML2\\XML\\samlp\\AbstractSubjectQuery' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/samlp/AbstractSubjectQuery.php',
        'SimpleSAML\\SAML2\\XML\\samlp\\Artifact' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/samlp/Artifact.php',
        'SimpleSAML\\SAML2\\XML\\samlp\\ArtifactResolve' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/samlp/ArtifactResolve.php',
        'SimpleSAML\\SAML2\\XML\\samlp\\ArtifactResponse' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/samlp/ArtifactResponse.php',
        'SimpleSAML\\SAML2\\XML\\samlp\\AssertionIDRequest' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/samlp/AssertionIDRequest.php',
        'SimpleSAML\\SAML2\\XML\\samlp\\AttributeQuery' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/samlp/AttributeQuery.php',
        'SimpleSAML\\SAML2\\XML\\samlp\\AuthnQuery' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/samlp/AuthnQuery.php',
        'SimpleSAML\\SAML2\\XML\\samlp\\AuthnRequest' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/samlp/AuthnRequest.php',
        'SimpleSAML\\SAML2\\XML\\samlp\\AuthzDecisionQuery' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/samlp/AuthzDecisionQuery.php',
        'SimpleSAML\\SAML2\\XML\\samlp\\Extensions' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/samlp/Extensions.php',
        'SimpleSAML\\SAML2\\XML\\samlp\\GetComplete' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/samlp/GetComplete.php',
        'SimpleSAML\\SAML2\\XML\\samlp\\IDPEntry' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/samlp/IDPEntry.php',
        'SimpleSAML\\SAML2\\XML\\samlp\\IDPList' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/samlp/IDPList.php',
        'SimpleSAML\\SAML2\\XML\\samlp\\LogoutRequest' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/samlp/LogoutRequest.php',
        'SimpleSAML\\SAML2\\XML\\samlp\\LogoutResponse' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/samlp/LogoutResponse.php',
        'SimpleSAML\\SAML2\\XML\\samlp\\MessageFactory' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/samlp/MessageFactory.php',
        'SimpleSAML\\SAML2\\XML\\samlp\\NameIDPolicy' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/samlp/NameIDPolicy.php',
        'SimpleSAML\\SAML2\\XML\\samlp\\RequestedAuthnContext' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/samlp/RequestedAuthnContext.php',
        'SimpleSAML\\SAML2\\XML\\samlp\\RequesterID' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/samlp/RequesterID.php',
        'SimpleSAML\\SAML2\\XML\\samlp\\Response' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/samlp/Response.php',
        'SimpleSAML\\SAML2\\XML\\samlp\\Scoping' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/samlp/Scoping.php',
        'SimpleSAML\\SAML2\\XML\\samlp\\SessionIndex' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/samlp/SessionIndex.php',
        'SimpleSAML\\SAML2\\XML\\samlp\\Status' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/samlp/Status.php',
        'SimpleSAML\\SAML2\\XML\\samlp\\StatusCode' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/samlp/StatusCode.php',
        'SimpleSAML\\SAML2\\XML\\samlp\\StatusDetail' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/samlp/StatusDetail.php',
        'SimpleSAML\\SAML2\\XML\\samlp\\StatusMessage' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/samlp/StatusMessage.php',
        'SimpleSAML\\SAML2\\XML\\shibmd\\AbstractShibmdElement' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/shibmd/AbstractShibmdElement.php',
        'SimpleSAML\\SAML2\\XML\\shibmd\\KeyAuthority' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/shibmd/KeyAuthority.php',
        'SimpleSAML\\SAML2\\XML\\shibmd\\Scope' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/shibmd/Scope.php',
        'SimpleSAML\\SAML2\\XML\\subjectid\\SignalEnum' => __DIR__ . '/..' . '/simplesamlphp/saml2/src/XML/subjectid/SignalEnum.php',
        'SimpleSAML\\SOAP\\Constants' => __DIR__ . '/..' . '/simplesamlphp/xml-soap/src/Constants.php',
        'SimpleSAML\\SOAP\\Exception\\ProtocolViolationException' => __DIR__ . '/..' . '/simplesamlphp/xml-soap/src/Exception/ProtocolViolationException.php',
        'SimpleSAML\\SOAP\\Exception\\RuntimeException' => __DIR__ . '/..' . '/simplesamlphp/xml-soap/src/Exception/RuntimeException.php',
        'SimpleSAML\\SOAP\\Utils\\XPath' => __DIR__ . '/..' . '/simplesamlphp/xml-soap/src/Utils/XPath.php',
        'SimpleSAML\\SOAP\\XML\\env_200106\\AbstractSoapElement' => __DIR__ . '/..' . '/simplesamlphp/xml-soap/src/XML/env_200106/AbstractSoapElement.php',
        'SimpleSAML\\SOAP\\XML\\env_200106\\Body' => __DIR__ . '/..' . '/simplesamlphp/xml-soap/src/XML/env_200106/Body.php',
        'SimpleSAML\\SOAP\\XML\\env_200106\\Detail' => __DIR__ . '/..' . '/simplesamlphp/xml-soap/src/XML/env_200106/Detail.php',
        'SimpleSAML\\SOAP\\XML\\env_200106\\Envelope' => __DIR__ . '/..' . '/simplesamlphp/xml-soap/src/XML/env_200106/Envelope.php',
        'SimpleSAML\\SOAP\\XML\\env_200106\\Fault' => __DIR__ . '/..' . '/simplesamlphp/xml-soap/src/XML/env_200106/Fault.php',
        'SimpleSAML\\SOAP\\XML\\env_200106\\FaultActor' => __DIR__ . '/..' . '/simplesamlphp/xml-soap/src/XML/env_200106/FaultActor.php',
        'SimpleSAML\\SOAP\\XML\\env_200106\\FaultCode' => __DIR__ . '/..' . '/simplesamlphp/xml-soap/src/XML/env_200106/FaultCode.php',
        'SimpleSAML\\SOAP\\XML\\env_200106\\FaultString' => __DIR__ . '/..' . '/simplesamlphp/xml-soap/src/XML/env_200106/FaultString.php',
        'SimpleSAML\\SOAP\\XML\\env_200106\\Header' => __DIR__ . '/..' . '/simplesamlphp/xml-soap/src/XML/env_200106/Header.php',
        'SimpleSAML\\SOAP\\XML\\env_200305\\AbstractSoapElement' => __DIR__ . '/..' . '/simplesamlphp/xml-soap/src/XML/env_200305/AbstractSoapElement.php',
        'SimpleSAML\\SOAP\\XML\\env_200305\\Body' => __DIR__ . '/..' . '/simplesamlphp/xml-soap/src/XML/env_200305/Body.php',
        'SimpleSAML\\SOAP\\XML\\env_200305\\Code' => __DIR__ . '/..' . '/simplesamlphp/xml-soap/src/XML/env_200305/Code.php',
        'SimpleSAML\\SOAP\\XML\\env_200305\\Detail' => __DIR__ . '/..' . '/simplesamlphp/xml-soap/src/XML/env_200305/Detail.php',
        'SimpleSAML\\SOAP\\XML\\env_200305\\Envelope' => __DIR__ . '/..' . '/simplesamlphp/xml-soap/src/XML/env_200305/Envelope.php',
        'SimpleSAML\\SOAP\\XML\\env_200305\\Fault' => __DIR__ . '/..' . '/simplesamlphp/xml-soap/src/XML/env_200305/Fault.php',
        'SimpleSAML\\SOAP\\XML\\env_200305\\FaultEnum' => __DIR__ . '/..' . '/simplesamlphp/xml-soap/src/XML/env_200305/FaultEnum.php',
        'SimpleSAML\\SOAP\\XML\\env_200305\\Header' => __DIR__ . '/..' . '/simplesamlphp/xml-soap/src/XML/env_200305/Header.php',
        'SimpleSAML\\SOAP\\XML\\env_200305\\Node' => __DIR__ . '/..' . '/simplesamlphp/xml-soap/src/XML/env_200305/Node.php',
        'SimpleSAML\\SOAP\\XML\\env_200305\\NotUnderstood' => __DIR__ . '/..' . '/simplesamlphp/xml-soap/src/XML/env_200305/NotUnderstood.php',
        'SimpleSAML\\SOAP\\XML\\env_200305\\Reason' => __DIR__ . '/..' . '/simplesamlphp/xml-soap/src/XML/env_200305/Reason.php',
        'SimpleSAML\\SOAP\\XML\\env_200305\\Role' => __DIR__ . '/..' . '/simplesamlphp/xml-soap/src/XML/env_200305/Role.php',
        'SimpleSAML\\SOAP\\XML\\env_200305\\Subcode' => __DIR__ . '/..' . '/simplesamlphp/xml-soap/src/XML/env_200305/Subcode.php',
        'SimpleSAML\\SOAP\\XML\\env_200305\\SupportedEnvelope' => __DIR__ . '/..' . '/simplesamlphp/xml-soap/src/XML/env_200305/SupportedEnvelope.php',
        'SimpleSAML\\SOAP\\XML\\env_200305\\Text' => __DIR__ . '/..' . '/simplesamlphp/xml-soap/src/XML/env_200305/Text.php',
        'SimpleSAML\\SOAP\\XML\\env_200305\\Upgrade' => __DIR__ . '/..' . '/simplesamlphp/xml-soap/src/XML/env_200305/Upgrade.php',
        'SimpleSAML\\SOAP\\XML\\env_200305\\Value' => __DIR__ . '/..' . '/simplesamlphp/xml-soap/src/XML/env_200305/Value.php',
        'SimpleSAML\\Session' => __DIR__ . '/../..' . '/src/SimpleSAML/Session.php',
        'SimpleSAML\\SessionHandler' => __DIR__ . '/../..' . '/src/SimpleSAML/SessionHandler.php',
        'SimpleSAML\\SessionHandlerCookie' => __DIR__ . '/../..' . '/src/SimpleSAML/SessionHandlerCookie.php',
        'SimpleSAML\\SessionHandlerPHP' => __DIR__ . '/../..' . '/src/SimpleSAML/SessionHandlerPHP.php',
        'SimpleSAML\\SessionHandlerStore' => __DIR__ . '/../..' . '/src/SimpleSAML/SessionHandlerStore.php',
        'SimpleSAML\\Stats' => __DIR__ . '/../..' . '/src/SimpleSAML/Stats.php',
        'SimpleSAML\\Stats\\Output' => __DIR__ . '/../..' . '/src/SimpleSAML/Stats/Output.php',
        'SimpleSAML\\Store\\MemcacheStore' => __DIR__ . '/../..' . '/src/SimpleSAML/Store/MemcacheStore.php',
        'SimpleSAML\\Store\\RedisStore' => __DIR__ . '/../..' . '/src/SimpleSAML/Store/RedisStore.php',
        'SimpleSAML\\Store\\SQLStore' => __DIR__ . '/../..' . '/src/SimpleSAML/Store/SQLStore.php',
        'SimpleSAML\\Store\\StoreFactory' => __DIR__ . '/../..' . '/src/SimpleSAML/Store/StoreFactory.php',
        'SimpleSAML\\Store\\StoreInterface' => __DIR__ . '/../..' . '/src/SimpleSAML/Store/StoreInterface.php',
        'SimpleSAML\\Utils\\Arrays' => __DIR__ . '/../..' . '/src/SimpleSAML/Utils/Arrays.php',
        'SimpleSAML\\Utils\\Attributes' => __DIR__ . '/../..' . '/src/SimpleSAML/Utils/Attributes.php',
        'SimpleSAML\\Utils\\Auth' => __DIR__ . '/../..' . '/src/SimpleSAML/Utils/Auth.php',
        'SimpleSAML\\Utils\\ClearableState' => __DIR__ . '/../..' . '/src/SimpleSAML/Utils/ClearableState.php',
        'SimpleSAML\\Utils\\Config' => __DIR__ . '/../..' . '/src/SimpleSAML/Utils/Config.php',
        'SimpleSAML\\Utils\\Config\\Metadata' => __DIR__ . '/../..' . '/src/SimpleSAML/Utils/Config/Metadata.php',
        'SimpleSAML\\Utils\\Crypto' => __DIR__ . '/../..' . '/src/SimpleSAML/Utils/Crypto.php',
        'SimpleSAML\\Utils\\EMail' => __DIR__ . '/../..' . '/src/SimpleSAML/Utils/EMail.php',
        'SimpleSAML\\Utils\\HTTP' => __DIR__ . '/../..' . '/src/SimpleSAML/Utils/HTTP.php',
        'SimpleSAML\\Utils\\Net' => __DIR__ . '/../..' . '/src/SimpleSAML/Utils/Net.php',
        'SimpleSAML\\Utils\\Random' => __DIR__ . '/../..' . '/src/SimpleSAML/Utils/Random.php',
        'SimpleSAML\\Utils\\System' => __DIR__ . '/../..' . '/src/SimpleSAML/Utils/System.php',
        'SimpleSAML\\Utils\\Time' => __DIR__ . '/../..' . '/src/SimpleSAML/Utils/Time.php',
        'SimpleSAML\\Utils\\Translate' => __DIR__ . '/../..' . '/src/SimpleSAML/Utils/Translate.php',
        'SimpleSAML\\Utils\\XML' => __DIR__ . '/../..' . '/src/SimpleSAML/Utils/XML.php',
        'SimpleSAML\\XHTML\\IdPDisco' => __DIR__ . '/../..' . '/src/SimpleSAML/XHTML/IdPDisco.php',
        'SimpleSAML\\XHTML\\Template' => __DIR__ . '/../..' . '/src/SimpleSAML/XHTML/Template.php',
        'SimpleSAML\\XHTML\\TemplateControllerInterface' => __DIR__ . '/../..' . '/src/SimpleSAML/XHTML/TemplateControllerInterface.php',
        'SimpleSAML\\XHTML\\TemplateLoader' => __DIR__ . '/../..' . '/src/SimpleSAML/XHTML/TemplateLoader.php',
        'SimpleSAML\\XMLSecurity\\Alg\\AlgorithmInterface' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/Alg/AlgorithmInterface.php',
        'SimpleSAML\\XMLSecurity\\Alg\\Encryption\\AES' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/Alg/Encryption/AES.php',
        'SimpleSAML\\XMLSecurity\\Alg\\Encryption\\AbstractEncryptor' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/Alg/Encryption/AbstractEncryptor.php',
        'SimpleSAML\\XMLSecurity\\Alg\\Encryption\\EncryptionAlgorithmFactory' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/Alg/Encryption/EncryptionAlgorithmFactory.php',
        'SimpleSAML\\XMLSecurity\\Alg\\Encryption\\EncryptionAlgorithmInterface' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/Alg/Encryption/EncryptionAlgorithmInterface.php',
        'SimpleSAML\\XMLSecurity\\Alg\\Encryption\\TripleDES' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/Alg/Encryption/TripleDES.php',
        'SimpleSAML\\XMLSecurity\\Alg\\KeyTransport\\AbstractKeyTransporter' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/Alg/KeyTransport/AbstractKeyTransporter.php',
        'SimpleSAML\\XMLSecurity\\Alg\\KeyTransport\\KeyTransportAlgorithmFactory' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/Alg/KeyTransport/KeyTransportAlgorithmFactory.php',
        'SimpleSAML\\XMLSecurity\\Alg\\KeyTransport\\KeyTransportAlgorithmInterface' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/Alg/KeyTransport/KeyTransportAlgorithmInterface.php',
        'SimpleSAML\\XMLSecurity\\Alg\\KeyTransport\\RSA' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/Alg/KeyTransport/RSA.php',
        'SimpleSAML\\XMLSecurity\\Alg\\Signature\\AbstractSigner' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/Alg/Signature/AbstractSigner.php',
        'SimpleSAML\\XMLSecurity\\Alg\\Signature\\HMAC' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/Alg/Signature/HMAC.php',
        'SimpleSAML\\XMLSecurity\\Alg\\Signature\\RSA' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/Alg/Signature/RSA.php',
        'SimpleSAML\\XMLSecurity\\Alg\\Signature\\SignatureAlgorithmFactory' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/Alg/Signature/SignatureAlgorithmFactory.php',
        'SimpleSAML\\XMLSecurity\\Alg\\Signature\\SignatureAlgorithmInterface' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/Alg/Signature/SignatureAlgorithmInterface.php',
        'SimpleSAML\\XMLSecurity\\Assert\\Assert' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/Assert/Assert.php',
        'SimpleSAML\\XMLSecurity\\Backend\\EncryptionBackend' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/Backend/EncryptionBackend.php',
        'SimpleSAML\\XMLSecurity\\Backend\\HMAC' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/Backend/HMAC.php',
        'SimpleSAML\\XMLSecurity\\Backend\\OpenSSL' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/Backend/OpenSSL.php',
        'SimpleSAML\\XMLSecurity\\Backend\\SignatureBackend' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/Backend/SignatureBackend.php',
        'SimpleSAML\\XMLSecurity\\Constants' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/Constants.php',
        'SimpleSAML\\XMLSecurity\\CryptoEncoding\\PEM' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/CryptoEncoding/PEM.php',
        'SimpleSAML\\XMLSecurity\\CryptoEncoding\\PEMBundle' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/CryptoEncoding/PEMBundle.php',
        'SimpleSAML\\XMLSecurity\\Exception\\BlacklistedAlgorithmException' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/Exception/BlacklistedAlgorithmException.php',
        'SimpleSAML\\XMLSecurity\\Exception\\CanonicalizationFailedException' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/Exception/CanonicalizationFailedException.php',
        'SimpleSAML\\XMLSecurity\\Exception\\IOException' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/Exception/IOException.php',
        'SimpleSAML\\XMLSecurity\\Exception\\InvalidArgumentException' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/Exception/InvalidArgumentException.php',
        'SimpleSAML\\XMLSecurity\\Exception\\NoEncryptedDataException' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/Exception/NoEncryptedDataException.php',
        'SimpleSAML\\XMLSecurity\\Exception\\NoSignatureFoundException' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/Exception/NoSignatureFoundException.php',
        'SimpleSAML\\XMLSecurity\\Exception\\OpenSSLException' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/Exception/OpenSSLException.php',
        'SimpleSAML\\XMLSecurity\\Exception\\ReferenceValidationFailedException' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/Exception/ReferenceValidationFailedException.php',
        'SimpleSAML\\XMLSecurity\\Exception\\RuntimeException' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/Exception/RuntimeException.php',
        'SimpleSAML\\XMLSecurity\\Exception\\SignatureVerificationFailedException' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/Exception/SignatureVerificationFailedException.php',
        'SimpleSAML\\XMLSecurity\\Exception\\UnsupportedAlgorithmException' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/Exception/UnsupportedAlgorithmException.php',
        'SimpleSAML\\XMLSecurity\\Key\\AsymmetricKey' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/Key/AsymmetricKey.php',
        'SimpleSAML\\XMLSecurity\\Key\\KeyInterface' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/Key/KeyInterface.php',
        'SimpleSAML\\XMLSecurity\\Key\\PrivateKey' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/Key/PrivateKey.php',
        'SimpleSAML\\XMLSecurity\\Key\\PublicKey' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/Key/PublicKey.php',
        'SimpleSAML\\XMLSecurity\\Key\\SymmetricKey' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/Key/SymmetricKey.php',
        'SimpleSAML\\XMLSecurity\\Key\\X509Certificate' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/Key/X509Certificate.php',
        'SimpleSAML\\XMLSecurity\\TestUtils\\PEMCertificatesMock' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/TestUtils/PEMCertificatesMock.php',
        'SimpleSAML\\XMLSecurity\\TestUtils\\SignedElementTestTrait' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/TestUtils/SignedElementTestTrait.php',
        'SimpleSAML\\XMLSecurity\\Utils\\Certificate' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/Utils/Certificate.php',
        'SimpleSAML\\XMLSecurity\\Utils\\Random' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/Utils/Random.php',
        'SimpleSAML\\XMLSecurity\\Utils\\XML' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/Utils/XML.php',
        'SimpleSAML\\XMLSecurity\\Utils\\XPath' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/Utils/XPath.php',
        'SimpleSAML\\XMLSecurity\\XML\\CanonicalizableElementInterface' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/CanonicalizableElementInterface.php',
        'SimpleSAML\\XMLSecurity\\XML\\CanonicalizableElementTrait' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/CanonicalizableElementTrait.php',
        'SimpleSAML\\XMLSecurity\\XML\\EncryptableElementInterface' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/EncryptableElementInterface.php',
        'SimpleSAML\\XMLSecurity\\XML\\EncryptableElementTrait' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/EncryptableElementTrait.php',
        'SimpleSAML\\XMLSecurity\\XML\\EncryptedElementInterface' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/EncryptedElementInterface.php',
        'SimpleSAML\\XMLSecurity\\XML\\EncryptedElementTrait' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/EncryptedElementTrait.php',
        'SimpleSAML\\XMLSecurity\\XML\\SignableElementInterface' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/SignableElementInterface.php',
        'SimpleSAML\\XMLSecurity\\XML\\SignableElementTrait' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/SignableElementTrait.php',
        'SimpleSAML\\XMLSecurity\\XML\\SignedElementInterface' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/SignedElementInterface.php',
        'SimpleSAML\\XMLSecurity\\XML\\SignedElementTrait' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/SignedElementTrait.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\AbstractDSAKeyValueType' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/AbstractDSAKeyValueType.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\AbstractDsElement' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/AbstractDsElement.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\AbstractKeyInfoType' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/AbstractKeyInfoType.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\AbstractPGPDataType' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/AbstractPGPDataType.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\AbstractSPKIDataType' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/AbstractSPKIDataType.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\CanonicalizationMethod' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/CanonicalizationMethod.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\DSAKeyValue' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/DSAKeyValue.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\DigestMethod' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/DigestMethod.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\DigestValue' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/DigestValue.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\DsObject' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/DsObject.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\Exponent' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/Exponent.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\G' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/G.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\HMACOutputLength' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/HMACOutputLength.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\J' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/J.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\KeyInfo' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/KeyInfo.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\KeyName' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/KeyName.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\KeyValue' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/KeyValue.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\Manifest' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/Manifest.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\MgmtData' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/MgmtData.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\Modulus' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/Modulus.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\P' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/P.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\PGPData' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/PGPData.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\PGPKeyID' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/PGPKeyID.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\PGPKeyPacket' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/PGPKeyPacket.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\PgenCounter' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/PgenCounter.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\Q' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/Q.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\RSAKeyValue' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/RSAKeyValue.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\Reference' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/Reference.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\RetrievalMethod' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/RetrievalMethod.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\SPKIData' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/SPKIData.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\SPKISexp' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/SPKISexp.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\Seed' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/Seed.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\Signature' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/Signature.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\SignatureMethod' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/SignatureMethod.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\SignatureProperties' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/SignatureProperties.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\SignatureProperty' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/SignatureProperty.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\SignatureValue' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/SignatureValue.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\SignedInfo' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/SignedInfo.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\Transform' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/Transform.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\Transforms' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/Transforms.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\X509CRL' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/X509CRL.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\X509Certificate' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/X509Certificate.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\X509Data' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/X509Data.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\X509IssuerName' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/X509IssuerName.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\X509IssuerSerial' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/X509IssuerSerial.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\X509SKI' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/X509SKI.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\X509SerialNumber' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/X509SerialNumber.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\X509SubjectName' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/X509SubjectName.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\XPath' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/XPath.php',
        'SimpleSAML\\XMLSecurity\\XML\\ds\\Y' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ds/Y.php',
        'SimpleSAML\\XMLSecurity\\XML\\dsig11\\A' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/dsig11/A.php',
        'SimpleSAML\\XMLSecurity\\XML\\dsig11\\AbstractCharTwoFieldParamsType' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/dsig11/AbstractCharTwoFieldParamsType.php',
        'SimpleSAML\\XMLSecurity\\XML\\dsig11\\AbstractCurveType' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/dsig11/AbstractCurveType.php',
        'SimpleSAML\\XMLSecurity\\XML\\dsig11\\AbstractDsig11Element' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/dsig11/AbstractDsig11Element.php',
        'SimpleSAML\\XMLSecurity\\XML\\dsig11\\AbstractECKeyValueType' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/dsig11/AbstractECKeyValueType.php',
        'SimpleSAML\\XMLSecurity\\XML\\dsig11\\AbstractECParametersType' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/dsig11/AbstractECParametersType.php',
        'SimpleSAML\\XMLSecurity\\XML\\dsig11\\AbstractECValidationDataType' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/dsig11/AbstractECValidationDataType.php',
        'SimpleSAML\\XMLSecurity\\XML\\dsig11\\AbstractFieldIDType' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/dsig11/AbstractFieldIDType.php',
        'SimpleSAML\\XMLSecurity\\XML\\dsig11\\AbstractNamedCurveType' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/dsig11/AbstractNamedCurveType.php',
        'SimpleSAML\\XMLSecurity\\XML\\dsig11\\AbstractPnBFieldParamsType' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/dsig11/AbstractPnBFieldParamsType.php',
        'SimpleSAML\\XMLSecurity\\XML\\dsig11\\AbstractPrimeFieldParamsType' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/dsig11/AbstractPrimeFieldParamsType.php',
        'SimpleSAML\\XMLSecurity\\XML\\dsig11\\AbstractTnBFieldParamsType' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/dsig11/AbstractTnBFieldParamsType.php',
        'SimpleSAML\\XMLSecurity\\XML\\dsig11\\B' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/dsig11/B.php',
        'SimpleSAML\\XMLSecurity\\XML\\dsig11\\Base' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/dsig11/Base.php',
        'SimpleSAML\\XMLSecurity\\XML\\dsig11\\CoFactor' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/dsig11/CoFactor.php',
        'SimpleSAML\\XMLSecurity\\XML\\dsig11\\Curve' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/dsig11/Curve.php',
        'SimpleSAML\\XMLSecurity\\XML\\dsig11\\DEREncodedKeyValue' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/dsig11/DEREncodedKeyValue.php',
        'SimpleSAML\\XMLSecurity\\XML\\dsig11\\ECKeyValue' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/dsig11/ECKeyValue.php',
        'SimpleSAML\\XMLSecurity\\XML\\dsig11\\ECParameters' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/dsig11/ECParameters.php',
        'SimpleSAML\\XMLSecurity\\XML\\dsig11\\FieldID' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/dsig11/FieldID.php',
        'SimpleSAML\\XMLSecurity\\XML\\dsig11\\GnB' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/dsig11/GnB.php',
        'SimpleSAML\\XMLSecurity\\XML\\dsig11\\K' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/dsig11/K.php',
        'SimpleSAML\\XMLSecurity\\XML\\dsig11\\K1' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/dsig11/K1.php',
        'SimpleSAML\\XMLSecurity\\XML\\dsig11\\K2' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/dsig11/K2.php',
        'SimpleSAML\\XMLSecurity\\XML\\dsig11\\K3' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/dsig11/K3.php',
        'SimpleSAML\\XMLSecurity\\XML\\dsig11\\KeyInfoReference' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/dsig11/KeyInfoReference.php',
        'SimpleSAML\\XMLSecurity\\XML\\dsig11\\M' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/dsig11/M.php',
        'SimpleSAML\\XMLSecurity\\XML\\dsig11\\NamedCurve' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/dsig11/NamedCurve.php',
        'SimpleSAML\\XMLSecurity\\XML\\dsig11\\Order' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/dsig11/Order.php',
        'SimpleSAML\\XMLSecurity\\XML\\dsig11\\P' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/dsig11/P.php',
        'SimpleSAML\\XMLSecurity\\XML\\dsig11\\PnB' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/dsig11/PnB.php',
        'SimpleSAML\\XMLSecurity\\XML\\dsig11\\Prime' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/dsig11/Prime.php',
        'SimpleSAML\\XMLSecurity\\XML\\dsig11\\PublicKey' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/dsig11/PublicKey.php',
        'SimpleSAML\\XMLSecurity\\XML\\dsig11\\Seed' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/dsig11/Seed.php',
        'SimpleSAML\\XMLSecurity\\XML\\dsig11\\TnB' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/dsig11/TnB.php',
        'SimpleSAML\\XMLSecurity\\XML\\dsig11\\ValidationData' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/dsig11/ValidationData.php',
        'SimpleSAML\\XMLSecurity\\XML\\dsig11\\X509Digest' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/dsig11/X509Digest.php',
        'SimpleSAML\\XMLSecurity\\XML\\ec\\AbstractEcElement' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ec/AbstractEcElement.php',
        'SimpleSAML\\XMLSecurity\\XML\\ec\\InclusiveNamespaces' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/ec/InclusiveNamespaces.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc11\\AbstractAlgorithmIdentifierType' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc11/AbstractAlgorithmIdentifierType.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc11\\AbstractConcatKDFParamsType' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc11/AbstractConcatKDFParamsType.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc11\\AbstractDerivedKeyType' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc11/AbstractDerivedKeyType.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc11\\AbstractKeyDerivationMethodType' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc11/AbstractKeyDerivationMethodType.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc11\\AbstractMGFType' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc11/AbstractMGFType.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc11\\AbstractPBKDF2ParameterType' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc11/AbstractPBKDF2ParameterType.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc11\\AbstractPRFAlgorithmIdentifierType' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc11/AbstractPRFAlgorithmIdentifierType.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc11\\AbstractXenc11Element' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc11/AbstractXenc11Element.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc11\\ConcatKDFParams' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc11/ConcatKDFParams.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc11\\DerivedKey' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc11/DerivedKey.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc11\\DerivedKeyName' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc11/DerivedKeyName.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc11\\IterationCount' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc11/IterationCount.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc11\\KeyDerivationMethod' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc11/KeyDerivationMethod.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc11\\KeyLength' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc11/KeyLength.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc11\\MGF' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc11/MGF.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc11\\MasterKeyName' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc11/MasterKeyName.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc11\\OtherSource' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc11/OtherSource.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc11\\PBKDF2params' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc11/PBKDF2params.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc11\\PRF' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc11/PRF.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc11\\Parameters' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc11/Parameters.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc11\\Salt' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc11/Salt.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc11\\Specified' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc11/Specified.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc\\AbstractAgreementMethodType' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc/AbstractAgreementMethodType.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc\\AbstractDHKeyValueType' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc/AbstractDHKeyValueType.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc\\AbstractEncryptedType' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc/AbstractEncryptedType.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc\\AbstractEncryptionMethod' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc/AbstractEncryptionMethod.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc\\AbstractEncryptionPropertiesType' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc/AbstractEncryptionPropertiesType.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc\\AbstractEncryptionPropertyType' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc/AbstractEncryptionPropertyType.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc\\AbstractReference' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc/AbstractReference.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc\\AbstractXencElement' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc/AbstractXencElement.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc\\AgreementMethod' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc/AgreementMethod.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc\\CarriedKeyName' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc/CarriedKeyName.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc\\CipherData' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc/CipherData.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc\\CipherReference' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc/CipherReference.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc\\CipherValue' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc/CipherValue.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc\\DHKeyValue' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc/DHKeyValue.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc\\DataReference' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc/DataReference.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc\\EncryptedData' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc/EncryptedData.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc\\EncryptedKey' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc/EncryptedKey.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc\\EncryptionMethod' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc/EncryptionMethod.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc\\EncryptionProperties' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc/EncryptionProperties.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc\\EncryptionProperty' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc/EncryptionProperty.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc\\Generator' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc/Generator.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc\\KANonce' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc/KANonce.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc\\KeyReference' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc/KeyReference.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc\\KeySize' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc/KeySize.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc\\OAEPparams' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc/OAEPparams.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc\\OriginatorKeyInfo' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc/OriginatorKeyInfo.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc\\P' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc/P.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc\\PgenCounter' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc/PgenCounter.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc\\Q' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc/Q.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc\\RecipientKeyInfo' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc/RecipientKeyInfo.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc\\ReferenceList' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc/ReferenceList.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc\\Seed' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc/Seed.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc\\Transforms' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc/Transforms.php',
        'SimpleSAML\\XMLSecurity\\XML\\xenc\\XencPublic' => __DIR__ . '/..' . '/simplesamlphp/xml-security/src/XML/xenc/XencPublic.php',
        'SimpleSAML\\XML\\AbstractElement' => __DIR__ . '/..' . '/simplesamlphp/xml-common/src/AbstractElement.php',
        'SimpleSAML\\XML\\ArrayizableElementInterface' => __DIR__ . '/..' . '/simplesamlphp/xml-common/src/ArrayizableElementInterface.php',
        'SimpleSAML\\XML\\Assert\\Assert' => __DIR__ . '/..' . '/simplesamlphp/xml-common/src/Assert/Assert.php',
        'SimpleSAML\\XML\\Assert\\DateTimeTrait' => __DIR__ . '/..' . '/simplesamlphp/xml-common/src/Assert/DateTimeTrait.php',
        'SimpleSAML\\XML\\Assert\\DurationTrait' => __DIR__ . '/..' . '/simplesamlphp/xml-common/src/Assert/DurationTrait.php',
        'SimpleSAML\\XML\\Assert\\HexBinTrait' => __DIR__ . '/..' . '/simplesamlphp/xml-common/src/Assert/HexBinTrait.php',
        'SimpleSAML\\XML\\Assert\\NamesTrait' => __DIR__ . '/..' . '/simplesamlphp/xml-common/src/Assert/NamesTrait.php',
        'SimpleSAML\\XML\\Assert\\TokensTrait' => __DIR__ . '/..' . '/simplesamlphp/xml-common/src/Assert/TokensTrait.php',
        'SimpleSAML\\XML\\Assert\\XPathFilterTrait' => __DIR__ . '/..' . '/simplesamlphp/xml-common/src/Assert/XPathFilterTrait.php',
        'SimpleSAML\\XML\\Attribute' => __DIR__ . '/..' . '/simplesamlphp/xml-common/src/Attribute.php',
        'SimpleSAML\\XML\\Base64ElementTrait' => __DIR__ . '/..' . '/simplesamlphp/xml-common/src/Base64ElementTrait.php',
        'SimpleSAML\\XML\\BooleanElementTrait' => __DIR__ . '/..' . '/simplesamlphp/xml-common/src/BooleanElementTrait.php',
        'SimpleSAML\\XML\\Chunk' => __DIR__ . '/..' . '/simplesamlphp/xml-common/src/Chunk.php',
        'SimpleSAML\\XML\\Constants' => __DIR__ . '/..' . '/simplesamlphp/xml-common/src/Constants.php',
        'SimpleSAML\\XML\\DOMDocumentFactory' => __DIR__ . '/..' . '/simplesamlphp/xml-common/src/DOMDocumentFactory.php',
        'SimpleSAML\\XML\\ElementInterface' => __DIR__ . '/..' . '/simplesamlphp/xml-common/src/ElementInterface.php',
        'SimpleSAML\\XML\\Errors' => __DIR__ . '/../..' . '/src/SimpleSAML/XML/Errors.php',
        'SimpleSAML\\XML\\Exception\\IOException' => __DIR__ . '/..' . '/simplesamlphp/xml-common/src/Exception/IOException.php',
        'SimpleSAML\\XML\\Exception\\InvalidDOMElementException' => __DIR__ . '/..' . '/simplesamlphp/xml-common/src/Exception/InvalidDOMElementException.php',
        'SimpleSAML\\XML\\Exception\\MissingAttributeException' => __DIR__ . '/..' . '/simplesamlphp/xml-common/src/Exception/MissingAttributeException.php',
        'SimpleSAML\\XML\\Exception\\MissingElementException' => __DIR__ . '/..' . '/simplesamlphp/xml-common/src/Exception/MissingElementException.php',
        'SimpleSAML\\XML\\Exception\\RuntimeException' => __DIR__ . '/..' . '/simplesamlphp/xml-common/src/Exception/RuntimeException.php',
        'SimpleSAML\\XML\\Exception\\SchemaViolationException' => __DIR__ . '/..' . '/simplesamlphp/xml-common/src/Exception/SchemaViolationException.php',
        'SimpleSAML\\XML\\Exception\\TooManyElementsException' => __DIR__ . '/..' . '/simplesamlphp/xml-common/src/Exception/TooManyElementsException.php',
        'SimpleSAML\\XML\\Exception\\UnparseableXMLException' => __DIR__ . '/..' . '/simplesamlphp/xml-common/src/Exception/UnparseableXMLException.php',
        'SimpleSAML\\XML\\ExtendableAttributesTrait' => __DIR__ . '/..' . '/simplesamlphp/xml-common/src/ExtendableAttributesTrait.php',
        'SimpleSAML\\XML\\ExtendableElementTrait' => __DIR__ . '/..' . '/simplesamlphp/xml-common/src/ExtendableElementTrait.php',
        'SimpleSAML\\XML\\HexBinaryElementTrait' => __DIR__ . '/..' . '/simplesamlphp/xml-common/src/HexBinaryElementTrait.php',
        'SimpleSAML\\XML\\IntegerElementTrait' => __DIR__ . '/..' . '/simplesamlphp/xml-common/src/IntegerElementTrait.php',
        'SimpleSAML\\XML\\LocalizedStringElementTrait' => __DIR__ . '/..' . '/simplesamlphp/xml-common/src/LocalizedStringElementTrait.php',
        'SimpleSAML\\XML\\Parser' => __DIR__ . '/../..' . '/src/SimpleSAML/XML/Parser.php',
        'SimpleSAML\\XML\\QNameElementTrait' => __DIR__ . '/..' . '/simplesamlphp/xml-common/src/QNameElementTrait.php',
        'SimpleSAML\\XML\\Registry\\ElementRegistry' => __DIR__ . '/..' . '/simplesamlphp/xml-common/src/Registry/ElementRegistry.php',
        'SimpleSAML\\XML\\SchemaValidatableElementInterface' => __DIR__ . '/..' . '/simplesamlphp/xml-common/src/SchemaValidatableElementInterface.php',
        'SimpleSAML\\XML\\SchemaValidatableElementTrait' => __DIR__ . '/..' . '/simplesamlphp/xml-common/src/SchemaValidatableElementTrait.php',
        'SimpleSAML\\XML\\SerializableElementInterface' => __DIR__ . '/..' . '/simplesamlphp/xml-common/src/SerializableElementInterface.php',
        'SimpleSAML\\XML\\SerializableElementTrait' => __DIR__ . '/..' . '/simplesamlphp/xml-common/src/SerializableElementTrait.php',
        'SimpleSAML\\XML\\Signer' => __DIR__ . '/../..' . '/src/SimpleSAML/XML/Signer.php',
        'SimpleSAML\\XML\\StringElementTrait' => __DIR__ . '/..' . '/simplesamlphp/xml-common/src/StringElementTrait.php',
        'SimpleSAML\\XML\\TestUtils\\ArrayizableElementTestTrait' => __DIR__ . '/..' . '/simplesamlphp/xml-common/src/TestUtils/ArrayizableElementTestTrait.php',
        'SimpleSAML\\XML\\TestUtils\\SchemaValidationTestTrait' => __DIR__ . '/..' . '/simplesamlphp/xml-common/src/TestUtils/SchemaValidationTestTrait.php',
        'SimpleSAML\\XML\\TestUtils\\SerializableElementTestTrait' => __DIR__ . '/..' . '/simplesamlphp/xml-common/src/TestUtils/SerializableElementTestTrait.php',
        'SimpleSAML\\XML\\URIElementTrait' => __DIR__ . '/..' . '/simplesamlphp/xml-common/src/URIElementTrait.php',
        'SimpleSAML\\XML\\Utils' => __DIR__ . '/..' . '/simplesamlphp/xml-common/src/Utils.php',
        'SimpleSAML\\XML\\Utils\\Random' => __DIR__ . '/..' . '/simplesamlphp/xml-common/src/Utils/Random.php',
        'SimpleSAML\\XML\\Utils\\XPath' => __DIR__ . '/..' . '/simplesamlphp/xml-common/src/Utils/XPath.php',
        'SimpleSAML\\XML\\Utils\\XPathFilter' => __DIR__ . '/..' . '/simplesamlphp/xml-common/src/Utils/XPathFilter.php',
        'SimpleSAML\\XML\\Validator' => __DIR__ . '/../..' . '/src/SimpleSAML/XML/Validator.php',
        'SimpleSAML\\XML\\XsNamespace' => __DIR__ . '/..' . '/simplesamlphp/xml-common/src/XsNamespace.php',
        'Stringable' => __DIR__ . '/..' . '/symfony/polyfill-php80/Resources/stubs/Stringable.php',
        'Symfony\\Bridge\\Twig\\AppVariable' => __DIR__ . '/..' . '/symfony/twig-bridge/AppVariable.php',
        'Symfony\\Bridge\\Twig\\Attribute\\Template' => __DIR__ . '/..' . '/symfony/twig-bridge/Attribute/Template.php',
        'Symfony\\Bridge\\Twig\\Command\\DebugCommand' => __DIR__ . '/..' . '/symfony/twig-bridge/Command/DebugCommand.php',
        'Symfony\\Bridge\\Twig\\Command\\LintCommand' => __DIR__ . '/..' . '/symfony/twig-bridge/Command/LintCommand.php',
        'Symfony\\Bridge\\Twig\\DataCollector\\TwigDataCollector' => __DIR__ . '/..' . '/symfony/twig-bridge/DataCollector/TwigDataCollector.php',
        'Symfony\\Bridge\\Twig\\ErrorRenderer\\TwigErrorRenderer' => __DIR__ . '/..' . '/symfony/twig-bridge/ErrorRenderer/TwigErrorRenderer.php',
        'Symfony\\Bridge\\Twig\\EventListener\\TemplateAttributeListener' => __DIR__ . '/..' . '/symfony/twig-bridge/EventListener/TemplateAttributeListener.php',
        'Symfony\\Bridge\\Twig\\Extension\\AssetExtension' => __DIR__ . '/..' . '/symfony/twig-bridge/Extension/AssetExtension.php',
        'Symfony\\Bridge\\Twig\\Extension\\CodeExtension' => __DIR__ . '/..' . '/symfony/twig-bridge/Extension/CodeExtension.php',
        'Symfony\\Bridge\\Twig\\Extension\\CsrfExtension' => __DIR__ . '/..' . '/symfony/twig-bridge/Extension/CsrfExtension.php',
        'Symfony\\Bridge\\Twig\\Extension\\CsrfRuntime' => __DIR__ . '/..' . '/symfony/twig-bridge/Extension/CsrfRuntime.php',
        'Symfony\\Bridge\\Twig\\Extension\\DumpExtension' => __DIR__ . '/..' . '/symfony/twig-bridge/Extension/DumpExtension.php',
        'Symfony\\Bridge\\Twig\\Extension\\ExpressionExtension' => __DIR__ . '/..' . '/symfony/twig-bridge/Extension/ExpressionExtension.php',
        'Symfony\\Bridge\\Twig\\Extension\\FormExtension' => __DIR__ . '/..' . '/symfony/twig-bridge/Extension/FormExtension.php',
        'Symfony\\Bridge\\Twig\\Extension\\HtmlSanitizerExtension' => __DIR__ . '/..' . '/symfony/twig-bridge/Extension/HtmlSanitizerExtension.php',
        'Symfony\\Bridge\\Twig\\Extension\\HttpFoundationExtension' => __DIR__ . '/..' . '/symfony/twig-bridge/Extension/HttpFoundationExtension.php',
        'Symfony\\Bridge\\Twig\\Extension\\HttpKernelExtension' => __DIR__ . '/..' . '/symfony/twig-bridge/Extension/HttpKernelExtension.php',
        'Symfony\\Bridge\\Twig\\Extension\\HttpKernelRuntime' => __DIR__ . '/..' . '/symfony/twig-bridge/Extension/HttpKernelRuntime.php',
        'Symfony\\Bridge\\Twig\\Extension\\ImportMapExtension' => __DIR__ . '/..' . '/symfony/twig-bridge/Extension/ImportMapExtension.php',
        'Symfony\\Bridge\\Twig\\Extension\\ImportMapRuntime' => __DIR__ . '/..' . '/symfony/twig-bridge/Extension/ImportMapRuntime.php',
        'Symfony\\Bridge\\Twig\\Extension\\LogoutUrlExtension' => __DIR__ . '/..' . '/symfony/twig-bridge/Extension/LogoutUrlExtension.php',
        'Symfony\\Bridge\\Twig\\Extension\\ProfilerExtension' => __DIR__ . '/..' . '/symfony/twig-bridge/Extension/ProfilerExtension.php',
        'Symfony\\Bridge\\Twig\\Extension\\RoutingExtension' => __DIR__ . '/..' . '/symfony/twig-bridge/Extension/RoutingExtension.php',
        'Symfony\\Bridge\\Twig\\Extension\\SecurityExtension' => __DIR__ . '/..' . '/symfony/twig-bridge/Extension/SecurityExtension.php',
        'Symfony\\Bridge\\Twig\\Extension\\SerializerExtension' => __DIR__ . '/..' . '/symfony/twig-bridge/Extension/SerializerExtension.php',
        'Symfony\\Bridge\\Twig\\Extension\\SerializerRuntime' => __DIR__ . '/..' . '/symfony/twig-bridge/Extension/SerializerRuntime.php',
        'Symfony\\Bridge\\Twig\\Extension\\StopwatchExtension' => __DIR__ . '/..' . '/symfony/twig-bridge/Extension/StopwatchExtension.php',
        'Symfony\\Bridge\\Twig\\Extension\\TranslationExtension' => __DIR__ . '/..' . '/symfony/twig-bridge/Extension/TranslationExtension.php',
        'Symfony\\Bridge\\Twig\\Extension\\WebLinkExtension' => __DIR__ . '/..' . '/symfony/twig-bridge/Extension/WebLinkExtension.php',
        'Symfony\\Bridge\\Twig\\Extension\\WorkflowExtension' => __DIR__ . '/..' . '/symfony/twig-bridge/Extension/WorkflowExtension.php',
        'Symfony\\Bridge\\Twig\\Extension\\YamlExtension' => __DIR__ . '/..' . '/symfony/twig-bridge/Extension/YamlExtension.php',
        'Symfony\\Bridge\\Twig\\Form\\TwigRendererEngine' => __DIR__ . '/..' . '/symfony/twig-bridge/Form/TwigRendererEngine.php',
        'Symfony\\Bridge\\Twig\\Mime\\BodyRenderer' => __DIR__ . '/..' . '/symfony/twig-bridge/Mime/BodyRenderer.php',
        'Symfony\\Bridge\\Twig\\Mime\\NotificationEmail' => __DIR__ . '/..' . '/symfony/twig-bridge/Mime/NotificationEmail.php',
        'Symfony\\Bridge\\Twig\\Mime\\TemplatedEmail' => __DIR__ . '/..' . '/symfony/twig-bridge/Mime/TemplatedEmail.php',
        'Symfony\\Bridge\\Twig\\Mime\\WrappedTemplatedEmail' => __DIR__ . '/..' . '/symfony/twig-bridge/Mime/WrappedTemplatedEmail.php',
        'Symfony\\Bridge\\Twig\\NodeVisitor\\Scope' => __DIR__ . '/..' . '/symfony/twig-bridge/NodeVisitor/Scope.php',
        'Symfony\\Bridge\\Twig\\NodeVisitor\\TranslationDefaultDomainNodeVisitor' => __DIR__ . '/..' . '/symfony/twig-bridge/NodeVisitor/TranslationDefaultDomainNodeVisitor.php',
        'Symfony\\Bridge\\Twig\\NodeVisitor\\TranslationNodeVisitor' => __DIR__ . '/..' . '/symfony/twig-bridge/NodeVisitor/TranslationNodeVisitor.php',
        'Symfony\\Bridge\\Twig\\Node\\DumpNode' => __DIR__ . '/..' . '/symfony/twig-bridge/Node/DumpNode.php',
        'Symfony\\Bridge\\Twig\\Node\\FormThemeNode' => __DIR__ . '/..' . '/symfony/twig-bridge/Node/FormThemeNode.php',
        'Symfony\\Bridge\\Twig\\Node\\RenderBlockNode' => __DIR__ . '/..' . '/symfony/twig-bridge/Node/RenderBlockNode.php',
        'Symfony\\Bridge\\Twig\\Node\\SearchAndRenderBlockNode' => __DIR__ . '/..' . '/symfony/twig-bridge/Node/SearchAndRenderBlockNode.php',
        'Symfony\\Bridge\\Twig\\Node\\StopwatchNode' => __DIR__ . '/..' . '/symfony/twig-bridge/Node/StopwatchNode.php',
        'Symfony\\Bridge\\Twig\\Node\\TransDefaultDomainNode' => __DIR__ . '/..' . '/symfony/twig-bridge/Node/TransDefaultDomainNode.php',
        'Symfony\\Bridge\\Twig\\Node\\TransNode' => __DIR__ . '/..' . '/symfony/twig-bridge/Node/TransNode.php',
        'Symfony\\Bridge\\Twig\\Test\\FormLayoutTestCase' => __DIR__ . '/..' . '/symfony/twig-bridge/Test/FormLayoutTestCase.php',
        'Symfony\\Bridge\\Twig\\Test\\Traits\\RuntimeLoaderProvider' => __DIR__ . '/..' . '/symfony/twig-bridge/Test/Traits/RuntimeLoaderProvider.php',
        'Symfony\\Bridge\\Twig\\TokenParser\\DumpTokenParser' => __DIR__ . '/..' . '/symfony/twig-bridge/TokenParser/DumpTokenParser.php',
        'Symfony\\Bridge\\Twig\\TokenParser\\FormThemeTokenParser' => __DIR__ . '/..' . '/symfony/twig-bridge/TokenParser/FormThemeTokenParser.php',
        'Symfony\\Bridge\\Twig\\TokenParser\\StopwatchTokenParser' => __DIR__ . '/..' . '/symfony/twig-bridge/TokenParser/StopwatchTokenParser.php',
        'Symfony\\Bridge\\Twig\\TokenParser\\TransDefaultDomainTokenParser' => __DIR__ . '/..' . '/symfony/twig-bridge/TokenParser/TransDefaultDomainTokenParser.php',
        'Symfony\\Bridge\\Twig\\TokenParser\\TransTokenParser' => __DIR__ . '/..' . '/symfony/twig-bridge/TokenParser/TransTokenParser.php',
        'Symfony\\Bridge\\Twig\\Translation\\TwigExtractor' => __DIR__ . '/..' . '/symfony/twig-bridge/Translation/TwigExtractor.php',
        'Symfony\\Bridge\\Twig\\UndefinedCallableHandler' => __DIR__ . '/..' . '/symfony/twig-bridge/UndefinedCallableHandler.php',
        'Symfony\\Bundle\\FrameworkBundle\\CacheWarmer\\AbstractPhpFileCacheWarmer' => __DIR__ . '/..' . '/symfony/framework-bundle/CacheWarmer/AbstractPhpFileCacheWarmer.php',
        'Symfony\\Bundle\\FrameworkBundle\\CacheWarmer\\AnnotationsCacheWarmer' => __DIR__ . '/..' . '/symfony/framework-bundle/CacheWarmer/AnnotationsCacheWarmer.php',
        'Symfony\\Bundle\\FrameworkBundle\\CacheWarmer\\CachePoolClearerCacheWarmer' => __DIR__ . '/..' . '/symfony/framework-bundle/CacheWarmer/CachePoolClearerCacheWarmer.php',
        'Symfony\\Bundle\\FrameworkBundle\\CacheWarmer\\ConfigBuilderCacheWarmer' => __DIR__ . '/..' . '/symfony/framework-bundle/CacheWarmer/ConfigBuilderCacheWarmer.php',
        'Symfony\\Bundle\\FrameworkBundle\\CacheWarmer\\RouterCacheWarmer' => __DIR__ . '/..' . '/symfony/framework-bundle/CacheWarmer/RouterCacheWarmer.php',
        'Symfony\\Bundle\\FrameworkBundle\\CacheWarmer\\SerializerCacheWarmer' => __DIR__ . '/..' . '/symfony/framework-bundle/CacheWarmer/SerializerCacheWarmer.php',
        'Symfony\\Bundle\\FrameworkBundle\\CacheWarmer\\TranslationsCacheWarmer' => __DIR__ . '/..' . '/symfony/framework-bundle/CacheWarmer/TranslationsCacheWarmer.php',
        'Symfony\\Bundle\\FrameworkBundle\\CacheWarmer\\ValidatorCacheWarmer' => __DIR__ . '/..' . '/symfony/framework-bundle/CacheWarmer/ValidatorCacheWarmer.php',
        'Symfony\\Bundle\\FrameworkBundle\\Command\\AboutCommand' => __DIR__ . '/..' . '/symfony/framework-bundle/Command/AboutCommand.php',
        'Symfony\\Bundle\\FrameworkBundle\\Command\\AbstractConfigCommand' => __DIR__ . '/..' . '/symfony/framework-bundle/Command/AbstractConfigCommand.php',
        'Symfony\\Bundle\\FrameworkBundle\\Command\\AssetsInstallCommand' => __DIR__ . '/..' . '/symfony/framework-bundle/Command/AssetsInstallCommand.php',
        'Symfony\\Bundle\\FrameworkBundle\\Command\\BuildDebugContainerTrait' => __DIR__ . '/..' . '/symfony/framework-bundle/Command/BuildDebugContainerTrait.php',
        'Symfony\\Bundle\\FrameworkBundle\\Command\\CacheClearCommand' => __DIR__ . '/..' . '/symfony/framework-bundle/Command/CacheClearCommand.php',
        'Symfony\\Bundle\\FrameworkBundle\\Command\\CachePoolClearCommand' => __DIR__ . '/..' . '/symfony/framework-bundle/Command/CachePoolClearCommand.php',
        'Symfony\\Bundle\\FrameworkBundle\\Command\\CachePoolDeleteCommand' => __DIR__ . '/..' . '/symfony/framework-bundle/Command/CachePoolDeleteCommand.php',
        'Symfony\\Bundle\\FrameworkBundle\\Command\\CachePoolInvalidateTagsCommand' => __DIR__ . '/..' . '/symfony/framework-bundle/Command/CachePoolInvalidateTagsCommand.php',
        'Symfony\\Bundle\\FrameworkBundle\\Command\\CachePoolListCommand' => __DIR__ . '/..' . '/symfony/framework-bundle/Command/CachePoolListCommand.php',
        'Symfony\\Bundle\\FrameworkBundle\\Command\\CachePoolPruneCommand' => __DIR__ . '/..' . '/symfony/framework-bundle/Command/CachePoolPruneCommand.php',
        'Symfony\\Bundle\\FrameworkBundle\\Command\\CacheWarmupCommand' => __DIR__ . '/..' . '/symfony/framework-bundle/Command/CacheWarmupCommand.php',
        'Symfony\\Bundle\\FrameworkBundle\\Command\\ConfigDebugCommand' => __DIR__ . '/..' . '/symfony/framework-bundle/Command/ConfigDebugCommand.php',
        'Symfony\\Bundle\\FrameworkBundle\\Command\\ConfigDumpReferenceCommand' => __DIR__ . '/..' . '/symfony/framework-bundle/Command/ConfigDumpReferenceCommand.php',
        'Symfony\\Bundle\\FrameworkBundle\\Command\\ContainerDebugCommand' => __DIR__ . '/..' . '/symfony/framework-bundle/Command/ContainerDebugCommand.php',
        'Symfony\\Bundle\\FrameworkBundle\\Command\\ContainerLintCommand' => __DIR__ . '/..' . '/symfony/framework-bundle/Command/ContainerLintCommand.php',
        'Symfony\\Bundle\\FrameworkBundle\\Command\\DebugAutowiringCommand' => __DIR__ . '/..' . '/symfony/framework-bundle/Command/DebugAutowiringCommand.php',
        'Symfony\\Bundle\\FrameworkBundle\\Command\\EventDispatcherDebugCommand' => __DIR__ . '/..' . '/symfony/framework-bundle/Command/EventDispatcherDebugCommand.php',
        'Symfony\\Bundle\\FrameworkBundle\\Command\\RouterDebugCommand' => __DIR__ . '/..' . '/symfony/framework-bundle/Command/RouterDebugCommand.php',
        'Symfony\\Bundle\\FrameworkBundle\\Command\\RouterMatchCommand' => __DIR__ . '/..' . '/symfony/framework-bundle/Command/RouterMatchCommand.php',
        'Symfony\\Bundle\\FrameworkBundle\\Command\\SecretsDecryptToLocalCommand' => __DIR__ . '/..' . '/symfony/framework-bundle/Command/SecretsDecryptToLocalCommand.php',
        'Symfony\\Bundle\\FrameworkBundle\\Command\\SecretsEncryptFromLocalCommand' => __DIR__ . '/..' . '/symfony/framework-bundle/Command/SecretsEncryptFromLocalCommand.php',
        'Symfony\\Bundle\\FrameworkBundle\\Command\\SecretsGenerateKeysCommand' => __DIR__ . '/..' . '/symfony/framework-bundle/Command/SecretsGenerateKeysCommand.php',
        'Symfony\\Bundle\\FrameworkBundle\\Command\\SecretsListCommand' => __DIR__ . '/..' . '/symfony/framework-bundle/Command/SecretsListCommand.php',
        'Symfony\\Bundle\\FrameworkBundle\\Command\\SecretsRemoveCommand' => __DIR__ . '/..' . '/symfony/framework-bundle/Command/SecretsRemoveCommand.php',
        'Symfony\\Bundle\\FrameworkBundle\\Command\\SecretsSetCommand' => __DIR__ . '/..' . '/symfony/framework-bundle/Command/SecretsSetCommand.php',
        'Symfony\\Bundle\\FrameworkBundle\\Command\\TranslationDebugCommand' => __DIR__ . '/..' . '/symfony/framework-bundle/Command/TranslationDebugCommand.php',
        'Symfony\\Bundle\\FrameworkBundle\\Command\\TranslationUpdateCommand' => __DIR__ . '/..' . '/symfony/framework-bundle/Command/TranslationUpdateCommand.php',
        'Symfony\\Bundle\\FrameworkBundle\\Command\\WorkflowDumpCommand' => __DIR__ . '/..' . '/symfony/framework-bundle/Command/WorkflowDumpCommand.php',
        'Symfony\\Bundle\\FrameworkBundle\\Command\\XliffLintCommand' => __DIR__ . '/..' . '/symfony/framework-bundle/Command/XliffLintCommand.php',
        'Symfony\\Bundle\\FrameworkBundle\\Command\\YamlLintCommand' => __DIR__ . '/..' . '/symfony/framework-bundle/Command/YamlLintCommand.php',
        'Symfony\\Bundle\\FrameworkBundle\\Console\\Application' => __DIR__ . '/..' . '/symfony/framework-bundle/Console/Application.php',
        'Symfony\\Bundle\\FrameworkBundle\\Console\\Descriptor\\Descriptor' => __DIR__ . '/..' . '/symfony/framework-bundle/Console/Descriptor/Descriptor.php',
        'Symfony\\Bundle\\FrameworkBundle\\Console\\Descriptor\\JsonDescriptor' => __DIR__ . '/..' . '/symfony/framework-bundle/Console/Descriptor/JsonDescriptor.php',
        'Symfony\\Bundle\\FrameworkBundle\\Console\\Descriptor\\MarkdownDescriptor' => __DIR__ . '/..' . '/symfony/framework-bundle/Console/Descriptor/MarkdownDescriptor.php',
        'Symfony\\Bundle\\FrameworkBundle\\Console\\Descriptor\\TextDescriptor' => __DIR__ . '/..' . '/symfony/framework-bundle/Console/Descriptor/TextDescriptor.php',
        'Symfony\\Bundle\\FrameworkBundle\\Console\\Descriptor\\XmlDescriptor' => __DIR__ . '/..' . '/symfony/framework-bundle/Console/Descriptor/XmlDescriptor.php',
        'Symfony\\Bundle\\FrameworkBundle\\Console\\Helper\\DescriptorHelper' => __DIR__ . '/..' . '/symfony/framework-bundle/Console/Helper/DescriptorHelper.php',
        'Symfony\\Bundle\\FrameworkBundle\\Controller\\AbstractController' => __DIR__ . '/..' . '/symfony/framework-bundle/Controller/AbstractController.php',
        'Symfony\\Bundle\\FrameworkBundle\\Controller\\ControllerResolver' => __DIR__ . '/..' . '/symfony/framework-bundle/Controller/ControllerResolver.php',
        'Symfony\\Bundle\\FrameworkBundle\\Controller\\RedirectController' => __DIR__ . '/..' . '/symfony/framework-bundle/Controller/RedirectController.php',
        'Symfony\\Bundle\\FrameworkBundle\\Controller\\TemplateController' => __DIR__ . '/..' . '/symfony/framework-bundle/Controller/TemplateController.php',
        'Symfony\\Bundle\\FrameworkBundle\\DataCollector\\AbstractDataCollector' => __DIR__ . '/..' . '/symfony/framework-bundle/DataCollector/AbstractDataCollector.php',
        'Symfony\\Bundle\\FrameworkBundle\\DataCollector\\RouterDataCollector' => __DIR__ . '/..' . '/symfony/framework-bundle/DataCollector/RouterDataCollector.php',
        'Symfony\\Bundle\\FrameworkBundle\\DataCollector\\TemplateAwareDataCollectorInterface' => __DIR__ . '/..' . '/symfony/framework-bundle/DataCollector/TemplateAwareDataCollectorInterface.php',
        'Symfony\\Bundle\\FrameworkBundle\\DependencyInjection\\Compiler\\AddAnnotationsCachedReaderPass' => __DIR__ . '/..' . '/symfony/framework-bundle/DependencyInjection/Compiler/AddAnnotationsCachedReaderPass.php',
        'Symfony\\Bundle\\FrameworkBundle\\DependencyInjection\\Compiler\\AddDebugLogProcessorPass' => __DIR__ . '/..' . '/symfony/framework-bundle/DependencyInjection/Compiler/AddDebugLogProcessorPass.php',
        'Symfony\\Bundle\\FrameworkBundle\\DependencyInjection\\Compiler\\AddExpressionLanguageProvidersPass' => __DIR__ . '/..' . '/symfony/framework-bundle/DependencyInjection/Compiler/AddExpressionLanguageProvidersPass.php',
        'Symfony\\Bundle\\FrameworkBundle\\DependencyInjection\\Compiler\\AssetsContextPass' => __DIR__ . '/..' . '/symfony/framework-bundle/DependencyInjection/Compiler/AssetsContextPass.php',
        'Symfony\\Bundle\\FrameworkBundle\\DependencyInjection\\Compiler\\ContainerBuilderDebugDumpPass' => __DIR__ . '/..' . '/symfony/framework-bundle/DependencyInjection/Compiler/ContainerBuilderDebugDumpPass.php',
        'Symfony\\Bundle\\FrameworkBundle\\DependencyInjection\\Compiler\\DataCollectorTranslatorPass' => __DIR__ . '/..' . '/symfony/framework-bundle/DependencyInjection/Compiler/DataCollectorTranslatorPass.php',
        'Symfony\\Bundle\\FrameworkBundle\\DependencyInjection\\Compiler\\EnableLoggerDebugModePass' => __DIR__ . '/..' . '/symfony/framework-bundle/DependencyInjection/Compiler/EnableLoggerDebugModePass.php',
        'Symfony\\Bundle\\FrameworkBundle\\DependencyInjection\\Compiler\\ErrorLoggerCompilerPass' => __DIR__ . '/..' . '/symfony/framework-bundle/DependencyInjection/Compiler/ErrorLoggerCompilerPass.php',
        'Symfony\\Bundle\\FrameworkBundle\\DependencyInjection\\Compiler\\LoggingTranslatorPass' => __DIR__ . '/..' . '/symfony/framework-bundle/DependencyInjection/Compiler/LoggingTranslatorPass.php',
        'Symfony\\Bundle\\FrameworkBundle\\DependencyInjection\\Compiler\\ProfilerPass' => __DIR__ . '/..' . '/symfony/framework-bundle/DependencyInjection/Compiler/ProfilerPass.php',
        'Symfony\\Bundle\\FrameworkBundle\\DependencyInjection\\Compiler\\RemoveUnusedSessionMarshallingHandlerPass' => __DIR__ . '/..' . '/symfony/framework-bundle/DependencyInjection/Compiler/RemoveUnusedSessionMarshallingHandlerPass.php',
        'Symfony\\Bundle\\FrameworkBundle\\DependencyInjection\\Compiler\\TestServiceContainerRealRefPass' => __DIR__ . '/..' . '/symfony/framework-bundle/DependencyInjection/Compiler/TestServiceContainerRealRefPass.php',
        'Symfony\\Bundle\\FrameworkBundle\\DependencyInjection\\Compiler\\TestServiceContainerWeakRefPass' => __DIR__ . '/..' . '/symfony/framework-bundle/DependencyInjection/Compiler/TestServiceContainerWeakRefPass.php',
        'Symfony\\Bundle\\FrameworkBundle\\DependencyInjection\\Compiler\\TranslationUpdateCommandPass' => __DIR__ . '/..' . '/symfony/framework-bundle/DependencyInjection/Compiler/TranslationUpdateCommandPass.php',
        'Symfony\\Bundle\\FrameworkBundle\\DependencyInjection\\Compiler\\UnusedTagsPass' => __DIR__ . '/..' . '/symfony/framework-bundle/DependencyInjection/Compiler/UnusedTagsPass.php',
        'Symfony\\Bundle\\FrameworkBundle\\DependencyInjection\\Compiler\\WorkflowGuardListenerPass' => __DIR__ . '/..' . '/symfony/framework-bundle/DependencyInjection/Compiler/WorkflowGuardListenerPass.php',
        'Symfony\\Bundle\\FrameworkBundle\\DependencyInjection\\Configuration' => __DIR__ . '/..' . '/symfony/framework-bundle/DependencyInjection/Configuration.php',
        'Symfony\\Bundle\\FrameworkBundle\\DependencyInjection\\FrameworkExtension' => __DIR__ . '/..' . '/symfony/framework-bundle/DependencyInjection/FrameworkExtension.php',
        'Symfony\\Bundle\\FrameworkBundle\\DependencyInjection\\VirtualRequestStackPass' => __DIR__ . '/..' . '/symfony/framework-bundle/DependencyInjection/VirtualRequestStackPass.php',
        'Symfony\\Bundle\\FrameworkBundle\\EventListener\\ConsoleProfilerListener' => __DIR__ . '/..' . '/symfony/framework-bundle/EventListener/ConsoleProfilerListener.php',
        'Symfony\\Bundle\\FrameworkBundle\\EventListener\\SuggestMissingPackageSubscriber' => __DIR__ . '/..' . '/symfony/framework-bundle/EventListener/SuggestMissingPackageSubscriber.php',
        'Symfony\\Bundle\\FrameworkBundle\\FrameworkBundle' => __DIR__ . '/..' . '/symfony/framework-bundle/FrameworkBundle.php',
        'Symfony\\Bundle\\FrameworkBundle\\HttpCache\\HttpCache' => __DIR__ . '/..' . '/symfony/framework-bundle/HttpCache/HttpCache.php',
        'Symfony\\Bundle\\FrameworkBundle\\KernelBrowser' => __DIR__ . '/..' . '/symfony/framework-bundle/KernelBrowser.php',
        'Symfony\\Bundle\\FrameworkBundle\\Kernel\\MicroKernelTrait' => __DIR__ . '/..' . '/symfony/framework-bundle/Kernel/MicroKernelTrait.php',
        'Symfony\\Bundle\\FrameworkBundle\\Routing\\AnnotatedRouteControllerLoader' => __DIR__ . '/..' . '/symfony/framework-bundle/Routing/AnnotatedRouteControllerLoader.php',
        'Symfony\\Bundle\\FrameworkBundle\\Routing\\AttributeRouteControllerLoader' => __DIR__ . '/..' . '/symfony/framework-bundle/Routing/AttributeRouteControllerLoader.php',
        'Symfony\\Bundle\\FrameworkBundle\\Routing\\Attribute\\AsRoutingConditionService' => __DIR__ . '/..' . '/symfony/framework-bundle/Routing/Attribute/AsRoutingConditionService.php',
        'Symfony\\Bundle\\FrameworkBundle\\Routing\\DelegatingLoader' => __DIR__ . '/..' . '/symfony/framework-bundle/Routing/DelegatingLoader.php',
        'Symfony\\Bundle\\FrameworkBundle\\Routing\\RedirectableCompiledUrlMatcher' => __DIR__ . '/..' . '/symfony/framework-bundle/Routing/RedirectableCompiledUrlMatcher.php',
        'Symfony\\Bundle\\FrameworkBundle\\Routing\\RouteLoaderInterface' => __DIR__ . '/..' . '/symfony/framework-bundle/Routing/RouteLoaderInterface.php',
        'Symfony\\Bundle\\FrameworkBundle\\Routing\\Router' => __DIR__ . '/..' . '/symfony/framework-bundle/Routing/Router.php',
        'Symfony\\Bundle\\FrameworkBundle\\Secrets\\AbstractVault' => __DIR__ . '/..' . '/symfony/framework-bundle/Secrets/AbstractVault.php',
        'Symfony\\Bundle\\FrameworkBundle\\Secrets\\DotenvVault' => __DIR__ . '/..' . '/symfony/framework-bundle/Secrets/DotenvVault.php',
        'Symfony\\Bundle\\FrameworkBundle\\Secrets\\SodiumVault' => __DIR__ . '/..' . '/symfony/framework-bundle/Secrets/SodiumVault.php',
        'Symfony\\Bundle\\FrameworkBundle\\Test\\BrowserKitAssertionsTrait' => __DIR__ . '/..' . '/symfony/framework-bundle/Test/BrowserKitAssertionsTrait.php',
        'Symfony\\Bundle\\FrameworkBundle\\Test\\DomCrawlerAssertionsTrait' => __DIR__ . '/..' . '/symfony/framework-bundle/Test/DomCrawlerAssertionsTrait.php',
        'Symfony\\Bundle\\FrameworkBundle\\Test\\HttpClientAssertionsTrait' => __DIR__ . '/..' . '/symfony/framework-bundle/Test/HttpClientAssertionsTrait.php',
        'Symfony\\Bundle\\FrameworkBundle\\Test\\KernelTestCase' => __DIR__ . '/..' . '/symfony/framework-bundle/Test/KernelTestCase.php',
        'Symfony\\Bundle\\FrameworkBundle\\Test\\MailerAssertionsTrait' => __DIR__ . '/..' . '/symfony/framework-bundle/Test/MailerAssertionsTrait.php',
        'Symfony\\Bundle\\FrameworkBundle\\Test\\NotificationAssertionsTrait' => __DIR__ . '/..' . '/symfony/framework-bundle/Test/NotificationAssertionsTrait.php',
        'Symfony\\Bundle\\FrameworkBundle\\Test\\TestBrowserToken' => __DIR__ . '/..' . '/symfony/framework-bundle/Test/TestBrowserToken.php',
        'Symfony\\Bundle\\FrameworkBundle\\Test\\TestContainer' => __DIR__ . '/..' . '/symfony/framework-bundle/Test/TestContainer.php',
        'Symfony\\Bundle\\FrameworkBundle\\Test\\WebTestAssertionsTrait' => __DIR__ . '/..' . '/symfony/framework-bundle/Test/WebTestAssertionsTrait.php',
        'Symfony\\Bundle\\FrameworkBundle\\Test\\WebTestCase' => __DIR__ . '/..' . '/symfony/framework-bundle/Test/WebTestCase.php',
        'Symfony\\Bundle\\FrameworkBundle\\Translation\\Translator' => __DIR__ . '/..' . '/symfony/framework-bundle/Translation/Translator.php',
        'Symfony\\Component\\Cache\\Adapter\\AbstractAdapter' => __DIR__ . '/..' . '/symfony/cache/Adapter/AbstractAdapter.php',
        'Symfony\\Component\\Cache\\Adapter\\AbstractTagAwareAdapter' => __DIR__ . '/..' . '/symfony/cache/Adapter/AbstractTagAwareAdapter.php',
        'Symfony\\Component\\Cache\\Adapter\\AdapterInterface' => __DIR__ . '/..' . '/symfony/cache/Adapter/AdapterInterface.php',
        'Symfony\\Component\\Cache\\Adapter\\ApcuAdapter' => __DIR__ . '/..' . '/symfony/cache/Adapter/ApcuAdapter.php',
        'Symfony\\Component\\Cache\\Adapter\\ArrayAdapter' => __DIR__ . '/..' . '/symfony/cache/Adapter/ArrayAdapter.php',
        'Symfony\\Component\\Cache\\Adapter\\ChainAdapter' => __DIR__ . '/..' . '/symfony/cache/Adapter/ChainAdapter.php',
        'Symfony\\Component\\Cache\\Adapter\\CouchbaseBucketAdapter' => __DIR__ . '/..' . '/symfony/cache/Adapter/CouchbaseBucketAdapter.php',
        'Symfony\\Component\\Cache\\Adapter\\CouchbaseCollectionAdapter' => __DIR__ . '/..' . '/symfony/cache/Adapter/CouchbaseCollectionAdapter.php',
        'Symfony\\Component\\Cache\\Adapter\\DoctrineDbalAdapter' => __DIR__ . '/..' . '/symfony/cache/Adapter/DoctrineDbalAdapter.php',
        'Symfony\\Component\\Cache\\Adapter\\FilesystemAdapter' => __DIR__ . '/..' . '/symfony/cache/Adapter/FilesystemAdapter.php',
        'Symfony\\Component\\Cache\\Adapter\\FilesystemTagAwareAdapter' => __DIR__ . '/..' . '/symfony/cache/Adapter/FilesystemTagAwareAdapter.php',
        'Symfony\\Component\\Cache\\Adapter\\MemcachedAdapter' => __DIR__ . '/..' . '/symfony/cache/Adapter/MemcachedAdapter.php',
        'Symfony\\Component\\Cache\\Adapter\\NullAdapter' => __DIR__ . '/..' . '/symfony/cache/Adapter/NullAdapter.php',
        'Symfony\\Component\\Cache\\Adapter\\ParameterNormalizer' => __DIR__ . '/..' . '/symfony/cache/Adapter/ParameterNormalizer.php',
        'Symfony\\Component\\Cache\\Adapter\\PdoAdapter' => __DIR__ . '/..' . '/symfony/cache/Adapter/PdoAdapter.php',
        'Symfony\\Component\\Cache\\Adapter\\PhpArrayAdapter' => __DIR__ . '/..' . '/symfony/cache/Adapter/PhpArrayAdapter.php',
        'Symfony\\Component\\Cache\\Adapter\\PhpFilesAdapter' => __DIR__ . '/..' . '/symfony/cache/Adapter/PhpFilesAdapter.php',
        'Symfony\\Component\\Cache\\Adapter\\ProxyAdapter' => __DIR__ . '/..' . '/symfony/cache/Adapter/ProxyAdapter.php',
        'Symfony\\Component\\Cache\\Adapter\\Psr16Adapter' => __DIR__ . '/..' . '/symfony/cache/Adapter/Psr16Adapter.php',
        'Symfony\\Component\\Cache\\Adapter\\RedisAdapter' => __DIR__ . '/..' . '/symfony/cache/Adapter/RedisAdapter.php',
        'Symfony\\Component\\Cache\\Adapter\\RedisTagAwareAdapter' => __DIR__ . '/..' . '/symfony/cache/Adapter/RedisTagAwareAdapter.php',
        'Symfony\\Component\\Cache\\Adapter\\TagAwareAdapter' => __DIR__ . '/..' . '/symfony/cache/Adapter/TagAwareAdapter.php',
        'Symfony\\Component\\Cache\\Adapter\\TagAwareAdapterInterface' => __DIR__ . '/..' . '/symfony/cache/Adapter/TagAwareAdapterInterface.php',
        'Symfony\\Component\\Cache\\Adapter\\TraceableAdapter' => __DIR__ . '/..' . '/symfony/cache/Adapter/TraceableAdapter.php',
        'Symfony\\Component\\Cache\\Adapter\\TraceableTagAwareAdapter' => __DIR__ . '/..' . '/symfony/cache/Adapter/TraceableTagAwareAdapter.php',
        'Symfony\\Component\\Cache\\CacheItem' => __DIR__ . '/..' . '/symfony/cache/CacheItem.php',
        'Symfony\\Component\\Cache\\DataCollector\\CacheDataCollector' => __DIR__ . '/..' . '/symfony/cache/DataCollector/CacheDataCollector.php',
        'Symfony\\Component\\Cache\\DependencyInjection\\CacheCollectorPass' => __DIR__ . '/..' . '/symfony/cache/DependencyInjection/CacheCollectorPass.php',
        'Symfony\\Component\\Cache\\DependencyInjection\\CachePoolClearerPass' => __DIR__ . '/..' . '/symfony/cache/DependencyInjection/CachePoolClearerPass.php',
        'Symfony\\Component\\Cache\\DependencyInjection\\CachePoolPass' => __DIR__ . '/..' . '/symfony/cache/DependencyInjection/CachePoolPass.php',
        'Symfony\\Component\\Cache\\DependencyInjection\\CachePoolPrunerPass' => __DIR__ . '/..' . '/symfony/cache/DependencyInjection/CachePoolPrunerPass.php',
        'Symfony\\Component\\Cache\\Exception\\CacheException' => __DIR__ . '/..' . '/symfony/cache/Exception/CacheException.php',
        'Symfony\\Component\\Cache\\Exception\\InvalidArgumentException' => __DIR__ . '/..' . '/symfony/cache/Exception/InvalidArgumentException.php',
        'Symfony\\Component\\Cache\\Exception\\LogicException' => __DIR__ . '/..' . '/symfony/cache/Exception/LogicException.php',
        'Symfony\\Component\\Cache\\LockRegistry' => __DIR__ . '/..' . '/symfony/cache/LockRegistry.php',
        'Symfony\\Component\\Cache\\Marshaller\\DefaultMarshaller' => __DIR__ . '/..' . '/symfony/cache/Marshaller/DefaultMarshaller.php',
        'Symfony\\Component\\Cache\\Marshaller\\DeflateMarshaller' => __DIR__ . '/..' . '/symfony/cache/Marshaller/DeflateMarshaller.php',
        'Symfony\\Component\\Cache\\Marshaller\\MarshallerInterface' => __DIR__ . '/..' . '/symfony/cache/Marshaller/MarshallerInterface.php',
        'Symfony\\Component\\Cache\\Marshaller\\SodiumMarshaller' => __DIR__ . '/..' . '/symfony/cache/Marshaller/SodiumMarshaller.php',
        'Symfony\\Component\\Cache\\Marshaller\\TagAwareMarshaller' => __DIR__ . '/..' . '/symfony/cache/Marshaller/TagAwareMarshaller.php',
        'Symfony\\Component\\Cache\\Messenger\\EarlyExpirationDispatcher' => __DIR__ . '/..' . '/symfony/cache/Messenger/EarlyExpirationDispatcher.php',
        'Symfony\\Component\\Cache\\Messenger\\EarlyExpirationHandler' => __DIR__ . '/..' . '/symfony/cache/Messenger/EarlyExpirationHandler.php',
        'Symfony\\Component\\Cache\\Messenger\\EarlyExpirationMessage' => __DIR__ . '/..' . '/symfony/cache/Messenger/EarlyExpirationMessage.php',
        'Symfony\\Component\\Cache\\PruneableInterface' => __DIR__ . '/..' . '/symfony/cache/PruneableInterface.php',
        'Symfony\\Component\\Cache\\Psr16Cache' => __DIR__ . '/..' . '/symfony/cache/Psr16Cache.php',
        'Symfony\\Component\\Cache\\ResettableInterface' => __DIR__ . '/..' . '/symfony/cache/ResettableInterface.php',
        'Symfony\\Component\\Cache\\Traits\\AbstractAdapterTrait' => __DIR__ . '/..' . '/symfony/cache/Traits/AbstractAdapterTrait.php',
        'Symfony\\Component\\Cache\\Traits\\CachedValueInterface' => __DIR__ . '/..' . '/symfony/cache/Traits/CachedValueInterface.php',
        'Symfony\\Component\\Cache\\Traits\\ContractsTrait' => __DIR__ . '/..' . '/symfony/cache/Traits/ContractsTrait.php',
        'Symfony\\Component\\Cache\\Traits\\FilesystemCommonTrait' => __DIR__ . '/..' . '/symfony/cache/Traits/FilesystemCommonTrait.php',
        'Symfony\\Component\\Cache\\Traits\\FilesystemTrait' => __DIR__ . '/..' . '/symfony/cache/Traits/FilesystemTrait.php',
        'Symfony\\Component\\Cache\\Traits\\ProxyTrait' => __DIR__ . '/..' . '/symfony/cache/Traits/ProxyTrait.php',
        'Symfony\\Component\\Cache\\Traits\\Redis5Proxy' => __DIR__ . '/..' . '/symfony/cache/Traits/Redis5Proxy.php',
        'Symfony\\Component\\Cache\\Traits\\Redis61ProxyTrait' => __DIR__ . '/..' . '/symfony/cache/Traits/Redis61ProxyTrait.php',
        'Symfony\\Component\\Cache\\Traits\\Redis62ProxyTrait' => __DIR__ . '/..' . '/symfony/cache/Traits/Redis62ProxyTrait.php',
        'Symfony\\Component\\Cache\\Traits\\Redis63ProxyTrait' => __DIR__ . '/..' . '/symfony/cache/Traits/Redis63ProxyTrait.php',
        'Symfony\\Component\\Cache\\Traits\\Redis6Proxy' => __DIR__ . '/..' . '/symfony/cache/Traits/Redis6Proxy.php',
        'Symfony\\Component\\Cache\\Traits\\RedisCluster5Proxy' => __DIR__ . '/..' . '/symfony/cache/Traits/RedisCluster5Proxy.php',
        'Symfony\\Component\\Cache\\Traits\\RedisCluster61ProxyTrait' => __DIR__ . '/..' . '/symfony/cache/Traits/RedisCluster61ProxyTrait.php',
        'Symfony\\Component\\Cache\\Traits\\RedisCluster62ProxyTrait' => __DIR__ . '/..' . '/symfony/cache/Traits/RedisCluster62ProxyTrait.php',
        'Symfony\\Component\\Cache\\Traits\\RedisCluster63ProxyTrait' => __DIR__ . '/..' . '/symfony/cache/Traits/RedisCluster63ProxyTrait.php',
        'Symfony\\Component\\Cache\\Traits\\RedisCluster6Proxy' => __DIR__ . '/..' . '/symfony/cache/Traits/RedisCluster6Proxy.php',
        'Symfony\\Component\\Cache\\Traits\\RedisClusterNodeProxy' => __DIR__ . '/..' . '/symfony/cache/Traits/RedisClusterNodeProxy.php',
        'Symfony\\Component\\Cache\\Traits\\RedisClusterProxy' => __DIR__ . '/..' . '/symfony/cache/Traits/RedisClusterProxy.php',
        'Symfony\\Component\\Cache\\Traits\\RedisProxy' => __DIR__ . '/..' . '/symfony/cache/Traits/RedisProxy.php',
        'Symfony\\Component\\Cache\\Traits\\RedisTrait' => __DIR__ . '/..' . '/symfony/cache/Traits/RedisTrait.php',
        'Symfony\\Component\\Cache\\Traits\\RelayProxy' => __DIR__ . '/..' . '/symfony/cache/Traits/RelayProxy.php',
        'Symfony\\Component\\Cache\\Traits\\RelayProxyTrait' => __DIR__ . '/..' . '/symfony/cache/Traits/RelayProxyTrait.php',
        'Symfony\\Component\\Cache\\Traits\\Relay\\BgsaveTrait' => __DIR__ . '/..' . '/symfony/cache/Traits/Relay/BgsaveTrait.php',
        'Symfony\\Component\\Cache\\Traits\\Relay\\CopyTrait' => __DIR__ . '/..' . '/symfony/cache/Traits/Relay/CopyTrait.php',
        'Symfony\\Component\\Cache\\Traits\\Relay\\FtTrait' => __DIR__ . '/..' . '/symfony/cache/Traits/Relay/FtTrait.php',
        'Symfony\\Component\\Cache\\Traits\\Relay\\GeosearchTrait' => __DIR__ . '/..' . '/symfony/cache/Traits/Relay/GeosearchTrait.php',
        'Symfony\\Component\\Cache\\Traits\\Relay\\GetWithMetaTrait' => __DIR__ . '/..' . '/symfony/cache/Traits/Relay/GetWithMetaTrait.php',
        'Symfony\\Component\\Cache\\Traits\\Relay\\GetrangeTrait' => __DIR__ . '/..' . '/symfony/cache/Traits/Relay/GetrangeTrait.php',
        'Symfony\\Component\\Cache\\Traits\\Relay\\HsetTrait' => __DIR__ . '/..' . '/symfony/cache/Traits/Relay/HsetTrait.php',
        'Symfony\\Component\\Cache\\Traits\\Relay\\IsTrackedTrait' => __DIR__ . '/..' . '/symfony/cache/Traits/Relay/IsTrackedTrait.php',
        'Symfony\\Component\\Cache\\Traits\\Relay\\MoveTrait' => __DIR__ . '/..' . '/symfony/cache/Traits/Relay/MoveTrait.php',
        'Symfony\\Component\\Cache\\Traits\\Relay\\NullableReturnTrait' => __DIR__ . '/..' . '/symfony/cache/Traits/Relay/NullableReturnTrait.php',
        'Symfony\\Component\\Cache\\Traits\\Relay\\PfcountTrait' => __DIR__ . '/..' . '/symfony/cache/Traits/Relay/PfcountTrait.php',
        'Symfony\\Component\\Cache\\Traits\\Relay\\Relay11Trait' => __DIR__ . '/..' . '/symfony/cache/Traits/Relay/Relay11Trait.php',
        'Symfony\\Component\\Cache\\Traits\\Relay\\Relay121Trait' => __DIR__ . '/..' . '/symfony/cache/Traits/Relay/Relay121Trait.php',
        'Symfony\\Component\\Cache\\Traits\\Relay\\Relay12Trait' => __DIR__ . '/..' . '/symfony/cache/Traits/Relay/Relay12Trait.php',
        'Symfony\\Component\\Cache\\Traits\\Relay\\Relay20Trait' => __DIR__ . '/..' . '/symfony/cache/Traits/Relay/Relay20Trait.php',
        'Symfony\\Component\\Cache\\Traits\\Relay\\Relay21Trait' => __DIR__ . '/..' . '/symfony/cache/Traits/Relay/Relay21Trait.php',
        'Symfony\\Component\\Cache\\Traits\\Relay\\Relay22Trait' => __DIR__ . '/..' . '/symfony/cache/Traits/Relay/Relay22Trait.php',
        'Symfony\\Component\\Cache\\Traits\\Relay\\Relay30Trait' => __DIR__ . '/..' . '/symfony/cache/Traits/Relay/Relay30Trait.php',
        'Symfony\\Component\\Cache\\Traits\\Relay\\SwapdbTrait' => __DIR__ . '/..' . '/symfony/cache/Traits/Relay/SwapdbTrait.php',
        'Symfony\\Component\\Config\\Builder\\ClassBuilder' => __DIR__ . '/..' . '/symfony/config/Builder/ClassBuilder.php',
        'Symfony\\Component\\Config\\Builder\\ConfigBuilderGenerator' => __DIR__ . '/..' . '/symfony/config/Builder/ConfigBuilderGenerator.php',
        'Symfony\\Component\\Config\\Builder\\ConfigBuilderGeneratorInterface' => __DIR__ . '/..' . '/symfony/config/Builder/ConfigBuilderGeneratorInterface.php',
        'Symfony\\Component\\Config\\Builder\\ConfigBuilderInterface' => __DIR__ . '/..' . '/symfony/config/Builder/ConfigBuilderInterface.php',
        'Symfony\\Component\\Config\\Builder\\Method' => __DIR__ . '/..' . '/symfony/config/Builder/Method.php',
        'Symfony\\Component\\Config\\Builder\\Property' => __DIR__ . '/..' . '/symfony/config/Builder/Property.php',
        'Symfony\\Component\\Config\\ConfigCache' => __DIR__ . '/..' . '/symfony/config/ConfigCache.php',
        'Symfony\\Component\\Config\\ConfigCacheFactory' => __DIR__ . '/..' . '/symfony/config/ConfigCacheFactory.php',
        'Symfony\\Component\\Config\\ConfigCacheFactoryInterface' => __DIR__ . '/..' . '/symfony/config/ConfigCacheFactoryInterface.php',
        'Symfony\\Component\\Config\\ConfigCacheInterface' => __DIR__ . '/..' . '/symfony/config/ConfigCacheInterface.php',
        'Symfony\\Component\\Config\\Definition\\ArrayNode' => __DIR__ . '/..' . '/symfony/config/Definition/ArrayNode.php',
        'Symfony\\Component\\Config\\Definition\\BaseNode' => __DIR__ . '/..' . '/symfony/config/Definition/BaseNode.php',
        'Symfony\\Component\\Config\\Definition\\BooleanNode' => __DIR__ . '/..' . '/symfony/config/Definition/BooleanNode.php',
        'Symfony\\Component\\Config\\Definition\\Builder\\ArrayNodeDefinition' => __DIR__ . '/..' . '/symfony/config/Definition/Builder/ArrayNodeDefinition.php',
        'Symfony\\Component\\Config\\Definition\\Builder\\BooleanNodeDefinition' => __DIR__ . '/..' . '/symfony/config/Definition/Builder/BooleanNodeDefinition.php',
        'Symfony\\Component\\Config\\Definition\\Builder\\BuilderAwareInterface' => __DIR__ . '/..' . '/symfony/config/Definition/Builder/BuilderAwareInterface.php',
        'Symfony\\Component\\Config\\Definition\\Builder\\EnumNodeDefinition' => __DIR__ . '/..' . '/symfony/config/Definition/Builder/EnumNodeDefinition.php',
        'Symfony\\Component\\Config\\Definition\\Builder\\ExprBuilder' => __DIR__ . '/..' . '/symfony/config/Definition/Builder/ExprBuilder.php',
        'Symfony\\Component\\Config\\Definition\\Builder\\FloatNodeDefinition' => __DIR__ . '/..' . '/symfony/config/Definition/Builder/FloatNodeDefinition.php',
        'Symfony\\Component\\Config\\Definition\\Builder\\IntegerNodeDefinition' => __DIR__ . '/..' . '/symfony/config/Definition/Builder/IntegerNodeDefinition.php',
        'Symfony\\Component\\Config\\Definition\\Builder\\MergeBuilder' => __DIR__ . '/..' . '/symfony/config/Definition/Builder/MergeBuilder.php',
        'Symfony\\Component\\Config\\Definition\\Builder\\NodeBuilder' => __DIR__ . '/..' . '/symfony/config/Definition/Builder/NodeBuilder.php',
        'Symfony\\Component\\Config\\Definition\\Builder\\NodeDefinition' => __DIR__ . '/..' . '/symfony/config/Definition/Builder/NodeDefinition.php',
        'Symfony\\Component\\Config\\Definition\\Builder\\NodeParentInterface' => __DIR__ . '/..' . '/symfony/config/Definition/Builder/NodeParentInterface.php',
        'Symfony\\Component\\Config\\Definition\\Builder\\NormalizationBuilder' => __DIR__ . '/..' . '/symfony/config/Definition/Builder/NormalizationBuilder.php',
        'Symfony\\Component\\Config\\Definition\\Builder\\NumericNodeDefinition' => __DIR__ . '/..' . '/symfony/config/Definition/Builder/NumericNodeDefinition.php',
        'Symfony\\Component\\Config\\Definition\\Builder\\ParentNodeDefinitionInterface' => __DIR__ . '/..' . '/symfony/config/Definition/Builder/ParentNodeDefinitionInterface.php',
        'Symfony\\Component\\Config\\Definition\\Builder\\ScalarNodeDefinition' => __DIR__ . '/..' . '/symfony/config/Definition/Builder/ScalarNodeDefinition.php',
        'Symfony\\Component\\Config\\Definition\\Builder\\TreeBuilder' => __DIR__ . '/..' . '/symfony/config/Definition/Builder/TreeBuilder.php',
        'Symfony\\Component\\Config\\Definition\\Builder\\ValidationBuilder' => __DIR__ . '/..' . '/symfony/config/Definition/Builder/ValidationBuilder.php',
        'Symfony\\Component\\Config\\Definition\\Builder\\VariableNodeDefinition' => __DIR__ . '/..' . '/symfony/config/Definition/Builder/VariableNodeDefinition.php',
        'Symfony\\Component\\Config\\Definition\\ConfigurableInterface' => __DIR__ . '/..' . '/symfony/config/Definition/ConfigurableInterface.php',
        'Symfony\\Component\\Config\\Definition\\Configuration' => __DIR__ . '/..' . '/symfony/config/Definition/Configuration.php',
        'Symfony\\Component\\Config\\Definition\\ConfigurationInterface' => __DIR__ . '/..' . '/symfony/config/Definition/ConfigurationInterface.php',
        'Symfony\\Component\\Config\\Definition\\Configurator\\DefinitionConfigurator' => __DIR__ . '/..' . '/symfony/config/Definition/Configurator/DefinitionConfigurator.php',
        'Symfony\\Component\\Config\\Definition\\Dumper\\XmlReferenceDumper' => __DIR__ . '/..' . '/symfony/config/Definition/Dumper/XmlReferenceDumper.php',
        'Symfony\\Component\\Config\\Definition\\Dumper\\YamlReferenceDumper' => __DIR__ . '/..' . '/symfony/config/Definition/Dumper/YamlReferenceDumper.php',
        'Symfony\\Component\\Config\\Definition\\EnumNode' => __DIR__ . '/..' . '/symfony/config/Definition/EnumNode.php',
        'Symfony\\Component\\Config\\Definition\\Exception\\DuplicateKeyException' => __DIR__ . '/..' . '/symfony/config/Definition/Exception/DuplicateKeyException.php',
        'Symfony\\Component\\Config\\Definition\\Exception\\Exception' => __DIR__ . '/..' . '/symfony/config/Definition/Exception/Exception.php',
        'Symfony\\Component\\Config\\Definition\\Exception\\ForbiddenOverwriteException' => __DIR__ . '/..' . '/symfony/config/Definition/Exception/ForbiddenOverwriteException.php',
        'Symfony\\Component\\Config\\Definition\\Exception\\InvalidConfigurationException' => __DIR__ . '/..' . '/symfony/config/Definition/Exception/InvalidConfigurationException.php',
        'Symfony\\Component\\Config\\Definition\\Exception\\InvalidDefinitionException' => __DIR__ . '/..' . '/symfony/config/Definition/Exception/InvalidDefinitionException.php',
        'Symfony\\Component\\Config\\Definition\\Exception\\InvalidTypeException' => __DIR__ . '/..' . '/symfony/config/Definition/Exception/InvalidTypeException.php',
        'Symfony\\Component\\Config\\Definition\\Exception\\UnsetKeyException' => __DIR__ . '/..' . '/symfony/config/Definition/Exception/UnsetKeyException.php',
        'Symfony\\Component\\Config\\Definition\\FloatNode' => __DIR__ . '/..' . '/symfony/config/Definition/FloatNode.php',
        'Symfony\\Component\\Config\\Definition\\IntegerNode' => __DIR__ . '/..' . '/symfony/config/Definition/IntegerNode.php',
        'Symfony\\Component\\Config\\Definition\\Loader\\DefinitionFileLoader' => __DIR__ . '/..' . '/symfony/config/Definition/Loader/DefinitionFileLoader.php',
        'Symfony\\Component\\Config\\Definition\\NodeInterface' => __DIR__ . '/..' . '/symfony/config/Definition/NodeInterface.php',
        'Symfony\\Component\\Config\\Definition\\NumericNode' => __DIR__ . '/..' . '/symfony/config/Definition/NumericNode.php',
        'Symfony\\Component\\Config\\Definition\\Processor' => __DIR__ . '/..' . '/symfony/config/Definition/Processor.php',
        'Symfony\\Component\\Config\\Definition\\PrototypeNodeInterface' => __DIR__ . '/..' . '/symfony/config/Definition/PrototypeNodeInterface.php',
        'Symfony\\Component\\Config\\Definition\\PrototypedArrayNode' => __DIR__ . '/..' . '/symfony/config/Definition/PrototypedArrayNode.php',
        'Symfony\\Component\\Config\\Definition\\ScalarNode' => __DIR__ . '/..' . '/symfony/config/Definition/ScalarNode.php',
        'Symfony\\Component\\Config\\Definition\\VariableNode' => __DIR__ . '/..' . '/symfony/config/Definition/VariableNode.php',
        'Symfony\\Component\\Config\\Exception\\FileLoaderImportCircularReferenceException' => __DIR__ . '/..' . '/symfony/config/Exception/FileLoaderImportCircularReferenceException.php',
        'Symfony\\Component\\Config\\Exception\\FileLocatorFileNotFoundException' => __DIR__ . '/..' . '/symfony/config/Exception/FileLocatorFileNotFoundException.php',
        'Symfony\\Component\\Config\\Exception\\LoaderLoadException' => __DIR__ . '/..' . '/symfony/config/Exception/LoaderLoadException.php',
        'Symfony\\Component\\Config\\FileLocator' => __DIR__ . '/..' . '/symfony/config/FileLocator.php',
        'Symfony\\Component\\Config\\FileLocatorInterface' => __DIR__ . '/..' . '/symfony/config/FileLocatorInterface.php',
        'Symfony\\Component\\Config\\Loader\\DelegatingLoader' => __DIR__ . '/..' . '/symfony/config/Loader/DelegatingLoader.php',
        'Symfony\\Component\\Config\\Loader\\DirectoryAwareLoaderInterface' => __DIR__ . '/..' . '/symfony/config/Loader/DirectoryAwareLoaderInterface.php',
        'Symfony\\Component\\Config\\Loader\\FileLoader' => __DIR__ . '/..' . '/symfony/config/Loader/FileLoader.php',
        'Symfony\\Component\\Config\\Loader\\GlobFileLoader' => __DIR__ . '/..' . '/symfony/config/Loader/GlobFileLoader.php',
        'Symfony\\Component\\Config\\Loader\\Loader' => __DIR__ . '/..' . '/symfony/config/Loader/Loader.php',
        'Symfony\\Component\\Config\\Loader\\LoaderInterface' => __DIR__ . '/..' . '/symfony/config/Loader/LoaderInterface.php',
        'Symfony\\Component\\Config\\Loader\\LoaderResolver' => __DIR__ . '/..' . '/symfony/config/Loader/LoaderResolver.php',
        'Symfony\\Component\\Config\\Loader\\LoaderResolverInterface' => __DIR__ . '/..' . '/symfony/config/Loader/LoaderResolverInterface.php',
        'Symfony\\Component\\Config\\Loader\\ParamConfigurator' => __DIR__ . '/..' . '/symfony/config/Loader/ParamConfigurator.php',
        'Symfony\\Component\\Config\\ResourceCheckerConfigCache' => __DIR__ . '/..' . '/symfony/config/ResourceCheckerConfigCache.php',
        'Symfony\\Component\\Config\\ResourceCheckerConfigCacheFactory' => __DIR__ . '/..' . '/symfony/config/ResourceCheckerConfigCacheFactory.php',
        'Symfony\\Component\\Config\\ResourceCheckerInterface' => __DIR__ . '/..' . '/symfony/config/ResourceCheckerInterface.php',
        'Symfony\\Component\\Config\\Resource\\ClassExistenceResource' => __DIR__ . '/..' . '/symfony/config/Resource/ClassExistenceResource.php',
        'Symfony\\Component\\Config\\Resource\\ComposerResource' => __DIR__ . '/..' . '/symfony/config/Resource/ComposerResource.php',
        'Symfony\\Component\\Config\\Resource\\DirectoryResource' => __DIR__ . '/..' . '/symfony/config/Resource/DirectoryResource.php',
        'Symfony\\Component\\Config\\Resource\\FileExistenceResource' => __DIR__ . '/..' . '/symfony/config/Resource/FileExistenceResource.php',
        'Symfony\\Component\\Config\\Resource\\FileResource' => __DIR__ . '/..' . '/symfony/config/Resource/FileResource.php',
        'Symfony\\Component\\Config\\Resource\\GlobResource' => __DIR__ . '/..' . '/symfony/config/Resource/GlobResource.php',
        'Symfony\\Component\\Config\\Resource\\ReflectionClassResource' => __DIR__ . '/..' . '/symfony/config/Resource/ReflectionClassResource.php',
        'Symfony\\Component\\Config\\Resource\\ResourceInterface' => __DIR__ . '/..' . '/symfony/config/Resource/ResourceInterface.php',
        'Symfony\\Component\\Config\\Resource\\SelfCheckingResourceChecker' => __DIR__ . '/..' . '/symfony/config/Resource/SelfCheckingResourceChecker.php',
        'Symfony\\Component\\Config\\Resource\\SelfCheckingResourceInterface' => __DIR__ . '/..' . '/symfony/config/Resource/SelfCheckingResourceInterface.php',
        'Symfony\\Component\\Config\\Util\\Exception\\InvalidXmlException' => __DIR__ . '/..' . '/symfony/config/Util/Exception/InvalidXmlException.php',
        'Symfony\\Component\\Config\\Util\\Exception\\XmlParsingException' => __DIR__ . '/..' . '/symfony/config/Util/Exception/XmlParsingException.php',
        'Symfony\\Component\\Config\\Util\\XmlUtils' => __DIR__ . '/..' . '/symfony/config/Util/XmlUtils.php',
        'Symfony\\Component\\Console\\Application' => __DIR__ . '/..' . '/symfony/console/Application.php',
        'Symfony\\Component\\Console\\Attribute\\AsCommand' => __DIR__ . '/..' . '/symfony/console/Attribute/AsCommand.php',
        'Symfony\\Component\\Console\\CI\\GithubActionReporter' => __DIR__ . '/..' . '/symfony/console/CI/GithubActionReporter.php',
        'Symfony\\Component\\Console\\Color' => __DIR__ . '/..' . '/symfony/console/Color.php',
        'Symfony\\Component\\Console\\CommandLoader\\CommandLoaderInterface' => __DIR__ . '/..' . '/symfony/console/CommandLoader/CommandLoaderInterface.php',
        'Symfony\\Component\\Console\\CommandLoader\\ContainerCommandLoader' => __DIR__ . '/..' . '/symfony/console/CommandLoader/ContainerCommandLoader.php',
        'Symfony\\Component\\Console\\CommandLoader\\FactoryCommandLoader' => __DIR__ . '/..' . '/symfony/console/CommandLoader/FactoryCommandLoader.php',
        'Symfony\\Component\\Console\\Command\\Command' => __DIR__ . '/..' . '/symfony/console/Command/Command.php',
        'Symfony\\Component\\Console\\Command\\CompleteCommand' => __DIR__ . '/..' . '/symfony/console/Command/CompleteCommand.php',
        'Symfony\\Component\\Console\\Command\\DumpCompletionCommand' => __DIR__ . '/..' . '/symfony/console/Command/DumpCompletionCommand.php',
        'Symfony\\Component\\Console\\Command\\HelpCommand' => __DIR__ . '/..' . '/symfony/console/Command/HelpCommand.php',
        'Symfony\\Component\\Console\\Command\\LazyCommand' => __DIR__ . '/..' . '/symfony/console/Command/LazyCommand.php',
        'Symfony\\Component\\Console\\Command\\ListCommand' => __DIR__ . '/..' . '/symfony/console/Command/ListCommand.php',
        'Symfony\\Component\\Console\\Command\\LockableTrait' => __DIR__ . '/..' . '/symfony/console/Command/LockableTrait.php',
        'Symfony\\Component\\Console\\Command\\SignalableCommandInterface' => __DIR__ . '/..' . '/symfony/console/Command/SignalableCommandInterface.php',
        'Symfony\\Component\\Console\\Command\\TraceableCommand' => __DIR__ . '/..' . '/symfony/console/Command/TraceableCommand.php',
        'Symfony\\Component\\Console\\Completion\\CompletionInput' => __DIR__ . '/..' . '/symfony/console/Completion/CompletionInput.php',
        'Symfony\\Component\\Console\\Completion\\CompletionSuggestions' => __DIR__ . '/..' . '/symfony/console/Completion/CompletionSuggestions.php',
        'Symfony\\Component\\Console\\Completion\\Output\\BashCompletionOutput' => __DIR__ . '/..' . '/symfony/console/Completion/Output/BashCompletionOutput.php',
        'Symfony\\Component\\Console\\Completion\\Output\\CompletionOutputInterface' => __DIR__ . '/..' . '/symfony/console/Completion/Output/CompletionOutputInterface.php',
        'Symfony\\Component\\Console\\Completion\\Output\\FishCompletionOutput' => __DIR__ . '/..' . '/symfony/console/Completion/Output/FishCompletionOutput.php',
        'Symfony\\Component\\Console\\Completion\\Output\\ZshCompletionOutput' => __DIR__ . '/..' . '/symfony/console/Completion/Output/ZshCompletionOutput.php',
        'Symfony\\Component\\Console\\Completion\\Suggestion' => __DIR__ . '/..' . '/symfony/console/Completion/Suggestion.php',
        'Symfony\\Component\\Console\\ConsoleEvents' => __DIR__ . '/..' . '/symfony/console/ConsoleEvents.php',
        'Symfony\\Component\\Console\\Cursor' => __DIR__ . '/..' . '/symfony/console/Cursor.php',
        'Symfony\\Component\\Console\\DataCollector\\CommandDataCollector' => __DIR__ . '/..' . '/symfony/console/DataCollector/CommandDataCollector.php',
        'Symfony\\Component\\Console\\Debug\\CliRequest' => __DIR__ . '/..' . '/symfony/console/Debug/CliRequest.php',
        'Symfony\\Component\\Console\\DependencyInjection\\AddConsoleCommandPass' => __DIR__ . '/..' . '/symfony/console/DependencyInjection/AddConsoleCommandPass.php',
        'Symfony\\Component\\Console\\Descriptor\\ApplicationDescription' => __DIR__ . '/..' . '/symfony/console/Descriptor/ApplicationDescription.php',
        'Symfony\\Component\\Console\\Descriptor\\Descriptor' => __DIR__ . '/..' . '/symfony/console/Descriptor/Descriptor.php',
        'Symfony\\Component\\Console\\Descriptor\\DescriptorInterface' => __DIR__ . '/..' . '/symfony/console/Descriptor/DescriptorInterface.php',
        'Symfony\\Component\\Console\\Descriptor\\JsonDescriptor' => __DIR__ . '/..' . '/symfony/console/Descriptor/JsonDescriptor.php',
        'Symfony\\Component\\Console\\Descriptor\\MarkdownDescriptor' => __DIR__ . '/..' . '/symfony/console/Descriptor/MarkdownDescriptor.php',
        'Symfony\\Component\\Console\\Descriptor\\ReStructuredTextDescriptor' => __DIR__ . '/..' . '/symfony/console/Descriptor/ReStructuredTextDescriptor.php',
        'Symfony\\Component\\Console\\Descriptor\\TextDescriptor' => __DIR__ . '/..' . '/symfony/console/Descriptor/TextDescriptor.php',
        'Symfony\\Component\\Console\\Descriptor\\XmlDescriptor' => __DIR__ . '/..' . '/symfony/console/Descriptor/XmlDescriptor.php',
        'Symfony\\Component\\Console\\EventListener\\ErrorListener' => __DIR__ . '/..' . '/symfony/console/EventListener/ErrorListener.php',
        'Symfony\\Component\\Console\\Event\\ConsoleCommandEvent' => __DIR__ . '/..' . '/symfony/console/Event/ConsoleCommandEvent.php',
        'Symfony\\Component\\Console\\Event\\ConsoleErrorEvent' => __DIR__ . '/..' . '/symfony/console/Event/ConsoleErrorEvent.php',
        'Symfony\\Component\\Console\\Event\\ConsoleEvent' => __DIR__ . '/..' . '/symfony/console/Event/ConsoleEvent.php',
        'Symfony\\Component\\Console\\Event\\ConsoleSignalEvent' => __DIR__ . '/..' . '/symfony/console/Event/ConsoleSignalEvent.php',
        'Symfony\\Component\\Console\\Event\\ConsoleTerminateEvent' => __DIR__ . '/..' . '/symfony/console/Event/ConsoleTerminateEvent.php',
        'Symfony\\Component\\Console\\Exception\\CommandNotFoundException' => __DIR__ . '/..' . '/symfony/console/Exception/CommandNotFoundException.php',
        'Symfony\\Component\\Console\\Exception\\ExceptionInterface' => __DIR__ . '/..' . '/symfony/console/Exception/ExceptionInterface.php',
        'Symfony\\Component\\Console\\Exception\\InvalidArgumentException' => __DIR__ . '/..' . '/symfony/console/Exception/InvalidArgumentException.php',
        'Symfony\\Component\\Console\\Exception\\InvalidOptionException' => __DIR__ . '/..' . '/symfony/console/Exception/InvalidOptionException.php',
        'Symfony\\Component\\Console\\Exception\\LogicException' => __DIR__ . '/..' . '/symfony/console/Exception/LogicException.php',
        'Symfony\\Component\\Console\\Exception\\MissingInputException' => __DIR__ . '/..' . '/symfony/console/Exception/MissingInputException.php',
        'Symfony\\Component\\Console\\Exception\\NamespaceNotFoundException' => __DIR__ . '/..' . '/symfony/console/Exception/NamespaceNotFoundException.php',
        'Symfony\\Component\\Console\\Exception\\RunCommandFailedException' => __DIR__ . '/..' . '/symfony/console/Exception/RunCommandFailedException.php',
        'Symfony\\Component\\Console\\Exception\\RuntimeException' => __DIR__ . '/..' . '/symfony/console/Exception/RuntimeException.php',
        'Symfony\\Component\\Console\\Formatter\\NullOutputFormatter' => __DIR__ . '/..' . '/symfony/console/Formatter/NullOutputFormatter.php',
        'Symfony\\Component\\Console\\Formatter\\NullOutputFormatterStyle' => __DIR__ . '/..' . '/symfony/console/Formatter/NullOutputFormatterStyle.php',
        'Symfony\\Component\\Console\\Formatter\\OutputFormatter' => __DIR__ . '/..' . '/symfony/console/Formatter/OutputFormatter.php',
        'Symfony\\Component\\Console\\Formatter\\OutputFormatterInterface' => __DIR__ . '/..' . '/symfony/console/Formatter/OutputFormatterInterface.php',
        'Symfony\\Component\\Console\\Formatter\\OutputFormatterStyle' => __DIR__ . '/..' . '/symfony/console/Formatter/OutputFormatterStyle.php',
        'Symfony\\Component\\Console\\Formatter\\OutputFormatterStyleInterface' => __DIR__ . '/..' . '/symfony/console/Formatter/OutputFormatterStyleInterface.php',
        'Symfony\\Component\\Console\\Formatter\\OutputFormatterStyleStack' => __DIR__ . '/..' . '/symfony/console/Formatter/OutputFormatterStyleStack.php',
        'Symfony\\Component\\Console\\Formatter\\WrappableOutputFormatterInterface' => __DIR__ . '/..' . '/symfony/console/Formatter/WrappableOutputFormatterInterface.php',
        'Symfony\\Component\\Console\\Helper\\DebugFormatterHelper' => __DIR__ . '/..' . '/symfony/console/Helper/DebugFormatterHelper.php',
        'Symfony\\Component\\Console\\Helper\\DescriptorHelper' => __DIR__ . '/..' . '/symfony/console/Helper/DescriptorHelper.php',
        'Symfony\\Component\\Console\\Helper\\Dumper' => __DIR__ . '/..' . '/symfony/console/Helper/Dumper.php',
        'Symfony\\Component\\Console\\Helper\\FormatterHelper' => __DIR__ . '/..' . '/symfony/console/Helper/FormatterHelper.php',
        'Symfony\\Component\\Console\\Helper\\Helper' => __DIR__ . '/..' . '/symfony/console/Helper/Helper.php',
        'Symfony\\Component\\Console\\Helper\\HelperInterface' => __DIR__ . '/..' . '/symfony/console/Helper/HelperInterface.php',
        'Symfony\\Component\\Console\\Helper\\HelperSet' => __DIR__ . '/..' . '/symfony/console/Helper/HelperSet.php',
        'Symfony\\Component\\Console\\Helper\\InputAwareHelper' => __DIR__ . '/..' . '/symfony/console/Helper/InputAwareHelper.php',
        'Symfony\\Component\\Console\\Helper\\OutputWrapper' => __DIR__ . '/..' . '/symfony/console/Helper/OutputWrapper.php',
        'Symfony\\Component\\Console\\Helper\\ProcessHelper' => __DIR__ . '/..' . '/symfony/console/Helper/ProcessHelper.php',
        'Symfony\\Component\\Console\\Helper\\ProgressBar' => __DIR__ . '/..' . '/symfony/console/Helper/ProgressBar.php',
        'Symfony\\Component\\Console\\Helper\\ProgressIndicator' => __DIR__ . '/..' . '/symfony/console/Helper/ProgressIndicator.php',
        'Symfony\\Component\\Console\\Helper\\QuestionHelper' => __DIR__ . '/..' . '/symfony/console/Helper/QuestionHelper.php',
        'Symfony\\Component\\Console\\Helper\\SymfonyQuestionHelper' => __DIR__ . '/..' . '/symfony/console/Helper/SymfonyQuestionHelper.php',
        'Symfony\\Component\\Console\\Helper\\Table' => __DIR__ . '/..' . '/symfony/console/Helper/Table.php',
        'Symfony\\Component\\Console\\Helper\\TableCell' => __DIR__ . '/..' . '/symfony/console/Helper/TableCell.php',
        'Symfony\\Component\\Console\\Helper\\TableCellStyle' => __DIR__ . '/..' . '/symfony/console/Helper/TableCellStyle.php',
        'Symfony\\Component\\Console\\Helper\\TableRows' => __DIR__ . '/..' . '/symfony/console/Helper/TableRows.php',
        'Symfony\\Component\\Console\\Helper\\TableSeparator' => __DIR__ . '/..' . '/symfony/console/Helper/TableSeparator.php',
        'Symfony\\Component\\Console\\Helper\\TableStyle' => __DIR__ . '/..' . '/symfony/console/Helper/TableStyle.php',
        'Symfony\\Component\\Console\\Helper\\TerminalInputHelper' => __DIR__ . '/..' . '/symfony/console/Helper/TerminalInputHelper.php',
        'Symfony\\Component\\Console\\Input\\ArgvInput' => __DIR__ . '/..' . '/symfony/console/Input/ArgvInput.php',
        'Symfony\\Component\\Console\\Input\\ArrayInput' => __DIR__ . '/..' . '/symfony/console/Input/ArrayInput.php',
        'Symfony\\Component\\Console\\Input\\Input' => __DIR__ . '/..' . '/symfony/console/Input/Input.php',
        'Symfony\\Component\\Console\\Input\\InputArgument' => __DIR__ . '/..' . '/symfony/console/Input/InputArgument.php',
        'Symfony\\Component\\Console\\Input\\InputAwareInterface' => __DIR__ . '/..' . '/symfony/console/Input/InputAwareInterface.php',
        'Symfony\\Component\\Console\\Input\\InputDefinition' => __DIR__ . '/..' . '/symfony/console/Input/InputDefinition.php',
        'Symfony\\Component\\Console\\Input\\InputInterface' => __DIR__ . '/..' . '/symfony/console/Input/InputInterface.php',
        'Symfony\\Component\\Console\\Input\\InputOption' => __DIR__ . '/..' . '/symfony/console/Input/InputOption.php',
        'Symfony\\Component\\Console\\Input\\StreamableInputInterface' => __DIR__ . '/..' . '/symfony/console/Input/StreamableInputInterface.php',
        'Symfony\\Component\\Console\\Input\\StringInput' => __DIR__ . '/..' . '/symfony/console/Input/StringInput.php',
        'Symfony\\Component\\Console\\Logger\\ConsoleLogger' => __DIR__ . '/..' . '/symfony/console/Logger/ConsoleLogger.php',
        'Symfony\\Component\\Console\\Messenger\\RunCommandContext' => __DIR__ . '/..' . '/symfony/console/Messenger/RunCommandContext.php',
        'Symfony\\Component\\Console\\Messenger\\RunCommandMessage' => __DIR__ . '/..' . '/symfony/console/Messenger/RunCommandMessage.php',
        'Symfony\\Component\\Console\\Messenger\\RunCommandMessageHandler' => __DIR__ . '/..' . '/symfony/console/Messenger/RunCommandMessageHandler.php',
        'Symfony\\Component\\Console\\Output\\AnsiColorMode' => __DIR__ . '/..' . '/symfony/console/Output/AnsiColorMode.php',
        'Symfony\\Component\\Console\\Output\\BufferedOutput' => __DIR__ . '/..' . '/symfony/console/Output/BufferedOutput.php',
        'Symfony\\Component\\Console\\Output\\ConsoleOutput' => __DIR__ . '/..' . '/symfony/console/Output/ConsoleOutput.php',
        'Symfony\\Component\\Console\\Output\\ConsoleOutputInterface' => __DIR__ . '/..' . '/symfony/console/Output/ConsoleOutputInterface.php',
        'Symfony\\Component\\Console\\Output\\ConsoleSectionOutput' => __DIR__ . '/..' . '/symfony/console/Output/ConsoleSectionOutput.php',
        'Symfony\\Component\\Console\\Output\\NullOutput' => __DIR__ . '/..' . '/symfony/console/Output/NullOutput.php',
        'Symfony\\Component\\Console\\Output\\Output' => __DIR__ . '/..' . '/symfony/console/Output/Output.php',
        'Symfony\\Component\\Console\\Output\\OutputInterface' => __DIR__ . '/..' . '/symfony/console/Output/OutputInterface.php',
        'Symfony\\Component\\Console\\Output\\StreamOutput' => __DIR__ . '/..' . '/symfony/console/Output/StreamOutput.php',
        'Symfony\\Component\\Console\\Output\\TrimmedBufferOutput' => __DIR__ . '/..' . '/symfony/console/Output/TrimmedBufferOutput.php',
        'Symfony\\Component\\Console\\Question\\ChoiceQuestion' => __DIR__ . '/..' . '/symfony/console/Question/ChoiceQuestion.php',
        'Symfony\\Component\\Console\\Question\\ConfirmationQuestion' => __DIR__ . '/..' . '/symfony/console/Question/ConfirmationQuestion.php',
        'Symfony\\Component\\Console\\Question\\Question' => __DIR__ . '/..' . '/symfony/console/Question/Question.php',
        'Symfony\\Component\\Console\\SignalRegistry\\SignalMap' => __DIR__ . '/..' . '/symfony/console/SignalRegistry/SignalMap.php',
        'Symfony\\Component\\Console\\SignalRegistry\\SignalRegistry' => __DIR__ . '/..' . '/symfony/console/SignalRegistry/SignalRegistry.php',
        'Symfony\\Component\\Console\\SingleCommandApplication' => __DIR__ . '/..' . '/symfony/console/SingleCommandApplication.php',
        'Symfony\\Component\\Console\\Style\\OutputStyle' => __DIR__ . '/..' . '/symfony/console/Style/OutputStyle.php',
        'Symfony\\Component\\Console\\Style\\StyleInterface' => __DIR__ . '/..' . '/symfony/console/Style/StyleInterface.php',
        'Symfony\\Component\\Console\\Style\\SymfonyStyle' => __DIR__ . '/..' . '/symfony/console/Style/SymfonyStyle.php',
        'Symfony\\Component\\Console\\Terminal' => __DIR__ . '/..' . '/symfony/console/Terminal.php',
        'Symfony\\Component\\Console\\Tester\\ApplicationTester' => __DIR__ . '/..' . '/symfony/console/Tester/ApplicationTester.php',
        'Symfony\\Component\\Console\\Tester\\CommandCompletionTester' => __DIR__ . '/..' . '/symfony/console/Tester/CommandCompletionTester.php',
        'Symfony\\Component\\Console\\Tester\\CommandTester' => __DIR__ . '/..' . '/symfony/console/Tester/CommandTester.php',
        'Symfony\\Component\\Console\\Tester\\Constraint\\CommandIsSuccessful' => __DIR__ . '/..' . '/symfony/console/Tester/Constraint/CommandIsSuccessful.php',
        'Symfony\\Component\\Console\\Tester\\TesterTrait' => __DIR__ . '/..' . '/symfony/console/Tester/TesterTrait.php',
        'Symfony\\Component\\DependencyInjection\\Alias' => __DIR__ . '/..' . '/symfony/dependency-injection/Alias.php',
        'Symfony\\Component\\DependencyInjection\\Argument\\AbstractArgument' => __DIR__ . '/..' . '/symfony/dependency-injection/Argument/AbstractArgument.php',
        'Symfony\\Component\\DependencyInjection\\Argument\\ArgumentInterface' => __DIR__ . '/..' . '/symfony/dependency-injection/Argument/ArgumentInterface.php',
        'Symfony\\Component\\DependencyInjection\\Argument\\BoundArgument' => __DIR__ . '/..' . '/symfony/dependency-injection/Argument/BoundArgument.php',
        'Symfony\\Component\\DependencyInjection\\Argument\\IteratorArgument' => __DIR__ . '/..' . '/symfony/dependency-injection/Argument/IteratorArgument.php',
        'Symfony\\Component\\DependencyInjection\\Argument\\LazyClosure' => __DIR__ . '/..' . '/symfony/dependency-injection/Argument/LazyClosure.php',
        'Symfony\\Component\\DependencyInjection\\Argument\\ReferenceSetArgumentTrait' => __DIR__ . '/..' . '/symfony/dependency-injection/Argument/ReferenceSetArgumentTrait.php',
        'Symfony\\Component\\DependencyInjection\\Argument\\RewindableGenerator' => __DIR__ . '/..' . '/symfony/dependency-injection/Argument/RewindableGenerator.php',
        'Symfony\\Component\\DependencyInjection\\Argument\\ServiceClosureArgument' => __DIR__ . '/..' . '/symfony/dependency-injection/Argument/ServiceClosureArgument.php',
        'Symfony\\Component\\DependencyInjection\\Argument\\ServiceLocator' => __DIR__ . '/..' . '/symfony/dependency-injection/Argument/ServiceLocator.php',
        'Symfony\\Component\\DependencyInjection\\Argument\\ServiceLocatorArgument' => __DIR__ . '/..' . '/symfony/dependency-injection/Argument/ServiceLocatorArgument.php',
        'Symfony\\Component\\DependencyInjection\\Argument\\TaggedIteratorArgument' => __DIR__ . '/..' . '/symfony/dependency-injection/Argument/TaggedIteratorArgument.php',
        'Symfony\\Component\\DependencyInjection\\Attribute\\AsAlias' => __DIR__ . '/..' . '/symfony/dependency-injection/Attribute/AsAlias.php',
        'Symfony\\Component\\DependencyInjection\\Attribute\\AsDecorator' => __DIR__ . '/..' . '/symfony/dependency-injection/Attribute/AsDecorator.php',
        'Symfony\\Component\\DependencyInjection\\Attribute\\AsTaggedItem' => __DIR__ . '/..' . '/symfony/dependency-injection/Attribute/AsTaggedItem.php',
        'Symfony\\Component\\DependencyInjection\\Attribute\\Autoconfigure' => __DIR__ . '/..' . '/symfony/dependency-injection/Attribute/Autoconfigure.php',
        'Symfony\\Component\\DependencyInjection\\Attribute\\AutoconfigureTag' => __DIR__ . '/..' . '/symfony/dependency-injection/Attribute/AutoconfigureTag.php',
        'Symfony\\Component\\DependencyInjection\\Attribute\\Autowire' => __DIR__ . '/..' . '/symfony/dependency-injection/Attribute/Autowire.php',
        'Symfony\\Component\\DependencyInjection\\Attribute\\AutowireCallable' => __DIR__ . '/..' . '/symfony/dependency-injection/Attribute/AutowireCallable.php',
        'Symfony\\Component\\DependencyInjection\\Attribute\\AutowireDecorated' => __DIR__ . '/..' . '/symfony/dependency-injection/Attribute/AutowireDecorated.php',
        'Symfony\\Component\\DependencyInjection\\Attribute\\AutowireIterator' => __DIR__ . '/..' . '/symfony/dependency-injection/Attribute/AutowireIterator.php',
        'Symfony\\Component\\DependencyInjection\\Attribute\\AutowireLocator' => __DIR__ . '/..' . '/symfony/dependency-injection/Attribute/AutowireLocator.php',
        'Symfony\\Component\\DependencyInjection\\Attribute\\AutowireServiceClosure' => __DIR__ . '/..' . '/symfony/dependency-injection/Attribute/AutowireServiceClosure.php',
        'Symfony\\Component\\DependencyInjection\\Attribute\\Exclude' => __DIR__ . '/..' . '/symfony/dependency-injection/Attribute/Exclude.php',
        'Symfony\\Component\\DependencyInjection\\Attribute\\MapDecorated' => __DIR__ . '/..' . '/symfony/dependency-injection/Attribute/MapDecorated.php',
        'Symfony\\Component\\DependencyInjection\\Attribute\\TaggedIterator' => __DIR__ . '/..' . '/symfony/dependency-injection/Attribute/TaggedIterator.php',
        'Symfony\\Component\\DependencyInjection\\Attribute\\TaggedLocator' => __DIR__ . '/..' . '/symfony/dependency-injection/Attribute/TaggedLocator.php',
        'Symfony\\Component\\DependencyInjection\\Attribute\\Target' => __DIR__ . '/..' . '/symfony/dependency-injection/Attribute/Target.php',
        'Symfony\\Component\\DependencyInjection\\Attribute\\When' => __DIR__ . '/..' . '/symfony/dependency-injection/Attribute/When.php',
        'Symfony\\Component\\DependencyInjection\\ChildDefinition' => __DIR__ . '/..' . '/symfony/dependency-injection/ChildDefinition.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\AbstractRecursivePass' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/AbstractRecursivePass.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\AliasDeprecatedPublicServicesPass' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/AliasDeprecatedPublicServicesPass.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\AnalyzeServiceReferencesPass' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/AnalyzeServiceReferencesPass.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\AttributeAutoconfigurationPass' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/AttributeAutoconfigurationPass.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\AutoAliasServicePass' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/AutoAliasServicePass.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\AutowireAsDecoratorPass' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/AutowireAsDecoratorPass.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\AutowirePass' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/AutowirePass.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\AutowireRequiredMethodsPass' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/AutowireRequiredMethodsPass.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\AutowireRequiredPropertiesPass' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/AutowireRequiredPropertiesPass.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\CheckArgumentsValidityPass' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/CheckArgumentsValidityPass.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\CheckCircularReferencesPass' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/CheckCircularReferencesPass.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\CheckDefinitionValidityPass' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/CheckDefinitionValidityPass.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\CheckExceptionOnInvalidReferenceBehaviorPass' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/CheckExceptionOnInvalidReferenceBehaviorPass.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\CheckFactoryBuilderCircularReferencePass' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/CheckFactoryBuilderCircularReferencePass.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\CheckReferenceValidityPass' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/CheckReferenceValidityPass.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\CheckTypeDeclarationsPass' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/CheckTypeDeclarationsPass.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\Compiler' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/Compiler.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\CompilerPassInterface' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/CompilerPassInterface.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\DecoratorServicePass' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/DecoratorServicePass.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\DefinitionErrorExceptionPass' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/DefinitionErrorExceptionPass.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\ExtensionCompilerPass' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/ExtensionCompilerPass.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\InlineServiceDefinitionsPass' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/InlineServiceDefinitionsPass.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\MergeExtensionConfigurationPass' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/MergeExtensionConfigurationPass.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\PassConfig' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/PassConfig.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\PriorityTaggedServiceTrait' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/PriorityTaggedServiceTrait.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\RegisterAutoconfigureAttributesPass' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/RegisterAutoconfigureAttributesPass.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\RegisterEnvVarProcessorsPass' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/RegisterEnvVarProcessorsPass.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\RegisterReverseContainerPass' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/RegisterReverseContainerPass.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\RegisterServiceSubscribersPass' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/RegisterServiceSubscribersPass.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\RemoveAbstractDefinitionsPass' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/RemoveAbstractDefinitionsPass.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\RemoveBuildParametersPass' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/RemoveBuildParametersPass.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\RemovePrivateAliasesPass' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/RemovePrivateAliasesPass.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\RemoveUnusedDefinitionsPass' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/RemoveUnusedDefinitionsPass.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\ReplaceAliasByActualDefinitionPass' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/ReplaceAliasByActualDefinitionPass.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\ResolveBindingsPass' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/ResolveBindingsPass.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\ResolveChildDefinitionsPass' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/ResolveChildDefinitionsPass.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\ResolveClassPass' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/ResolveClassPass.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\ResolveDecoratorStackPass' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/ResolveDecoratorStackPass.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\ResolveEnvPlaceholdersPass' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/ResolveEnvPlaceholdersPass.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\ResolveFactoryClassPass' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/ResolveFactoryClassPass.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\ResolveHotPathPass' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/ResolveHotPathPass.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\ResolveInstanceofConditionalsPass' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/ResolveInstanceofConditionalsPass.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\ResolveInvalidReferencesPass' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/ResolveInvalidReferencesPass.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\ResolveNamedArgumentsPass' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/ResolveNamedArgumentsPass.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\ResolveNoPreloadPass' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/ResolveNoPreloadPass.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\ResolveParameterPlaceHoldersPass' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/ResolveParameterPlaceHoldersPass.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\ResolveReferencesToAliasesPass' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/ResolveReferencesToAliasesPass.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\ResolveServiceSubscribersPass' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/ResolveServiceSubscribersPass.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\ResolveTaggedIteratorArgumentPass' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/ResolveTaggedIteratorArgumentPass.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\ServiceLocatorTagPass' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/ServiceLocatorTagPass.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\ServiceReferenceGraph' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/ServiceReferenceGraph.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\ServiceReferenceGraphEdge' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/ServiceReferenceGraphEdge.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\ServiceReferenceGraphNode' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/ServiceReferenceGraphNode.php',
        'Symfony\\Component\\DependencyInjection\\Compiler\\ValidateEnvPlaceholdersPass' => __DIR__ . '/..' . '/symfony/dependency-injection/Compiler/ValidateEnvPlaceholdersPass.php',
        'Symfony\\Component\\DependencyInjection\\Config\\ContainerParametersResource' => __DIR__ . '/..' . '/symfony/dependency-injection/Config/ContainerParametersResource.php',
        'Symfony\\Component\\DependencyInjection\\Config\\ContainerParametersResourceChecker' => __DIR__ . '/..' . '/symfony/dependency-injection/Config/ContainerParametersResourceChecker.php',
        'Symfony\\Component\\DependencyInjection\\Container' => __DIR__ . '/..' . '/symfony/dependency-injection/Container.php',
        'Symfony\\Component\\DependencyInjection\\ContainerAwareInterface' => __DIR__ . '/..' . '/symfony/dependency-injection/ContainerAwareInterface.php',
        'Symfony\\Component\\DependencyInjection\\ContainerAwareTrait' => __DIR__ . '/..' . '/symfony/dependency-injection/ContainerAwareTrait.php',
        'Symfony\\Component\\DependencyInjection\\ContainerBuilder' => __DIR__ . '/..' . '/symfony/dependency-injection/ContainerBuilder.php',
        'Symfony\\Component\\DependencyInjection\\ContainerInterface' => __DIR__ . '/..' . '/symfony/dependency-injection/ContainerInterface.php',
        'Symfony\\Component\\DependencyInjection\\Definition' => __DIR__ . '/..' . '/symfony/dependency-injection/Definition.php',
        'Symfony\\Component\\DependencyInjection\\Dumper\\Dumper' => __DIR__ . '/..' . '/symfony/dependency-injection/Dumper/Dumper.php',
        'Symfony\\Component\\DependencyInjection\\Dumper\\DumperInterface' => __DIR__ . '/..' . '/symfony/dependency-injection/Dumper/DumperInterface.php',
        'Symfony\\Component\\DependencyInjection\\Dumper\\GraphvizDumper' => __DIR__ . '/..' . '/symfony/dependency-injection/Dumper/GraphvizDumper.php',
        'Symfony\\Component\\DependencyInjection\\Dumper\\PhpDumper' => __DIR__ . '/..' . '/symfony/dependency-injection/Dumper/PhpDumper.php',
        'Symfony\\Component\\DependencyInjection\\Dumper\\Preloader' => __DIR__ . '/..' . '/symfony/dependency-injection/Dumper/Preloader.php',
        'Symfony\\Component\\DependencyInjection\\Dumper\\XmlDumper' => __DIR__ . '/..' . '/symfony/dependency-injection/Dumper/XmlDumper.php',
        'Symfony\\Component\\DependencyInjection\\Dumper\\YamlDumper' => __DIR__ . '/..' . '/symfony/dependency-injection/Dumper/YamlDumper.php',
        'Symfony\\Component\\DependencyInjection\\EnvVarLoaderInterface' => __DIR__ . '/..' . '/symfony/dependency-injection/EnvVarLoaderInterface.php',
        'Symfony\\Component\\DependencyInjection\\EnvVarProcessor' => __DIR__ . '/..' . '/symfony/dependency-injection/EnvVarProcessor.php',
        'Symfony\\Component\\DependencyInjection\\EnvVarProcessorInterface' => __DIR__ . '/..' . '/symfony/dependency-injection/EnvVarProcessorInterface.php',
        'Symfony\\Component\\DependencyInjection\\Exception\\AutowiringFailedException' => __DIR__ . '/..' . '/symfony/dependency-injection/Exception/AutowiringFailedException.php',
        'Symfony\\Component\\DependencyInjection\\Exception\\BadMethodCallException' => __DIR__ . '/..' . '/symfony/dependency-injection/Exception/BadMethodCallException.php',
        'Symfony\\Component\\DependencyInjection\\Exception\\EnvNotFoundException' => __DIR__ . '/..' . '/symfony/dependency-injection/Exception/EnvNotFoundException.php',
        'Symfony\\Component\\DependencyInjection\\Exception\\EnvParameterException' => __DIR__ . '/..' . '/symfony/dependency-injection/Exception/EnvParameterException.php',
        'Symfony\\Component\\DependencyInjection\\Exception\\ExceptionInterface' => __DIR__ . '/..' . '/symfony/dependency-injection/Exception/ExceptionInterface.php',
        'Symfony\\Component\\DependencyInjection\\Exception\\InvalidArgumentException' => __DIR__ . '/..' . '/symfony/dependency-injection/Exception/InvalidArgumentException.php',
        'Symfony\\Component\\DependencyInjection\\Exception\\InvalidParameterTypeException' => __DIR__ . '/..' . '/symfony/dependency-injection/Exception/InvalidParameterTypeException.php',
        'Symfony\\Component\\DependencyInjection\\Exception\\LogicException' => __DIR__ . '/..' . '/symfony/dependency-injection/Exception/LogicException.php',
        'Symfony\\Component\\DependencyInjection\\Exception\\OutOfBoundsException' => __DIR__ . '/..' . '/symfony/dependency-injection/Exception/OutOfBoundsException.php',
        'Symfony\\Component\\DependencyInjection\\Exception\\ParameterCircularReferenceException' => __DIR__ . '/..' . '/symfony/dependency-injection/Exception/ParameterCircularReferenceException.php',
        'Symfony\\Component\\DependencyInjection\\Exception\\ParameterNotFoundException' => __DIR__ . '/..' . '/symfony/dependency-injection/Exception/ParameterNotFoundException.php',
        'Symfony\\Component\\DependencyInjection\\Exception\\RuntimeException' => __DIR__ . '/..' . '/symfony/dependency-injection/Exception/RuntimeException.php',
        'Symfony\\Component\\DependencyInjection\\Exception\\ServiceCircularReferenceException' => __DIR__ . '/..' . '/symfony/dependency-injection/Exception/ServiceCircularReferenceException.php',
        'Symfony\\Component\\DependencyInjection\\Exception\\ServiceNotFoundException' => __DIR__ . '/..' . '/symfony/dependency-injection/Exception/ServiceNotFoundException.php',
        'Symfony\\Component\\DependencyInjection\\ExpressionLanguage' => __DIR__ . '/..' . '/symfony/dependency-injection/ExpressionLanguage.php',
        'Symfony\\Component\\DependencyInjection\\ExpressionLanguageProvider' => __DIR__ . '/..' . '/symfony/dependency-injection/ExpressionLanguageProvider.php',
        'Symfony\\Component\\DependencyInjection\\Extension\\AbstractExtension' => __DIR__ . '/..' . '/symfony/dependency-injection/Extension/AbstractExtension.php',
        'Symfony\\Component\\DependencyInjection\\Extension\\ConfigurableExtensionInterface' => __DIR__ . '/..' . '/symfony/dependency-injection/Extension/ConfigurableExtensionInterface.php',
        'Symfony\\Component\\DependencyInjection\\Extension\\ConfigurationExtensionInterface' => __DIR__ . '/..' . '/symfony/dependency-injection/Extension/ConfigurationExtensionInterface.php',
        'Symfony\\Component\\DependencyInjection\\Extension\\Extension' => __DIR__ . '/..' . '/symfony/dependency-injection/Extension/Extension.php',
        'Symfony\\Component\\DependencyInjection\\Extension\\ExtensionInterface' => __DIR__ . '/..' . '/symfony/dependency-injection/Extension/ExtensionInterface.php',
        'Symfony\\Component\\DependencyInjection\\Extension\\ExtensionTrait' => __DIR__ . '/..' . '/symfony/dependency-injection/Extension/ExtensionTrait.php',
        'Symfony\\Component\\DependencyInjection\\Extension\\PrependExtensionInterface' => __DIR__ . '/..' . '/symfony/dependency-injection/Extension/PrependExtensionInterface.php',
        'Symfony\\Component\\DependencyInjection\\LazyProxy\\Instantiator\\InstantiatorInterface' => __DIR__ . '/..' . '/symfony/dependency-injection/LazyProxy/Instantiator/InstantiatorInterface.php',
        'Symfony\\Component\\DependencyInjection\\LazyProxy\\Instantiator\\LazyServiceInstantiator' => __DIR__ . '/..' . '/symfony/dependency-injection/LazyProxy/Instantiator/LazyServiceInstantiator.php',
        'Symfony\\Component\\DependencyInjection\\LazyProxy\\Instantiator\\RealServiceInstantiator' => __DIR__ . '/..' . '/symfony/dependency-injection/LazyProxy/Instantiator/RealServiceInstantiator.php',
        'Symfony\\Component\\DependencyInjection\\LazyProxy\\PhpDumper\\DumperInterface' => __DIR__ . '/..' . '/symfony/dependency-injection/LazyProxy/PhpDumper/DumperInterface.php',
        'Symfony\\Component\\DependencyInjection\\LazyProxy\\PhpDumper\\LazyServiceDumper' => __DIR__ . '/..' . '/symfony/dependency-injection/LazyProxy/PhpDumper/LazyServiceDumper.php',
        'Symfony\\Component\\DependencyInjection\\LazyProxy\\PhpDumper\\NullDumper' => __DIR__ . '/..' . '/symfony/dependency-injection/LazyProxy/PhpDumper/NullDumper.php',
        'Symfony\\Component\\DependencyInjection\\LazyProxy\\ProxyHelper' => __DIR__ . '/..' . '/symfony/dependency-injection/LazyProxy/ProxyHelper.php',
        'Symfony\\Component\\DependencyInjection\\Loader\\ClosureLoader' => __DIR__ . '/..' . '/symfony/dependency-injection/Loader/ClosureLoader.php',
        'Symfony\\Component\\DependencyInjection\\Loader\\Configurator\\AbstractConfigurator' => __DIR__ . '/..' . '/symfony/dependency-injection/Loader/Configurator/AbstractConfigurator.php',
        'Symfony\\Component\\DependencyInjection\\Loader\\Configurator\\AbstractServiceConfigurator' => __DIR__ . '/..' . '/symfony/dependency-injection/Loader/Configurator/AbstractServiceConfigurator.php',
        'Symfony\\Component\\DependencyInjection\\Loader\\Configurator\\AliasConfigurator' => __DIR__ . '/..' . '/symfony/dependency-injection/Loader/Configurator/AliasConfigurator.php',
        'Symfony\\Component\\DependencyInjection\\Loader\\Configurator\\ClosureReferenceConfigurator' => __DIR__ . '/..' . '/symfony/dependency-injection/Loader/Configurator/ClosureReferenceConfigurator.php',
        'Symfony\\Component\\DependencyInjection\\Loader\\Configurator\\ContainerConfigurator' => __DIR__ . '/..' . '/symfony/dependency-injection/Loader/Configurator/ContainerConfigurator.php',
        'Symfony\\Component\\DependencyInjection\\Loader\\Configurator\\DefaultsConfigurator' => __DIR__ . '/..' . '/symfony/dependency-injection/Loader/Configurator/DefaultsConfigurator.php',
        'Symfony\\Component\\DependencyInjection\\Loader\\Configurator\\EnvConfigurator' => __DIR__ . '/..' . '/symfony/dependency-injection/Loader/Configurator/EnvConfigurator.php',
        'Symfony\\Component\\DependencyInjection\\Loader\\Configurator\\FromCallableConfigurator' => __DIR__ . '/..' . '/symfony/dependency-injection/Loader/Configurator/FromCallableConfigurator.php',
        'Symfony\\Component\\DependencyInjection\\Loader\\Configurator\\InlineServiceConfigurator' => __DIR__ . '/..' . '/symfony/dependency-injection/Loader/Configurator/InlineServiceConfigurator.php',
        'Symfony\\Component\\DependencyInjection\\Loader\\Configurator\\InstanceofConfigurator' => __DIR__ . '/..' . '/symfony/dependency-injection/Loader/Configurator/InstanceofConfigurator.php',
        'Symfony\\Component\\DependencyInjection\\Loader\\Configurator\\ParametersConfigurator' => __DIR__ . '/..' . '/symfony/dependency-injection/Loader/Configurator/ParametersConfigurator.php',
        'Symfony\\Component\\DependencyInjection\\Loader\\Configurator\\PrototypeConfigurator' => __DIR__ . '/..' . '/symfony/dependency-injection/Loader/Configurator/PrototypeConfigurator.php',
        'Symfony\\Component\\DependencyInjection\\Loader\\Configurator\\ReferenceConfigurator' => __DIR__ . '/..' . '/symfony/dependency-injection/Loader/Configurator/ReferenceConfigurator.php',
        'Symfony\\Component\\DependencyInjection\\Loader\\Configurator\\ServiceConfigurator' => __DIR__ . '/..' . '/symfony/dependency-injection/Loader/Configurator/ServiceConfigurator.php',
        'Symfony\\Component\\DependencyInjection\\Loader\\Configurator\\ServicesConfigurator' => __DIR__ . '/..' . '/symfony/dependency-injection/Loader/Configurator/ServicesConfigurator.php',
        'Symfony\\Component\\DependencyInjection\\Loader\\Configurator\\Traits\\AbstractTrait' => __DIR__ . '/..' . '/symfony/dependency-injection/Loader/Configurator/Traits/AbstractTrait.php',
        'Symfony\\Component\\DependencyInjection\\Loader\\Configurator\\Traits\\ArgumentTrait' => __DIR__ . '/..' . '/symfony/dependency-injection/Loader/Configurator/Traits/ArgumentTrait.php',
        'Symfony\\Component\\DependencyInjection\\Loader\\Configurator\\Traits\\AutoconfigureTrait' => __DIR__ . '/..' . '/symfony/dependency-injection/Loader/Configurator/Traits/AutoconfigureTrait.php',
        'Symfony\\Component\\DependencyInjection\\Loader\\Configurator\\Traits\\AutowireTrait' => __DIR__ . '/..' . '/symfony/dependency-injection/Loader/Configurator/Traits/AutowireTrait.php',
        'Symfony\\Component\\DependencyInjection\\Loader\\Configurator\\Traits\\BindTrait' => __DIR__ . '/..' . '/symfony/dependency-injection/Loader/Configurator/Traits/BindTrait.php',
        'Symfony\\Component\\DependencyInjection\\Loader\\Configurator\\Traits\\CallTrait' => __DIR__ . '/..' . '/symfony/dependency-injection/Loader/Configurator/Traits/CallTrait.php',
        'Symfony\\Component\\DependencyInjection\\Loader\\Configurator\\Traits\\ClassTrait' => __DIR__ . '/..' . '/symfony/dependency-injection/Loader/Configurator/Traits/ClassTrait.php',
        'Symfony\\Component\\DependencyInjection\\Loader\\Configurator\\Traits\\ConfiguratorTrait' => __DIR__ . '/..' . '/symfony/dependency-injection/Loader/Configurator/Traits/ConfiguratorTrait.php',
        'Symfony\\Component\\DependencyInjection\\Loader\\Configurator\\Traits\\ConstructorTrait' => __DIR__ . '/..' . '/symfony/dependency-injection/Loader/Configurator/Traits/ConstructorTrait.php',
        'Symfony\\Component\\DependencyInjection\\Loader\\Configurator\\Traits\\DecorateTrait' => __DIR__ . '/..' . '/symfony/dependency-injection/Loader/Configurator/Traits/DecorateTrait.php',
        'Symfony\\Component\\DependencyInjection\\Loader\\Configurator\\Traits\\DeprecateTrait' => __DIR__ . '/..' . '/symfony/dependency-injection/Loader/Configurator/Traits/DeprecateTrait.php',
        'Symfony\\Component\\DependencyInjection\\Loader\\Configurator\\Traits\\FactoryTrait' => __DIR__ . '/..' . '/symfony/dependency-injection/Loader/Configurator/Traits/FactoryTrait.php',
        'Symfony\\Component\\DependencyInjection\\Loader\\Configurator\\Traits\\FileTrait' => __DIR__ . '/..' . '/symfony/dependency-injection/Loader/Configurator/Traits/FileTrait.php',
        'Symfony\\Component\\DependencyInjection\\Loader\\Configurator\\Traits\\FromCallableTrait' => __DIR__ . '/..' . '/symfony/dependency-injection/Loader/Configurator/Traits/FromCallableTrait.php',
        'Symfony\\Component\\DependencyInjection\\Loader\\Configurator\\Traits\\LazyTrait' => __DIR__ . '/..' . '/symfony/dependency-injection/Loader/Configurator/Traits/LazyTrait.php',
        'Symfony\\Component\\DependencyInjection\\Loader\\Configurator\\Traits\\ParentTrait' => __DIR__ . '/..' . '/symfony/dependency-injection/Loader/Configurator/Traits/ParentTrait.php',
        'Symfony\\Component\\DependencyInjection\\Loader\\Configurator\\Traits\\PropertyTrait' => __DIR__ . '/..' . '/symfony/dependency-injection/Loader/Configurator/Traits/PropertyTrait.php',
        'Symfony\\Component\\DependencyInjection\\Loader\\Configurator\\Traits\\PublicTrait' => __DIR__ . '/..' . '/symfony/dependency-injection/Loader/Configurator/Traits/PublicTrait.php',
        'Symfony\\Component\\DependencyInjection\\Loader\\Configurator\\Traits\\ShareTrait' => __DIR__ . '/..' . '/symfony/dependency-injection/Loader/Configurator/Traits/ShareTrait.php',
        'Symfony\\Component\\DependencyInjection\\Loader\\Configurator\\Traits\\SyntheticTrait' => __DIR__ . '/..' . '/symfony/dependency-injection/Loader/Configurator/Traits/SyntheticTrait.php',
        'Symfony\\Component\\DependencyInjection\\Loader\\Configurator\\Traits\\TagTrait' => __DIR__ . '/..' . '/symfony/dependency-injection/Loader/Configurator/Traits/TagTrait.php',
        'Symfony\\Component\\DependencyInjection\\Loader\\DirectoryLoader' => __DIR__ . '/..' . '/symfony/dependency-injection/Loader/DirectoryLoader.php',
        'Symfony\\Component\\DependencyInjection\\Loader\\FileLoader' => __DIR__ . '/..' . '/symfony/dependency-injection/Loader/FileLoader.php',
        'Symfony\\Component\\DependencyInjection\\Loader\\GlobFileLoader' => __DIR__ . '/..' . '/symfony/dependency-injection/Loader/GlobFileLoader.php',
        'Symfony\\Component\\DependencyInjection\\Loader\\IniFileLoader' => __DIR__ . '/..' . '/symfony/dependency-injection/Loader/IniFileLoader.php',
        'Symfony\\Component\\DependencyInjection\\Loader\\PhpFileLoader' => __DIR__ . '/..' . '/symfony/dependency-injection/Loader/PhpFileLoader.php',
        'Symfony\\Component\\DependencyInjection\\Loader\\XmlFileLoader' => __DIR__ . '/..' . '/symfony/dependency-injection/Loader/XmlFileLoader.php',
        'Symfony\\Component\\DependencyInjection\\Loader\\YamlFileLoader' => __DIR__ . '/..' . '/symfony/dependency-injection/Loader/YamlFileLoader.php',
        'Symfony\\Component\\DependencyInjection\\Parameter' => __DIR__ . '/..' . '/symfony/dependency-injection/Parameter.php',
        'Symfony\\Component\\DependencyInjection\\ParameterBag\\ContainerBag' => __DIR__ . '/..' . '/symfony/dependency-injection/ParameterBag/ContainerBag.php',
        'Symfony\\Component\\DependencyInjection\\ParameterBag\\ContainerBagInterface' => __DIR__ . '/..' . '/symfony/dependency-injection/ParameterBag/ContainerBagInterface.php',
        'Symfony\\Component\\DependencyInjection\\ParameterBag\\EnvPlaceholderParameterBag' => __DIR__ . '/..' . '/symfony/dependency-injection/ParameterBag/EnvPlaceholderParameterBag.php',
        'Symfony\\Component\\DependencyInjection\\ParameterBag\\FrozenParameterBag' => __DIR__ . '/..' . '/symfony/dependency-injection/ParameterBag/FrozenParameterBag.php',
        'Symfony\\Component\\DependencyInjection\\ParameterBag\\ParameterBag' => __DIR__ . '/..' . '/symfony/dependency-injection/ParameterBag/ParameterBag.php',
        'Symfony\\Component\\DependencyInjection\\ParameterBag\\ParameterBagInterface' => __DIR__ . '/..' . '/symfony/dependency-injection/ParameterBag/ParameterBagInterface.php',
        'Symfony\\Component\\DependencyInjection\\Reference' => __DIR__ . '/..' . '/symfony/dependency-injection/Reference.php',
        'Symfony\\Component\\DependencyInjection\\ReverseContainer' => __DIR__ . '/..' . '/symfony/dependency-injection/ReverseContainer.php',
        'Symfony\\Component\\DependencyInjection\\ServiceLocator' => __DIR__ . '/..' . '/symfony/dependency-injection/ServiceLocator.php',
        'Symfony\\Component\\DependencyInjection\\TaggedContainerInterface' => __DIR__ . '/..' . '/symfony/dependency-injection/TaggedContainerInterface.php',
        'Symfony\\Component\\DependencyInjection\\TypedReference' => __DIR__ . '/..' . '/symfony/dependency-injection/TypedReference.php',
        'Symfony\\Component\\DependencyInjection\\Variable' => __DIR__ . '/..' . '/symfony/dependency-injection/Variable.php',
        'Symfony\\Component\\ErrorHandler\\BufferingLogger' => __DIR__ . '/..' . '/symfony/error-handler/BufferingLogger.php',
        'Symfony\\Component\\ErrorHandler\\Debug' => __DIR__ . '/..' . '/symfony/error-handler/Debug.php',
        'Symfony\\Component\\ErrorHandler\\DebugClassLoader' => __DIR__ . '/..' . '/symfony/error-handler/DebugClassLoader.php',
        'Symfony\\Component\\ErrorHandler\\ErrorEnhancer\\ClassNotFoundErrorEnhancer' => __DIR__ . '/..' . '/symfony/error-handler/ErrorEnhancer/ClassNotFoundErrorEnhancer.php',
        'Symfony\\Component\\ErrorHandler\\ErrorEnhancer\\ErrorEnhancerInterface' => __DIR__ . '/..' . '/symfony/error-handler/ErrorEnhancer/ErrorEnhancerInterface.php',
        'Symfony\\Component\\ErrorHandler\\ErrorEnhancer\\UndefinedFunctionErrorEnhancer' => __DIR__ . '/..' . '/symfony/error-handler/ErrorEnhancer/UndefinedFunctionErrorEnhancer.php',
        'Symfony\\Component\\ErrorHandler\\ErrorEnhancer\\UndefinedMethodErrorEnhancer' => __DIR__ . '/..' . '/symfony/error-handler/ErrorEnhancer/UndefinedMethodErrorEnhancer.php',
        'Symfony\\Component\\ErrorHandler\\ErrorHandler' => __DIR__ . '/..' . '/symfony/error-handler/ErrorHandler.php',
        'Symfony\\Component\\ErrorHandler\\ErrorRenderer\\CliErrorRenderer' => __DIR__ . '/..' . '/symfony/error-handler/ErrorRenderer/CliErrorRenderer.php',
        'Symfony\\Component\\ErrorHandler\\ErrorRenderer\\ErrorRendererInterface' => __DIR__ . '/..' . '/symfony/error-handler/ErrorRenderer/ErrorRendererInterface.php',
        'Symfony\\Component\\ErrorHandler\\ErrorRenderer\\FileLinkFormatter' => __DIR__ . '/..' . '/symfony/error-handler/ErrorRenderer/FileLinkFormatter.php',
        'Symfony\\Component\\ErrorHandler\\ErrorRenderer\\HtmlErrorRenderer' => __DIR__ . '/..' . '/symfony/error-handler/ErrorRenderer/HtmlErrorRenderer.php',
        'Symfony\\Component\\ErrorHandler\\ErrorRenderer\\SerializerErrorRenderer' => __DIR__ . '/..' . '/symfony/error-handler/ErrorRenderer/SerializerErrorRenderer.php',
        'Symfony\\Component\\ErrorHandler\\Error\\ClassNotFoundError' => __DIR__ . '/..' . '/symfony/error-handler/Error/ClassNotFoundError.php',
        'Symfony\\Component\\ErrorHandler\\Error\\FatalError' => __DIR__ . '/..' . '/symfony/error-handler/Error/FatalError.php',
        'Symfony\\Component\\ErrorHandler\\Error\\OutOfMemoryError' => __DIR__ . '/..' . '/symfony/error-handler/Error/OutOfMemoryError.php',
        'Symfony\\Component\\ErrorHandler\\Error\\UndefinedFunctionError' => __DIR__ . '/..' . '/symfony/error-handler/Error/UndefinedFunctionError.php',
        'Symfony\\Component\\ErrorHandler\\Error\\UndefinedMethodError' => __DIR__ . '/..' . '/symfony/error-handler/Error/UndefinedMethodError.php',
        'Symfony\\Component\\ErrorHandler\\Exception\\FlattenException' => __DIR__ . '/..' . '/symfony/error-handler/Exception/FlattenException.php',
        'Symfony\\Component\\ErrorHandler\\Exception\\SilencedErrorContext' => __DIR__ . '/..' . '/symfony/error-handler/Exception/SilencedErrorContext.php',
        'Symfony\\Component\\ErrorHandler\\Internal\\TentativeTypes' => __DIR__ . '/..' . '/symfony/error-handler/Internal/TentativeTypes.php',
        'Symfony\\Component\\ErrorHandler\\ThrowableUtils' => __DIR__ . '/..' . '/symfony/error-handler/ThrowableUtils.php',
        'Symfony\\Component\\EventDispatcher\\Attribute\\AsEventListener' => __DIR__ . '/..' . '/symfony/event-dispatcher/Attribute/AsEventListener.php',
        'Symfony\\Component\\EventDispatcher\\Debug\\TraceableEventDispatcher' => __DIR__ . '/..' . '/symfony/event-dispatcher/Debug/TraceableEventDispatcher.php',
        'Symfony\\Component\\EventDispatcher\\Debug\\WrappedListener' => __DIR__ . '/..' . '/symfony/event-dispatcher/Debug/WrappedListener.php',
        'Symfony\\Component\\EventDispatcher\\DependencyInjection\\AddEventAliasesPass' => __DIR__ . '/..' . '/symfony/event-dispatcher/DependencyInjection/AddEventAliasesPass.php',
        'Symfony\\Component\\EventDispatcher\\DependencyInjection\\RegisterListenersPass' => __DIR__ . '/..' . '/symfony/event-dispatcher/DependencyInjection/RegisterListenersPass.php',
        'Symfony\\Component\\EventDispatcher\\EventDispatcher' => __DIR__ . '/..' . '/symfony/event-dispatcher/EventDispatcher.php',
        'Symfony\\Component\\EventDispatcher\\EventDispatcherInterface' => __DIR__ . '/..' . '/symfony/event-dispatcher/EventDispatcherInterface.php',
        'Symfony\\Component\\EventDispatcher\\EventSubscriberInterface' => __DIR__ . '/..' . '/symfony/event-dispatcher/EventSubscriberInterface.php',
        'Symfony\\Component\\EventDispatcher\\GenericEvent' => __DIR__ . '/..' . '/symfony/event-dispatcher/GenericEvent.php',
        'Symfony\\Component\\EventDispatcher\\ImmutableEventDispatcher' => __DIR__ . '/..' . '/symfony/event-dispatcher/ImmutableEventDispatcher.php',
        'Symfony\\Component\\ExpressionLanguage\\Compiler' => __DIR__ . '/..' . '/symfony/expression-language/Compiler.php',
        'Symfony\\Component\\ExpressionLanguage\\Expression' => __DIR__ . '/..' . '/symfony/expression-language/Expression.php',
        'Symfony\\Component\\ExpressionLanguage\\ExpressionFunction' => __DIR__ . '/..' . '/symfony/expression-language/ExpressionFunction.php',
        'Symfony\\Component\\ExpressionLanguage\\ExpressionFunctionProviderInterface' => __DIR__ . '/..' . '/symfony/expression-language/ExpressionFunctionProviderInterface.php',
        'Symfony\\Component\\ExpressionLanguage\\ExpressionLanguage' => __DIR__ . '/..' . '/symfony/expression-language/ExpressionLanguage.php',
        'Symfony\\Component\\ExpressionLanguage\\Lexer' => __DIR__ . '/..' . '/symfony/expression-language/Lexer.php',
        'Symfony\\Component\\ExpressionLanguage\\Node\\ArgumentsNode' => __DIR__ . '/..' . '/symfony/expression-language/Node/ArgumentsNode.php',
        'Symfony\\Component\\ExpressionLanguage\\Node\\ArrayNode' => __DIR__ . '/..' . '/symfony/expression-language/Node/ArrayNode.php',
        'Symfony\\Component\\ExpressionLanguage\\Node\\BinaryNode' => __DIR__ . '/..' . '/symfony/expression-language/Node/BinaryNode.php',
        'Symfony\\Component\\ExpressionLanguage\\Node\\ConditionalNode' => __DIR__ . '/..' . '/symfony/expression-language/Node/ConditionalNode.php',
        'Symfony\\Component\\ExpressionLanguage\\Node\\ConstantNode' => __DIR__ . '/..' . '/symfony/expression-language/Node/ConstantNode.php',
        'Symfony\\Component\\ExpressionLanguage\\Node\\FunctionNode' => __DIR__ . '/..' . '/symfony/expression-language/Node/FunctionNode.php',
        'Symfony\\Component\\ExpressionLanguage\\Node\\GetAttrNode' => __DIR__ . '/..' . '/symfony/expression-language/Node/GetAttrNode.php',
        'Symfony\\Component\\ExpressionLanguage\\Node\\NameNode' => __DIR__ . '/..' . '/symfony/expression-language/Node/NameNode.php',
        'Symfony\\Component\\ExpressionLanguage\\Node\\Node' => __DIR__ . '/..' . '/symfony/expression-language/Node/Node.php',
        'Symfony\\Component\\ExpressionLanguage\\Node\\NullCoalesceNode' => __DIR__ . '/..' . '/symfony/expression-language/Node/NullCoalesceNode.php',
        'Symfony\\Component\\ExpressionLanguage\\Node\\UnaryNode' => __DIR__ . '/..' . '/symfony/expression-language/Node/UnaryNode.php',
        'Symfony\\Component\\ExpressionLanguage\\ParsedExpression' => __DIR__ . '/..' . '/symfony/expression-language/ParsedExpression.php',
        'Symfony\\Component\\ExpressionLanguage\\Parser' => __DIR__ . '/..' . '/symfony/expression-language/Parser.php',
        'Symfony\\Component\\ExpressionLanguage\\SerializedParsedExpression' => __DIR__ . '/..' . '/symfony/expression-language/SerializedParsedExpression.php',
        'Symfony\\Component\\ExpressionLanguage\\SyntaxError' => __DIR__ . '/..' . '/symfony/expression-language/SyntaxError.php',
        'Symfony\\Component\\ExpressionLanguage\\Token' => __DIR__ . '/..' . '/symfony/expression-language/Token.php',
        'Symfony\\Component\\ExpressionLanguage\\TokenStream' => __DIR__ . '/..' . '/symfony/expression-language/TokenStream.php',
        'Symfony\\Component\\Filesystem\\Exception\\ExceptionInterface' => __DIR__ . '/..' . '/symfony/filesystem/Exception/ExceptionInterface.php',
        'Symfony\\Component\\Filesystem\\Exception\\FileNotFoundException' => __DIR__ . '/..' . '/symfony/filesystem/Exception/FileNotFoundException.php',
        'Symfony\\Component\\Filesystem\\Exception\\IOException' => __DIR__ . '/..' . '/symfony/filesystem/Exception/IOException.php',
        'Symfony\\Component\\Filesystem\\Exception\\IOExceptionInterface' => __DIR__ . '/..' . '/symfony/filesystem/Exception/IOExceptionInterface.php',
        'Symfony\\Component\\Filesystem\\Exception\\InvalidArgumentException' => __DIR__ . '/..' . '/symfony/filesystem/Exception/InvalidArgumentException.php',
        'Symfony\\Component\\Filesystem\\Exception\\RuntimeException' => __DIR__ . '/..' . '/symfony/filesystem/Exception/RuntimeException.php',
        'Symfony\\Component\\Filesystem\\Filesystem' => __DIR__ . '/..' . '/symfony/filesystem/Filesystem.php',
        'Symfony\\Component\\Filesystem\\Path' => __DIR__ . '/..' . '/symfony/filesystem/Path.php',
        'Symfony\\Component\\Finder\\Comparator\\Comparator' => __DIR__ . '/..' . '/symfony/finder/Comparator/Comparator.php',
        'Symfony\\Component\\Finder\\Comparator\\DateComparator' => __DIR__ . '/..' . '/symfony/finder/Comparator/DateComparator.php',
        'Symfony\\Component\\Finder\\Comparator\\NumberComparator' => __DIR__ . '/..' . '/symfony/finder/Comparator/NumberComparator.php',
        'Symfony\\Component\\Finder\\Exception\\AccessDeniedException' => __DIR__ . '/..' . '/symfony/finder/Exception/AccessDeniedException.php',
        'Symfony\\Component\\Finder\\Exception\\DirectoryNotFoundException' => __DIR__ . '/..' . '/symfony/finder/Exception/DirectoryNotFoundException.php',
        'Symfony\\Component\\Finder\\Finder' => __DIR__ . '/..' . '/symfony/finder/Finder.php',
        'Symfony\\Component\\Finder\\Gitignore' => __DIR__ . '/..' . '/symfony/finder/Gitignore.php',
        'Symfony\\Component\\Finder\\Glob' => __DIR__ . '/..' . '/symfony/finder/Glob.php',
        'Symfony\\Component\\Finder\\Iterator\\CustomFilterIterator' => __DIR__ . '/..' . '/symfony/finder/Iterator/CustomFilterIterator.php',
        'Symfony\\Component\\Finder\\Iterator\\DateRangeFilterIterator' => __DIR__ . '/..' . '/symfony/finder/Iterator/DateRangeFilterIterator.php',
        'Symfony\\Component\\Finder\\Iterator\\DepthRangeFilterIterator' => __DIR__ . '/..' . '/symfony/finder/Iterator/DepthRangeFilterIterator.php',
        'Symfony\\Component\\Finder\\Iterator\\ExcludeDirectoryFilterIterator' => __DIR__ . '/..' . '/symfony/finder/Iterator/ExcludeDirectoryFilterIterator.php',
        'Symfony\\Component\\Finder\\Iterator\\FileTypeFilterIterator' => __DIR__ . '/..' . '/symfony/finder/Iterator/FileTypeFilterIterator.php',
        'Symfony\\Component\\Finder\\Iterator\\FilecontentFilterIterator' => __DIR__ . '/..' . '/symfony/finder/Iterator/FilecontentFilterIterator.php',
        'Symfony\\Component\\Finder\\Iterator\\FilenameFilterIterator' => __DIR__ . '/..' . '/symfony/finder/Iterator/FilenameFilterIterator.php',
        'Symfony\\Component\\Finder\\Iterator\\LazyIterator' => __DIR__ . '/..' . '/symfony/finder/Iterator/LazyIterator.php',
        'Symfony\\Component\\Finder\\Iterator\\MultiplePcreFilterIterator' => __DIR__ . '/..' . '/symfony/finder/Iterator/MultiplePcreFilterIterator.php',
        'Symfony\\Component\\Finder\\Iterator\\PathFilterIterator' => __DIR__ . '/..' . '/symfony/finder/Iterator/PathFilterIterator.php',
        'Symfony\\Component\\Finder\\Iterator\\RecursiveDirectoryIterator' => __DIR__ . '/..' . '/symfony/finder/Iterator/RecursiveDirectoryIterator.php',
        'Symfony\\Component\\Finder\\Iterator\\SizeRangeFilterIterator' => __DIR__ . '/..' . '/symfony/finder/Iterator/SizeRangeFilterIterator.php',
        'Symfony\\Component\\Finder\\Iterator\\SortableIterator' => __DIR__ . '/..' . '/symfony/finder/Iterator/SortableIterator.php',
        'Symfony\\Component\\Finder\\Iterator\\VcsIgnoredFilterIterator' => __DIR__ . '/..' . '/symfony/finder/Iterator/VcsIgnoredFilterIterator.php',
        'Symfony\\Component\\Finder\\SplFileInfo' => __DIR__ . '/..' . '/symfony/finder/SplFileInfo.php',
        'Symfony\\Component\\HttpFoundation\\AcceptHeader' => __DIR__ . '/..' . '/symfony/http-foundation/AcceptHeader.php',
        'Symfony\\Component\\HttpFoundation\\AcceptHeaderItem' => __DIR__ . '/..' . '/symfony/http-foundation/AcceptHeaderItem.php',
        'Symfony\\Component\\HttpFoundation\\BinaryFileResponse' => __DIR__ . '/..' . '/symfony/http-foundation/BinaryFileResponse.php',
        'Symfony\\Component\\HttpFoundation\\ChainRequestMatcher' => __DIR__ . '/..' . '/symfony/http-foundation/ChainRequestMatcher.php',
        'Symfony\\Component\\HttpFoundation\\Cookie' => __DIR__ . '/..' . '/symfony/http-foundation/Cookie.php',
        'Symfony\\Component\\HttpFoundation\\Exception\\BadRequestException' => __DIR__ . '/..' . '/symfony/http-foundation/Exception/BadRequestException.php',
        'Symfony\\Component\\HttpFoundation\\Exception\\ConflictingHeadersException' => __DIR__ . '/..' . '/symfony/http-foundation/Exception/ConflictingHeadersException.php',
        'Symfony\\Component\\HttpFoundation\\Exception\\JsonException' => __DIR__ . '/..' . '/symfony/http-foundation/Exception/JsonException.php',
        'Symfony\\Component\\HttpFoundation\\Exception\\RequestExceptionInterface' => __DIR__ . '/..' . '/symfony/http-foundation/Exception/RequestExceptionInterface.php',
        'Symfony\\Component\\HttpFoundation\\Exception\\SessionNotFoundException' => __DIR__ . '/..' . '/symfony/http-foundation/Exception/SessionNotFoundException.php',
        'Symfony\\Component\\HttpFoundation\\Exception\\SuspiciousOperationException' => __DIR__ . '/..' . '/symfony/http-foundation/Exception/SuspiciousOperationException.php',
        'Symfony\\Component\\HttpFoundation\\Exception\\UnexpectedValueException' => __DIR__ . '/..' . '/symfony/http-foundation/Exception/UnexpectedValueException.php',
        'Symfony\\Component\\HttpFoundation\\ExpressionRequestMatcher' => __DIR__ . '/..' . '/symfony/http-foundation/ExpressionRequestMatcher.php',
        'Symfony\\Component\\HttpFoundation\\FileBag' => __DIR__ . '/..' . '/symfony/http-foundation/FileBag.php',
        'Symfony\\Component\\HttpFoundation\\File\\Exception\\AccessDeniedException' => __DIR__ . '/..' . '/symfony/http-foundation/File/Exception/AccessDeniedException.php',
        'Symfony\\Component\\HttpFoundation\\File\\Exception\\CannotWriteFileException' => __DIR__ . '/..' . '/symfony/http-foundation/File/Exception/CannotWriteFileException.php',
        'Symfony\\Component\\HttpFoundation\\File\\Exception\\ExtensionFileException' => __DIR__ . '/..' . '/symfony/http-foundation/File/Exception/ExtensionFileException.php',
        'Symfony\\Component\\HttpFoundation\\File\\Exception\\FileException' => __DIR__ . '/..' . '/symfony/http-foundation/File/Exception/FileException.php',
        'Symfony\\Component\\HttpFoundation\\File\\Exception\\FileNotFoundException' => __DIR__ . '/..' . '/symfony/http-foundation/File/Exception/FileNotFoundException.php',
        'Symfony\\Component\\HttpFoundation\\File\\Exception\\FormSizeFileException' => __DIR__ . '/..' . '/symfony/http-foundation/File/Exception/FormSizeFileException.php',
        'Symfony\\Component\\HttpFoundation\\File\\Exception\\IniSizeFileException' => __DIR__ . '/..' . '/symfony/http-foundation/File/Exception/IniSizeFileException.php',
        'Symfony\\Component\\HttpFoundation\\File\\Exception\\NoFileException' => __DIR__ . '/..' . '/symfony/http-foundation/File/Exception/NoFileException.php',
        'Symfony\\Component\\HttpFoundation\\File\\Exception\\NoTmpDirFileException' => __DIR__ . '/..' . '/symfony/http-foundation/File/Exception/NoTmpDirFileException.php',
        'Symfony\\Component\\HttpFoundation\\File\\Exception\\PartialFileException' => __DIR__ . '/..' . '/symfony/http-foundation/File/Exception/PartialFileException.php',
        'Symfony\\Component\\HttpFoundation\\File\\Exception\\UnexpectedTypeException' => __DIR__ . '/..' . '/symfony/http-foundation/File/Exception/UnexpectedTypeException.php',
        'Symfony\\Component\\HttpFoundation\\File\\Exception\\UploadException' => __DIR__ . '/..' . '/symfony/http-foundation/File/Exception/UploadException.php',
        'Symfony\\Component\\HttpFoundation\\File\\File' => __DIR__ . '/..' . '/symfony/http-foundation/File/File.php',
        'Symfony\\Component\\HttpFoundation\\File\\Stream' => __DIR__ . '/..' . '/symfony/http-foundation/File/Stream.php',
        'Symfony\\Component\\HttpFoundation\\File\\UploadedFile' => __DIR__ . '/..' . '/symfony/http-foundation/File/UploadedFile.php',
        'Symfony\\Component\\HttpFoundation\\HeaderBag' => __DIR__ . '/..' . '/symfony/http-foundation/HeaderBag.php',
        'Symfony\\Component\\HttpFoundation\\HeaderUtils' => __DIR__ . '/..' . '/symfony/http-foundation/HeaderUtils.php',
        'Symfony\\Component\\HttpFoundation\\InputBag' => __DIR__ . '/..' . '/symfony/http-foundation/InputBag.php',
        'Symfony\\Component\\HttpFoundation\\IpUtils' => __DIR__ . '/..' . '/symfony/http-foundation/IpUtils.php',
        'Symfony\\Component\\HttpFoundation\\JsonResponse' => __DIR__ . '/..' . '/symfony/http-foundation/JsonResponse.php',
        'Symfony\\Component\\HttpFoundation\\ParameterBag' => __DIR__ . '/..' . '/symfony/http-foundation/ParameterBag.php',
        'Symfony\\Component\\HttpFoundation\\RateLimiter\\AbstractRequestRateLimiter' => __DIR__ . '/..' . '/symfony/http-foundation/RateLimiter/AbstractRequestRateLimiter.php',
        'Symfony\\Component\\HttpFoundation\\RateLimiter\\PeekableRequestRateLimiterInterface' => __DIR__ . '/..' . '/symfony/http-foundation/RateLimiter/PeekableRequestRateLimiterInterface.php',
        'Symfony\\Component\\HttpFoundation\\RateLimiter\\RequestRateLimiterInterface' => __DIR__ . '/..' . '/symfony/http-foundation/RateLimiter/RequestRateLimiterInterface.php',
        'Symfony\\Component\\HttpFoundation\\RedirectResponse' => __DIR__ . '/..' . '/symfony/http-foundation/RedirectResponse.php',
        'Symfony\\Component\\HttpFoundation\\Request' => __DIR__ . '/..' . '/symfony/http-foundation/Request.php',
        'Symfony\\Component\\HttpFoundation\\RequestMatcher' => __DIR__ . '/..' . '/symfony/http-foundation/RequestMatcher.php',
        'Symfony\\Component\\HttpFoundation\\RequestMatcherInterface' => __DIR__ . '/..' . '/symfony/http-foundation/RequestMatcherInterface.php',
        'Symfony\\Component\\HttpFoundation\\RequestMatcher\\AttributesRequestMatcher' => __DIR__ . '/..' . '/symfony/http-foundation/RequestMatcher/AttributesRequestMatcher.php',
        'Symfony\\Component\\HttpFoundation\\RequestMatcher\\ExpressionRequestMatcher' => __DIR__ . '/..' . '/symfony/http-foundation/RequestMatcher/ExpressionRequestMatcher.php',
        'Symfony\\Component\\HttpFoundation\\RequestMatcher\\HostRequestMatcher' => __DIR__ . '/..' . '/symfony/http-foundation/RequestMatcher/HostRequestMatcher.php',
        'Symfony\\Component\\HttpFoundation\\RequestMatcher\\IpsRequestMatcher' => __DIR__ . '/..' . '/symfony/http-foundation/RequestMatcher/IpsRequestMatcher.php',
        'Symfony\\Component\\HttpFoundation\\RequestMatcher\\IsJsonRequestMatcher' => __DIR__ . '/..' . '/symfony/http-foundation/RequestMatcher/IsJsonRequestMatcher.php',
        'Symfony\\Component\\HttpFoundation\\RequestMatcher\\MethodRequestMatcher' => __DIR__ . '/..' . '/symfony/http-foundation/RequestMatcher/MethodRequestMatcher.php',
        'Symfony\\Component\\HttpFoundation\\RequestMatcher\\PathRequestMatcher' => __DIR__ . '/..' . '/symfony/http-foundation/RequestMatcher/PathRequestMatcher.php',
        'Symfony\\Component\\HttpFoundation\\RequestMatcher\\PortRequestMatcher' => __DIR__ . '/..' . '/symfony/http-foundation/RequestMatcher/PortRequestMatcher.php',
        'Symfony\\Component\\HttpFoundation\\RequestMatcher\\SchemeRequestMatcher' => __DIR__ . '/..' . '/symfony/http-foundation/RequestMatcher/SchemeRequestMatcher.php',
        'Symfony\\Component\\HttpFoundation\\RequestStack' => __DIR__ . '/..' . '/symfony/http-foundation/RequestStack.php',
        'Symfony\\Component\\HttpFoundation\\Response' => __DIR__ . '/..' . '/symfony/http-foundation/Response.php',
        'Symfony\\Component\\HttpFoundation\\ResponseHeaderBag' => __DIR__ . '/..' . '/symfony/http-foundation/ResponseHeaderBag.php',
        'Symfony\\Component\\HttpFoundation\\ServerBag' => __DIR__ . '/..' . '/symfony/http-foundation/ServerBag.php',
        'Symfony\\Component\\HttpFoundation\\Session\\Attribute\\AttributeBag' => __DIR__ . '/..' . '/symfony/http-foundation/Session/Attribute/AttributeBag.php',
        'Symfony\\Component\\HttpFoundation\\Session\\Attribute\\AttributeBagInterface' => __DIR__ . '/..' . '/symfony/http-foundation/Session/Attribute/AttributeBagInterface.php',
        'Symfony\\Component\\HttpFoundation\\Session\\FlashBagAwareSessionInterface' => __DIR__ . '/..' . '/symfony/http-foundation/Session/FlashBagAwareSessionInterface.php',
        'Symfony\\Component\\HttpFoundation\\Session\\Flash\\AutoExpireFlashBag' => __DIR__ . '/..' . '/symfony/http-foundation/Session/Flash/AutoExpireFlashBag.php',
        'Symfony\\Component\\HttpFoundation\\Session\\Flash\\FlashBag' => __DIR__ . '/..' . '/symfony/http-foundation/Session/Flash/FlashBag.php',
        'Symfony\\Component\\HttpFoundation\\Session\\Flash\\FlashBagInterface' => __DIR__ . '/..' . '/symfony/http-foundation/Session/Flash/FlashBagInterface.php',
        'Symfony\\Component\\HttpFoundation\\Session\\Session' => __DIR__ . '/..' . '/symfony/http-foundation/Session/Session.php',
        'Symfony\\Component\\HttpFoundation\\Session\\SessionBagInterface' => __DIR__ . '/..' . '/symfony/http-foundation/Session/SessionBagInterface.php',
        'Symfony\\Component\\HttpFoundation\\Session\\SessionBagProxy' => __DIR__ . '/..' . '/symfony/http-foundation/Session/SessionBagProxy.php',
        'Symfony\\Component\\HttpFoundation\\Session\\SessionFactory' => __DIR__ . '/..' . '/symfony/http-foundation/Session/SessionFactory.php',
        'Symfony\\Component\\HttpFoundation\\Session\\SessionFactoryInterface' => __DIR__ . '/..' . '/symfony/http-foundation/Session/SessionFactoryInterface.php',
        'Symfony\\Component\\HttpFoundation\\Session\\SessionInterface' => __DIR__ . '/..' . '/symfony/http-foundation/Session/SessionInterface.php',
        'Symfony\\Component\\HttpFoundation\\Session\\SessionUtils' => __DIR__ . '/..' . '/symfony/http-foundation/Session/SessionUtils.php',
        'Symfony\\Component\\HttpFoundation\\Session\\Storage\\Handler\\AbstractSessionHandler' => __DIR__ . '/..' . '/symfony/http-foundation/Session/Storage/Handler/AbstractSessionHandler.php',
        'Symfony\\Component\\HttpFoundation\\Session\\Storage\\Handler\\IdentityMarshaller' => __DIR__ . '/..' . '/symfony/http-foundation/Session/Storage/Handler/IdentityMarshaller.php',
        'Symfony\\Component\\HttpFoundation\\Session\\Storage\\Handler\\MarshallingSessionHandler' => __DIR__ . '/..' . '/symfony/http-foundation/Session/Storage/Handler/MarshallingSessionHandler.php',
        'Symfony\\Component\\HttpFoundation\\Session\\Storage\\Handler\\MemcachedSessionHandler' => __DIR__ . '/..' . '/symfony/http-foundation/Session/Storage/Handler/MemcachedSessionHandler.php',
        'Symfony\\Component\\HttpFoundation\\Session\\Storage\\Handler\\MigratingSessionHandler' => __DIR__ . '/..' . '/symfony/http-foundation/Session/Storage/Handler/MigratingSessionHandler.php',
        'Symfony\\Component\\HttpFoundation\\Session\\Storage\\Handler\\MongoDbSessionHandler' => __DIR__ . '/..' . '/symfony/http-foundation/Session/Storage/Handler/MongoDbSessionHandler.php',
        'Symfony\\Component\\HttpFoundation\\Session\\Storage\\Handler\\NativeFileSessionHandler' => __DIR__ . '/..' . '/symfony/http-foundation/Session/Storage/Handler/NativeFileSessionHandler.php',
        'Symfony\\Component\\HttpFoundation\\Session\\Storage\\Handler\\NullSessionHandler' => __DIR__ . '/..' . '/symfony/http-foundation/Session/Storage/Handler/NullSessionHandler.php',
        'Symfony\\Component\\HttpFoundation\\Session\\Storage\\Handler\\PdoSessionHandler' => __DIR__ . '/..' . '/symfony/http-foundation/Session/Storage/Handler/PdoSessionHandler.php',
        'Symfony\\Component\\HttpFoundation\\Session\\Storage\\Handler\\RedisSessionHandler' => __DIR__ . '/..' . '/symfony/http-foundation/Session/Storage/Handler/RedisSessionHandler.php',
        'Symfony\\Component\\HttpFoundation\\Session\\Storage\\Handler\\SessionHandlerFactory' => __DIR__ . '/..' . '/symfony/http-foundation/Session/Storage/Handler/SessionHandlerFactory.php',
        'Symfony\\Component\\HttpFoundation\\Session\\Storage\\Handler\\StrictSessionHandler' => __DIR__ . '/..' . '/symfony/http-foundation/Session/Storage/Handler/StrictSessionHandler.php',
        'Symfony\\Component\\HttpFoundation\\Session\\Storage\\MetadataBag' => __DIR__ . '/..' . '/symfony/http-foundation/Session/Storage/MetadataBag.php',
        'Symfony\\Component\\HttpFoundation\\Session\\Storage\\MockArraySessionStorage' => __DIR__ . '/..' . '/symfony/http-foundation/Session/Storage/MockArraySessionStorage.php',
        'Symfony\\Component\\HttpFoundation\\Session\\Storage\\MockFileSessionStorage' => __DIR__ . '/..' . '/symfony/http-foundation/Session/Storage/MockFileSessionStorage.php',
        'Symfony\\Component\\HttpFoundation\\Session\\Storage\\MockFileSessionStorageFactory' => __DIR__ . '/..' . '/symfony/http-foundation/Session/Storage/MockFileSessionStorageFactory.php',
        'Symfony\\Component\\HttpFoundation\\Session\\Storage\\NativeSessionStorage' => __DIR__ . '/..' . '/symfony/http-foundation/Session/Storage/NativeSessionStorage.php',
        'Symfony\\Component\\HttpFoundation\\Session\\Storage\\NativeSessionStorageFactory' => __DIR__ . '/..' . '/symfony/http-foundation/Session/Storage/NativeSessionStorageFactory.php',
        'Symfony\\Component\\HttpFoundation\\Session\\Storage\\PhpBridgeSessionStorage' => __DIR__ . '/..' . '/symfony/http-foundation/Session/Storage/PhpBridgeSessionStorage.php',
        'Symfony\\Component\\HttpFoundation\\Session\\Storage\\PhpBridgeSessionStorageFactory' => __DIR__ . '/..' . '/symfony/http-foundation/Session/Storage/PhpBridgeSessionStorageFactory.php',
        'Symfony\\Component\\HttpFoundation\\Session\\Storage\\Proxy\\AbstractProxy' => __DIR__ . '/..' . '/symfony/http-foundation/Session/Storage/Proxy/AbstractProxy.php',
        'Symfony\\Component\\HttpFoundation\\Session\\Storage\\Proxy\\SessionHandlerProxy' => __DIR__ . '/..' . '/symfony/http-foundation/Session/Storage/Proxy/SessionHandlerProxy.php',
        'Symfony\\Component\\HttpFoundation\\Session\\Storage\\SessionStorageFactoryInterface' => __DIR__ . '/..' . '/symfony/http-foundation/Session/Storage/SessionStorageFactoryInterface.php',
        'Symfony\\Component\\HttpFoundation\\Session\\Storage\\SessionStorageInterface' => __DIR__ . '/..' . '/symfony/http-foundation/Session/Storage/SessionStorageInterface.php',
        'Symfony\\Component\\HttpFoundation\\StreamedJsonResponse' => __DIR__ . '/..' . '/symfony/http-foundation/StreamedJsonResponse.php',
        'Symfony\\Component\\HttpFoundation\\StreamedResponse' => __DIR__ . '/..' . '/symfony/http-foundation/StreamedResponse.php',
        'Symfony\\Component\\HttpFoundation\\Test\\Constraint\\RequestAttributeValueSame' => __DIR__ . '/..' . '/symfony/http-foundation/Test/Constraint/RequestAttributeValueSame.php',
        'Symfony\\Component\\HttpFoundation\\Test\\Constraint\\ResponseCookieValueSame' => __DIR__ . '/..' . '/symfony/http-foundation/Test/Constraint/ResponseCookieValueSame.php',
        'Symfony\\Component\\HttpFoundation\\Test\\Constraint\\ResponseFormatSame' => __DIR__ . '/..' . '/symfony/http-foundation/Test/Constraint/ResponseFormatSame.php',
        'Symfony\\Component\\HttpFoundation\\Test\\Constraint\\ResponseHasCookie' => __DIR__ . '/..' . '/symfony/http-foundation/Test/Constraint/ResponseHasCookie.php',
        'Symfony\\Component\\HttpFoundation\\Test\\Constraint\\ResponseHasHeader' => __DIR__ . '/..' . '/symfony/http-foundation/Test/Constraint/ResponseHasHeader.php',
        'Symfony\\Component\\HttpFoundation\\Test\\Constraint\\ResponseHeaderLocationSame' => __DIR__ . '/..' . '/symfony/http-foundation/Test/Constraint/ResponseHeaderLocationSame.php',
        'Symfony\\Component\\HttpFoundation\\Test\\Constraint\\ResponseHeaderSame' => __DIR__ . '/..' . '/symfony/http-foundation/Test/Constraint/ResponseHeaderSame.php',
        'Symfony\\Component\\HttpFoundation\\Test\\Constraint\\ResponseIsRedirected' => __DIR__ . '/..' . '/symfony/http-foundation/Test/Constraint/ResponseIsRedirected.php',
        'Symfony\\Component\\HttpFoundation\\Test\\Constraint\\ResponseIsSuccessful' => __DIR__ . '/..' . '/symfony/http-foundation/Test/Constraint/ResponseIsSuccessful.php',
        'Symfony\\Component\\HttpFoundation\\Test\\Constraint\\ResponseIsUnprocessable' => __DIR__ . '/..' . '/symfony/http-foundation/Test/Constraint/ResponseIsUnprocessable.php',
        'Symfony\\Component\\HttpFoundation\\Test\\Constraint\\ResponseStatusCodeSame' => __DIR__ . '/..' . '/symfony/http-foundation/Test/Constraint/ResponseStatusCodeSame.php',
        'Symfony\\Component\\HttpFoundation\\UriSigner' => __DIR__ . '/..' . '/symfony/http-foundation/UriSigner.php',
        'Symfony\\Component\\HttpFoundation\\UrlHelper' => __DIR__ . '/..' . '/symfony/http-foundation/UrlHelper.php',
        'Symfony\\Component\\HttpKernel\\Attribute\\AsController' => __DIR__ . '/..' . '/symfony/http-kernel/Attribute/AsController.php',
        'Symfony\\Component\\HttpKernel\\Attribute\\AsTargetedValueResolver' => __DIR__ . '/..' . '/symfony/http-kernel/Attribute/AsTargetedValueResolver.php',
        'Symfony\\Component\\HttpKernel\\Attribute\\Cache' => __DIR__ . '/..' . '/symfony/http-kernel/Attribute/Cache.php',
        'Symfony\\Component\\HttpKernel\\Attribute\\MapDateTime' => __DIR__ . '/..' . '/symfony/http-kernel/Attribute/MapDateTime.php',
        'Symfony\\Component\\HttpKernel\\Attribute\\MapQueryParameter' => __DIR__ . '/..' . '/symfony/http-kernel/Attribute/MapQueryParameter.php',
        'Symfony\\Component\\HttpKernel\\Attribute\\MapQueryString' => __DIR__ . '/..' . '/symfony/http-kernel/Attribute/MapQueryString.php',
        'Symfony\\Component\\HttpKernel\\Attribute\\MapRequestPayload' => __DIR__ . '/..' . '/symfony/http-kernel/Attribute/MapRequestPayload.php',
        'Symfony\\Component\\HttpKernel\\Attribute\\ValueResolver' => __DIR__ . '/..' . '/symfony/http-kernel/Attribute/ValueResolver.php',
        'Symfony\\Component\\HttpKernel\\Attribute\\WithHttpStatus' => __DIR__ . '/..' . '/symfony/http-kernel/Attribute/WithHttpStatus.php',
        'Symfony\\Component\\HttpKernel\\Attribute\\WithLogLevel' => __DIR__ . '/..' . '/symfony/http-kernel/Attribute/WithLogLevel.php',
        'Symfony\\Component\\HttpKernel\\Bundle\\AbstractBundle' => __DIR__ . '/..' . '/symfony/http-kernel/Bundle/AbstractBundle.php',
        'Symfony\\Component\\HttpKernel\\Bundle\\Bundle' => __DIR__ . '/..' . '/symfony/http-kernel/Bundle/Bundle.php',
        'Symfony\\Component\\HttpKernel\\Bundle\\BundleExtension' => __DIR__ . '/..' . '/symfony/http-kernel/Bundle/BundleExtension.php',
        'Symfony\\Component\\HttpKernel\\Bundle\\BundleInterface' => __DIR__ . '/..' . '/symfony/http-kernel/Bundle/BundleInterface.php',
        'Symfony\\Component\\HttpKernel\\CacheClearer\\CacheClearerInterface' => __DIR__ . '/..' . '/symfony/http-kernel/CacheClearer/CacheClearerInterface.php',
        'Symfony\\Component\\HttpKernel\\CacheClearer\\ChainCacheClearer' => __DIR__ . '/..' . '/symfony/http-kernel/CacheClearer/ChainCacheClearer.php',
        'Symfony\\Component\\HttpKernel\\CacheClearer\\Psr6CacheClearer' => __DIR__ . '/..' . '/symfony/http-kernel/CacheClearer/Psr6CacheClearer.php',
        'Symfony\\Component\\HttpKernel\\CacheWarmer\\CacheWarmer' => __DIR__ . '/..' . '/symfony/http-kernel/CacheWarmer/CacheWarmer.php',
        'Symfony\\Component\\HttpKernel\\CacheWarmer\\CacheWarmerAggregate' => __DIR__ . '/..' . '/symfony/http-kernel/CacheWarmer/CacheWarmerAggregate.php',
        'Symfony\\Component\\HttpKernel\\CacheWarmer\\CacheWarmerInterface' => __DIR__ . '/..' . '/symfony/http-kernel/CacheWarmer/CacheWarmerInterface.php',
        'Symfony\\Component\\HttpKernel\\CacheWarmer\\WarmableInterface' => __DIR__ . '/..' . '/symfony/http-kernel/CacheWarmer/WarmableInterface.php',
        'Symfony\\Component\\HttpKernel\\Config\\FileLocator' => __DIR__ . '/..' . '/symfony/http-kernel/Config/FileLocator.php',
        'Symfony\\Component\\HttpKernel\\ControllerMetadata\\ArgumentMetadata' => __DIR__ . '/..' . '/symfony/http-kernel/ControllerMetadata/ArgumentMetadata.php',
        'Symfony\\Component\\HttpKernel\\ControllerMetadata\\ArgumentMetadataFactory' => __DIR__ . '/..' . '/symfony/http-kernel/ControllerMetadata/ArgumentMetadataFactory.php',
        'Symfony\\Component\\HttpKernel\\ControllerMetadata\\ArgumentMetadataFactoryInterface' => __DIR__ . '/..' . '/symfony/http-kernel/ControllerMetadata/ArgumentMetadataFactoryInterface.php',
        'Symfony\\Component\\HttpKernel\\Controller\\ArgumentResolver' => __DIR__ . '/..' . '/symfony/http-kernel/Controller/ArgumentResolver.php',
        'Symfony\\Component\\HttpKernel\\Controller\\ArgumentResolverInterface' => __DIR__ . '/..' . '/symfony/http-kernel/Controller/ArgumentResolverInterface.php',
        'Symfony\\Component\\HttpKernel\\Controller\\ArgumentResolver\\BackedEnumValueResolver' => __DIR__ . '/..' . '/symfony/http-kernel/Controller/ArgumentResolver/BackedEnumValueResolver.php',
        'Symfony\\Component\\HttpKernel\\Controller\\ArgumentResolver\\DateTimeValueResolver' => __DIR__ . '/..' . '/symfony/http-kernel/Controller/ArgumentResolver/DateTimeValueResolver.php',
        'Symfony\\Component\\HttpKernel\\Controller\\ArgumentResolver\\DefaultValueResolver' => __DIR__ . '/..' . '/symfony/http-kernel/Controller/ArgumentResolver/DefaultValueResolver.php',
        'Symfony\\Component\\HttpKernel\\Controller\\ArgumentResolver\\NotTaggedControllerValueResolver' => __DIR__ . '/..' . '/symfony/http-kernel/Controller/ArgumentResolver/NotTaggedControllerValueResolver.php',
        'Symfony\\Component\\HttpKernel\\Controller\\ArgumentResolver\\QueryParameterValueResolver' => __DIR__ . '/..' . '/symfony/http-kernel/Controller/ArgumentResolver/QueryParameterValueResolver.php',
        'Symfony\\Component\\HttpKernel\\Controller\\ArgumentResolver\\RequestAttributeValueResolver' => __DIR__ . '/..' . '/symfony/http-kernel/Controller/ArgumentResolver/RequestAttributeValueResolver.php',
        'Symfony\\Component\\HttpKernel\\Controller\\ArgumentResolver\\RequestPayloadValueResolver' => __DIR__ . '/..' . '/symfony/http-kernel/Controller/ArgumentResolver/RequestPayloadValueResolver.php',
        'Symfony\\Component\\HttpKernel\\Controller\\ArgumentResolver\\RequestValueResolver' => __DIR__ . '/..' . '/symfony/http-kernel/Controller/ArgumentResolver/RequestValueResolver.php',
        'Symfony\\Component\\HttpKernel\\Controller\\ArgumentResolver\\ServiceValueResolver' => __DIR__ . '/..' . '/symfony/http-kernel/Controller/ArgumentResolver/ServiceValueResolver.php',
        'Symfony\\Component\\HttpKernel\\Controller\\ArgumentResolver\\SessionValueResolver' => __DIR__ . '/..' . '/symfony/http-kernel/Controller/ArgumentResolver/SessionValueResolver.php',
        'Symfony\\Component\\HttpKernel\\Controller\\ArgumentResolver\\TraceableValueResolver' => __DIR__ . '/..' . '/symfony/http-kernel/Controller/ArgumentResolver/TraceableValueResolver.php',
        'Symfony\\Component\\HttpKernel\\Controller\\ArgumentResolver\\UidValueResolver' => __DIR__ . '/..' . '/symfony/http-kernel/Controller/ArgumentResolver/UidValueResolver.php',
        'Symfony\\Component\\HttpKernel\\Controller\\ArgumentResolver\\VariadicValueResolver' => __DIR__ . '/..' . '/symfony/http-kernel/Controller/ArgumentResolver/VariadicValueResolver.php',
        'Symfony\\Component\\HttpKernel\\Controller\\ArgumentValueResolverInterface' => __DIR__ . '/..' . '/symfony/http-kernel/Controller/ArgumentValueResolverInterface.php',
        'Symfony\\Component\\HttpKernel\\Controller\\ContainerControllerResolver' => __DIR__ . '/..' . '/symfony/http-kernel/Controller/ContainerControllerResolver.php',
        'Symfony\\Component\\HttpKernel\\Controller\\ControllerReference' => __DIR__ . '/..' . '/symfony/http-kernel/Controller/ControllerReference.php',
        'Symfony\\Component\\HttpKernel\\Controller\\ControllerResolver' => __DIR__ . '/..' . '/symfony/http-kernel/Controller/ControllerResolver.php',
        'Symfony\\Component\\HttpKernel\\Controller\\ControllerResolverInterface' => __DIR__ . '/..' . '/symfony/http-kernel/Controller/ControllerResolverInterface.php',
        'Symfony\\Component\\HttpKernel\\Controller\\ErrorController' => __DIR__ . '/..' . '/symfony/http-kernel/Controller/ErrorController.php',
        'Symfony\\Component\\HttpKernel\\Controller\\TraceableArgumentResolver' => __DIR__ . '/..' . '/symfony/http-kernel/Controller/TraceableArgumentResolver.php',
        'Symfony\\Component\\HttpKernel\\Controller\\TraceableControllerResolver' => __DIR__ . '/..' . '/symfony/http-kernel/Controller/TraceableControllerResolver.php',
        'Symfony\\Component\\HttpKernel\\Controller\\ValueResolverInterface' => __DIR__ . '/..' . '/symfony/http-kernel/Controller/ValueResolverInterface.php',
        'Symfony\\Component\\HttpKernel\\DataCollector\\AjaxDataCollector' => __DIR__ . '/..' . '/symfony/http-kernel/DataCollector/AjaxDataCollector.php',
        'Symfony\\Component\\HttpKernel\\DataCollector\\ConfigDataCollector' => __DIR__ . '/..' . '/symfony/http-kernel/DataCollector/ConfigDataCollector.php',
        'Symfony\\Component\\HttpKernel\\DataCollector\\DataCollector' => __DIR__ . '/..' . '/symfony/http-kernel/DataCollector/DataCollector.php',
        'Symfony\\Component\\HttpKernel\\DataCollector\\DataCollectorInterface' => __DIR__ . '/..' . '/symfony/http-kernel/DataCollector/DataCollectorInterface.php',
        'Symfony\\Component\\HttpKernel\\DataCollector\\DumpDataCollector' => __DIR__ . '/..' . '/symfony/http-kernel/DataCollector/DumpDataCollector.php',
        'Symfony\\Component\\HttpKernel\\DataCollector\\EventDataCollector' => __DIR__ . '/..' . '/symfony/http-kernel/DataCollector/EventDataCollector.php',
        'Symfony\\Component\\HttpKernel\\DataCollector\\ExceptionDataCollector' => __DIR__ . '/..' . '/symfony/http-kernel/DataCollector/ExceptionDataCollector.php',
        'Symfony\\Component\\HttpKernel\\DataCollector\\LateDataCollectorInterface' => __DIR__ . '/..' . '/symfony/http-kernel/DataCollector/LateDataCollectorInterface.php',
        'Symfony\\Component\\HttpKernel\\DataCollector\\LoggerDataCollector' => __DIR__ . '/..' . '/symfony/http-kernel/DataCollector/LoggerDataCollector.php',
        'Symfony\\Component\\HttpKernel\\DataCollector\\MemoryDataCollector' => __DIR__ . '/..' . '/symfony/http-kernel/DataCollector/MemoryDataCollector.php',
        'Symfony\\Component\\HttpKernel\\DataCollector\\RequestDataCollector' => __DIR__ . '/..' . '/symfony/http-kernel/DataCollector/RequestDataCollector.php',
        'Symfony\\Component\\HttpKernel\\DataCollector\\RouterDataCollector' => __DIR__ . '/..' . '/symfony/http-kernel/DataCollector/RouterDataCollector.php',
        'Symfony\\Component\\HttpKernel\\DataCollector\\TimeDataCollector' => __DIR__ . '/..' . '/symfony/http-kernel/DataCollector/TimeDataCollector.php',
        'Symfony\\Component\\HttpKernel\\Debug\\ErrorHandlerConfigurator' => __DIR__ . '/..' . '/symfony/http-kernel/Debug/ErrorHandlerConfigurator.php',
        'Symfony\\Component\\HttpKernel\\Debug\\FileLinkFormatter' => __DIR__ . '/..' . '/symfony/http-kernel/Debug/FileLinkFormatter.php',
        'Symfony\\Component\\HttpKernel\\Debug\\TraceableEventDispatcher' => __DIR__ . '/..' . '/symfony/http-kernel/Debug/TraceableEventDispatcher.php',
        'Symfony\\Component\\HttpKernel\\Debug\\VirtualRequestStack' => __DIR__ . '/..' . '/symfony/http-kernel/Debug/VirtualRequestStack.php',
        'Symfony\\Component\\HttpKernel\\DependencyInjection\\AddAnnotatedClassesToCachePass' => __DIR__ . '/..' . '/symfony/http-kernel/DependencyInjection/AddAnnotatedClassesToCachePass.php',
        'Symfony\\Component\\HttpKernel\\DependencyInjection\\ConfigurableExtension' => __DIR__ . '/..' . '/symfony/http-kernel/DependencyInjection/ConfigurableExtension.php',
        'Symfony\\Component\\HttpKernel\\DependencyInjection\\ControllerArgumentValueResolverPass' => __DIR__ . '/..' . '/symfony/http-kernel/DependencyInjection/ControllerArgumentValueResolverPass.php',
        'Symfony\\Component\\HttpKernel\\DependencyInjection\\Extension' => __DIR__ . '/..' . '/symfony/http-kernel/DependencyInjection/Extension.php',
        'Symfony\\Component\\HttpKernel\\DependencyInjection\\FragmentRendererPass' => __DIR__ . '/..' . '/symfony/http-kernel/DependencyInjection/FragmentRendererPass.php',
        'Symfony\\Component\\HttpKernel\\DependencyInjection\\LazyLoadingFragmentHandler' => __DIR__ . '/..' . '/symfony/http-kernel/DependencyInjection/LazyLoadingFragmentHandler.php',
        'Symfony\\Component\\HttpKernel\\DependencyInjection\\LoggerPass' => __DIR__ . '/..' . '/symfony/http-kernel/DependencyInjection/LoggerPass.php',
        'Symfony\\Component\\HttpKernel\\DependencyInjection\\MergeExtensionConfigurationPass' => __DIR__ . '/..' . '/symfony/http-kernel/DependencyInjection/MergeExtensionConfigurationPass.php',
        'Symfony\\Component\\HttpKernel\\DependencyInjection\\RegisterControllerArgumentLocatorsPass' => __DIR__ . '/..' . '/symfony/http-kernel/DependencyInjection/RegisterControllerArgumentLocatorsPass.php',
        'Symfony\\Component\\HttpKernel\\DependencyInjection\\RegisterLocaleAwareServicesPass' => __DIR__ . '/..' . '/symfony/http-kernel/DependencyInjection/RegisterLocaleAwareServicesPass.php',
        'Symfony\\Component\\HttpKernel\\DependencyInjection\\RemoveEmptyControllerArgumentLocatorsPass' => __DIR__ . '/..' . '/symfony/http-kernel/DependencyInjection/RemoveEmptyControllerArgumentLocatorsPass.php',
        'Symfony\\Component\\HttpKernel\\DependencyInjection\\ResettableServicePass' => __DIR__ . '/..' . '/symfony/http-kernel/DependencyInjection/ResettableServicePass.php',
        'Symfony\\Component\\HttpKernel\\DependencyInjection\\ServicesResetter' => __DIR__ . '/..' . '/symfony/http-kernel/DependencyInjection/ServicesResetter.php',
        'Symfony\\Component\\HttpKernel\\EventListener\\AbstractSessionListener' => __DIR__ . '/..' . '/symfony/http-kernel/EventListener/AbstractSessionListener.php',
        'Symfony\\Component\\HttpKernel\\EventListener\\AddRequestFormatsListener' => __DIR__ . '/..' . '/symfony/http-kernel/EventListener/AddRequestFormatsListener.php',
        'Symfony\\Component\\HttpKernel\\EventListener\\CacheAttributeListener' => __DIR__ . '/..' . '/symfony/http-kernel/EventListener/CacheAttributeListener.php',
        'Symfony\\Component\\HttpKernel\\EventListener\\DebugHandlersListener' => __DIR__ . '/..' . '/symfony/http-kernel/EventListener/DebugHandlersListener.php',
        'Symfony\\Component\\HttpKernel\\EventListener\\DisallowRobotsIndexingListener' => __DIR__ . '/..' . '/symfony/http-kernel/EventListener/DisallowRobotsIndexingListener.php',
        'Symfony\\Component\\HttpKernel\\EventListener\\DumpListener' => __DIR__ . '/..' . '/symfony/http-kernel/EventListener/DumpListener.php',
        'Symfony\\Component\\HttpKernel\\EventListener\\ErrorListener' => __DIR__ . '/..' . '/symfony/http-kernel/EventListener/ErrorListener.php',
        'Symfony\\Component\\HttpKernel\\EventListener\\FragmentListener' => __DIR__ . '/..' . '/symfony/http-kernel/EventListener/FragmentListener.php',
        'Symfony\\Component\\HttpKernel\\EventListener\\LocaleAwareListener' => __DIR__ . '/..' . '/symfony/http-kernel/EventListener/LocaleAwareListener.php',
        'Symfony\\Component\\HttpKernel\\EventListener\\LocaleListener' => __DIR__ . '/..' . '/symfony/http-kernel/EventListener/LocaleListener.php',
        'Symfony\\Component\\HttpKernel\\EventListener\\ProfilerListener' => __DIR__ . '/..' . '/symfony/http-kernel/EventListener/ProfilerListener.php',
        'Symfony\\Component\\HttpKernel\\EventListener\\ResponseListener' => __DIR__ . '/..' . '/symfony/http-kernel/EventListener/ResponseListener.php',
        'Symfony\\Component\\HttpKernel\\EventListener\\RouterListener' => __DIR__ . '/..' . '/symfony/http-kernel/EventListener/RouterListener.php',
        'Symfony\\Component\\HttpKernel\\EventListener\\SessionListener' => __DIR__ . '/..' . '/symfony/http-kernel/EventListener/SessionListener.php',
        'Symfony\\Component\\HttpKernel\\EventListener\\StreamedResponseListener' => __DIR__ . '/..' . '/symfony/http-kernel/EventListener/StreamedResponseListener.php',
        'Symfony\\Component\\HttpKernel\\EventListener\\SurrogateListener' => __DIR__ . '/..' . '/symfony/http-kernel/EventListener/SurrogateListener.php',
        'Symfony\\Component\\HttpKernel\\EventListener\\ValidateRequestListener' => __DIR__ . '/..' . '/symfony/http-kernel/EventListener/ValidateRequestListener.php',
        'Symfony\\Component\\HttpKernel\\Event\\ControllerArgumentsEvent' => __DIR__ . '/..' . '/symfony/http-kernel/Event/ControllerArgumentsEvent.php',
        'Symfony\\Component\\HttpKernel\\Event\\ControllerEvent' => __DIR__ . '/..' . '/symfony/http-kernel/Event/ControllerEvent.php',
        'Symfony\\Component\\HttpKernel\\Event\\ExceptionEvent' => __DIR__ . '/..' . '/symfony/http-kernel/Event/ExceptionEvent.php',
        'Symfony\\Component\\HttpKernel\\Event\\FinishRequestEvent' => __DIR__ . '/..' . '/symfony/http-kernel/Event/FinishRequestEvent.php',
        'Symfony\\Component\\HttpKernel\\Event\\KernelEvent' => __DIR__ . '/..' . '/symfony/http-kernel/Event/KernelEvent.php',
        'Symfony\\Component\\HttpKernel\\Event\\RequestEvent' => __DIR__ . '/..' . '/symfony/http-kernel/Event/RequestEvent.php',
        'Symfony\\Component\\HttpKernel\\Event\\ResponseEvent' => __DIR__ . '/..' . '/symfony/http-kernel/Event/ResponseEvent.php',
        'Symfony\\Component\\HttpKernel\\Event\\TerminateEvent' => __DIR__ . '/..' . '/symfony/http-kernel/Event/TerminateEvent.php',
        'Symfony\\Component\\HttpKernel\\Event\\ViewEvent' => __DIR__ . '/..' . '/symfony/http-kernel/Event/ViewEvent.php',
        'Symfony\\Component\\HttpKernel\\Exception\\AccessDeniedHttpException' => __DIR__ . '/..' . '/symfony/http-kernel/Exception/AccessDeniedHttpException.php',
        'Symfony\\Component\\HttpKernel\\Exception\\BadRequestHttpException' => __DIR__ . '/..' . '/symfony/http-kernel/Exception/BadRequestHttpException.php',
        'Symfony\\Component\\HttpKernel\\Exception\\ConflictHttpException' => __DIR__ . '/..' . '/symfony/http-kernel/Exception/ConflictHttpException.php',
        'Symfony\\Component\\HttpKernel\\Exception\\ControllerDoesNotReturnResponseException' => __DIR__ . '/..' . '/symfony/http-kernel/Exception/ControllerDoesNotReturnResponseException.php',
        'Symfony\\Component\\HttpKernel\\Exception\\GoneHttpException' => __DIR__ . '/..' . '/symfony/http-kernel/Exception/GoneHttpException.php',
        'Symfony\\Component\\HttpKernel\\Exception\\HttpException' => __DIR__ . '/..' . '/symfony/http-kernel/Exception/HttpException.php',
        'Symfony\\Component\\HttpKernel\\Exception\\HttpExceptionInterface' => __DIR__ . '/..' . '/symfony/http-kernel/Exception/HttpExceptionInterface.php',
        'Symfony\\Component\\HttpKernel\\Exception\\InvalidMetadataException' => __DIR__ . '/..' . '/symfony/http-kernel/Exception/InvalidMetadataException.php',
        'Symfony\\Component\\HttpKernel\\Exception\\LengthRequiredHttpException' => __DIR__ . '/..' . '/symfony/http-kernel/Exception/LengthRequiredHttpException.php',
        'Symfony\\Component\\HttpKernel\\Exception\\LockedHttpException' => __DIR__ . '/..' . '/symfony/http-kernel/Exception/LockedHttpException.php',
        'Symfony\\Component\\HttpKernel\\Exception\\MethodNotAllowedHttpException' => __DIR__ . '/..' . '/symfony/http-kernel/Exception/MethodNotAllowedHttpException.php',
        'Symfony\\Component\\HttpKernel\\Exception\\NotAcceptableHttpException' => __DIR__ . '/..' . '/symfony/http-kernel/Exception/NotAcceptableHttpException.php',
        'Symfony\\Component\\HttpKernel\\Exception\\NotFoundHttpException' => __DIR__ . '/..' . '/symfony/http-kernel/Exception/NotFoundHttpException.php',
        'Symfony\\Component\\HttpKernel\\Exception\\PreconditionFailedHttpException' => __DIR__ . '/..' . '/symfony/http-kernel/Exception/PreconditionFailedHttpException.php',
        'Symfony\\Component\\HttpKernel\\Exception\\PreconditionRequiredHttpException' => __DIR__ . '/..' . '/symfony/http-kernel/Exception/PreconditionRequiredHttpException.php',
        'Symfony\\Component\\HttpKernel\\Exception\\ResolverNotFoundException' => __DIR__ . '/..' . '/symfony/http-kernel/Exception/ResolverNotFoundException.php',
        'Symfony\\Component\\HttpKernel\\Exception\\ServiceUnavailableHttpException' => __DIR__ . '/..' . '/symfony/http-kernel/Exception/ServiceUnavailableHttpException.php',
        'Symfony\\Component\\HttpKernel\\Exception\\TooManyRequestsHttpException' => __DIR__ . '/..' . '/symfony/http-kernel/Exception/TooManyRequestsHttpException.php',
        'Symfony\\Component\\HttpKernel\\Exception\\UnauthorizedHttpException' => __DIR__ . '/..' . '/symfony/http-kernel/Exception/UnauthorizedHttpException.php',
        'Symfony\\Component\\HttpKernel\\Exception\\UnexpectedSessionUsageException' => __DIR__ . '/..' . '/symfony/http-kernel/Exception/UnexpectedSessionUsageException.php',
        'Symfony\\Component\\HttpKernel\\Exception\\UnprocessableEntityHttpException' => __DIR__ . '/..' . '/symfony/http-kernel/Exception/UnprocessableEntityHttpException.php',
        'Symfony\\Component\\HttpKernel\\Exception\\UnsupportedMediaTypeHttpException' => __DIR__ . '/..' . '/symfony/http-kernel/Exception/UnsupportedMediaTypeHttpException.php',
        'Symfony\\Component\\HttpKernel\\Fragment\\AbstractSurrogateFragmentRenderer' => __DIR__ . '/..' . '/symfony/http-kernel/Fragment/AbstractSurrogateFragmentRenderer.php',
        'Symfony\\Component\\HttpKernel\\Fragment\\EsiFragmentRenderer' => __DIR__ . '/..' . '/symfony/http-kernel/Fragment/EsiFragmentRenderer.php',
        'Symfony\\Component\\HttpKernel\\Fragment\\FragmentHandler' => __DIR__ . '/..' . '/symfony/http-kernel/Fragment/FragmentHandler.php',
        'Symfony\\Component\\HttpKernel\\Fragment\\FragmentRendererInterface' => __DIR__ . '/..' . '/symfony/http-kernel/Fragment/FragmentRendererInterface.php',
        'Symfony\\Component\\HttpKernel\\Fragment\\FragmentUriGenerator' => __DIR__ . '/..' . '/symfony/http-kernel/Fragment/FragmentUriGenerator.php',
        'Symfony\\Component\\HttpKernel\\Fragment\\FragmentUriGeneratorInterface' => __DIR__ . '/..' . '/symfony/http-kernel/Fragment/FragmentUriGeneratorInterface.php',
        'Symfony\\Component\\HttpKernel\\Fragment\\HIncludeFragmentRenderer' => __DIR__ . '/..' . '/symfony/http-kernel/Fragment/HIncludeFragmentRenderer.php',
        'Symfony\\Component\\HttpKernel\\Fragment\\InlineFragmentRenderer' => __DIR__ . '/..' . '/symfony/http-kernel/Fragment/InlineFragmentRenderer.php',
        'Symfony\\Component\\HttpKernel\\Fragment\\RoutableFragmentRenderer' => __DIR__ . '/..' . '/symfony/http-kernel/Fragment/RoutableFragmentRenderer.php',
        'Symfony\\Component\\HttpKernel\\Fragment\\SsiFragmentRenderer' => __DIR__ . '/..' . '/symfony/http-kernel/Fragment/SsiFragmentRenderer.php',
        'Symfony\\Component\\HttpKernel\\HttpCache\\AbstractSurrogate' => __DIR__ . '/..' . '/symfony/http-kernel/HttpCache/AbstractSurrogate.php',
        'Symfony\\Component\\HttpKernel\\HttpCache\\CacheWasLockedException' => __DIR__ . '/..' . '/symfony/http-kernel/HttpCache/CacheWasLockedException.php',
        'Symfony\\Component\\HttpKernel\\HttpCache\\Esi' => __DIR__ . '/..' . '/symfony/http-kernel/HttpCache/Esi.php',
        'Symfony\\Component\\HttpKernel\\HttpCache\\HttpCache' => __DIR__ . '/..' . '/symfony/http-kernel/HttpCache/HttpCache.php',
        'Symfony\\Component\\HttpKernel\\HttpCache\\ResponseCacheStrategy' => __DIR__ . '/..' . '/symfony/http-kernel/HttpCache/ResponseCacheStrategy.php',
        'Symfony\\Component\\HttpKernel\\HttpCache\\ResponseCacheStrategyInterface' => __DIR__ . '/..' . '/symfony/http-kernel/HttpCache/ResponseCacheStrategyInterface.php',
        'Symfony\\Component\\HttpKernel\\HttpCache\\Ssi' => __DIR__ . '/..' . '/symfony/http-kernel/HttpCache/Ssi.php',
        'Symfony\\Component\\HttpKernel\\HttpCache\\Store' => __DIR__ . '/..' . '/symfony/http-kernel/HttpCache/Store.php',
        'Symfony\\Component\\HttpKernel\\HttpCache\\StoreInterface' => __DIR__ . '/..' . '/symfony/http-kernel/HttpCache/StoreInterface.php',
        'Symfony\\Component\\HttpKernel\\HttpCache\\SubRequestHandler' => __DIR__ . '/..' . '/symfony/http-kernel/HttpCache/SubRequestHandler.php',
        'Symfony\\Component\\HttpKernel\\HttpCache\\SurrogateInterface' => __DIR__ . '/..' . '/symfony/http-kernel/HttpCache/SurrogateInterface.php',
        'Symfony\\Component\\HttpKernel\\HttpClientKernel' => __DIR__ . '/..' . '/symfony/http-kernel/HttpClientKernel.php',
        'Symfony\\Component\\HttpKernel\\HttpKernel' => __DIR__ . '/..' . '/symfony/http-kernel/HttpKernel.php',
        'Symfony\\Component\\HttpKernel\\HttpKernelBrowser' => __DIR__ . '/..' . '/symfony/http-kernel/HttpKernelBrowser.php',
        'Symfony\\Component\\HttpKernel\\HttpKernelInterface' => __DIR__ . '/..' . '/symfony/http-kernel/HttpKernelInterface.php',
        'Symfony\\Component\\HttpKernel\\Kernel' => __DIR__ . '/..' . '/symfony/http-kernel/Kernel.php',
        'Symfony\\Component\\HttpKernel\\KernelEvents' => __DIR__ . '/..' . '/symfony/http-kernel/KernelEvents.php',
        'Symfony\\Component\\HttpKernel\\KernelInterface' => __DIR__ . '/..' . '/symfony/http-kernel/KernelInterface.php',
        'Symfony\\Component\\HttpKernel\\Log\\DebugLoggerConfigurator' => __DIR__ . '/..' . '/symfony/http-kernel/Log/DebugLoggerConfigurator.php',
        'Symfony\\Component\\HttpKernel\\Log\\DebugLoggerInterface' => __DIR__ . '/..' . '/symfony/http-kernel/Log/DebugLoggerInterface.php',
        'Symfony\\Component\\HttpKernel\\Log\\Logger' => __DIR__ . '/..' . '/symfony/http-kernel/Log/Logger.php',
        'Symfony\\Component\\HttpKernel\\Profiler\\FileProfilerStorage' => __DIR__ . '/..' . '/symfony/http-kernel/Profiler/FileProfilerStorage.php',
        'Symfony\\Component\\HttpKernel\\Profiler\\Profile' => __DIR__ . '/..' . '/symfony/http-kernel/Profiler/Profile.php',
        'Symfony\\Component\\HttpKernel\\Profiler\\Profiler' => __DIR__ . '/..' . '/symfony/http-kernel/Profiler/Profiler.php',
        'Symfony\\Component\\HttpKernel\\Profiler\\ProfilerStorageInterface' => __DIR__ . '/..' . '/symfony/http-kernel/Profiler/ProfilerStorageInterface.php',
        'Symfony\\Component\\HttpKernel\\RebootableInterface' => __DIR__ . '/..' . '/symfony/http-kernel/RebootableInterface.php',
        'Symfony\\Component\\HttpKernel\\TerminableInterface' => __DIR__ . '/..' . '/symfony/http-kernel/TerminableInterface.php',
        'Symfony\\Component\\HttpKernel\\UriSigner' => __DIR__ . '/..' . '/symfony/http-kernel/UriSigner.php',
        'Symfony\\Component\\Intl\\Countries' => __DIR__ . '/..' . '/symfony/intl/Countries.php',
        'Symfony\\Component\\Intl\\Currencies' => __DIR__ . '/..' . '/symfony/intl/Currencies.php',
        'Symfony\\Component\\Intl\\Data\\Bundle\\Compiler\\BundleCompilerInterface' => __DIR__ . '/..' . '/symfony/intl/Data/Bundle/Compiler/BundleCompilerInterface.php',
        'Symfony\\Component\\Intl\\Data\\Bundle\\Compiler\\GenrbCompiler' => __DIR__ . '/..' . '/symfony/intl/Data/Bundle/Compiler/GenrbCompiler.php',
        'Symfony\\Component\\Intl\\Data\\Bundle\\Reader\\BufferedBundleReader' => __DIR__ . '/..' . '/symfony/intl/Data/Bundle/Reader/BufferedBundleReader.php',
        'Symfony\\Component\\Intl\\Data\\Bundle\\Reader\\BundleEntryReader' => __DIR__ . '/..' . '/symfony/intl/Data/Bundle/Reader/BundleEntryReader.php',
        'Symfony\\Component\\Intl\\Data\\Bundle\\Reader\\BundleEntryReaderInterface' => __DIR__ . '/..' . '/symfony/intl/Data/Bundle/Reader/BundleEntryReaderInterface.php',
        'Symfony\\Component\\Intl\\Data\\Bundle\\Reader\\BundleReaderInterface' => __DIR__ . '/..' . '/symfony/intl/Data/Bundle/Reader/BundleReaderInterface.php',
        'Symfony\\Component\\Intl\\Data\\Bundle\\Reader\\IntlBundleReader' => __DIR__ . '/..' . '/symfony/intl/Data/Bundle/Reader/IntlBundleReader.php',
        'Symfony\\Component\\Intl\\Data\\Bundle\\Reader\\JsonBundleReader' => __DIR__ . '/..' . '/symfony/intl/Data/Bundle/Reader/JsonBundleReader.php',
        'Symfony\\Component\\Intl\\Data\\Bundle\\Reader\\PhpBundleReader' => __DIR__ . '/..' . '/symfony/intl/Data/Bundle/Reader/PhpBundleReader.php',
        'Symfony\\Component\\Intl\\Data\\Bundle\\Writer\\BundleWriterInterface' => __DIR__ . '/..' . '/symfony/intl/Data/Bundle/Writer/BundleWriterInterface.php',
        'Symfony\\Component\\Intl\\Data\\Bundle\\Writer\\JsonBundleWriter' => __DIR__ . '/..' . '/symfony/intl/Data/Bundle/Writer/JsonBundleWriter.php',
        'Symfony\\Component\\Intl\\Data\\Bundle\\Writer\\PhpBundleWriter' => __DIR__ . '/..' . '/symfony/intl/Data/Bundle/Writer/PhpBundleWriter.php',
        'Symfony\\Component\\Intl\\Data\\Bundle\\Writer\\TextBundleWriter' => __DIR__ . '/..' . '/symfony/intl/Data/Bundle/Writer/TextBundleWriter.php',
        'Symfony\\Component\\Intl\\Data\\Generator\\AbstractDataGenerator' => __DIR__ . '/..' . '/symfony/intl/Data/Generator/AbstractDataGenerator.php',
        'Symfony\\Component\\Intl\\Data\\Generator\\CurrencyDataGenerator' => __DIR__ . '/..' . '/symfony/intl/Data/Generator/CurrencyDataGenerator.php',
        'Symfony\\Component\\Intl\\Data\\Generator\\FallbackTrait' => __DIR__ . '/..' . '/symfony/intl/Data/Generator/FallbackTrait.php',
        'Symfony\\Component\\Intl\\Data\\Generator\\GeneratorConfig' => __DIR__ . '/..' . '/symfony/intl/Data/Generator/GeneratorConfig.php',
        'Symfony\\Component\\Intl\\Data\\Generator\\LanguageDataGenerator' => __DIR__ . '/..' . '/symfony/intl/Data/Generator/LanguageDataGenerator.php',
        'Symfony\\Component\\Intl\\Data\\Generator\\LocaleDataGenerator' => __DIR__ . '/..' . '/symfony/intl/Data/Generator/LocaleDataGenerator.php',
        'Symfony\\Component\\Intl\\Data\\Generator\\RegionDataGenerator' => __DIR__ . '/..' . '/symfony/intl/Data/Generator/RegionDataGenerator.php',
        'Symfony\\Component\\Intl\\Data\\Generator\\ScriptDataGenerator' => __DIR__ . '/..' . '/symfony/intl/Data/Generator/ScriptDataGenerator.php',
        'Symfony\\Component\\Intl\\Data\\Generator\\TimezoneDataGenerator' => __DIR__ . '/..' . '/symfony/intl/Data/Generator/TimezoneDataGenerator.php',
        'Symfony\\Component\\Intl\\Data\\Util\\ArrayAccessibleResourceBundle' => __DIR__ . '/..' . '/symfony/intl/Data/Util/ArrayAccessibleResourceBundle.php',
        'Symfony\\Component\\Intl\\Data\\Util\\LocaleScanner' => __DIR__ . '/..' . '/symfony/intl/Data/Util/LocaleScanner.php',
        'Symfony\\Component\\Intl\\Data\\Util\\RecursiveArrayAccess' => __DIR__ . '/..' . '/symfony/intl/Data/Util/RecursiveArrayAccess.php',
        'Symfony\\Component\\Intl\\Data\\Util\\RingBuffer' => __DIR__ . '/..' . '/symfony/intl/Data/Util/RingBuffer.php',
        'Symfony\\Component\\Intl\\Exception\\BadMethodCallException' => __DIR__ . '/..' . '/symfony/intl/Exception/BadMethodCallException.php',
        'Symfony\\Component\\Intl\\Exception\\ExceptionInterface' => __DIR__ . '/..' . '/symfony/intl/Exception/ExceptionInterface.php',
        'Symfony\\Component\\Intl\\Exception\\InvalidArgumentException' => __DIR__ . '/..' . '/symfony/intl/Exception/InvalidArgumentException.php',
        'Symfony\\Component\\Intl\\Exception\\MissingResourceException' => __DIR__ . '/..' . '/symfony/intl/Exception/MissingResourceException.php',
        'Symfony\\Component\\Intl\\Exception\\OutOfBoundsException' => __DIR__ . '/..' . '/symfony/intl/Exception/OutOfBoundsException.php',
        'Symfony\\Component\\Intl\\Exception\\ResourceBundleNotFoundException' => __DIR__ . '/..' . '/symfony/intl/Exception/ResourceBundleNotFoundException.php',
        'Symfony\\Component\\Intl\\Exception\\RuntimeException' => __DIR__ . '/..' . '/symfony/intl/Exception/RuntimeException.php',
        'Symfony\\Component\\Intl\\Exception\\UnexpectedTypeException' => __DIR__ . '/..' . '/symfony/intl/Exception/UnexpectedTypeException.php',
        'Symfony\\Component\\Intl\\Intl' => __DIR__ . '/..' . '/symfony/intl/Intl.php',
        'Symfony\\Component\\Intl\\Languages' => __DIR__ . '/..' . '/symfony/intl/Languages.php',
        'Symfony\\Component\\Intl\\Locale' => __DIR__ . '/..' . '/symfony/intl/Locale.php',
        'Symfony\\Component\\Intl\\Locales' => __DIR__ . '/..' . '/symfony/intl/Locales.php',
        'Symfony\\Component\\Intl\\ResourceBundle' => __DIR__ . '/..' . '/symfony/intl/ResourceBundle.php',
        'Symfony\\Component\\Intl\\Scripts' => __DIR__ . '/..' . '/symfony/intl/Scripts.php',
        'Symfony\\Component\\Intl\\Timezones' => __DIR__ . '/..' . '/symfony/intl/Timezones.php',
        'Symfony\\Component\\Intl\\Transliterator\\EmojiTransliterator' => __DIR__ . '/..' . '/symfony/intl/Transliterator/EmojiTransliterator.php',
        'Symfony\\Component\\Intl\\Util\\GitRepository' => __DIR__ . '/..' . '/symfony/intl/Util/GitRepository.php',
        'Symfony\\Component\\Intl\\Util\\GzipStreamWrapper' => __DIR__ . '/..' . '/symfony/intl/Util/GzipStreamWrapper.php',
        'Symfony\\Component\\Intl\\Util\\IcuVersion' => __DIR__ . '/..' . '/symfony/intl/Util/IcuVersion.php',
        'Symfony\\Component\\Intl\\Util\\IntlTestHelper' => __DIR__ . '/..' . '/symfony/intl/Util/IntlTestHelper.php',
        'Symfony\\Component\\Intl\\Util\\Version' => __DIR__ . '/..' . '/symfony/intl/Util/Version.php',
        'Symfony\\Component\\PasswordHasher\\Command\\UserPasswordHashCommand' => __DIR__ . '/..' . '/symfony/password-hasher/Command/UserPasswordHashCommand.php',
        'Symfony\\Component\\PasswordHasher\\Exception\\ExceptionInterface' => __DIR__ . '/..' . '/symfony/password-hasher/Exception/ExceptionInterface.php',
        'Symfony\\Component\\PasswordHasher\\Exception\\InvalidPasswordException' => __DIR__ . '/..' . '/symfony/password-hasher/Exception/InvalidPasswordException.php',
        'Symfony\\Component\\PasswordHasher\\Exception\\LogicException' => __DIR__ . '/..' . '/symfony/password-hasher/Exception/LogicException.php',
        'Symfony\\Component\\PasswordHasher\\Hasher\\CheckPasswordLengthTrait' => __DIR__ . '/..' . '/symfony/password-hasher/Hasher/CheckPasswordLengthTrait.php',
        'Symfony\\Component\\PasswordHasher\\Hasher\\MessageDigestPasswordHasher' => __DIR__ . '/..' . '/symfony/password-hasher/Hasher/MessageDigestPasswordHasher.php',
        'Symfony\\Component\\PasswordHasher\\Hasher\\MigratingPasswordHasher' => __DIR__ . '/..' . '/symfony/password-hasher/Hasher/MigratingPasswordHasher.php',
        'Symfony\\Component\\PasswordHasher\\Hasher\\NativePasswordHasher' => __DIR__ . '/..' . '/symfony/password-hasher/Hasher/NativePasswordHasher.php',
        'Symfony\\Component\\PasswordHasher\\Hasher\\PasswordHasherAwareInterface' => __DIR__ . '/..' . '/symfony/password-hasher/Hasher/PasswordHasherAwareInterface.php',
        'Symfony\\Component\\PasswordHasher\\Hasher\\PasswordHasherFactory' => __DIR__ . '/..' . '/symfony/password-hasher/Hasher/PasswordHasherFactory.php',
        'Symfony\\Component\\PasswordHasher\\Hasher\\PasswordHasherFactoryInterface' => __DIR__ . '/..' . '/symfony/password-hasher/Hasher/PasswordHasherFactoryInterface.php',
        'Symfony\\Component\\PasswordHasher\\Hasher\\Pbkdf2PasswordHasher' => __DIR__ . '/..' . '/symfony/password-hasher/Hasher/Pbkdf2PasswordHasher.php',
        'Symfony\\Component\\PasswordHasher\\Hasher\\PlaintextPasswordHasher' => __DIR__ . '/..' . '/symfony/password-hasher/Hasher/PlaintextPasswordHasher.php',
        'Symfony\\Component\\PasswordHasher\\Hasher\\SodiumPasswordHasher' => __DIR__ . '/..' . '/symfony/password-hasher/Hasher/SodiumPasswordHasher.php',
        'Symfony\\Component\\PasswordHasher\\Hasher\\UserPasswordHasher' => __DIR__ . '/..' . '/symfony/password-hasher/Hasher/UserPasswordHasher.php',
        'Symfony\\Component\\PasswordHasher\\Hasher\\UserPasswordHasherInterface' => __DIR__ . '/..' . '/symfony/password-hasher/Hasher/UserPasswordHasherInterface.php',
        'Symfony\\Component\\PasswordHasher\\LegacyPasswordHasherInterface' => __DIR__ . '/..' . '/symfony/password-hasher/LegacyPasswordHasherInterface.php',
        'Symfony\\Component\\PasswordHasher\\PasswordHasherInterface' => __DIR__ . '/..' . '/symfony/password-hasher/PasswordHasherInterface.php',
        'Symfony\\Component\\Routing\\Alias' => __DIR__ . '/..' . '/symfony/routing/Alias.php',
        'Symfony\\Component\\Routing\\Annotation\\Route' => __DIR__ . '/..' . '/symfony/routing/Annotation/Route.php',
        'Symfony\\Component\\Routing\\Attribute\\Route' => __DIR__ . '/..' . '/symfony/routing/Attribute/Route.php',
        'Symfony\\Component\\Routing\\CompiledRoute' => __DIR__ . '/..' . '/symfony/routing/CompiledRoute.php',
        'Symfony\\Component\\Routing\\DependencyInjection\\AddExpressionLanguageProvidersPass' => __DIR__ . '/..' . '/symfony/routing/DependencyInjection/AddExpressionLanguageProvidersPass.php',
        'Symfony\\Component\\Routing\\DependencyInjection\\RoutingResolverPass' => __DIR__ . '/..' . '/symfony/routing/DependencyInjection/RoutingResolverPass.php',
        'Symfony\\Component\\Routing\\Exception\\ExceptionInterface' => __DIR__ . '/..' . '/symfony/routing/Exception/ExceptionInterface.php',
        'Symfony\\Component\\Routing\\Exception\\InvalidArgumentException' => __DIR__ . '/..' . '/symfony/routing/Exception/InvalidArgumentException.php',
        'Symfony\\Component\\Routing\\Exception\\InvalidParameterException' => __DIR__ . '/..' . '/symfony/routing/Exception/InvalidParameterException.php',
        'Symfony\\Component\\Routing\\Exception\\MethodNotAllowedException' => __DIR__ . '/..' . '/symfony/routing/Exception/MethodNotAllowedException.php',
        'Symfony\\Component\\Routing\\Exception\\MissingMandatoryParametersException' => __DIR__ . '/..' . '/symfony/routing/Exception/MissingMandatoryParametersException.php',
        'Symfony\\Component\\Routing\\Exception\\NoConfigurationException' => __DIR__ . '/..' . '/symfony/routing/Exception/NoConfigurationException.php',
        'Symfony\\Component\\Routing\\Exception\\ResourceNotFoundException' => __DIR__ . '/..' . '/symfony/routing/Exception/ResourceNotFoundException.php',
        'Symfony\\Component\\Routing\\Exception\\RouteCircularReferenceException' => __DIR__ . '/..' . '/symfony/routing/Exception/RouteCircularReferenceException.php',
        'Symfony\\Component\\Routing\\Exception\\RouteNotFoundException' => __DIR__ . '/..' . '/symfony/routing/Exception/RouteNotFoundException.php',
        'Symfony\\Component\\Routing\\Exception\\RuntimeException' => __DIR__ . '/..' . '/symfony/routing/Exception/RuntimeException.php',
        'Symfony\\Component\\Routing\\Generator\\CompiledUrlGenerator' => __DIR__ . '/..' . '/symfony/routing/Generator/CompiledUrlGenerator.php',
        'Symfony\\Component\\Routing\\Generator\\ConfigurableRequirementsInterface' => __DIR__ . '/..' . '/symfony/routing/Generator/ConfigurableRequirementsInterface.php',
        'Symfony\\Component\\Routing\\Generator\\Dumper\\CompiledUrlGeneratorDumper' => __DIR__ . '/..' . '/symfony/routing/Generator/Dumper/CompiledUrlGeneratorDumper.php',
        'Symfony\\Component\\Routing\\Generator\\Dumper\\GeneratorDumper' => __DIR__ . '/..' . '/symfony/routing/Generator/Dumper/GeneratorDumper.php',
        'Symfony\\Component\\Routing\\Generator\\Dumper\\GeneratorDumperInterface' => __DIR__ . '/..' . '/symfony/routing/Generator/Dumper/GeneratorDumperInterface.php',
        'Symfony\\Component\\Routing\\Generator\\UrlGenerator' => __DIR__ . '/..' . '/symfony/routing/Generator/UrlGenerator.php',
        'Symfony\\Component\\Routing\\Generator\\UrlGeneratorInterface' => __DIR__ . '/..' . '/symfony/routing/Generator/UrlGeneratorInterface.php',
        'Symfony\\Component\\Routing\\Loader\\AnnotationClassLoader' => __DIR__ . '/..' . '/symfony/routing/Loader/AnnotationClassLoader.php',
        'Symfony\\Component\\Routing\\Loader\\AnnotationDirectoryLoader' => __DIR__ . '/..' . '/symfony/routing/Loader/AnnotationDirectoryLoader.php',
        'Symfony\\Component\\Routing\\Loader\\AnnotationFileLoader' => __DIR__ . '/..' . '/symfony/routing/Loader/AnnotationFileLoader.php',
        'Symfony\\Component\\Routing\\Loader\\AttributeClassLoader' => __DIR__ . '/..' . '/symfony/routing/Loader/AttributeClassLoader.php',
        'Symfony\\Component\\Routing\\Loader\\AttributeDirectoryLoader' => __DIR__ . '/..' . '/symfony/routing/Loader/AttributeDirectoryLoader.php',
        'Symfony\\Component\\Routing\\Loader\\AttributeFileLoader' => __DIR__ . '/..' . '/symfony/routing/Loader/AttributeFileLoader.php',
        'Symfony\\Component\\Routing\\Loader\\ClosureLoader' => __DIR__ . '/..' . '/symfony/routing/Loader/ClosureLoader.php',
        'Symfony\\Component\\Routing\\Loader\\Configurator\\AliasConfigurator' => __DIR__ . '/..' . '/symfony/routing/Loader/Configurator/AliasConfigurator.php',
        'Symfony\\Component\\Routing\\Loader\\Configurator\\CollectionConfigurator' => __DIR__ . '/..' . '/symfony/routing/Loader/Configurator/CollectionConfigurator.php',
        'Symfony\\Component\\Routing\\Loader\\Configurator\\ImportConfigurator' => __DIR__ . '/..' . '/symfony/routing/Loader/Configurator/ImportConfigurator.php',
        'Symfony\\Component\\Routing\\Loader\\Configurator\\RouteConfigurator' => __DIR__ . '/..' . '/symfony/routing/Loader/Configurator/RouteConfigurator.php',
        'Symfony\\Component\\Routing\\Loader\\Configurator\\RoutingConfigurator' => __DIR__ . '/..' . '/symfony/routing/Loader/Configurator/RoutingConfigurator.php',
        'Symfony\\Component\\Routing\\Loader\\Configurator\\Traits\\AddTrait' => __DIR__ . '/..' . '/symfony/routing/Loader/Configurator/Traits/AddTrait.php',
        'Symfony\\Component\\Routing\\Loader\\Configurator\\Traits\\HostTrait' => __DIR__ . '/..' . '/symfony/routing/Loader/Configurator/Traits/HostTrait.php',
        'Symfony\\Component\\Routing\\Loader\\Configurator\\Traits\\LocalizedRouteTrait' => __DIR__ . '/..' . '/symfony/routing/Loader/Configurator/Traits/LocalizedRouteTrait.php',
        'Symfony\\Component\\Routing\\Loader\\Configurator\\Traits\\PrefixTrait' => __DIR__ . '/..' . '/symfony/routing/Loader/Configurator/Traits/PrefixTrait.php',
        'Symfony\\Component\\Routing\\Loader\\Configurator\\Traits\\RouteTrait' => __DIR__ . '/..' . '/symfony/routing/Loader/Configurator/Traits/RouteTrait.php',
        'Symfony\\Component\\Routing\\Loader\\ContainerLoader' => __DIR__ . '/..' . '/symfony/routing/Loader/ContainerLoader.php',
        'Symfony\\Component\\Routing\\Loader\\DirectoryLoader' => __DIR__ . '/..' . '/symfony/routing/Loader/DirectoryLoader.php',
        'Symfony\\Component\\Routing\\Loader\\GlobFileLoader' => __DIR__ . '/..' . '/symfony/routing/Loader/GlobFileLoader.php',
        'Symfony\\Component\\Routing\\Loader\\ObjectLoader' => __DIR__ . '/..' . '/symfony/routing/Loader/ObjectLoader.php',
        'Symfony\\Component\\Routing\\Loader\\PhpFileLoader' => __DIR__ . '/..' . '/symfony/routing/Loader/PhpFileLoader.php',
        'Symfony\\Component\\Routing\\Loader\\Psr4DirectoryLoader' => __DIR__ . '/..' . '/symfony/routing/Loader/Psr4DirectoryLoader.php',
        'Symfony\\Component\\Routing\\Loader\\XmlFileLoader' => __DIR__ . '/..' . '/symfony/routing/Loader/XmlFileLoader.php',
        'Symfony\\Component\\Routing\\Loader\\YamlFileLoader' => __DIR__ . '/..' . '/symfony/routing/Loader/YamlFileLoader.php',
        'Symfony\\Component\\Routing\\Matcher\\CompiledUrlMatcher' => __DIR__ . '/..' . '/symfony/routing/Matcher/CompiledUrlMatcher.php',
        'Symfony\\Component\\Routing\\Matcher\\Dumper\\CompiledUrlMatcherDumper' => __DIR__ . '/..' . '/symfony/routing/Matcher/Dumper/CompiledUrlMatcherDumper.php',
        'Symfony\\Component\\Routing\\Matcher\\Dumper\\CompiledUrlMatcherTrait' => __DIR__ . '/..' . '/symfony/routing/Matcher/Dumper/CompiledUrlMatcherTrait.php',
        'Symfony\\Component\\Routing\\Matcher\\Dumper\\MatcherDumper' => __DIR__ . '/..' . '/symfony/routing/Matcher/Dumper/MatcherDumper.php',
        'Symfony\\Component\\Routing\\Matcher\\Dumper\\MatcherDumperInterface' => __DIR__ . '/..' . '/symfony/routing/Matcher/Dumper/MatcherDumperInterface.php',
        'Symfony\\Component\\Routing\\Matcher\\Dumper\\StaticPrefixCollection' => __DIR__ . '/..' . '/symfony/routing/Matcher/Dumper/StaticPrefixCollection.php',
        'Symfony\\Component\\Routing\\Matcher\\ExpressionLanguageProvider' => __DIR__ . '/..' . '/symfony/routing/Matcher/ExpressionLanguageProvider.php',
        'Symfony\\Component\\Routing\\Matcher\\RedirectableUrlMatcher' => __DIR__ . '/..' . '/symfony/routing/Matcher/RedirectableUrlMatcher.php',
        'Symfony\\Component\\Routing\\Matcher\\RedirectableUrlMatcherInterface' => __DIR__ . '/..' . '/symfony/routing/Matcher/RedirectableUrlMatcherInterface.php',
        'Symfony\\Component\\Routing\\Matcher\\RequestMatcherInterface' => __DIR__ . '/..' . '/symfony/routing/Matcher/RequestMatcherInterface.php',
        'Symfony\\Component\\Routing\\Matcher\\TraceableUrlMatcher' => __DIR__ . '/..' . '/symfony/routing/Matcher/TraceableUrlMatcher.php',
        'Symfony\\Component\\Routing\\Matcher\\UrlMatcher' => __DIR__ . '/..' . '/symfony/routing/Matcher/UrlMatcher.php',
        'Symfony\\Component\\Routing\\Matcher\\UrlMatcherInterface' => __DIR__ . '/..' . '/symfony/routing/Matcher/UrlMatcherInterface.php',
        'Symfony\\Component\\Routing\\RequestContext' => __DIR__ . '/..' . '/symfony/routing/RequestContext.php',
        'Symfony\\Component\\Routing\\RequestContextAwareInterface' => __DIR__ . '/..' . '/symfony/routing/RequestContextAwareInterface.php',
        'Symfony\\Component\\Routing\\Requirement\\EnumRequirement' => __DIR__ . '/..' . '/symfony/routing/Requirement/EnumRequirement.php',
        'Symfony\\Component\\Routing\\Requirement\\Requirement' => __DIR__ . '/..' . '/symfony/routing/Requirement/Requirement.php',
        'Symfony\\Component\\Routing\\Route' => __DIR__ . '/..' . '/symfony/routing/Route.php',
        'Symfony\\Component\\Routing\\RouteCollection' => __DIR__ . '/..' . '/symfony/routing/RouteCollection.php',
        'Symfony\\Component\\Routing\\RouteCompiler' => __DIR__ . '/..' . '/symfony/routing/RouteCompiler.php',
        'Symfony\\Component\\Routing\\RouteCompilerInterface' => __DIR__ . '/..' . '/symfony/routing/RouteCompilerInterface.php',
        'Symfony\\Component\\Routing\\Router' => __DIR__ . '/..' . '/symfony/routing/Router.php',
        'Symfony\\Component\\Routing\\RouterInterface' => __DIR__ . '/..' . '/symfony/routing/RouterInterface.php',
        'Symfony\\Component\\String\\AbstractString' => __DIR__ . '/..' . '/symfony/string/AbstractString.php',
        'Symfony\\Component\\String\\AbstractUnicodeString' => __DIR__ . '/..' . '/symfony/string/AbstractUnicodeString.php',
        'Symfony\\Component\\String\\ByteString' => __DIR__ . '/..' . '/symfony/string/ByteString.php',
        'Symfony\\Component\\String\\CodePointString' => __DIR__ . '/..' . '/symfony/string/CodePointString.php',
        'Symfony\\Component\\String\\Exception\\ExceptionInterface' => __DIR__ . '/..' . '/symfony/string/Exception/ExceptionInterface.php',
        'Symfony\\Component\\String\\Exception\\InvalidArgumentException' => __DIR__ . '/..' . '/symfony/string/Exception/InvalidArgumentException.php',
        'Symfony\\Component\\String\\Exception\\RuntimeException' => __DIR__ . '/..' . '/symfony/string/Exception/RuntimeException.php',
        'Symfony\\Component\\String\\Inflector\\EnglishInflector' => __DIR__ . '/..' . '/symfony/string/Inflector/EnglishInflector.php',
        'Symfony\\Component\\String\\Inflector\\FrenchInflector' => __DIR__ . '/..' . '/symfony/string/Inflector/FrenchInflector.php',
        'Symfony\\Component\\String\\Inflector\\InflectorInterface' => __DIR__ . '/..' . '/symfony/string/Inflector/InflectorInterface.php',
        'Symfony\\Component\\String\\LazyString' => __DIR__ . '/..' . '/symfony/string/LazyString.php',
        'Symfony\\Component\\String\\Slugger\\AsciiSlugger' => __DIR__ . '/..' . '/symfony/string/Slugger/AsciiSlugger.php',
        'Symfony\\Component\\String\\Slugger\\SluggerInterface' => __DIR__ . '/..' . '/symfony/string/Slugger/SluggerInterface.php',
        'Symfony\\Component\\String\\UnicodeString' => __DIR__ . '/..' . '/symfony/string/UnicodeString.php',
        'Symfony\\Component\\VarDumper\\Caster\\AmqpCaster' => __DIR__ . '/..' . '/symfony/var-dumper/Caster/AmqpCaster.php',
        'Symfony\\Component\\VarDumper\\Caster\\ArgsStub' => __DIR__ . '/..' . '/symfony/var-dumper/Caster/ArgsStub.php',
        'Symfony\\Component\\VarDumper\\Caster\\Caster' => __DIR__ . '/..' . '/symfony/var-dumper/Caster/Caster.php',
        'Symfony\\Component\\VarDumper\\Caster\\ClassStub' => __DIR__ . '/..' . '/symfony/var-dumper/Caster/ClassStub.php',
        'Symfony\\Component\\VarDumper\\Caster\\ConstStub' => __DIR__ . '/..' . '/symfony/var-dumper/Caster/ConstStub.php',
        'Symfony\\Component\\VarDumper\\Caster\\CutArrayStub' => __DIR__ . '/..' . '/symfony/var-dumper/Caster/CutArrayStub.php',
        'Symfony\\Component\\VarDumper\\Caster\\CutStub' => __DIR__ . '/..' . '/symfony/var-dumper/Caster/CutStub.php',
        'Symfony\\Component\\VarDumper\\Caster\\DOMCaster' => __DIR__ . '/..' . '/symfony/var-dumper/Caster/DOMCaster.php',
        'Symfony\\Component\\VarDumper\\Caster\\DateCaster' => __DIR__ . '/..' . '/symfony/var-dumper/Caster/DateCaster.php',
        'Symfony\\Component\\VarDumper\\Caster\\DoctrineCaster' => __DIR__ . '/..' . '/symfony/var-dumper/Caster/DoctrineCaster.php',
        'Symfony\\Component\\VarDumper\\Caster\\DsCaster' => __DIR__ . '/..' . '/symfony/var-dumper/Caster/DsCaster.php',
        'Symfony\\Component\\VarDumper\\Caster\\DsPairStub' => __DIR__ . '/..' . '/symfony/var-dumper/Caster/DsPairStub.php',
        'Symfony\\Component\\VarDumper\\Caster\\EnumStub' => __DIR__ . '/..' . '/symfony/var-dumper/Caster/EnumStub.php',
        'Symfony\\Component\\VarDumper\\Caster\\ExceptionCaster' => __DIR__ . '/..' . '/symfony/var-dumper/Caster/ExceptionCaster.php',
        'Symfony\\Component\\VarDumper\\Caster\\FFICaster' => __DIR__ . '/..' . '/symfony/var-dumper/Caster/FFICaster.php',
        'Symfony\\Component\\VarDumper\\Caster\\FiberCaster' => __DIR__ . '/..' . '/symfony/var-dumper/Caster/FiberCaster.php',
        'Symfony\\Component\\VarDumper\\Caster\\FrameStub' => __DIR__ . '/..' . '/symfony/var-dumper/Caster/FrameStub.php',
        'Symfony\\Component\\VarDumper\\Caster\\GmpCaster' => __DIR__ . '/..' . '/symfony/var-dumper/Caster/GmpCaster.php',
        'Symfony\\Component\\VarDumper\\Caster\\ImagineCaster' => __DIR__ . '/..' . '/symfony/var-dumper/Caster/ImagineCaster.php',
        'Symfony\\Component\\VarDumper\\Caster\\ImgStub' => __DIR__ . '/..' . '/symfony/var-dumper/Caster/ImgStub.php',
        'Symfony\\Component\\VarDumper\\Caster\\IntlCaster' => __DIR__ . '/..' . '/symfony/var-dumper/Caster/IntlCaster.php',
        'Symfony\\Component\\VarDumper\\Caster\\LinkStub' => __DIR__ . '/..' . '/symfony/var-dumper/Caster/LinkStub.php',
        'Symfony\\Component\\VarDumper\\Caster\\MemcachedCaster' => __DIR__ . '/..' . '/symfony/var-dumper/Caster/MemcachedCaster.php',
        'Symfony\\Component\\VarDumper\\Caster\\MysqliCaster' => __DIR__ . '/..' . '/symfony/var-dumper/Caster/MysqliCaster.php',
        'Symfony\\Component\\VarDumper\\Caster\\PdoCaster' => __DIR__ . '/..' . '/symfony/var-dumper/Caster/PdoCaster.php',
        'Symfony\\Component\\VarDumper\\Caster\\PgSqlCaster' => __DIR__ . '/..' . '/symfony/var-dumper/Caster/PgSqlCaster.php',
        'Symfony\\Component\\VarDumper\\Caster\\ProxyManagerCaster' => __DIR__ . '/..' . '/symfony/var-dumper/Caster/ProxyManagerCaster.php',
        'Symfony\\Component\\VarDumper\\Caster\\RdKafkaCaster' => __DIR__ . '/..' . '/symfony/var-dumper/Caster/RdKafkaCaster.php',
        'Symfony\\Component\\VarDumper\\Caster\\RedisCaster' => __DIR__ . '/..' . '/symfony/var-dumper/Caster/RedisCaster.php',
        'Symfony\\Component\\VarDumper\\Caster\\ReflectionCaster' => __DIR__ . '/..' . '/symfony/var-dumper/Caster/ReflectionCaster.php',
        'Symfony\\Component\\VarDumper\\Caster\\ResourceCaster' => __DIR__ . '/..' . '/symfony/var-dumper/Caster/ResourceCaster.php',
        'Symfony\\Component\\VarDumper\\Caster\\ScalarStub' => __DIR__ . '/..' . '/symfony/var-dumper/Caster/ScalarStub.php',
        'Symfony\\Component\\VarDumper\\Caster\\SplCaster' => __DIR__ . '/..' . '/symfony/var-dumper/Caster/SplCaster.php',
        'Symfony\\Component\\VarDumper\\Caster\\StubCaster' => __DIR__ . '/..' . '/symfony/var-dumper/Caster/StubCaster.php',
        'Symfony\\Component\\VarDumper\\Caster\\SymfonyCaster' => __DIR__ . '/..' . '/symfony/var-dumper/Caster/SymfonyCaster.php',
        'Symfony\\Component\\VarDumper\\Caster\\TraceStub' => __DIR__ . '/..' . '/symfony/var-dumper/Caster/TraceStub.php',
        'Symfony\\Component\\VarDumper\\Caster\\UninitializedStub' => __DIR__ . '/..' . '/symfony/var-dumper/Caster/UninitializedStub.php',
        'Symfony\\Component\\VarDumper\\Caster\\UuidCaster' => __DIR__ . '/..' . '/symfony/var-dumper/Caster/UuidCaster.php',
        'Symfony\\Component\\VarDumper\\Caster\\XmlReaderCaster' => __DIR__ . '/..' . '/symfony/var-dumper/Caster/XmlReaderCaster.php',
        'Symfony\\Component\\VarDumper\\Caster\\XmlResourceCaster' => __DIR__ . '/..' . '/symfony/var-dumper/Caster/XmlResourceCaster.php',
        'Symfony\\Component\\VarDumper\\Cloner\\AbstractCloner' => __DIR__ . '/..' . '/symfony/var-dumper/Cloner/AbstractCloner.php',
        'Symfony\\Component\\VarDumper\\Cloner\\ClonerInterface' => __DIR__ . '/..' . '/symfony/var-dumper/Cloner/ClonerInterface.php',
        'Symfony\\Component\\VarDumper\\Cloner\\Cursor' => __DIR__ . '/..' . '/symfony/var-dumper/Cloner/Cursor.php',
        'Symfony\\Component\\VarDumper\\Cloner\\Data' => __DIR__ . '/..' . '/symfony/var-dumper/Cloner/Data.php',
        'Symfony\\Component\\VarDumper\\Cloner\\DumperInterface' => __DIR__ . '/..' . '/symfony/var-dumper/Cloner/DumperInterface.php',
        'Symfony\\Component\\VarDumper\\Cloner\\Stub' => __DIR__ . '/..' . '/symfony/var-dumper/Cloner/Stub.php',
        'Symfony\\Component\\VarDumper\\Cloner\\VarCloner' => __DIR__ . '/..' . '/symfony/var-dumper/Cloner/VarCloner.php',
        'Symfony\\Component\\VarDumper\\Command\\Descriptor\\CliDescriptor' => __DIR__ . '/..' . '/symfony/var-dumper/Command/Descriptor/CliDescriptor.php',
        'Symfony\\Component\\VarDumper\\Command\\Descriptor\\DumpDescriptorInterface' => __DIR__ . '/..' . '/symfony/var-dumper/Command/Descriptor/DumpDescriptorInterface.php',
        'Symfony\\Component\\VarDumper\\Command\\Descriptor\\HtmlDescriptor' => __DIR__ . '/..' . '/symfony/var-dumper/Command/Descriptor/HtmlDescriptor.php',
        'Symfony\\Component\\VarDumper\\Command\\ServerDumpCommand' => __DIR__ . '/..' . '/symfony/var-dumper/Command/ServerDumpCommand.php',
        'Symfony\\Component\\VarDumper\\Dumper\\AbstractDumper' => __DIR__ . '/..' . '/symfony/var-dumper/Dumper/AbstractDumper.php',
        'Symfony\\Component\\VarDumper\\Dumper\\CliDumper' => __DIR__ . '/..' . '/symfony/var-dumper/Dumper/CliDumper.php',
        'Symfony\\Component\\VarDumper\\Dumper\\ContextProvider\\CliContextProvider' => __DIR__ . '/..' . '/symfony/var-dumper/Dumper/ContextProvider/CliContextProvider.php',
        'Symfony\\Component\\VarDumper\\Dumper\\ContextProvider\\ContextProviderInterface' => __DIR__ . '/..' . '/symfony/var-dumper/Dumper/ContextProvider/ContextProviderInterface.php',
        'Symfony\\Component\\VarDumper\\Dumper\\ContextProvider\\RequestContextProvider' => __DIR__ . '/..' . '/symfony/var-dumper/Dumper/ContextProvider/RequestContextProvider.php',
        'Symfony\\Component\\VarDumper\\Dumper\\ContextProvider\\SourceContextProvider' => __DIR__ . '/..' . '/symfony/var-dumper/Dumper/ContextProvider/SourceContextProvider.php',
        'Symfony\\Component\\VarDumper\\Dumper\\ContextualizedDumper' => __DIR__ . '/..' . '/symfony/var-dumper/Dumper/ContextualizedDumper.php',
        'Symfony\\Component\\VarDumper\\Dumper\\DataDumperInterface' => __DIR__ . '/..' . '/symfony/var-dumper/Dumper/DataDumperInterface.php',
        'Symfony\\Component\\VarDumper\\Dumper\\HtmlDumper' => __DIR__ . '/..' . '/symfony/var-dumper/Dumper/HtmlDumper.php',
        'Symfony\\Component\\VarDumper\\Dumper\\ServerDumper' => __DIR__ . '/..' . '/symfony/var-dumper/Dumper/ServerDumper.php',
        'Symfony\\Component\\VarDumper\\Exception\\ThrowingCasterException' => __DIR__ . '/..' . '/symfony/var-dumper/Exception/ThrowingCasterException.php',
        'Symfony\\Component\\VarDumper\\Server\\Connection' => __DIR__ . '/..' . '/symfony/var-dumper/Server/Connection.php',
        'Symfony\\Component\\VarDumper\\Server\\DumpServer' => __DIR__ . '/..' . '/symfony/var-dumper/Server/DumpServer.php',
        'Symfony\\Component\\VarDumper\\Test\\VarDumperTestTrait' => __DIR__ . '/..' . '/symfony/var-dumper/Test/VarDumperTestTrait.php',
        'Symfony\\Component\\VarDumper\\VarDumper' => __DIR__ . '/..' . '/symfony/var-dumper/VarDumper.php',
        'Symfony\\Component\\VarExporter\\Exception\\ClassNotFoundException' => __DIR__ . '/..' . '/symfony/var-exporter/Exception/ClassNotFoundException.php',
        'Symfony\\Component\\VarExporter\\Exception\\ExceptionInterface' => __DIR__ . '/..' . '/symfony/var-exporter/Exception/ExceptionInterface.php',
        'Symfony\\Component\\VarExporter\\Exception\\LogicException' => __DIR__ . '/..' . '/symfony/var-exporter/Exception/LogicException.php',
        'Symfony\\Component\\VarExporter\\Exception\\NotInstantiableTypeException' => __DIR__ . '/..' . '/symfony/var-exporter/Exception/NotInstantiableTypeException.php',
        'Symfony\\Component\\VarExporter\\Hydrator' => __DIR__ . '/..' . '/symfony/var-exporter/Hydrator.php',
        'Symfony\\Component\\VarExporter\\Instantiator' => __DIR__ . '/..' . '/symfony/var-exporter/Instantiator.php',
        'Symfony\\Component\\VarExporter\\Internal\\Exporter' => __DIR__ . '/..' . '/symfony/var-exporter/Internal/Exporter.php',
        'Symfony\\Component\\VarExporter\\Internal\\Hydrator' => __DIR__ . '/..' . '/symfony/var-exporter/Internal/Hydrator.php',
        'Symfony\\Component\\VarExporter\\Internal\\LazyObjectRegistry' => __DIR__ . '/..' . '/symfony/var-exporter/Internal/LazyObjectRegistry.php',
        'Symfony\\Component\\VarExporter\\Internal\\LazyObjectState' => __DIR__ . '/..' . '/symfony/var-exporter/Internal/LazyObjectState.php',
        'Symfony\\Component\\VarExporter\\Internal\\LazyObjectTrait' => __DIR__ . '/..' . '/symfony/var-exporter/Internal/LazyObjectTrait.php',
        'Symfony\\Component\\VarExporter\\Internal\\Reference' => __DIR__ . '/..' . '/symfony/var-exporter/Internal/Reference.php',
        'Symfony\\Component\\VarExporter\\Internal\\Registry' => __DIR__ . '/..' . '/symfony/var-exporter/Internal/Registry.php',
        'Symfony\\Component\\VarExporter\\Internal\\Values' => __DIR__ . '/..' . '/symfony/var-exporter/Internal/Values.php',
        'Symfony\\Component\\VarExporter\\LazyGhostTrait' => __DIR__ . '/..' . '/symfony/var-exporter/LazyGhostTrait.php',
        'Symfony\\Component\\VarExporter\\LazyObjectInterface' => __DIR__ . '/..' . '/symfony/var-exporter/LazyObjectInterface.php',
        'Symfony\\Component\\VarExporter\\LazyProxyTrait' => __DIR__ . '/..' . '/symfony/var-exporter/LazyProxyTrait.php',
        'Symfony\\Component\\VarExporter\\ProxyHelper' => __DIR__ . '/..' . '/symfony/var-exporter/ProxyHelper.php',
        'Symfony\\Component\\VarExporter\\VarExporter' => __DIR__ . '/..' . '/symfony/var-exporter/VarExporter.php',
        'Symfony\\Component\\Yaml\\Command\\LintCommand' => __DIR__ . '/..' . '/symfony/yaml/Command/LintCommand.php',
        'Symfony\\Component\\Yaml\\Dumper' => __DIR__ . '/..' . '/symfony/yaml/Dumper.php',
        'Symfony\\Component\\Yaml\\Escaper' => __DIR__ . '/..' . '/symfony/yaml/Escaper.php',
        'Symfony\\Component\\Yaml\\Exception\\DumpException' => __DIR__ . '/..' . '/symfony/yaml/Exception/DumpException.php',
        'Symfony\\Component\\Yaml\\Exception\\ExceptionInterface' => __DIR__ . '/..' . '/symfony/yaml/Exception/ExceptionInterface.php',
        'Symfony\\Component\\Yaml\\Exception\\ParseException' => __DIR__ . '/..' . '/symfony/yaml/Exception/ParseException.php',
        'Symfony\\Component\\Yaml\\Exception\\RuntimeException' => __DIR__ . '/..' . '/symfony/yaml/Exception/RuntimeException.php',
        'Symfony\\Component\\Yaml\\Inline' => __DIR__ . '/..' . '/symfony/yaml/Inline.php',
        'Symfony\\Component\\Yaml\\Parser' => __DIR__ . '/..' . '/symfony/yaml/Parser.php',
        'Symfony\\Component\\Yaml\\ParserState' => __DIR__ . '/..' . '/symfony/yaml/ParserState.php',
        'Symfony\\Component\\Yaml\\Tag\\TaggedValue' => __DIR__ . '/..' . '/symfony/yaml/Tag/TaggedValue.php',
        'Symfony\\Component\\Yaml\\Unescaper' => __DIR__ . '/..' . '/symfony/yaml/Unescaper.php',
        'Symfony\\Component\\Yaml\\Yaml' => __DIR__ . '/..' . '/symfony/yaml/Yaml.php',
        'Symfony\\Contracts\\Cache\\CacheInterface' => __DIR__ . '/..' . '/symfony/cache-contracts/CacheInterface.php',
        'Symfony\\Contracts\\Cache\\CacheTrait' => __DIR__ . '/..' . '/symfony/cache-contracts/CacheTrait.php',
        'Symfony\\Contracts\\Cache\\CallbackInterface' => __DIR__ . '/..' . '/symfony/cache-contracts/CallbackInterface.php',
        'Symfony\\Contracts\\Cache\\ItemInterface' => __DIR__ . '/..' . '/symfony/cache-contracts/ItemInterface.php',
        'Symfony\\Contracts\\Cache\\NamespacedPoolInterface' => __DIR__ . '/..' . '/symfony/cache-contracts/NamespacedPoolInterface.php',
        'Symfony\\Contracts\\Cache\\TagAwareCacheInterface' => __DIR__ . '/..' . '/symfony/cache-contracts/TagAwareCacheInterface.php',
        'Symfony\\Contracts\\EventDispatcher\\Event' => __DIR__ . '/..' . '/symfony/event-dispatcher-contracts/Event.php',
        'Symfony\\Contracts\\EventDispatcher\\EventDispatcherInterface' => __DIR__ . '/..' . '/symfony/event-dispatcher-contracts/EventDispatcherInterface.php',
        'Symfony\\Contracts\\Service\\Attribute\\Required' => __DIR__ . '/..' . '/symfony/service-contracts/Attribute/Required.php',
        'Symfony\\Contracts\\Service\\Attribute\\SubscribedService' => __DIR__ . '/..' . '/symfony/service-contracts/Attribute/SubscribedService.php',
        'Symfony\\Contracts\\Service\\ContainerAwareInterface' => __DIR__ . '/..' . '/symfony/service-contracts/ContainerAwareInterface.php',
        'Symfony\\Contracts\\Service\\ContainerProviderInterface' => __DIR__ . '/..' . '/symfony/service-contracts/ContainerProviderInterface.php',
        'Symfony\\Contracts\\Service\\ResetInterface' => __DIR__ . '/..' . '/symfony/service-contracts/ResetInterface.php',
        'Symfony\\Contracts\\Service\\ServiceCollectionInterface' => __DIR__ . '/..' . '/symfony/service-contracts/ServiceCollectionInterface.php',
        'Symfony\\Contracts\\Service\\ServiceLocatorTrait' => __DIR__ . '/..' . '/symfony/service-contracts/ServiceLocatorTrait.php',
        'Symfony\\Contracts\\Service\\ServiceMethodsSubscriberTrait' => __DIR__ . '/..' . '/symfony/service-contracts/ServiceMethodsSubscriberTrait.php',
        'Symfony\\Contracts\\Service\\ServiceProviderInterface' => __DIR__ . '/..' . '/symfony/service-contracts/ServiceProviderInterface.php',
        'Symfony\\Contracts\\Service\\ServiceSubscriberInterface' => __DIR__ . '/..' . '/symfony/service-contracts/ServiceSubscriberInterface.php',
        'Symfony\\Contracts\\Service\\ServiceSubscriberTrait' => __DIR__ . '/..' . '/symfony/service-contracts/ServiceSubscriberTrait.php',
        'Symfony\\Contracts\\Translation\\LocaleAwareInterface' => __DIR__ . '/..' . '/symfony/translation-contracts/LocaleAwareInterface.php',
        'Symfony\\Contracts\\Translation\\TranslatableInterface' => __DIR__ . '/..' . '/symfony/translation-contracts/TranslatableInterface.php',
        'Symfony\\Contracts\\Translation\\TranslatorInterface' => __DIR__ . '/..' . '/symfony/translation-contracts/TranslatorInterface.php',
        'Symfony\\Contracts\\Translation\\TranslatorTrait' => __DIR__ . '/..' . '/symfony/translation-contracts/TranslatorTrait.php',
        'Symfony\\Polyfill\\Ctype\\Ctype' => __DIR__ . '/..' . '/symfony/polyfill-ctype/Ctype.php',
        'Symfony\\Polyfill\\Intl\\Grapheme\\Grapheme' => __DIR__ . '/..' . '/symfony/polyfill-intl-grapheme/Grapheme.php',
        'Symfony\\Polyfill\\Intl\\Icu\\Collator' => __DIR__ . '/..' . '/symfony/polyfill-intl-icu/Collator.php',
        'Symfony\\Polyfill\\Intl\\Icu\\Currencies' => __DIR__ . '/..' . '/symfony/polyfill-intl-icu/Currencies.php',
        'Symfony\\Polyfill\\Intl\\Icu\\DateFormat\\AmPmTransformer' => __DIR__ . '/..' . '/symfony/polyfill-intl-icu/DateFormat/AmPmTransformer.php',
        'Symfony\\Polyfill\\Intl\\Icu\\DateFormat\\DayOfWeekTransformer' => __DIR__ . '/..' . '/symfony/polyfill-intl-icu/DateFormat/DayOfWeekTransformer.php',
        'Symfony\\Polyfill\\Intl\\Icu\\DateFormat\\DayOfYearTransformer' => __DIR__ . '/..' . '/symfony/polyfill-intl-icu/DateFormat/DayOfYearTransformer.php',
        'Symfony\\Polyfill\\Intl\\Icu\\DateFormat\\DayTransformer' => __DIR__ . '/..' . '/symfony/polyfill-intl-icu/DateFormat/DayTransformer.php',
        'Symfony\\Polyfill\\Intl\\Icu\\DateFormat\\FullTransformer' => __DIR__ . '/..' . '/symfony/polyfill-intl-icu/DateFormat/FullTransformer.php',
        'Symfony\\Polyfill\\Intl\\Icu\\DateFormat\\Hour1200Transformer' => __DIR__ . '/..' . '/symfony/polyfill-intl-icu/DateFormat/Hour1200Transformer.php',
        'Symfony\\Polyfill\\Intl\\Icu\\DateFormat\\Hour1201Transformer' => __DIR__ . '/..' . '/symfony/polyfill-intl-icu/DateFormat/Hour1201Transformer.php',
        'Symfony\\Polyfill\\Intl\\Icu\\DateFormat\\Hour2400Transformer' => __DIR__ . '/..' . '/symfony/polyfill-intl-icu/DateFormat/Hour2400Transformer.php',
        'Symfony\\Polyfill\\Intl\\Icu\\DateFormat\\Hour2401Transformer' => __DIR__ . '/..' . '/symfony/polyfill-intl-icu/DateFormat/Hour2401Transformer.php',
        'Symfony\\Polyfill\\Intl\\Icu\\DateFormat\\HourTransformer' => __DIR__ . '/..' . '/symfony/polyfill-intl-icu/DateFormat/HourTransformer.php',
        'Symfony\\Polyfill\\Intl\\Icu\\DateFormat\\MinuteTransformer' => __DIR__ . '/..' . '/symfony/polyfill-intl-icu/DateFormat/MinuteTransformer.php',
        'Symfony\\Polyfill\\Intl\\Icu\\DateFormat\\MonthTransformer' => __DIR__ . '/..' . '/symfony/polyfill-intl-icu/DateFormat/MonthTransformer.php',
        'Symfony\\Polyfill\\Intl\\Icu\\DateFormat\\QuarterTransformer' => __DIR__ . '/..' . '/symfony/polyfill-intl-icu/DateFormat/QuarterTransformer.php',
        'Symfony\\Polyfill\\Intl\\Icu\\DateFormat\\SecondTransformer' => __DIR__ . '/..' . '/symfony/polyfill-intl-icu/DateFormat/SecondTransformer.php',
        'Symfony\\Polyfill\\Intl\\Icu\\DateFormat\\TimezoneTransformer' => __DIR__ . '/..' . '/symfony/polyfill-intl-icu/DateFormat/TimezoneTransformer.php',
        'Symfony\\Polyfill\\Intl\\Icu\\DateFormat\\Transformer' => __DIR__ . '/..' . '/symfony/polyfill-intl-icu/DateFormat/Transformer.php',
        'Symfony\\Polyfill\\Intl\\Icu\\DateFormat\\YearTransformer' => __DIR__ . '/..' . '/symfony/polyfill-intl-icu/DateFormat/YearTransformer.php',
        'Symfony\\Polyfill\\Intl\\Icu\\Exception\\ExceptionInterface' => __DIR__ . '/..' . '/symfony/polyfill-intl-icu/Exception/ExceptionInterface.php',
        'Symfony\\Polyfill\\Intl\\Icu\\Exception\\MethodArgumentNotImplementedException' => __DIR__ . '/..' . '/symfony/polyfill-intl-icu/Exception/MethodArgumentNotImplementedException.php',
        'Symfony\\Polyfill\\Intl\\Icu\\Exception\\MethodArgumentValueNotImplementedException' => __DIR__ . '/..' . '/symfony/polyfill-intl-icu/Exception/MethodArgumentValueNotImplementedException.php',
        'Symfony\\Polyfill\\Intl\\Icu\\Exception\\MethodNotImplementedException' => __DIR__ . '/..' . '/symfony/polyfill-intl-icu/Exception/MethodNotImplementedException.php',
        'Symfony\\Polyfill\\Intl\\Icu\\Exception\\NotImplementedException' => __DIR__ . '/..' . '/symfony/polyfill-intl-icu/Exception/NotImplementedException.php',
        'Symfony\\Polyfill\\Intl\\Icu\\Exception\\RuntimeException' => __DIR__ . '/..' . '/symfony/polyfill-intl-icu/Exception/RuntimeException.php',
        'Symfony\\Polyfill\\Intl\\Icu\\Icu' => __DIR__ . '/..' . '/symfony/polyfill-intl-icu/Icu.php',
        'Symfony\\Polyfill\\Intl\\Icu\\IntlDateFormatter' => __DIR__ . '/..' . '/symfony/polyfill-intl-icu/IntlDateFormatter.php',
        'Symfony\\Polyfill\\Intl\\Icu\\IntlListFormatter' => __DIR__ . '/..' . '/symfony/polyfill-intl-icu/IntlListFormatter.php',
        'Symfony\\Polyfill\\Intl\\Icu\\Locale' => __DIR__ . '/..' . '/symfony/polyfill-intl-icu/Locale.php',
        'Symfony\\Polyfill\\Intl\\Icu\\NumberFormatter' => __DIR__ . '/..' . '/symfony/polyfill-intl-icu/NumberFormatter.php',
        'Symfony\\Polyfill\\Intl\\Normalizer\\Normalizer' => __DIR__ . '/..' . '/symfony/polyfill-intl-normalizer/Normalizer.php',
        'Symfony\\Polyfill\\Mbstring\\Mbstring' => __DIR__ . '/..' . '/symfony/polyfill-mbstring/Mbstring.php',
        'Symfony\\Polyfill\\Php80\\Php80' => __DIR__ . '/..' . '/symfony/polyfill-php80/Php80.php',
        'Symfony\\Polyfill\\Php80\\PhpToken' => __DIR__ . '/..' . '/symfony/polyfill-php80/PhpToken.php',
        'Symfony\\Polyfill\\Php83\\Php83' => __DIR__ . '/..' . '/symfony/polyfill-php83/Php83.php',
        'Twig\\AbstractTwigCallable' => __DIR__ . '/..' . '/twig/twig/src/AbstractTwigCallable.php',
        'Twig\\Attribute\\AsTwigFilter' => __DIR__ . '/..' . '/twig/twig/src/Attribute/AsTwigFilter.php',
        'Twig\\Attribute\\AsTwigFunction' => __DIR__ . '/..' . '/twig/twig/src/Attribute/AsTwigFunction.php',
        'Twig\\Attribute\\AsTwigTest' => __DIR__ . '/..' . '/twig/twig/src/Attribute/AsTwigTest.php',
        'Twig\\Attribute\\FirstClassTwigCallableReady' => __DIR__ . '/..' . '/twig/twig/src/Attribute/FirstClassTwigCallableReady.php',
        'Twig\\Attribute\\YieldReady' => __DIR__ . '/..' . '/twig/twig/src/Attribute/YieldReady.php',
        'Twig\\Cache\\CacheInterface' => __DIR__ . '/..' . '/twig/twig/src/Cache/CacheInterface.php',
        'Twig\\Cache\\ChainCache' => __DIR__ . '/..' . '/twig/twig/src/Cache/ChainCache.php',
        'Twig\\Cache\\FilesystemCache' => __DIR__ . '/..' . '/twig/twig/src/Cache/FilesystemCache.php',
        'Twig\\Cache\\NullCache' => __DIR__ . '/..' . '/twig/twig/src/Cache/NullCache.php',
        'Twig\\Cache\\ReadOnlyFilesystemCache' => __DIR__ . '/..' . '/twig/twig/src/Cache/ReadOnlyFilesystemCache.php',
        'Twig\\Cache\\RemovableCacheInterface' => __DIR__ . '/..' . '/twig/twig/src/Cache/RemovableCacheInterface.php',
        'Twig\\Compiler' => __DIR__ . '/..' . '/twig/twig/src/Compiler.php',
        'Twig\\DeprecatedCallableInfo' => __DIR__ . '/..' . '/twig/twig/src/DeprecatedCallableInfo.php',
        'Twig\\Environment' => __DIR__ . '/..' . '/twig/twig/src/Environment.php',
        'Twig\\Error\\Error' => __DIR__ . '/..' . '/twig/twig/src/Error/Error.php',
        'Twig\\Error\\LoaderError' => __DIR__ . '/..' . '/twig/twig/src/Error/LoaderError.php',
        'Twig\\Error\\RuntimeError' => __DIR__ . '/..' . '/twig/twig/src/Error/RuntimeError.php',
        'Twig\\Error\\SyntaxError' => __DIR__ . '/..' . '/twig/twig/src/Error/SyntaxError.php',
        'Twig\\ExpressionParser' => __DIR__ . '/..' . '/twig/twig/src/ExpressionParser.php',
        'Twig\\ExpressionParser\\AbstractExpressionParser' => __DIR__ . '/..' . '/twig/twig/src/ExpressionParser/AbstractExpressionParser.php',
        'Twig\\ExpressionParser\\ExpressionParserDescriptionInterface' => __DIR__ . '/..' . '/twig/twig/src/ExpressionParser/ExpressionParserDescriptionInterface.php',
        'Twig\\ExpressionParser\\ExpressionParserInterface' => __DIR__ . '/..' . '/twig/twig/src/ExpressionParser/ExpressionParserInterface.php',
        'Twig\\ExpressionParser\\ExpressionParserType' => __DIR__ . '/..' . '/twig/twig/src/ExpressionParser/ExpressionParserType.php',
        'Twig\\ExpressionParser\\ExpressionParsers' => __DIR__ . '/..' . '/twig/twig/src/ExpressionParser/ExpressionParsers.php',
        'Twig\\ExpressionParser\\InfixAssociativity' => __DIR__ . '/..' . '/twig/twig/src/ExpressionParser/InfixAssociativity.php',
        'Twig\\ExpressionParser\\InfixExpressionParserInterface' => __DIR__ . '/..' . '/twig/twig/src/ExpressionParser/InfixExpressionParserInterface.php',
        'Twig\\ExpressionParser\\Infix\\ArgumentsTrait' => __DIR__ . '/..' . '/twig/twig/src/ExpressionParser/Infix/ArgumentsTrait.php',
        'Twig\\ExpressionParser\\Infix\\ArrowExpressionParser' => __DIR__ . '/..' . '/twig/twig/src/ExpressionParser/Infix/ArrowExpressionParser.php',
        'Twig\\ExpressionParser\\Infix\\AssignmentExpressionParser' => __DIR__ . '/..' . '/twig/twig/src/ExpressionParser/Infix/AssignmentExpressionParser.php',
        'Twig\\ExpressionParser\\Infix\\BinaryOperatorExpressionParser' => __DIR__ . '/..' . '/twig/twig/src/ExpressionParser/Infix/BinaryOperatorExpressionParser.php',
        'Twig\\ExpressionParser\\Infix\\ConditionalTernaryExpressionParser' => __DIR__ . '/..' . '/twig/twig/src/ExpressionParser/Infix/ConditionalTernaryExpressionParser.php',
        'Twig\\ExpressionParser\\Infix\\DotExpressionParser' => __DIR__ . '/..' . '/twig/twig/src/ExpressionParser/Infix/DotExpressionParser.php',
        'Twig\\ExpressionParser\\Infix\\FilterExpressionParser' => __DIR__ . '/..' . '/twig/twig/src/ExpressionParser/Infix/FilterExpressionParser.php',
        'Twig\\ExpressionParser\\Infix\\FunctionExpressionParser' => __DIR__ . '/..' . '/twig/twig/src/ExpressionParser/Infix/FunctionExpressionParser.php',
        'Twig\\ExpressionParser\\Infix\\IsExpressionParser' => __DIR__ . '/..' . '/twig/twig/src/ExpressionParser/Infix/IsExpressionParser.php',
        'Twig\\ExpressionParser\\Infix\\IsNotExpressionParser' => __DIR__ . '/..' . '/twig/twig/src/ExpressionParser/Infix/IsNotExpressionParser.php',
        'Twig\\ExpressionParser\\Infix\\SquareBracketExpressionParser' => __DIR__ . '/..' . '/twig/twig/src/ExpressionParser/Infix/SquareBracketExpressionParser.php',
        'Twig\\ExpressionParser\\PrecedenceChange' => __DIR__ . '/..' . '/twig/twig/src/ExpressionParser/PrecedenceChange.php',
        'Twig\\ExpressionParser\\PrefixExpressionParserInterface' => __DIR__ . '/..' . '/twig/twig/src/ExpressionParser/PrefixExpressionParserInterface.php',
        'Twig\\ExpressionParser\\Prefix\\GroupingExpressionParser' => __DIR__ . '/..' . '/twig/twig/src/ExpressionParser/Prefix/GroupingExpressionParser.php',
        'Twig\\ExpressionParser\\Prefix\\LiteralExpressionParser' => __DIR__ . '/..' . '/twig/twig/src/ExpressionParser/Prefix/LiteralExpressionParser.php',
        'Twig\\ExpressionParser\\Prefix\\UnaryOperatorExpressionParser' => __DIR__ . '/..' . '/twig/twig/src/ExpressionParser/Prefix/UnaryOperatorExpressionParser.php',
        'Twig\\ExtensionSet' => __DIR__ . '/..' . '/twig/twig/src/ExtensionSet.php',
        'Twig\\Extension\\AbstractExtension' => __DIR__ . '/..' . '/twig/twig/src/Extension/AbstractExtension.php',
        'Twig\\Extension\\AttributeExtension' => __DIR__ . '/..' . '/twig/twig/src/Extension/AttributeExtension.php',
        'Twig\\Extension\\CoreExtension' => __DIR__ . '/..' . '/twig/twig/src/Extension/CoreExtension.php',
        'Twig\\Extension\\DebugExtension' => __DIR__ . '/..' . '/twig/twig/src/Extension/DebugExtension.php',
        'Twig\\Extension\\EscaperExtension' => __DIR__ . '/..' . '/twig/twig/src/Extension/EscaperExtension.php',
        'Twig\\Extension\\ExtensionInterface' => __DIR__ . '/..' . '/twig/twig/src/Extension/ExtensionInterface.php',
        'Twig\\Extension\\GlobalsInterface' => __DIR__ . '/..' . '/twig/twig/src/Extension/GlobalsInterface.php',
        'Twig\\Extension\\LastModifiedExtensionInterface' => __DIR__ . '/..' . '/twig/twig/src/Extension/LastModifiedExtensionInterface.php',
        'Twig\\Extension\\OptimizerExtension' => __DIR__ . '/..' . '/twig/twig/src/Extension/OptimizerExtension.php',
        'Twig\\Extension\\ProfilerExtension' => __DIR__ . '/..' . '/twig/twig/src/Extension/ProfilerExtension.php',
        'Twig\\Extension\\RuntimeExtensionInterface' => __DIR__ . '/..' . '/twig/twig/src/Extension/RuntimeExtensionInterface.php',
        'Twig\\Extension\\SandboxExtension' => __DIR__ . '/..' . '/twig/twig/src/Extension/SandboxExtension.php',
        'Twig\\Extension\\StagingExtension' => __DIR__ . '/..' . '/twig/twig/src/Extension/StagingExtension.php',
        'Twig\\Extension\\StringLoaderExtension' => __DIR__ . '/..' . '/twig/twig/src/Extension/StringLoaderExtension.php',
        'Twig\\Extension\\YieldNotReadyExtension' => __DIR__ . '/..' . '/twig/twig/src/Extension/YieldNotReadyExtension.php',
        'Twig\\Extra\\Intl\\IntlExtension' => __DIR__ . '/..' . '/twig/intl-extra/IntlExtension.php',
        'Twig\\FileExtensionEscapingStrategy' => __DIR__ . '/..' . '/twig/twig/src/FileExtensionEscapingStrategy.php',
        'Twig\\Lexer' => __DIR__ . '/..' . '/twig/twig/src/Lexer.php',
        'Twig\\Loader\\ArrayLoader' => __DIR__ . '/..' . '/twig/twig/src/Loader/ArrayLoader.php',
        'Twig\\Loader\\ChainLoader' => __DIR__ . '/..' . '/twig/twig/src/Loader/ChainLoader.php',
        'Twig\\Loader\\FilesystemLoader' => __DIR__ . '/..' . '/twig/twig/src/Loader/FilesystemLoader.php',
        'Twig\\Loader\\LoaderInterface' => __DIR__ . '/..' . '/twig/twig/src/Loader/LoaderInterface.php',
        'Twig\\Markup' => __DIR__ . '/..' . '/twig/twig/src/Markup.php',
        'Twig\\NodeTraverser' => __DIR__ . '/..' . '/twig/twig/src/NodeTraverser.php',
        'Twig\\NodeVisitor\\AbstractNodeVisitor' => __DIR__ . '/..' . '/twig/twig/src/NodeVisitor/AbstractNodeVisitor.php',
        'Twig\\NodeVisitor\\CorrectnessNodeVisitor' => __DIR__ . '/..' . '/twig/twig/src/NodeVisitor/CorrectnessNodeVisitor.php',
        'Twig\\NodeVisitor\\EscaperNodeVisitor' => __DIR__ . '/..' . '/twig/twig/src/NodeVisitor/EscaperNodeVisitor.php',
        'Twig\\NodeVisitor\\NodeVisitorInterface' => __DIR__ . '/..' . '/twig/twig/src/NodeVisitor/NodeVisitorInterface.php',
        'Twig\\NodeVisitor\\OptimizerNodeVisitor' => __DIR__ . '/..' . '/twig/twig/src/NodeVisitor/OptimizerNodeVisitor.php',
        'Twig\\NodeVisitor\\SafeAnalysisNodeVisitor' => __DIR__ . '/..' . '/twig/twig/src/NodeVisitor/SafeAnalysisNodeVisitor.php',
        'Twig\\NodeVisitor\\SandboxNodeVisitor' => __DIR__ . '/..' . '/twig/twig/src/NodeVisitor/SandboxNodeVisitor.php',
        'Twig\\NodeVisitor\\YieldNotReadyNodeVisitor' => __DIR__ . '/..' . '/twig/twig/src/NodeVisitor/YieldNotReadyNodeVisitor.php',
        'Twig\\Node\\AutoEscapeNode' => __DIR__ . '/..' . '/twig/twig/src/Node/AutoEscapeNode.php',
        'Twig\\Node\\BlockNode' => __DIR__ . '/..' . '/twig/twig/src/Node/BlockNode.php',
        'Twig\\Node\\BlockReferenceNode' => __DIR__ . '/..' . '/twig/twig/src/Node/BlockReferenceNode.php',
        'Twig\\Node\\BodyNode' => __DIR__ . '/..' . '/twig/twig/src/Node/BodyNode.php',
        'Twig\\Node\\CaptureNode' => __DIR__ . '/..' . '/twig/twig/src/Node/CaptureNode.php',
        'Twig\\Node\\CheckSecurityCallNode' => __DIR__ . '/..' . '/twig/twig/src/Node/CheckSecurityCallNode.php',
        'Twig\\Node\\CheckSecurityNode' => __DIR__ . '/..' . '/twig/twig/src/Node/CheckSecurityNode.php',
        'Twig\\Node\\CheckToStringNode' => __DIR__ . '/..' . '/twig/twig/src/Node/CheckToStringNode.php',
        'Twig\\Node\\CoercesChildrenToStringInterface' => __DIR__ . '/..' . '/twig/twig/src/Node/CoercesChildrenToStringInterface.php',
        'Twig\\Node\\ConfigNode' => __DIR__ . '/..' . '/twig/twig/src/Node/ConfigNode.php',
        'Twig\\Node\\DeprecatedNode' => __DIR__ . '/..' . '/twig/twig/src/Node/DeprecatedNode.php',
        'Twig\\Node\\DoNode' => __DIR__ . '/..' . '/twig/twig/src/Node/DoNode.php',
        'Twig\\Node\\EmbedNode' => __DIR__ . '/..' . '/twig/twig/src/Node/EmbedNode.php',
        'Twig\\Node\\EmptyNode' => __DIR__ . '/..' . '/twig/twig/src/Node/EmptyNode.php',
        'Twig\\Node\\Expression\\AbstractExpression' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/AbstractExpression.php',
        'Twig\\Node\\Expression\\ArrayExpression' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/ArrayExpression.php',
        'Twig\\Node\\Expression\\ArrowFunctionExpression' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/ArrowFunctionExpression.php',
        'Twig\\Node\\Expression\\AssignNameExpression' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/AssignNameExpression.php',
        'Twig\\Node\\Expression\\Binary\\AbstractBinary' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Binary/AbstractBinary.php',
        'Twig\\Node\\Expression\\Binary\\AddBinary' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Binary/AddBinary.php',
        'Twig\\Node\\Expression\\Binary\\AndBinary' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Binary/AndBinary.php',
        'Twig\\Node\\Expression\\Binary\\BinaryInterface' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Binary/BinaryInterface.php',
        'Twig\\Node\\Expression\\Binary\\BitwiseAndBinary' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Binary/BitwiseAndBinary.php',
        'Twig\\Node\\Expression\\Binary\\BitwiseOrBinary' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Binary/BitwiseOrBinary.php',
        'Twig\\Node\\Expression\\Binary\\BitwiseXorBinary' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Binary/BitwiseXorBinary.php',
        'Twig\\Node\\Expression\\Binary\\ConcatBinary' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Binary/ConcatBinary.php',
        'Twig\\Node\\Expression\\Binary\\DivBinary' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Binary/DivBinary.php',
        'Twig\\Node\\Expression\\Binary\\ElvisBinary' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Binary/ElvisBinary.php',
        'Twig\\Node\\Expression\\Binary\\EndsWithBinary' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Binary/EndsWithBinary.php',
        'Twig\\Node\\Expression\\Binary\\EqualBinary' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Binary/EqualBinary.php',
        'Twig\\Node\\Expression\\Binary\\FloorDivBinary' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Binary/FloorDivBinary.php',
        'Twig\\Node\\Expression\\Binary\\GreaterBinary' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Binary/GreaterBinary.php',
        'Twig\\Node\\Expression\\Binary\\GreaterEqualBinary' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Binary/GreaterEqualBinary.php',
        'Twig\\Node\\Expression\\Binary\\HasEveryBinary' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Binary/HasEveryBinary.php',
        'Twig\\Node\\Expression\\Binary\\HasSomeBinary' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Binary/HasSomeBinary.php',
        'Twig\\Node\\Expression\\Binary\\InBinary' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Binary/InBinary.php',
        'Twig\\Node\\Expression\\Binary\\LessBinary' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Binary/LessBinary.php',
        'Twig\\Node\\Expression\\Binary\\LessEqualBinary' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Binary/LessEqualBinary.php',
        'Twig\\Node\\Expression\\Binary\\MatchesBinary' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Binary/MatchesBinary.php',
        'Twig\\Node\\Expression\\Binary\\ModBinary' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Binary/ModBinary.php',
        'Twig\\Node\\Expression\\Binary\\MulBinary' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Binary/MulBinary.php',
        'Twig\\Node\\Expression\\Binary\\NotEqualBinary' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Binary/NotEqualBinary.php',
        'Twig\\Node\\Expression\\Binary\\NotInBinary' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Binary/NotInBinary.php',
        'Twig\\Node\\Expression\\Binary\\NotSameAsBinary' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Binary/NotSameAsBinary.php',
        'Twig\\Node\\Expression\\Binary\\NullCoalesceBinary' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Binary/NullCoalesceBinary.php',
        'Twig\\Node\\Expression\\Binary\\ObjectDestructuringSetBinary' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Binary/ObjectDestructuringSetBinary.php',
        'Twig\\Node\\Expression\\Binary\\OrBinary' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Binary/OrBinary.php',
        'Twig\\Node\\Expression\\Binary\\PowerBinary' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Binary/PowerBinary.php',
        'Twig\\Node\\Expression\\Binary\\RangeBinary' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Binary/RangeBinary.php',
        'Twig\\Node\\Expression\\Binary\\SameAsBinary' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Binary/SameAsBinary.php',
        'Twig\\Node\\Expression\\Binary\\SequenceDestructuringSetBinary' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Binary/SequenceDestructuringSetBinary.php',
        'Twig\\Node\\Expression\\Binary\\SetBinary' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Binary/SetBinary.php',
        'Twig\\Node\\Expression\\Binary\\SpaceshipBinary' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Binary/SpaceshipBinary.php',
        'Twig\\Node\\Expression\\Binary\\StartsWithBinary' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Binary/StartsWithBinary.php',
        'Twig\\Node\\Expression\\Binary\\SubBinary' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Binary/SubBinary.php',
        'Twig\\Node\\Expression\\Binary\\XorBinary' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Binary/XorBinary.php',
        'Twig\\Node\\Expression\\BlockReferenceExpression' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/BlockReferenceExpression.php',
        'Twig\\Node\\Expression\\CallExpression' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/CallExpression.php',
        'Twig\\Node\\Expression\\ConditionalExpression' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/ConditionalExpression.php',
        'Twig\\Node\\Expression\\ConstantExpression' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/ConstantExpression.php',
        'Twig\\Node\\Expression\\EmptyExpression' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/EmptyExpression.php',
        'Twig\\Node\\Expression\\FilterExpression' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/FilterExpression.php',
        'Twig\\Node\\Expression\\Filter\\DefaultFilter' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Filter/DefaultFilter.php',
        'Twig\\Node\\Expression\\Filter\\RawFilter' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Filter/RawFilter.php',
        'Twig\\Node\\Expression\\FunctionExpression' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/FunctionExpression.php',
        'Twig\\Node\\Expression\\FunctionNode\\EnumCasesFunction' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/FunctionNode/EnumCasesFunction.php',
        'Twig\\Node\\Expression\\FunctionNode\\EnumFunction' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/FunctionNode/EnumFunction.php',
        'Twig\\Node\\Expression\\GetAttrExpression' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/GetAttrExpression.php',
        'Twig\\Node\\Expression\\InlinePrint' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/InlinePrint.php',
        'Twig\\Node\\Expression\\ListExpression' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/ListExpression.php',
        'Twig\\Node\\Expression\\MacroReferenceExpression' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/MacroReferenceExpression.php',
        'Twig\\Node\\Expression\\MethodCallExpression' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/MethodCallExpression.php',
        'Twig\\Node\\Expression\\NameExpression' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/NameExpression.php',
        'Twig\\Node\\Expression\\NullCoalesceExpression' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/NullCoalesceExpression.php',
        'Twig\\Node\\Expression\\OperatorEscapeInterface' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/OperatorEscapeInterface.php',
        'Twig\\Node\\Expression\\ParentExpression' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/ParentExpression.php',
        'Twig\\Node\\Expression\\ReturnArrayInterface' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/ReturnArrayInterface.php',
        'Twig\\Node\\Expression\\ReturnBoolInterface' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/ReturnBoolInterface.php',
        'Twig\\Node\\Expression\\ReturnNumberInterface' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/ReturnNumberInterface.php',
        'Twig\\Node\\Expression\\ReturnPrimitiveTypeInterface' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/ReturnPrimitiveTypeInterface.php',
        'Twig\\Node\\Expression\\ReturnStringInterface' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/ReturnStringInterface.php',
        'Twig\\Node\\Expression\\SupportDefinedTestDeprecationTrait' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/SupportDefinedTestDeprecationTrait.php',
        'Twig\\Node\\Expression\\SupportDefinedTestInterface' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/SupportDefinedTestInterface.php',
        'Twig\\Node\\Expression\\SupportDefinedTestTrait' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/SupportDefinedTestTrait.php',
        'Twig\\Node\\Expression\\TempNameExpression' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/TempNameExpression.php',
        'Twig\\Node\\Expression\\Ternary\\ConditionalTernary' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Ternary/ConditionalTernary.php',
        'Twig\\Node\\Expression\\TestExpression' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/TestExpression.php',
        'Twig\\Node\\Expression\\Test\\ConstantTest' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Test/ConstantTest.php',
        'Twig\\Node\\Expression\\Test\\DefinedTest' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Test/DefinedTest.php',
        'Twig\\Node\\Expression\\Test\\DivisiblebyTest' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Test/DivisiblebyTest.php',
        'Twig\\Node\\Expression\\Test\\EvenTest' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Test/EvenTest.php',
        'Twig\\Node\\Expression\\Test\\NullTest' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Test/NullTest.php',
        'Twig\\Node\\Expression\\Test\\OddTest' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Test/OddTest.php',
        'Twig\\Node\\Expression\\Test\\SameasTest' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Test/SameasTest.php',
        'Twig\\Node\\Expression\\Test\\TrueTest' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Test/TrueTest.php',
        'Twig\\Node\\Expression\\Unary\\AbstractUnary' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Unary/AbstractUnary.php',
        'Twig\\Node\\Expression\\Unary\\NegUnary' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Unary/NegUnary.php',
        'Twig\\Node\\Expression\\Unary\\NotUnary' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Unary/NotUnary.php',
        'Twig\\Node\\Expression\\Unary\\PosUnary' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Unary/PosUnary.php',
        'Twig\\Node\\Expression\\Unary\\SpreadUnary' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Unary/SpreadUnary.php',
        'Twig\\Node\\Expression\\Unary\\StringCastUnary' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Unary/StringCastUnary.php',
        'Twig\\Node\\Expression\\Unary\\UnaryInterface' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Unary/UnaryInterface.php',
        'Twig\\Node\\Expression\\Variable\\AssignContextVariable' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Variable/AssignContextVariable.php',
        'Twig\\Node\\Expression\\Variable\\AssignTemplateVariable' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Variable/AssignTemplateVariable.php',
        'Twig\\Node\\Expression\\Variable\\ContextVariable' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Variable/ContextVariable.php',
        'Twig\\Node\\Expression\\Variable\\LocalVariable' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Variable/LocalVariable.php',
        'Twig\\Node\\Expression\\Variable\\TemplateVariable' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/Variable/TemplateVariable.php',
        'Twig\\Node\\Expression\\VariadicExpression' => __DIR__ . '/..' . '/twig/twig/src/Node/Expression/VariadicExpression.php',
        'Twig\\Node\\FlushNode' => __DIR__ . '/..' . '/twig/twig/src/Node/FlushNode.php',
        'Twig\\Node\\ForElseNode' => __DIR__ . '/..' . '/twig/twig/src/Node/ForElseNode.php',
        'Twig\\Node\\ForLoopNode' => __DIR__ . '/..' . '/twig/twig/src/Node/ForLoopNode.php',
        'Twig\\Node\\ForNode' => __DIR__ . '/..' . '/twig/twig/src/Node/ForNode.php',
        'Twig\\Node\\IfNode' => __DIR__ . '/..' . '/twig/twig/src/Node/IfNode.php',
        'Twig\\Node\\ImportNode' => __DIR__ . '/..' . '/twig/twig/src/Node/ImportNode.php',
        'Twig\\Node\\IncludeNode' => __DIR__ . '/..' . '/twig/twig/src/Node/IncludeNode.php',
        'Twig\\Node\\MacroNode' => __DIR__ . '/..' . '/twig/twig/src/Node/MacroNode.php',
        'Twig\\Node\\ModuleNode' => __DIR__ . '/..' . '/twig/twig/src/Node/ModuleNode.php',
        'Twig\\Node\\NameDeprecation' => __DIR__ . '/..' . '/twig/twig/src/Node/NameDeprecation.php',
        'Twig\\Node\\Node' => __DIR__ . '/..' . '/twig/twig/src/Node/Node.php',
        'Twig\\Node\\NodeCaptureInterface' => __DIR__ . '/..' . '/twig/twig/src/Node/NodeCaptureInterface.php',
        'Twig\\Node\\NodeOutputInterface' => __DIR__ . '/..' . '/twig/twig/src/Node/NodeOutputInterface.php',
        'Twig\\Node\\Nodes' => __DIR__ . '/..' . '/twig/twig/src/Node/Nodes.php',
        'Twig\\Node\\PrintNode' => __DIR__ . '/..' . '/twig/twig/src/Node/PrintNode.php',
        'Twig\\Node\\SandboxNode' => __DIR__ . '/..' . '/twig/twig/src/Node/SandboxNode.php',
        'Twig\\Node\\SetNode' => __DIR__ . '/..' . '/twig/twig/src/Node/SetNode.php',
        'Twig\\Node\\TextNode' => __DIR__ . '/..' . '/twig/twig/src/Node/TextNode.php',
        'Twig\\Node\\TypesNode' => __DIR__ . '/..' . '/twig/twig/src/Node/TypesNode.php',
        'Twig\\Node\\WithNode' => __DIR__ . '/..' . '/twig/twig/src/Node/WithNode.php',
        'Twig\\OperatorPrecedenceChange' => __DIR__ . '/..' . '/twig/twig/src/OperatorPrecedenceChange.php',
        'Twig\\Parser' => __DIR__ . '/..' . '/twig/twig/src/Parser.php',
        'Twig\\Profiler\\Dumper\\BaseDumper' => __DIR__ . '/..' . '/twig/twig/src/Profiler/Dumper/BaseDumper.php',
        'Twig\\Profiler\\Dumper\\BlackfireDumper' => __DIR__ . '/..' . '/twig/twig/src/Profiler/Dumper/BlackfireDumper.php',
        'Twig\\Profiler\\Dumper\\HtmlDumper' => __DIR__ . '/..' . '/twig/twig/src/Profiler/Dumper/HtmlDumper.php',
        'Twig\\Profiler\\Dumper\\TextDumper' => __DIR__ . '/..' . '/twig/twig/src/Profiler/Dumper/TextDumper.php',
        'Twig\\Profiler\\NodeVisitor\\ProfilerNodeVisitor' => __DIR__ . '/..' . '/twig/twig/src/Profiler/NodeVisitor/ProfilerNodeVisitor.php',
        'Twig\\Profiler\\Node\\EnterProfileNode' => __DIR__ . '/..' . '/twig/twig/src/Profiler/Node/EnterProfileNode.php',
        'Twig\\Profiler\\Node\\LeaveProfileNode' => __DIR__ . '/..' . '/twig/twig/src/Profiler/Node/LeaveProfileNode.php',
        'Twig\\Profiler\\Profile' => __DIR__ . '/..' . '/twig/twig/src/Profiler/Profile.php',
        'Twig\\RuntimeLoader\\ContainerRuntimeLoader' => __DIR__ . '/..' . '/twig/twig/src/RuntimeLoader/ContainerRuntimeLoader.php',
        'Twig\\RuntimeLoader\\FactoryRuntimeLoader' => __DIR__ . '/..' . '/twig/twig/src/RuntimeLoader/FactoryRuntimeLoader.php',
        'Twig\\RuntimeLoader\\RuntimeLoaderInterface' => __DIR__ . '/..' . '/twig/twig/src/RuntimeLoader/RuntimeLoaderInterface.php',
        'Twig\\Runtime\\EscaperRuntime' => __DIR__ . '/..' . '/twig/twig/src/Runtime/EscaperRuntime.php',
        'Twig\\Sandbox\\SecurityError' => __DIR__ . '/..' . '/twig/twig/src/Sandbox/SecurityError.php',
        'Twig\\Sandbox\\SecurityNotAllowedFilterError' => __DIR__ . '/..' . '/twig/twig/src/Sandbox/SecurityNotAllowedFilterError.php',
        'Twig\\Sandbox\\SecurityNotAllowedFunctionError' => __DIR__ . '/..' . '/twig/twig/src/Sandbox/SecurityNotAllowedFunctionError.php',
        'Twig\\Sandbox\\SecurityNotAllowedMethodError' => __DIR__ . '/..' . '/twig/twig/src/Sandbox/SecurityNotAllowedMethodError.php',
        'Twig\\Sandbox\\SecurityNotAllowedPropertyError' => __DIR__ . '/..' . '/twig/twig/src/Sandbox/SecurityNotAllowedPropertyError.php',
        'Twig\\Sandbox\\SecurityNotAllowedTagError' => __DIR__ . '/..' . '/twig/twig/src/Sandbox/SecurityNotAllowedTagError.php',
        'Twig\\Sandbox\\SecurityNotAllowedTestError' => __DIR__ . '/..' . '/twig/twig/src/Sandbox/SecurityNotAllowedTestError.php',
        'Twig\\Sandbox\\SecurityPolicy' => __DIR__ . '/..' . '/twig/twig/src/Sandbox/SecurityPolicy.php',
        'Twig\\Sandbox\\SecurityPolicyInterface' => __DIR__ . '/..' . '/twig/twig/src/Sandbox/SecurityPolicyInterface.php',
        'Twig\\Sandbox\\SourcePolicyInterface' => __DIR__ . '/..' . '/twig/twig/src/Sandbox/SourcePolicyInterface.php',
        'Twig\\Source' => __DIR__ . '/..' . '/twig/twig/src/Source.php',
        'Twig\\Template' => __DIR__ . '/..' . '/twig/twig/src/Template.php',
        'Twig\\TemplateWrapper' => __DIR__ . '/..' . '/twig/twig/src/TemplateWrapper.php',
        'Twig\\Test\\IntegrationTestCase' => __DIR__ . '/..' . '/twig/twig/src/Test/IntegrationTestCase.php',
        'Twig\\Test\\NodeTestCase' => __DIR__ . '/..' . '/twig/twig/src/Test/NodeTestCase.php',
        'Twig\\Token' => __DIR__ . '/..' . '/twig/twig/src/Token.php',
        'Twig\\TokenParser\\AbstractTokenParser' => __DIR__ . '/..' . '/twig/twig/src/TokenParser/AbstractTokenParser.php',
        'Twig\\TokenParser\\ApplyTokenParser' => __DIR__ . '/..' . '/twig/twig/src/TokenParser/ApplyTokenParser.php',
        'Twig\\TokenParser\\AutoEscapeTokenParser' => __DIR__ . '/..' . '/twig/twig/src/TokenParser/AutoEscapeTokenParser.php',
        'Twig\\TokenParser\\BlockTokenParser' => __DIR__ . '/..' . '/twig/twig/src/TokenParser/BlockTokenParser.php',
        'Twig\\TokenParser\\DeprecatedTokenParser' => __DIR__ . '/..' . '/twig/twig/src/TokenParser/DeprecatedTokenParser.php',
        'Twig\\TokenParser\\DoTokenParser' => __DIR__ . '/..' . '/twig/twig/src/TokenParser/DoTokenParser.php',
        'Twig\\TokenParser\\EmbedTokenParser' => __DIR__ . '/..' . '/twig/twig/src/TokenParser/EmbedTokenParser.php',
        'Twig\\TokenParser\\ExtendsTokenParser' => __DIR__ . '/..' . '/twig/twig/src/TokenParser/ExtendsTokenParser.php',
        'Twig\\TokenParser\\FlushTokenParser' => __DIR__ . '/..' . '/twig/twig/src/TokenParser/FlushTokenParser.php',
        'Twig\\TokenParser\\ForTokenParser' => __DIR__ . '/..' . '/twig/twig/src/TokenParser/ForTokenParser.php',
        'Twig\\TokenParser\\FromTokenParser' => __DIR__ . '/..' . '/twig/twig/src/TokenParser/FromTokenParser.php',
        'Twig\\TokenParser\\GuardTokenParser' => __DIR__ . '/..' . '/twig/twig/src/TokenParser/GuardTokenParser.php',
        'Twig\\TokenParser\\IfTokenParser' => __DIR__ . '/..' . '/twig/twig/src/TokenParser/IfTokenParser.php',
        'Twig\\TokenParser\\ImportTokenParser' => __DIR__ . '/..' . '/twig/twig/src/TokenParser/ImportTokenParser.php',
        'Twig\\TokenParser\\IncludeTokenParser' => __DIR__ . '/..' . '/twig/twig/src/TokenParser/IncludeTokenParser.php',
        'Twig\\TokenParser\\MacroTokenParser' => __DIR__ . '/..' . '/twig/twig/src/TokenParser/MacroTokenParser.php',
        'Twig\\TokenParser\\SandboxTokenParser' => __DIR__ . '/..' . '/twig/twig/src/TokenParser/SandboxTokenParser.php',
        'Twig\\TokenParser\\SetTokenParser' => __DIR__ . '/..' . '/twig/twig/src/TokenParser/SetTokenParser.php',
        'Twig\\TokenParser\\TokenParserInterface' => __DIR__ . '/..' . '/twig/twig/src/TokenParser/TokenParserInterface.php',
        'Twig\\TokenParser\\TypesTokenParser' => __DIR__ . '/..' . '/twig/twig/src/TokenParser/TypesTokenParser.php',
        'Twig\\TokenParser\\UseTokenParser' => __DIR__ . '/..' . '/twig/twig/src/TokenParser/UseTokenParser.php',
        'Twig\\TokenParser\\WithTokenParser' => __DIR__ . '/..' . '/twig/twig/src/TokenParser/WithTokenParser.php',
        'Twig\\TokenStream' => __DIR__ . '/..' . '/twig/twig/src/TokenStream.php',
        'Twig\\TwigCallableInterface' => __DIR__ . '/..' . '/twig/twig/src/TwigCallableInterface.php',
        'Twig\\TwigFilter' => __DIR__ . '/..' . '/twig/twig/src/TwigFilter.php',
        'Twig\\TwigFunction' => __DIR__ . '/..' . '/twig/twig/src/TwigFunction.php',
        'Twig\\TwigTest' => __DIR__ . '/..' . '/twig/twig/src/TwigTest.php',
        'Twig\\Util\\CallableArgumentsExtractor' => __DIR__ . '/..' . '/twig/twig/src/Util/CallableArgumentsExtractor.php',
        'Twig\\Util\\CallableParameters' => __DIR__ . '/..' . '/twig/twig/src/Util/CallableParameters.php',
        'Twig\\Util\\DeprecationCollector' => __DIR__ . '/..' . '/twig/twig/src/Util/DeprecationCollector.php',
        'Twig\\Util\\ReflectionCallable' => __DIR__ . '/..' . '/twig/twig/src/Util/ReflectionCallable.php',
        'Twig\\Util\\TemplateDirIterator' => __DIR__ . '/..' . '/twig/twig/src/Util/TemplateDirIterator.php',
        'UnhandledMatchError' => __DIR__ . '/..' . '/symfony/polyfill-php80/Resources/stubs/UnhandledMatchError.php',
        'ValueError' => __DIR__ . '/..' . '/symfony/polyfill-php80/Resources/stubs/ValueError.php',
        'Webmozart\\Assert\\Assert' => __DIR__ . '/..' . '/webmozart/assert/src/Assert.php',
        'Webmozart\\Assert\\InvalidArgumentException' => __DIR__ . '/..' . '/webmozart/assert/src/InvalidArgumentException.php',
        'Webmozart\\Assert\\Mixin' => __DIR__ . '/..' . '/webmozart/assert/src/Mixin.php',
        '©' => __DIR__ . '/..' . '/symfony/cache/Traits/ValueWrapper.php',
    );

    public static function getInitializer(ClassLoader $loader)
    {
        return \Closure::bind(function () use ($loader) {
            $loader->prefixLengthsPsr4 = ComposerStaticInit507d84c131cfddd27aaafdb45bfc7db8::$prefixLengthsPsr4;
            $loader->prefixDirsPsr4 = ComposerStaticInit507d84c131cfddd27aaafdb45bfc7db8::$prefixDirsPsr4;
            $loader->classMap = ComposerStaticInit507d84c131cfddd27aaafdb45bfc7db8::$classMap;

        }, null, ClassLoader::class);
    }
}
