<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'maghahalikan: tao, tao, light na kulay ng balat, katamtamang light na kulay ng balat',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'maghahalikan: tao, tao, light na kulay ng balat, katamtamang kulay ng balat',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'maghahalikan: tao, tao, light na kulay ng balat, katamtamang dark na kulay ng balat',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'maghahalikan: tao, tao, light na kulay ng balat, dark na kulay ng balat',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'maghahalikan: tao, tao, katamtamang light na kulay ng balat, light na kulay ng balat',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'maghahalikan: tao, tao, katamtamang light na kulay ng balat, katamtamang kulay ng balat',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'maghahalikan: tao, tao, katamtamang light na kulay ng balat, katamtamang dark na kulay ng balat',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'maghahalikan: tao, tao, katamtamang light na kulay ng balat, dark na kulay ng balat',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'maghahalikan: tao, tao, katamtamang kulay ng balat, light na kulay ng balat',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'maghahalikan: tao, tao, katamtamang kulay ng balat, katamtamang light na kulay ng balat',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'maghahalikan: tao, tao, katamtamang kulay ng balat, katamtamang dark na kulay ng balat',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'maghahalikan: tao, tao, katamtamang kulay ng balat, dark na kulay ng balat',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'maghahalikan: tao, tao, katamtamang dark na kulay ng balat, light na kulay ng balat',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'maghahalikan: tao, tao, katamtamang dark na kulay ng balat, katamtamang light na kulay ng balat',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'maghahalikan: tao, tao, katamtamang dark na kulay ng balat, katamtamang kulay ng balat',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'maghahalikan: tao, tao, katamtamang dark na kulay ng balat, dark na kulay ng balat',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'maghahalikan: tao, tao, dark na kulay ng balat, light na kulay ng balat',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'maghahalikan: tao, tao, dark na kulay ng balat, katamtamang light na kulay ng balat',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'maghahalikan: tao, tao, dark na kulay ng balat, katamtamang kulay ng balat',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'maghahalikan: tao, tao, dark na kulay ng balat, katamtamang dark na kulay ng balat',
    '👨🏻‍❤‍💋‍👨🏻' => 'maghahalikan: lalaki, lalaki, light na kulay ng balat',
    '👨🏻‍❤‍💋‍👨🏼' => 'maghahalikan: lalaki, lalaki, light na kulay ng balat, katamtamang light na kulay ng balat',
    '👨🏻‍❤‍💋‍👨🏽' => 'maghahalikan: lalaki, lalaki, light na kulay ng balat, katamtamang kulay ng balat',
    '👨🏻‍❤‍💋‍👨🏾' => 'maghahalikan: lalaki, lalaki, light na kulay ng balat, katamtamang dark na kulay ng balat',
    '👨🏻‍❤‍💋‍👨🏿' => 'maghahalikan: lalaki, lalaki, light na kulay ng balat, dark na kulay ng balat',
    '👨🏼‍❤‍💋‍👨🏻' => 'maghahalikan: lalaki, lalaki, katamtamang light na kulay ng balat, light na kulay ng balat',
    '👨🏼‍❤‍💋‍👨🏼' => 'maghahalikan: lalaki, lalaki, katamtamang light na kulay ng balat',
    '👨🏼‍❤‍💋‍👨🏽' => 'maghahalikan: lalaki, lalaki, katamtamang light na kulay ng balat, katamtamang kulay ng balat',
    '👨🏼‍❤‍💋‍👨🏾' => 'maghahalikan: lalaki, lalaki, katamtamang light na kulay ng balat, katamtamang dark na kulay ng balat',
    '👨🏼‍❤‍💋‍👨🏿' => 'maghahalikan: lalaki, lalaki, katamtamang light na kulay ng balat, dark na kulay ng balat',
    '👨🏽‍❤‍💋‍👨🏻' => 'maghahalikan: lalaki, lalaki, katamtamang kulay ng balat, light na kulay ng balat',
    '👨🏽‍❤‍💋‍👨🏼' => 'maghahalikan: lalaki, lalaki, katamtamang kulay ng balat, katamtamang light na kulay ng balat',
    '👨🏽‍❤‍💋‍👨🏽' => 'maghahalikan: lalaki, lalaki, katamtamang kulay ng balat',
    '👨🏽‍❤‍💋‍👨🏾' => 'maghahalikan: lalaki, lalaki, katamtamang kulay ng balat, katamtamang dark na kulay ng balat',
    '👨🏽‍❤‍💋‍👨🏿' => 'maghahalikan: lalaki, lalaki, katamtamang kulay ng balat, dark na kulay ng balat',
    '👨🏾‍❤‍💋‍👨🏻' => 'maghahalikan: lalaki, lalaki, katamtamang dark na kulay ng balat, light na kulay ng balat',
    '👨🏾‍❤‍💋‍👨🏼' => 'maghahalikan: lalaki, lalaki, katamtamang dark na kulay ng balat, katamtamang light na kulay ng balat',
    '👨🏾‍❤‍💋‍👨🏽' => 'maghahalikan: lalaki, lalaki, katamtamang dark na kulay ng balat, katamtamang kulay ng balat',
    '👨🏾‍❤‍💋‍👨🏾' => 'maghahalikan: lalaki, lalaki, katamtamang dark na kulay ng balat',
    '👨🏾‍❤‍💋‍👨🏿' => 'maghahalikan: lalaki, lalaki, katamtamang dark na kulay ng balat, dark na kulay ng balat',
    '👨🏿‍❤‍💋‍👨🏻' => 'maghahalikan: lalaki, lalaki, dark na kulay ng balat, light na kulay ng balat',
    '👨🏿‍❤‍💋‍👨🏼' => 'maghahalikan: lalaki, lalaki, dark na kulay ng balat, katamtamang light na kulay ng balat',
    '👨🏿‍❤‍💋‍👨🏽' => 'maghahalikan: lalaki, lalaki, dark na kulay ng balat, katamtamang kulay ng balat',
    '👨🏿‍❤‍💋‍👨🏾' => 'maghahalikan: lalaki, lalaki, dark na kulay ng balat, katamtamang dark na kulay ng balat',
    '👨🏿‍❤‍💋‍👨🏿' => 'maghahalikan: lalaki, lalaki, dark na kulay ng balat',
    '👩🏻‍❤‍💋‍👨🏻' => 'maghahalikan: babae, lalaki, light na kulay ng balat',
    '👩🏻‍❤‍💋‍👨🏼' => 'maghahalikan: babae, lalaki, light na kulay ng balat, katamtamang light na kulay ng balat',
    '👩🏻‍❤‍💋‍👨🏽' => 'maghahalikan: babae, lalaki, light na kulay ng balat, katamtamang kulay ng balat',
    '👩🏻‍❤‍💋‍👨🏾' => 'maghahalikan: babae, lalaki, light na kulay ng balat, katamtamang dark na kulay ng balat',
    '👩🏻‍❤‍💋‍👨🏿' => 'maghahalikan: babae, lalaki, light na kulay ng balat, dark na kulay ng balat',
    '👩🏼‍❤‍💋‍👨🏻' => 'maghahalikan: babae, lalaki, katamtamang light na kulay ng balat, light na kulay ng balat',
    '👩🏼‍❤‍💋‍👨🏼' => 'maghahalikan: babae, lalaki, katamtamang light na kulay ng balat',
    '👩🏼‍❤‍💋‍👨🏽' => 'maghahalikan: babae, lalaki, katamtamang light na kulay ng balat, katamtamang kulay ng balat',
    '👩🏼‍❤‍💋‍👨🏾' => 'maghahalikan: babae, lalaki, katamtamang light na kulay ng balat, katamtamang dark na kulay ng balat',
    '👩🏼‍❤‍💋‍👨🏿' => 'maghahalikan: babae, lalaki, katamtamang light na kulay ng balat, dark na kulay ng balat',
    '👩🏽‍❤‍💋‍👨🏻' => 'maghahalikan: babae, lalaki, katamtamang kulay ng balat, light na kulay ng balat',
    '👩🏽‍❤‍💋‍👨🏼' => 'maghahalikan: babae, lalaki, katamtamang kulay ng balat, katamtamang light na kulay ng balat',
    '👩🏽‍❤‍💋‍👨🏽' => 'maghahalikan: babae, lalaki, katamtamang kulay ng balat',
    '👩🏽‍❤‍💋‍👨🏾' => 'maghahalikan: babae, lalaki, katamtamang kulay ng balat, katamtamang dark na kulay ng balat',
    '👩🏽‍❤‍💋‍👨🏿' => 'maghahalikan: babae, lalaki, katamtamang kulay ng balat, dark na kulay ng balat',
    '👩🏾‍❤‍💋‍👨🏻' => 'maghahalikan: babae, lalaki, katamtamang dark na kulay ng balat, light na kulay ng balat',
    '👩🏾‍❤‍💋‍👨🏼' => 'maghahalikan: babae, lalaki, katamtamang dark na kulay ng balat, katamtamang light na kulay ng balat',
    '👩🏾‍❤‍💋‍👨🏽' => 'maghahalikan: babae, lalaki, katamtamang dark na kulay ng balat, katamtamang kulay ng balat',
    '👩🏾‍❤‍💋‍👨🏾' => 'maghahalikan: babae, lalaki, katamtamang dark na kulay ng balat',
    '👩🏾‍❤‍💋‍👨🏿' => 'maghahalikan: babae, lalaki, katamtamang dark na kulay ng balat, dark na kulay ng balat',
    '👩🏿‍❤‍💋‍👨🏻' => 'maghahalikan: babae, lalaki, dark na kulay ng balat, light na kulay ng balat',
    '👩🏿‍❤‍💋‍👨🏼' => 'maghahalikan: babae, lalaki, dark na kulay ng balat, katamtamang light na kulay ng balat',
    '👩🏿‍❤‍💋‍👨🏽' => 'maghahalikan: babae, lalaki, dark na kulay ng balat, katamtamang kulay ng balat',
    '👩🏿‍❤‍💋‍👨🏾' => 'maghahalikan: babae, lalaki, dark na kulay ng balat, katamtamang dark na kulay ng balat',
    '👩🏿‍❤‍💋‍👨🏿' => 'maghahalikan: babae, lalaki, dark na kulay ng balat',
    '👩🏻‍❤‍💋‍👩🏻' => 'maghahalikan: babae, babae, light na kulay ng balat',
    '👩🏻‍❤‍💋‍👩🏼' => 'maghahalikan: babae, babae, light na kulay ng balat, katamtamang light na kulay ng balat',
    '👩🏻‍❤‍💋‍👩🏽' => 'maghahalikan: babae, babae, light na kulay ng balat, katamtamang kulay ng balat',
    '👩🏻‍❤‍💋‍👩🏾' => 'maghahalikan: babae, babae, light na kulay ng balat, katamtamang dark na kulay ng balat',
    '👩🏻‍❤‍💋‍👩🏿' => 'maghahalikan: babae, babae, light na kulay ng balat, dark na kulay ng balat',
    '👩🏼‍❤‍💋‍👩🏻' => 'maghahalikan: babae, babae, katamtamang light na kulay ng balat, light na kulay ng balat',
    '👩🏼‍❤‍💋‍👩🏼' => 'maghahalikan: babae, babae, katamtamang light na kulay ng balat',
    '👩🏼‍❤‍💋‍👩🏽' => 'maghahalikan: babae, babae, katamtamang light na kulay ng balat, katamtamang kulay ng balat',
    '👩🏼‍❤‍💋‍👩🏾' => 'maghahalikan: babae, babae, katamtamang light na kulay ng balat, katamtamang dark na kulay ng balat',
    '👩🏼‍❤‍💋‍👩🏿' => 'maghahalikan: babae, babae, katamtamang light na kulay ng balat, dark na kulay ng balat',
    '👩🏽‍❤‍💋‍👩🏻' => 'maghahalikan: babae, babae, katamtamang kulay ng balat, light na kulay ng balat',
    '👩🏽‍❤‍💋‍👩🏼' => 'maghahalikan: babae, babae, katamtamang kulay ng balat, katamtamang light na kulay ng balat',
    '👩🏽‍❤‍💋‍👩🏽' => 'maghahalikan: babae, babae, katamtamang kulay ng balat',
    '👩🏽‍❤‍💋‍👩🏾' => 'maghahalikan: babae, babae, katamtamang kulay ng balat, katamtamang dark na kulay ng balat',
    '👩🏽‍❤‍💋‍👩🏿' => 'maghahalikan: babae, babae, katamtamang kulay ng balat, dark na kulay ng balat',
    '👩🏾‍❤‍💋‍👩🏻' => 'maghahalikan: babae, babae, katamtamang dark na kulay ng balat, light na kulay ng balat',
    '👩🏾‍❤‍💋‍👩🏼' => 'maghahalikan: babae, babae, katamtamang dark na kulay ng balat, katamtamang light na kulay ng balat',
    '👩🏾‍❤‍💋‍👩🏽' => 'maghahalikan: babae, babae, katamtamang dark na kulay ng balat, katamtamang kulay ng balat',
    '👩🏾‍❤‍💋‍👩🏾' => 'maghahalikan: babae, babae, katamtamang dark na kulay ng balat',
    '👩🏾‍❤‍💋‍👩🏿' => 'maghahalikan: babae, babae, katamtamang dark na kulay ng balat, dark na kulay ng balat',
    '👩🏿‍❤‍💋‍👩🏻' => 'maghahalikan: babae, babae, dark na kulay ng balat, light na kulay ng balat',
    '👩🏿‍❤‍💋‍👩🏼' => 'maghahalikan: babae, babae, dark na kulay ng balat, katamtamang light na kulay ng balat',
    '👩🏿‍❤‍💋‍👩🏽' => 'maghahalikan: babae, babae, dark na kulay ng balat, katamtamang kulay ng balat',
    '👩🏿‍❤‍💋‍👩🏾' => 'maghahalikan: babae, babae, dark na kulay ng balat, katamtamang dark na kulay ng balat',
    '👩🏿‍❤‍💋‍👩🏿' => 'maghahalikan: babae, babae, dark na kulay ng balat',
    '🧑🏻‍🫯‍🧑🏼' => 'mga taong nagre-wrestling: light na kulay ng balat, katamtamang light na kulay ng balat',
    '🧑🏻‍🫯‍🧑🏽' => 'mga taong nagre-wrestling: light na kulay ng balat, katamtamang kulay ng balat',
    '🧑🏻‍🫯‍🧑🏾' => 'mga taong nagre-wrestling: light na kulay ng balat, katamtamang dark na kulay ng balat',
    '🧑🏻‍🫯‍🧑🏿' => 'mga taong nagre-wrestling: light na kulay ng balat, dark na kulay ng balat',
    '🧑🏼‍🫯‍🧑🏻' => 'mga taong nagre-wrestling: katamtamang light na kulay ng balat, light na kulay ng balat',
    '🧑🏼‍🫯‍🧑🏽' => 'mga taong nagre-wrestling: katamtamang light na kulay ng balat, katamtamang kulay ng balat',
    '🧑🏼‍🫯‍🧑🏾' => 'mga taong nagre-wrestling: katamtamang light na kulay ng balat, katamtamang dark na kulay ng balat',
    '🧑🏼‍🫯‍🧑🏿' => 'mga taong nagre-wrestling: katamtamang light na kulay ng balat, dark na kulay ng balat',
    '🧑🏽‍🫯‍🧑🏻' => 'mga taong nagre-wrestling: katamtamang kulay ng balat, light na kulay ng balat',
    '🧑🏽‍🫯‍🧑🏼' => 'mga taong nagre-wrestling: katamtamang kulay ng balat, katamtamang light na kulay ng balat',
    '🧑🏽‍🫯‍🧑🏾' => 'mga taong nagre-wrestling: katamtamang kulay ng balat, katamtamang dark na kulay ng balat',
    '🧑🏽‍🫯‍🧑🏿' => 'mga taong nagre-wrestling: katamtamang kulay ng balat, dark na kulay ng balat',
    '🧑🏾‍🫯‍🧑🏻' => 'mga taong nagre-wrestling: katamtamang dark na kulay ng balat, light na kulay ng balat',
    '🧑🏾‍🫯‍🧑🏼' => 'mga taong nagre-wrestling: katamtamang dark na kulay ng balat, katamtamang light na kulay ng balat',
    '🧑🏾‍🫯‍🧑🏽' => 'mga taong nagre-wrestling: katamtamang dark na kulay ng balat, katamtamang kulay ng balat',
    '🧑🏾‍🫯‍🧑🏿' => 'mga taong nagre-wrestling: katamtamang dark na kulay ng balat, dark na kulay ng balat',
    '🧑🏿‍🫯‍🧑🏻' => 'mga taong nagre-wrestling: dark na kulay ng balat, light na kulay ng balat',
    '🧑🏿‍🫯‍🧑🏼' => 'mga taong nagre-wrestling: dark na kulay ng balat, katamtamang light na kulay ng balat',
    '🧑🏿‍🫯‍🧑🏽' => 'mga taong nagre-wrestling: dark na kulay ng balat, katamtamang kulay ng balat',
    '🧑🏿‍🫯‍🧑🏾' => 'mga taong nagre-wrestling: dark na kulay ng balat, katamtamang dark na kulay ng balat',
    '🧑🏻‍❤‍🧑🏼' => 'magkapareha na may puso: tao, tao, light na kulay ng balat, katamtamang light na kulay ng balat',
    '🧑🏻‍❤‍🧑🏽' => 'magkapareha na may puso: tao, tao, light na kulay ng balat, katamtamang kulay ng balat',
    '🧑🏻‍❤‍🧑🏾' => 'magkapareha na may puso: tao, tao, light na kulay ng balat, katamtamang dark na kulay ng balat',
    '🧑🏻‍❤‍🧑🏿' => 'magkapareha na may puso: tao, tao, light na kulay ng balat, dark na kulay ng balat',
    '🧑🏼‍❤‍🧑🏻' => 'magkapareha na may puso: tao, tao, katamtamang light na kulay ng balat, light na kulay ng balat',
    '🧑🏼‍❤‍🧑🏽' => 'magkapareha na may puso: tao, tao, katamtamang light na kulay ng balat, katamtamang kulay ng balat',
    '🧑🏼‍❤‍🧑🏾' => 'magkapareha na may puso: tao, tao, katamtamang light na kulay ng balat, katamtamang dark na kulay ng balat',
    '🧑🏼‍❤‍🧑🏿' => 'magkapareha na may puso: tao, tao, katamtamang light na kulay ng balat, dark na kulay ng balat',
    '🧑🏽‍❤‍🧑🏻' => 'magkapareha na may puso: tao, tao, katamtamang kulay ng balat, light na kulay ng balat',
    '🧑🏽‍❤‍🧑🏼' => 'magkapareha na may puso: tao, tao, katamtamang kulay ng balat, katamtamang light na kulay ng balat',
    '🧑🏽‍❤‍🧑🏾' => 'magkapareha na may puso: tao, tao, katamtamang kulay ng balat, katamtamang dark na kulay ng balat',
    '🧑🏽‍❤‍🧑🏿' => 'magkapareha na may puso: tao, tao, katamtamang kulay ng balat, dark na kulay ng balat',
    '🧑🏾‍❤‍🧑🏻' => 'magkapareha na may puso: tao, tao, katamtamang dark na kulay ng balat, light na kulay ng balat',
    '🧑🏾‍❤‍🧑🏼' => 'magkapareha na may puso: tao, tao, katamtamang dark na kulay ng balat, katamtamang light na kulay ng balat',
    '🧑🏾‍❤‍🧑🏽' => 'magkapareha na may puso: tao, tao, katamtamang dark na kulay ng balat, katamtamang kulay ng balat',
    '🧑🏾‍❤‍🧑🏿' => 'magkapareha na may puso: tao, tao, katamtamang dark na kulay ng balat, dark na kulay ng balat',
    '🧑🏿‍❤‍🧑🏻' => 'magkapareha na may puso: tao, tao, dark na kulay ng balat, light na kulay ng balat',
    '🧑🏿‍❤‍🧑🏼' => 'magkapareha na may puso: tao, tao, dark na kulay ng balat, katamtamang light na kulay ng balat',
    '🧑🏿‍❤‍🧑🏽' => 'magkapareha na may puso: tao, tao, dark na kulay ng balat, katamtamang kulay ng balat',
    '🧑🏿‍❤‍🧑🏾' => 'magkapareha na may puso: tao, tao, dark na kulay ng balat, katamtamang dark na kulay ng balat',
    '🧑🏻‍🐰‍🧑🏼' => 'mga babaeng may tainga ng kuneho: light na kulay ng balat, katamtamang light na kulay ng balat',
    '🧑🏻‍🐰‍🧑🏽' => 'mga babaeng may tainga ng kuneho: light na kulay ng balat, katamtamang kulay ng balat',
    '🧑🏻‍🐰‍🧑🏾' => 'mga babaeng may tainga ng kuneho: light na kulay ng balat, katamtamang dark na kulay ng balat',
    '🧑🏻‍🐰‍🧑🏿' => 'mga babaeng may tainga ng kuneho: light na kulay ng balat, dark na kulay ng balat',
    '🧑🏼‍🐰‍🧑🏻' => 'mga babaeng may tainga ng kuneho: katamtamang light na kulay ng balat, light na kulay ng balat',
    '🧑🏼‍🐰‍🧑🏽' => 'mga babaeng may tainga ng kuneho: katamtamang light na kulay ng balat, katamtamang kulay ng balat',
    '🧑🏼‍🐰‍🧑🏾' => 'mga babaeng may tainga ng kuneho: katamtamang light na kulay ng balat, katamtamang dark na kulay ng balat',
    '🧑🏼‍🐰‍🧑🏿' => 'mga babaeng may tainga ng kuneho: katamtamang light na kulay ng balat, dark na kulay ng balat',
    '🧑🏽‍🐰‍🧑🏻' => 'mga babaeng may tainga ng kuneho: katamtamang kulay ng balat, light na kulay ng balat',
    '🧑🏽‍🐰‍🧑🏼' => 'mga babaeng may tainga ng kuneho: katamtamang kulay ng balat, katamtamang light na kulay ng balat',
    '🧑🏽‍🐰‍🧑🏾' => 'mga babaeng may tainga ng kuneho: katamtamang kulay ng balat, katamtamang dark na kulay ng balat',
    '🧑🏽‍🐰‍🧑🏿' => 'mga babaeng may tainga ng kuneho: katamtamang kulay ng balat, dark na kulay ng balat',
    '🧑🏾‍🐰‍🧑🏻' => 'mga babaeng may tainga ng kuneho: katamtamang dark na kulay ng balat, light na kulay ng balat',
    '🧑🏾‍🐰‍🧑🏼' => 'mga babaeng may tainga ng kuneho: katamtamang dark na kulay ng balat, katamtamang light na kulay ng balat',
    '🧑🏾‍🐰‍🧑🏽' => 'mga babaeng may tainga ng kuneho: katamtamang dark na kulay ng balat, katamtamang kulay ng balat',
    '🧑🏾‍🐰‍🧑🏿' => 'mga babaeng may tainga ng kuneho: katamtamang dark na kulay ng balat, dark na kulay ng balat',
    '🧑🏿‍🐰‍🧑🏻' => 'mga babaeng may tainga ng kuneho: dark na kulay ng balat, light na kulay ng balat',
    '🧑🏿‍🐰‍🧑🏼' => 'mga babaeng may tainga ng kuneho: dark na kulay ng balat, katamtamang light na kulay ng balat',
    '🧑🏿‍🐰‍🧑🏽' => 'mga babaeng may tainga ng kuneho: dark na kulay ng balat, katamtamang kulay ng balat',
    '🧑🏿‍🐰‍🧑🏾' => 'mga babaeng may tainga ng kuneho: dark na kulay ng balat, katamtamang dark na kulay ng balat',
    '👨🏻‍🫯‍👨🏼' => 'lalaking nakikipagbuno: light na kulay ng balat, katamtamang light na kulay ng balat',
    '👨🏻‍🫯‍👨🏽' => 'lalaking nakikipagbuno: light na kulay ng balat, katamtamang kulay ng balat',
    '👨🏻‍🫯‍👨🏾' => 'lalaking nakikipagbuno: light na kulay ng balat, katamtamang dark na kulay ng balat',
    '👨🏻‍🫯‍👨🏿' => 'lalaking nakikipagbuno: light na kulay ng balat, dark na kulay ng balat',
    '👨🏼‍🫯‍👨🏻' => 'lalaking nakikipagbuno: katamtamang light na kulay ng balat, light na kulay ng balat',
    '👨🏼‍🫯‍👨🏽' => 'lalaking nakikipagbuno: katamtamang light na kulay ng balat, katamtamang kulay ng balat',
    '👨🏼‍🫯‍👨🏾' => 'lalaking nakikipagbuno: katamtamang light na kulay ng balat, katamtamang dark na kulay ng balat',
    '👨🏼‍🫯‍👨🏿' => 'lalaking nakikipagbuno: katamtamang light na kulay ng balat, dark na kulay ng balat',
    '👨🏽‍🫯‍👨🏻' => 'lalaking nakikipagbuno: katamtamang kulay ng balat, light na kulay ng balat',
    '👨🏽‍🫯‍👨🏼' => 'lalaking nakikipagbuno: katamtamang kulay ng balat, katamtamang light na kulay ng balat',
    '👨🏽‍🫯‍👨🏾' => 'lalaking nakikipagbuno: katamtamang kulay ng balat, katamtamang dark na kulay ng balat',
    '👨🏽‍🫯‍👨🏿' => 'lalaking nakikipagbuno: katamtamang kulay ng balat, dark na kulay ng balat',
    '👨🏾‍🫯‍👨🏻' => 'lalaking nakikipagbuno: katamtamang dark na kulay ng balat, light na kulay ng balat',
    '👨🏾‍🫯‍👨🏼' => 'lalaking nakikipagbuno: katamtamang dark na kulay ng balat, katamtamang light na kulay ng balat',
    '👨🏾‍🫯‍👨🏽' => 'lalaking nakikipagbuno: katamtamang dark na kulay ng balat, katamtamang kulay ng balat',
    '👨🏾‍🫯‍👨🏿' => 'lalaking nakikipagbuno: katamtamang dark na kulay ng balat, dark na kulay ng balat',
    '👨🏿‍🫯‍👨🏻' => 'lalaking nakikipagbuno: dark na kulay ng balat, light na kulay ng balat',
    '👨🏿‍🫯‍👨🏼' => 'lalaking nakikipagbuno: dark na kulay ng balat, katamtamang light na kulay ng balat',
    '👨🏿‍🫯‍👨🏽' => 'lalaking nakikipagbuno: dark na kulay ng balat, katamtamang kulay ng balat',
    '👨🏿‍🫯‍👨🏾' => 'lalaking nakikipagbuno: dark na kulay ng balat, katamtamang dark na kulay ng balat',
    '👨🏻‍❤‍👨🏻' => 'magkapareha na may puso: lalaki, lalaki, light na kulay ng balat',
    '👨🏻‍❤‍👨🏼' => 'magkapareha na may puso: lalaki, lalaki, light na kulay ng balat, katamtamang light na kulay ng balat',
    '👨🏻‍❤‍👨🏽' => 'magkapareha na may puso: lalaki, lalaki, light na kulay ng balat, katamtamang kulay ng balat',
    '👨🏻‍❤‍👨🏾' => 'magkapareha na may puso: lalaki, lalaki, light na kulay ng balat, katamtamang dark na kulay ng balat',
    '👨🏻‍❤‍👨🏿' => 'magkapareha na may puso: lalaki, lalaki, light na kulay ng balat, dark na kulay ng balat',
    '👨🏼‍❤‍👨🏻' => 'magkapareha na may puso: lalaki, lalaki, katamtamang light na kulay ng balat, light na kulay ng balat',
    '👨🏼‍❤‍👨🏼' => 'magkapareha na may puso: lalaki, lalaki, katamtamang light na kulay ng balat',
    '👨🏼‍❤‍👨🏽' => 'magkapareha na may puso: lalaki, lalaki, katamtamang light na kulay ng balat, katamtamang kulay ng balat',
    '👨🏼‍❤‍👨🏾' => 'magkapareha na may puso: lalaki, lalaki, katamtamang light na kulay ng balat, katamtamang dark na kulay ng balat',
    '👨🏼‍❤‍👨🏿' => 'magkapareha na may puso: lalaki, lalaki, katamtamang light na kulay ng balat, dark na kulay ng balat',
    '👨🏽‍❤‍👨🏻' => 'magkapareha na may puso: lalaki, lalaki, katamtamang kulay ng balat, light na kulay ng balat',
    '👨🏽‍❤‍👨🏼' => 'magkapareha na may puso: lalaki, lalaki, katamtamang kulay ng balat, katamtamang light na kulay ng balat',
    '👨🏽‍❤‍👨🏽' => 'magkapareha na may puso: lalaki, lalaki, katamtamang kulay ng balat',
    '👨🏽‍❤‍👨🏾' => 'magkapareha na may puso: lalaki, lalaki, katamtamang kulay ng balat, katamtamang dark na kulay ng balat',
    '👨🏽‍❤‍👨🏿' => 'magkapareha na may puso: lalaki, lalaki, katamtamang kulay ng balat, dark na kulay ng balat',
    '👨🏾‍❤‍👨🏻' => 'magkapareha na may puso: lalaki, lalaki, katamtamang dark na kulay ng balat, light na kulay ng balat',
    '👨🏾‍❤‍👨🏼' => 'magkapareha na may puso: lalaki, lalaki, katamtamang dark na kulay ng balat, katamtamang light na kulay ng balat',
    '👨🏾‍❤‍👨🏽' => 'magkapareha na may puso: lalaki, lalaki, katamtamang dark na kulay ng balat, katamtamang kulay ng balat',
    '👨🏾‍❤‍👨🏾' => 'magkapareha na may puso: lalaki, lalaki, katamtamang dark na kulay ng balat',
    '👨🏾‍❤‍👨🏿' => 'magkapareha na may puso: lalaki, lalaki, katamtamang dark na kulay ng balat, dark na kulay ng balat',
    '👨🏿‍❤‍👨🏻' => 'magkapareha na may puso: lalaki, lalaki, dark na kulay ng balat, light na kulay ng balat',
    '👨🏿‍❤‍👨🏼' => 'magkapareha na may puso: lalaki, lalaki, dark na kulay ng balat, katamtamang light na kulay ng balat',
    '👨🏿‍❤‍👨🏽' => 'magkapareha na may puso: lalaki, lalaki, dark na kulay ng balat, katamtamang kulay ng balat',
    '👨🏿‍❤‍👨🏾' => 'magkapareha na may puso: lalaki, lalaki, dark na kulay ng balat, katamtamang dark na kulay ng balat',
    '👨🏿‍❤‍👨🏿' => 'magkapareha na may puso: lalaki, lalaki, dark na kulay ng balat',
    '👨🏻‍🐰‍👨🏼' => 'mga lalaking may tainga ng kuneho: light na kulay ng balat, katamtamang light na kulay ng balat',
    '👨🏻‍🐰‍👨🏽' => 'mga lalaking may tainga ng kuneho: light na kulay ng balat, katamtamang kulay ng balat',
    '👨🏻‍🐰‍👨🏾' => 'mga lalaking may tainga ng kuneho: light na kulay ng balat, katamtamang dark na kulay ng balat',
    '👨🏻‍🐰‍👨🏿' => 'mga lalaking may tainga ng kuneho: light na kulay ng balat, dark na kulay ng balat',
    '👨🏼‍🐰‍👨🏻' => 'mga lalaking may tainga ng kuneho: katamtamang light na kulay ng balat, light na kulay ng balat',
    '👨🏼‍🐰‍👨🏽' => 'mga lalaking may tainga ng kuneho: katamtamang light na kulay ng balat, katamtamang kulay ng balat',
    '👨🏼‍🐰‍👨🏾' => 'mga lalaking may tainga ng kuneho: katamtamang light na kulay ng balat, katamtamang dark na kulay ng balat',
    '👨🏼‍🐰‍👨🏿' => 'mga lalaking may tainga ng kuneho: katamtamang light na kulay ng balat, dark na kulay ng balat',
    '👨🏽‍🐰‍👨🏻' => 'mga lalaking may tainga ng kuneho: katamtamang kulay ng balat, light na kulay ng balat',
    '👨🏽‍🐰‍👨🏼' => 'mga lalaking may tainga ng kuneho: katamtamang kulay ng balat, katamtamang light na kulay ng balat',
    '👨🏽‍🐰‍👨🏾' => 'mga lalaking may tainga ng kuneho: katamtamang kulay ng balat, katamtamang dark na kulay ng balat',
    '👨🏽‍🐰‍👨🏿' => 'mga lalaking may tainga ng kuneho: katamtamang kulay ng balat, dark na kulay ng balat',
    '👨🏾‍🐰‍👨🏻' => 'mga lalaking may tainga ng kuneho: katamtamang dark na kulay ng balat, light na kulay ng balat',
    '👨🏾‍🐰‍👨🏼' => 'mga lalaking may tainga ng kuneho: katamtamang dark na kulay ng balat, katamtamang light na kulay ng balat',
    '👨🏾‍🐰‍👨🏽' => 'mga lalaking may tainga ng kuneho: katamtamang dark na kulay ng balat, katamtamang kulay ng balat',
    '👨🏾‍🐰‍👨🏿' => 'mga lalaking may tainga ng kuneho: katamtamang dark na kulay ng balat, dark na kulay ng balat',
    '👨🏿‍🐰‍👨🏻' => 'mga lalaking may tainga ng kuneho: dark na kulay ng balat, light na kulay ng balat',
    '👨🏿‍🐰‍👨🏼' => 'mga lalaking may tainga ng kuneho: dark na kulay ng balat, katamtamang light na kulay ng balat',
    '👨🏿‍🐰‍👨🏽' => 'mga lalaking may tainga ng kuneho: dark na kulay ng balat, katamtamang kulay ng balat',
    '👨🏿‍🐰‍👨🏾' => 'mga lalaking may tainga ng kuneho: dark na kulay ng balat, katamtamang dark na kulay ng balat',
    '👩🏻‍🫯‍👩🏼' => 'babaeng nakikipagbuno: light na kulay ng balat, katamtamang light na kulay ng balat',
    '👩🏻‍🫯‍👩🏽' => 'babaeng nakikipagbuno: light na kulay ng balat, katamtamang kulay ng balat',
    '👩🏻‍🫯‍👩🏾' => 'babaeng nakikipagbuno: light na kulay ng balat, katamtamang dark na kulay ng balat',
    '👩🏻‍🫯‍👩🏿' => 'babaeng nakikipagbuno: light na kulay ng balat, dark na kulay ng balat',
    '👩🏼‍🫯‍👩🏻' => 'babaeng nakikipagbuno: katamtamang light na kulay ng balat, light na kulay ng balat',
    '👩🏼‍🫯‍👩🏽' => 'babaeng nakikipagbuno: katamtamang light na kulay ng balat, katamtamang kulay ng balat',
    '👩🏼‍🫯‍👩🏾' => 'babaeng nakikipagbuno: katamtamang light na kulay ng balat, katamtamang dark na kulay ng balat',
    '👩🏼‍🫯‍👩🏿' => 'babaeng nakikipagbuno: katamtamang light na kulay ng balat, dark na kulay ng balat',
    '👩🏽‍🫯‍👩🏻' => 'babaeng nakikipagbuno: katamtamang kulay ng balat, light na kulay ng balat',
    '👩🏽‍🫯‍👩🏼' => 'babaeng nakikipagbuno: katamtamang kulay ng balat, katamtamang light na kulay ng balat',
    '👩🏽‍🫯‍👩🏾' => 'babaeng nakikipagbuno: katamtamang kulay ng balat, katamtamang dark na kulay ng balat',
    '👩🏽‍🫯‍👩🏿' => 'babaeng nakikipagbuno: katamtamang kulay ng balat, dark na kulay ng balat',
    '👩🏾‍🫯‍👩🏻' => 'babaeng nakikipagbuno: katamtamang dark na kulay ng balat, light na kulay ng balat',
    '👩🏾‍🫯‍👩🏼' => 'babaeng nakikipagbuno: katamtamang dark na kulay ng balat, katamtamang light na kulay ng balat',
    '👩🏾‍🫯‍👩🏽' => 'babaeng nakikipagbuno: katamtamang dark na kulay ng balat, katamtamang kulay ng balat',
    '👩🏾‍🫯‍👩🏿' => 'babaeng nakikipagbuno: katamtamang dark na kulay ng balat, dark na kulay ng balat',
    '👩🏿‍🫯‍👩🏻' => 'babaeng nakikipagbuno: dark na kulay ng balat, light na kulay ng balat',
    '👩🏿‍🫯‍👩🏼' => 'babaeng nakikipagbuno: dark na kulay ng balat, katamtamang light na kulay ng balat',
    '👩🏿‍🫯‍👩🏽' => 'babaeng nakikipagbuno: dark na kulay ng balat, katamtamang kulay ng balat',
    '👩🏿‍🫯‍👩🏾' => 'babaeng nakikipagbuno: dark na kulay ng balat, katamtamang dark na kulay ng balat',
    '👩🏻‍❤‍👨🏻' => 'magkapareha na may puso: babae, lalaki, light na kulay ng balat',
    '👩🏻‍❤‍👨🏼' => 'magkapareha na may puso: babae, lalaki, light na kulay ng balat, katamtamang light na kulay ng balat',
    '👩🏻‍❤‍👨🏽' => 'magkapareha na may puso: babae, lalaki, light na kulay ng balat, katamtamang kulay ng balat',
    '👩🏻‍❤‍👨🏾' => 'magkapareha na may puso: babae, lalaki, light na kulay ng balat, katamtamang dark na kulay ng balat',
    '👩🏻‍❤‍👨🏿' => 'magkapareha na may puso: babae, lalaki, light na kulay ng balat, dark na kulay ng balat',
    '👩🏼‍❤‍👨🏻' => 'magkapareha na may puso: babae, lalaki, katamtamang light na kulay ng balat, light na kulay ng balat',
    '👩🏼‍❤‍👨🏼' => 'magkapareha na may puso: babae, lalaki, katamtamang light na kulay ng balat',
    '👩🏼‍❤‍👨🏽' => 'magkapareha na may puso: babae, lalaki, katamtamang light na kulay ng balat, katamtamang kulay ng balat',
    '👩🏼‍❤‍👨🏾' => 'magkapareha na may puso: babae, lalaki, katamtamang light na kulay ng balat, katamtamang dark na kulay ng balat',
    '👩🏼‍❤‍👨🏿' => 'magkapareha na may puso: babae, lalaki, katamtamang light na kulay ng balat, dark na kulay ng balat',
    '👩🏽‍❤‍👨🏻' => 'magkapareha na may puso: babae, lalaki, katamtamang kulay ng balat, light na kulay ng balat',
    '👩🏽‍❤‍👨🏼' => 'magkapareha na may puso: babae, lalaki, katamtamang kulay ng balat, katamtamang light na kulay ng balat',
    '👩🏽‍❤‍👨🏽' => 'magkapareha na may puso: babae, lalaki, katamtamang kulay ng balat',
    '👩🏽‍❤‍👨🏾' => 'magkapareha na may puso: babae, lalaki, katamtamang kulay ng balat, katamtamang dark na kulay ng balat',
    '👩🏽‍❤‍👨🏿' => 'magkapareha na may puso: babae, lalaki, katamtamang kulay ng balat, dark na kulay ng balat',
    '👩🏾‍❤‍👨🏻' => 'magkapareha na may puso: babae, lalaki, katamtamang dark na kulay ng balat, light na kulay ng balat',
    '👩🏾‍❤‍👨🏼' => 'magkapareha na may puso: babae, lalaki, katamtamang dark na kulay ng balat, katamtamang light na kulay ng balat',
    '👩🏾‍❤‍👨🏽' => 'magkapareha na may puso: babae, lalaki, katamtamang dark na kulay ng balat, katamtamang kulay ng balat',
    '👩🏾‍❤‍👨🏾' => 'magkapareha na may puso: babae, lalaki, katamtamang dark na kulay ng balat',
    '👩🏾‍❤‍👨🏿' => 'magkapareha na may puso: babae, lalaki, katamtamang dark na kulay ng balat, dark na kulay ng balat',
    '👩🏿‍❤‍👨🏻' => 'magkapareha na may puso: babae, lalaki, dark na kulay ng balat, light na kulay ng balat',
    '👩🏿‍❤‍👨🏼' => 'magkapareha na may puso: babae, lalaki, dark na kulay ng balat, katamtamang light na kulay ng balat',
    '👩🏿‍❤‍👨🏽' => 'magkapareha na may puso: babae, lalaki, dark na kulay ng balat, katamtamang kulay ng balat',
    '👩🏿‍❤‍👨🏾' => 'magkapareha na may puso: babae, lalaki, dark na kulay ng balat, katamtamang dark na kulay ng balat',
    '👩🏿‍❤‍👨🏿' => 'magkapareha na may puso: babae, lalaki, dark na kulay ng balat',
    '👩🏻‍❤‍👩🏻' => 'magkapareha na may puso: babae, babae, light na kulay ng balat',
    '👩🏻‍❤‍👩🏼' => 'magkapareha na may puso: babae, babae, light na kulay ng balat, katamtamang light na kulay ng balat',
    '👩🏻‍❤‍👩🏽' => 'magkapareha na may puso: babae, babae, light na kulay ng balat, katamtamang kulay ng balat',
    '👩🏻‍❤‍👩🏾' => 'magkapareha na may puso: babae, babae, light na kulay ng balat, katamtamang dark na kulay ng balat',
    '👩🏻‍❤‍👩🏿' => 'magkapareha na may puso: babae, babae, light na kulay ng balat, dark na kulay ng balat',
    '👩🏼‍❤‍👩🏻' => 'magkapareha na may puso: babae, babae, katamtamang light na kulay ng balat, light na kulay ng balat',
    '👩🏼‍❤‍👩🏼' => 'magkapareha na may puso: babae, babae, katamtamang light na kulay ng balat',
    '👩🏼‍❤‍👩🏽' => 'magkapareha na may puso: babae, babae, katamtamang light na kulay ng balat, katamtamang kulay ng balat',
    '👩🏼‍❤‍👩🏾' => 'magkapareha na may puso: babae, babae, katamtamang light na kulay ng balat, katamtamang dark na kulay ng balat',
    '👩🏼‍❤‍👩🏿' => 'magkapareha na may puso: babae, babae, katamtamang light na kulay ng balat, dark na kulay ng balat',
    '👩🏽‍❤‍👩🏻' => 'magkapareha na may puso: babae, babae, katamtamang kulay ng balat, light na kulay ng balat',
    '👩🏽‍❤‍👩🏼' => 'magkapareha na may puso: babae, babae, katamtamang kulay ng balat, katamtamang light na kulay ng balat',
    '👩🏽‍❤‍👩🏽' => 'magkapareha na may puso: babae, babae, katamtamang kulay ng balat',
    '👩🏽‍❤‍👩🏾' => 'magkapareha na may puso: babae, babae, katamtamang kulay ng balat, katamtamang dark na kulay ng balat',
    '👩🏽‍❤‍👩🏿' => 'magkapareha na may puso: babae, babae, katamtamang kulay ng balat, dark na kulay ng balat',
    '👩🏾‍❤‍👩🏻' => 'magkapareha na may puso: babae, babae, katamtamang dark na kulay ng balat, light na kulay ng balat',
    '👩🏾‍❤‍👩🏼' => 'magkapareha na may puso: babae, babae, katamtamang dark na kulay ng balat, katamtamang light na kulay ng balat',
    '👩🏾‍❤‍👩🏽' => 'magkapareha na may puso: babae, babae, katamtamang dark na kulay ng balat, katamtamang kulay ng balat',
    '👩🏾‍❤‍👩🏾' => 'magkapareha na may puso: babae, babae, katamtamang dark na kulay ng balat',
    '👩🏾‍❤‍👩🏿' => 'magkapareha na may puso: babae, babae, katamtamang dark na kulay ng balat, dark na kulay ng balat',
    '👩🏿‍❤‍👩🏻' => 'magkapareha na may puso: babae, babae, dark na kulay ng balat, light na kulay ng balat',
    '👩🏿‍❤‍👩🏼' => 'magkapareha na may puso: babae, babae, dark na kulay ng balat, katamtamang light na kulay ng balat',
    '👩🏿‍❤‍👩🏽' => 'magkapareha na may puso: babae, babae, dark na kulay ng balat, katamtamang kulay ng balat',
    '👩🏿‍❤‍👩🏾' => 'magkapareha na may puso: babae, babae, dark na kulay ng balat, katamtamang dark na kulay ng balat',
    '👩🏿‍❤‍👩🏿' => 'magkapareha na may puso: babae, babae, dark na kulay ng balat',
    '👩🏻‍🐰‍👩🏼' => 'babaeng nagpa-party: light na kulay ng balat, katamtamang light na kulay ng balat',
    '👩🏻‍🐰‍👩🏽' => 'babaeng nagpa-party: light na kulay ng balat, katamtamang kulay ng balat',
    '👩🏻‍🐰‍👩🏾' => 'babaeng nagpa-party: light na kulay ng balat, katamtamang dark na kulay ng balat',
    '👩🏻‍🐰‍👩🏿' => 'babaeng nagpa-party: light na kulay ng balat, dark na kulay ng balat',
    '👩🏼‍🐰‍👩🏻' => 'babaeng nagpa-party: katamtamang light na kulay ng balat, light na kulay ng balat',
    '👩🏼‍🐰‍👩🏽' => 'babaeng nagpa-party: katamtamang light na kulay ng balat, katamtamang kulay ng balat',
    '👩🏼‍🐰‍👩🏾' => 'babaeng nagpa-party: katamtamang light na kulay ng balat, katamtamang dark na kulay ng balat',
    '👩🏼‍🐰‍👩🏿' => 'babaeng nagpa-party: katamtamang light na kulay ng balat, dark na kulay ng balat',
    '👩🏽‍🐰‍👩🏻' => 'babaeng nagpa-party: katamtamang kulay ng balat, light na kulay ng balat',
    '👩🏽‍🐰‍👩🏼' => 'babaeng nagpa-party: katamtamang kulay ng balat, katamtamang light na kulay ng balat',
    '👩🏽‍🐰‍👩🏾' => 'babaeng nagpa-party: katamtamang kulay ng balat, katamtamang dark na kulay ng balat',
    '👩🏽‍🐰‍👩🏿' => 'babaeng nagpa-party: katamtamang kulay ng balat, dark na kulay ng balat',
    '👩🏾‍🐰‍👩🏻' => 'babaeng nagpa-party: katamtamang dark na kulay ng balat, light na kulay ng balat',
    '👩🏾‍🐰‍👩🏼' => 'babaeng nagpa-party: katamtamang dark na kulay ng balat, katamtamang light na kulay ng balat',
    '👩🏾‍🐰‍👩🏽' => 'babaeng nagpa-party: katamtamang dark na kulay ng balat, katamtamang kulay ng balat',
    '👩🏾‍🐰‍👩🏿' => 'babaeng nagpa-party: katamtamang dark na kulay ng balat, dark na kulay ng balat',
    '👩🏿‍🐰‍👩🏻' => 'babaeng nagpa-party: dark na kulay ng balat, light na kulay ng balat',
    '👩🏿‍🐰‍👩🏼' => 'babaeng nagpa-party: dark na kulay ng balat, katamtamang light na kulay ng balat',
    '👩🏿‍🐰‍👩🏽' => 'babaeng nagpa-party: dark na kulay ng balat, katamtamang kulay ng balat',
    '👩🏿‍🐰‍👩🏾' => 'babaeng nagpa-party: dark na kulay ng balat, katamtamang dark na kulay ng balat',
    '🧑🏻‍🤝‍🧑🏻' => 'mga taong magkahawak-kamay: light na kulay ng balat',
    '🧑🏻‍🤝‍🧑🏼' => 'mga taong magkahawak-kamay: light na kulay ng balat, katamtamang light na kulay ng balat',
    '🧑🏻‍🤝‍🧑🏽' => 'mga taong magkahawak-kamay: light na kulay ng balat, katamtamang kulay ng balat',
    '🧑🏻‍🤝‍🧑🏾' => 'mga taong magkahawak-kamay: light na kulay ng balat, katamtamang dark na kulay ng balat',
    '🧑🏻‍🤝‍🧑🏿' => 'mga taong magkahawak-kamay: light na kulay ng balat, dark na kulay ng balat',
    '🧑🏼‍🤝‍🧑🏻' => 'mga taong magkahawak-kamay: katamtamang light na kulay ng balat, light na kulay ng balat',
    '🧑🏼‍🤝‍🧑🏼' => 'mga taong magkahawak-kamay: katamtamang light na kulay ng balat',
    '🧑🏼‍🤝‍🧑🏽' => 'mga taong magkahawak-kamay: katamtamang light na kulay ng balat, katamtamang kulay ng balat',
    '🧑🏼‍🤝‍🧑🏾' => 'mga taong magkahawak-kamay: katamtamang light na kulay ng balat, katamtamang dark na kulay ng balat',
    '🧑🏼‍🤝‍🧑🏿' => 'mga taong magkahawak-kamay: katamtamang light na kulay ng balat, dark na kulay ng balat',
    '🧑🏽‍🤝‍🧑🏻' => 'mga taong magkahawak-kamay: katamtamang kulay ng balat, light na kulay ng balat',
    '🧑🏽‍🤝‍🧑🏼' => 'mga taong magkahawak-kamay: katamtamang kulay ng balat, katamtamang light na kulay ng balat',
    '🧑🏽‍🤝‍🧑🏽' => 'mga taong magkahawak-kamay: katamtamang kulay ng balat',
    '🧑🏽‍🤝‍🧑🏾' => 'mga taong magkahawak-kamay: katamtamang kulay ng balat, katamtamang dark na kulay ng balat',
    '🧑🏽‍🤝‍🧑🏿' => 'mga taong magkahawak-kamay: katamtamang kulay ng balat, dark na kulay ng balat',
    '🧑🏾‍🤝‍🧑🏻' => 'mga taong magkahawak-kamay: katamtamang dark na kulay ng balat, light na kulay ng balat',
    '🧑🏾‍🤝‍🧑🏼' => 'mga taong magkahawak-kamay: katamtamang dark na kulay ng balat, katamtamang light na kulay ng balat',
    '🧑🏾‍🤝‍🧑🏽' => 'mga taong magkahawak-kamay: katamtamang dark na kulay ng balat, katamtamang kulay ng balat',
    '🧑🏾‍🤝‍🧑🏾' => 'mga taong magkahawak-kamay: katamtamang dark na kulay ng balat',
    '🧑🏾‍🤝‍🧑🏿' => 'mga taong magkahawak-kamay: katamtamang dark na kulay ng balat, dark na kulay ng balat',
    '🧑🏿‍🤝‍🧑🏻' => 'mga taong magkahawak-kamay: dark na kulay ng balat, light na kulay ng balat',
    '🧑🏿‍🤝‍🧑🏼' => 'mga taong magkahawak-kamay: dark na kulay ng balat, katamtamang light na kulay ng balat',
    '🧑🏿‍🤝‍🧑🏽' => 'mga taong magkahawak-kamay: dark na kulay ng balat, katamtamang kulay ng balat',
    '🧑🏿‍🤝‍🧑🏾' => 'mga taong magkahawak-kamay: dark na kulay ng balat, katamtamang dark na kulay ng balat',
    '🧑🏿‍🤝‍🧑🏿' => 'mga taong magkahawak-kamay: dark na kulay ng balat',
    '👩🏻‍🤝‍👩🏼' => 'dalawang babaeng magkahawak-kamay: light na kulay ng balat, katamtamang light na kulay ng balat',
    '👩🏻‍🤝‍👩🏽' => 'dalawang babaeng magkahawak-kamay: light na kulay ng balat, katamtamang kulay ng balat',
    '👩🏻‍🤝‍👩🏾' => 'dalawang babaeng magkahawak-kamay: light na kulay ng balat, katamtamang dark na kulay ng balat',
    '👩🏻‍🤝‍👩🏿' => 'dalawang babaeng magkahawak-kamay: light na kulay ng balat, dark na kulay ng balat',
    '👩🏼‍🤝‍👩🏻' => 'dalawang babaeng magkahawak-kamay: katamtamang light na kulay ng balat, light na kulay ng balat',
    '👩🏼‍🤝‍👩🏽' => 'dalawang babaeng magkahawak-kamay: katamtamang light na kulay ng balat, katamtamang kulay ng balat',
    '👩🏼‍🤝‍👩🏾' => 'dalawang babaeng magkahawak-kamay: katamtamang light na kulay ng balat, katamtamang dark na kulay ng balat',
    '👩🏼‍🤝‍👩🏿' => 'dalawang babaeng magkahawak-kamay: katamtamang light na kulay ng balat, dark na kulay ng balat',
    '👩🏽‍🤝‍👩🏻' => 'dalawang babaeng magkahawak-kamay: katamtamang kulay ng balat, light na kulay ng balat',
    '👩🏽‍🤝‍👩🏼' => 'dalawang babaeng magkahawak-kamay: katamtamang kulay ng balat, katamtamang light na kulay ng balat',
    '👩🏽‍🤝‍👩🏾' => 'dalawang babaeng magkahawak-kamay: katamtamang kulay ng balat, katamtamang dark na kulay ng balat',
    '👩🏽‍🤝‍👩🏿' => 'dalawang babaeng magkahawak-kamay: katamtamang kulay ng balat, dark na kulay ng balat',
    '👩🏾‍🤝‍👩🏻' => 'dalawang babaeng magkahawak-kamay: katamtamang dark na kulay ng balat, light na kulay ng balat',
    '👩🏾‍🤝‍👩🏼' => 'dalawang babaeng magkahawak-kamay: katamtamang dark na kulay ng balat, katamtamang light na kulay ng balat',
    '👩🏾‍🤝‍👩🏽' => 'dalawang babaeng magkahawak-kamay: katamtamang dark na kulay ng balat, katamtamang kulay ng balat',
    '👩🏾‍🤝‍👩🏿' => 'dalawang babaeng magkahawak-kamay: katamtamang dark na kulay ng balat, dark na kulay ng balat',
    '👩🏿‍🤝‍👩🏻' => 'dalawang babaeng magkahawak-kamay: dark na kulay ng balat, light na kulay ng balat',
    '👩🏿‍🤝‍👩🏼' => 'dalawang babaeng magkahawak-kamay: dark na kulay ng balat, katamtamang light na kulay ng balat',
    '👩🏿‍🤝‍👩🏽' => 'dalawang babaeng magkahawak-kamay: dark na kulay ng balat, katamtamang kulay ng balat',
    '👩🏿‍🤝‍👩🏾' => 'dalawang babaeng magkahawak-kamay: dark na kulay ng balat, katamtamang dark na kulay ng balat',
    '👩🏻‍🤝‍👨🏼' => 'lalaki at babaeng magkahawak-kamay: light na kulay ng balat, katamtamang light na kulay ng balat',
    '👩🏻‍🤝‍👨🏽' => 'lalaki at babaeng magkahawak-kamay: light na kulay ng balat, katamtamang kulay ng balat',
    '👩🏻‍🤝‍👨🏾' => 'lalaki at babaeng magkahawak-kamay: light na kulay ng balat, katamtamang dark na kulay ng balat',
    '👩🏻‍🤝‍👨🏿' => 'lalaki at babaeng magkahawak-kamay: light na kulay ng balat, dark na kulay ng balat',
    '👩🏼‍🤝‍👨🏻' => 'lalaki at babaeng magkahawak-kamay: katamtamang light na kulay ng balat, light na kulay ng balat',
    '👩🏼‍🤝‍👨🏽' => 'lalaki at babaeng magkahawak-kamay: katamtamang light na kulay ng balat, katamtamang kulay ng balat',
    '👩🏼‍🤝‍👨🏾' => 'lalaki at babaeng magkahawak-kamay: katamtamang light na kulay ng balat, katamtamang dark na kulay ng balat',
    '👩🏼‍🤝‍👨🏿' => 'lalaki at babaeng magkahawak-kamay: katamtamang light na kulay ng balat, dark na kulay ng balat',
    '👩🏽‍🤝‍👨🏻' => 'lalaki at babaeng magkahawak-kamay: katamtamang kulay ng balat, light na kulay ng balat',
    '👩🏽‍🤝‍👨🏼' => 'lalaki at babaeng magkahawak-kamay: katamtamang kulay ng balat, katamtamang light na kulay ng balat',
    '👩🏽‍🤝‍👨🏾' => 'lalaki at babaeng magkahawak-kamay: katamtamang kulay ng balat, katamtamang dark na kulay ng balat',
    '👩🏽‍🤝‍👨🏿' => 'lalaki at babaeng magkahawak-kamay: katamtamang kulay ng balat, dark na kulay ng balat',
    '👩🏾‍🤝‍👨🏻' => 'lalaki at babaeng magkahawak-kamay: katamtamang dark na kulay ng balat, light na kulay ng balat',
    '👩🏾‍🤝‍👨🏼' => 'lalaki at babaeng magkahawak-kamay: katamtamang dark na kulay ng balat, katamtamang light na kulay ng balat',
    '👩🏾‍🤝‍👨🏽' => 'lalaki at babaeng magkahawak-kamay: katamtamang dark na kulay ng balat, katamtamang kulay ng balat',
    '👩🏾‍🤝‍👨🏿' => 'lalaki at babaeng magkahawak-kamay: katamtamang dark na kulay ng balat, dark na kulay ng balat',
    '👩🏿‍🤝‍👨🏻' => 'lalaki at babaeng magkahawak-kamay: dark na kulay ng balat, light na kulay ng balat',
    '👩🏿‍🤝‍👨🏼' => 'lalaki at babaeng magkahawak-kamay: dark na kulay ng balat, katamtamang light na kulay ng balat',
    '👩🏿‍🤝‍👨🏽' => 'lalaki at babaeng magkahawak-kamay: dark na kulay ng balat, katamtamang kulay ng balat',
    '👩🏿‍🤝‍👨🏾' => 'lalaki at babaeng magkahawak-kamay: dark na kulay ng balat, katamtamang dark na kulay ng balat',
    '👨🏻‍🤝‍👨🏼' => 'dalawang lalaking magkahawak-kamay: light na kulay ng balat, katamtamang light na kulay ng balat',
    '👨🏻‍🤝‍👨🏽' => 'dalawang lalaking magkahawak-kamay: light na kulay ng balat, katamtamang kulay ng balat',
    '👨🏻‍🤝‍👨🏾' => 'dalawang lalaking magkahawak-kamay: light na kulay ng balat, katamtamang dark na kulay ng balat',
    '👨🏻‍🤝‍👨🏿' => 'dalawang lalaking magkahawak-kamay: light na kulay ng balat, dark na kulay ng balat',
    '👨🏼‍🤝‍👨🏻' => 'dalawang lalaking magkahawak-kamay: katamtamang light na kulay ng balat, light na kulay ng balat',
    '👨🏼‍🤝‍👨🏽' => 'dalawang lalaking magkahawak-kamay: katamtamang light na kulay ng balat, katamtamang kulay ng balat',
    '👨🏼‍🤝‍👨🏾' => 'dalawang lalaking magkahawak-kamay: katamtamang light na kulay ng balat, katamtamang dark na kulay ng balat',
    '👨🏼‍🤝‍👨🏿' => 'dalawang lalaking magkahawak-kamay: katamtamang light na kulay ng balat, dark na kulay ng balat',
    '👨🏽‍🤝‍👨🏻' => 'dalawang lalaking magkahawak-kamay: katamtamang kulay ng balat, light na kulay ng balat',
    '👨🏽‍🤝‍👨🏼' => 'dalawang lalaking magkahawak-kamay: katamtamang kulay ng balat, katamtamang light na kulay ng balat',
    '👨🏽‍🤝‍👨🏾' => 'dalawang lalaking magkahawak-kamay: katamtamang kulay ng balat, katamtamang dark na kulay ng balat',
    '👨🏽‍🤝‍👨🏿' => 'dalawang lalaking magkahawak-kamay: katamtamang kulay ng balat, dark na kulay ng balat',
    '👨🏾‍🤝‍👨🏻' => 'dalawang lalaking magkahawak-kamay: katamtamang dark na kulay ng balat, light na kulay ng balat',
    '👨🏾‍🤝‍👨🏼' => 'dalawang lalaking magkahawak-kamay: katamtamang dark na kulay ng balat, katamtamang light na kulay ng balat',
    '👨🏾‍🤝‍👨🏽' => 'dalawang lalaking magkahawak-kamay: katamtamang dark na kulay ng balat, katamtamang kulay ng balat',
    '👨🏾‍🤝‍👨🏿' => 'dalawang lalaking magkahawak-kamay: katamtamang dark na kulay ng balat, dark na kulay ng balat',
    '👨🏿‍🤝‍👨🏻' => 'dalawang lalaking magkahawak-kamay: dark na kulay ng balat, light na kulay ng balat',
    '👨🏿‍🤝‍👨🏼' => 'dalawang lalaking magkahawak-kamay: dark na kulay ng balat, katamtamang light na kulay ng balat',
    '👨🏿‍🤝‍👨🏽' => 'dalawang lalaking magkahawak-kamay: dark na kulay ng balat, katamtamang kulay ng balat',
    '👨🏿‍🤝‍👨🏾' => 'dalawang lalaking magkahawak-kamay: dark na kulay ng balat, katamtamang dark na kulay ng balat',
    '👩‍❤‍💋‍👨' => 'maghahalikan: babae, lalaki',
    '👨‍❤‍💋‍👨' => 'maghahalikan: lalaki, lalaki',
    '👩‍❤‍💋‍👩' => 'maghahalikan: babae, babae',
    '👨‍👩‍👧‍👦' => 'pamilya: lalaki, babae, batang babae, batang lalaki',
    '👨‍👩‍👦‍👦' => 'pamilya: lalaki, babae, batang lalaki, batang lalaki',
    '👨‍👩‍👧‍👧' => 'pamilya: lalaki, babae, batang babae, batang babae',
    '👨‍👨‍👧‍👦' => 'pamilya: lalaki, lalaki, batang babae, batang lalaki',
    '👨‍👨‍👦‍👦' => 'pamilya: lalaki, lalaki, batang lalaki, batang lalaki',
    '👨‍👨‍👧‍👧' => 'pamilya: lalaki, lalaki, batang babae, batang babae',
    '👩‍👩‍👧‍👦' => 'pamilya: babae, babae, batang babae, batang lalaki',
    '👩‍👩‍👦‍👦' => 'pamilya: babae, babae, batang lalaki, batang lalaki',
    '👩‍👩‍👧‍👧' => 'pamilya: babae, babae, batang babae, batang babae',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'bandila: England',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'bandila: Scotland',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'bandila: Wales',
    '🧑‍🧑‍🧒‍🧒' => 'pamilya: adulto, adulto, bata, bata',
    '🚶🏻‍♀‍➡' => 'babaeng naglalakad: light na kulay ng balat, nakaharap sa kanan',
    '🚶🏼‍♀‍➡' => 'babaeng naglalakad: katamtamang light na kulay ng balat, nakaharap sa kanan',
    '🚶🏽‍♀‍➡' => 'babaeng naglalakad: katamtamang kulay ng balat, nakaharap sa kanan',
    '🚶🏾‍♀‍➡' => 'babaeng naglalakad: katamtamang dark na kulay ng balat, nakaharap sa kanan',
    '🚶🏿‍♀‍➡' => 'babaeng naglalakad: dark na kulay ng balat, nakaharap sa kanan',
    '🚶🏻‍♂‍➡' => 'lalaking naglalakad: light na kulay ng balat, nakaharap sa kanan',
    '🚶🏼‍♂‍➡' => 'lalaking naglalakad: katamtamang light na kulay ng balat, nakaharap sa kanan',
    '🚶🏽‍♂‍➡' => 'lalaking naglalakad: katamtamang kulay ng balat, nakaharap sa kanan',
    '🚶🏾‍♂‍➡' => 'lalaking naglalakad: katamtamang dark na kulay ng balat, nakaharap sa kanan',
    '🚶🏿‍♂‍➡' => 'lalaking naglalakad: dark na kulay ng balat, nakaharap sa kanan',
    '🧎🏻‍♀‍➡' => 'babaeng nakaluhod: light na kulay ng balat, nakaharap sa kanan',
    '🧎🏼‍♀‍➡' => 'babaeng nakaluhod: katamtamang light na kulay ng balat, nakaharap sa kanan',
    '🧎🏽‍♀‍➡' => 'babaeng nakaluhod: katamtamang kulay ng balat, nakaharap sa kanan',
    '🧎🏾‍♀‍➡' => 'babaeng nakaluhod: katamtamang dark na kulay ng balat, nakaharap sa kanan',
    '🧎🏿‍♀‍➡' => 'babaeng nakaluhod: dark na kulay ng balat, nakaharap sa kanan',
    '🧎🏻‍♂‍➡' => 'lalaking nakaluhod: light na kulay ng balat, nakaharap sa kanan',
    '🧎🏼‍♂‍➡' => 'lalaking nakaluhod: katamtamang light na kulay ng balat, nakaharap sa kanan',
    '🧎🏽‍♂‍➡' => 'lalaking nakaluhod: katamtamang kulay ng balat, nakaharap sa kanan',
    '🧎🏾‍♂‍➡' => 'lalaking nakaluhod: katamtamang dark na kulay ng balat, nakaharap sa kanan',
    '🧎🏿‍♂‍➡' => 'lalaking nakaluhod: dark na kulay ng balat, nakaharap sa kanan',
    '🧑🏻‍🦯‍➡' => 'taong may tungkod: light na kulay ng balat, nakaharap sa kanan',
    '🧑🏼‍🦯‍➡' => 'taong may tungkod: katamtamang light na kulay ng balat, nakaharap sa kanan',
    '🧑🏽‍🦯‍➡' => 'taong may tungkod: katamtamang kulay ng balat, nakaharap sa kanan',
    '🧑🏾‍🦯‍➡' => 'taong may tungkod: katamtamang dark na kulay ng balat, nakaharap sa kanan',
    '🧑🏿‍🦯‍➡' => 'taong may tungkod: dark na kulay ng balat, nakaharap sa kanan',
    '👨🏻‍🦯‍➡' => 'lalaking may baston: light na kulay ng balat, nakaharap sa kanan',
    '👨🏼‍🦯‍➡' => 'lalaking may baston: katamtamang light na kulay ng balat, nakaharap sa kanan',
    '👨🏽‍🦯‍➡' => 'lalaking may baston: katamtamang kulay ng balat, nakaharap sa kanan',
    '👨🏾‍🦯‍➡' => 'lalaking may baston: katamtamang dark na kulay ng balat, nakaharap sa kanan',
    '👨🏿‍🦯‍➡' => 'lalaking may baston: dark na kulay ng balat, nakaharap sa kanan',
    '👩🏻‍🦯‍➡' => 'babaeng may baston: light na kulay ng balat, nakaharap sa kanan',
    '👩🏼‍🦯‍➡' => 'babaeng may baston: katamtamang light na kulay ng balat, nakaharap sa kanan',
    '👩🏽‍🦯‍➡' => 'babaeng may baston: katamtamang kulay ng balat, nakaharap sa kanan',
    '👩🏾‍🦯‍➡' => 'babaeng may baston: katamtamang dark na kulay ng balat, nakaharap sa kanan',
    '👩🏿‍🦯‍➡' => 'babaeng may baston: dark na kulay ng balat, nakaharap sa kanan',
    '🧑🏻‍🦼‍➡' => 'tao sa de-kuryenteng wheelchair: light na kulay ng balat, nakaharap sa kanan',
    '🧑🏼‍🦼‍➡' => 'tao sa de-kuryenteng wheelchair: katamtamang light na kulay ng balat, nakaharap sa kanan',
    '🧑🏽‍🦼‍➡' => 'tao sa de-kuryenteng wheelchair: katamtamang kulay ng balat, nakaharap sa kanan',
    '🧑🏾‍🦼‍➡' => 'tao sa de-kuryenteng wheelchair: katamtamang dark na kulay ng balat, nakaharap sa kanan',
    '🧑🏿‍🦼‍➡' => 'tao sa de-kuryenteng wheelchair: dark na kulay ng balat, nakaharap sa kanan',
    '👨🏻‍🦼‍➡' => 'lalaki sa de-kuryenteng wheelchair: light na kulay ng balat, nakaharap sa kanan',
    '👨🏼‍🦼‍➡' => 'lalaki sa de-kuryenteng wheelchair: katamtamang light na kulay ng balat, nakaharap sa kanan',
    '👨🏽‍🦼‍➡' => 'lalaki sa de-kuryenteng wheelchair: katamtamang kulay ng balat, nakaharap sa kanan',
    '👨🏾‍🦼‍➡' => 'lalaki sa de-kuryenteng wheelchair: katamtamang dark na kulay ng balat, nakaharap sa kanan',
    '👨🏿‍🦼‍➡' => 'lalaki sa de-kuryenteng wheelchair: dark na kulay ng balat, nakaharap sa kanan',
    '👩🏻‍🦼‍➡' => 'babae sa de-kuryenteng wheelchair: light na kulay ng balat, nakaharap sa kanan',
    '👩🏼‍🦼‍➡' => 'babae sa de-kuryenteng wheelchair: katamtamang light na kulay ng balat, nakaharap sa kanan',
    '👩🏽‍🦼‍➡' => 'babae sa de-kuryenteng wheelchair: katamtamang kulay ng balat, nakaharap sa kanan',
    '👩🏾‍🦼‍➡' => 'babae sa de-kuryenteng wheelchair: katamtamang dark na kulay ng balat, nakaharap sa kanan',
    '👩🏿‍🦼‍➡' => 'babae sa de-kuryenteng wheelchair: dark na kulay ng balat, nakaharap sa kanan',
    '🧑🏻‍🦽‍➡' => 'tao sa manu-manong wheelchair: light na kulay ng balat, nakaharap sa kanan',
    '🧑🏼‍🦽‍➡' => 'tao sa manu-manong wheelchair: katamtamang light na kulay ng balat, nakaharap sa kanan',
    '🧑🏽‍🦽‍➡' => 'tao sa manu-manong wheelchair: katamtamang kulay ng balat, nakaharap sa kanan',
    '🧑🏾‍🦽‍➡' => 'tao sa manu-manong wheelchair: katamtamang dark na kulay ng balat, nakaharap sa kanan',
    '🧑🏿‍🦽‍➡' => 'tao sa manu-manong wheelchair: dark na kulay ng balat, nakaharap sa kanan',
    '👨🏻‍🦽‍➡' => 'lalaki sa manu-manong wheelchair: light na kulay ng balat, nakaharap sa kanan',
    '👨🏼‍🦽‍➡' => 'lalaki sa manu-manong wheelchair: katamtamang light na kulay ng balat, nakaharap sa kanan',
    '👨🏽‍🦽‍➡' => 'lalaki sa manu-manong wheelchair: katamtamang kulay ng balat, nakaharap sa kanan',
    '👨🏾‍🦽‍➡' => 'lalaki sa manu-manong wheelchair: katamtamang dark na kulay ng balat, nakaharap sa kanan',
    '👨🏿‍🦽‍➡' => 'lalaki sa manu-manong wheelchair: dark na kulay ng balat, nakaharap sa kanan',
    '👩🏻‍🦽‍➡' => 'babae sa manu-manong wheelchair: light na kulay ng balat, nakaharap sa kanan',
    '👩🏼‍🦽‍➡' => 'babae sa manu-manong wheelchair: katamtamang light na kulay ng balat, nakaharap sa kanan',
    '👩🏽‍🦽‍➡' => 'babae sa manu-manong wheelchair: katamtamang kulay ng balat, nakaharap sa kanan',
    '👩🏾‍🦽‍➡' => 'babae sa manu-manong wheelchair: katamtamang dark na kulay ng balat, nakaharap sa kanan',
    '👩🏿‍🦽‍➡' => 'babae sa manu-manong wheelchair: dark na kulay ng balat, nakaharap sa kanan',
    '🏃🏻‍♀‍➡' => 'babaeng tumatakbo: light na kulay ng balat, nakaharap sa kanan',
    '🏃🏼‍♀‍➡' => 'babaeng tumatakbo: katamtamang light na kulay ng balat, nakaharap sa kanan',
    '🏃🏽‍♀‍➡' => 'babaeng tumatakbo: katamtamang kulay ng balat, nakaharap sa kanan',
    '🏃🏾‍♀‍➡' => 'babaeng tumatakbo: katamtamang dark na kulay ng balat, nakaharap sa kanan',
    '🏃🏿‍♀‍➡' => 'babaeng tumatakbo: dark na kulay ng balat, nakaharap sa kanan',
    '🏃🏻‍♂‍➡' => 'lalaking tumatakbo: light na kulay ng balat, nakaharap sa kanan',
    '🏃🏼‍♂‍➡' => 'lalaking tumatakbo: katamtamang light na kulay ng balat, nakaharap sa kanan',
    '🏃🏽‍♂‍➡' => 'lalaking tumatakbo: katamtamang kulay ng balat, nakaharap sa kanan',
    '🏃🏾‍♂‍➡' => 'lalaking tumatakbo: katamtamang dark na kulay ng balat, nakaharap sa kanan',
    '🏃🏿‍♂‍➡' => 'lalaking tumatakbo: dark na kulay ng balat, nakaharap sa kanan',
    '🫱🏻‍🫲🏼' => 'pagkakamay: light na kulay ng balat, katamtamang light na kulay ng balat',
    '🫱🏻‍🫲🏽' => 'pagkakamay: light na kulay ng balat, katamtamang kulay ng balat',
    '🫱🏻‍🫲🏾' => 'pagkakamay: light na kulay ng balat, katamtamang dark na kulay ng balat',
    '🫱🏻‍🫲🏿' => 'pagkakamay: light na kulay ng balat, dark na kulay ng balat',
    '🫱🏼‍🫲🏻' => 'pagkakamay: katamtamang light na kulay ng balat, light na kulay ng balat',
    '🫱🏼‍🫲🏽' => 'pagkakamay: katamtamang light na kulay ng balat, katamtamang kulay ng balat',
    '🫱🏼‍🫲🏾' => 'pagkakamay: katamtamang light na kulay ng balat, katamtamang dark na kulay ng balat',
    '🫱🏼‍🫲🏿' => 'pagkakamay: katamtamang light na kulay ng balat, dark na kulay ng balat',
    '🫱🏽‍🫲🏻' => 'pagkakamay: katamtamang kulay ng balat, light na kulay ng balat',
    '🫱🏽‍🫲🏼' => 'pagkakamay: katamtamang kulay ng balat, katamtamang light na kulay ng balat',
    '🫱🏽‍🫲🏾' => 'pagkakamay: katamtamang kulay ng balat, katamtamang dark na kulay ng balat',
    '🫱🏽‍🫲🏿' => 'pagkakamay: katamtamang kulay ng balat, dark na kulay ng balat',
    '🫱🏾‍🫲🏻' => 'pagkakamay: katamtamang dark na kulay ng balat, light na kulay ng balat',
    '🫱🏾‍🫲🏼' => 'pagkakamay: katamtamang dark na kulay ng balat, katamtamang light na kulay ng balat',
    '🫱🏾‍🫲🏽' => 'pagkakamay: katamtamang dark na kulay ng balat, katamtamang kulay ng balat',
    '🫱🏾‍🫲🏿' => 'pagkakamay: katamtamang dark na kulay ng balat, dark na kulay ng balat',
    '🫱🏿‍🫲🏻' => 'pagkakamay: dark na kulay ng balat, light na kulay ng balat',
    '🫱🏿‍🫲🏼' => 'pagkakamay: dark na kulay ng balat, katamtamang light na kulay ng balat',
    '🫱🏿‍🫲🏽' => 'pagkakamay: dark na kulay ng balat, katamtamang kulay ng balat',
    '🫱🏿‍🫲🏾' => 'pagkakamay: dark na kulay ng balat, katamtamang dark na kulay ng balat',
    '🚶‍♀‍➡' => 'babaeng naglalakad: nakaharap sa kanan',
    '🚶‍♂‍➡' => 'lalaking naglalakad: nakaharap sa kanan',
    '🧎‍♀‍➡' => 'babaeng nakaluhod: nakaharap sa kanan',
    '🧎‍♂‍➡' => 'lalaking nakaluhod: nakaharap sa kanan',
    '🧑‍🦯‍➡' => 'taong may tungkod: nakaharap sa kanan',
    '👨‍🦯‍➡' => 'lalaking may baston: nakaharap sa kanan',
    '👩‍🦯‍➡' => 'babaeng may baston: nakaharap sa kanan',
    '🧑‍🦼‍➡' => 'tao sa de-kuryenteng wheelchair: nakaharap sa kanan',
    '👨‍🦼‍➡' => 'lalaki sa de-kuryenteng wheelchair: nakaharap sa kanan',
    '👩‍🦼‍➡' => 'babae sa de-kuryenteng wheelchair: nakaharap sa kanan',
    '🧑‍🦽‍➡' => 'tao sa manu-manong wheelchair: nakaharap sa kanan',
    '👨‍🦽‍➡' => 'lalaki sa manu-manong wheelchair: nakaharap sa kanan',
    '👩‍🦽‍➡' => 'babae sa manu-manong wheelchair: nakaharap sa kanan',
    '🏃‍♀‍➡' => 'babaeng tumatakbo: nakaharap sa kanan',
    '🏃‍♂‍➡' => 'lalaking tumatakbo: nakaharap sa kanan',
    '👩‍❤‍👨' => 'magkapareha na may puso: babae, lalaki',
    '👨‍❤‍👨' => 'magkapareha na may puso: lalaki, lalaki',
    '👩‍❤‍👩' => 'magkapareha na may puso: babae, babae',
    '👨‍👩‍👦' => 'pamilya: lalaki, babae, batang lalaki',
    '👨‍👩‍👧' => 'pamilya: lalaki, babae, batang babae',
    '👨‍👨‍👦' => 'pamilya: lalaki, lalaki, batang lalaki',
    '👨‍👨‍👧' => 'pamilya: lalaki, lalaki, batang babae',
    '👩‍👩‍👦' => 'pamilya: babae, babae, batang lalaki',
    '👩‍👩‍👧' => 'pamilya: babae, babae, batang babae',
    '👨‍👦‍👦' => 'pamilya: lalaki, batang lalaki, batang lalaki',
    '👨‍👧‍👦' => 'pamilya: lalaki, batang babae, batang lalaki',
    '👨‍👧‍👧' => 'pamilya: lalaki, batang babae, batang babae',
    '👩‍👦‍👦' => 'pamilya: babae, batang lalaki, batang lalaki',
    '👩‍👧‍👦' => 'pamilya: babae, batang babae, batang lalaki',
    '👩‍👧‍👧' => 'pamilya: babae, batang babae, batang babae',
    '🧑‍🤝‍🧑' => 'mga taong magkahawak-kamay',
    '🧑‍🧑‍🧒' => 'pamilya: adulto, adulto, bata',
    '🧑‍🧒‍🧒' => 'pamilya: adulto, bata, bata',
    '🧑🏻‍🦰' => 'tao: light na kulay ng balat, pulang buhok',
    '🧑🏼‍🦰' => 'tao: katamtamang light na kulay ng balat, pulang buhok',
    '🧑🏽‍🦰' => 'tao: katamtamang kulay ng balat, pulang buhok',
    '🧑🏾‍🦰' => 'tao: katamtamang dark na kulay ng balat, pulang buhok',
    '🧑🏿‍🦰' => 'tao: dark na kulay ng balat, pulang buhok',
    '🧑🏻‍🦱' => 'tao: light na kulay ng balat, kulot na buhok',
    '🧑🏼‍🦱' => 'tao: katamtamang light na kulay ng balat, kulot na buhok',
    '🧑🏽‍🦱' => 'tao: katamtamang kulay ng balat, kulot na buhok',
    '🧑🏾‍🦱' => 'tao: katamtamang dark na kulay ng balat, kulot na buhok',
    '🧑🏿‍🦱' => 'tao: dark na kulay ng balat, kulot na buhok',
    '🧑🏻‍🦳' => 'tao: light na kulay ng balat, puting buhok',
    '🧑🏼‍🦳' => 'tao: katamtamang light na kulay ng balat, puting buhok',
    '🧑🏽‍🦳' => 'tao: katamtamang kulay ng balat, puting buhok',
    '🧑🏾‍🦳' => 'tao: katamtamang dark na kulay ng balat, puting buhok',
    '🧑🏿‍🦳' => 'tao: dark na kulay ng balat, puting buhok',
    '🧑🏻‍🦲' => 'tao: light na kulay ng balat, kalbo',
    '🧑🏼‍🦲' => 'tao: katamtamang light na kulay ng balat, kalbo',
    '🧑🏽‍🦲' => 'tao: katamtamang kulay ng balat, kalbo',
    '🧑🏾‍🦲' => 'tao: katamtamang dark na kulay ng balat, kalbo',
    '🧑🏿‍🦲' => 'tao: dark na kulay ng balat, kalbo',
    '🧑🏻‍🩰' => 'ballet dancer: light na kulay ng balat',
    '🧑🏼‍🩰' => 'ballet dancer: katamtamang light na kulay ng balat',
    '🧑🏽‍🩰' => 'ballet dancer: katamtamang kulay ng balat',
    '🧑🏾‍🩰' => 'ballet dancer: katamtamang dark na kulay ng balat',
    '🧑🏿‍🩰' => 'ballet dancer: dark na kulay ng balat',
    '🧔🏻‍♂' => 'lalaki: light na kulay ng balat, balbas',
    '🧔🏼‍♂' => 'lalaki: katamtamang light na kulay ng balat, balbas',
    '🧔🏽‍♂' => 'lalaki: katamtamang kulay ng balat, balbas',
    '🧔🏾‍♂' => 'lalaki: katamtamang dark na kulay ng balat, balbas',
    '🧔🏿‍♂' => 'lalaki: dark na kulay ng balat, balbas',
    '👱🏻‍♂' => 'lalaking blonde: light na kulay ng balat',
    '👱🏼‍♂' => 'lalaking blonde: katamtamang light na kulay ng balat',
    '👱🏽‍♂' => 'lalaking blonde: katamtamang kulay ng balat',
    '👱🏾‍♂' => 'lalaking blonde: katamtamang dark na kulay ng balat',
    '👱🏿‍♂' => 'lalaking blonde: dark na kulay ng balat',
    '👨🏻‍🦰' => 'lalaki: light na kulay ng balat, pulang buhok',
    '👨🏼‍🦰' => 'lalaki: katamtamang light na kulay ng balat, pulang buhok',
    '👨🏽‍🦰' => 'lalaki: katamtamang kulay ng balat, pulang buhok',
    '👨🏾‍🦰' => 'lalaki: katamtamang dark na kulay ng balat, pulang buhok',
    '👨🏿‍🦰' => 'lalaki: dark na kulay ng balat, pulang buhok',
    '👨🏻‍🦱' => 'lalaki: light na kulay ng balat, kulot na buhok',
    '👨🏼‍🦱' => 'lalaki: katamtamang light na kulay ng balat, kulot na buhok',
    '👨🏽‍🦱' => 'lalaki: katamtamang kulay ng balat, kulot na buhok',
    '👨🏾‍🦱' => 'lalaki: katamtamang dark na kulay ng balat, kulot na buhok',
    '👨🏿‍🦱' => 'lalaki: dark na kulay ng balat, kulot na buhok',
    '👨🏻‍🦳' => 'lalaki: light na kulay ng balat, puting buhok',
    '👨🏼‍🦳' => 'lalaki: katamtamang light na kulay ng balat, puting buhok',
    '👨🏽‍🦳' => 'lalaki: katamtamang kulay ng balat, puting buhok',
    '👨🏾‍🦳' => 'lalaki: katamtamang dark na kulay ng balat, puting buhok',
    '👨🏿‍🦳' => 'lalaki: dark na kulay ng balat, puting buhok',
    '👨🏻‍🦲' => 'lalaki: light na kulay ng balat, kalbo',
    '👨🏼‍🦲' => 'lalaki: katamtamang light na kulay ng balat, kalbo',
    '👨🏽‍🦲' => 'lalaki: katamtamang kulay ng balat, kalbo',
    '👨🏾‍🦲' => 'lalaki: katamtamang dark na kulay ng balat, kalbo',
    '👨🏿‍🦲' => 'lalaki: dark na kulay ng balat, kalbo',
    '🧔🏻‍♀' => 'babae: light na kulay ng balat, balbas',
    '🧔🏼‍♀' => 'babae: katamtamang light na kulay ng balat, balbas',
    '🧔🏽‍♀' => 'babae: katamtamang kulay ng balat, balbas',
    '🧔🏾‍♀' => 'babae: katamtamang dark na kulay ng balat, balbas',
    '🧔🏿‍♀' => 'babae: dark na kulay ng balat, balbas',
    '👱🏻‍♀' => 'babae: light na kulay ng balat, blond na buhok',
    '👱🏼‍♀' => 'babae: katamtamang light na kulay ng balat, blond na buhok',
    '👱🏽‍♀' => 'babae: katamtamang kulay ng balat, blond na buhok',
    '👱🏾‍♀' => 'babae: katamtamang dark na kulay ng balat, blond na buhok',
    '👱🏿‍♀' => 'babae: dark na kulay ng balat, blond na buhok',
    '👩🏻‍🦰' => 'babae: light na kulay ng balat, pulang buhok',
    '👩🏼‍🦰' => 'babae: katamtamang light na kulay ng balat, pulang buhok',
    '👩🏽‍🦰' => 'babae: katamtamang kulay ng balat, pulang buhok',
    '👩🏾‍🦰' => 'babae: katamtamang dark na kulay ng balat, pulang buhok',
    '👩🏿‍🦰' => 'babae: dark na kulay ng balat, pulang buhok',
    '👩🏻‍🦱' => 'babae: light na kulay ng balat, kulot na buhok',
    '👩🏼‍🦱' => 'babae: katamtamang light na kulay ng balat, kulot na buhok',
    '👩🏽‍🦱' => 'babae: katamtamang kulay ng balat, kulot na buhok',
    '👩🏾‍🦱' => 'babae: katamtamang dark na kulay ng balat, kulot na buhok',
    '👩🏿‍🦱' => 'babae: dark na kulay ng balat, kulot na buhok',
    '👩🏻‍🦳' => 'babae: light na kulay ng balat, puting buhok',
    '👩🏼‍🦳' => 'babae: katamtamang light na kulay ng balat, puting buhok',
    '👩🏽‍🦳' => 'babae: katamtamang kulay ng balat, puting buhok',
    '👩🏾‍🦳' => 'babae: katamtamang dark na kulay ng balat, puting buhok',
    '👩🏿‍🦳' => 'babae: dark na kulay ng balat, puting buhok',
    '👩🏻‍🦲' => 'babae: light na kulay ng balat, kalbo',
    '👩🏼‍🦲' => 'babae: katamtamang light na kulay ng balat, kalbo',
    '👩🏽‍🦲' => 'babae: katamtamang kulay ng balat, kalbo',
    '👩🏾‍🦲' => 'babae: katamtamang dark na kulay ng balat, kalbo',
    '👩🏿‍🦲' => 'babae: dark na kulay ng balat, kalbo',
    '🙍🏻‍♂' => 'lalaking nakasimangot: light na kulay ng balat',
    '🙍🏼‍♂' => 'lalaking nakasimangot: katamtamang light na kulay ng balat',
    '🙍🏽‍♂' => 'lalaking nakasimangot: katamtamang kulay ng balat',
    '🙍🏾‍♂' => 'lalaking nakasimangot: katamtamang dark na kulay ng balat',
    '🙍🏿‍♂' => 'lalaking nakasimangot: dark na kulay ng balat',
    '🙍🏻‍♀' => 'babaeng nakasimangot: light na kulay ng balat',
    '🙍🏼‍♀' => 'babaeng nakasimangot: katamtamang light na kulay ng balat',
    '🙍🏽‍♀' => 'babaeng nakasimangot: katamtamang kulay ng balat',
    '🙍🏾‍♀' => 'babaeng nakasimangot: katamtamang dark na kulay ng balat',
    '🙍🏿‍♀' => 'babaeng nakasimangot: dark na kulay ng balat',
    '🙎🏻‍♂' => 'lalaking nakanguso: light na kulay ng balat',
    '🙎🏼‍♂' => 'lalaking nakanguso: katamtamang light na kulay ng balat',
    '🙎🏽‍♂' => 'lalaking nakanguso: katamtamang kulay ng balat',
    '🙎🏾‍♂' => 'lalaking nakanguso: katamtamang dark na kulay ng balat',
    '🙎🏿‍♂' => 'lalaking nakanguso: dark na kulay ng balat',
    '🙎🏻‍♀' => 'babaeng nakanguso: light na kulay ng balat',
    '🙎🏼‍♀' => 'babaeng nakanguso: katamtamang light na kulay ng balat',
    '🙎🏽‍♀' => 'babaeng nakanguso: katamtamang kulay ng balat',
    '🙎🏾‍♀' => 'babaeng nakanguso: katamtamang dark na kulay ng balat',
    '🙎🏿‍♀' => 'babaeng nakanguso: dark na kulay ng balat',
    '🙅🏻‍♂' => 'lalaking kumukumpas na hindi ok: light na kulay ng balat',
    '🙅🏼‍♂' => 'lalaking kumukumpas na hindi ok: katamtamang light na kulay ng balat',
    '🙅🏽‍♂' => 'lalaking kumukumpas na hindi ok: katamtamang kulay ng balat',
    '🙅🏾‍♂' => 'lalaking kumukumpas na hindi ok: katamtamang dark na kulay ng balat',
    '🙅🏿‍♂' => 'lalaking kumukumpas na hindi ok: dark na kulay ng balat',
    '🙅🏻‍♀' => 'babaeng kumukumpas na hindi ok: light na kulay ng balat',
    '🙅🏼‍♀' => 'babaeng kumukumpas na hindi ok: katamtamang light na kulay ng balat',
    '🙅🏽‍♀' => 'babaeng kumukumpas na hindi ok: katamtamang kulay ng balat',
    '🙅🏾‍♀' => 'babaeng kumukumpas na hindi ok: katamtamang dark na kulay ng balat',
    '🙅🏿‍♀' => 'babaeng kumukumpas na hindi ok: dark na kulay ng balat',
    '🙆🏻‍♂' => 'lalaking kumukumpas na ok: light na kulay ng balat',
    '🙆🏼‍♂' => 'lalaking kumukumpas na ok: katamtamang light na kulay ng balat',
    '🙆🏽‍♂' => 'lalaking kumukumpas na ok: katamtamang kulay ng balat',
    '🙆🏾‍♂' => 'lalaking kumukumpas na ok: katamtamang dark na kulay ng balat',
    '🙆🏿‍♂' => 'lalaking kumukumpas na ok: dark na kulay ng balat',
    '🙆🏻‍♀' => 'babaeng kumukumpas na ok: light na kulay ng balat',
    '🙆🏼‍♀' => 'babaeng kumukumpas na ok: katamtamang light na kulay ng balat',
    '🙆🏽‍♀' => 'babaeng kumukumpas na ok: katamtamang kulay ng balat',
    '🙆🏾‍♀' => 'babaeng kumukumpas na ok: katamtamang dark na kulay ng balat',
    '🙆🏿‍♀' => 'babaeng kumukumpas na ok: dark na kulay ng balat',
    '💁🏻‍♂' => 'lalaking nakatikwas ang kamay: light na kulay ng balat',
    '💁🏼‍♂' => 'lalaking nakatikwas ang kamay: katamtamang light na kulay ng balat',
    '💁🏽‍♂' => 'lalaking nakatikwas ang kamay: katamtamang kulay ng balat',
    '💁🏾‍♂' => 'lalaking nakatikwas ang kamay: katamtamang dark na kulay ng balat',
    '💁🏿‍♂' => 'lalaking nakatikwas ang kamay: dark na kulay ng balat',
    '💁🏻‍♀' => 'babaeng nakatikwas ang kamay: light na kulay ng balat',
    '💁🏼‍♀' => 'babaeng nakatikwas ang kamay: katamtamang light na kulay ng balat',
    '💁🏽‍♀' => 'babaeng nakatikwas ang kamay: katamtamang kulay ng balat',
    '💁🏾‍♀' => 'babaeng nakatikwas ang kamay: katamtamang dark na kulay ng balat',
    '💁🏿‍♀' => 'babaeng nakatikwas ang kamay: dark na kulay ng balat',
    '🙋🏻‍♂' => 'lalaking nakataas ang kamay: light na kulay ng balat',
    '🙋🏼‍♂' => 'lalaking nakataas ang kamay: katamtamang light na kulay ng balat',
    '🙋🏽‍♂' => 'lalaking nakataas ang kamay: katamtamang kulay ng balat',
    '🙋🏾‍♂' => 'lalaking nakataas ang kamay: katamtamang dark na kulay ng balat',
    '🙋🏿‍♂' => 'lalaking nakataas ang kamay: dark na kulay ng balat',
    '🙋🏻‍♀' => 'babaeng nakataas ang kamay: light na kulay ng balat',
    '🙋🏼‍♀' => 'babaeng nakataas ang kamay: katamtamang light na kulay ng balat',
    '🙋🏽‍♀' => 'babaeng nakataas ang kamay: katamtamang kulay ng balat',
    '🙋🏾‍♀' => 'babaeng nakataas ang kamay: katamtamang dark na kulay ng balat',
    '🙋🏿‍♀' => 'babaeng nakataas ang kamay: dark na kulay ng balat',
    '🧏🏻‍♂' => 'lalaking bingi: light na kulay ng balat',
    '🧏🏼‍♂' => 'lalaking bingi: katamtamang light na kulay ng balat',
    '🧏🏽‍♂' => 'lalaking bingi: katamtamang kulay ng balat',
    '🧏🏾‍♂' => 'lalaking bingi: katamtamang dark na kulay ng balat',
    '🧏🏿‍♂' => 'lalaking bingi: dark na kulay ng balat',
    '🧏🏻‍♀' => 'babaeng bingi: light na kulay ng balat',
    '🧏🏼‍♀' => 'babaeng bingi: katamtamang light na kulay ng balat',
    '🧏🏽‍♀' => 'babaeng bingi: katamtamang kulay ng balat',
    '🧏🏾‍♀' => 'babaeng bingi: katamtamang dark na kulay ng balat',
    '🧏🏿‍♀' => 'babaeng bingi: dark na kulay ng balat',
    '🙇🏻‍♂' => 'lalaking nakayuko: light na kulay ng balat',
    '🙇🏼‍♂' => 'lalaking nakayuko: katamtamang light na kulay ng balat',
    '🙇🏽‍♂' => 'lalaking nakayuko: katamtamang kulay ng balat',
    '🙇🏾‍♂' => 'lalaking nakayuko: katamtamang dark na kulay ng balat',
    '🙇🏿‍♂' => 'lalaking nakayuko: dark na kulay ng balat',
    '🙇🏻‍♀' => 'babaeng nakayuko: light na kulay ng balat',
    '🙇🏼‍♀' => 'babaeng nakayuko: katamtamang light na kulay ng balat',
    '🙇🏽‍♀' => 'babaeng nakayuko: katamtamang kulay ng balat',
    '🙇🏾‍♀' => 'babaeng nakayuko: katamtamang dark na kulay ng balat',
    '🙇🏿‍♀' => 'babaeng nakayuko: dark na kulay ng balat',
    '🤦🏻‍♂' => 'lalaking naka-facepalm: light na kulay ng balat',
    '🤦🏼‍♂' => 'lalaking naka-facepalm: katamtamang light na kulay ng balat',
    '🤦🏽‍♂' => 'lalaking naka-facepalm: katamtamang kulay ng balat',
    '🤦🏾‍♂' => 'lalaking naka-facepalm: katamtamang dark na kulay ng balat',
    '🤦🏿‍♂' => 'lalaking naka-facepalm: dark na kulay ng balat',
    '🤦🏻‍♀' => 'babaeng naka-facepalm: light na kulay ng balat',
    '🤦🏼‍♀' => 'babaeng naka-facepalm: katamtamang light na kulay ng balat',
    '🤦🏽‍♀' => 'babaeng naka-facepalm: katamtamang kulay ng balat',
    '🤦🏾‍♀' => 'babaeng naka-facepalm: katamtamang dark na kulay ng balat',
    '🤦🏿‍♀' => 'babaeng naka-facepalm: dark na kulay ng balat',
    '🤷🏻‍♂' => 'lalaking nagkikibit-balikat: light na kulay ng balat',
    '🤷🏼‍♂' => 'lalaking nagkikibit-balikat: katamtamang light na kulay ng balat',
    '🤷🏽‍♂' => 'lalaking nagkikibit-balikat: katamtamang kulay ng balat',
    '🤷🏾‍♂' => 'lalaking nagkikibit-balikat: katamtamang dark na kulay ng balat',
    '🤷🏿‍♂' => 'lalaking nagkikibit-balikat: dark na kulay ng balat',
    '🤷🏻‍♀' => 'babaeng nagkikibit-balikat: light na kulay ng balat',
    '🤷🏼‍♀' => 'babaeng nagkikibit-balikat: katamtamang light na kulay ng balat',
    '🤷🏽‍♀' => 'babaeng nagkikibit-balikat: katamtamang kulay ng balat',
    '🤷🏾‍♀' => 'babaeng nagkikibit-balikat: katamtamang dark na kulay ng balat',
    '🤷🏿‍♀' => 'babaeng nagkikibit-balikat: dark na kulay ng balat',
    '🧑🏻‍⚕' => 'health worker: light na kulay ng balat',
    '🧑🏼‍⚕' => 'health worker: katamtamang light na kulay ng balat',
    '🧑🏽‍⚕' => 'health worker: katamtamang kulay ng balat',
    '🧑🏾‍⚕' => 'health worker: katamtamang dark na kulay ng balat',
    '🧑🏿‍⚕' => 'health worker: dark na kulay ng balat',
    '👨🏻‍⚕' => 'lalaking health worker: light na kulay ng balat',
    '👨🏼‍⚕' => 'lalaking health worker: katamtamang light na kulay ng balat',
    '👨🏽‍⚕' => 'lalaking health worker: katamtamang kulay ng balat',
    '👨🏾‍⚕' => 'lalaking health worker: katamtamang dark na kulay ng balat',
    '👨🏿‍⚕' => 'lalaking health worker: dark na kulay ng balat',
    '👩🏻‍⚕' => 'babaeng health worker: light na kulay ng balat',
    '👩🏼‍⚕' => 'babaeng health worker: katamtamang light na kulay ng balat',
    '👩🏽‍⚕' => 'babaeng health worker: katamtamang kulay ng balat',
    '👩🏾‍⚕' => 'babaeng health worker: katamtamang dark na kulay ng balat',
    '👩🏿‍⚕' => 'babaeng health worker: dark na kulay ng balat',
    '🧑🏻‍🎓' => 'estudyante: light na kulay ng balat',
    '🧑🏼‍🎓' => 'estudyante: katamtamang light na kulay ng balat',
    '🧑🏽‍🎓' => 'estudyante: katamtamang kulay ng balat',
    '🧑🏾‍🎓' => 'estudyante: katamtamang dark na kulay ng balat',
    '🧑🏿‍🎓' => 'estudyante: dark na kulay ng balat',
    '👨🏻‍🎓' => 'lalaking mag-aaral: light na kulay ng balat',
    '👨🏼‍🎓' => 'lalaking mag-aaral: katamtamang light na kulay ng balat',
    '👨🏽‍🎓' => 'lalaking mag-aaral: katamtamang kulay ng balat',
    '👨🏾‍🎓' => 'lalaking mag-aaral: katamtamang dark na kulay ng balat',
    '👨🏿‍🎓' => 'lalaking mag-aaral: dark na kulay ng balat',
    '👩🏻‍🎓' => 'babaeng mag-aaral: light na kulay ng balat',
    '👩🏼‍🎓' => 'babaeng mag-aaral: katamtamang light na kulay ng balat',
    '👩🏽‍🎓' => 'babaeng mag-aaral: katamtamang kulay ng balat',
    '👩🏾‍🎓' => 'babaeng mag-aaral: katamtamang dark na kulay ng balat',
    '👩🏿‍🎓' => 'babaeng mag-aaral: dark na kulay ng balat',
    '🧑🏻‍🏫' => 'guro: light na kulay ng balat',
    '🧑🏼‍🏫' => 'guro: katamtamang light na kulay ng balat',
    '🧑🏽‍🏫' => 'guro: katamtamang kulay ng balat',
    '🧑🏾‍🏫' => 'guro: katamtamang dark na kulay ng balat',
    '🧑🏿‍🏫' => 'guro: dark na kulay ng balat',
    '👨🏻‍🏫' => 'lalaking guro: light na kulay ng balat',
    '👨🏼‍🏫' => 'lalaking guro: katamtamang light na kulay ng balat',
    '👨🏽‍🏫' => 'lalaking guro: katamtamang kulay ng balat',
    '👨🏾‍🏫' => 'lalaking guro: katamtamang dark na kulay ng balat',
    '👨🏿‍🏫' => 'lalaking guro: dark na kulay ng balat',
    '👩🏻‍🏫' => 'babaeng guro: light na kulay ng balat',
    '👩🏼‍🏫' => 'babaeng guro: katamtamang light na kulay ng balat',
    '👩🏽‍🏫' => 'babaeng guro: katamtamang kulay ng balat',
    '👩🏾‍🏫' => 'babaeng guro: katamtamang dark na kulay ng balat',
    '👩🏿‍🏫' => 'babaeng guro: dark na kulay ng balat',
    '🧑🏻‍⚖' => 'hukom: light na kulay ng balat',
    '🧑🏼‍⚖' => 'hukom: katamtamang light na kulay ng balat',
    '🧑🏽‍⚖' => 'hukom: katamtamang kulay ng balat',
    '🧑🏾‍⚖' => 'hukom: katamtamang dark na kulay ng balat',
    '🧑🏿‍⚖' => 'hukom: dark na kulay ng balat',
    '👨🏻‍⚖' => 'lalaking hukom: light na kulay ng balat',
    '👨🏼‍⚖' => 'lalaking hukom: katamtamang light na kulay ng balat',
    '👨🏽‍⚖' => 'lalaking hukom: katamtamang kulay ng balat',
    '👨🏾‍⚖' => 'lalaking hukom: katamtamang dark na kulay ng balat',
    '👨🏿‍⚖' => 'lalaking hukom: dark na kulay ng balat',
    '👩🏻‍⚖' => 'babaeng hukom: light na kulay ng balat',
    '👩🏼‍⚖' => 'babaeng hukom: katamtamang light na kulay ng balat',
    '👩🏽‍⚖' => 'babaeng hukom: katamtamang kulay ng balat',
    '👩🏾‍⚖' => 'babaeng hukom: katamtamang dark na kulay ng balat',
    '👩🏿‍⚖' => 'babaeng hukom: dark na kulay ng balat',
    '🧑🏻‍🌾' => 'magsasaka: light na kulay ng balat',
    '🧑🏼‍🌾' => 'magsasaka: katamtamang light na kulay ng balat',
    '🧑🏽‍🌾' => 'magsasaka: katamtamang kulay ng balat',
    '🧑🏾‍🌾' => 'magsasaka: katamtamang dark na kulay ng balat',
    '🧑🏿‍🌾' => 'magsasaka: dark na kulay ng balat',
    '👨🏻‍🌾' => 'lalaking magsasaka: light na kulay ng balat',
    '👨🏼‍🌾' => 'lalaking magsasaka: katamtamang light na kulay ng balat',
    '👨🏽‍🌾' => 'lalaking magsasaka: katamtamang kulay ng balat',
    '👨🏾‍🌾' => 'lalaking magsasaka: katamtamang dark na kulay ng balat',
    '👨🏿‍🌾' => 'lalaking magsasaka: dark na kulay ng balat',
    '👩🏻‍🌾' => 'babaeng magsasaka: light na kulay ng balat',
    '👩🏼‍🌾' => 'babaeng magsasaka: katamtamang light na kulay ng balat',
    '👩🏽‍🌾' => 'babaeng magsasaka: katamtamang kulay ng balat',
    '👩🏾‍🌾' => 'babaeng magsasaka: katamtamang dark na kulay ng balat',
    '👩🏿‍🌾' => 'babaeng magsasaka: dark na kulay ng balat',
    '🧑🏻‍🍳' => 'tagaluto: light na kulay ng balat',
    '🧑🏼‍🍳' => 'tagaluto: katamtamang light na kulay ng balat',
    '🧑🏽‍🍳' => 'tagaluto: katamtamang kulay ng balat',
    '🧑🏾‍🍳' => 'tagaluto: katamtamang dark na kulay ng balat',
    '🧑🏿‍🍳' => 'tagaluto: dark na kulay ng balat',
    '👨🏻‍🍳' => 'kusinero: light na kulay ng balat',
    '👨🏼‍🍳' => 'kusinero: katamtamang light na kulay ng balat',
    '👨🏽‍🍳' => 'kusinero: katamtamang kulay ng balat',
    '👨🏾‍🍳' => 'kusinero: katamtamang dark na kulay ng balat',
    '👨🏿‍🍳' => 'kusinero: dark na kulay ng balat',
    '👩🏻‍🍳' => 'kusinera: light na kulay ng balat',
    '👩🏼‍🍳' => 'kusinera: katamtamang light na kulay ng balat',
    '👩🏽‍🍳' => 'kusinera: katamtamang kulay ng balat',
    '👩🏾‍🍳' => 'kusinera: katamtamang dark na kulay ng balat',
    '👩🏿‍🍳' => 'kusinera: dark na kulay ng balat',
    '🧑🏻‍🔧' => 'mekaniko: light na kulay ng balat',
    '🧑🏼‍🔧' => 'mekaniko: katamtamang light na kulay ng balat',
    '🧑🏽‍🔧' => 'mekaniko: katamtamang kulay ng balat',
    '🧑🏾‍🔧' => 'mekaniko: katamtamang dark na kulay ng balat',
    '🧑🏿‍🔧' => 'mekaniko: dark na kulay ng balat',
    '👨🏻‍🔧' => 'lalaking mekaniko: light na kulay ng balat',
    '👨🏼‍🔧' => 'lalaking mekaniko: katamtamang light na kulay ng balat',
    '👨🏽‍🔧' => 'lalaking mekaniko: katamtamang kulay ng balat',
    '👨🏾‍🔧' => 'lalaking mekaniko: katamtamang dark na kulay ng balat',
    '👨🏿‍🔧' => 'lalaking mekaniko: dark na kulay ng balat',
    '👩🏻‍🔧' => 'babaeng mekaniko: light na kulay ng balat',
    '👩🏼‍🔧' => 'babaeng mekaniko: katamtamang light na kulay ng balat',
    '👩🏽‍🔧' => 'babaeng mekaniko: katamtamang kulay ng balat',
    '👩🏾‍🔧' => 'babaeng mekaniko: katamtamang dark na kulay ng balat',
    '👩🏿‍🔧' => 'babaeng mekaniko: dark na kulay ng balat',
    '🧑🏻‍🏭' => 'trabahador sa pabrika: light na kulay ng balat',
    '🧑🏼‍🏭' => 'trabahador sa pabrika: katamtamang light na kulay ng balat',
    '🧑🏽‍🏭' => 'trabahador sa pabrika: katamtamang kulay ng balat',
    '🧑🏾‍🏭' => 'trabahador sa pabrika: katamtamang dark na kulay ng balat',
    '🧑🏿‍🏭' => 'trabahador sa pabrika: dark na kulay ng balat',
    '👨🏻‍🏭' => 'lalaking manggagawa sa pabrika: light na kulay ng balat',
    '👨🏼‍🏭' => 'lalaking manggagawa sa pabrika: katamtamang light na kulay ng balat',
    '👨🏽‍🏭' => 'lalaking manggagawa sa pabrika: katamtamang kulay ng balat',
    '👨🏾‍🏭' => 'lalaking manggagawa sa pabrika: katamtamang dark na kulay ng balat',
    '👨🏿‍🏭' => 'lalaking manggagawa sa pabrika: dark na kulay ng balat',
    '👩🏻‍🏭' => 'babaeng manggagawa sa pabrika: light na kulay ng balat',
    '👩🏼‍🏭' => 'babaeng manggagawa sa pabrika: katamtamang light na kulay ng balat',
    '👩🏽‍🏭' => 'babaeng manggagawa sa pabrika: katamtamang kulay ng balat',
    '👩🏾‍🏭' => 'babaeng manggagawa sa pabrika: katamtamang dark na kulay ng balat',
    '👩🏿‍🏭' => 'babaeng manggagawa sa pabrika: dark na kulay ng balat',
    '🧑🏻‍💼' => 'trabahador sa opisina: light na kulay ng balat',
    '🧑🏼‍💼' => 'trabahador sa opisina: katamtamang light na kulay ng balat',
    '🧑🏽‍💼' => 'trabahador sa opisina: katamtamang kulay ng balat',
    '🧑🏾‍💼' => 'trabahador sa opisina: katamtamang dark na kulay ng balat',
    '🧑🏿‍💼' => 'trabahador sa opisina: dark na kulay ng balat',
    '👨🏻‍💼' => 'empleyado sa opisina: light na kulay ng balat',
    '👨🏼‍💼' => 'empleyado sa opisina: katamtamang light na kulay ng balat',
    '👨🏽‍💼' => 'empleyado sa opisina: katamtamang kulay ng balat',
    '👨🏾‍💼' => 'empleyado sa opisina: katamtamang dark na kulay ng balat',
    '👨🏿‍💼' => 'empleyado sa opisina: dark na kulay ng balat',
    '👩🏻‍💼' => 'babaeng empleyado sa opisina: light na kulay ng balat',
    '👩🏼‍💼' => 'babaeng empleyado sa opisina: katamtamang light na kulay ng balat',
    '👩🏽‍💼' => 'babaeng empleyado sa opisina: katamtamang kulay ng balat',
    '👩🏾‍💼' => 'babaeng empleyado sa opisina: katamtamang dark na kulay ng balat',
    '👩🏿‍💼' => 'babaeng empleyado sa opisina: dark na kulay ng balat',
    '🧑🏻‍🔬' => 'siyentipiko: light na kulay ng balat',
    '🧑🏼‍🔬' => 'siyentipiko: katamtamang light na kulay ng balat',
    '🧑🏽‍🔬' => 'siyentipiko: katamtamang kulay ng balat',
    '🧑🏾‍🔬' => 'siyentipiko: katamtamang dark na kulay ng balat',
    '🧑🏿‍🔬' => 'siyentipiko: dark na kulay ng balat',
    '👨🏻‍🔬' => 'lalaking siyentipiko: light na kulay ng balat',
    '👨🏼‍🔬' => 'lalaking siyentipiko: katamtamang light na kulay ng balat',
    '👨🏽‍🔬' => 'lalaking siyentipiko: katamtamang kulay ng balat',
    '👨🏾‍🔬' => 'lalaking siyentipiko: katamtamang dark na kulay ng balat',
    '👨🏿‍🔬' => 'lalaking siyentipiko: dark na kulay ng balat',
    '👩🏻‍🔬' => 'babaeng siyentipiko: light na kulay ng balat',
    '👩🏼‍🔬' => 'babaeng siyentipiko: katamtamang light na kulay ng balat',
    '👩🏽‍🔬' => 'babaeng siyentipiko: katamtamang kulay ng balat',
    '👩🏾‍🔬' => 'babaeng siyentipiko: katamtamang dark na kulay ng balat',
    '👩🏿‍🔬' => 'babaeng siyentipiko: dark na kulay ng balat',
    '🧑🏻‍💻' => 'technologist: light na kulay ng balat',
    '🧑🏼‍💻' => 'technologist: katamtamang light na kulay ng balat',
    '🧑🏽‍💻' => 'technologist: katamtamang kulay ng balat',
    '🧑🏾‍💻' => 'technologist: katamtamang dark na kulay ng balat',
    '🧑🏿‍💻' => 'technologist: dark na kulay ng balat',
    '👨🏻‍💻' => 'lalaking technologist: light na kulay ng balat',
    '👨🏼‍💻' => 'lalaking technologist: katamtamang light na kulay ng balat',
    '👨🏽‍💻' => 'lalaking technologist: katamtamang kulay ng balat',
    '👨🏾‍💻' => 'lalaking technologist: katamtamang dark na kulay ng balat',
    '👨🏿‍💻' => 'lalaking technologist: dark na kulay ng balat',
    '👩🏻‍💻' => 'babaeng technologist: light na kulay ng balat',
    '👩🏼‍💻' => 'babaeng technologist: katamtamang light na kulay ng balat',
    '👩🏽‍💻' => 'babaeng technologist: katamtamang kulay ng balat',
    '👩🏾‍💻' => 'babaeng technologist: katamtamang dark na kulay ng balat',
    '👩🏿‍💻' => 'babaeng technologist: dark na kulay ng balat',
    '🧑🏻‍🎤' => 'mang-aawit: light na kulay ng balat',
    '🧑🏼‍🎤' => 'mang-aawit: katamtamang light na kulay ng balat',
    '🧑🏽‍🎤' => 'mang-aawit: katamtamang kulay ng balat',
    '🧑🏾‍🎤' => 'mang-aawit: katamtamang dark na kulay ng balat',
    '🧑🏿‍🎤' => 'mang-aawit: dark na kulay ng balat',
    '👨🏻‍🎤' => 'lalaking mang-aawit: light na kulay ng balat',
    '👨🏼‍🎤' => 'lalaking mang-aawit: katamtamang light na kulay ng balat',
    '👨🏽‍🎤' => 'lalaking mang-aawit: katamtamang kulay ng balat',
    '👨🏾‍🎤' => 'lalaking mang-aawit: katamtamang dark na kulay ng balat',
    '👨🏿‍🎤' => 'lalaking mang-aawit: dark na kulay ng balat',
    '👩🏻‍🎤' => 'babaeng mang-aawit: light na kulay ng balat',
    '👩🏼‍🎤' => 'babaeng mang-aawit: katamtamang light na kulay ng balat',
    '👩🏽‍🎤' => 'babaeng mang-aawit: katamtamang kulay ng balat',
    '👩🏾‍🎤' => 'babaeng mang-aawit: katamtamang dark na kulay ng balat',
    '👩🏿‍🎤' => 'babaeng mang-aawit: dark na kulay ng balat',
    '🧑🏻‍🎨' => 'pintor: light na kulay ng balat',
    '🧑🏼‍🎨' => 'pintor: katamtamang light na kulay ng balat',
    '🧑🏽‍🎨' => 'pintor: katamtamang kulay ng balat',
    '🧑🏾‍🎨' => 'pintor: katamtamang dark na kulay ng balat',
    '🧑🏿‍🎨' => 'pintor: dark na kulay ng balat',
    '👨🏻‍🎨' => 'lalaking pintor: light na kulay ng balat',
    '👨🏼‍🎨' => 'lalaking pintor: katamtamang light na kulay ng balat',
    '👨🏽‍🎨' => 'lalaking pintor: katamtamang kulay ng balat',
    '👨🏾‍🎨' => 'lalaking pintor: katamtamang dark na kulay ng balat',
    '👨🏿‍🎨' => 'lalaking pintor: dark na kulay ng balat',
    '👩🏻‍🎨' => 'babaeng pintor: light na kulay ng balat',
    '👩🏼‍🎨' => 'babaeng pintor: katamtamang light na kulay ng balat',
    '👩🏽‍🎨' => 'babaeng pintor: katamtamang kulay ng balat',
    '👩🏾‍🎨' => 'babaeng pintor: katamtamang dark na kulay ng balat',
    '👩🏿‍🎨' => 'babaeng pintor: dark na kulay ng balat',
    '🧑🏻‍✈' => 'piloto: light na kulay ng balat',
    '🧑🏼‍✈' => 'piloto: katamtamang light na kulay ng balat',
    '🧑🏽‍✈' => 'piloto: katamtamang kulay ng balat',
    '🧑🏾‍✈' => 'piloto: katamtamang dark na kulay ng balat',
    '🧑🏿‍✈' => 'piloto: dark na kulay ng balat',
    '👨🏻‍✈' => 'lalaking piloto: light na kulay ng balat',
    '👨🏼‍✈' => 'lalaking piloto: katamtamang light na kulay ng balat',
    '👨🏽‍✈' => 'lalaking piloto: katamtamang kulay ng balat',
    '👨🏾‍✈' => 'lalaking piloto: katamtamang dark na kulay ng balat',
    '👨🏿‍✈' => 'lalaking piloto: dark na kulay ng balat',
    '👩🏻‍✈' => 'babaeng piloto: light na kulay ng balat',
    '👩🏼‍✈' => 'babaeng piloto: katamtamang light na kulay ng balat',
    '👩🏽‍✈' => 'babaeng piloto: katamtamang kulay ng balat',
    '👩🏾‍✈' => 'babaeng piloto: katamtamang dark na kulay ng balat',
    '👩🏿‍✈' => 'babaeng piloto: dark na kulay ng balat',
    '🧑🏻‍🚀' => 'astronaut: light na kulay ng balat',
    '🧑🏼‍🚀' => 'astronaut: katamtamang light na kulay ng balat',
    '🧑🏽‍🚀' => 'astronaut: katamtamang kulay ng balat',
    '🧑🏾‍🚀' => 'astronaut: katamtamang dark na kulay ng balat',
    '🧑🏿‍🚀' => 'astronaut: dark na kulay ng balat',
    '👨🏻‍🚀' => 'lalaking astronaut: light na kulay ng balat',
    '👨🏼‍🚀' => 'lalaking astronaut: katamtamang light na kulay ng balat',
    '👨🏽‍🚀' => 'lalaking astronaut: katamtamang kulay ng balat',
    '👨🏾‍🚀' => 'lalaking astronaut: katamtamang dark na kulay ng balat',
    '👨🏿‍🚀' => 'lalaking astronaut: dark na kulay ng balat',
    '👩🏻‍🚀' => 'babaeng astronaut: light na kulay ng balat',
    '👩🏼‍🚀' => 'babaeng astronaut: katamtamang light na kulay ng balat',
    '👩🏽‍🚀' => 'babaeng astronaut: katamtamang kulay ng balat',
    '👩🏾‍🚀' => 'babaeng astronaut: katamtamang dark na kulay ng balat',
    '👩🏿‍🚀' => 'babaeng astronaut: dark na kulay ng balat',
    '🧑🏻‍🚒' => 'bumbero: light na kulay ng balat',
    '🧑🏼‍🚒' => 'bumbero: katamtamang light na kulay ng balat',
    '🧑🏽‍🚒' => 'bumbero: katamtamang kulay ng balat',
    '🧑🏾‍🚒' => 'bumbero: katamtamang dark na kulay ng balat',
    '🧑🏿‍🚒' => 'bumbero: dark na kulay ng balat',
    '👨🏻‍🚒' => 'lalaking bumbero: light na kulay ng balat',
    '👨🏼‍🚒' => 'lalaking bumbero: katamtamang light na kulay ng balat',
    '👨🏽‍🚒' => 'lalaking bumbero: katamtamang kulay ng balat',
    '👨🏾‍🚒' => 'lalaking bumbero: katamtamang dark na kulay ng balat',
    '👨🏿‍🚒' => 'lalaking bumbero: dark na kulay ng balat',
    '👩🏻‍🚒' => 'babaeng bumbero: light na kulay ng balat',
    '👩🏼‍🚒' => 'babaeng bumbero: katamtamang light na kulay ng balat',
    '👩🏽‍🚒' => 'babaeng bumbero: katamtamang kulay ng balat',
    '👩🏾‍🚒' => 'babaeng bumbero: katamtamang dark na kulay ng balat',
    '👩🏿‍🚒' => 'babaeng bumbero: dark na kulay ng balat',
    '👮🏻‍♂' => 'lalaking pulis: light na kulay ng balat',
    '👮🏼‍♂' => 'lalaking pulis: katamtamang light na kulay ng balat',
    '👮🏽‍♂' => 'lalaking pulis: katamtamang kulay ng balat',
    '👮🏾‍♂' => 'lalaking pulis: katamtamang dark na kulay ng balat',
    '👮🏿‍♂' => 'lalaking pulis: dark na kulay ng balat',
    '👮🏻‍♀' => 'babaeng pulis: light na kulay ng balat',
    '👮🏼‍♀' => 'babaeng pulis: katamtamang light na kulay ng balat',
    '👮🏽‍♀' => 'babaeng pulis: katamtamang kulay ng balat',
    '👮🏾‍♀' => 'babaeng pulis: katamtamang dark na kulay ng balat',
    '👮🏿‍♀' => 'babaeng pulis: dark na kulay ng balat',
    '🕵🏻‍♂' => 'lalaking detektib: light na kulay ng balat',
    '🕵🏼‍♂' => 'lalaking detektib: katamtamang light na kulay ng balat',
    '🕵🏽‍♂' => 'lalaking detektib: katamtamang kulay ng balat',
    '🕵🏾‍♂' => 'lalaking detektib: katamtamang dark na kulay ng balat',
    '🕵🏿‍♂' => 'lalaking detektib: dark na kulay ng balat',
    '🕵🏻‍♀' => 'babaeng detektib: light na kulay ng balat',
    '🕵🏼‍♀' => 'babaeng detektib: katamtamang light na kulay ng balat',
    '🕵🏽‍♀' => 'babaeng detektib: katamtamang kulay ng balat',
    '🕵🏾‍♀' => 'babaeng detektib: katamtamang dark na kulay ng balat',
    '🕵🏿‍♀' => 'babaeng detektib: dark na kulay ng balat',
    '💂🏻‍♂' => 'lalaking guwardya: light na kulay ng balat',
    '💂🏼‍♂' => 'lalaking guwardya: katamtamang light na kulay ng balat',
    '💂🏽‍♂' => 'lalaking guwardya: katamtamang kulay ng balat',
    '💂🏾‍♂' => 'lalaking guwardya: katamtamang dark na kulay ng balat',
    '💂🏿‍♂' => 'lalaking guwardya: dark na kulay ng balat',
    '💂🏻‍♀' => 'babaeng guwardya: light na kulay ng balat',
    '💂🏼‍♀' => 'babaeng guwardya: katamtamang light na kulay ng balat',
    '💂🏽‍♀' => 'babaeng guwardya: katamtamang kulay ng balat',
    '💂🏾‍♀' => 'babaeng guwardya: katamtamang dark na kulay ng balat',
    '💂🏿‍♀' => 'babaeng guwardya: dark na kulay ng balat',
    '👷🏻‍♂' => 'lalaking trabahador sa konstruksyon: light na kulay ng balat',
    '👷🏼‍♂' => 'lalaking trabahador sa konstruksyon: katamtamang light na kulay ng balat',
    '👷🏽‍♂' => 'lalaking trabahador sa konstruksyon: katamtamang kulay ng balat',
    '👷🏾‍♂' => 'lalaking trabahador sa konstruksyon: katamtamang dark na kulay ng balat',
    '👷🏿‍♂' => 'lalaking trabahador sa konstruksyon: dark na kulay ng balat',
    '👷🏻‍♀' => 'babaeng trabahador sa konstruksyon: light na kulay ng balat',
    '👷🏼‍♀' => 'babaeng trabahador sa konstruksyon: katamtamang light na kulay ng balat',
    '👷🏽‍♀' => 'babaeng trabahador sa konstruksyon: katamtamang kulay ng balat',
    '👷🏾‍♀' => 'babaeng trabahador sa konstruksyon: katamtamang dark na kulay ng balat',
    '👷🏿‍♀' => 'babaeng trabahador sa konstruksyon: dark na kulay ng balat',
    '👳🏻‍♂' => 'lalaking may turban: light na kulay ng balat',
    '👳🏼‍♂' => 'lalaking may turban: katamtamang light na kulay ng balat',
    '👳🏽‍♂' => 'lalaking may turban: katamtamang kulay ng balat',
    '👳🏾‍♂' => 'lalaking may turban: katamtamang dark na kulay ng balat',
    '👳🏿‍♂' => 'lalaking may turban: dark na kulay ng balat',
    '👳🏻‍♀' => 'babaeng may turban: light na kulay ng balat',
    '👳🏼‍♀' => 'babaeng may turban: katamtamang light na kulay ng balat',
    '👳🏽‍♀' => 'babaeng may turban: katamtamang kulay ng balat',
    '👳🏾‍♀' => 'babaeng may turban: katamtamang dark na kulay ng balat',
    '👳🏿‍♀' => 'babaeng may turban: dark na kulay ng balat',
    '🤵🏻‍♂' => 'lalaking naka-tuxedo: light na kulay ng balat',
    '🤵🏼‍♂' => 'lalaking naka-tuxedo: katamtamang light na kulay ng balat',
    '🤵🏽‍♂' => 'lalaking naka-tuxedo: katamtamang kulay ng balat',
    '🤵🏾‍♂' => 'lalaking naka-tuxedo: katamtamang dark na kulay ng balat',
    '🤵🏿‍♂' => 'lalaking naka-tuxedo: dark na kulay ng balat',
    '🤵🏻‍♀' => 'babaeng naka-tuxedo: light na kulay ng balat',
    '🤵🏼‍♀' => 'babaeng naka-tuxedo: katamtamang light na kulay ng balat',
    '🤵🏽‍♀' => 'babaeng naka-tuxedo: katamtamang kulay ng balat',
    '🤵🏾‍♀' => 'babaeng naka-tuxedo: katamtamang dark na kulay ng balat',
    '🤵🏿‍♀' => 'babaeng naka-tuxedo: dark na kulay ng balat',
    '👰🏻‍♂' => 'lalaking nakabelo: light na kulay ng balat',
    '👰🏼‍♂' => 'lalaking nakabelo: katamtamang light na kulay ng balat',
    '👰🏽‍♂' => 'lalaking nakabelo: katamtamang kulay ng balat',
    '👰🏾‍♂' => 'lalaking nakabelo: katamtamang dark na kulay ng balat',
    '👰🏿‍♂' => 'lalaking nakabelo: dark na kulay ng balat',
    '👰🏻‍♀' => 'babaeng nakabelo: light na kulay ng balat',
    '👰🏼‍♀' => 'babaeng nakabelo: katamtamang light na kulay ng balat',
    '👰🏽‍♀' => 'babaeng nakabelo: katamtamang kulay ng balat',
    '👰🏾‍♀' => 'babaeng nakabelo: katamtamang dark na kulay ng balat',
    '👰🏿‍♀' => 'babaeng nakabelo: dark na kulay ng balat',
    '👩🏻‍🍼' => 'babaeng nagpapadede ng sanggol: light na kulay ng balat',
    '👩🏼‍🍼' => 'babaeng nagpapadede ng sanggol: katamtamang light na kulay ng balat',
    '👩🏽‍🍼' => 'babaeng nagpapadede ng sanggol: katamtamang kulay ng balat',
    '👩🏾‍🍼' => 'babaeng nagpapadede ng sanggol: katamtamang dark na kulay ng balat',
    '👩🏿‍🍼' => 'babaeng nagpapadede ng sanggol: dark na kulay ng balat',
    '👨🏻‍🍼' => 'lalaking nagpapadede ng sanggol: light na kulay ng balat',
    '👨🏼‍🍼' => 'lalaking nagpapadede ng sanggol: katamtamang light na kulay ng balat',
    '👨🏽‍🍼' => 'lalaking nagpapadede ng sanggol: katamtamang kulay ng balat',
    '👨🏾‍🍼' => 'lalaking nagpapadede ng sanggol: katamtamang dark na kulay ng balat',
    '👨🏿‍🍼' => 'lalaking nagpapadede ng sanggol: dark na kulay ng balat',
    '🧑🏻‍🍼' => 'taong nagpapadede ng sanggol: light na kulay ng balat',
    '🧑🏼‍🍼' => 'taong nagpapadede ng sanggol: katamtamang light na kulay ng balat',
    '🧑🏽‍🍼' => 'taong nagpapadede ng sanggol: katamtamang kulay ng balat',
    '🧑🏾‍🍼' => 'taong nagpapadede ng sanggol: katamtamang dark na kulay ng balat',
    '🧑🏿‍🍼' => 'taong nagpapadede ng sanggol: dark na kulay ng balat',
    '🧑🏻‍🎄' => 'mx claus: light na kulay ng balat',
    '🧑🏼‍🎄' => 'mx claus: katamtamang light na kulay ng balat',
    '🧑🏽‍🎄' => 'mx claus: katamtamang kulay ng balat',
    '🧑🏾‍🎄' => 'mx claus: katamtamang dark na kulay ng balat',
    '🧑🏿‍🎄' => 'mx claus: dark na kulay ng balat',
    '🦸🏻‍♂' => 'lalaking superhero: light na kulay ng balat',
    '🦸🏼‍♂' => 'lalaking superhero: katamtamang light na kulay ng balat',
    '🦸🏽‍♂' => 'lalaking superhero: katamtamang kulay ng balat',
    '🦸🏾‍♂' => 'lalaking superhero: katamtamang dark na kulay ng balat',
    '🦸🏿‍♂' => 'lalaking superhero: dark na kulay ng balat',
    '🦸🏻‍♀' => 'babaeng superhero: light na kulay ng balat',
    '🦸🏼‍♀' => 'babaeng superhero: katamtamang light na kulay ng balat',
    '🦸🏽‍♀' => 'babaeng superhero: katamtamang kulay ng balat',
    '🦸🏾‍♀' => 'babaeng superhero: katamtamang dark na kulay ng balat',
    '🦸🏿‍♀' => 'babaeng superhero: dark na kulay ng balat',
    '🦹🏻‍♂' => 'lalaking supervillain: light na kulay ng balat',
    '🦹🏼‍♂' => 'lalaking supervillain: katamtamang light na kulay ng balat',
    '🦹🏽‍♂' => 'lalaking supervillain: katamtamang kulay ng balat',
    '🦹🏾‍♂' => 'lalaking supervillain: katamtamang dark na kulay ng balat',
    '🦹🏿‍♂' => 'lalaking supervillain: dark na kulay ng balat',
    '🦹🏻‍♀' => 'babaeng supervillain: light na kulay ng balat',
    '🦹🏼‍♀' => 'babaeng supervillain: katamtamang light na kulay ng balat',
    '🦹🏽‍♀' => 'babaeng supervillain: katamtamang kulay ng balat',
    '🦹🏾‍♀' => 'babaeng supervillain: katamtamang dark na kulay ng balat',
    '🦹🏿‍♀' => 'babaeng supervillain: dark na kulay ng balat',
    '🧙🏻‍♂' => 'lalaking salamangkero: light na kulay ng balat',
    '🧙🏼‍♂' => 'lalaking salamangkero: katamtamang light na kulay ng balat',
    '🧙🏽‍♂' => 'lalaking salamangkero: katamtamang kulay ng balat',
    '🧙🏾‍♂' => 'lalaking salamangkero: katamtamang dark na kulay ng balat',
    '🧙🏿‍♂' => 'lalaking salamangkero: dark na kulay ng balat',
    '🧙🏻‍♀' => 'babaeng salamangkero: light na kulay ng balat',
    '🧙🏼‍♀' => 'babaeng salamangkero: katamtamang light na kulay ng balat',
    '🧙🏽‍♀' => 'babaeng salamangkero: katamtamang kulay ng balat',
    '🧙🏾‍♀' => 'babaeng salamangkero: katamtamang dark na kulay ng balat',
    '🧙🏿‍♀' => 'babaeng salamangkero: dark na kulay ng balat',
    '🧚🏻‍♂' => 'lalaking diwata: light na kulay ng balat',
    '🧚🏼‍♂' => 'lalaking diwata: katamtamang light na kulay ng balat',
    '🧚🏽‍♂' => 'lalaking diwata: katamtamang kulay ng balat',
    '🧚🏾‍♂' => 'lalaking diwata: katamtamang dark na kulay ng balat',
    '🧚🏿‍♂' => 'lalaking diwata: dark na kulay ng balat',
    '🧚🏻‍♀' => 'babaeng diwata: light na kulay ng balat',
    '🧚🏼‍♀' => 'babaeng diwata: katamtamang light na kulay ng balat',
    '🧚🏽‍♀' => 'babaeng diwata: katamtamang kulay ng balat',
    '🧚🏾‍♀' => 'babaeng diwata: katamtamang dark na kulay ng balat',
    '🧚🏿‍♀' => 'babaeng diwata: dark na kulay ng balat',
    '🧛🏻‍♂' => 'lalaking bampira: light na kulay ng balat',
    '🧛🏼‍♂' => 'lalaking bampira: katamtamang light na kulay ng balat',
    '🧛🏽‍♂' => 'lalaking bampira: katamtamang kulay ng balat',
    '🧛🏾‍♂' => 'lalaking bampira: katamtamang dark na kulay ng balat',
    '🧛🏿‍♂' => 'lalaking bampira: dark na kulay ng balat',
    '🧛🏻‍♀' => 'babaeng bampira: light na kulay ng balat',
    '🧛🏼‍♀' => 'babaeng bampira: katamtamang light na kulay ng balat',
    '🧛🏽‍♀' => 'babaeng bampira: katamtamang kulay ng balat',
    '🧛🏾‍♀' => 'babaeng bampira: katamtamang dark na kulay ng balat',
    '🧛🏿‍♀' => 'babaeng bampira: dark na kulay ng balat',
    '🧜🏻‍♂' => 'lalaking sirena: light na kulay ng balat',
    '🧜🏼‍♂' => 'lalaking sirena: katamtamang light na kulay ng balat',
    '🧜🏽‍♂' => 'lalaking sirena: katamtamang kulay ng balat',
    '🧜🏾‍♂' => 'lalaking sirena: katamtamang dark na kulay ng balat',
    '🧜🏿‍♂' => 'lalaking sirena: dark na kulay ng balat',
    '🧜🏻‍♀' => 'sirena: light na kulay ng balat',
    '🧜🏼‍♀' => 'sirena: katamtamang light na kulay ng balat',
    '🧜🏽‍♀' => 'sirena: katamtamang kulay ng balat',
    '🧜🏾‍♀' => 'sirena: katamtamang dark na kulay ng balat',
    '🧜🏿‍♀' => 'sirena: dark na kulay ng balat',
    '🧝🏻‍♂' => 'lalaking duwende: light na kulay ng balat',
    '🧝🏼‍♂' => 'lalaking duwende: katamtamang light na kulay ng balat',
    '🧝🏽‍♂' => 'lalaking duwende: katamtamang kulay ng balat',
    '🧝🏾‍♂' => 'lalaking duwende: katamtamang dark na kulay ng balat',
    '🧝🏿‍♂' => 'lalaking duwende: dark na kulay ng balat',
    '🧝🏻‍♀' => 'babaeng duwende: light na kulay ng balat',
    '🧝🏼‍♀' => 'babaeng duwende: katamtamang light na kulay ng balat',
    '🧝🏽‍♀' => 'babaeng duwende: katamtamang kulay ng balat',
    '🧝🏾‍♀' => 'babaeng duwende: katamtamang dark na kulay ng balat',
    '🧝🏿‍♀' => 'babaeng duwende: dark na kulay ng balat',
    '💆🏻‍♂' => 'lalaking nagpapamasahe ng mukha: light na kulay ng balat',
    '💆🏼‍♂' => 'lalaking nagpapamasahe ng mukha: katamtamang light na kulay ng balat',
    '💆🏽‍♂' => 'lalaking nagpapamasahe ng mukha: katamtamang kulay ng balat',
    '💆🏾‍♂' => 'lalaking nagpapamasahe ng mukha: katamtamang dark na kulay ng balat',
    '💆🏿‍♂' => 'lalaking nagpapamasahe ng mukha: dark na kulay ng balat',
    '💆🏻‍♀' => 'babaeng nagpapamasahe ng mukha: light na kulay ng balat',
    '💆🏼‍♀' => 'babaeng nagpapamasahe ng mukha: katamtamang light na kulay ng balat',
    '💆🏽‍♀' => 'babaeng nagpapamasahe ng mukha: katamtamang kulay ng balat',
    '💆🏾‍♀' => 'babaeng nagpapamasahe ng mukha: katamtamang dark na kulay ng balat',
    '💆🏿‍♀' => 'babaeng nagpapamasahe ng mukha: dark na kulay ng balat',
    '💇🏻‍♂' => 'lalaking nagpapagupit: light na kulay ng balat',
    '💇🏼‍♂' => 'lalaking nagpapagupit: katamtamang light na kulay ng balat',
    '💇🏽‍♂' => 'lalaking nagpapagupit: katamtamang kulay ng balat',
    '💇🏾‍♂' => 'lalaking nagpapagupit: katamtamang dark na kulay ng balat',
    '💇🏿‍♂' => 'lalaking nagpapagupit: dark na kulay ng balat',
    '💇🏻‍♀' => 'babaeng nagpapagupit: light na kulay ng balat',
    '💇🏼‍♀' => 'babaeng nagpapagupit: katamtamang light na kulay ng balat',
    '💇🏽‍♀' => 'babaeng nagpapagupit: katamtamang kulay ng balat',
    '💇🏾‍♀' => 'babaeng nagpapagupit: katamtamang dark na kulay ng balat',
    '💇🏿‍♀' => 'babaeng nagpapagupit: dark na kulay ng balat',
    '🚶🏻‍♂' => 'lalaking naglalakad: light na kulay ng balat',
    '🚶🏼‍♂' => 'lalaking naglalakad: katamtamang light na kulay ng balat',
    '🚶🏽‍♂' => 'lalaking naglalakad: katamtamang kulay ng balat',
    '🚶🏾‍♂' => 'lalaking naglalakad: katamtamang dark na kulay ng balat',
    '🚶🏿‍♂' => 'lalaking naglalakad: dark na kulay ng balat',
    '🚶🏻‍♀' => 'babaeng naglalakad: light na kulay ng balat',
    '🚶🏼‍♀' => 'babaeng naglalakad: katamtamang light na kulay ng balat',
    '🚶🏽‍♀' => 'babaeng naglalakad: katamtamang kulay ng balat',
    '🚶🏾‍♀' => 'babaeng naglalakad: katamtamang dark na kulay ng balat',
    '🚶🏿‍♀' => 'babaeng naglalakad: dark na kulay ng balat',
    '🚶🏻‍➡' => 'taong naglalakad: light na kulay ng balat, nakaharap sa kanan',
    '🚶🏼‍➡' => 'taong naglalakad: katamtamang light na kulay ng balat, nakaharap sa kanan',
    '🚶🏽‍➡' => 'taong naglalakad: katamtamang kulay ng balat, nakaharap sa kanan',
    '🚶🏾‍➡' => 'taong naglalakad: katamtamang dark na kulay ng balat, nakaharap sa kanan',
    '🚶🏿‍➡' => 'taong naglalakad: dark na kulay ng balat, nakaharap sa kanan',
    '🧍🏻‍♂' => 'lalaking nakatayo: light na kulay ng balat',
    '🧍🏼‍♂' => 'lalaking nakatayo: katamtamang light na kulay ng balat',
    '🧍🏽‍♂' => 'lalaking nakatayo: katamtamang kulay ng balat',
    '🧍🏾‍♂' => 'lalaking nakatayo: katamtamang dark na kulay ng balat',
    '🧍🏿‍♂' => 'lalaking nakatayo: dark na kulay ng balat',
    '🧍🏻‍♀' => 'babaeng nakatayo: light na kulay ng balat',
    '🧍🏼‍♀' => 'babaeng nakatayo: katamtamang light na kulay ng balat',
    '🧍🏽‍♀' => 'babaeng nakatayo: katamtamang kulay ng balat',
    '🧍🏾‍♀' => 'babaeng nakatayo: katamtamang dark na kulay ng balat',
    '🧍🏿‍♀' => 'babaeng nakatayo: dark na kulay ng balat',
    '🧎🏻‍♂' => 'lalaking nakaluhod: light na kulay ng balat',
    '🧎🏼‍♂' => 'lalaking nakaluhod: katamtamang light na kulay ng balat',
    '🧎🏽‍♂' => 'lalaking nakaluhod: katamtamang kulay ng balat',
    '🧎🏾‍♂' => 'lalaking nakaluhod: katamtamang dark na kulay ng balat',
    '🧎🏿‍♂' => 'lalaking nakaluhod: dark na kulay ng balat',
    '🧎🏻‍♀' => 'babaeng nakaluhod: light na kulay ng balat',
    '🧎🏼‍♀' => 'babaeng nakaluhod: katamtamang light na kulay ng balat',
    '🧎🏽‍♀' => 'babaeng nakaluhod: katamtamang kulay ng balat',
    '🧎🏾‍♀' => 'babaeng nakaluhod: katamtamang dark na kulay ng balat',
    '🧎🏿‍♀' => 'babaeng nakaluhod: dark na kulay ng balat',
    '🧎🏻‍➡' => 'taong nakaluhod: light na kulay ng balat, nakaharap sa kanan',
    '🧎🏼‍➡' => 'taong nakaluhod: katamtamang light na kulay ng balat, nakaharap sa kanan',
    '🧎🏽‍➡' => 'taong nakaluhod: katamtamang kulay ng balat, nakaharap sa kanan',
    '🧎🏾‍➡' => 'taong nakaluhod: katamtamang dark na kulay ng balat, nakaharap sa kanan',
    '🧎🏿‍➡' => 'taong nakaluhod: dark na kulay ng balat, nakaharap sa kanan',
    '🧑🏻‍🦯' => 'taong may tungkod: light na kulay ng balat',
    '🧑🏼‍🦯' => 'taong may tungkod: katamtamang light na kulay ng balat',
    '🧑🏽‍🦯' => 'taong may tungkod: katamtamang kulay ng balat',
    '🧑🏾‍🦯' => 'taong may tungkod: katamtamang dark na kulay ng balat',
    '🧑🏿‍🦯' => 'taong may tungkod: dark na kulay ng balat',
    '👨🏻‍🦯' => 'lalaking may baston: light na kulay ng balat',
    '👨🏼‍🦯' => 'lalaking may baston: katamtamang light na kulay ng balat',
    '👨🏽‍🦯' => 'lalaking may baston: katamtamang kulay ng balat',
    '👨🏾‍🦯' => 'lalaking may baston: katamtamang dark na kulay ng balat',
    '👨🏿‍🦯' => 'lalaking may baston: dark na kulay ng balat',
    '👩🏻‍🦯' => 'babaeng may baston: light na kulay ng balat',
    '👩🏼‍🦯' => 'babaeng may baston: katamtamang light na kulay ng balat',
    '👩🏽‍🦯' => 'babaeng may baston: katamtamang kulay ng balat',
    '👩🏾‍🦯' => 'babaeng may baston: katamtamang dark na kulay ng balat',
    '👩🏿‍🦯' => 'babaeng may baston: dark na kulay ng balat',
    '🧑🏻‍🦼' => 'tao sa de-kuryenteng wheelchair: light na kulay ng balat',
    '🧑🏼‍🦼' => 'tao sa de-kuryenteng wheelchair: katamtamang light na kulay ng balat',
    '🧑🏽‍🦼' => 'tao sa de-kuryenteng wheelchair: katamtamang kulay ng balat',
    '🧑🏾‍🦼' => 'tao sa de-kuryenteng wheelchair: katamtamang dark na kulay ng balat',
    '🧑🏿‍🦼' => 'tao sa de-kuryenteng wheelchair: dark na kulay ng balat',
    '👨🏻‍🦼' => 'lalaki sa de-kuryenteng wheelchair: light na kulay ng balat',
    '👨🏼‍🦼' => 'lalaki sa de-kuryenteng wheelchair: katamtamang light na kulay ng balat',
    '👨🏽‍🦼' => 'lalaki sa de-kuryenteng wheelchair: katamtamang kulay ng balat',
    '👨🏾‍🦼' => 'lalaki sa de-kuryenteng wheelchair: katamtamang dark na kulay ng balat',
    '👨🏿‍🦼' => 'lalaki sa de-kuryenteng wheelchair: dark na kulay ng balat',
    '👩🏻‍🦼' => 'babae sa de-kuryenteng wheelchair: light na kulay ng balat',
    '👩🏼‍🦼' => 'babae sa de-kuryenteng wheelchair: katamtamang light na kulay ng balat',
    '👩🏽‍🦼' => 'babae sa de-kuryenteng wheelchair: katamtamang kulay ng balat',
    '👩🏾‍🦼' => 'babae sa de-kuryenteng wheelchair: katamtamang dark na kulay ng balat',
    '👩🏿‍🦼' => 'babae sa de-kuryenteng wheelchair: dark na kulay ng balat',
    '🧑🏻‍🦽' => 'tao sa manu-manong wheelchair: light na kulay ng balat',
    '🧑🏼‍🦽' => 'tao sa manu-manong wheelchair: katamtamang light na kulay ng balat',
    '🧑🏽‍🦽' => 'tao sa manu-manong wheelchair: katamtamang kulay ng balat',
    '🧑🏾‍🦽' => 'tao sa manu-manong wheelchair: katamtamang dark na kulay ng balat',
    '🧑🏿‍🦽' => 'tao sa manu-manong wheelchair: dark na kulay ng balat',
    '👨🏻‍🦽' => 'lalaki sa manu-manong wheelchair: light na kulay ng balat',
    '👨🏼‍🦽' => 'lalaki sa manu-manong wheelchair: katamtamang light na kulay ng balat',
    '👨🏽‍🦽' => 'lalaki sa manu-manong wheelchair: katamtamang kulay ng balat',
    '👨🏾‍🦽' => 'lalaki sa manu-manong wheelchair: katamtamang dark na kulay ng balat',
    '👨🏿‍🦽' => 'lalaki sa manu-manong wheelchair: dark na kulay ng balat',
    '👩🏻‍🦽' => 'babae sa manu-manong wheelchair: light na kulay ng balat',
    '👩🏼‍🦽' => 'babae sa manu-manong wheelchair: katamtamang light na kulay ng balat',
    '👩🏽‍🦽' => 'babae sa manu-manong wheelchair: katamtamang kulay ng balat',
    '👩🏾‍🦽' => 'babae sa manu-manong wheelchair: katamtamang dark na kulay ng balat',
    '👩🏿‍🦽' => 'babae sa manu-manong wheelchair: dark na kulay ng balat',
    '🏃🏻‍♂' => 'lalaking tumatakbo: light na kulay ng balat',
    '🏃🏼‍♂' => 'lalaking tumatakbo: katamtamang light na kulay ng balat',
    '🏃🏽‍♂' => 'lalaking tumatakbo: katamtamang kulay ng balat',
    '🏃🏾‍♂' => 'lalaking tumatakbo: katamtamang dark na kulay ng balat',
    '🏃🏿‍♂' => 'lalaking tumatakbo: dark na kulay ng balat',
    '🏃🏻‍♀' => 'babaeng tumatakbo: light na kulay ng balat',
    '🏃🏼‍♀' => 'babaeng tumatakbo: katamtamang light na kulay ng balat',
    '🏃🏽‍♀' => 'babaeng tumatakbo: katamtamang kulay ng balat',
    '🏃🏾‍♀' => 'babaeng tumatakbo: katamtamang dark na kulay ng balat',
    '🏃🏿‍♀' => 'babaeng tumatakbo: dark na kulay ng balat',
    '🏃🏻‍➡' => 'tumatakbo: light na kulay ng balat, nakaharap sa kanan',
    '🏃🏼‍➡' => 'tumatakbo: katamtamang light na kulay ng balat, nakaharap sa kanan',
    '🏃🏽‍➡' => 'tumatakbo: katamtamang kulay ng balat, nakaharap sa kanan',
    '🏃🏾‍➡' => 'tumatakbo: katamtamang dark na kulay ng balat, nakaharap sa kanan',
    '🏃🏿‍➡' => 'tumatakbo: dark na kulay ng balat, nakaharap sa kanan',
    '👯🏻‍♀' => 'babaeng nagpa-party: light na kulay ng balat',
    '👯🏼‍♀' => 'babaeng nagpa-party: katamtamang light na kulay ng balat',
    '👯🏽‍♀' => 'babaeng nagpa-party: katamtamang kulay ng balat',
    '👯🏾‍♀' => 'babaeng nagpa-party: katamtamang dark na kulay ng balat',
    '👯🏿‍♀' => 'babaeng nagpa-party: dark na kulay ng balat',
    '👯🏻‍♂' => 'mga lalaking may tainga ng kuneho: light na kulay ng balat',
    '👯🏼‍♂' => 'mga lalaking may tainga ng kuneho: katamtamang light na kulay ng balat',
    '👯🏽‍♂' => 'mga lalaking may tainga ng kuneho: katamtamang kulay ng balat',
    '👯🏾‍♂' => 'mga lalaking may tainga ng kuneho: katamtamang dark na kulay ng balat',
    '👯🏿‍♂' => 'mga lalaking may tainga ng kuneho: dark na kulay ng balat',
    '🧖🏻‍♂' => 'lalaki sa sauna: light na kulay ng balat',
    '🧖🏼‍♂' => 'lalaki sa sauna: katamtamang light na kulay ng balat',
    '🧖🏽‍♂' => 'lalaki sa sauna: katamtamang kulay ng balat',
    '🧖🏾‍♂' => 'lalaki sa sauna: katamtamang dark na kulay ng balat',
    '🧖🏿‍♂' => 'lalaki sa sauna: dark na kulay ng balat',
    '🧖🏻‍♀' => 'babae na nasa sauna: light na kulay ng balat',
    '🧖🏼‍♀' => 'babae na nasa sauna: katamtamang light na kulay ng balat',
    '🧖🏽‍♀' => 'babae na nasa sauna: katamtamang kulay ng balat',
    '🧖🏾‍♀' => 'babae na nasa sauna: katamtamang dark na kulay ng balat',
    '🧖🏿‍♀' => 'babae na nasa sauna: dark na kulay ng balat',
    '🧗🏻‍♂' => 'lalaki na umaakyat: light na kulay ng balat',
    '🧗🏼‍♂' => 'lalaki na umaakyat: katamtamang light na kulay ng balat',
    '🧗🏽‍♂' => 'lalaki na umaakyat: katamtamang kulay ng balat',
    '🧗🏾‍♂' => 'lalaki na umaakyat: katamtamang dark na kulay ng balat',
    '🧗🏿‍♂' => 'lalaki na umaakyat: dark na kulay ng balat',
    '🧗🏻‍♀' => 'babae na umaakyat: light na kulay ng balat',
    '🧗🏼‍♀' => 'babae na umaakyat: katamtamang light na kulay ng balat',
    '🧗🏽‍♀' => 'babae na umaakyat: katamtamang kulay ng balat',
    '🧗🏾‍♀' => 'babae na umaakyat: katamtamang dark na kulay ng balat',
    '🧗🏿‍♀' => 'babae na umaakyat: dark na kulay ng balat',
    '🏌🏻‍♂' => 'lalaking naglalaro ng golf: light na kulay ng balat',
    '🏌🏼‍♂' => 'lalaking naglalaro ng golf: katamtamang light na kulay ng balat',
    '🏌🏽‍♂' => 'lalaking naglalaro ng golf: katamtamang kulay ng balat',
    '🏌🏾‍♂' => 'lalaking naglalaro ng golf: katamtamang dark na kulay ng balat',
    '🏌🏿‍♂' => 'lalaking naglalaro ng golf: dark na kulay ng balat',
    '🏌🏻‍♀' => 'babaeng naglalaro ng golf: light na kulay ng balat',
    '🏌🏼‍♀' => 'babaeng naglalaro ng golf: katamtamang light na kulay ng balat',
    '🏌🏽‍♀' => 'babaeng naglalaro ng golf: katamtamang kulay ng balat',
    '🏌🏾‍♀' => 'babaeng naglalaro ng golf: katamtamang dark na kulay ng balat',
    '🏌🏿‍♀' => 'babaeng naglalaro ng golf: dark na kulay ng balat',
    '🏄🏻‍♂' => 'lalaking nagsu-surf: light na kulay ng balat',
    '🏄🏼‍♂' => 'lalaking nagsu-surf: katamtamang light na kulay ng balat',
    '🏄🏽‍♂' => 'lalaking nagsu-surf: katamtamang kulay ng balat',
    '🏄🏾‍♂' => 'lalaking nagsu-surf: katamtamang dark na kulay ng balat',
    '🏄🏿‍♂' => 'lalaking nagsu-surf: dark na kulay ng balat',
    '🏄🏻‍♀' => 'babaeng nagsu-surf: light na kulay ng balat',
    '🏄🏼‍♀' => 'babaeng nagsu-surf: katamtamang light na kulay ng balat',
    '🏄🏽‍♀' => 'babaeng nagsu-surf: katamtamang kulay ng balat',
    '🏄🏾‍♀' => 'babaeng nagsu-surf: katamtamang dark na kulay ng balat',
    '🏄🏿‍♀' => 'babaeng nagsu-surf: dark na kulay ng balat',
    '🚣🏻‍♂' => 'lalaking nagsasagwan: light na kulay ng balat',
    '🚣🏼‍♂' => 'lalaking nagsasagwan: katamtamang light na kulay ng balat',
    '🚣🏽‍♂' => 'lalaking nagsasagwan: katamtamang kulay ng balat',
    '🚣🏾‍♂' => 'lalaking nagsasagwan: katamtamang dark na kulay ng balat',
    '🚣🏿‍♂' => 'lalaking nagsasagwan: dark na kulay ng balat',
    '🚣🏻‍♀' => 'babaeng nagsasagwan: light na kulay ng balat',
    '🚣🏼‍♀' => 'babaeng nagsasagwan: katamtamang light na kulay ng balat',
    '🚣🏽‍♀' => 'babaeng nagsasagwan: katamtamang kulay ng balat',
    '🚣🏾‍♀' => 'babaeng nagsasagwan: katamtamang dark na kulay ng balat',
    '🚣🏿‍♀' => 'babaeng nagsasagwan: dark na kulay ng balat',
    '🏊🏻‍♂' => 'lalaking lumalangoy: light na kulay ng balat',
    '🏊🏼‍♂' => 'lalaking lumalangoy: katamtamang light na kulay ng balat',
    '🏊🏽‍♂' => 'lalaking lumalangoy: katamtamang kulay ng balat',
    '🏊🏾‍♂' => 'lalaking lumalangoy: katamtamang dark na kulay ng balat',
    '🏊🏿‍♂' => 'lalaking lumalangoy: dark na kulay ng balat',
    '🏊🏻‍♀' => 'babaeng lumalangoy: light na kulay ng balat',
    '🏊🏼‍♀' => 'babaeng lumalangoy: katamtamang light na kulay ng balat',
    '🏊🏽‍♀' => 'babaeng lumalangoy: katamtamang kulay ng balat',
    '🏊🏾‍♀' => 'babaeng lumalangoy: katamtamang dark na kulay ng balat',
    '🏊🏿‍♀' => 'babaeng lumalangoy: dark na kulay ng balat',
    '⛹🏻‍♂' => 'lalaking may bola: light na kulay ng balat',
    '⛹🏼‍♂' => 'lalaking may bola: katamtamang light na kulay ng balat',
    '⛹🏽‍♂' => 'lalaking may bola: katamtamang kulay ng balat',
    '⛹🏾‍♂' => 'lalaking may bola: katamtamang dark na kulay ng balat',
    '⛹🏿‍♂' => 'lalaking may bola: dark na kulay ng balat',
    '⛹🏻‍♀' => 'babaeng may bola: light na kulay ng balat',
    '⛹🏼‍♀' => 'babaeng may bola: katamtamang light na kulay ng balat',
    '⛹🏽‍♀' => 'babaeng may bola: katamtamang kulay ng balat',
    '⛹🏾‍♀' => 'babaeng may bola: katamtamang dark na kulay ng balat',
    '⛹🏿‍♀' => 'babaeng may bola: dark na kulay ng balat',
    '🏋🏻‍♂' => 'lalaking nagwe-weight lift: light na kulay ng balat',
    '🏋🏼‍♂' => 'lalaking nagwe-weight lift: katamtamang light na kulay ng balat',
    '🏋🏽‍♂' => 'lalaking nagwe-weight lift: katamtamang kulay ng balat',
    '🏋🏾‍♂' => 'lalaking nagwe-weight lift: katamtamang dark na kulay ng balat',
    '🏋🏿‍♂' => 'lalaking nagwe-weight lift: dark na kulay ng balat',
    '🏋🏻‍♀' => 'babaeng nagwe-weight lift: light na kulay ng balat',
    '🏋🏼‍♀' => 'babaeng nagwe-weight lift: katamtamang light na kulay ng balat',
    '🏋🏽‍♀' => 'babaeng nagwe-weight lift: katamtamang kulay ng balat',
    '🏋🏾‍♀' => 'babaeng nagwe-weight lift: katamtamang dark na kulay ng balat',
    '🏋🏿‍♀' => 'babaeng nagwe-weight lift: dark na kulay ng balat',
    '🚴🏻‍♂' => 'lalaking nagbibisikleta: light na kulay ng balat',
    '🚴🏼‍♂' => 'lalaking nagbibisikleta: katamtamang light na kulay ng balat',
    '🚴🏽‍♂' => 'lalaking nagbibisikleta: katamtamang kulay ng balat',
    '🚴🏾‍♂' => 'lalaking nagbibisikleta: katamtamang dark na kulay ng balat',
    '🚴🏿‍♂' => 'lalaking nagbibisikleta: dark na kulay ng balat',
    '🚴🏻‍♀' => 'babaeng nagbibisikleta: light na kulay ng balat',
    '🚴🏼‍♀' => 'babaeng nagbibisikleta: katamtamang light na kulay ng balat',
    '🚴🏽‍♀' => 'babaeng nagbibisikleta: katamtamang kulay ng balat',
    '🚴🏾‍♀' => 'babaeng nagbibisikleta: katamtamang dark na kulay ng balat',
    '🚴🏿‍♀' => 'babaeng nagbibisikleta: dark na kulay ng balat',
    '🚵🏻‍♂' => 'lalaking nagma-mountain bike: light na kulay ng balat',
    '🚵🏼‍♂' => 'lalaking nagma-mountain bike: katamtamang light na kulay ng balat',
    '🚵🏽‍♂' => 'lalaking nagma-mountain bike: katamtamang kulay ng balat',
    '🚵🏾‍♂' => 'lalaking nagma-mountain bike: katamtamang dark na kulay ng balat',
    '🚵🏿‍♂' => 'lalaking nagma-mountain bike: dark na kulay ng balat',
    '🚵🏻‍♀' => 'babaeng nagma-mountain bike: light na kulay ng balat',
    '🚵🏼‍♀' => 'babaeng nagma-mountain bike: katamtamang light na kulay ng balat',
    '🚵🏽‍♀' => 'babaeng nagma-mountain bike: katamtamang kulay ng balat',
    '🚵🏾‍♀' => 'babaeng nagma-mountain bike: katamtamang dark na kulay ng balat',
    '🚵🏿‍♀' => 'babaeng nagma-mountain bike: dark na kulay ng balat',
    '🤸🏻‍♂' => 'lalaking nagka-cartwheel: light na kulay ng balat',
    '🤸🏼‍♂' => 'lalaking nagka-cartwheel: katamtamang light na kulay ng balat',
    '🤸🏽‍♂' => 'lalaking nagka-cartwheel: katamtamang kulay ng balat',
    '🤸🏾‍♂' => 'lalaking nagka-cartwheel: katamtamang dark na kulay ng balat',
    '🤸🏿‍♂' => 'lalaking nagka-cartwheel: dark na kulay ng balat',
    '🤸🏻‍♀' => 'babaeng nagka-cartwheel: light na kulay ng balat',
    '🤸🏼‍♀' => 'babaeng nagka-cartwheel: katamtamang light na kulay ng balat',
    '🤸🏽‍♀' => 'babaeng nagka-cartwheel: katamtamang kulay ng balat',
    '🤸🏾‍♀' => 'babaeng nagka-cartwheel: katamtamang dark na kulay ng balat',
    '🤸🏿‍♀' => 'babaeng nagka-cartwheel: dark na kulay ng balat',
    '🤼🏻‍♀' => 'babaeng nakikipagbuno: light na kulay ng balat',
    '🤼🏼‍♀' => 'babaeng nakikipagbuno: katamtamang light na kulay ng balat',
    '🤼🏽‍♀' => 'babaeng nakikipagbuno: katamtamang kulay ng balat',
    '🤼🏾‍♀' => 'babaeng nakikipagbuno: katamtamang dark na kulay ng balat',
    '🤼🏿‍♀' => 'babaeng nakikipagbuno: dark na kulay ng balat',
    '🤼🏻‍♂' => 'lalaking nakikipagbuno: light na kulay ng balat',
    '🤼🏼‍♂' => 'lalaking nakikipagbuno: katamtamang light na kulay ng balat',
    '🤼🏽‍♂' => 'lalaking nakikipagbuno: katamtamang kulay ng balat',
    '🤼🏾‍♂' => 'lalaking nakikipagbuno: katamtamang dark na kulay ng balat',
    '🤼🏿‍♂' => 'lalaking nakikipagbuno: dark na kulay ng balat',
    '🤽🏻‍♂' => 'lalaking naglalaro ng water polo: light na kulay ng balat',
    '🤽🏼‍♂' => 'lalaking naglalaro ng water polo: katamtamang light na kulay ng balat',
    '🤽🏽‍♂' => 'lalaking naglalaro ng water polo: katamtamang kulay ng balat',
    '🤽🏾‍♂' => 'lalaking naglalaro ng water polo: katamtamang dark na kulay ng balat',
    '🤽🏿‍♂' => 'lalaking naglalaro ng water polo: dark na kulay ng balat',
    '🤽🏻‍♀' => 'babaeng naglalaro ng water polo: light na kulay ng balat',
    '🤽🏼‍♀' => 'babaeng naglalaro ng water polo: katamtamang light na kulay ng balat',
    '🤽🏽‍♀' => 'babaeng naglalaro ng water polo: katamtamang kulay ng balat',
    '🤽🏾‍♀' => 'babaeng naglalaro ng water polo: katamtamang dark na kulay ng balat',
    '🤽🏿‍♀' => 'babaeng naglalaro ng water polo: dark na kulay ng balat',
    '🤾🏻‍♂' => 'lalaking naglalaro ng handball: light na kulay ng balat',
    '🤾🏼‍♂' => 'lalaking naglalaro ng handball: katamtamang light na kulay ng balat',
    '🤾🏽‍♂' => 'lalaking naglalaro ng handball: katamtamang kulay ng balat',
    '🤾🏾‍♂' => 'lalaking naglalaro ng handball: katamtamang dark na kulay ng balat',
    '🤾🏿‍♂' => 'lalaking naglalaro ng handball: dark na kulay ng balat',
    '🤾🏻‍♀' => 'babaeng naglalaro ng handball: light na kulay ng balat',
    '🤾🏼‍♀' => 'babaeng naglalaro ng handball: katamtamang light na kulay ng balat',
    '🤾🏽‍♀' => 'babaeng naglalaro ng handball: katamtamang kulay ng balat',
    '🤾🏾‍♀' => 'babaeng naglalaro ng handball: katamtamang dark na kulay ng balat',
    '🤾🏿‍♀' => 'babaeng naglalaro ng handball: dark na kulay ng balat',
    '🤹🏻‍♂' => 'lalaking nagja-juggle: light na kulay ng balat',
    '🤹🏼‍♂' => 'lalaking nagja-juggle: katamtamang light na kulay ng balat',
    '🤹🏽‍♂' => 'lalaking nagja-juggle: katamtamang kulay ng balat',
    '🤹🏾‍♂' => 'lalaking nagja-juggle: katamtamang dark na kulay ng balat',
    '🤹🏿‍♂' => 'lalaking nagja-juggle: dark na kulay ng balat',
    '🤹🏻‍♀' => 'babaeng nagja-juggle: light na kulay ng balat',
    '🤹🏼‍♀' => 'babaeng nagja-juggle: katamtamang light na kulay ng balat',
    '🤹🏽‍♀' => 'babaeng nagja-juggle: katamtamang kulay ng balat',
    '🤹🏾‍♀' => 'babaeng nagja-juggle: katamtamang dark na kulay ng balat',
    '🤹🏿‍♀' => 'babaeng nagja-juggle: dark na kulay ng balat',
    '🧘🏻‍♂' => 'lalaki na naka-lotus position: light na kulay ng balat',
    '🧘🏼‍♂' => 'lalaki na naka-lotus position: katamtamang light na kulay ng balat',
    '🧘🏽‍♂' => 'lalaki na naka-lotus position: katamtamang kulay ng balat',
    '🧘🏾‍♂' => 'lalaki na naka-lotus position: katamtamang dark na kulay ng balat',
    '🧘🏿‍♂' => 'lalaki na naka-lotus position: dark na kulay ng balat',
    '🧘🏻‍♀' => 'babae na naka-lotus position: light na kulay ng balat',
    '🧘🏼‍♀' => 'babae na naka-lotus position: katamtamang light na kulay ng balat',
    '🧘🏽‍♀' => 'babae na naka-lotus position: katamtamang kulay ng balat',
    '🧘🏾‍♀' => 'babae na naka-lotus position: katamtamang dark na kulay ng balat',
    '🧘🏿‍♀' => 'babae na naka-lotus position: dark na kulay ng balat',
    '🧑‍🦰' => 'tao: pulang buhok',
    '🧑‍🦱' => 'tao: kulot na buhok',
    '🧑‍🦳' => 'tao: puting buhok',
    '🧑‍🦲' => 'tao: kalbo',
    '👨‍🦰' => 'lalaki: pulang buhok',
    '👨‍🦱' => 'lalaki: kulot na buhok',
    '👨‍🦳' => 'lalaki: puting buhok',
    '👨‍🦲' => 'lalaki: kalbo',
    '👩‍🦰' => 'babae: pulang buhok',
    '👩‍🦱' => 'babae: kulot na buhok',
    '👩‍🦳' => 'babae: puting buhok',
    '👩‍🦲' => 'babae: kalbo',
    '🚶‍➡' => 'taong naglalakad: nakaharap sa kanan',
    '🧎‍➡' => 'taong nakaluhod: nakaharap sa kanan',
    '🏃‍➡' => 'tumatakbo: nakaharap sa kanan',
    '👨‍👦' => 'pamilya: lalaki, batang lalaki',
    '👨‍👧' => 'pamilya: lalaki, batang babae',
    '👩‍👦' => 'pamilya: babae, batang lalaki',
    '👩‍👧' => 'pamilya: babae, batang babae',
    '😶‍🌫' => 'mukhang nasa ulap',
    '😮‍💨' => 'mukhang humihinga palabas',
    '🙂‍↕' => 'gumagalaw na mukha paayon',
    '😵‍💫' => 'mukang may spiral na mata',
    '❤‍🔥' => 'pusong nasa apoy',
    '❤‍🩹' => 'pag-ayos sa puso',
    '👁‍🗨' => 'mata sa speech bubble',
    '🧔‍♂' => 'lalaki: balbas',
    '👱‍♂' => 'lalaking blonde',
    '🧔‍♀' => 'babae: balbas',
    '👱‍♀' => 'babae: blond na buhok',
    '🙍‍♂' => 'lalaking nakasimangot',
    '🙍‍♀' => 'babaeng nakasimangot',
    '🙎‍♂' => 'lalaking nakanguso',
    '🙎‍♀' => 'babaeng nakanguso',
    '🙅‍♂' => 'lalaking kumukumpas na hindi ok',
    '🙅‍♀' => 'babaeng kumukumpas na hindi ok',
    '🙆‍♂' => 'lalaking kumukumpas na ok',
    '🙆‍♀' => 'babaeng kumukumpas na ok',
    '💁‍♂' => 'lalaking nakatikwas ang kamay',
    '💁‍♀' => 'babaeng nakatikwas ang kamay',
    '🙋‍♂' => 'lalaking nakataas ang kamay',
    '🙋‍♀' => 'babaeng nakataas ang kamay',
    '🧏‍♂' => 'lalaking bingi',
    '🧏‍♀' => 'babaeng bingi',
    '🙇‍♂' => 'lalaking nakayuko',
    '🙇‍♀' => 'babaeng nakayuko',
    '🤦‍♂' => 'lalaking naka-facepalm',
    '🤦‍♀' => 'babaeng naka-facepalm',
    '🤷‍♂' => 'lalaking nagkikibit-balikat',
    '🤷‍♀' => 'babaeng nagkikibit-balikat',
    '🧑‍⚕' => 'health worker',
    '👨‍⚕' => 'lalaking health worker',
    '👩‍⚕' => 'babaeng health worker',
    '🧑‍🎓' => 'estudyante',
    '👨‍🎓' => 'lalaking mag-aaral',
    '👩‍🎓' => 'babaeng mag-aaral',
    '🧑‍🏫' => 'guro',
    '👨‍🏫' => 'lalaking guro',
    '👩‍🏫' => 'babaeng guro',
    '🧑‍⚖' => 'hukom',
    '👨‍⚖' => 'lalaking hukom',
    '👩‍⚖' => 'babaeng hukom',
    '🧑‍🌾' => 'magsasaka',
    '👨‍🌾' => 'lalaking magsasaka',
    '👩‍🌾' => 'babaeng magsasaka',
    '🧑‍🍳' => 'tagaluto',
    '👨‍🍳' => 'kusinero',
    '👩‍🍳' => 'kusinera',
    '🧑‍🔧' => 'mekaniko',
    '👨‍🔧' => 'lalaking mekaniko',
    '👩‍🔧' => 'babaeng mekaniko',
    '🧑‍🏭' => 'trabahador sa pabrika',
    '👨‍🏭' => 'lalaking manggagawa sa pabrika',
    '👩‍🏭' => 'babaeng manggagawa sa pabrika',
    '🧑‍💼' => 'trabahador sa opisina',
    '👨‍💼' => 'empleyado sa opisina',
    '👩‍💼' => 'babaeng empleyado sa opisina',
    '🧑‍🔬' => 'siyentipiko',
    '👨‍🔬' => 'lalaking siyentipiko',
    '👩‍🔬' => 'babaeng siyentipiko',
    '🧑‍💻' => 'technologist',
    '👨‍💻' => 'lalaking technologist',
    '👩‍💻' => 'babaeng technologist',
    '🧑‍🎤' => 'mang-aawit',
    '👨‍🎤' => 'lalaking mang-aawit',
    '👩‍🎤' => 'babaeng mang-aawit',
    '🧑‍🎨' => 'pintor',
    '👨‍🎨' => 'lalaking pintor',
    '👩‍🎨' => 'babaeng pintor',
    '🧑‍✈' => 'piloto',
    '👨‍✈' => 'lalaking piloto',
    '👩‍✈' => 'babaeng piloto',
    '🧑‍🚀' => 'astronaut',
    '👨‍🚀' => 'lalaking astronaut',
    '👩‍🚀' => 'babaeng astronaut',
    '🧑‍🚒' => 'bumbero',
    '👨‍🚒' => 'lalaking bumbero',
    '👩‍🚒' => 'babaeng bumbero',
    '👮‍♂' => 'lalaking pulis',
    '👮‍♀' => 'babaeng pulis',
    '🕵‍♂' => 'lalaking detektib',
    '🕵‍♀' => 'babaeng detektib',
    '💂‍♂' => 'lalaking guwardya',
    '💂‍♀' => 'babaeng guwardya',
    '👷‍♂' => 'lalaking trabahador sa konstruksyon',
    '👷‍♀' => 'babaeng trabahador sa konstruksyon',
    '👳‍♂' => 'lalaking may turban',
    '👳‍♀' => 'babaeng may turban',
    '🤵‍♂' => 'lalaking naka-tuxedo',
    '🤵‍♀' => 'babaeng naka-tuxedo',
    '👰‍♂' => 'lalaking nakabelo',
    '👰‍♀' => 'babaeng nakabelo',
    '👩‍🍼' => 'babaeng nagpapadede ng sanggol',
    '👨‍🍼' => 'lalaking nagpapadede ng sanggol',
    '🧑‍🍼' => 'taong nagpapadede ng sanggol',
    '🧑‍🎄' => 'mx claus',
    '🦸‍♂' => 'lalaking superhero',
    '🦸‍♀' => 'babaeng superhero',
    '🦹‍♂' => 'lalaking supervillain',
    '🦹‍♀' => 'babaeng supervillain',
    '🧙‍♂' => 'lalaking salamangkero',
    '🧙‍♀' => 'babaeng salamangkero',
    '🧚‍♂' => 'lalaking diwata',
    '🧚‍♀' => 'babaeng diwata',
    '🧛‍♂' => 'lalaking bampira',
    '🧛‍♀' => 'babaeng bampira',
    '🧜‍♂' => 'lalaking sirena',
    '🧜‍♀' => 'sirena',
    '🧝‍♂' => 'lalaking duwende',
    '🧝‍♀' => 'babaeng duwende',
    '🧞‍♂' => 'lalaking genie',
    '🧞‍♀' => 'babaeng genie',
    '🧟‍♂' => 'lalaking zombie',
    '🧟‍♀' => 'babaeng zombie',
    '💆‍♂' => 'lalaking nagpapamasahe ng mukha',
    '💆‍♀' => 'babaeng nagpapamasahe ng mukha',
    '💇‍♂' => 'lalaking nagpapagupit',
    '💇‍♀' => 'babaeng nagpapagupit',
    '🚶‍♂' => 'lalaking naglalakad',
    '🚶‍♀' => 'babaeng naglalakad',
    '🧍‍♂' => 'lalaking nakatayo',
    '🧍‍♀' => 'babaeng nakatayo',
    '🧎‍♂' => 'lalaking nakaluhod',
    '🧎‍♀' => 'babaeng nakaluhod',
    '🧑‍🦯' => 'taong may tungkod',
    '👨‍🦯' => 'lalaking may baston',
    '👩‍🦯' => 'babaeng may baston',
    '🧑‍🦼' => 'tao sa de-kuryenteng wheelchair',
    '👨‍🦼' => 'lalaki sa de-kuryenteng wheelchair',
    '👩‍🦼' => 'babae sa de-kuryenteng wheelchair',
    '🧑‍🦽' => 'tao sa manu-manong wheelchair',
    '👨‍🦽' => 'lalaki sa manu-manong wheelchair',
    '👩‍🦽' => 'babae sa manu-manong wheelchair',
    '🏃‍♂' => 'lalaking tumatakbo',
    '🏃‍♀' => 'babaeng tumatakbo',
    '🧑‍🩰' => 'ballet dancer',
    '👯‍♂' => 'mga lalaking may tainga ng kuneho',
    '👯‍♀' => 'babaeng nagpa-party',
    '🧖‍♂' => 'lalaki sa sauna',
    '🧖‍♀' => 'babae na nasa sauna',
    '🧗‍♂' => 'lalaki na umaakyat',
    '🧗‍♀' => 'babae na umaakyat',
    '🏌‍♂' => 'lalaking naglalaro ng golf',
    '🏌‍♀' => 'babaeng naglalaro ng golf',
    '🏄‍♂' => 'lalaking nagsu-surf',
    '🏄‍♀' => 'babaeng nagsu-surf',
    '🚣‍♂' => 'lalaking nagsasagwan',
    '🚣‍♀' => 'babaeng nagsasagwan',
    '🏊‍♂' => 'lalaking lumalangoy',
    '🏊‍♀' => 'babaeng lumalangoy',
    '⛹‍♂' => 'lalaking may bola',
    '⛹‍♀' => 'babaeng may bola',
    '🏋‍♂' => 'lalaking nagwe-weight lift',
    '🏋‍♀' => 'babaeng nagwe-weight lift',
    '🚴‍♂' => 'lalaking nagbibisikleta',
    '🚴‍♀' => 'babaeng nagbibisikleta',
    '🚵‍♂' => 'lalaking nagma-mountain bike',
    '🚵‍♀' => 'babaeng nagma-mountain bike',
    '🤸‍♂' => 'lalaking nagka-cartwheel',
    '🤸‍♀' => 'babaeng nagka-cartwheel',
    '🤼‍♂' => 'lalaking nakikipagbuno',
    '🤼‍♀' => 'babaeng nakikipagbuno',
    '🤽‍♂' => 'lalaking naglalaro ng water polo',
    '🤽‍♀' => 'babaeng naglalaro ng water polo',
    '🤾‍♂' => 'lalaking naglalaro ng handball',
    '🤾‍♀' => 'babaeng naglalaro ng handball',
    '🤹‍♂' => 'lalaking nagja-juggle',
    '🤹‍♀' => 'babaeng nagja-juggle',
    '🧘‍♂' => 'lalaki na naka-lotus position',
    '🧘‍♀' => 'babae na naka-lotus position',
    '🧑‍🧒' => 'pamilya: adulto, bata',
    '🐕‍🦺' => 'asong panserbisyo',
    '🐈‍⬛' => 'itim na pusa',
    '🐻‍❄' => 'polar bear',
    '🐦‍⬛' => 'itim na ibon',
    '🐦‍🔥' => 'phoenix',
    '🍋‍🟩' => 'dayap',
    '🍄‍🟫' => 'kayumanggi na kabute',
    '⛓‍💥' => 'lagot na kadena',
    '🏳‍🌈' => 'bahagharing bandila',
    '🏳‍⚧' => 'bandila ng transgender',
    '🏴‍☠' => 'bandila ng pirata',
    '👋🏻' => 'kumakaway na kamay: light na kulay ng balat',
    '👋🏼' => 'kumakaway na kamay: katamtamang light na kulay ng balat',
    '👋🏽' => 'kumakaway na kamay: katamtamang kulay ng balat',
    '👋🏾' => 'kumakaway na kamay: katamtamang dark na kulay ng balat',
    '👋🏿' => 'kumakaway na kamay: dark na kulay ng balat',
    '🤚🏻' => 'nakataas na baliktad na kamay: light na kulay ng balat',
    '🤚🏼' => 'nakataas na baliktad na kamay: katamtamang light na kulay ng balat',
    '🤚🏽' => 'nakataas na baliktad na kamay: katamtamang kulay ng balat',
    '🤚🏾' => 'nakataas na baliktad na kamay: katamtamang dark na kulay ng balat',
    '🤚🏿' => 'nakataas na baliktad na kamay: dark na kulay ng balat',
    '🖐🏻' => 'nakataas na nakabukas na kamay: light na kulay ng balat',
    '🖐🏼' => 'nakataas na nakabukas na kamay: katamtamang light na kulay ng balat',
    '🖐🏽' => 'nakataas na nakabukas na kamay: katamtamang kulay ng balat',
    '🖐🏾' => 'nakataas na nakabukas na kamay: katamtamang dark na kulay ng balat',
    '🖐🏿' => 'nakataas na nakabukas na kamay: dark na kulay ng balat',
    '✋🏻' => 'nakataas na kamay: light na kulay ng balat',
    '✋🏼' => 'nakataas na kamay: katamtamang light na kulay ng balat',
    '✋🏽' => 'nakataas na kamay: katamtamang kulay ng balat',
    '✋🏾' => 'nakataas na kamay: katamtamang dark na kulay ng balat',
    '✋🏿' => 'nakataas na kamay: dark na kulay ng balat',
    '🖖🏻' => 'vulcan salute: light na kulay ng balat',
    '🖖🏼' => 'vulcan salute: katamtamang light na kulay ng balat',
    '🖖🏽' => 'vulcan salute: katamtamang kulay ng balat',
    '🖖🏾' => 'vulcan salute: katamtamang dark na kulay ng balat',
    '🖖🏿' => 'vulcan salute: dark na kulay ng balat',
    '🫱🏻' => 'pakanang kamay: light na kulay ng balat',
    '🫱🏼' => 'pakanang kamay: katamtamang light na kulay ng balat',
    '🫱🏽' => 'pakanang kamay: katamtamang kulay ng balat',
    '🫱🏾' => 'pakanang kamay: katamtamang dark na kulay ng balat',
    '🫱🏿' => 'pakanang kamay: dark na kulay ng balat',
    '🫲🏻' => 'pakaliwang kamay: light na kulay ng balat',
    '🫲🏼' => 'pakaliwang kamay: katamtamang light na kulay ng balat',
    '🫲🏽' => 'pakaliwang kamay: katamtamang kulay ng balat',
    '🫲🏾' => 'pakaliwang kamay: katamtamang dark na kulay ng balat',
    '🫲🏿' => 'pakaliwang kamay: dark na kulay ng balat',
    '🫳🏻' => 'nakataob na palad: light na kulay ng balat',
    '🫳🏼' => 'nakataob na palad: katamtamang light na kulay ng balat',
    '🫳🏽' => 'nakataob na palad: katamtamang kulay ng balat',
    '🫳🏾' => 'nakataob na palad: katamtamang dark na kulay ng balat',
    '🫳🏿' => 'nakataob na palad: dark na kulay ng balat',
    '🫴🏻' => 'nakasalong palad: light na kulay ng balat',
    '🫴🏼' => 'nakasalong palad: katamtamang light na kulay ng balat',
    '🫴🏽' => 'nakasalong palad: katamtamang kulay ng balat',
    '🫴🏾' => 'nakasalong palad: katamtamang dark na kulay ng balat',
    '🫴🏿' => 'nakasalong palad: dark na kulay ng balat',
    '🫷🏻' => 'pakaliwang tumutulak na kamay: light na kulay ng balat',
    '🫷🏼' => 'pakaliwang tumutulak na kamay: katamtamang light na kulay ng balat',
    '🫷🏽' => 'pakaliwang tumutulak na kamay: katamtamang kulay ng balat',
    '🫷🏾' => 'pakaliwang tumutulak na kamay: katamtamang dark na kulay ng balat',
    '🫷🏿' => 'pakaliwang tumutulak na kamay: dark na kulay ng balat',
    '🫸🏻' => 'pakanang tumutulak na kamay: light na kulay ng balat',
    '🫸🏼' => 'pakanang tumutulak na kamay: katamtamang light na kulay ng balat',
    '🫸🏽' => 'pakanang tumutulak na kamay: katamtamang kulay ng balat',
    '🫸🏾' => 'pakanang tumutulak na kamay: katamtamang dark na kulay ng balat',
    '🫸🏿' => 'pakanang tumutulak na kamay: dark na kulay ng balat',
    '👌🏻' => 'kamay na nagpapahiwatig ng ok: light na kulay ng balat',
    '👌🏼' => 'kamay na nagpapahiwatig ng ok: katamtamang light na kulay ng balat',
    '👌🏽' => 'kamay na nagpapahiwatig ng ok: katamtamang kulay ng balat',
    '👌🏾' => 'kamay na nagpapahiwatig ng ok: katamtamang dark na kulay ng balat',
    '👌🏿' => 'kamay na nagpapahiwatig ng ok: dark na kulay ng balat',
    '🤌🏻' => 'pakurot na daliri: light na kulay ng balat',
    '🤌🏼' => 'pakurot na daliri: katamtamang light na kulay ng balat',
    '🤌🏽' => 'pakurot na daliri: katamtamang kulay ng balat',
    '🤌🏾' => 'pakurot na daliri: katamtamang dark na kulay ng balat',
    '🤌🏿' => 'pakurot na daliri: dark na kulay ng balat',
    '🤏🏻' => 'kamay na kumukurot: light na kulay ng balat',
    '🤏🏼' => 'kamay na kumukurot: katamtamang light na kulay ng balat',
    '🤏🏽' => 'kamay na kumukurot: katamtamang kulay ng balat',
    '🤏🏾' => 'kamay na kumukurot: katamtamang dark na kulay ng balat',
    '🤏🏿' => 'kamay na kumukurot: dark na kulay ng balat',
    '✌🏻' => 'peace sign: light na kulay ng balat',
    '✌🏼' => 'peace sign: katamtamang light na kulay ng balat',
    '✌🏽' => 'peace sign: katamtamang kulay ng balat',
    '✌🏾' => 'peace sign: katamtamang dark na kulay ng balat',
    '✌🏿' => 'peace sign: dark na kulay ng balat',
    '🤞🏻' => 'naka-cross na mga daliri: light na kulay ng balat',
    '🤞🏼' => 'naka-cross na mga daliri: katamtamang light na kulay ng balat',
    '🤞🏽' => 'naka-cross na mga daliri: katamtamang kulay ng balat',
    '🤞🏾' => 'naka-cross na mga daliri: katamtamang dark na kulay ng balat',
    '🤞🏿' => 'naka-cross na mga daliri: dark na kulay ng balat',
    '🫰🏻' => 'kamay na magkakrus ang hintuturo at hinlalaki: light na kulay ng balat',
    '🫰🏼' => 'kamay na magkakrus ang hintuturo at hinlalaki: katamtamang light na kulay ng balat',
    '🫰🏽' => 'kamay na magkakrus ang hintuturo at hinlalaki: katamtamang kulay ng balat',
    '🫰🏾' => 'kamay na magkakrus ang hintuturo at hinlalaki: katamtamang dark na kulay ng balat',
    '🫰🏿' => 'kamay na magkakrus ang hintuturo at hinlalaki: dark na kulay ng balat',
    '🤟🏻' => 'love-you gesture: light na kulay ng balat',
    '🤟🏼' => 'love-you gesture: katamtamang light na kulay ng balat',
    '🤟🏽' => 'love-you gesture: katamtamang kulay ng balat',
    '🤟🏾' => 'love-you gesture: katamtamang dark na kulay ng balat',
    '🤟🏿' => 'love-you gesture: dark na kulay ng balat',
    '🤘🏻' => 'rock ’n’ roll: light na kulay ng balat',
    '🤘🏼' => 'rock ’n’ roll: katamtamang light na kulay ng balat',
    '🤘🏽' => 'rock ’n’ roll: katamtamang kulay ng balat',
    '🤘🏾' => 'rock ’n’ roll: katamtamang dark na kulay ng balat',
    '🤘🏿' => 'rock ’n’ roll: dark na kulay ng balat',
    '🤙🏻' => 'tawagan mo ko: light na kulay ng balat',
    '🤙🏼' => 'tawagan mo ko: katamtamang light na kulay ng balat',
    '🤙🏽' => 'tawagan mo ko: katamtamang kulay ng balat',
    '🤙🏾' => 'tawagan mo ko: katamtamang dark na kulay ng balat',
    '🤙🏿' => 'tawagan mo ko: dark na kulay ng balat',
    '👈🏻' => 'backhand ng hintuturo na nakaturo sa kaliwa: light na kulay ng balat',
    '👈🏼' => 'backhand ng hintuturo na nakaturo sa kaliwa: katamtamang light na kulay ng balat',
    '👈🏽' => 'backhand ng hintuturo na nakaturo sa kaliwa: katamtamang kulay ng balat',
    '👈🏾' => 'backhand ng hintuturo na nakaturo sa kaliwa: katamtamang dark na kulay ng balat',
    '👈🏿' => 'backhand ng hintuturo na nakaturo sa kaliwa: dark na kulay ng balat',
    '👉🏻' => 'backhand ng hintuturo na nakaturo sa kanan: light na kulay ng balat',
    '👉🏼' => 'backhand ng hintuturo na nakaturo sa kanan: katamtamang light na kulay ng balat',
    '👉🏽' => 'backhand ng hintuturo na nakaturo sa kanan: katamtamang kulay ng balat',
    '👉🏾' => 'backhand ng hintuturo na nakaturo sa kanan: katamtamang dark na kulay ng balat',
    '👉🏿' => 'backhand ng hintuturo na nakaturo sa kanan: dark na kulay ng balat',
    '👆🏻' => 'backhand ng hintuturo na nakaturo sa itaas: light na kulay ng balat',
    '👆🏼' => 'backhand ng hintuturo na nakaturo sa itaas: katamtamang light na kulay ng balat',
    '👆🏽' => 'backhand ng hintuturo na nakaturo sa itaas: katamtamang kulay ng balat',
    '👆🏾' => 'backhand ng hintuturo na nakaturo sa itaas: katamtamang dark na kulay ng balat',
    '👆🏿' => 'backhand ng hintuturo na nakaturo sa itaas: dark na kulay ng balat',
    '🖕🏻' => 'hinlalato: light na kulay ng balat',
    '🖕🏼' => 'hinlalato: katamtamang light na kulay ng balat',
    '🖕🏽' => 'hinlalato: katamtamang kulay ng balat',
    '🖕🏾' => 'hinlalato: katamtamang dark na kulay ng balat',
    '🖕🏿' => 'hinlalato: dark na kulay ng balat',
    '👇🏻' => 'backhand ng hintuturo na nakaturo sa ibaba: light na kulay ng balat',
    '👇🏼' => 'backhand ng hintuturo na nakaturo sa ibaba: katamtamang light na kulay ng balat',
    '👇🏽' => 'backhand ng hintuturo na nakaturo sa ibaba: katamtamang kulay ng balat',
    '👇🏾' => 'backhand ng hintuturo na nakaturo sa ibaba: katamtamang dark na kulay ng balat',
    '👇🏿' => 'backhand ng hintuturo na nakaturo sa ibaba: dark na kulay ng balat',
    '☝🏻' => 'hintuturo na nakaturo sa itaas: light na kulay ng balat',
    '☝🏼' => 'hintuturo na nakaturo sa itaas: katamtamang light na kulay ng balat',
    '☝🏽' => 'hintuturo na nakaturo sa itaas: katamtamang kulay ng balat',
    '☝🏾' => 'hintuturo na nakaturo sa itaas: katamtamang dark na kulay ng balat',
    '☝🏿' => 'hintuturo na nakaturo sa itaas: dark na kulay ng balat',
    '🫵🏻' => 'hintuturong nakaturo sa tumitingin: light na kulay ng balat',
    '🫵🏼' => 'hintuturong nakaturo sa tumitingin: katamtamang light na kulay ng balat',
    '🫵🏽' => 'hintuturong nakaturo sa tumitingin: katamtamang kulay ng balat',
    '🫵🏾' => 'hintuturong nakaturo sa tumitingin: katamtamang dark na kulay ng balat',
    '🫵🏿' => 'hintuturong nakaturo sa tumitingin: dark na kulay ng balat',
    '👍🏻' => 'thumbs up: light na kulay ng balat',
    '👍🏼' => 'thumbs up: katamtamang light na kulay ng balat',
    '👍🏽' => 'thumbs up: katamtamang kulay ng balat',
    '👍🏾' => 'thumbs up: katamtamang dark na kulay ng balat',
    '👍🏿' => 'thumbs up: dark na kulay ng balat',
    '👎🏻' => 'thumbs down: light na kulay ng balat',
    '👎🏼' => 'thumbs down: katamtamang light na kulay ng balat',
    '👎🏽' => 'thumbs down: katamtamang kulay ng balat',
    '👎🏾' => 'thumbs down: katamtamang dark na kulay ng balat',
    '👎🏿' => 'thumbs down: dark na kulay ng balat',
    '✊🏻' => 'nakataas na kamao: light na kulay ng balat',
    '✊🏼' => 'nakataas na kamao: katamtamang light na kulay ng balat',
    '✊🏽' => 'nakataas na kamao: katamtamang kulay ng balat',
    '✊🏾' => 'nakataas na kamao: katamtamang dark na kulay ng balat',
    '✊🏿' => 'nakataas na kamao: dark na kulay ng balat',
    '👊🏻' => 'pasuntok na kamao: light na kulay ng balat',
    '👊🏼' => 'pasuntok na kamao: katamtamang light na kulay ng balat',
    '👊🏽' => 'pasuntok na kamao: katamtamang kulay ng balat',
    '👊🏾' => 'pasuntok na kamao: katamtamang dark na kulay ng balat',
    '👊🏿' => 'pasuntok na kamao: dark na kulay ng balat',
    '🤛🏻' => 'pakaliwang kamao: light na kulay ng balat',
    '🤛🏼' => 'pakaliwang kamao: katamtamang light na kulay ng balat',
    '🤛🏽' => 'pakaliwang kamao: katamtamang kulay ng balat',
    '🤛🏾' => 'pakaliwang kamao: katamtamang dark na kulay ng balat',
    '🤛🏿' => 'pakaliwang kamao: dark na kulay ng balat',
    '🤜🏻' => 'pakanang kamao: light na kulay ng balat',
    '🤜🏼' => 'pakanang kamao: katamtamang light na kulay ng balat',
    '🤜🏽' => 'pakanang kamao: katamtamang kulay ng balat',
    '🤜🏾' => 'pakanang kamao: katamtamang dark na kulay ng balat',
    '🤜🏿' => 'pakanang kamao: dark na kulay ng balat',
    '👏🏻' => 'pumapalakpak: light na kulay ng balat',
    '👏🏼' => 'pumapalakpak: katamtamang light na kulay ng balat',
    '👏🏽' => 'pumapalakpak: katamtamang kulay ng balat',
    '👏🏾' => 'pumapalakpak: katamtamang dark na kulay ng balat',
    '👏🏿' => 'pumapalakpak: dark na kulay ng balat',
    '🙌🏻' => 'nakataas na mga kamay: light na kulay ng balat',
    '🙌🏼' => 'nakataas na mga kamay: katamtamang light na kulay ng balat',
    '🙌🏽' => 'nakataas na mga kamay: katamtamang kulay ng balat',
    '🙌🏾' => 'nakataas na mga kamay: katamtamang dark na kulay ng balat',
    '🙌🏿' => 'nakataas na mga kamay: dark na kulay ng balat',
    '🫶🏻' => 'nakapusong kamay: light na kulay ng balat',
    '🫶🏼' => 'nakapusong kamay: katamtamang light na kulay ng balat',
    '🫶🏽' => 'nakapusong kamay: katamtamang kulay ng balat',
    '🫶🏾' => 'nakapusong kamay: katamtamang dark na kulay ng balat',
    '🫶🏿' => 'nakapusong kamay: dark na kulay ng balat',
    '👐🏻' => 'bukas-palad: light na kulay ng balat',
    '👐🏼' => 'bukas-palad: katamtamang light na kulay ng balat',
    '👐🏽' => 'bukas-palad: katamtamang kulay ng balat',
    '👐🏾' => 'bukas-palad: katamtamang dark na kulay ng balat',
    '👐🏿' => 'bukas-palad: dark na kulay ng balat',
    '🤲🏻' => 'nakataas na magkadikit na palad: light na kulay ng balat',
    '🤲🏼' => 'nakataas na magkadikit na palad: katamtamang light na kulay ng balat',
    '🤲🏽' => 'nakataas na magkadikit na palad: katamtamang kulay ng balat',
    '🤲🏾' => 'nakataas na magkadikit na palad: katamtamang dark na kulay ng balat',
    '🤲🏿' => 'nakataas na magkadikit na palad: dark na kulay ng balat',
    '🤝🏻' => 'pagkakamay: light na kulay ng balat',
    '🤝🏼' => 'pagkakamay: katamtamang light na kulay ng balat',
    '🤝🏽' => 'pagkakamay: katamtamang kulay ng balat',
    '🤝🏾' => 'pagkakamay: katamtamang dark na kulay ng balat',
    '🤝🏿' => 'pagkakamay: dark na kulay ng balat',
    '🙏🏻' => 'magkalapat na mga palad: light na kulay ng balat',
    '🙏🏼' => 'magkalapat na mga palad: katamtamang light na kulay ng balat',
    '🙏🏽' => 'magkalapat na mga palad: katamtamang kulay ng balat',
    '🙏🏾' => 'magkalapat na mga palad: katamtamang dark na kulay ng balat',
    '🙏🏿' => 'magkalapat na mga palad: dark na kulay ng balat',
    '✍🏻' => 'nagsusulat na kamay: light na kulay ng balat',
    '✍🏼' => 'nagsusulat na kamay: katamtamang light na kulay ng balat',
    '✍🏽' => 'nagsusulat na kamay: katamtamang kulay ng balat',
    '✍🏾' => 'nagsusulat na kamay: katamtamang dark na kulay ng balat',
    '✍🏿' => 'nagsusulat na kamay: dark na kulay ng balat',
    '💅🏻' => 'nail polish: light na kulay ng balat',
    '💅🏼' => 'nail polish: katamtamang light na kulay ng balat',
    '💅🏽' => 'nail polish: katamtamang kulay ng balat',
    '💅🏾' => 'nail polish: katamtamang dark na kulay ng balat',
    '💅🏿' => 'nail polish: dark na kulay ng balat',
    '🤳🏻' => 'selfie: light na kulay ng balat',
    '🤳🏼' => 'selfie: katamtamang light na kulay ng balat',
    '🤳🏽' => 'selfie: katamtamang kulay ng balat',
    '🤳🏾' => 'selfie: katamtamang dark na kulay ng balat',
    '🤳🏿' => 'selfie: dark na kulay ng balat',
    '💪🏻' => 'pinalaking biceps: light na kulay ng balat',
    '💪🏼' => 'pinalaking biceps: katamtamang light na kulay ng balat',
    '💪🏽' => 'pinalaking biceps: katamtamang kulay ng balat',
    '💪🏾' => 'pinalaking biceps: katamtamang dark na kulay ng balat',
    '💪🏿' => 'pinalaking biceps: dark na kulay ng balat',
    '🦵🏻' => 'hita: light na kulay ng balat',
    '🦵🏼' => 'hita: katamtamang light na kulay ng balat',
    '🦵🏽' => 'hita: katamtamang kulay ng balat',
    '🦵🏾' => 'hita: katamtamang dark na kulay ng balat',
    '🦵🏿' => 'hita: dark na kulay ng balat',
    '🦶🏻' => 'paa: light na kulay ng balat',
    '🦶🏼' => 'paa: katamtamang light na kulay ng balat',
    '🦶🏽' => 'paa: katamtamang kulay ng balat',
    '🦶🏾' => 'paa: katamtamang dark na kulay ng balat',
    '🦶🏿' => 'paa: dark na kulay ng balat',
    '👂🏻' => 'tainga: light na kulay ng balat',
    '👂🏼' => 'tainga: katamtamang light na kulay ng balat',
    '👂🏽' => 'tainga: katamtamang kulay ng balat',
    '👂🏾' => 'tainga: katamtamang dark na kulay ng balat',
    '👂🏿' => 'tainga: dark na kulay ng balat',
    '🦻🏻' => 'tainga na may hearing aid: light na kulay ng balat',
    '🦻🏼' => 'tainga na may hearing aid: katamtamang light na kulay ng balat',
    '🦻🏽' => 'tainga na may hearing aid: katamtamang kulay ng balat',
    '🦻🏾' => 'tainga na may hearing aid: katamtamang dark na kulay ng balat',
    '🦻🏿' => 'tainga na may hearing aid: dark na kulay ng balat',
    '👃🏻' => 'ilong: light na kulay ng balat',
    '👃🏼' => 'ilong: katamtamang light na kulay ng balat',
    '👃🏽' => 'ilong: katamtamang kulay ng balat',
    '👃🏾' => 'ilong: katamtamang dark na kulay ng balat',
    '👃🏿' => 'ilong: dark na kulay ng balat',
    '👶🏻' => 'sanggol: light na kulay ng balat',
    '👶🏼' => 'sanggol: katamtamang light na kulay ng balat',
    '👶🏽' => 'sanggol: katamtamang kulay ng balat',
    '👶🏾' => 'sanggol: katamtamang dark na kulay ng balat',
    '👶🏿' => 'sanggol: dark na kulay ng balat',
    '🧒🏻' => 'bata: light na kulay ng balat',
    '🧒🏼' => 'bata: katamtamang light na kulay ng balat',
    '🧒🏽' => 'bata: katamtamang kulay ng balat',
    '🧒🏾' => 'bata: katamtamang dark na kulay ng balat',
    '🧒🏿' => 'bata: dark na kulay ng balat',
    '👦🏻' => 'batang lalaki: light na kulay ng balat',
    '👦🏼' => 'batang lalaki: katamtamang light na kulay ng balat',
    '👦🏽' => 'batang lalaki: katamtamang kulay ng balat',
    '👦🏾' => 'batang lalaki: katamtamang dark na kulay ng balat',
    '👦🏿' => 'batang lalaki: dark na kulay ng balat',
    '👧🏻' => 'batang babae: light na kulay ng balat',
    '👧🏼' => 'batang babae: katamtamang light na kulay ng balat',
    '👧🏽' => 'batang babae: katamtamang kulay ng balat',
    '👧🏾' => 'batang babae: katamtamang dark na kulay ng balat',
    '👧🏿' => 'batang babae: dark na kulay ng balat',
    '🧑🏻' => 'tao: light na kulay ng balat',
    '🧑🏼' => 'tao: katamtamang light na kulay ng balat',
    '🧑🏽' => 'tao: katamtamang kulay ng balat',
    '🧑🏾' => 'tao: katamtamang dark na kulay ng balat',
    '🧑🏿' => 'tao: dark na kulay ng balat',
    '👱🏻' => 'taong may blond na buhok: light na kulay ng balat',
    '👱🏼' => 'taong may blond na buhok: katamtamang light na kulay ng balat',
    '👱🏽' => 'taong may blond na buhok: katamtamang kulay ng balat',
    '👱🏾' => 'taong may blond na buhok: katamtamang dark na kulay ng balat',
    '👱🏿' => 'taong may blond na buhok: dark na kulay ng balat',
    '👨🏻' => 'lalaki: light na kulay ng balat',
    '👨🏼' => 'lalaki: katamtamang light na kulay ng balat',
    '👨🏽' => 'lalaki: katamtamang kulay ng balat',
    '👨🏾' => 'lalaki: katamtamang dark na kulay ng balat',
    '👨🏿' => 'lalaki: dark na kulay ng balat',
    '🧔🏻' => 'taong may balbas: light na kulay ng balat',
    '🧔🏼' => 'taong may balbas: katamtamang light na kulay ng balat',
    '🧔🏽' => 'taong may balbas: katamtamang kulay ng balat',
    '🧔🏾' => 'taong may balbas: katamtamang dark na kulay ng balat',
    '🧔🏿' => 'taong may balbas: dark na kulay ng balat',
    '👩🏻' => 'babae: light na kulay ng balat',
    '👩🏼' => 'babae: katamtamang light na kulay ng balat',
    '👩🏽' => 'babae: katamtamang kulay ng balat',
    '👩🏾' => 'babae: katamtamang dark na kulay ng balat',
    '👩🏿' => 'babae: dark na kulay ng balat',
    '🧓🏻' => 'mas matandang tao: light na kulay ng balat',
    '🧓🏼' => 'mas matandang tao: katamtamang light na kulay ng balat',
    '🧓🏽' => 'mas matandang tao: katamtamang kulay ng balat',
    '🧓🏾' => 'mas matandang tao: katamtamang dark na kulay ng balat',
    '🧓🏿' => 'mas matandang tao: dark na kulay ng balat',
    '👴🏻' => 'matandang lalaki: light na kulay ng balat',
    '👴🏼' => 'matandang lalaki: katamtamang light na kulay ng balat',
    '👴🏽' => 'matandang lalaki: katamtamang kulay ng balat',
    '👴🏾' => 'matandang lalaki: katamtamang dark na kulay ng balat',
    '👴🏿' => 'matandang lalaki: dark na kulay ng balat',
    '👵🏻' => 'matandang babae: light na kulay ng balat',
    '👵🏼' => 'matandang babae: katamtamang light na kulay ng balat',
    '👵🏽' => 'matandang babae: katamtamang kulay ng balat',
    '👵🏾' => 'matandang babae: katamtamang dark na kulay ng balat',
    '👵🏿' => 'matandang babae: dark na kulay ng balat',
    '🙍🏻' => 'taong nakasimangot: light na kulay ng balat',
    '🙍🏼' => 'taong nakasimangot: katamtamang light na kulay ng balat',
    '🙍🏽' => 'taong nakasimangot: katamtamang kulay ng balat',
    '🙍🏾' => 'taong nakasimangot: katamtamang dark na kulay ng balat',
    '🙍🏿' => 'taong nakasimangot: dark na kulay ng balat',
    '🙎🏻' => 'taong naka-pout: light na kulay ng balat',
    '🙎🏼' => 'taong naka-pout: katamtamang light na kulay ng balat',
    '🙎🏽' => 'taong naka-pout: katamtamang kulay ng balat',
    '🙎🏾' => 'taong naka-pout: katamtamang dark na kulay ng balat',
    '🙎🏿' => 'taong naka-pout: dark na kulay ng balat',
    '🙅🏻' => 'nagpapahiwatig na hindi pwede: light na kulay ng balat',
    '🙅🏼' => 'nagpapahiwatig na hindi pwede: katamtamang light na kulay ng balat',
    '🙅🏽' => 'nagpapahiwatig na hindi pwede: katamtamang kulay ng balat',
    '🙅🏾' => 'nagpapahiwatig na hindi pwede: katamtamang dark na kulay ng balat',
    '🙅🏿' => 'nagpapahiwatig na hindi pwede: dark na kulay ng balat',
    '🙆🏻' => 'nagpapahiwatig na ok: light na kulay ng balat',
    '🙆🏼' => 'nagpapahiwatig na ok: katamtamang light na kulay ng balat',
    '🙆🏽' => 'nagpapahiwatig na ok: katamtamang kulay ng balat',
    '🙆🏾' => 'nagpapahiwatig na ok: katamtamang dark na kulay ng balat',
    '🙆🏿' => 'nagpapahiwatig na ok: dark na kulay ng balat',
    '💁🏻' => 'taong nakatikwas ang kamay: light na kulay ng balat',
    '💁🏼' => 'taong nakatikwas ang kamay: katamtamang light na kulay ng balat',
    '💁🏽' => 'taong nakatikwas ang kamay: katamtamang kulay ng balat',
    '💁🏾' => 'taong nakatikwas ang kamay: katamtamang dark na kulay ng balat',
    '💁🏿' => 'taong nakatikwas ang kamay: dark na kulay ng balat',
    '🙋🏻' => 'masayang tao na nakataas ang kamay: light na kulay ng balat',
    '🙋🏼' => 'masayang tao na nakataas ang kamay: katamtamang light na kulay ng balat',
    '🙋🏽' => 'masayang tao na nakataas ang kamay: katamtamang kulay ng balat',
    '🙋🏾' => 'masayang tao na nakataas ang kamay: katamtamang dark na kulay ng balat',
    '🙋🏿' => 'masayang tao na nakataas ang kamay: dark na kulay ng balat',
    '🧏🏻' => 'taong bingi: light na kulay ng balat',
    '🧏🏼' => 'taong bingi: katamtamang light na kulay ng balat',
    '🧏🏽' => 'taong bingi: katamtamang kulay ng balat',
    '🧏🏾' => 'taong bingi: katamtamang dark na kulay ng balat',
    '🧏🏿' => 'taong bingi: dark na kulay ng balat',
    '🙇🏻' => 'yumuyukong tao: light na kulay ng balat',
    '🙇🏼' => 'yumuyukong tao: katamtamang light na kulay ng balat',
    '🙇🏽' => 'yumuyukong tao: katamtamang kulay ng balat',
    '🙇🏾' => 'yumuyukong tao: katamtamang dark na kulay ng balat',
    '🙇🏿' => 'yumuyukong tao: dark na kulay ng balat',
    '🤦🏻' => 'naka-facepalm: light na kulay ng balat',
    '🤦🏼' => 'naka-facepalm: katamtamang light na kulay ng balat',
    '🤦🏽' => 'naka-facepalm: katamtamang kulay ng balat',
    '🤦🏾' => 'naka-facepalm: katamtamang dark na kulay ng balat',
    '🤦🏿' => 'naka-facepalm: dark na kulay ng balat',
    '🤷🏻' => 'nagkikibit-balikat: light na kulay ng balat',
    '🤷🏼' => 'nagkikibit-balikat: katamtamang light na kulay ng balat',
    '🤷🏽' => 'nagkikibit-balikat: katamtamang kulay ng balat',
    '🤷🏾' => 'nagkikibit-balikat: katamtamang dark na kulay ng balat',
    '🤷🏿' => 'nagkikibit-balikat: dark na kulay ng balat',
    '👮🏻' => 'pulis: light na kulay ng balat',
    '👮🏼' => 'pulis: katamtamang light na kulay ng balat',
    '👮🏽' => 'pulis: katamtamang kulay ng balat',
    '👮🏾' => 'pulis: katamtamang dark na kulay ng balat',
    '👮🏿' => 'pulis: dark na kulay ng balat',
    '🕵🏻' => 'imbestigador: light na kulay ng balat',
    '🕵🏼' => 'imbestigador: katamtamang light na kulay ng balat',
    '🕵🏽' => 'imbestigador: katamtamang kulay ng balat',
    '🕵🏾' => 'imbestigador: katamtamang dark na kulay ng balat',
    '🕵🏿' => 'imbestigador: dark na kulay ng balat',
    '💂🏻' => 'gwardya: light na kulay ng balat',
    '💂🏼' => 'gwardya: katamtamang light na kulay ng balat',
    '💂🏽' => 'gwardya: katamtamang kulay ng balat',
    '💂🏾' => 'gwardya: katamtamang dark na kulay ng balat',
    '💂🏿' => 'gwardya: dark na kulay ng balat',
    '🥷🏻' => 'ninja: light na kulay ng balat',
    '🥷🏼' => 'ninja: katamtamang light na kulay ng balat',
    '🥷🏽' => 'ninja: katamtamang kulay ng balat',
    '🥷🏾' => 'ninja: katamtamang dark na kulay ng balat',
    '🥷🏿' => 'ninja: dark na kulay ng balat',
    '👷🏻' => 'construction worker: light na kulay ng balat',
    '👷🏼' => 'construction worker: katamtamang light na kulay ng balat',
    '👷🏽' => 'construction worker: katamtamang kulay ng balat',
    '👷🏾' => 'construction worker: katamtamang dark na kulay ng balat',
    '👷🏿' => 'construction worker: dark na kulay ng balat',
    '🫅🏻' => 'taong may korona: light na kulay ng balat',
    '🫅🏼' => 'taong may korona: katamtamang light na kulay ng balat',
    '🫅🏽' => 'taong may korona: katamtamang kulay ng balat',
    '🫅🏾' => 'taong may korona: katamtamang dark na kulay ng balat',
    '🫅🏿' => 'taong may korona: dark na kulay ng balat',
    '🤴🏻' => 'prinsipe: light na kulay ng balat',
    '🤴🏼' => 'prinsipe: katamtamang light na kulay ng balat',
    '🤴🏽' => 'prinsipe: katamtamang kulay ng balat',
    '🤴🏾' => 'prinsipe: katamtamang dark na kulay ng balat',
    '🤴🏿' => 'prinsipe: dark na kulay ng balat',
    '👸🏻' => 'prinsesa: light na kulay ng balat',
    '👸🏼' => 'prinsesa: katamtamang light na kulay ng balat',
    '👸🏽' => 'prinsesa: katamtamang kulay ng balat',
    '👸🏾' => 'prinsesa: katamtamang dark na kulay ng balat',
    '👸🏿' => 'prinsesa: dark na kulay ng balat',
    '👳🏻' => 'lalaking may suot na turban: light na kulay ng balat',
    '👳🏼' => 'lalaking may suot na turban: katamtamang light na kulay ng balat',
    '👳🏽' => 'lalaking may suot na turban: katamtamang kulay ng balat',
    '👳🏾' => 'lalaking may suot na turban: katamtamang dark na kulay ng balat',
    '👳🏿' => 'lalaking may suot na turban: dark na kulay ng balat',
    '👲🏻' => 'lalaking may suot na sombrerong chinese: light na kulay ng balat',
    '👲🏼' => 'lalaking may suot na sombrerong chinese: katamtamang light na kulay ng balat',
    '👲🏽' => 'lalaking may suot na sombrerong chinese: katamtamang kulay ng balat',
    '👲🏾' => 'lalaking may suot na sombrerong chinese: katamtamang dark na kulay ng balat',
    '👲🏿' => 'lalaking may suot na sombrerong chinese: dark na kulay ng balat',
    '🧕🏻' => 'babae na may headscarf: light na kulay ng balat',
    '🧕🏼' => 'babae na may headscarf: katamtamang light na kulay ng balat',
    '🧕🏽' => 'babae na may headscarf: katamtamang kulay ng balat',
    '🧕🏾' => 'babae na may headscarf: katamtamang dark na kulay ng balat',
    '🧕🏿' => 'babae na may headscarf: dark na kulay ng balat',
    '🤵🏻' => 'taong naka-tuxedo: light na kulay ng balat',
    '🤵🏼' => 'taong naka-tuxedo: katamtamang light na kulay ng balat',
    '🤵🏽' => 'taong naka-tuxedo: katamtamang kulay ng balat',
    '🤵🏾' => 'taong naka-tuxedo: katamtamang dark na kulay ng balat',
    '🤵🏿' => 'taong naka-tuxedo: dark na kulay ng balat',
    '👰🏻' => 'taong may suot na belo: light na kulay ng balat',
    '👰🏼' => 'taong may suot na belo: katamtamang light na kulay ng balat',
    '👰🏽' => 'taong may suot na belo: katamtamang kulay ng balat',
    '👰🏾' => 'taong may suot na belo: katamtamang dark na kulay ng balat',
    '👰🏿' => 'taong may suot na belo: dark na kulay ng balat',
    '🤰🏻' => 'buntis: light na kulay ng balat',
    '🤰🏼' => 'buntis: katamtamang light na kulay ng balat',
    '🤰🏽' => 'buntis: katamtamang kulay ng balat',
    '🤰🏾' => 'buntis: katamtamang dark na kulay ng balat',
    '🤰🏿' => 'buntis: dark na kulay ng balat',
    '🫃🏻' => 'lalaking buntis: light na kulay ng balat',
    '🫃🏼' => 'lalaking buntis: katamtamang light na kulay ng balat',
    '🫃🏽' => 'lalaking buntis: katamtamang kulay ng balat',
    '🫃🏾' => 'lalaking buntis: katamtamang dark na kulay ng balat',
    '🫃🏿' => 'lalaking buntis: dark na kulay ng balat',
    '🫄🏻' => 'taong buntis: light na kulay ng balat',
    '🫄🏼' => 'taong buntis: katamtamang light na kulay ng balat',
    '🫄🏽' => 'taong buntis: katamtamang kulay ng balat',
    '🫄🏾' => 'taong buntis: katamtamang dark na kulay ng balat',
    '🫄🏿' => 'taong buntis: dark na kulay ng balat',
    '🤱🏻' => 'breast-feeding: light na kulay ng balat',
    '🤱🏼' => 'breast-feeding: katamtamang light na kulay ng balat',
    '🤱🏽' => 'breast-feeding: katamtamang kulay ng balat',
    '🤱🏾' => 'breast-feeding: katamtamang dark na kulay ng balat',
    '🤱🏿' => 'breast-feeding: dark na kulay ng balat',
    '👼🏻' => 'sanggol na anghel: light na kulay ng balat',
    '👼🏼' => 'sanggol na anghel: katamtamang light na kulay ng balat',
    '👼🏽' => 'sanggol na anghel: katamtamang kulay ng balat',
    '👼🏾' => 'sanggol na anghel: katamtamang dark na kulay ng balat',
    '👼🏿' => 'sanggol na anghel: dark na kulay ng balat',
    '🎅🏻' => 'santa claus: light na kulay ng balat',
    '🎅🏼' => 'santa claus: katamtamang light na kulay ng balat',
    '🎅🏽' => 'santa claus: katamtamang kulay ng balat',
    '🎅🏾' => 'santa claus: katamtamang dark na kulay ng balat',
    '🎅🏿' => 'santa claus: dark na kulay ng balat',
    '🤶🏻' => 'Mrs Claus: light na kulay ng balat',
    '🤶🏼' => 'Mrs Claus: katamtamang light na kulay ng balat',
    '🤶🏽' => 'Mrs Claus: katamtamang kulay ng balat',
    '🤶🏾' => 'Mrs Claus: katamtamang dark na kulay ng balat',
    '🤶🏿' => 'Mrs Claus: dark na kulay ng balat',
    '🦸🏻' => 'superhero: light na kulay ng balat',
    '🦸🏼' => 'superhero: katamtamang light na kulay ng balat',
    '🦸🏽' => 'superhero: katamtamang kulay ng balat',
    '🦸🏾' => 'superhero: katamtamang dark na kulay ng balat',
    '🦸🏿' => 'superhero: dark na kulay ng balat',
    '🦹🏻' => 'supervillain: light na kulay ng balat',
    '🦹🏼' => 'supervillain: katamtamang light na kulay ng balat',
    '🦹🏽' => 'supervillain: katamtamang kulay ng balat',
    '🦹🏾' => 'supervillain: katamtamang dark na kulay ng balat',
    '🦹🏿' => 'supervillain: dark na kulay ng balat',
    '🧙🏻' => 'salamangkero: light na kulay ng balat',
    '🧙🏼' => 'salamangkero: katamtamang light na kulay ng balat',
    '🧙🏽' => 'salamangkero: katamtamang kulay ng balat',
    '🧙🏾' => 'salamangkero: katamtamang dark na kulay ng balat',
    '🧙🏿' => 'salamangkero: dark na kulay ng balat',
    '🧚🏻' => 'diwata: light na kulay ng balat',
    '🧚🏼' => 'diwata: katamtamang light na kulay ng balat',
    '🧚🏽' => 'diwata: katamtamang kulay ng balat',
    '🧚🏾' => 'diwata: katamtamang dark na kulay ng balat',
    '🧚🏿' => 'diwata: dark na kulay ng balat',
    '🧛🏻' => 'bampira: light na kulay ng balat',
    '🧛🏼' => 'bampira: katamtamang light na kulay ng balat',
    '🧛🏽' => 'bampira: katamtamang kulay ng balat',
    '🧛🏾' => 'bampira: katamtamang dark na kulay ng balat',
    '🧛🏿' => 'bampira: dark na kulay ng balat',
    '🧜🏻' => 'merperson: light na kulay ng balat',
    '🧜🏼' => 'merperson: katamtamang light na kulay ng balat',
    '🧜🏽' => 'merperson: katamtamang kulay ng balat',
    '🧜🏾' => 'merperson: katamtamang dark na kulay ng balat',
    '🧜🏿' => 'merperson: dark na kulay ng balat',
    '🧝🏻' => 'duwende: light na kulay ng balat',
    '🧝🏼' => 'duwende: katamtamang light na kulay ng balat',
    '🧝🏽' => 'duwende: katamtamang kulay ng balat',
    '🧝🏾' => 'duwende: katamtamang dark na kulay ng balat',
    '🧝🏿' => 'duwende: dark na kulay ng balat',
    '💆🏻' => 'pagpapamasahe ng mukha: light na kulay ng balat',
    '💆🏼' => 'pagpapamasahe ng mukha: katamtamang light na kulay ng balat',
    '💆🏽' => 'pagpapamasahe ng mukha: katamtamang kulay ng balat',
    '💆🏾' => 'pagpapamasahe ng mukha: katamtamang dark na kulay ng balat',
    '💆🏿' => 'pagpapamasahe ng mukha: dark na kulay ng balat',
    '💇🏻' => 'pagpapagupit ng buhok: light na kulay ng balat',
    '💇🏼' => 'pagpapagupit ng buhok: katamtamang light na kulay ng balat',
    '💇🏽' => 'pagpapagupit ng buhok: katamtamang kulay ng balat',
    '💇🏾' => 'pagpapagupit ng buhok: katamtamang dark na kulay ng balat',
    '💇🏿' => 'pagpapagupit ng buhok: dark na kulay ng balat',
    '🚶🏻' => 'taong naglalakad: light na kulay ng balat',
    '🚶🏼' => 'taong naglalakad: katamtamang light na kulay ng balat',
    '🚶🏽' => 'taong naglalakad: katamtamang kulay ng balat',
    '🚶🏾' => 'taong naglalakad: katamtamang dark na kulay ng balat',
    '🚶🏿' => 'taong naglalakad: dark na kulay ng balat',
    '🧍🏻' => 'nakatayong tao: light na kulay ng balat',
    '🧍🏼' => 'nakatayong tao: katamtamang light na kulay ng balat',
    '🧍🏽' => 'nakatayong tao: katamtamang kulay ng balat',
    '🧍🏾' => 'nakatayong tao: katamtamang dark na kulay ng balat',
    '🧍🏿' => 'nakatayong tao: dark na kulay ng balat',
    '🧎🏻' => 'taong nakaluhod: light na kulay ng balat',
    '🧎🏼' => 'taong nakaluhod: katamtamang light na kulay ng balat',
    '🧎🏽' => 'taong nakaluhod: katamtamang kulay ng balat',
    '🧎🏾' => 'taong nakaluhod: katamtamang dark na kulay ng balat',
    '🧎🏿' => 'taong nakaluhod: dark na kulay ng balat',
    '🏃🏻' => 'tumatakbo: light na kulay ng balat',
    '🏃🏼' => 'tumatakbo: katamtamang light na kulay ng balat',
    '🏃🏽' => 'tumatakbo: katamtamang kulay ng balat',
    '🏃🏾' => 'tumatakbo: katamtamang dark na kulay ng balat',
    '🏃🏿' => 'tumatakbo: dark na kulay ng balat',
    '💃🏻' => 'mananayaw: light na kulay ng balat',
    '💃🏼' => 'mananayaw: katamtamang light na kulay ng balat',
    '💃🏽' => 'mananayaw: katamtamang kulay ng balat',
    '💃🏾' => 'mananayaw: katamtamang dark na kulay ng balat',
    '💃🏿' => 'mananayaw: dark na kulay ng balat',
    '🕺🏻' => 'lalaking sumasayaw: light na kulay ng balat',
    '🕺🏼' => 'lalaking sumasayaw: katamtamang light na kulay ng balat',
    '🕺🏽' => 'lalaking sumasayaw: katamtamang kulay ng balat',
    '🕺🏾' => 'lalaking sumasayaw: katamtamang dark na kulay ng balat',
    '🕺🏿' => 'lalaking sumasayaw: dark na kulay ng balat',
    '🕴🏻' => 'lumulutang na lalaking nakapormal: light na kulay ng balat',
    '🕴🏼' => 'lumulutang na lalaking nakapormal: katamtamang light na kulay ng balat',
    '🕴🏽' => 'lumulutang na lalaking nakapormal: katamtamang kulay ng balat',
    '🕴🏾' => 'lumulutang na lalaking nakapormal: katamtamang dark na kulay ng balat',
    '🕴🏿' => 'lumulutang na lalaking nakapormal: dark na kulay ng balat',
    '👯🏻' => 'mga babaeng may tainga ng kuneho: light na kulay ng balat',
    '👯🏼' => 'mga babaeng may tainga ng kuneho: katamtamang light na kulay ng balat',
    '👯🏽' => 'mga babaeng may tainga ng kuneho: katamtamang kulay ng balat',
    '👯🏾' => 'mga babaeng may tainga ng kuneho: katamtamang dark na kulay ng balat',
    '👯🏿' => 'mga babaeng may tainga ng kuneho: dark na kulay ng balat',
    '🧖🏻' => 'tao na nasa sauna: light na kulay ng balat',
    '🧖🏼' => 'tao na nasa sauna: katamtamang light na kulay ng balat',
    '🧖🏽' => 'tao na nasa sauna: katamtamang kulay ng balat',
    '🧖🏾' => 'tao na nasa sauna: katamtamang dark na kulay ng balat',
    '🧖🏿' => 'tao na nasa sauna: dark na kulay ng balat',
    '🧗🏻' => 'tao na umaakyat: light na kulay ng balat',
    '🧗🏼' => 'tao na umaakyat: katamtamang light na kulay ng balat',
    '🧗🏽' => 'tao na umaakyat: katamtamang kulay ng balat',
    '🧗🏾' => 'tao na umaakyat: katamtamang dark na kulay ng balat',
    '🧗🏿' => 'tao na umaakyat: dark na kulay ng balat',
    '🏇🏻' => 'karerahan ng kabayo: light na kulay ng balat',
    '🏇🏼' => 'karerahan ng kabayo: katamtamang light na kulay ng balat',
    '🏇🏽' => 'karerahan ng kabayo: katamtamang kulay ng balat',
    '🏇🏾' => 'karerahan ng kabayo: katamtamang dark na kulay ng balat',
    '🏇🏿' => 'karerahan ng kabayo: dark na kulay ng balat',
    '🏂🏻' => 'snowboarder: light na kulay ng balat',
    '🏂🏼' => 'snowboarder: katamtamang light na kulay ng balat',
    '🏂🏽' => 'snowboarder: katamtamang kulay ng balat',
    '🏂🏾' => 'snowboarder: katamtamang dark na kulay ng balat',
    '🏂🏿' => 'snowboarder: dark na kulay ng balat',
    '🏌🏻' => 'golfer: light na kulay ng balat',
    '🏌🏼' => 'golfer: katamtamang light na kulay ng balat',
    '🏌🏽' => 'golfer: katamtamang kulay ng balat',
    '🏌🏾' => 'golfer: katamtamang dark na kulay ng balat',
    '🏌🏿' => 'golfer: dark na kulay ng balat',
    '🏄🏻' => 'surfer: light na kulay ng balat',
    '🏄🏼' => 'surfer: katamtamang light na kulay ng balat',
    '🏄🏽' => 'surfer: katamtamang kulay ng balat',
    '🏄🏾' => 'surfer: katamtamang dark na kulay ng balat',
    '🏄🏿' => 'surfer: dark na kulay ng balat',
    '🚣🏻' => 'bangkang de-sagwan: light na kulay ng balat',
    '🚣🏼' => 'bangkang de-sagwan: katamtamang light na kulay ng balat',
    '🚣🏽' => 'bangkang de-sagwan: katamtamang kulay ng balat',
    '🚣🏾' => 'bangkang de-sagwan: katamtamang dark na kulay ng balat',
    '🚣🏿' => 'bangkang de-sagwan: dark na kulay ng balat',
    '🏊🏻' => 'swimmer: light na kulay ng balat',
    '🏊🏼' => 'swimmer: katamtamang light na kulay ng balat',
    '🏊🏽' => 'swimmer: katamtamang kulay ng balat',
    '🏊🏾' => 'swimmer: katamtamang dark na kulay ng balat',
    '🏊🏿' => 'swimmer: dark na kulay ng balat',
    '⛹🏻' => 'taong naglalaro ng bola: light na kulay ng balat',
    '⛹🏼' => 'taong naglalaro ng bola: katamtamang light na kulay ng balat',
    '⛹🏽' => 'taong naglalaro ng bola: katamtamang kulay ng balat',
    '⛹🏾' => 'taong naglalaro ng bola: katamtamang dark na kulay ng balat',
    '⛹🏿' => 'taong naglalaro ng bola: dark na kulay ng balat',
    '🏋🏻' => 'weight lifter: light na kulay ng balat',
    '🏋🏼' => 'weight lifter: katamtamang light na kulay ng balat',
    '🏋🏽' => 'weight lifter: katamtamang kulay ng balat',
    '🏋🏾' => 'weight lifter: katamtamang dark na kulay ng balat',
    '🏋🏿' => 'weight lifter: dark na kulay ng balat',
    '🚴🏻' => 'nagbibisikleta: light na kulay ng balat',
    '🚴🏼' => 'nagbibisikleta: katamtamang light na kulay ng balat',
    '🚴🏽' => 'nagbibisikleta: katamtamang kulay ng balat',
    '🚴🏾' => 'nagbibisikleta: katamtamang dark na kulay ng balat',
    '🚴🏿' => 'nagbibisikleta: dark na kulay ng balat',
    '🚵🏻' => 'mountain biker: light na kulay ng balat',
    '🚵🏼' => 'mountain biker: katamtamang light na kulay ng balat',
    '🚵🏽' => 'mountain biker: katamtamang kulay ng balat',
    '🚵🏾' => 'mountain biker: katamtamang dark na kulay ng balat',
    '🚵🏿' => 'mountain biker: dark na kulay ng balat',
    '🤸🏻' => 'taong nagka-cartwheel: light na kulay ng balat',
    '🤸🏼' => 'taong nagka-cartwheel: katamtamang light na kulay ng balat',
    '🤸🏽' => 'taong nagka-cartwheel: katamtamang kulay ng balat',
    '🤸🏾' => 'taong nagka-cartwheel: katamtamang dark na kulay ng balat',
    '🤸🏿' => 'taong nagka-cartwheel: dark na kulay ng balat',
    '🤼🏻' => 'mga taong nagre-wrestling: light na kulay ng balat',
    '🤼🏼' => 'mga taong nagre-wrestling: katamtamang light na kulay ng balat',
    '🤼🏽' => 'mga taong nagre-wrestling: katamtamang kulay ng balat',
    '🤼🏾' => 'mga taong nagre-wrestling: katamtamang dark na kulay ng balat',
    '🤼🏿' => 'mga taong nagre-wrestling: dark na kulay ng balat',
    '🤽🏻' => 'taong naglalaro ng water polo: light na kulay ng balat',
    '🤽🏼' => 'taong naglalaro ng water polo: katamtamang light na kulay ng balat',
    '🤽🏽' => 'taong naglalaro ng water polo: katamtamang kulay ng balat',
    '🤽🏾' => 'taong naglalaro ng water polo: katamtamang dark na kulay ng balat',
    '🤽🏿' => 'taong naglalaro ng water polo: dark na kulay ng balat',
    '🤾🏻' => 'taong naglalaro ng handball: light na kulay ng balat',
    '🤾🏼' => 'taong naglalaro ng handball: katamtamang light na kulay ng balat',
    '🤾🏽' => 'taong naglalaro ng handball: katamtamang kulay ng balat',
    '🤾🏾' => 'taong naglalaro ng handball: katamtamang dark na kulay ng balat',
    '🤾🏿' => 'taong naglalaro ng handball: dark na kulay ng balat',
    '🤹🏻' => 'taong nagja-juggle: light na kulay ng balat',
    '🤹🏼' => 'taong nagja-juggle: katamtamang light na kulay ng balat',
    '🤹🏽' => 'taong nagja-juggle: katamtamang kulay ng balat',
    '🤹🏾' => 'taong nagja-juggle: katamtamang dark na kulay ng balat',
    '🤹🏿' => 'taong nagja-juggle: dark na kulay ng balat',
    '🧘🏻' => 'tao na naka-lotus position: light na kulay ng balat',
    '🧘🏼' => 'tao na naka-lotus position: katamtamang light na kulay ng balat',
    '🧘🏽' => 'tao na naka-lotus position: katamtamang kulay ng balat',
    '🧘🏾' => 'tao na naka-lotus position: katamtamang dark na kulay ng balat',
    '🧘🏿' => 'tao na naka-lotus position: dark na kulay ng balat',
    '🛀🏻' => 'taong naliligo: light na kulay ng balat',
    '🛀🏼' => 'taong naliligo: katamtamang light na kulay ng balat',
    '🛀🏽' => 'taong naliligo: katamtamang kulay ng balat',
    '🛀🏾' => 'taong naliligo: katamtamang dark na kulay ng balat',
    '🛀🏿' => 'taong naliligo: dark na kulay ng balat',
    '🛌🏻' => 'taong nakahiga: light na kulay ng balat',
    '🛌🏼' => 'taong nakahiga: katamtamang light na kulay ng balat',
    '🛌🏽' => 'taong nakahiga: katamtamang kulay ng balat',
    '🛌🏾' => 'taong nakahiga: katamtamang dark na kulay ng balat',
    '🛌🏿' => 'taong nakahiga: dark na kulay ng balat',
    '👭🏻' => 'dalawang babaeng magkahawak-kamay: light na kulay ng balat',
    '👭🏼' => 'dalawang babaeng magkahawak-kamay: katamtamang light na kulay ng balat',
    '👭🏽' => 'dalawang babaeng magkahawak-kamay: katamtamang kulay ng balat',
    '👭🏾' => 'dalawang babaeng magkahawak-kamay: katamtamang dark na kulay ng balat',
    '👭🏿' => 'dalawang babaeng magkahawak-kamay: dark na kulay ng balat',
    '👫🏻' => 'lalaki at babaeng magkahawak-kamay: light na kulay ng balat',
    '👫🏼' => 'lalaki at babaeng magkahawak-kamay: katamtamang light na kulay ng balat',
    '👫🏽' => 'lalaki at babaeng magkahawak-kamay: katamtamang kulay ng balat',
    '👫🏾' => 'lalaki at babaeng magkahawak-kamay: katamtamang dark na kulay ng balat',
    '👫🏿' => 'lalaki at babaeng magkahawak-kamay: dark na kulay ng balat',
    '👬🏻' => 'dalawang lalaking magkahawak-kamay: light na kulay ng balat',
    '👬🏼' => 'dalawang lalaking magkahawak-kamay: katamtamang light na kulay ng balat',
    '👬🏽' => 'dalawang lalaking magkahawak-kamay: katamtamang kulay ng balat',
    '👬🏾' => 'dalawang lalaking magkahawak-kamay: katamtamang dark na kulay ng balat',
    '👬🏿' => 'dalawang lalaking magkahawak-kamay: dark na kulay ng balat',
    '💏🏻' => 'maghahalikan: light na kulay ng balat',
    '💏🏼' => 'maghahalikan: katamtamang light na kulay ng balat',
    '💏🏽' => 'maghahalikan: katamtamang kulay ng balat',
    '💏🏾' => 'maghahalikan: katamtamang dark na kulay ng balat',
    '💏🏿' => 'maghahalikan: dark na kulay ng balat',
    '💑🏻' => 'magkapareha na may puso: light na kulay ng balat',
    '💑🏼' => 'magkapareha na may puso: katamtamang light na kulay ng balat',
    '💑🏽' => 'magkapareha na may puso: katamtamang kulay ng balat',
    '💑🏾' => 'magkapareha na may puso: katamtamang dark na kulay ng balat',
    '💑🏿' => 'magkapareha na may puso: dark na kulay ng balat',
    '🇦🇨' => 'bandila: Acsencion island',
    '🇦🇩' => 'bandila: Andorra',
    '🇦🇪' => 'bandila: United Arab Emirates',
    '🇦🇫' => 'bandila: Afghanistan',
    '🇦🇬' => 'bandila: Antigua & Barbuda',
    '🇦🇮' => 'bandila: Anguilla',
    '🇦🇱' => 'bandila: Albania',
    '🇦🇲' => 'bandila: Armenia',
    '🇦🇴' => 'bandila: Angola',
    '🇦🇶' => 'bandila: Antarctica',
    '🇦🇷' => 'bandila: Argentina',
    '🇦🇸' => 'bandila: American Samoa',
    '🇦🇹' => 'bandila: Austria',
    '🇦🇺' => 'bandila: Australia',
    '🇦🇼' => 'bandila: Aruba',
    '🇦🇽' => 'bandila: Åland Islands',
    '🇦🇿' => 'bandila: Azerbaijan',
    '🇧🇦' => 'bandila: Bosnia and Herzegovina',
    '🇧🇧' => 'bandila: Barbados',
    '🇧🇩' => 'bandila: Bangladesh',
    '🇧🇪' => 'bandila: Belgium',
    '🇧🇫' => 'bandila: Burkina Faso',
    '🇧🇬' => 'bandila: Bulgaria',
    '🇧🇭' => 'bandila: Bahrain',
    '🇧🇮' => 'bandila: Burundi',
    '🇧🇯' => 'bandila: Benin',
    '🇧🇱' => 'bandila: St. Barthélemy',
    '🇧🇲' => 'bandila: Bermuda',
    '🇧🇳' => 'bandila: Brunei',
    '🇧🇴' => 'bandila: Bolivia',
    '🇧🇶' => 'bandila: Caribbean Netherlands',
    '🇧🇷' => 'bandila: Brazil',
    '🇧🇸' => 'bandila: Bahamas',
    '🇧🇹' => 'bandila: Bhutan',
    '🇧🇻' => 'bandila: Bouvet Island',
    '🇧🇼' => 'bandila: Botswana',
    '🇧🇾' => 'bandila: Belarus',
    '🇧🇿' => 'bandila: Belize',
    '🇨🇦' => 'bandila: Canada',
    '🇨🇨' => 'bandila: Cocos (Keeling) Islands',
    '🇨🇩' => 'bandila: Congo - Kinshasa',
    '🇨🇫' => 'bandila: Central African Republic',
    '🇨🇬' => 'bandila: Congo - Brazzaville',
    '🇨🇭' => 'bandila: Switzerland',
    '🇨🇮' => 'bandila: Côte d’Ivoire',
    '🇨🇰' => 'bandila: Cook Islands',
    '🇨🇱' => 'bandila: Chile',
    '🇨🇲' => 'bandila: Cameroon',
    '🇨🇳' => 'bandila: China',
    '🇨🇴' => 'bandila: Colombia',
    '🇨🇵' => 'bandila: Clipperton Island',
    '🇨🇶' => 'bandila: Sark',
    '🇨🇷' => 'bandila: Costa Rica',
    '🇨🇺' => 'bandila: Cuba',
    '🇨🇻' => 'bandila: Cape Verde',
    '🇨🇼' => 'bandila: Curaçao',
    '🇨🇽' => 'bandila: Christmas Island',
    '🇨🇾' => 'bandila: Cyprus',
    '🇨🇿' => 'bandila: Czechia',
    '🇩🇪' => 'bandila: Germany',
    '🇩🇬' => 'bandila: Diego Garcia',
    '🇩🇯' => 'bandila: Djibouti',
    '🇩🇰' => 'bandila: Denmark',
    '🇩🇲' => 'bandila: Dominica',
    '🇩🇴' => 'bandila: Dominican Republic',
    '🇩🇿' => 'bandila: Algeria',
    '🇪🇦' => 'bandila: Ceuta & Melilla',
    '🇪🇨' => 'bandila: Ecuador',
    '🇪🇪' => 'bandila: Estonia',
    '🇪🇬' => 'bandila: Egypt',
    '🇪🇭' => 'bandila: Kanlurang Sahara',
    '🇪🇷' => 'bandila: Eritrea',
    '🇪🇸' => 'bandila: Spain',
    '🇪🇹' => 'bandila: Ethiopia',
    '🇪🇺' => 'bandila: European Union',
    '🇫🇮' => 'bandila: Finland',
    '🇫🇯' => 'bandila: Fiji',
    '🇫🇰' => 'bandila: Falkland Islands',
    '🇫🇲' => 'bandila: Micronesia',
    '🇫🇴' => 'bandila: Faroe Islands',
    '🇫🇷' => 'bandila: France',
    '🇬🇦' => 'bandila: Gabon',
    '🇬🇧' => 'bandila: United Kingdom',
    '🇬🇩' => 'bandila: Grenada',
    '🇬🇪' => 'bandila: Georgia',
    '🇬🇫' => 'bandila: French Guiana',
    '🇬🇬' => 'bandila: Guernsey',
    '🇬🇭' => 'bandila: Ghana',
    '🇬🇮' => 'bandila: Gibraltar',
    '🇬🇱' => 'bandila: Greenland',
    '🇬🇲' => 'bandila: Gambia',
    '🇬🇳' => 'bandila: Guinea',
    '🇬🇵' => 'bandila: Guadeloupe',
    '🇬🇶' => 'bandila: Equatorial Guinea',
    '🇬🇷' => 'bandila: Greece',
    '🇬🇸' => 'bandila: South Georgia & South Sandwich Islands',
    '🇬🇹' => 'bandila: Guatemala',
    '🇬🇺' => 'bandila: Guam',
    '🇬🇼' => 'bandila: Guinea-Bissau',
    '🇬🇾' => 'bandila: Guyana',
    '🇭🇰' => 'bandila: Hong Kong SAR China',
    '🇭🇲' => 'bandila: Heard & McDonald Islands',
    '🇭🇳' => 'bandila: Honduras',
    '🇭🇷' => 'bandila: Croatia',
    '🇭🇹' => 'bandila: Haiti',
    '🇭🇺' => 'bandila: Hungary',
    '🇮🇨' => 'bandila: Canary Islands',
    '🇮🇩' => 'bandila: Indonesia',
    '🇮🇪' => 'bandila: Ireland',
    '🇮🇱' => 'bandila: Israel',
    '🇮🇲' => 'bandila: Isle of Man',
    '🇮🇳' => 'bandila: India',
    '🇮🇴' => 'bandila: British Indian Ocean Territory',
    '🇮🇶' => 'bandila: Iraq',
    '🇮🇷' => 'bandila: Iran',
    '🇮🇸' => 'bandila: Iceland',
    '🇮🇹' => 'bandila: Italy',
    '🇯🇪' => 'bandila: Jersey',
    '🇯🇲' => 'bandila: Jamaica',
    '🇯🇴' => 'bandila: Jordan',
    '🇯🇵' => 'bandila: Japan',
    '🇰🇪' => 'bandila: Kenya',
    '🇰🇬' => 'bandila: Kyrgyzstan',
    '🇰🇭' => 'bandila: Cambodia',
    '🇰🇮' => 'bandila: Kiribati',
    '🇰🇲' => 'bandila: Comoros',
    '🇰🇳' => 'bandila: St. Kitts & Nevis',
    '🇰🇵' => 'bandila: Hilagang Korea',
    '🇰🇷' => 'bandila: Timog Korea',
    '🇰🇼' => 'bandila: Kuwait',
    '🇰🇾' => 'bandila: Cayman Islands',
    '🇰🇿' => 'bandila: Kazakhstan',
    '🇱🇦' => 'bandila: Laos',
    '🇱🇧' => 'bandila: Lebanon',
    '🇱🇨' => 'bandila: Saint Lucia',
    '🇱🇮' => 'bandila: Liechtenstein',
    '🇱🇰' => 'bandila: Sri Lanka',
    '🇱🇷' => 'bandila: Liberia',
    '🇱🇸' => 'bandila: Lesotho',
    '🇱🇹' => 'bandila: Lithuania',
    '🇱🇺' => 'bandila: Luxembourg',
    '🇱🇻' => 'bandila: Latvia',
    '🇱🇾' => 'bandila: Libya',
    '🇲🇦' => 'bandila: Morocco',
    '🇲🇨' => 'bandila: Monaco',
    '🇲🇩' => 'bandila: Moldova',
    '🇲🇪' => 'bandila: Montenegro',
    '🇲🇫' => 'bandila: Saint Martin',
    '🇲🇬' => 'bandila: Madagascar',
    '🇲🇭' => 'bandila: Marshall Islands',
    '🇲🇰' => 'bandila: North Macedonia',
    '🇲🇱' => 'bandila: Mali',
    '🇲🇲' => 'bandila: Myanmar (Burma)',
    '🇲🇳' => 'bandila: Mongolia',
    '🇲🇴' => 'bandila: Macau SAR China',
    '🇲🇵' => 'bandila: Northern Mariana Islands',
    '🇲🇶' => 'bandila: Martinique',
    '🇲🇷' => 'bandila: Mauritania',
    '🇲🇸' => 'bandila: Montserrat',
    '🇲🇹' => 'bandila: Malta',
    '🇲🇺' => 'bandila: Mauritius',
    '🇲🇻' => 'bandila: Maldives',
    '🇲🇼' => 'bandila: Malawi',
    '🇲🇽' => 'bandila: Mexico',
    '🇲🇾' => 'bandila: Malaysia',
    '🇲🇿' => 'bandila: Mozambique',
    '🇳🇦' => 'bandila: Namibia',
    '🇳🇨' => 'bandila: New Caledonia',
    '🇳🇪' => 'bandila: Niger',
    '🇳🇫' => 'bandila: Norfolk Island',
    '🇳🇬' => 'bandila: Nigeria',
    '🇳🇮' => 'bandila: Nicaragua',
    '🇳🇱' => 'bandila: Netherlands',
    '🇳🇴' => 'bandila: Norway',
    '🇳🇵' => 'bandila: Nepal',
    '🇳🇷' => 'bandila: Nauru',
    '🇳🇺' => 'bandila: Niue',
    '🇳🇿' => 'bandila: New Zealand',
    '🇴🇲' => 'bandila: Oman',
    '🇵🇦' => 'bandila: Panama',
    '🇵🇪' => 'bandila: Peru',
    '🇵🇫' => 'bandila: French Polynesia',
    '🇵🇬' => 'bandila: Papua New Guinea',
    '🇵🇭' => 'bandila: Pilipinas',
    '🇵🇰' => 'bandila: Pakistan',
    '🇵🇱' => 'bandila: Poland',
    '🇵🇲' => 'bandila: St. Pierre & Miquelon',
    '🇵🇳' => 'bandila: Pitcairn Islands',
    '🇵🇷' => 'bandila: Puerto Rico',
    '🇵🇸' => 'bandila: Palestinian Territories',
    '🇵🇹' => 'bandila: Portugal',
    '🇵🇼' => 'bandila: Palau',
    '🇵🇾' => 'bandila: Paraguay',
    '🇶🇦' => 'bandila: Qatar',
    '🇷🇪' => 'bandila: Réunion',
    '🇷🇴' => 'bandila: Romania',
    '🇷🇸' => 'bandila: Serbia',
    '🇷🇺' => 'bandila: Russia',
    '🇷🇼' => 'bandila: Rwanda',
    '🇸🇦' => 'bandila: Saudi Arabia',
    '🇸🇧' => 'bandila: Solomon Islands',
    '🇸🇨' => 'bandila: Seychelles',
    '🇸🇩' => 'bandila: Sudan',
    '🇸🇪' => 'bandila: Sweden',
    '🇸🇬' => 'bandila: Singapore',
    '🇸🇭' => 'bandila: St. Helena',
    '🇸🇮' => 'bandila: Slovenia',
    '🇸🇯' => 'bandila: Svalbard & Jan Mayen',
    '🇸🇰' => 'bandila: Slovakia',
    '🇸🇱' => 'bandila: Sierra Leone',
    '🇸🇲' => 'bandila: San Marino',
    '🇸🇳' => 'bandila: Senegal',
    '🇸🇴' => 'bandila: Somalia',
    '🇸🇷' => 'bandila: Suriname',
    '🇸🇸' => 'bandila: Timog Sudan',
    '🇸🇹' => 'bandila: São Tomé & Príncipe',
    '🇸🇻' => 'bandila: El Salvador',
    '🇸🇽' => 'bandila: Sint Maarten',
    '🇸🇾' => 'bandila: Syria',
    '🇸🇿' => 'bandila: Swaziland',
    '🇹🇦' => 'bandila: Tristan de Cunha',
    '🇹🇨' => 'bandila: Turks & Caicos Islands',
    '🇹🇩' => 'bandila: Chad',
    '🇹🇫' => 'bandila: French Southern Territories',
    '🇹🇬' => 'bandila: Togo',
    '🇹🇭' => 'bandila: Thailand',
    '🇹🇯' => 'bandila: Tajikistan',
    '🇹🇰' => 'bandila: Tokelau',
    '🇹🇱' => 'bandila: Timor-Leste',
    '🇹🇲' => 'bandila: Turkmenistan',
    '🇹🇳' => 'bandila: Tunisia',
    '🇹🇴' => 'bandila: Tonga',
    '🇹🇷' => 'bandila: Türkiye',
    '🇹🇹' => 'bandila: Trinidad & Tobago',
    '🇹🇻' => 'bandila: Tuvalu',
    '🇹🇼' => 'bandila: Taiwan',
    '🇹🇿' => 'bandila: Tanzania',
    '🇺🇦' => 'bandila: Ukraine',
    '🇺🇬' => 'bandila: Uganda',
    '🇺🇲' => 'bandila: U.S. Outlying Islands',
    '🇺🇳' => 'bandila: United Nations',
    '🇺🇸' => 'bandila: Estados Unidos',
    '🇺🇾' => 'bandila: Uruguay',
    '🇺🇿' => 'bandila: Uzbekistan',
    '🇻🇦' => 'bandila: Vatican City',
    '🇻🇨' => 'bandila: St. Vincent & Grenadines',
    '🇻🇪' => 'bandila: Venezuela',
    '🇻🇬' => 'bandila: British Virgin Islands',
    '🇻🇮' => 'bandila: U.S. Virgin Islands',
    '🇻🇳' => 'bandila: Vietnam',
    '🇻🇺' => 'bandila: Vanuatu',
    '🇼🇫' => 'bandila: Wallis & Futuna',
    '🇼🇸' => 'bandila: Samoa',
    '🇽🇰' => 'bandila: Kosovo',
    '🇾🇪' => 'bandila: Yemen',
    '🇾🇹' => 'bandila: Mayotte',
    '🇿🇦' => 'bandila: South Africa',
    '🇿🇲' => 'bandila: Zambia',
    '🇿🇼' => 'bandila: Zimbabwe',
    '🏻' => 'light na kulay ng balat',
    '🏼' => 'katamtamang light na kulay ng balat',
    '🏽' => 'katamtamang kulay ng balat',
    '🏾' => 'katamtamang dark na kulay ng balat',
    '🏿' => 'dark na kulay ng balat',
    '😀' => 'mukhang nakangiti',
    '😃' => 'nakangisi na may malaking mga mata',
    '😄' => 'nakangisi kasama ang mga nakangiting mata',
    '😁' => 'nakangiti pati ang mga mata',
    '😆' => 'nakatawa nang nakapikit',
    '😅' => 'nakangising mukha na may pawis',
    '🤣' => 'gumugulong sa kakatawa',
    '😂' => 'mukhang naiiyak sa tuwa',
    '🙂' => 'medyo nakangiti',
    '🙃' => 'baligtad na mukha',
    '🫠' => 'natutunaw na mukha',
    '😉' => 'kumikindat',
    '😊' => 'nakangiti kasama ang mga mata',
    '😇' => 'nakangiti nang may halo',
    '🥰' => 'nakangiting mukha na may 3 na puso',
    '😍' => 'nakangiti nang may hugis-pusong mga mata',
    '🤩' => 'star-struck',
    '😘' => 'flying kiss',
    '😗' => 'humahalik',
    '☺' => 'nakangiti',
    '😚' => 'humahalik nang nakapikit',
    '😙' => 'humahalik nang nakangiti ang mga mata',
    '🥲' => 'mukhang nakangiti na may luha',
    '😋' => 'lumalasap ng masarap na pagkain',
    '😛' => 'nakadila',
    '😜' => 'kumikindat nang nakadila',
    '🤪' => 'baliw na mukha',
    '😝' => 'nakadila nang nakapikit',
    '🤑' => 'mukhang pera',
    '🤗' => 'nangyayakap',
    '🤭' => 'mukha na nakatakip ang kamay sa bibig',
    '🫢' => 'mukha na may mga nakabukas na mata at kamay sa bibig',
    '🫣' => 'mukha na may sumisilip na mata',
    '🤫' => 'mukha na nagpapatahimik',
    '🤔' => 'nag-iisip',
    '🫡' => 'saludo',
    '🤐' => 'naka-zipper ang bibig',
    '🤨' => 'mukhang nakataas ang kilay',
    '😐' => 'walang reaksyon',
    '😑' => 'walang ekspresyon',
    '😶' => 'mukhang walang bibig',
    '🫥' => 'dotted na linya na mukha',
    '😏' => 'nakangisi',
    '😒' => 'hindi natutuwa',
    '🙄' => 'itinitirik ang mga mata',
    '😬' => 'nakangiwi',
    '🤥' => 'nagsisinungaling',
    '🫨' => 'nanginginig na mukha',
    '😌' => 'nakahinga nang maluwag',
    '😔' => 'malungkot na nag-iisip',
    '😪' => 'inaantok na mukha',
    '🤤' => 'naglalaway',
    '😴' => 'natutulog',
    '🫩' => 'mukha na nangangalumata',
    '😷' => 'may suot na medical mask',
    '🤒' => 'may thermometer sa bibig',
    '🤕' => 'may benda sa ulo',
    '🤢' => 'nasusuka',
    '🤮' => 'mukha na nagsusuka',
    '🤧' => 'bumabahing',
    '🥵' => 'mainit na mukha',
    '🥶' => 'malamig na mukha',
    '🥴' => 'woozy na mukha',
    '😵' => 'mukhang nahihilo',
    '🤯' => 'sumasabog na ulo',
    '🤠' => 'mukha na may cowboy hat',
    '🥳' => 'nagdiriwang na mukha',
    '🥸' => 'nakatagong mukha',
    '😎' => 'nakangiti nang may suot na shades',
    '🤓' => 'nerd',
    '🧐' => 'mukha na may monocle',
    '😕' => 'nalilito',
    '🫤' => 'mukha na may diagonal na bibig',
    '😟' => 'nag-aalala',
    '🙁' => 'medyo nakasimangot',
    '☹' => 'nakasimangot',
    '😮' => 'nakanganga',
    '😯' => 'tahimik na naghihintay',
    '😲' => 'gulat na gulat',
    '😳' => 'namumula',
    '🫪' => 'distorted na mukha',
    '🥺' => 'nagsusumamo na mukha',
    '🥹' => 'mukhang nagpipigil ng luha',
    '😦' => 'nakasimangot nang nakanganga',
    '😧' => 'nagdurusa',
    '😨' => 'natatakot',
    '😰' => 'balisa at pinagpapawisan',
    '😥' => 'malungkot pero naibsan',
    '😢' => 'umiiyak',
    '😭' => 'umiiyak nang malakas',
    '😱' => 'sumisigaw sa takot',
    '😖' => 'natataranta',
    '😣' => 'nagsisikap',
    '😞' => 'dismayado',
    '😓' => 'pinagpapawisan nang malamig',
    '😩' => 'pagod na pagod',
    '😫' => 'pagod na mukha',
    '🥱' => 'mukhang humihikab',
    '😤' => 'umuusok ang ilong',
    '😡' => 'nakasimangot at nakakunot ang noo',
    '😠' => 'galit',
    '🤬' => 'mukha na may mga simbolo sa bibig',
    '😈' => 'nakangiti nang may mga sungay',
    '👿' => 'demonyo',
    '💀' => 'bungo',
    '☠' => 'bungo at crossbones',
    '💩' => 'tumpok ng tae',
    '🤡' => 'payaso',
    '👹' => 'kapre',
    '👺' => 'goblin',
    '👻' => 'multo',
    '👽' => 'alien',
    '👾' => 'halimaw na alien',
    '🤖' => 'mukha ng robot',
    '😺' => 'pusang nakatawa',
    '😸' => 'pusang nakatawa kasama ang mga mata',
    '😹' => 'pusang naiiyak sa kakatawa',
    '😻' => 'pusang nakangiti nang may hugis-pusong mga mata',
    '😼' => 'pusang nakangisi',
    '😽' => 'pusang humahalik nang nakapikit',
    '🙀' => 'pusang pagod na pagod',
    '😿' => 'pusang umiiyak',
    '😾' => 'pusang nakasimangot',
    '🙈' => 'huwag tumingin sa masama',
    '🙉' => 'huwag makinig sa masama',
    '🙊' => 'huwag magsalita nang masama',
    '💌' => 'liham ng pag-ibig',
    '💘' => 'pusong may palaso',
    '💝' => 'pusong may ribbon',
    '💖' => 'kumikinang na puso',
    '💗' => 'lumalaking puso',
    '💓' => 'tumitibok na puso',
    '💞' => 'umiikot na mga puso',
    '💕' => 'dalawang puso',
    '💟' => 'dekorasyong puso',
    '❣' => 'tandang padamdam na hugis-puso',
    '💔' => 'durog na puso',
    '❤' => 'pulang puso',
    '🩷' => 'pink na puso',
    '🧡' => 'pusong dalandan',
    '💛' => 'dilaw na puso',
    '💚' => 'berdeng puso',
    '💙' => 'asul na puso',
    '🩵' => 'light blue na puso',
    '💜' => 'purple na puso',
    '🤎' => 'kayumangging puso',
    '🖤' => 'itim na puso',
    '🩶' => 'grey na puso',
    '🤍' => 'puting puso',
    '💋' => 'marka ng halik',
    '💯' => 'sandaang puntos',
    '💢' => 'simbolo ng galit',
    '🫯' => 'cloud ng away',
    '💥' => 'banggaan',
    '💫' => 'nahihilo',
    '💦' => 'mga patak ng pawis',
    '💨' => 'nagmamadali',
    '🕳' => 'butas',
    '💬' => 'speech balloon',
    '🗨' => 'kaliwang speech bubble',
    '🗯' => 'kanang anger bubble',
    '💭' => 'thought balloon',
    '💤' => 'zzz',
    '👋' => 'kumakaway na kamay',
    '🤚' => 'nakataas na baliktad na kamay',
    '🖐' => 'nakataas na nakabukas na kamay',
    '✋' => 'nakataas na kamay',
    '🖖' => 'vulcan salute',
    '🫱' => 'pakanang kamay',
    '🫲' => 'pakaliwang kamay',
    '🫳' => 'nakataob na palad',
    '🫴' => 'nakasalong palad',
    '🫷' => 'pakaliwang tumutulak na kamay',
    '🫸' => 'pakanang tumutulak na kamay',
    '👌' => 'kamay na nagpapahiwatig ng ok',
    '🤌' => 'pakurot na daliri',
    '🤏' => 'kamay na kumukurot',
    '✌' => 'peace sign',
    '🤞' => 'naka-cross na mga daliri',
    '🫰' => 'kamay na magkakrus ang hintuturo at hinlalaki',
    '🤟' => 'love-you gesture',
    '🤘' => 'rock ’n’ roll',
    '🤙' => 'tawagan mo ko',
    '👈' => 'backhand ng hintuturo na nakaturo sa kaliwa',
    '👉' => 'backhand ng hintuturo na nakaturo sa kanan',
    '👆' => 'backhand ng hintuturo na nakaturo sa itaas',
    '🖕' => 'hinlalato',
    '👇' => 'backhand ng hintuturo na nakaturo sa ibaba',
    '☝' => 'hintuturo na nakaturo sa itaas',
    '🫵' => 'hintuturong nakaturo sa tumitingin',
    '👍' => 'thumbs up',
    '👎' => 'thumbs down',
    '✊' => 'nakataas na kamao',
    '👊' => 'pasuntok na kamao',
    '🤛' => 'pakaliwang kamao',
    '🤜' => 'pakanang kamao',
    '👏' => 'pumapalakpak',
    '🙌' => 'nakataas na mga kamay',
    '🫶' => 'nakapusong kamay',
    '👐' => 'bukas-palad',
    '🤲' => 'nakataas na magkadikit na palad',
    '🤝' => 'pagkakamay',
    '🙏' => 'magkalapat na mga palad',
    '✍' => 'nagsusulat na kamay',
    '💅' => 'nail polish',
    '🤳' => 'selfie',
    '💪' => 'pinalaking biceps',
    '🦾' => 'mekanikal na braso',
    '🦿' => 'mekanikal na binti',
    '🦵' => 'hita',
    '🦶' => 'paa',
    '👂' => 'tainga',
    '🦻' => 'tainga na may hearing aid',
    '👃' => 'ilong',
    '🧠' => 'utak',
    '🫀' => 'puso',
    '🫁' => 'baga',
    '🦷' => 'ngipin',
    '🦴' => 'buto',
    '👀' => 'mga mata',
    '👁' => 'mata',
    '👅' => 'dila',
    '👄' => 'bibig',
    '🫦' => 'kagat-labi',
    '👶' => 'sanggol',
    '🧒' => 'bata',
    '👦' => 'batang lalaki',
    '👧' => 'batang babae',
    '🧑' => 'tao',
    '👱' => 'taong may blond na buhok',
    '👨' => 'lalaki',
    '🧔' => 'taong may balbas',
    '👩' => 'babae',
    '🧓' => 'mas matandang tao',
    '👴' => 'matandang lalaki',
    '👵' => 'matandang babae',
    '🙍' => 'taong nakasimangot',
    '🙎' => 'taong naka-pout',
    '🙅' => 'nagpapahiwatig na hindi pwede',
    '🙆' => 'nagpapahiwatig na ok',
    '💁' => 'taong nakatikwas ang kamay',
    '🙋' => 'masayang tao na nakataas ang kamay',
    '🧏' => 'taong bingi',
    '🙇' => 'yumuyukong tao',
    '🤦' => 'naka-facepalm',
    '🤷' => 'nagkikibit-balikat',
    '👮' => 'pulis',
    '🕵' => 'imbestigador',
    '💂' => 'gwardya',
    '🥷' => 'ninja',
    '👷' => 'construction worker',
    '🫅' => 'taong may korona',
    '🤴' => 'prinsipe',
    '👸' => 'prinsesa',
    '👳' => 'lalaking may suot na turban',
    '👲' => 'lalaking may suot na sombrerong chinese',
    '🧕' => 'babae na may headscarf',
    '🤵' => 'taong naka-tuxedo',
    '👰' => 'taong may suot na belo',
    '🤰' => 'buntis',
    '🫃' => 'lalaking buntis',
    '🫄' => 'taong buntis',
    '🤱' => 'breast-feeding',
    '👼' => 'sanggol na anghel',
    '🎅' => 'santa claus',
    '🤶' => 'Mrs Claus',
    '🦸' => 'superhero',
    '🦹' => 'supervillain',
    '🧙' => 'salamangkero',
    '🧚' => 'diwata',
    '🧛' => 'bampira',
    '🧜' => 'merperson',
    '🧝' => 'duwende',
    '🧞' => 'genie',
    '🧟' => 'zombie',
    '🧌' => 'troll',
    '🫈' => 'mabalahibong nilalang',
    '💆' => 'pagpapamasahe ng mukha',
    '💇' => 'pagpapagupit ng buhok',
    '🚶' => 'taong naglalakad',
    '🧍' => 'nakatayong tao',
    '🧎' => 'taong nakaluhod',
    '🏃' => 'tumatakbo',
    '💃' => 'mananayaw',
    '🕺' => 'lalaking sumasayaw',
    '🕴' => 'lumulutang na lalaking nakapormal',
    '👯' => 'mga babaeng may tainga ng kuneho',
    '🧖' => 'tao na nasa sauna',
    '🧗' => 'tao na umaakyat',
    '🤺' => 'fencer',
    '🏇' => 'karerahan ng kabayo',
    '⛷' => 'skier',
    '🏂' => 'snowboarder',
    '🏌' => 'golfer',
    '🏄' => 'surfer',
    '🚣' => 'bangkang de-sagwan',
    '🏊' => 'swimmer',
    '⛹' => 'taong naglalaro ng bola',
    '🏋' => 'weight lifter',
    '🚴' => 'nagbibisikleta',
    '🚵' => 'mountain biker',
    '🤸' => 'taong nagka-cartwheel',
    '🤼' => 'mga taong nagre-wrestling',
    '🤽' => 'taong naglalaro ng water polo',
    '🤾' => 'taong naglalaro ng handball',
    '🤹' => 'taong nagja-juggle',
    '🧘' => 'tao na naka-lotus position',
    '🛀' => 'taong naliligo',
    '🛌' => 'taong nakahiga',
    '👭' => 'dalawang babaeng magkahawak-kamay',
    '👫' => 'lalaki at babaeng magkahawak-kamay',
    '👬' => 'dalawang lalaking magkahawak-kamay',
    '💏' => 'maghahalikan',
    '💑' => 'magkapareha na may puso',
    '🗣' => 'ulong nagsasalita',
    '👤' => 'silhouette ng bust',
    '👥' => 'silhouette ng mga bust',
    '🫂' => 'tao na magkayakap',
    '👪' => 'pamilya',
    '👣' => 'mga bakas ng paa',
    '🫆' => 'bakas ng daliri',
    '🦰' => 'pulang buhok',
    '🦱' => 'kulot na buhok',
    '🦳' => 'puting buhok',
    '🦲' => 'kalbo',
    '🐵' => 'mukha ng unggoy',
    '🐒' => 'unggoy',
    '🦍' => 'gorilya',
    '🦧' => 'orangutan',
    '🐶' => 'mukha ng aso',
    '🐕' => 'aso',
    '🦮' => 'gabay na aso',
    '🐩' => 'poodle',
    '🐺' => 'mukha ng lobo',
    '🦊' => 'mukha ng fox',
    '🦝' => 'raccoon',
    '🐱' => 'mukha ng pusa',
    '🐈' => 'pusa',
    '🦁' => 'mukha ng leon',
    '🐯' => 'mukha ng tigre',
    '🐅' => 'tigre',
    '🐆' => 'leopard',
    '🐴' => 'mukha ng kabayo',
    '🫎' => 'moose',
    '🫏' => 'asno',
    '🐎' => 'kabayo',
    '🦄' => 'unicorn',
    '🦓' => 'zebra',
    '🦌' => 'usa',
    '🦬' => 'bison',
    '🐮' => 'mukha ng baka',
    '🐂' => 'toro',
    '🐃' => 'kalabaw',
    '🐄' => 'baka',
    '🐷' => 'mukha ng baboy',
    '🐖' => 'baboy',
    '🐗' => 'baboy-ramo',
    '🐽' => 'ilong ng baboy',
    '🐏' => 'lalaking tupa',
    '🐑' => 'tupa',
    '🐐' => 'kambing',
    '🐪' => 'camel',
    '🐫' => 'camel na may dalawang umbok sa likod',
    '🦙' => 'llama',
    '🦒' => 'giraffe',
    '🐘' => 'elepante',
    '🦣' => 'mammoth',
    '🦏' => 'rhinoceros',
    '🦛' => 'hippopotamus',
    '🐭' => 'mukha ng daga',
    '🐁' => 'bubuwit',
    '🐀' => 'daga',
    '🐹' => 'hamster',
    '🐰' => 'mukha ng kuneho',
    '🐇' => 'kuneho',
    '🐿' => 'chipmunk',
    '🦫' => 'beaver',
    '🦔' => 'hedgehog',
    '🦇' => 'paniki',
    '🐻' => 'oso',
    '🐨' => 'koala',
    '🐼' => 'panda',
    '🦥' => 'Sloth',
    '🦦' => 'otter',
    '🦨' => 'skunk',
    '🦘' => 'kangaroo',
    '🦡' => 'badger',
    '🐾' => 'mga bakas ng paa ng hayop',
    '🦃' => 'pabo',
    '🐔' => 'manok',
    '🐓' => 'tandang',
    '🐣' => 'bagong-pisang sisiw',
    '🐤' => 'sisiw',
    '🐥' => 'nakaharap na sisiw',
    '🐦' => 'ibon',
    '🐧' => 'penguin',
    '🕊' => 'kalapati',
    '🦅' => 'agila',
    '🦆' => 'bibi',
    '🦢' => 'swan',
    '🦉' => 'kuwago',
    '🦤' => 'dodo',
    '🪶' => 'balahibo',
    '🦩' => 'flamingo',
    '🦚' => 'peacock',
    '🦜' => 'loro',
    '🪽' => 'pakpak',
    '🪿' => 'gansa',
    '🐸' => 'palaka',
    '🐊' => 'buwaya',
    '🐢' => 'pagong',
    '🦎' => 'butiki',
    '🐍' => 'ahas',
    '🐲' => 'mukha ng dragon',
    '🐉' => 'dragon',
    '🦕' => 'sauropod',
    '🦖' => 'T-Rex',
    '🐳' => 'balyenang bumubuga ng tubig',
    '🐋' => 'balyena',
    '🐬' => 'dolphin',
    '🫍' => 'orca',
    '🦭' => 'seal',
    '🐟' => 'isda',
    '🐠' => 'tropical fish',
    '🐡' => 'blowfish',
    '🦈' => 'pating',
    '🐙' => 'pugita',
    '🐚' => 'pilipit na kabibe',
    '🪸' => 'korales',
    '🪼' => 'dikya',
    '🦀' => 'alimango',
    '🦞' => 'lobster',
    '🦐' => 'hipon',
    '🦑' => 'pusit',
    '🦪' => 'talaba',
    '🐌' => 'kuhol',
    '🦋' => 'paru-paro',
    '🐛' => 'insekto',
    '🐜' => 'langgam',
    '🐝' => 'bubuyog',
    '🪲' => 'salaginto',
    '🐞' => 'ladybug',
    '🦗' => 'kuliglig',
    '🪳' => 'ipis',
    '🕷' => 'gagamba',
    '🕸' => 'sapot',
    '🦂' => 'alakdan',
    '🦟' => 'lamok',
    '🪰' => 'langaw',
    '🪱' => 'uod',
    '🦠' => 'mikrobyo',
    '💐' => 'bungkos ng mga bulaklak',
    '🌸' => 'cherry blossom',
    '💮' => 'white flower',
    '🪷' => 'lotus',
    '🏵' => 'rosette',
    '🌹' => 'rosas',
    '🥀' => 'nalantang bulaklak',
    '🌺' => 'gumamela',
    '🌻' => 'mirasol',
    '🌼' => 'bulaklak',
    '🌷' => 'tulip',
    '🪻' => 'hyacinth',
    '🌱' => 'binhi',
    '🪴' => 'nakapasong halaman',
    '🌲' => 'evergreen',
    '🌳' => 'punong nalalagas ang dahon',
    '🌴' => 'palmera',
    '🌵' => 'cactus',
    '🌾' => 'bigkis ng palay',
    '🌿' => 'halamang-gamot',
    '☘' => 'shamrock',
    '🍀' => 'four-leaf clover',
    '🍁' => 'dahon ng maple',
    '🍂' => 'nalagas na dahon',
    '🍃' => 'dahong nililipad ng hangin',
    '🪹' => 'bakanteng pugad',
    '🪺' => 'pugad na may mga itlog',
    '🍄' => 'kabute',
    '🪾' => 'puno na walang dahon',
    '🍇' => 'ubas',
    '🍈' => 'melon',
    '🍉' => 'pakwan',
    '🍊' => 'dalanghita',
    '🍋' => 'lemon',
    '🍌' => 'saging',
    '🍍' => 'pinya',
    '🥭' => 'mangga',
    '🍎' => 'pulang mansanas',
    '🍏' => 'berdeng mansanas',
    '🍐' => 'peras',
    '🍑' => 'peach',
    '🍒' => 'cherry',
    '🍓' => 'strawberry',
    '🫐' => 'blueberries',
    '🥝' => 'kiwi',
    '🍅' => 'kamatis',
    '🫒' => 'olive',
    '🥥' => 'niyog',
    '🥑' => 'abokado',
    '🍆' => 'talong',
    '🥔' => 'patatas',
    '🥕' => 'carrot',
    '🌽' => 'busal ng mais',
    '🌶' => 'sili',
    '🫑' => 'bell pepper',
    '🥒' => 'pipino',
    '🥬' => 'madahong gulay',
    '🥦' => 'broccoli',
    '🧄' => 'bawang',
    '🧅' => 'sibuyas',
    '🥜' => 'mani',
    '🫘' => 'beans',
    '🌰' => 'kastanyas',
    '🫚' => 'luya',
    '🫛' => 'gisante',
    '🫜' => 'ugat na gulay',
    '🍞' => 'tinapay',
    '🥐' => 'croissant',
    '🥖' => 'baguette',
    '🫓' => 'flatbread',
    '🥨' => 'pretzel',
    '🥯' => 'bagel',
    '🥞' => 'pancakes',
    '🧇' => 'waffle',
    '🧀' => 'piraso ng keso',
    '🍖' => 'karneng may buto',
    '🍗' => 'binti ng manok',
    '🥩' => 'hiwa ng karne',
    '🥓' => 'bacon',
    '🍔' => 'hamburger',
    '🍟' => 'french fries',
    '🍕' => 'pizza',
    '🌭' => 'hot dog',
    '🥪' => 'sandwich',
    '🌮' => 'taco',
    '🌯' => 'burrito',
    '🫔' => 'tamale',
    '🥙' => 'stuffed flatbread',
    '🧆' => 'falafel',
    '🥚' => 'itlog',
    '🍳' => 'nagluluto',
    '🥘' => 'shallow pan ng pagkain',
    '🍲' => 'kaserola ng pagkain',
    '🫕' => 'fondue',
    '🥣' => 'mangkok na may kutsara',
    '🥗' => 'salad na gulay',
    '🍿' => 'popcorn',
    '🧈' => 'mantikilya',
    '🧂' => 'asin',
    '🥫' => 'de-latang pagkain',
    '🍱' => 'bento box',
    '🍘' => 'rice cracker',
    '🍙' => 'rice ball',
    '🍚' => 'kanin',
    '🍛' => 'curry rice',
    '🍜' => 'mainit na noodles',
    '🍝' => 'spaghetti',
    '🍠' => 'inihaw na kamote',
    '🍢' => 'oden',
    '🍣' => 'sushi',
    '🍤' => 'piniritong hipon',
    '🍥' => 'fish cake na may swirl',
    '🥮' => 'moon cake',
    '🍡' => 'dango',
    '🥟' => 'dumpling',
    '🥠' => 'fortune cookie',
    '🥡' => 'takeout box',
    '🍦' => 'swirl ice cream',
    '🍧' => 'shaved ice',
    '🍨' => 'ice cream',
    '🍩' => 'doughnut',
    '🍪' => 'cookie',
    '🎂' => 'birthday cake',
    '🍰' => 'shortcake',
    '🧁' => 'cupcake',
    '🥧' => 'pie',
    '🍫' => 'tsokolate',
    '🍬' => 'kendi',
    '🍭' => 'lollipop',
    '🍮' => 'pudding',
    '🍯' => 'pulot-pukyutan',
    '🍼' => 'dede',
    '🥛' => 'baso ng gatas',
    '☕' => 'mainit na inumin',
    '🫖' => 'teapot',
    '🍵' => 'tasa ng tsaa na walang hawakan',
    '🍶' => 'sake',
    '🍾' => 'boteng naalis ang takip',
    '🍷' => 'wine glass',
    '🍸' => 'cocktail glass',
    '🍹' => 'tropical drink',
    '🍺' => 'beer mug',
    '🍻' => 'pagtagay sa mga beer mug',
    '🥂' => 'toast',
    '🥃' => 'tumbler glass',
    '🫗' => 'binubuhos na likido',
    '🥤' => 'baso na may straw',
    '🧋' => 'bubble tea',
    '🧃' => 'kahon ng inumin',
    '🧉' => 'mate',
    '🧊' => 'ice cube',
    '🥢' => 'chopsticks',
    '🍽' => 'tinidor, kutsilyo at pinggan',
    '🍴' => 'tinidor at kutsilyo',
    '🥄' => 'kutsara',
    '🔪' => 'kutsilyo',
    '🫙' => 'garapon',
    '🏺' => 'amphora',
    '🌍' => 'globong nagpapakita sa europe at africa',
    '🌎' => 'globong nagpapakita sa America',
    '🌏' => 'globong nagpapakita sa asia at australia',
    '🌐' => 'globong may mga meridian',
    '🗺' => 'mapa ng mundo',
    '🗾' => 'mapa ng japan',
    '🧭' => 'compass',
    '🏔' => 'bundok na may niyebe sa tuktok',
    '⛰' => 'bundok',
    '🛘' => 'landslide',
    '🌋' => 'bulkan',
    '🗻' => 'bundok fuji',
    '🏕' => 'camping',
    '🏖' => 'beach na may payong',
    '🏜' => 'disyerto',
    '🏝' => 'islang walang nakatira',
    '🏞' => 'national park',
    '🏟' => 'istadyum',
    '🏛' => 'klasikong gusali',
    '🏗' => 'construction ng gusali',
    '🧱' => 'brick',
    '🪨' => 'bato',
    '🪵' => 'kahoy',
    '🛖' => 'kubo',
    '🏘' => 'mga bahay',
    '🏚' => 'napabayaang bahay',
    '🏠' => 'bahay',
    '🏡' => 'bahay na may hardin',
    '🏢' => 'office building',
    '🏣' => 'japanese post office',
    '🏤' => 'post office',
    '🏥' => 'ospital',
    '🏦' => 'bangko',
    '🏨' => 'hotel',
    '🏩' => 'motel',
    '🏪' => 'convenience store',
    '🏫' => 'paaralan',
    '🏬' => 'department store',
    '🏭' => 'pagawaan',
    '🏯' => 'japanese castle',
    '🏰' => 'kastilyo',
    '💒' => 'kasalan',
    '🗼' => 'tokyo tower',
    '🗽' => 'statue of liberty',
    '⛪' => 'simbahan',
    '🕌' => 'mosque',
    '🛕' => 'hindu temple',
    '🕍' => 'sinagoga',
    '⛩' => 'shinto shrine',
    '🕋' => 'kaaba',
    '⛲' => 'fountain',
    '⛺' => 'tent',
    '🌁' => 'mahamog',
    '🌃' => 'gabing maraming bituin',
    '🏙' => 'cityscape',
    '🌄' => 'pagsikat ng araw sa mga bundok',
    '🌅' => 'pagsikat ng araw',
    '🌆' => 'cityscape sa takipsilim',
    '🌇' => 'paglubog ng araw',
    '🌉' => 'tulay sa gabi',
    '♨' => 'hot springs',
    '🎠' => 'kabayo sa carousel',
    '🛝' => 'padulas sa playground',
    '🎡' => 'ferris wheel',
    '🎢' => 'roller coaster',
    '💈' => 'barber pole',
    '🎪' => 'circus tent',
    '🚂' => 'makina ng tren',
    '🚃' => 'railway car',
    '🚄' => 'high-speed train',
    '🚅' => 'bullet train',
    '🚆' => 'tren',
    '🚇' => 'subway',
    '🚈' => 'light rail',
    '🚉' => 'istasyon',
    '🚊' => 'tram',
    '🚝' => 'monorail',
    '🚞' => 'mountain railway',
    '🚋' => 'tram car',
    '🚌' => 'bus',
    '🚍' => 'paparating na bus',
    '🚎' => 'trolleybus',
    '🚐' => 'minibus',
    '🚑' => 'ambulansya',
    '🚒' => 'fire truck',
    '🚓' => 'sasakyan ng polis',
    '🚔' => 'paparating na police car',
    '🚕' => 'taxi',
    '🚖' => 'paparating na taxi',
    '🚗' => 'kotse',
    '🚘' => 'paparating na kotse',
    '🚙' => 'recreational vehicle',
    '🛻' => 'pickup truck',
    '🚚' => 'delivery truck',
    '🚛' => 'semi-trailer truck',
    '🚜' => 'traktora',
    '🏎' => 'racing car',
    '🏍' => 'motorsiklo',
    '🛵' => 'motor scooter',
    '🦽' => 'manu-manong wheelchair',
    '🦼' => 'de-kuryenteng wheelchair',
    '🛺' => 'auto rickshaw',
    '🚲' => 'bisikleta',
    '🛴' => 'micro scooter',
    '🛹' => 'skateboard',
    '🛼' => 'roller skate',
    '🚏' => 'bus stop',
    '🛣' => 'expressway',
    '🛤' => 'riles ng tren',
    '🛢' => 'drum ng langis',
    '⛽' => 'fuel pump',
    '🛞' => 'gulong',
    '🚨' => 'ilaw ng police car',
    '🚥' => 'pahalang na traffic light',
    '🚦' => 'patayong traffic light',
    '🛑' => 'stop sign',
    '🚧' => 'construction',
    '⚓' => 'angkla',
    '🛟' => 'salbabida',
    '⛵' => 'bangkang may layag',
    '🛶' => 'canoe',
    '🚤' => 'speedboat',
    '🛳' => 'pampasaherong barko',
    '⛴' => 'ferry',
    '🛥' => 'bangkang de-motor',
    '🚢' => 'barko',
    '✈' => 'eroplano',
    '🛩' => 'maliit na eroplano',
    '🛫' => 'pag-alis ng eroplano',
    '🛬' => 'pagdating ng eroplano',
    '🪂' => 'parachute',
    '💺' => 'upuan',
    '🚁' => 'helicopter',
    '🚟' => 'suspension railway',
    '🚠' => 'mountain cable car',
    '🚡' => 'cable car',
    '🛰' => 'satellite',
    '🚀' => 'rocket',
    '🛸' => 'flying saucer',
    '🛎' => 'bellhop bell',
    '🧳' => 'maleta',
    '⌛' => 'hourglass',
    '⏳' => 'hourglass na may bumabagsak na buhangin',
    '⌚' => 'relo',
    '⏰' => 'alarm clock',
    '⏱' => 'stopwatch',
    '⏲' => 'timer',
    '🕰' => 'mantel clock',
    '🕛' => 'a las dose',
    '🕧' => 'a las dose y medya',
    '🕐' => 'a la una',
    '🕜' => 'a la una y medya',
    '🕑' => 'a las dos',
    '🕝' => 'a las dos y medya',
    '🕒' => 'a las tres',
    '🕞' => 'a las tres y medya',
    '🕓' => 'a las quatro',
    '🕟' => 'a las quatro y medya',
    '🕔' => 'a las singko',
    '🕠' => 'a las singko y medya',
    '🕕' => 'a las sais',
    '🕡' => 'a las sais y medya',
    '🕖' => 'a las siyete',
    '🕢' => 'a las siyete y medya',
    '🕗' => 'a las otso',
    '🕣' => 'a las otso y medya',
    '🕘' => 'a las nuwebe',
    '🕤' => 'a las nuwebe y medya',
    '🕙' => 'a las dies',
    '🕥' => 'a las dies y medya',
    '🕚' => 'a las onse',
    '🕦' => 'a las onse y medya',
    '🌑' => 'new moon',
    '🌒' => 'waxing crescent moon',
    '🌓' => 'first quarter moon',
    '🌔' => 'waxing gibbous moon',
    '🌕' => 'full moon',
    '🌖' => 'waning gibbous moon',
    '🌗' => 'last quarter moon',
    '🌘' => 'waning crescent moon',
    '🌙' => 'crescent moon',
    '🌚' => 'new moon na may mukha',
    '🌛' => 'first quarter moon na may mukha',
    '🌜' => 'last quarter moon na may mukha',
    '🌡' => 'thermometer',
    '☀' => 'araw',
    '🌝' => 'full moon na may mukha',
    '🌞' => 'araw na may mukha',
    '🪐' => 'planetang may singsing',
    '⭐' => 'puting bituin na katamtamang-laki',
    '🌟' => 'kumikinang na bituin',
    '🌠' => 'bulalakaw',
    '🌌' => 'milky way',
    '☁' => 'ulap',
    '⛅' => 'araw sa likod ng ulap',
    '⛈' => 'ulap na may kidlat at ulan',
    '🌤' => 'araw sa likod ng maliit na ulap',
    '🌥' => 'araw sa likod ng malaking ulap',
    '🌦' => 'araw sa likod ng ulap na may ulan',
    '🌧' => 'ulap na may ulan',
    '🌨' => 'ulap na may niyebe',
    '🌩' => 'ulap na may kidlat',
    '🌪' => 'ipu-ipo',
    '🌫' => 'hamog',
    '🌬' => 'mukha ng hangin',
    '🌀' => 'buhawi',
    '🌈' => 'bahaghari',
    '🌂' => 'nakasarang payong',
    '☂' => 'payong',
    '☔' => 'payong na nauulanan',
    '⛱' => 'payong na nakabaon',
    '⚡' => 'may mataas na boltahe',
    '❄' => 'snowflake',
    '☃' => 'snowman',
    '⛄' => 'snowman na walang niyebe',
    '☄' => 'comet',
    '🔥' => 'apoy',
    '💧' => 'maliit na patak',
    '🌊' => 'alon',
    '🎃' => 'jack-o-lantern',
    '🎄' => 'christmas tree',
    '🎆' => 'fireworks',
    '🎇' => 'sparkler',
    '🧨' => 'paputok',
    '✨' => 'kumikinang',
    '🎈' => 'lobo',
    '🎉' => 'party popper',
    '🎊' => 'confetti ball',
    '🎋' => 'tanabata tree',
    '🎍' => 'pine decoration',
    '🎎' => 'japanese na manika',
    '🎏' => 'carp streamer',
    '🎐' => 'wind chime',
    '🎑' => 'moon viewing ceremony',
    '🧧' => 'ampao',
    '🎀' => 'ribbon',
    '🎁' => 'nakabalot na regalo',
    '🎗' => 'nagpapaalalang ribbon',
    '🎟' => 'mga admission ticket',
    '🎫' => 'tiket',
    '🎖' => 'medalyang pangmilitar',
    '🏆' => 'trophy',
    '🏅' => 'medalyang pang-sports',
    '🥇' => 'medalyang 1st place',
    '🥈' => 'medalyang 2nd place',
    '🥉' => 'medalyang 3rd place',
    '⚽' => 'bola ng soccer',
    '⚾' => 'baseball',
    '🥎' => 'softball',
    '🏀' => 'basketball',
    '🏐' => 'volleyball',
    '🏈' => 'american football',
    '🏉' => 'rugby football',
    '🎾' => 'tennis',
    '🥏' => 'lumilipad na disk',
    '🎳' => 'bowling',
    '🏏' => 'cricket',
    '🏑' => 'field hockey',
    '🏒' => 'stick at puck sa ice hockey',
    '🥍' => 'lacrosse',
    '🏓' => 'ping pong',
    '🏸' => 'badminton',
    '🥊' => 'boxing glove',
    '🥋' => 'martial arts uniform',
    '🥅' => 'net ng goal',
    '⛳' => 'flag sa butas',
    '⛸' => 'ice skate',
    '🎣' => 'pamingwit',
    '🤿' => 'diving mask',
    '🎽' => 'running shirt',
    '🎿' => 'mga ski',
    '🛷' => 'sled',
    '🥌' => 'curling stone',
    '🎯' => 'bullseye',
    '🪀' => 'yoyo',
    '🪁' => 'saranggola',
    '🔫' => 'water gun',
    '🎱' => 'billiards',
    '🔮' => 'bolang kristal',
    '🪄' => 'magic wand',
    '🎮' => 'video game',
    '🕹' => 'joystick',
    '🎰' => 'slot machine',
    '🎲' => 'dice',
    '🧩' => 'jigsaw',
    '🧸' => 'teddy bear',
    '🪅' => 'piñata',
    '🪩' => 'disco ball',
    '🪆' => 'manikang matryoshka',
    '♠' => 'spade',
    '♥' => 'heart',
    '♦' => 'diamond',
    '♣' => 'club',
    '♟' => 'chess pawn',
    '🃏' => 'joker',
    '🀄' => 'mahjong red dragon',
    '🎴' => 'flower playing card',
    '🎭' => 'sining pantanghalan',
    '🖼' => 'frame na may larawan',
    '🎨' => 'paleta ng pintor',
    '🧵' => 'sinulid',
    '🪡' => 'karayom',
    '🧶' => 'yarn',
    '🪢' => 'buhol',
    '👓' => 'salamin sa mata',
    '🕶' => 'shades',
    '🥽' => 'goggles',
    '🥼' => 'kapa sa lab',
    '🦺' => 'life vest',
    '👔' => 'kurbata',
    '👕' => 'kamiseta',
    '👖' => 'pantalon',
    '🧣' => 'bandana',
    '🧤' => 'guwantes',
    '🧥' => 'kapa',
    '🧦' => 'medyas',
    '👗' => 'bestida',
    '👘' => 'kimono',
    '🥻' => 'sari',
    '🩱' => 'one-piece na swimsuit',
    '🩲' => 'mga brief',
    '🩳' => 'shorts',
    '👙' => 'bikini',
    '👚' => 'mga damit na pambabae',
    '🪭' => 'de-tiklop na pamaypay',
    '👛' => 'pitaka',
    '👜' => 'handbag',
    '👝' => 'clutch bag',
    '🛍' => 'mga shopping bag',
    '🎒' => 'backpack na pang-eskwela',
    '🩴' => 'tsinelas',
    '👞' => 'sapatos na panlalaki',
    '👟' => 'running shoes',
    '🥾' => 'pang-hiking na bota',
    '🥿' => 'flat na sapatos',
    '👠' => 'high heels',
    '👡' => 'pambabaeng sandals',
    '🩰' => 'sapatos pang-ballet',
    '👢' => 'pambabaeng boots',
    '🪮' => 'pampili ng buhok',
    '👑' => 'korona',
    '👒' => 'sumbrerong pambabae',
    '🎩' => 'top hat',
    '🎓' => 'graduation cap',
    '🧢' => 'sinisingil na sombrero',
    '🪖' => 'helmet pang-militar',
    '⛑' => 'helmet ng rescue worker',
    '📿' => 'prayer beads',
    '💄' => 'lipstick',
    '💍' => 'singsing',
    '💎' => 'gem stone',
    '🔇' => 'naka-off ang speaker',
    '🔈' => 'speaker na mahina ang sound',
    '🔉' => 'speaker na katamtaman ang sound',
    '🔊' => 'malakas ang speaker',
    '📢' => 'loudspeaker',
    '📣' => 'megaphone',
    '📯' => 'post horn',
    '🔔' => 'bell',
    '🔕' => 'bell na may slash',
    '🎼' => 'musical score',
    '🎵' => 'notang pangmusika',
    '🎶' => 'mga notang pangmusika',
    '🎙' => 'mikroponong pang-studio',
    '🎚' => 'level slider',
    '🎛' => 'mga control knob',
    '🎤' => 'mikropono',
    '🎧' => 'headphone',
    '📻' => 'radyo',
    '🎷' => 'saxophone',
    '🎺' => 'trumpeta',
    '🪊' => 'trombone',
    '🪗' => 'accordion',
    '🎸' => 'gitara',
    '🎹' => 'keyboard na pangmusika',
    '🎻' => 'biyulin',
    '🪕' => 'banjo',
    '🥁' => 'drum',
    '🪘' => 'mahabang drum',
    '🪇' => 'maracas',
    '🪈' => 'plawta',
    '🪉' => 'alpa',
    '📱' => 'mobile phone',
    '📲' => 'mobile phone na may arrow',
    '☎' => 'telepono',
    '📞' => 'receiver ng telepono',
    '📟' => 'pager',
    '📠' => 'fax machine',
    '🔋' => 'baterya',
    '🪫' => 'paubos ang baterya',
    '🔌' => 'electric plug',
    '💻' => 'laptop computer',
    '🖥' => 'desktop computer',
    '🖨' => 'printer',
    '⌨' => 'keyboard',
    '🖱' => 'computer mouse',
    '🖲' => 'trackball',
    '💽' => 'minidisc',
    '💾' => 'floppy disk',
    '💿' => 'optical disc',
    '📀' => 'dvd',
    '🧮' => 'abacus',
    '🎥' => 'movie camera',
    '🎞' => 'frame ng film',
    '📽' => 'film projector',
    '🎬' => 'clapper board',
    '📺' => 'telebisyon',
    '📷' => 'camera',
    '📸' => 'camera na may flash',
    '📹' => 'video camera',
    '📼' => 'videotape',
    '🔍' => 'magnifying glass na nakahilig sa kaliwa',
    '🔎' => 'magnifying glass na nakahilig sa kanan',
    '🕯' => 'kandila',
    '💡' => 'bumbilya ng ilaw',
    '🔦' => 'flashlight',
    '🏮' => 'pulang paper lantern',
    '🪔' => 'lamparang diya',
    '📔' => 'notebook na may disenyo ang pabalat',
    '📕' => 'nakasarang aklat',
    '📖' => 'nakabukas na aklat',
    '📗' => 'berdeng aklat',
    '📘' => 'asul na aklat',
    '📙' => 'orange na aklat',
    '📚' => 'mga aklat',
    '📓' => 'notebook',
    '📒' => 'ledger',
    '📃' => 'pahinang bahagyang nakarolyo',
    '📜' => 'kalatas',
    '📄' => 'pahinang nakaharap',
    '📰' => 'dyaryo',
    '🗞' => 'nakarolyong dyaryo',
    '📑' => 'mga bookmark tab',
    '🔖' => 'bookmark',
    '🏷' => 'label',
    '🪙' => 'barya',
    '💰' => 'supot ng pera',
    '🪎' => 'kaban ng kayamanan',
    '💴' => 'yen bill',
    '💵' => 'dollar bill',
    '💶' => 'euro bill',
    '💷' => 'pound bill',
    '💸' => 'perang may pakpak',
    '💳' => 'credit card',
    '🧾' => 'resibo',
    '💹' => 'pataas na chart na may yen',
    '✉' => 'sobre',
    '📧' => 'e-mail',
    '📨' => 'papasok na sobre',
    '📩' => 'sobreng may arrow',
    '📤' => 'outbox tray',
    '📥' => 'inbox tray',
    '📦' => 'package',
    '📫' => 'nakasarang mailbox na may nakataas na flag',
    '📪' => 'nakasarang mailbox na may nakababang flag',
    '📬' => 'nakabukas na mailbox na may nakataas na flag',
    '📭' => 'nakabukas na mailbox na may nakababang flag',
    '📮' => 'hulugan ng sulat',
    '🗳' => 'ballot box na may balota',
    '✏' => 'lapis',
    '✒' => 'itim na nib',
    '🖋' => 'fountain pen',
    '🖊' => 'ball pen',
    '🖌' => 'paintbrush',
    '🖍' => 'krayola',
    '📝' => 'memo',
    '💼' => 'briefcase',
    '📁' => 'file folder',
    '📂' => 'nakabukas na file folder',
    '🗂' => 'mga divider ng card index',
    '📅' => 'kalendaryo',
    '📆' => 'pinipilas na kalendaryo',
    '🗒' => 'spiral notepad',
    '🗓' => 'spiral na kalendaryo',
    '📇' => 'card index',
    '📈' => 'tumataas na chart',
    '📉' => 'bumababang chart',
    '📊' => 'bar chart',
    '📋' => 'clipboard',
    '📌' => 'pushpin',
    '📍' => 'bilog na pushpin',
    '📎' => 'paperclip',
    '🖇' => 'magkakawing na paperclip',
    '📏' => 'tuwid na ruler',
    '📐' => 'tatsulok na ruler',
    '✂' => 'gunting',
    '🗃' => 'kahon ng cardfile',
    '🗄' => 'file cabinet',
    '🗑' => 'basurahan',
    '🔒' => 'kandado',
    '🔓' => 'nakabukas na kandado',
    '🔏' => 'kandado na may panulat',
    '🔐' => 'nakasarang kandado na may susi',
    '🔑' => 'susi',
    '🗝' => 'lumang susi',
    '🔨' => 'martilyo',
    '🪓' => 'palakol',
    '⛏' => 'piko',
    '⚒' => 'martilyo at piko',
    '🛠' => 'martilyo at liyabe',
    '🗡' => 'patalim',
    '⚔' => 'magkakrus na espada',
    '💣' => 'bomba',
    '🪃' => 'boomerang',
    '🏹' => 'pana',
    '🛡' => 'kalasag',
    '🪚' => 'lagari',
    '🔧' => 'liyabe',
    '🪛' => 'screwdriver',
    '🔩' => 'nut at bolt',
    '⚙' => 'gear',
    '🗜' => 'compression',
    '⚖' => 'timbangan',
    '🦯' => 'baston',
    '🔗' => 'kawing',
    '⛓' => 'kadena',
    '🪝' => 'kawit',
    '🧰' => 'kahon ng kagamitan',
    '🧲' => 'magneto',
    '🪜' => 'hagdan',
    '🪏' => 'pala',
    '⚗' => 'alembic',
    '🧪' => 'test tube',
    '🧫' => 'petri dish',
    '🧬' => 'dna',
    '🔬' => 'microscope',
    '🔭' => 'telescope',
    '📡' => 'satellite antenna',
    '💉' => 'hiringgilya',
    '🩸' => 'patak ng dugo',
    '💊' => 'pill',
    '🩹' => 'adhesive na bandaid',
    '🩼' => 'saklay',
    '🩺' => 'stethoscope',
    '🩻' => 'x-ray',
    '🚪' => 'pinto',
    '🛗' => 'elevator',
    '🪞' => 'salamin',
    '🪟' => 'bintana',
    '🛏' => 'higaan',
    '🛋' => 'sofa at ilaw',
    '🪑' => 'silya',
    '🚽' => 'inodoro',
    '🪠' => 'plunger',
    '🚿' => 'shower',
    '🛁' => 'bathtub',
    '🪤' => 'panghuli ng daga',
    '🪒' => 'razor',
    '🧴' => 'bote ng losyon',
    '🧷' => 'perdible',
    '🧹' => 'walis',
    '🧺' => 'basket',
    '🧻' => 'rolyo ng tisyu',
    '🪣' => 'timba',
    '🧼' => 'sabon',
    '🫧' => 'bula',
    '🪥' => 'sipilyo',
    '🧽' => 'espongha',
    '🧯' => 'pamatay apoy',
    '🛒' => 'shopping cart',
    '🚬' => 'sigarilyo',
    '⚰' => 'kabaong',
    '🪦' => 'lapida',
    '⚱' => 'sisidlan ng abo',
    '🧿' => 'nazar amulet',
    '🪬' => 'hamsa',
    '🗿' => 'moai',
    '🪧' => 'karatula',
    '🪪' => 'identification card',
    '🏧' => 'tanda ng ATM',
    '🚮' => 'tanda na magtapon sa basurahan',
    '🚰' => 'naiinom na tubig',
    '♿' => 'wheelchair',
    '🚹' => 'banyong panlalaki',
    '🚺' => 'banyong pambabae',
    '🚻' => 'banyo',
    '🚼' => 'pansanggol',
    '🚾' => 'comfort room',
    '🛂' => 'passport control',
    '🛃' => 'customs',
    '🛄' => 'kuhanan ng bagahe',
    '🛅' => 'naiwang bagahe',
    '⚠' => 'babala',
    '🚸' => 'may mga batang tumatawid',
    '⛔' => 'hindi pwedeng pumasok',
    '🚫' => 'bawal',
    '🚳' => 'bawal ang mga bisikleta',
    '🚭' => 'bawal manigarilyo',
    '🚯' => 'bawal magkalat',
    '🚱' => 'hindi pwedeng inumin',
    '🚷' => 'bawal tumawid',
    '📵' => 'bawal ang mga mobile phone',
    '🔞' => 'bawal ang hindi pa disiotso',
    '☢' => 'radioactive',
    '☣' => 'biohazard',
    '⬆' => 'pataas na arrow',
    '↗' => 'pataas na pakanan na arrow',
    '➡' => 'pakanang arrow',
    '↘' => 'pababang pakanan na arrow',
    '⬇' => 'pababang arrow',
    '↙' => 'pababang pakaliwang arrow',
    '⬅' => 'pakaliwang arrow',
    '↖' => 'pataas na pakaliwang arrow',
    '↕' => 'pataas-pababang arrow',
    '↔' => 'pakaliwa-pakanang arrow',
    '↩' => 'pakanang arrow na kumurba pakaliwa',
    '↪' => 'pakaliwang arrow na kumurba pakanan',
    '⤴' => 'pakanang arrow na kumurba pataas',
    '⤵' => 'pakanang arrow na kumurba pababa',
    '🔃' => 'mga clockwise na patayong arrow',
    '🔄' => 'mga counterclockwise na arrow',
    '🔙' => 'back arrow',
    '🔚' => 'end arrow',
    '🔛' => 'on! arrow',
    '🔜' => 'soon arrow',
    '🔝' => 'top arrow',
    '🛐' => 'sambahan',
    '⚛' => 'atom',
    '🕉' => 'om',
    '✡' => 'star of david',
    '☸' => 'gulong ng dharma',
    '☯' => 'yin yang',
    '✝' => 'latin na krus',
    '☦' => 'orthodox na krus',
    '☪' => 'star and crescent',
    '☮' => 'simbolo ng kapayapaan',
    '🕎' => 'menorah',
    '🔯' => 'six-pointed star na may tuldok',
    '🪯' => 'khanda',
    '♈' => 'Aries',
    '♉' => 'Taurus',
    '♊' => 'Gemini',
    '♋' => 'Cancer',
    '♌' => 'Leo',
    '♍' => 'Virgo',
    '♎' => 'Libra',
    '♏' => 'Scorpio',
    '♐' => 'Sagittarius',
    '♑' => 'Capricorn',
    '♒' => 'Aquarius',
    '♓' => 'Pisces',
    '⛎' => 'Ophiuchus',
    '🔀' => 'button na i-shuffle ang mga track',
    '🔁' => 'button na ulitin',
    '🔂' => 'button na ulitin ang track',
    '▶' => 'button na i-play',
    '⏩' => 'button na i-fast forward',
    '⏭' => 'button na susunod na track',
    '⏯' => 'button na i-play o i-pause',
    '◀' => 'button na i-reverse',
    '⏪' => 'button na i-fast reverse',
    '⏮' => 'button na huling track',
    '🔼' => 'button na itaas',
    '⏫' => 'button na i-fast up',
    '🔽' => 'button na ibaba',
    '⏬' => 'button na i-fast down',
    '⏸' => 'button na i-pause',
    '⏹' => 'button na itigil',
    '⏺' => 'button na i-record',
    '⏏' => 'button na i-eject',
    '🎦' => 'sinehan',
    '🔅' => 'button na diliman',
    '🔆' => 'button na liwanagan',
    '📶' => 'mga antenna bar',
    '🛜' => 'wireless',
    '📳' => 'vibration mode',
    '📴' => 'i-off ang mobile phone',
    '♀' => 'simbolo ng babae',
    '♂' => 'simbolo ng lalaki',
    '⚧' => 'simbolo ng transgender',
    '✖' => 'multiply',
    '➕' => 'plus',
    '➖' => 'minus',
    '➗' => 'divide',
    '🟰' => 'madiin na equals sign',
    '♾' => 'infinity',
    '‼' => 'dobleng tandang padamdam',
    '⁉' => 'tandang padamdam at pananong',
    '❓' => 'pulang tandang pananong',
    '❔' => 'puting tandang pananong',
    '❕' => 'puting tandang padamdam',
    '❗' => 'tandang padamdam',
    '〰' => 'maalon na gitling',
    '💱' => 'palitan ng pera',
    '💲' => 'malaking dollar sign',
    '⚕' => 'simbolong pang-medikal',
    '♻' => 'simbolo ng pag-recycle',
    '⚜' => 'flordelis',
    '🔱' => 'trident emblem',
    '📛' => 'badge ng pangalan',
    '🔰' => 'japanese na simbolo para sa baguhan',
    '⭕' => 'malaking bilog',
    '✅' => 'puting tsek',
    '☑' => 'balotang may tsek',
    '✔' => 'malaking tsek',
    '❌' => 'ekis',
    '❎' => 'button na ekis',
    '➰' => 'curly loop',
    '➿' => 'dobleng curly loop',
    '〽' => 'part alternation mark',
    '✳' => 'asterisk na may walong sulok',
    '✴' => 'bituin na may walong sulok',
    '❇' => 'kinang',
    '™' => 'trade mark',
    '🫟' => 'tilamsik',
    '🔠' => 'input na latin na uppercase',
    '🔡' => 'input na latin na lowercase',
    '🔢' => 'input na mga numero',
    '🔣' => 'input na mga simbolo',
    '🔤' => 'input na mga latin na titik',
    '🅰' => 'button na A',
    '🆎' => 'button na AB',
    '🅱' => 'button na B',
    '🆑' => 'button na CL',
    '🆒' => 'button na COOL',
    '🆓' => 'button na FREE',
    'ℹ' => 'pinagmulan ng impormasyon',
    '🆔' => 'button na ID',
    'Ⓜ' => 'binilugang M',
    '🆕' => 'button na NEW',
    '🆖' => 'button na NG',
    '🅾' => 'button na O',
    '🆗' => 'button na OK',
    '🅿' => 'button na P',
    '🆘' => 'button na SOS',
    '🆙' => 'button na UP!',
    '🆚' => 'button na VS',
    '🈁' => 'Hapones na button para sa salitang "dito"',
    '🈂' => 'Hapones na button para sa salitang "service charge"',
    '🈷' => 'Hapones na button para sa salitang "monthly amount"',
    '🈶' => 'Hapones na button na nagsasabing "hindi ito libre"',
    '🈯' => 'Hapopnes na button para sa salitang "nakareserba"',
    '🉐' => 'Hapones na button para sa salitang "bargain"',
    '🈹' => 'Hapones na button para sa salitang "diskuwento"',
    '🈚' => 'Hapones na button na nagsasabing "libre"',
    '🈲' => 'nakaparisukat na ideograph ng pagbabawal',
    '🉑' => 'nakabilog na ideograph ng pagtanggap',
    '🈸' => 'nakaparisukat na ideograph ng pag-apply',
    '🈴' => 'Japanese na button para sa "pasadong grado"',
    '🈳' => 'nakaparisukat na ideograph ng bakante',
    '㊗' => 'nakabilog na ideograph ng pagbati',
    '㊙' => 'nakabilog na ideograph ng lihim',
    '🈺' => 'Hapones na button para sa salitang “open for business”',
    '🈵' => 'Hapones na button para sa salitang “no vacancy”',
    '🔴' => 'pulang bilog',
    '🟠' => 'orange na bilog',
    '🟡' => 'dilaw na bilog',
    '🟢' => 'berdeng bilog',
    '🔵' => 'asul na bilog',
    '🟣' => 'lilang bilog',
    '🟤' => 'brown na bilog',
    '⚫' => 'itim na bilog',
    '⚪' => 'puting bilog',
    '🟥' => 'pulang parisukat',
    '🟧' => 'orange na parisukat',
    '🟨' => 'dilaw na parisukat',
    '🟩' => 'berdeng parisukat',
    '🟦' => 'asul na parisukat',
    '🟪' => 'lilang parisukat',
    '🟫' => 'brown na parisukat',
    '⬛' => 'malaking itim na parisukat',
    '⬜' => 'malaking puting parisukat',
    '◼' => 'katamtamang itim na parisukat',
    '◻' => 'katamtamang puting parisukat',
    '◾' => 'medyo maliit na itim na parisukat',
    '◽' => 'medyo maliit na puting parisukat',
    '▪' => 'maliit na itim na parisukat',
    '▫' => 'maliit na puting parisukat',
    '🔶' => 'malaking orange na diamond',
    '🔷' => 'malaking asul na diamond',
    '🔸' => 'maliit na orange na diamond',
    '🔹' => 'maliit na asul na diamond',
    '🔺' => 'pulang tatsulok na nakatutok pataas',
    '🔻' => 'pulang tatsulok na nakatutok pababa',
    '💠' => 'diamond na may tuldok',
    '🔘' => 'button ng radyo',
    '🔳' => 'puting parisukat na button',
    '🔲' => 'itim na parisukat na button',
    '🏁' => 'checkered na bandila',
    '🚩' => 'tatsulok na bandila',
    '🎌' => 'magkakrus na bandila',
    '🏴' => 'itim na bandila',
    '🏳' => 'puting bandila',
];
