<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'Tz’umanik: nim, nim, saq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'Tz’umanik: nim, nim, saq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'Tz’umanik: nim, nim, saq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'Tz’umanik: nim, nim, saq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'Tz’umanik: nim, nim, retal saq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'Tz’umanik: nim, nim, retal saq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'Tz’umanik: nim, nim, retal saq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'Tz’umanik: nim, nim, retal saq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'Tz’umanik: nim, nim, retal ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'Tz’umanik: nim, nim, retal ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'Tz’umanik: nim, nim, retal ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'Tz’umanik: nim, nim, retal ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'Tz’umanik: nim, nim, retal-q’eq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'Tz’umanik: nim, nim, retal-q’eq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'Tz’umanik: nim, nim, retal-q’eq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'Tz’umanik: nim, nim, retal-q’eq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'Tz’umanik: nim, nim, q’eq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'Tz’umanik: nim, nim, q’eq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'Tz’umanik: nim, nim, q’eq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'Tz’umanik: nim, nim, q’eq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👨🏻‍❤‍💋‍👨🏻' => 'Tz’umanik: Achi, Achi, saq ub’antajik b’aqilal',
    '👨🏻‍❤‍💋‍👨🏼' => 'Tz’umanik: Achi, Achi, saq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👨🏻‍❤‍💋‍👨🏽' => 'Tz’umanik: Achi, Achi, saq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👨🏻‍❤‍💋‍👨🏾' => 'Tz’umanik: Achi, Achi, saq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👨🏻‍❤‍💋‍👨🏿' => 'Tz’umanik: Achi, Achi, saq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👨🏼‍❤‍💋‍👨🏻' => 'Tz’umanik: Achi, Achi, retal saq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👨🏼‍❤‍💋‍👨🏼' => 'Tz’umanik: Achi, Achi, retal saq ub’antajik b’aqilal',
    '👨🏼‍❤‍💋‍👨🏽' => 'Tz’umanik: Achi, Achi, retal saq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👨🏼‍❤‍💋‍👨🏾' => 'Tz’umanik: Achi, Achi, retal saq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👨🏼‍❤‍💋‍👨🏿' => 'Tz’umanik: Achi, Achi, retal saq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👨🏽‍❤‍💋‍👨🏻' => 'Tz’umanik: Achi, Achi, retal ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👨🏽‍❤‍💋‍👨🏼' => 'Tz’umanik: Achi, Achi, retal ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👨🏽‍❤‍💋‍👨🏽' => 'Tz’umanik: Achi, Achi, retal ub’antajik b’aqilal',
    '👨🏽‍❤‍💋‍👨🏾' => 'Tz’umanik: Achi, Achi, retal ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👨🏽‍❤‍💋‍👨🏿' => 'Tz’umanik: Achi, Achi, retal ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👨🏾‍❤‍💋‍👨🏻' => 'Tz’umanik: Achi, Achi, retal-q’eq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👨🏾‍❤‍💋‍👨🏼' => 'Tz’umanik: Achi, Achi, retal-q’eq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👨🏾‍❤‍💋‍👨🏽' => 'Tz’umanik: Achi, Achi, retal-q’eq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👨🏾‍❤‍💋‍👨🏾' => 'Tz’umanik: Achi, Achi, retal-q’eq ub’antajik b’aqilal',
    '👨🏾‍❤‍💋‍👨🏿' => 'Tz’umanik: Achi, Achi, retal-q’eq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👨🏿‍❤‍💋‍👨🏻' => 'Tz’umanik: Achi, Achi, q’eq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👨🏿‍❤‍💋‍👨🏼' => 'Tz’umanik: Achi, Achi, q’eq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👨🏿‍❤‍💋‍👨🏽' => 'Tz’umanik: Achi, Achi, q’eq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👨🏿‍❤‍💋‍👨🏾' => 'Tz’umanik: Achi, Achi, q’eq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👨🏿‍❤‍💋‍👨🏿' => 'Tz’umanik: Achi, Achi, q’eq ub’antajik b’aqilal',
    '👩🏻‍❤‍💋‍👨🏻' => 'Tz’umanik: Ixoq, Achi, saq ub’antajik b’aqilal',
    '👩🏻‍❤‍💋‍👨🏼' => 'Tz’umanik: Ixoq, Achi, saq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👩🏻‍❤‍💋‍👨🏽' => 'Tz’umanik: Ixoq, Achi, saq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👩🏻‍❤‍💋‍👨🏾' => 'Tz’umanik: Ixoq, Achi, saq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👩🏻‍❤‍💋‍👨🏿' => 'Tz’umanik: Ixoq, Achi, saq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👩🏼‍❤‍💋‍👨🏻' => 'Tz’umanik: Ixoq, Achi, retal saq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👩🏼‍❤‍💋‍👨🏼' => 'Tz’umanik: Ixoq, Achi, retal saq ub’antajik b’aqilal',
    '👩🏼‍❤‍💋‍👨🏽' => 'Tz’umanik: Ixoq, Achi, retal saq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👩🏼‍❤‍💋‍👨🏾' => 'Tz’umanik: Ixoq, Achi, retal saq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👩🏼‍❤‍💋‍👨🏿' => 'Tz’umanik: Ixoq, Achi, retal saq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👩🏽‍❤‍💋‍👨🏻' => 'Tz’umanik: Ixoq, Achi, retal ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👩🏽‍❤‍💋‍👨🏼' => 'Tz’umanik: Ixoq, Achi, retal ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👩🏽‍❤‍💋‍👨🏽' => 'Tz’umanik: Ixoq, Achi, retal ub’antajik b’aqilal',
    '👩🏽‍❤‍💋‍👨🏾' => 'Tz’umanik: Ixoq, Achi, retal ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👩🏽‍❤‍💋‍👨🏿' => 'Tz’umanik: Ixoq, Achi, retal ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👩🏾‍❤‍💋‍👨🏻' => 'Tz’umanik: Ixoq, Achi, retal-q’eq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👩🏾‍❤‍💋‍👨🏼' => 'Tz’umanik: Ixoq, Achi, retal-q’eq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👩🏾‍❤‍💋‍👨🏽' => 'Tz’umanik: Ixoq, Achi, retal-q’eq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👩🏾‍❤‍💋‍👨🏾' => 'Tz’umanik: Ixoq, Achi, retal-q’eq ub’antajik b’aqilal',
    '👩🏾‍❤‍💋‍👨🏿' => 'Tz’umanik: Ixoq, Achi, retal-q’eq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👩🏿‍❤‍💋‍👨🏻' => 'Tz’umanik: Ixoq, Achi, q’eq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👩🏿‍❤‍💋‍👨🏼' => 'Tz’umanik: Ixoq, Achi, q’eq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👩🏿‍❤‍💋‍👨🏽' => 'Tz’umanik: Ixoq, Achi, q’eq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👩🏿‍❤‍💋‍👨🏾' => 'Tz’umanik: Ixoq, Achi, q’eq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👩🏿‍❤‍💋‍👨🏿' => 'Tz’umanik: Ixoq, Achi, q’eq ub’antajik b’aqilal',
    '👩🏻‍❤‍💋‍👩🏻' => 'Tz’umanik: Ixoq, Ixoq, saq ub’antajik b’aqilal',
    '👩🏻‍❤‍💋‍👩🏼' => 'Tz’umanik: Ixoq, Ixoq, saq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👩🏻‍❤‍💋‍👩🏽' => 'Tz’umanik: Ixoq, Ixoq, saq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👩🏻‍❤‍💋‍👩🏾' => 'Tz’umanik: Ixoq, Ixoq, saq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👩🏻‍❤‍💋‍👩🏿' => 'Tz’umanik: Ixoq, Ixoq, saq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👩🏼‍❤‍💋‍👩🏻' => 'Tz’umanik: Ixoq, Ixoq, retal saq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👩🏼‍❤‍💋‍👩🏼' => 'Tz’umanik: Ixoq, Ixoq, retal saq ub’antajik b’aqilal',
    '👩🏼‍❤‍💋‍👩🏽' => 'Tz’umanik: Ixoq, Ixoq, retal saq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👩🏼‍❤‍💋‍👩🏾' => 'Tz’umanik: Ixoq, Ixoq, retal saq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👩🏼‍❤‍💋‍👩🏿' => 'Tz’umanik: Ixoq, Ixoq, retal saq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👩🏽‍❤‍💋‍👩🏻' => 'Tz’umanik: Ixoq, Ixoq, retal ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👩🏽‍❤‍💋‍👩🏼' => 'Tz’umanik: Ixoq, Ixoq, retal ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👩🏽‍❤‍💋‍👩🏽' => 'Tz’umanik: Ixoq, Ixoq, retal ub’antajik b’aqilal',
    '👩🏽‍❤‍💋‍👩🏾' => 'Tz’umanik: Ixoq, Ixoq, retal ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👩🏽‍❤‍💋‍👩🏿' => 'Tz’umanik: Ixoq, Ixoq, retal ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👩🏾‍❤‍💋‍👩🏻' => 'Tz’umanik: Ixoq, Ixoq, retal-q’eq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👩🏾‍❤‍💋‍👩🏼' => 'Tz’umanik: Ixoq, Ixoq, retal-q’eq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👩🏾‍❤‍💋‍👩🏽' => 'Tz’umanik: Ixoq, Ixoq, retal-q’eq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👩🏾‍❤‍💋‍👩🏾' => 'Tz’umanik: Ixoq, Ixoq, retal-q’eq ub’antajik b’aqilal',
    '👩🏾‍❤‍💋‍👩🏿' => 'Tz’umanik: Ixoq, Ixoq, retal-q’eq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👩🏿‍❤‍💋‍👩🏻' => 'Tz’umanik: Ixoq, Ixoq, q’eq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👩🏿‍❤‍💋‍👩🏼' => 'Tz’umanik: Ixoq, Ixoq, q’eq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👩🏿‍❤‍💋‍👩🏽' => 'Tz’umanik: Ixoq, Ixoq, q’eq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👩🏿‍❤‍💋‍👩🏾' => 'Tz’umanik: Ixoq, Ixoq, q’eq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👩🏿‍❤‍💋‍👩🏿' => 'Tz’umanik: Ixoq, Ixoq, q’eq ub’antajik b’aqilal',
    '🧑🏻‍🫯‍🧑🏼' => 'E winaq kech’o’jinik: saq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '🧑🏻‍🫯‍🧑🏽' => 'E winaq kech’o’jinik: saq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '🧑🏻‍🫯‍🧑🏾' => 'E winaq kech’o’jinik: saq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '🧑🏻‍🫯‍🧑🏿' => 'E winaq kech’o’jinik: saq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '🧑🏼‍🫯‍🧑🏻' => 'E winaq kech’o’jinik: retal saq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '🧑🏼‍🫯‍🧑🏽' => 'E winaq kech’o’jinik: retal saq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '🧑🏼‍🫯‍🧑🏾' => 'E winaq kech’o’jinik: retal saq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '🧑🏼‍🫯‍🧑🏿' => 'E winaq kech’o’jinik: retal saq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '🧑🏽‍🫯‍🧑🏻' => 'E winaq kech’o’jinik: retal ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '🧑🏽‍🫯‍🧑🏼' => 'E winaq kech’o’jinik: retal ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '🧑🏽‍🫯‍🧑🏾' => 'E winaq kech’o’jinik: retal ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '🧑🏽‍🫯‍🧑🏿' => 'E winaq kech’o’jinik: retal ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '🧑🏾‍🫯‍🧑🏻' => 'E winaq kech’o’jinik: retal-q’eq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '🧑🏾‍🫯‍🧑🏼' => 'E winaq kech’o’jinik: retal-q’eq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '🧑🏾‍🫯‍🧑🏽' => 'E winaq kech’o’jinik: retal-q’eq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '🧑🏾‍🫯‍🧑🏿' => 'E winaq kech’o’jinik: retal-q’eq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '🧑🏿‍🫯‍🧑🏻' => 'E winaq kech’o’jinik: q’eq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '🧑🏿‍🫯‍🧑🏼' => 'E winaq kech’o’jinik: q’eq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '🧑🏿‍🫯‍🧑🏽' => 'E winaq kech’o’jinik: q’eq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '🧑🏿‍🫯‍🧑🏾' => 'E winaq kech’o’jinik: q’eq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '🧑🏻‍❤‍🧑🏼' => 'Kab’ichal ruk’ anima: nim, nim, saq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '🧑🏻‍❤‍🧑🏽' => 'Kab’ichal ruk’ anima: nim, nim, saq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '🧑🏻‍❤‍🧑🏾' => 'Kab’ichal ruk’ anima: nim, nim, saq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '🧑🏻‍❤‍🧑🏿' => 'Kab’ichal ruk’ anima: nim, nim, saq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '🧑🏼‍❤‍🧑🏻' => 'Kab’ichal ruk’ anima: nim, nim, retal saq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '🧑🏼‍❤‍🧑🏽' => 'Kab’ichal ruk’ anima: nim, nim, retal saq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '🧑🏼‍❤‍🧑🏾' => 'Kab’ichal ruk’ anima: nim, nim, retal saq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '🧑🏼‍❤‍🧑🏿' => 'Kab’ichal ruk’ anima: nim, nim, retal saq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '🧑🏽‍❤‍🧑🏻' => 'Kab’ichal ruk’ anima: nim, nim, retal ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '🧑🏽‍❤‍🧑🏼' => 'Kab’ichal ruk’ anima: nim, nim, retal ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '🧑🏽‍❤‍🧑🏾' => 'Kab’ichal ruk’ anima: nim, nim, retal ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '🧑🏽‍❤‍🧑🏿' => 'Kab’ichal ruk’ anima: nim, nim, retal ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '🧑🏾‍❤‍🧑🏻' => 'Kab’ichal ruk’ anima: nim, nim, retal-q’eq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '🧑🏾‍❤‍🧑🏼' => 'Kab’ichal ruk’ anima: nim, nim, retal-q’eq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '🧑🏾‍❤‍🧑🏽' => 'Kab’ichal ruk’ anima: nim, nim, retal-q’eq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '🧑🏾‍❤‍🧑🏿' => 'Kab’ichal ruk’ anima: nim, nim, retal-q’eq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '🧑🏿‍❤‍🧑🏻' => 'Kab’ichal ruk’ anima: nim, nim, q’eq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '🧑🏿‍❤‍🧑🏼' => 'Kab’ichal ruk’ anima: nim, nim, q’eq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '🧑🏿‍❤‍🧑🏽' => 'Kab’ichal ruk’ anima: nim, nim, q’eq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '🧑🏿‍❤‍🧑🏾' => 'Kab’ichal ruk’ anima: nim, nim, q’eq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '🧑🏻‍🐰‍🧑🏼' => 'E winaq ruk’ uxikin imul: saq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '🧑🏻‍🐰‍🧑🏽' => 'E winaq ruk’ uxikin imul: saq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '🧑🏻‍🐰‍🧑🏾' => 'E winaq ruk’ uxikin imul: saq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '🧑🏻‍🐰‍🧑🏿' => 'E winaq ruk’ uxikin imul: saq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '🧑🏼‍🐰‍🧑🏻' => 'E winaq ruk’ uxikin imul: retal saq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '🧑🏼‍🐰‍🧑🏽' => 'E winaq ruk’ uxikin imul: retal saq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '🧑🏼‍🐰‍🧑🏾' => 'E winaq ruk’ uxikin imul: retal saq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '🧑🏼‍🐰‍🧑🏿' => 'E winaq ruk’ uxikin imul: retal saq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '🧑🏽‍🐰‍🧑🏻' => 'E winaq ruk’ uxikin imul: retal ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '🧑🏽‍🐰‍🧑🏼' => 'E winaq ruk’ uxikin imul: retal ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '🧑🏽‍🐰‍🧑🏾' => 'E winaq ruk’ uxikin imul: retal ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '🧑🏽‍🐰‍🧑🏿' => 'E winaq ruk’ uxikin imul: retal ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '🧑🏾‍🐰‍🧑🏻' => 'E winaq ruk’ uxikin imul: retal-q’eq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '🧑🏾‍🐰‍🧑🏼' => 'E winaq ruk’ uxikin imul: retal-q’eq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '🧑🏾‍🐰‍🧑🏽' => 'E winaq ruk’ uxikin imul: retal-q’eq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '🧑🏾‍🐰‍🧑🏿' => 'E winaq ruk’ uxikin imul: retal-q’eq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '🧑🏿‍🐰‍🧑🏻' => 'E winaq ruk’ uxikin imul: q’eq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '🧑🏿‍🐰‍🧑🏼' => 'E winaq ruk’ uxikin imul: q’eq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '🧑🏿‍🐰‍🧑🏽' => 'E winaq ruk’ uxikin imul: q’eq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '🧑🏿‍🐰‍🧑🏾' => 'E winaq ruk’ uxikin imul: q’eq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👨🏻‍🫯‍👨🏼' => 'achi ktajin kch’ojinik: saq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👨🏻‍🫯‍👨🏽' => 'achi ktajin kch’ojinik: saq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👨🏻‍🫯‍👨🏾' => 'achi ktajin kch’ojinik: saq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👨🏻‍🫯‍👨🏿' => 'achi ktajin kch’ojinik: saq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👨🏼‍🫯‍👨🏻' => 'achi ktajin kch’ojinik: retal saq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👨🏼‍🫯‍👨🏽' => 'achi ktajin kch’ojinik: retal saq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👨🏼‍🫯‍👨🏾' => 'achi ktajin kch’ojinik: retal saq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👨🏼‍🫯‍👨🏿' => 'achi ktajin kch’ojinik: retal saq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👨🏽‍🫯‍👨🏻' => 'achi ktajin kch’ojinik: retal ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👨🏽‍🫯‍👨🏼' => 'achi ktajin kch’ojinik: retal ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👨🏽‍🫯‍👨🏾' => 'achi ktajin kch’ojinik: retal ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👨🏽‍🫯‍👨🏿' => 'achi ktajin kch’ojinik: retal ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👨🏾‍🫯‍👨🏻' => 'achi ktajin kch’ojinik: retal-q’eq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👨🏾‍🫯‍👨🏼' => 'achi ktajin kch’ojinik: retal-q’eq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👨🏾‍🫯‍👨🏽' => 'achi ktajin kch’ojinik: retal-q’eq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👨🏾‍🫯‍👨🏿' => 'achi ktajin kch’ojinik: retal-q’eq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👨🏿‍🫯‍👨🏻' => 'achi ktajin kch’ojinik: q’eq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👨🏿‍🫯‍👨🏼' => 'achi ktajin kch’ojinik: q’eq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👨🏿‍🫯‍👨🏽' => 'achi ktajin kch’ojinik: q’eq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👨🏿‍🫯‍👨🏾' => 'achi ktajin kch’ojinik: q’eq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👨🏻‍❤‍👨🏻' => 'Kab’ichal ruk’ anima: Achi, Achi, saq ub’antajik b’aqilal',
    '👨🏻‍❤‍👨🏼' => 'Kab’ichal ruk’ anima: Achi, Achi, saq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👨🏻‍❤‍👨🏽' => 'Kab’ichal ruk’ anima: Achi, Achi, saq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👨🏻‍❤‍👨🏾' => 'Kab’ichal ruk’ anima: Achi, Achi, saq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👨🏻‍❤‍👨🏿' => 'Kab’ichal ruk’ anima: Achi, Achi, saq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👨🏼‍❤‍👨🏻' => 'Kab’ichal ruk’ anima: Achi, Achi, retal saq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👨🏼‍❤‍👨🏼' => 'Kab’ichal ruk’ anima: Achi, Achi, retal saq ub’antajik b’aqilal',
    '👨🏼‍❤‍👨🏽' => 'Kab’ichal ruk’ anima: Achi, Achi, retal saq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👨🏼‍❤‍👨🏾' => 'Kab’ichal ruk’ anima: Achi, Achi, retal saq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👨🏼‍❤‍👨🏿' => 'Kab’ichal ruk’ anima: Achi, Achi, retal saq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👨🏽‍❤‍👨🏻' => 'Kab’ichal ruk’ anima: Achi, Achi, retal ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👨🏽‍❤‍👨🏼' => 'Kab’ichal ruk’ anima: Achi, Achi, retal ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👨🏽‍❤‍👨🏽' => 'Kab’ichal ruk’ anima: Achi, Achi, retal ub’antajik b’aqilal',
    '👨🏽‍❤‍👨🏾' => 'Kab’ichal ruk’ anima: Achi, Achi, retal ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👨🏽‍❤‍👨🏿' => 'Kab’ichal ruk’ anima: Achi, Achi, retal ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👨🏾‍❤‍👨🏻' => 'Kab’ichal ruk’ anima: Achi, Achi, retal-q’eq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👨🏾‍❤‍👨🏼' => 'Kab’ichal ruk’ anima: Achi, Achi, retal-q’eq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👨🏾‍❤‍👨🏽' => 'Kab’ichal ruk’ anima: Achi, Achi, retal-q’eq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👨🏾‍❤‍👨🏾' => 'Kab’ichal ruk’ anima: Achi, Achi, retal-q’eq ub’antajik b’aqilal',
    '👨🏾‍❤‍👨🏿' => 'Kab’ichal ruk’ anima: Achi, Achi, retal-q’eq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👨🏿‍❤‍👨🏻' => 'Kab’ichal ruk’ anima: Achi, Achi, q’eq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👨🏿‍❤‍👨🏼' => 'Kab’ichal ruk’ anima: Achi, Achi, q’eq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👨🏿‍❤‍👨🏽' => 'Kab’ichal ruk’ anima: Achi, Achi, q’eq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👨🏿‍❤‍👨🏾' => 'Kab’ichal ruk’ anima: Achi, Achi, q’eq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👨🏿‍❤‍👨🏿' => 'Kab’ichal ruk’ anima: Achi, Achi, q’eq ub’antajik b’aqilal',
    '👨🏻‍🐰‍👨🏼' => 'achi ruk’ uxikin imul pa nimaq’ij: saq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👨🏻‍🐰‍👨🏽' => 'achi ruk’ uxikin imul pa nimaq’ij: saq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👨🏻‍🐰‍👨🏾' => 'achi ruk’ uxikin imul pa nimaq’ij: saq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👨🏻‍🐰‍👨🏿' => 'achi ruk’ uxikin imul pa nimaq’ij: saq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👨🏼‍🐰‍👨🏻' => 'achi ruk’ uxikin imul pa nimaq’ij: retal saq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👨🏼‍🐰‍👨🏽' => 'achi ruk’ uxikin imul pa nimaq’ij: retal saq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👨🏼‍🐰‍👨🏾' => 'achi ruk’ uxikin imul pa nimaq’ij: retal saq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👨🏼‍🐰‍👨🏿' => 'achi ruk’ uxikin imul pa nimaq’ij: retal saq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👨🏽‍🐰‍👨🏻' => 'achi ruk’ uxikin imul pa nimaq’ij: retal ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👨🏽‍🐰‍👨🏼' => 'achi ruk’ uxikin imul pa nimaq’ij: retal ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👨🏽‍🐰‍👨🏾' => 'achi ruk’ uxikin imul pa nimaq’ij: retal ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👨🏽‍🐰‍👨🏿' => 'achi ruk’ uxikin imul pa nimaq’ij: retal ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👨🏾‍🐰‍👨🏻' => 'achi ruk’ uxikin imul pa nimaq’ij: retal-q’eq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👨🏾‍🐰‍👨🏼' => 'achi ruk’ uxikin imul pa nimaq’ij: retal-q’eq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👨🏾‍🐰‍👨🏽' => 'achi ruk’ uxikin imul pa nimaq’ij: retal-q’eq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👨🏾‍🐰‍👨🏿' => 'achi ruk’ uxikin imul pa nimaq’ij: retal-q’eq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👨🏿‍🐰‍👨🏻' => 'achi ruk’ uxikin imul pa nimaq’ij: q’eq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👨🏿‍🐰‍👨🏼' => 'achi ruk’ uxikin imul pa nimaq’ij: q’eq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👨🏿‍🐰‍👨🏽' => 'achi ruk’ uxikin imul pa nimaq’ij: q’eq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👨🏿‍🐰‍👨🏾' => 'achi ruk’ uxikin imul pa nimaq’ij: q’eq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👩🏻‍🫯‍👩🏼' => 'ixoq ktajin kch’ojinik: saq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👩🏻‍🫯‍👩🏽' => 'ixoq ktajin kch’ojinik: saq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👩🏻‍🫯‍👩🏾' => 'ixoq ktajin kch’ojinik: saq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👩🏻‍🫯‍👩🏿' => 'ixoq ktajin kch’ojinik: saq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👩🏼‍🫯‍👩🏻' => 'ixoq ktajin kch’ojinik: retal saq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👩🏼‍🫯‍👩🏽' => 'ixoq ktajin kch’ojinik: retal saq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👩🏼‍🫯‍👩🏾' => 'ixoq ktajin kch’ojinik: retal saq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👩🏼‍🫯‍👩🏿' => 'ixoq ktajin kch’ojinik: retal saq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👩🏽‍🫯‍👩🏻' => 'ixoq ktajin kch’ojinik: retal ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👩🏽‍🫯‍👩🏼' => 'ixoq ktajin kch’ojinik: retal ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👩🏽‍🫯‍👩🏾' => 'ixoq ktajin kch’ojinik: retal ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👩🏽‍🫯‍👩🏿' => 'ixoq ktajin kch’ojinik: retal ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👩🏾‍🫯‍👩🏻' => 'ixoq ktajin kch’ojinik: retal-q’eq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👩🏾‍🫯‍👩🏼' => 'ixoq ktajin kch’ojinik: retal-q’eq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👩🏾‍🫯‍👩🏽' => 'ixoq ktajin kch’ojinik: retal-q’eq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👩🏾‍🫯‍👩🏿' => 'ixoq ktajin kch’ojinik: retal-q’eq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👩🏿‍🫯‍👩🏻' => 'ixoq ktajin kch’ojinik: q’eq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👩🏿‍🫯‍👩🏼' => 'ixoq ktajin kch’ojinik: q’eq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👩🏿‍🫯‍👩🏽' => 'ixoq ktajin kch’ojinik: q’eq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👩🏿‍🫯‍👩🏾' => 'ixoq ktajin kch’ojinik: q’eq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👩🏻‍❤‍👨🏻' => 'Kab’ichal ruk’ anima: Ixoq, Achi, saq ub’antajik b’aqilal',
    '👩🏻‍❤‍👨🏼' => 'Kab’ichal ruk’ anima: Ixoq, Achi, saq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👩🏻‍❤‍👨🏽' => 'Kab’ichal ruk’ anima: Ixoq, Achi, saq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👩🏻‍❤‍👨🏾' => 'Kab’ichal ruk’ anima: Ixoq, Achi, saq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👩🏻‍❤‍👨🏿' => 'Kab’ichal ruk’ anima: Ixoq, Achi, saq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👩🏼‍❤‍👨🏻' => 'Kab’ichal ruk’ anima: Ixoq, Achi, retal saq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👩🏼‍❤‍👨🏼' => 'Kab’ichal ruk’ anima: Ixoq, Achi, retal saq ub’antajik b’aqilal',
    '👩🏼‍❤‍👨🏽' => 'Kab’ichal ruk’ anima: Ixoq, Achi, retal saq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👩🏼‍❤‍👨🏾' => 'Kab’ichal ruk’ anima: Ixoq, Achi, retal saq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👩🏼‍❤‍👨🏿' => 'Kab’ichal ruk’ anima: Ixoq, Achi, retal saq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👩🏽‍❤‍👨🏻' => 'Kab’ichal ruk’ anima: Ixoq, Achi, retal ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👩🏽‍❤‍👨🏼' => 'Kab’ichal ruk’ anima: Ixoq, Achi, retal ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👩🏽‍❤‍👨🏽' => 'Kab’ichal ruk’ anima: Ixoq, Achi, retal ub’antajik b’aqilal',
    '👩🏽‍❤‍👨🏾' => 'Kab’ichal ruk’ anima: Ixoq, Achi, retal ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👩🏽‍❤‍👨🏿' => 'Kab’ichal ruk’ anima: Ixoq, Achi, retal ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👩🏾‍❤‍👨🏻' => 'Kab’ichal ruk’ anima: Ixoq, Achi, retal-q’eq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👩🏾‍❤‍👨🏼' => 'Kab’ichal ruk’ anima: Ixoq, Achi, retal-q’eq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👩🏾‍❤‍👨🏽' => 'Kab’ichal ruk’ anima: Ixoq, Achi, retal-q’eq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👩🏾‍❤‍👨🏾' => 'Kab’ichal ruk’ anima: Ixoq, Achi, retal-q’eq ub’antajik b’aqilal',
    '👩🏾‍❤‍👨🏿' => 'Kab’ichal ruk’ anima: Ixoq, Achi, retal-q’eq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👩🏿‍❤‍👨🏻' => 'Kab’ichal ruk’ anima: Ixoq, Achi, q’eq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👩🏿‍❤‍👨🏼' => 'Kab’ichal ruk’ anima: Ixoq, Achi, q’eq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👩🏿‍❤‍👨🏽' => 'Kab’ichal ruk’ anima: Ixoq, Achi, q’eq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👩🏿‍❤‍👨🏾' => 'Kab’ichal ruk’ anima: Ixoq, Achi, q’eq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👩🏿‍❤‍👨🏿' => 'Kab’ichal ruk’ anima: Ixoq, Achi, q’eq ub’antajik b’aqilal',
    '👩🏻‍❤‍👩🏻' => 'Kab’ichal ruk’ anima: Ixoq, Ixoq, saq ub’antajik b’aqilal',
    '👩🏻‍❤‍👩🏼' => 'Kab’ichal ruk’ anima: Ixoq, Ixoq, saq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👩🏻‍❤‍👩🏽' => 'Kab’ichal ruk’ anima: Ixoq, Ixoq, saq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👩🏻‍❤‍👩🏾' => 'Kab’ichal ruk’ anima: Ixoq, Ixoq, saq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👩🏻‍❤‍👩🏿' => 'Kab’ichal ruk’ anima: Ixoq, Ixoq, saq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👩🏼‍❤‍👩🏻' => 'Kab’ichal ruk’ anima: Ixoq, Ixoq, retal saq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👩🏼‍❤‍👩🏼' => 'Kab’ichal ruk’ anima: Ixoq, Ixoq, retal saq ub’antajik b’aqilal',
    '👩🏼‍❤‍👩🏽' => 'Kab’ichal ruk’ anima: Ixoq, Ixoq, retal saq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👩🏼‍❤‍👩🏾' => 'Kab’ichal ruk’ anima: Ixoq, Ixoq, retal saq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👩🏼‍❤‍👩🏿' => 'Kab’ichal ruk’ anima: Ixoq, Ixoq, retal saq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👩🏽‍❤‍👩🏻' => 'Kab’ichal ruk’ anima: Ixoq, Ixoq, retal ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👩🏽‍❤‍👩🏼' => 'Kab’ichal ruk’ anima: Ixoq, Ixoq, retal ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👩🏽‍❤‍👩🏽' => 'Kab’ichal ruk’ anima: Ixoq, Ixoq, retal ub’antajik b’aqilal',
    '👩🏽‍❤‍👩🏾' => 'Kab’ichal ruk’ anima: Ixoq, Ixoq, retal ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👩🏽‍❤‍👩🏿' => 'Kab’ichal ruk’ anima: Ixoq, Ixoq, retal ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👩🏾‍❤‍👩🏻' => 'Kab’ichal ruk’ anima: Ixoq, Ixoq, retal-q’eq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👩🏾‍❤‍👩🏼' => 'Kab’ichal ruk’ anima: Ixoq, Ixoq, retal-q’eq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👩🏾‍❤‍👩🏽' => 'Kab’ichal ruk’ anima: Ixoq, Ixoq, retal-q’eq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👩🏾‍❤‍👩🏾' => 'Kab’ichal ruk’ anima: Ixoq, Ixoq, retal-q’eq ub’antajik b’aqilal',
    '👩🏾‍❤‍👩🏿' => 'Kab’ichal ruk’ anima: Ixoq, Ixoq, retal-q’eq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👩🏿‍❤‍👩🏻' => 'Kab’ichal ruk’ anima: Ixoq, Ixoq, q’eq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👩🏿‍❤‍👩🏼' => 'Kab’ichal ruk’ anima: Ixoq, Ixoq, q’eq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👩🏿‍❤‍👩🏽' => 'Kab’ichal ruk’ anima: Ixoq, Ixoq, q’eq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👩🏿‍❤‍👩🏾' => 'Kab’ichal ruk’ anima: Ixoq, Ixoq, q’eq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👩🏿‍❤‍👩🏿' => 'Kab’ichal ruk’ anima: Ixoq, Ixoq, q’eq ub’antajik b’aqilal',
    '👩🏻‍🐰‍👩🏼' => 'ixoq ruk’ uxikin imul pa nimaq’ij: saq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👩🏻‍🐰‍👩🏽' => 'ixoq ruk’ uxikin imul pa nimaq’ij: saq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👩🏻‍🐰‍👩🏾' => 'ixoq ruk’ uxikin imul pa nimaq’ij: saq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👩🏻‍🐰‍👩🏿' => 'ixoq ruk’ uxikin imul pa nimaq’ij: saq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👩🏼‍🐰‍👩🏻' => 'ixoq ruk’ uxikin imul pa nimaq’ij: retal saq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👩🏼‍🐰‍👩🏽' => 'ixoq ruk’ uxikin imul pa nimaq’ij: retal saq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👩🏼‍🐰‍👩🏾' => 'ixoq ruk’ uxikin imul pa nimaq’ij: retal saq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👩🏼‍🐰‍👩🏿' => 'ixoq ruk’ uxikin imul pa nimaq’ij: retal saq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👩🏽‍🐰‍👩🏻' => 'ixoq ruk’ uxikin imul pa nimaq’ij: retal ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👩🏽‍🐰‍👩🏼' => 'ixoq ruk’ uxikin imul pa nimaq’ij: retal ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👩🏽‍🐰‍👩🏾' => 'ixoq ruk’ uxikin imul pa nimaq’ij: retal ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👩🏽‍🐰‍👩🏿' => 'ixoq ruk’ uxikin imul pa nimaq’ij: retal ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👩🏾‍🐰‍👩🏻' => 'ixoq ruk’ uxikin imul pa nimaq’ij: retal-q’eq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👩🏾‍🐰‍👩🏼' => 'ixoq ruk’ uxikin imul pa nimaq’ij: retal-q’eq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👩🏾‍🐰‍👩🏽' => 'ixoq ruk’ uxikin imul pa nimaq’ij: retal-q’eq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👩🏾‍🐰‍👩🏿' => 'ixoq ruk’ uxikin imul pa nimaq’ij: retal-q’eq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👩🏿‍🐰‍👩🏻' => 'ixoq ruk’ uxikin imul pa nimaq’ij: q’eq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👩🏿‍🐰‍👩🏼' => 'ixoq ruk’ uxikin imul pa nimaq’ij: q’eq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👩🏿‍🐰‍👩🏽' => 'ixoq ruk’ uxikin imul pa nimaq’ij: q’eq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👩🏿‍🐰‍👩🏾' => 'ixoq ruk’ uxikin imul pa nimaq’ij: q’eq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👩🏻‍🤝‍👩🏼' => 'Keb’ ixoqib’ kichapom kiq’ab’: saq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👩🏻‍🤝‍👩🏽' => 'Keb’ ixoqib’ kichapom kiq’ab’: saq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👩🏻‍🤝‍👩🏾' => 'Keb’ ixoqib’ kichapom kiq’ab’: saq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👩🏻‍🤝‍👩🏿' => 'Keb’ ixoqib’ kichapom kiq’ab’: saq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👩🏼‍🤝‍👩🏻' => 'Keb’ ixoqib’ kichapom kiq’ab’: retal saq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👩🏼‍🤝‍👩🏽' => 'Keb’ ixoqib’ kichapom kiq’ab’: retal saq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👩🏼‍🤝‍👩🏾' => 'Keb’ ixoqib’ kichapom kiq’ab’: retal saq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👩🏼‍🤝‍👩🏿' => 'Keb’ ixoqib’ kichapom kiq’ab’: retal saq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👩🏽‍🤝‍👩🏻' => 'Keb’ ixoqib’ kichapom kiq’ab’: retal ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👩🏽‍🤝‍👩🏼' => 'Keb’ ixoqib’ kichapom kiq’ab’: retal ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👩🏽‍🤝‍👩🏾' => 'Keb’ ixoqib’ kichapom kiq’ab’: retal ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👩🏽‍🤝‍👩🏿' => 'Keb’ ixoqib’ kichapom kiq’ab’: retal ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👩🏾‍🤝‍👩🏻' => 'Keb’ ixoqib’ kichapom kiq’ab’: retal-q’eq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👩🏾‍🤝‍👩🏼' => 'Keb’ ixoqib’ kichapom kiq’ab’: retal-q’eq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👩🏾‍🤝‍👩🏽' => 'Keb’ ixoqib’ kichapom kiq’ab’: retal-q’eq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👩🏾‍🤝‍👩🏿' => 'Keb’ ixoqib’ kichapom kiq’ab’: retal-q’eq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👩🏿‍🤝‍👩🏻' => 'Keb’ ixoqib’ kichapom kiq’ab’: q’eq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👩🏿‍🤝‍👩🏼' => 'Keb’ ixoqib’ kichapom kiq’ab’: q’eq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👩🏿‍🤝‍👩🏽' => 'Keb’ ixoqib’ kichapom kiq’ab’: q’eq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👩🏿‍🤝‍👩🏾' => 'Keb’ ixoqib’ kichapom kiq’ab’: q’eq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👩🏻‍🤝‍👨🏼' => 'Achi chi’l ixoq kichapom kiq’ab’: saq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👩🏻‍🤝‍👨🏽' => 'Achi chi’l ixoq kichapom kiq’ab’: saq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👩🏻‍🤝‍👨🏾' => 'Achi chi’l ixoq kichapom kiq’ab’: saq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👩🏻‍🤝‍👨🏿' => 'Achi chi’l ixoq kichapom kiq’ab’: saq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👩🏼‍🤝‍👨🏻' => 'Achi chi’l ixoq kichapom kiq’ab’: retal saq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👩🏼‍🤝‍👨🏽' => 'Achi chi’l ixoq kichapom kiq’ab’: retal saq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👩🏼‍🤝‍👨🏾' => 'Achi chi’l ixoq kichapom kiq’ab’: retal saq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👩🏼‍🤝‍👨🏿' => 'Achi chi’l ixoq kichapom kiq’ab’: retal saq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👩🏽‍🤝‍👨🏻' => 'Achi chi’l ixoq kichapom kiq’ab’: retal ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👩🏽‍🤝‍👨🏼' => 'Achi chi’l ixoq kichapom kiq’ab’: retal ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👩🏽‍🤝‍👨🏾' => 'Achi chi’l ixoq kichapom kiq’ab’: retal ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👩🏽‍🤝‍👨🏿' => 'Achi chi’l ixoq kichapom kiq’ab’: retal ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👩🏾‍🤝‍👨🏻' => 'Achi chi’l ixoq kichapom kiq’ab’: retal-q’eq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👩🏾‍🤝‍👨🏼' => 'Achi chi’l ixoq kichapom kiq’ab’: retal-q’eq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👩🏾‍🤝‍👨🏽' => 'Achi chi’l ixoq kichapom kiq’ab’: retal-q’eq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👩🏾‍🤝‍👨🏿' => 'Achi chi’l ixoq kichapom kiq’ab’: retal-q’eq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👩🏿‍🤝‍👨🏻' => 'Achi chi’l ixoq kichapom kiq’ab’: q’eq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👩🏿‍🤝‍👨🏼' => 'Achi chi’l ixoq kichapom kiq’ab’: q’eq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👩🏿‍🤝‍👨🏽' => 'Achi chi’l ixoq kichapom kiq’ab’: q’eq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👩🏿‍🤝‍👨🏾' => 'Achi chi’l ixoq kichapom kiq’ab’: q’eq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👨🏻‍🤝‍👨🏼' => 'Keb’ achijab’ kichapom kiq’ab’: saq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👨🏻‍🤝‍👨🏽' => 'Keb’ achijab’ kichapom kiq’ab’: saq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👨🏻‍🤝‍👨🏾' => 'Keb’ achijab’ kichapom kiq’ab’: saq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👨🏻‍🤝‍👨🏿' => 'Keb’ achijab’ kichapom kiq’ab’: saq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👨🏼‍🤝‍👨🏻' => 'Keb’ achijab’ kichapom kiq’ab’: retal saq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👨🏼‍🤝‍👨🏽' => 'Keb’ achijab’ kichapom kiq’ab’: retal saq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👨🏼‍🤝‍👨🏾' => 'Keb’ achijab’ kichapom kiq’ab’: retal saq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👨🏼‍🤝‍👨🏿' => 'Keb’ achijab’ kichapom kiq’ab’: retal saq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👨🏽‍🤝‍👨🏻' => 'Keb’ achijab’ kichapom kiq’ab’: retal ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👨🏽‍🤝‍👨🏼' => 'Keb’ achijab’ kichapom kiq’ab’: retal ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👨🏽‍🤝‍👨🏾' => 'Keb’ achijab’ kichapom kiq’ab’: retal ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👨🏽‍🤝‍👨🏿' => 'Keb’ achijab’ kichapom kiq’ab’: retal ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👨🏾‍🤝‍👨🏻' => 'Keb’ achijab’ kichapom kiq’ab’: retal-q’eq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👨🏾‍🤝‍👨🏼' => 'Keb’ achijab’ kichapom kiq’ab’: retal-q’eq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👨🏾‍🤝‍👨🏽' => 'Keb’ achijab’ kichapom kiq’ab’: retal-q’eq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👨🏾‍🤝‍👨🏿' => 'Keb’ achijab’ kichapom kiq’ab’: retal-q’eq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '👨🏿‍🤝‍👨🏻' => 'Keb’ achijab’ kichapom kiq’ab’: q’eq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '👨🏿‍🤝‍👨🏼' => 'Keb’ achijab’ kichapom kiq’ab’: q’eq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '👨🏿‍🤝‍👨🏽' => 'Keb’ achijab’ kichapom kiq’ab’: q’eq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '👨🏿‍🤝‍👨🏾' => 'Keb’ achijab’ kichapom kiq’ab’: q’eq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👩‍❤‍💋‍👨' => 'Tz’umanik: Ixoq, Achi',
    '👨‍❤‍💋‍👨' => 'Tz’umanik: Achi, Achi',
    '👩‍❤‍💋‍👩' => 'Tz’umanik: Ixoq, Ixoq',
    '👨‍👩‍👧‍👦' => 'Ajupaja: Achi, Ixoq, Ali, Ala',
    '👨‍👩‍👦‍👦' => 'Ajupaja: Achi, Ixoq, Ala, Ala',
    '👨‍👩‍👧‍👧' => 'Ajupaja: Achi, Ixoq, Ali, Ali',
    '👨‍👨‍👧‍👦' => 'Ajupaja: Achi, Achi, Ali, Ala',
    '👨‍👨‍👦‍👦' => 'Ajupaja: Achi, Achi, Ala, Ala',
    '👨‍👨‍👧‍👧' => 'Ajupaja: Achi, Achi, Ali, Ali',
    '👩‍👩‍👧‍👦' => 'Ajupaja: Ixoq, Ixoq, Ali, Ala',
    '👩‍👩‍👦‍👦' => 'Ajupaja: Ixoq, Ixoq, Ala, Ala',
    '👩‍👩‍👧‍👧' => 'Ajupaja: Ixoq, Ixoq, Ali, Ali',
    '🫱🏻‍🫲🏼' => 'Uk’ulaxik Q’ab’aj: saq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '🫱🏻‍🫲🏽' => 'Uk’ulaxik Q’ab’aj: saq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '🫱🏻‍🫲🏾' => 'Uk’ulaxik Q’ab’aj: saq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '🫱🏻‍🫲🏿' => 'Uk’ulaxik Q’ab’aj: saq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '🫱🏼‍🫲🏻' => 'Uk’ulaxik Q’ab’aj: retal saq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '🫱🏼‍🫲🏽' => 'Uk’ulaxik Q’ab’aj: retal saq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '🫱🏼‍🫲🏾' => 'Uk’ulaxik Q’ab’aj: retal saq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '🫱🏼‍🫲🏿' => 'Uk’ulaxik Q’ab’aj: retal saq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '🫱🏽‍🫲🏻' => 'Uk’ulaxik Q’ab’aj: retal ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '🫱🏽‍🫲🏼' => 'Uk’ulaxik Q’ab’aj: retal ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '🫱🏽‍🫲🏾' => 'Uk’ulaxik Q’ab’aj: retal ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '🫱🏽‍🫲🏿' => 'Uk’ulaxik Q’ab’aj: retal ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '🫱🏾‍🫲🏻' => 'Uk’ulaxik Q’ab’aj: retal-q’eq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '🫱🏾‍🫲🏼' => 'Uk’ulaxik Q’ab’aj: retal-q’eq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '🫱🏾‍🫲🏽' => 'Uk’ulaxik Q’ab’aj: retal-q’eq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '🫱🏾‍🫲🏿' => 'Uk’ulaxik Q’ab’aj: retal-q’eq ub’antajik b’aqilal, q’eq ub’antajik b’aqilal',
    '🫱🏿‍🫲🏻' => 'Uk’ulaxik Q’ab’aj: q’eq ub’antajik b’aqilal, saq ub’antajik b’aqilal',
    '🫱🏿‍🫲🏼' => 'Uk’ulaxik Q’ab’aj: q’eq ub’antajik b’aqilal, retal saq ub’antajik b’aqilal',
    '🫱🏿‍🫲🏽' => 'Uk’ulaxik Q’ab’aj: q’eq ub’antajik b’aqilal, retal ub’antajik b’aqilal',
    '🫱🏿‍🫲🏾' => 'Uk’ulaxik Q’ab’aj: q’eq ub’antajik b’aqilal, retal-q’eq ub’antajik b’aqilal',
    '👩‍❤‍👨' => 'Kab’ichal ruk’ anima: Ixoq, Achi',
    '👨‍❤‍👨' => 'Kab’ichal ruk’ anima: Achi, Achi',
    '👩‍❤‍👩' => 'Kab’ichal ruk’ anima: Ixoq, Ixoq',
    '👨‍👩‍👦' => 'Ajupaja: Achi, Ixoq, Ala',
    '👨‍👩‍👧' => 'Ajupaja: Achi, Ixoq, Ali',
    '👨‍👨‍👦' => 'Ajupaja: Achi, Achi, Ala',
    '👨‍👨‍👧' => 'Ajupaja: Achi, Achi, Ali',
    '👩‍👩‍👦' => 'Ajupaja: Ixoq, Ixoq, Ala',
    '👩‍👩‍👧' => 'Ajupaja: Ixoq, Ixoq, Ali',
    '👨‍👦‍👦' => 'Ajupaja: Achi, Ala, Ala',
    '👨‍👧‍👦' => 'Ajupaja: Achi, Ali, Ala',
    '👨‍👧‍👧' => 'Ajupaja: Achi, Ali, Ali',
    '👩‍👦‍👦' => 'Ajupaja: Ixoq, Ala, Ala',
    '👩‍👧‍👦' => 'Ajupaja: Ixoq, Ali, Ala',
    '👩‍👧‍👧' => 'Ajupaja: Ixoq, Ali, Ali',
    '👱🏻‍♂' => 'aci q’an uwi’: saq ub’antajik b’aqilal',
    '👱🏼‍♂' => 'aci q’an uwi’: retal saq ub’antajik b’aqilal',
    '👱🏽‍♂' => 'aci q’an uwi’: retal ub’antajik b’aqilal',
    '👱🏾‍♂' => 'aci q’an uwi’: retal-q’eq ub’antajik b’aqilal',
    '👱🏿‍♂' => 'aci q’an uwi’: q’eq ub’antajik b’aqilal',
    '👱🏻‍♀' => 'ixoq q’an uwi’: saq ub’antajik b’aqilal',
    '👱🏼‍♀' => 'ixoq q’an uwi’: retal saq ub’antajik b’aqilal',
    '👱🏽‍♀' => 'ixoq q’an uwi’: retal ub’antajik b’aqilal',
    '👱🏾‍♀' => 'ixoq q’an uwi’: retal-q’eq ub’antajik b’aqilal',
    '👱🏿‍♀' => 'ixoq q’an uwi’: q’eq ub’antajik b’aqilal',
    '🙍🏻‍♂' => 'achi b’isorinaq: saq ub’antajik b’aqilal',
    '🙍🏼‍♂' => 'achi b’isorinaq: retal saq ub’antajik b’aqilal',
    '🙍🏽‍♂' => 'achi b’isorinaq: retal ub’antajik b’aqilal',
    '🙍🏾‍♂' => 'achi b’isorinaq: retal-q’eq ub’antajik b’aqilal',
    '🙍🏿‍♂' => 'achi b’isorinaq: q’eq ub’antajik b’aqilal',
    '🙍🏻‍♀' => 'ixoq b’isorinaq: saq ub’antajik b’aqilal',
    '🙍🏼‍♀' => 'ixoq b’isorinaq: retal saq ub’antajik b’aqilal',
    '🙍🏽‍♀' => 'ixoq b’isorinaq: retal ub’antajik b’aqilal',
    '🙍🏾‍♀' => 'ixoq b’isorinaq: retal-q’eq ub’antajik b’aqilal',
    '🙍🏿‍♀' => 'ixoq b’isorinaq: q’eq ub’antajik b’aqilal',
    '🙎🏻‍♂' => 'achi xuq’ulik: saq ub’antajik b’aqilal',
    '🙎🏼‍♂' => 'achi xuq’ulik: retal saq ub’antajik b’aqilal',
    '🙎🏽‍♂' => 'achi xuq’ulik: retal ub’antajik b’aqilal',
    '🙎🏾‍♂' => 'achi xuq’ulik: retal-q’eq ub’antajik b’aqilal',
    '🙎🏿‍♂' => 'achi xuq’ulik: q’eq ub’antajik b’aqilal',
    '🙎🏻‍♀' => 'ixoq xuq’ulik: saq ub’antajik b’aqilal',
    '🙎🏼‍♀' => 'ixoq xuq’ulik: retal saq ub’antajik b’aqilal',
    '🙎🏽‍♀' => 'ixoq xuq’ulik: retal ub’antajik b’aqilal',
    '🙎🏾‍♀' => 'ixoq xuq’ulik: retal-q’eq ub’antajik b’aqilal',
    '🙎🏿‍♀' => 'ixoq xuq’ulik: q’eq ub’antajik b’aqilal',
    '🙅🏻‍♂' => 'achi ktajin kuk’ut JA’I’: saq ub’antajik b’aqilal',
    '🙅🏼‍♂' => 'achi ktajin kuk’ut JA’I’: retal saq ub’antajik b’aqilal',
    '🙅🏽‍♂' => 'achi ktajin kuk’ut JA’I’: retal ub’antajik b’aqilal',
    '🙅🏾‍♂' => 'achi ktajin kuk’ut JA’I’: retal-q’eq ub’antajik b’aqilal',
    '🙅🏿‍♂' => 'achi ktajin kuk’ut JA’I’: q’eq ub’antajik b’aqilal',
    '🙅🏻‍♀' => 'ixoq uk’utum JA’I’: saq ub’antajik b’aqilal',
    '🙅🏼‍♀' => 'ixoq uk’utum JA’I’: retal saq ub’antajik b’aqilal',
    '🙅🏽‍♀' => 'ixoq uk’utum JA’I’: retal ub’antajik b’aqilal',
    '🙅🏾‍♀' => 'ixoq uk’utum JA’I’: retal-q’eq ub’antajik b’aqilal',
    '🙅🏿‍♀' => 'ixoq uk’utum JA’I’: q’eq ub’antajik b’aqilal',
    '🙆🏻‍♂' => 'achi ktajin kuk’ut JE’: saq ub’antajik b’aqilal',
    '🙆🏼‍♂' => 'achi ktajin kuk’ut JE’: retal saq ub’antajik b’aqilal',
    '🙆🏽‍♂' => 'achi ktajin kuk’ut JE’: retal ub’antajik b’aqilal',
    '🙆🏾‍♂' => 'achi ktajin kuk’ut JE’: retal-q’eq ub’antajik b’aqilal',
    '🙆🏿‍♂' => 'achi ktajin kuk’ut JE’: q’eq ub’antajik b’aqilal',
    '🙆🏻‍♀' => 'ixoq ktajin kuk’ut JE’: saq ub’antajik b’aqilal',
    '🙆🏼‍♀' => 'ixoq ktajin kuk’ut JE’: retal saq ub’antajik b’aqilal',
    '🙆🏽‍♀' => 'ixoq ktajin kuk’ut JE’: retal ub’antajik b’aqilal',
    '🙆🏾‍♀' => 'ixoq ktajin kuk’ut JE’: retal-q’eq ub’antajik b’aqilal',
    '🙆🏿‍♀' => 'ixoq ktajin kuk’ut JE’: q’eq ub’antajik b’aqilal',
    '💁🏻‍♂' => 'achi upaqab’isam uq’ab’: saq ub’antajik b’aqilal',
    '💁🏼‍♂' => 'achi upaqab’isam uq’ab’: retal saq ub’antajik b’aqilal',
    '💁🏽‍♂' => 'achi upaqab’isam uq’ab’: retal ub’antajik b’aqilal',
    '💁🏾‍♂' => 'achi upaqab’isam uq’ab’: retal-q’eq ub’antajik b’aqilal',
    '💁🏿‍♂' => 'achi upaqab’isam uq’ab’: q’eq ub’antajik b’aqilal',
    '💁🏻‍♀' => 'ixoq upaqab’isam uq’ab’: saq ub’antajik b’aqilal',
    '💁🏼‍♀' => 'ixoq upaqab’isam uq’ab’: retal saq ub’antajik b’aqilal',
    '💁🏽‍♀' => 'ixoq upaqab’isam uq’ab’: retal ub’antajik b’aqilal',
    '💁🏾‍♀' => 'ixoq upaqab’isam uq’ab’: retal-q’eq ub’antajik b’aqilal',
    '💁🏿‍♀' => 'ixoq upaqab’isam uq’ab’: q’eq ub’antajik b’aqilal',
    '🙋🏻‍♂' => 'achi uyakom uq’ab’: saq ub’antajik b’aqilal',
    '🙋🏼‍♂' => 'achi uyakom uq’ab’: retal saq ub’antajik b’aqilal',
    '🙋🏽‍♂' => 'achi uyakom uq’ab’: retal ub’antajik b’aqilal',
    '🙋🏾‍♂' => 'achi uyakom uq’ab’: retal-q’eq ub’antajik b’aqilal',
    '🙋🏿‍♂' => 'achi uyakom uq’ab’: q’eq ub’antajik b’aqilal',
    '🙋🏻‍♀' => 'ixoq uyakom uq’ab’: saq ub’antajik b’aqilal',
    '🙋🏼‍♀' => 'ixoq uyakom uq’ab’: retal saq ub’antajik b’aqilal',
    '🙋🏽‍♀' => 'ixoq uyakom uq’ab’: retal ub’antajik b’aqilal',
    '🙋🏾‍♀' => 'ixoq uyakom uq’ab’: retal-q’eq ub’antajik b’aqilal',
    '🙋🏿‍♀' => 'ixoq uyakom uq’ab’: q’eq ub’antajik b’aqilal',
    '🙇🏻‍♂' => 'achi ktajin kuk’ut k’ixb’alil: saq ub’antajik b’aqilal',
    '🙇🏼‍♂' => 'achi ktajin kuk’ut k’ixb’alil: retal saq ub’antajik b’aqilal',
    '🙇🏽‍♂' => 'achi ktajin kuk’ut k’ixb’alil: retal ub’antajik b’aqilal',
    '🙇🏾‍♂' => 'achi ktajin kuk’ut k’ixb’alil: retal-q’eq ub’antajik b’aqilal',
    '🙇🏿‍♂' => 'achi ktajin kuk’ut k’ixb’alil: q’eq ub’antajik b’aqilal',
    '🙇🏻‍♀' => 'Ixoq ktajin kuk’ut k’ixb’alil: saq ub’antajik b’aqilal',
    '🙇🏼‍♀' => 'Ixoq ktajin kuk’ut k’ixb’alil: retal saq ub’antajik b’aqilal',
    '🙇🏽‍♀' => 'Ixoq ktajin kuk’ut k’ixb’alil: retal ub’antajik b’aqilal',
    '🙇🏾‍♀' => 'Ixoq ktajin kuk’ut k’ixb’alil: retal-q’eq ub’antajik b’aqilal',
    '🙇🏿‍♀' => 'Ixoq ktajin kuk’ut k’ixb’alil: q’eq ub’antajik b’aqilal',
    '🤦🏻‍♂' => 'achi ktajin kuya’ uq’ab’ chi upalaj: saq ub’antajik b’aqilal',
    '🤦🏼‍♂' => 'achi ktajin kuya’ uq’ab’ chi upalaj: retal saq ub’antajik b’aqilal',
    '🤦🏽‍♂' => 'achi ktajin kuya’ uq’ab’ chi upalaj: retal ub’antajik b’aqilal',
    '🤦🏾‍♂' => 'achi ktajin kuya’ uq’ab’ chi upalaj: retal-q’eq ub’antajik b’aqilal',
    '🤦🏿‍♂' => 'achi ktajin kuya’ uq’ab’ chi upalaj: q’eq ub’antajik b’aqilal',
    '🤦🏻‍♀' => 'ixoq ktajin kuya’ uq’ab’ chi upalaj: saq ub’antajik b’aqilal',
    '🤦🏼‍♀' => 'ixoq ktajin kuya’ uq’ab’ chi upalaj: retal saq ub’antajik b’aqilal',
    '🤦🏽‍♀' => 'ixoq ktajin kuya’ uq’ab’ chi upalaj: retal ub’antajik b’aqilal',
    '🤦🏾‍♀' => 'ixoq ktajin kuya’ uq’ab’ chi upalaj: retal-q’eq ub’antajik b’aqilal',
    '🤦🏿‍♀' => 'ixoq ktajin kuya’ uq’ab’ chi upalaj: q’eq ub’antajik b’aqilal',
    '🤷🏻‍♂' => 'achi man q’alaj ta chi uwach: saq ub’antajik b’aqilal',
    '🤷🏼‍♂' => 'achi man q’alaj ta chi uwach: retal saq ub’antajik b’aqilal',
    '🤷🏽‍♂' => 'achi man q’alaj ta chi uwach: retal ub’antajik b’aqilal',
    '🤷🏾‍♂' => 'achi man q’alaj ta chi uwach: retal-q’eq ub’antajik b’aqilal',
    '🤷🏿‍♂' => 'achi man q’alaj ta chi uwach: q’eq ub’antajik b’aqilal',
    '🤷🏻‍♀' => 'ixoq man q’alaj ta chi uwach: saq ub’antajik b’aqilal',
    '🤷🏼‍♀' => 'ixoq man q’alaj ta chi uwach: retal saq ub’antajik b’aqilal',
    '🤷🏽‍♀' => 'ixoq man q’alaj ta chi uwach: retal ub’antajik b’aqilal',
    '🤷🏾‍♀' => 'ixoq man q’alaj ta chi uwach: retal-q’eq ub’antajik b’aqilal',
    '🤷🏿‍♀' => 'ixoq man q’alaj ta chi uwach: q’eq ub’antajik b’aqilal',
    '👨🏻‍⚕' => 'achi ajchaj chi rij utzwachil: saq ub’antajik b’aqilal',
    '👨🏼‍⚕' => 'achi ajchaj chi rij utzwachil: retal saq ub’antajik b’aqilal',
    '👨🏽‍⚕' => 'achi ajchaj chi rij utzwachil: retal ub’antajik b’aqilal',
    '👨🏾‍⚕' => 'achi ajchaj chi rij utzwachil: retal-q’eq ub’antajik b’aqilal',
    '👨🏿‍⚕' => 'achi ajchaj chi rij utzwachil: q’eq ub’antajik b’aqilal',
    '👩🏻‍⚕' => 'ixoq chakunel rech utzwachil: saq ub’antajik b’aqilal',
    '👩🏼‍⚕' => 'ixoq chakunel rech utzwachil: retal saq ub’antajik b’aqilal',
    '👩🏽‍⚕' => 'ixoq chakunel rech utzwachil: retal ub’antajik b’aqilal',
    '👩🏾‍⚕' => 'ixoq chakunel rech utzwachil: retal-q’eq ub’antajik b’aqilal',
    '👩🏿‍⚕' => 'ixoq chakunel rech utzwachil: q’eq ub’antajik b’aqilal',
    '👨🏻‍🎓' => 'achi tijoxel: saq ub’antajik b’aqilal',
    '👨🏼‍🎓' => 'achi tijoxel: retal saq ub’antajik b’aqilal',
    '👨🏽‍🎓' => 'achi tijoxel: retal ub’antajik b’aqilal',
    '👨🏾‍🎓' => 'achi tijoxel: retal-q’eq ub’antajik b’aqilal',
    '👨🏿‍🎓' => 'achi tijoxel: q’eq ub’antajik b’aqilal',
    '👩🏻‍🎓' => 'ixoq tijoxel: saq ub’antajik b’aqilal',
    '👩🏼‍🎓' => 'ixoq tijoxel: retal saq ub’antajik b’aqilal',
    '👩🏽‍🎓' => 'ixoq tijoxel: retal ub’antajik b’aqilal',
    '👩🏾‍🎓' => 'ixoq tijoxel: retal-q’eq ub’antajik b’aqilal',
    '👩🏿‍🎓' => 'ixoq tijoxel: q’eq ub’antajik b’aqilal',
    '👨🏻‍🏫' => 'achi ajtij: saq ub’antajik b’aqilal',
    '👨🏼‍🏫' => 'achi ajtij: retal saq ub’antajik b’aqilal',
    '👨🏽‍🏫' => 'achi ajtij: retal ub’antajik b’aqilal',
    '👨🏾‍🏫' => 'achi ajtij: retal-q’eq ub’antajik b’aqilal',
    '👨🏿‍🏫' => 'achi ajtij: q’eq ub’antajik b’aqilal',
    '👩🏻‍🏫' => 'ixoq ajtij: saq ub’antajik b’aqilal',
    '👩🏼‍🏫' => 'ixoq ajtij: retal saq ub’antajik b’aqilal',
    '👩🏽‍🏫' => 'ixoq ajtij: retal ub’antajik b’aqilal',
    '👩🏾‍🏫' => 'ixoq ajtij: retal-q’eq ub’antajik b’aqilal',
    '👩🏿‍🏫' => 'ixoq ajtij: q’eq ub’antajik b’aqilal',
    '👨🏻‍⚖' => 'achi q’atol tzij: saq ub’antajik b’aqilal',
    '👨🏼‍⚖' => 'achi q’atol tzij: retal saq ub’antajik b’aqilal',
    '👨🏽‍⚖' => 'achi q’atol tzij: retal ub’antajik b’aqilal',
    '👨🏾‍⚖' => 'achi q’atol tzij: retal-q’eq ub’antajik b’aqilal',
    '👨🏿‍⚖' => 'achi q’atol tzij: q’eq ub’antajik b’aqilal',
    '👩🏻‍⚖' => 'ixoq k’atb’al tzij: saq ub’antajik b’aqilal',
    '👩🏼‍⚖' => 'ixoq k’atb’al tzij: retal saq ub’antajik b’aqilal',
    '👩🏽‍⚖' => 'ixoq k’atb’al tzij: retal ub’antajik b’aqilal',
    '👩🏾‍⚖' => 'ixoq k’atb’al tzij: retal-q’eq ub’antajik b’aqilal',
    '👩🏿‍⚖' => 'ixoq k’atb’al tzij: q’eq ub’antajik b’aqilal',
    '👨🏻‍🌾' => 'achi ajtikon: saq ub’antajik b’aqilal',
    '👨🏼‍🌾' => 'achi ajtikon: retal saq ub’antajik b’aqilal',
    '👨🏽‍🌾' => 'achi ajtikon: retal ub’antajik b’aqilal',
    '👨🏾‍🌾' => 'achi ajtikon: retal-q’eq ub’antajik b’aqilal',
    '👨🏿‍🌾' => 'achi ajtikon: q’eq ub’antajik b’aqilal',
    '👩🏻‍🌾' => 'ixoq tikonel: saq ub’antajik b’aqilal',
    '👩🏼‍🌾' => 'ixoq tikonel: retal saq ub’antajik b’aqilal',
    '👩🏽‍🌾' => 'ixoq tikonel: retal ub’antajik b’aqilal',
    '👩🏾‍🌾' => 'ixoq tikonel: retal-q’eq ub’antajik b’aqilal',
    '👩🏿‍🌾' => 'ixoq tikonel: q’eq ub’antajik b’aqilal',
    '👨🏻‍🍳' => 'achi b’anal wa: saq ub’antajik b’aqilal',
    '👨🏼‍🍳' => 'achi b’anal wa: retal saq ub’antajik b’aqilal',
    '👨🏽‍🍳' => 'achi b’anal wa: retal ub’antajik b’aqilal',
    '👨🏾‍🍳' => 'achi b’anal wa: retal-q’eq ub’antajik b’aqilal',
    '👨🏿‍🍳' => 'achi b’anal wa: q’eq ub’antajik b’aqilal',
    '👩🏻‍🍳' => 'ixoq b’anal wa: saq ub’antajik b’aqilal',
    '👩🏼‍🍳' => 'ixoq b’anal wa: retal saq ub’antajik b’aqilal',
    '👩🏽‍🍳' => 'ixoq b’anal wa: retal ub’antajik b’aqilal',
    '👩🏾‍🍳' => 'ixoq b’anal wa: retal-q’eq ub’antajik b’aqilal',
    '👩🏿‍🍳' => 'ixoq b’anal wa: q’eq ub’antajik b’aqilal',
    '👨🏻‍🔧' => 'aj jaqoj ch’ich’: saq ub’antajik b’aqilal',
    '👨🏼‍🔧' => 'aj jaqoj ch’ich’: retal saq ub’antajik b’aqilal',
    '👨🏽‍🔧' => 'aj jaqoj ch’ich’: retal ub’antajik b’aqilal',
    '👨🏾‍🔧' => 'aj jaqoj ch’ich’: retal-q’eq ub’antajik b’aqilal',
    '👨🏿‍🔧' => 'aj jaqoj ch’ich’: q’eq ub’antajik b’aqilal',
    '👩🏻‍🔧' => 'ixoq jaqol ch’ich’: saq ub’antajik b’aqilal',
    '👩🏼‍🔧' => 'ixoq jaqol ch’ich’: retal saq ub’antajik b’aqilal',
    '👩🏽‍🔧' => 'ixoq jaqol ch’ich’: retal ub’antajik b’aqilal',
    '👩🏾‍🔧' => 'ixoq jaqol ch’ich’: retal-q’eq ub’antajik b’aqilal',
    '👩🏿‍🔧' => 'ixoq jaqol ch’ich’: q’eq ub’antajik b’aqilal',
    '👨🏻‍🏭' => 'achi ajachak pa ja b’anb’al: saq ub’antajik b’aqilal',
    '👨🏼‍🏭' => 'achi ajachak pa ja b’anb’al: retal saq ub’antajik b’aqilal',
    '👨🏽‍🏭' => 'achi ajachak pa ja b’anb’al: retal ub’antajik b’aqilal',
    '👨🏾‍🏭' => 'achi ajachak pa ja b’anb’al: retal-q’eq ub’antajik b’aqilal',
    '👨🏿‍🏭' => 'achi ajachak pa ja b’anb’al: q’eq ub’antajik b’aqilal',
    '👩🏻‍🏭' => 'ixoq ajchak pa ja b’anb’al: saq ub’antajik b’aqilal',
    '👩🏼‍🏭' => 'ixoq ajchak pa ja b’anb’al: retal saq ub’antajik b’aqilal',
    '👩🏽‍🏭' => 'ixoq ajchak pa ja b’anb’al: retal ub’antajik b’aqilal',
    '👩🏾‍🏭' => 'ixoq ajchak pa ja b’anb’al: retal-q’eq ub’antajik b’aqilal',
    '👩🏿‍🏭' => 'ixoq ajchak pa ja b’anb’al: q’eq ub’antajik b’aqilal',
    '👨🏻‍💼' => 'achi ajchak pa ja chakub’al: saq ub’antajik b’aqilal',
    '👨🏼‍💼' => 'achi ajchak pa ja chakub’al: retal saq ub’antajik b’aqilal',
    '👨🏽‍💼' => 'achi ajchak pa ja chakub’al: retal ub’antajik b’aqilal',
    '👨🏾‍💼' => 'achi ajchak pa ja chakub’al: retal-q’eq ub’antajik b’aqilal',
    '👨🏿‍💼' => 'achi ajchak pa ja chakub’al: q’eq ub’antajik b’aqilal',
    '👩🏻‍💼' => 'ixoq chakunel pa ja chak’ub’al: saq ub’antajik b’aqilal',
    '👩🏼‍💼' => 'ixoq chakunel pa ja chak’ub’al: retal saq ub’antajik b’aqilal',
    '👩🏽‍💼' => 'ixoq chakunel pa ja chak’ub’al: retal ub’antajik b’aqilal',
    '👩🏾‍💼' => 'ixoq chakunel pa ja chak’ub’al: retal-q’eq ub’antajik b’aqilal',
    '👩🏿‍💼' => 'ixoq chakunel pa ja chak’ub’al: q’eq ub’antajik b’aqilal',
    '👨🏻‍🔬' => 'ach aj q’inom eta’mab’al: saq ub’antajik b’aqilal',
    '👨🏼‍🔬' => 'ach aj q’inom eta’mab’al: retal saq ub’antajik b’aqilal',
    '👨🏽‍🔬' => 'ach aj q’inom eta’mab’al: retal ub’antajik b’aqilal',
    '👨🏾‍🔬' => 'ach aj q’inom eta’mab’al: retal-q’eq ub’antajik b’aqilal',
    '👨🏿‍🔬' => 'ach aj q’inom eta’mab’al: q’eq ub’antajik b’aqilal',
    '👩🏻‍🔬' => 'ixoq q’inom reta’mab’al: saq ub’antajik b’aqilal',
    '👩🏼‍🔬' => 'ixoq q’inom reta’mab’al: retal saq ub’antajik b’aqilal',
    '👩🏽‍🔬' => 'ixoq q’inom reta’mab’al: retal ub’antajik b’aqilal',
    '👩🏾‍🔬' => 'ixoq q’inom reta’mab’al: retal-q’eq ub’antajik b’aqilal',
    '👩🏿‍🔬' => 'ixoq q’inom reta’mab’al: q’eq ub’antajik b’aqilal',
    '👨🏻‍💻' => 'achi aj k’ak’ eta’mab’al: saq ub’antajik b’aqilal',
    '👨🏼‍💻' => 'achi aj k’ak’ eta’mab’al: retal saq ub’antajik b’aqilal',
    '👨🏽‍💻' => 'achi aj k’ak’ eta’mab’al: retal ub’antajik b’aqilal',
    '👨🏾‍💻' => 'achi aj k’ak’ eta’mab’al: retal-q’eq ub’antajik b’aqilal',
    '👨🏿‍💻' => 'achi aj k’ak’ eta’mab’al: q’eq ub’antajik b’aqilal',
    '👩🏻‍💻' => 'ixoq aj k’ak’ eta’mab’al: saq ub’antajik b’aqilal',
    '👩🏼‍💻' => 'ixoq aj k’ak’ eta’mab’al: retal saq ub’antajik b’aqilal',
    '👩🏽‍💻' => 'ixoq aj k’ak’ eta’mab’al: retal ub’antajik b’aqilal',
    '👩🏾‍💻' => 'ixoq aj k’ak’ eta’mab’al: retal-q’eq ub’antajik b’aqilal',
    '👩🏿‍💻' => 'ixoq aj k’ak’ eta’mab’al: q’eq ub’antajik b’aqilal',
    '👨🏻‍🎤' => 'achi b’ixanel: saq ub’antajik b’aqilal',
    '👨🏼‍🎤' => 'achi b’ixanel: retal saq ub’antajik b’aqilal',
    '👨🏽‍🎤' => 'achi b’ixanel: retal ub’antajik b’aqilal',
    '👨🏾‍🎤' => 'achi b’ixanel: retal-q’eq ub’antajik b’aqilal',
    '👨🏿‍🎤' => 'achi b’ixanel: q’eq ub’antajik b’aqilal',
    '👩🏻‍🎤' => 'ixoq b’ixanel: saq ub’antajik b’aqilal',
    '👩🏼‍🎤' => 'ixoq b’ixanel: retal saq ub’antajik b’aqilal',
    '👩🏽‍🎤' => 'ixoq b’ixanel: retal ub’antajik b’aqilal',
    '👩🏾‍🎤' => 'ixoq b’ixanel: retal-q’eq ub’antajik b’aqilal',
    '👩🏿‍🎤' => 'ixoq b’ixanel: q’eq ub’antajik b’aqilal',
    '👨🏻‍🎨' => 'achi ajje’lal chak: saq ub’antajik b’aqilal',
    '👨🏼‍🎨' => 'achi ajje’lal chak: retal saq ub’antajik b’aqilal',
    '👨🏽‍🎨' => 'achi ajje’lal chak: retal ub’antajik b’aqilal',
    '👨🏾‍🎨' => 'achi ajje’lal chak: retal-q’eq ub’antajik b’aqilal',
    '👨🏿‍🎨' => 'achi ajje’lal chak: q’eq ub’antajik b’aqilal',
    '👩🏻‍🎨' => 'ixoq ajje’lal chak: saq ub’antajik b’aqilal',
    '👩🏼‍🎨' => 'ixoq ajje’lal chak: retal saq ub’antajik b’aqilal',
    '👩🏽‍🎨' => 'ixoq ajje’lal chak: retal ub’antajik b’aqilal',
    '👩🏾‍🎨' => 'ixoq ajje’lal chak: retal-q’eq ub’antajik b’aqilal',
    '👩🏿‍🎨' => 'ixoq ajje’lal chak: q’eq ub’antajik b’aqilal',
    '👨🏻‍✈' => 'achi binsaj ch’ich’: saq ub’antajik b’aqilal',
    '👨🏼‍✈' => 'achi binsaj ch’ich’: retal saq ub’antajik b’aqilal',
    '👨🏽‍✈' => 'achi binsaj ch’ich’: retal ub’antajik b’aqilal',
    '👨🏾‍✈' => 'achi binsaj ch’ich’: retal-q’eq ub’antajik b’aqilal',
    '👨🏿‍✈' => 'achi binsaj ch’ich’: q’eq ub’antajik b’aqilal',
    '👩🏻‍✈' => 'ixoq b’inxik’ich’ich’: saq ub’antajik b’aqilal',
    '👩🏼‍✈' => 'ixoq b’inxik’ich’ich’: retal saq ub’antajik b’aqilal',
    '👩🏽‍✈' => 'ixoq b’inxik’ich’ich’: retal ub’antajik b’aqilal',
    '👩🏾‍✈' => 'ixoq b’inxik’ich’ich’: retal-q’eq ub’antajik b’aqilal',
    '👩🏿‍✈' => 'ixoq b’inxik’ich’ich’: q’eq ub’antajik b’aqilal',
    '👨🏻‍🚀' => 'achi nik’ol kaj: saq ub’antajik b’aqilal',
    '👨🏼‍🚀' => 'achi nik’ol kaj: retal saq ub’antajik b’aqilal',
    '👨🏽‍🚀' => 'achi nik’ol kaj: retal ub’antajik b’aqilal',
    '👨🏾‍🚀' => 'achi nik’ol kaj: retal-q’eq ub’antajik b’aqilal',
    '👨🏿‍🚀' => 'achi nik’ol kaj: q’eq ub’antajik b’aqilal',
    '👩🏻‍🚀' => 'ixoq nik’ol kaj: saq ub’antajik b’aqilal',
    '👩🏼‍🚀' => 'ixoq nik’ol kaj: retal saq ub’antajik b’aqilal',
    '👩🏽‍🚀' => 'ixoq nik’ol kaj: retal ub’antajik b’aqilal',
    '👩🏾‍🚀' => 'ixoq nik’ol kaj: retal-q’eq ub’antajik b’aqilal',
    '👩🏿‍🚀' => 'ixoq nik’ol kaj: q’eq ub’antajik b’aqilal',
    '👨🏻‍🚒' => 'achi chupul q’aq’: saq ub’antajik b’aqilal',
    '👨🏼‍🚒' => 'achi chupul q’aq’: retal saq ub’antajik b’aqilal',
    '👨🏽‍🚒' => 'achi chupul q’aq’: retal ub’antajik b’aqilal',
    '👨🏾‍🚒' => 'achi chupul q’aq’: retal-q’eq ub’antajik b’aqilal',
    '👨🏿‍🚒' => 'achi chupul q’aq’: q’eq ub’antajik b’aqilal',
    '👩🏻‍🚒' => 'ixoq chupul q’a’q: saq ub’antajik b’aqilal',
    '👩🏼‍🚒' => 'ixoq chupul q’a’q: retal saq ub’antajik b’aqilal',
    '👩🏽‍🚒' => 'ixoq chupul q’a’q: retal ub’antajik b’aqilal',
    '👩🏾‍🚒' => 'ixoq chupul q’a’q: retal-q’eq ub’antajik b’aqilal',
    '👩🏿‍🚒' => 'ixoq chupul q’a’q: q’eq ub’antajik b’aqilal',
    '👮🏻‍♂' => 'achi q’atb’altzij chajinel: saq ub’antajik b’aqilal',
    '👮🏼‍♂' => 'achi q’atb’altzij chajinel: retal saq ub’antajik b’aqilal',
    '👮🏽‍♂' => 'achi q’atb’altzij chajinel: retal ub’antajik b’aqilal',
    '👮🏾‍♂' => 'achi q’atb’altzij chajinel: retal-q’eq ub’antajik b’aqilal',
    '👮🏿‍♂' => 'achi q’atb’altzij chajinel: q’eq ub’antajik b’aqilal',
    '👮🏻‍♀' => 'ixoq q’atb’al tzij chajinel: saq ub’antajik b’aqilal',
    '👮🏼‍♀' => 'ixoq q’atb’al tzij chajinel: retal saq ub’antajik b’aqilal',
    '👮🏽‍♀' => 'ixoq q’atb’al tzij chajinel: retal ub’antajik b’aqilal',
    '👮🏾‍♀' => 'ixoq q’atb’al tzij chajinel: retal-q’eq ub’antajik b’aqilal',
    '👮🏿‍♀' => 'ixoq q’atb’al tzij chajinel: q’eq ub’antajik b’aqilal',
    '🕵🏻‍♂' => 'achi solonel uxe’: saq ub’antajik b’aqilal',
    '🕵🏼‍♂' => 'achi solonel uxe’: retal saq ub’antajik b’aqilal',
    '🕵🏽‍♂' => 'achi solonel uxe’: retal ub’antajik b’aqilal',
    '🕵🏾‍♂' => 'achi solonel uxe’: retal-q’eq ub’antajik b’aqilal',
    '🕵🏿‍♂' => 'achi solonel uxe’: q’eq ub’antajik b’aqilal',
    '🕵🏻‍♀' => 'ixoq solonel uxe’: saq ub’antajik b’aqilal',
    '🕵🏼‍♀' => 'ixoq solonel uxe’: retal saq ub’antajik b’aqilal',
    '🕵🏽‍♀' => 'ixoq solonel uxe’: retal ub’antajik b’aqilal',
    '🕵🏾‍♀' => 'ixoq solonel uxe’: retal-q’eq ub’antajik b’aqilal',
    '🕵🏿‍♀' => 'ixoq solonel uxe’: q’eq ub’antajik b’aqilal',
    '💂🏻‍♂' => 'achi chajinel: saq ub’antajik b’aqilal',
    '💂🏼‍♂' => 'achi chajinel: retal saq ub’antajik b’aqilal',
    '💂🏽‍♂' => 'achi chajinel: retal ub’antajik b’aqilal',
    '💂🏾‍♂' => 'achi chajinel: retal-q’eq ub’antajik b’aqilal',
    '💂🏿‍♂' => 'achi chajinel: q’eq ub’antajik b’aqilal',
    '💂🏻‍♀' => 'ixoq chajinel: saq ub’antajik b’aqilal',
    '💂🏼‍♀' => 'ixoq chajinel: retal saq ub’antajik b’aqilal',
    '💂🏽‍♀' => 'ixoq chajinel: retal ub’antajik b’aqilal',
    '💂🏾‍♀' => 'ixoq chajinel: retal-q’eq ub’antajik b’aqilal',
    '💂🏿‍♀' => 'ixoq chajinel: q’eq ub’antajik b’aqilal',
    '👷🏻‍♂' => 'achi chakunel pa tz’aqb’al: saq ub’antajik b’aqilal',
    '👷🏼‍♂' => 'achi chakunel pa tz’aqb’al: retal saq ub’antajik b’aqilal',
    '👷🏽‍♂' => 'achi chakunel pa tz’aqb’al: retal ub’antajik b’aqilal',
    '👷🏾‍♂' => 'achi chakunel pa tz’aqb’al: retal-q’eq ub’antajik b’aqilal',
    '👷🏿‍♂' => 'achi chakunel pa tz’aqb’al: q’eq ub’antajik b’aqilal',
    '👷🏻‍♀' => 'ixoq chakunel pa tz’aqb’al: saq ub’antajik b’aqilal',
    '👷🏼‍♀' => 'ixoq chakunel pa tz’aqb’al: retal saq ub’antajik b’aqilal',
    '👷🏽‍♀' => 'ixoq chakunel pa tz’aqb’al: retal ub’antajik b’aqilal',
    '👷🏾‍♀' => 'ixoq chakunel pa tz’aqb’al: retal-q’eq ub’antajik b’aqilal',
    '👷🏿‍♀' => 'ixoq chakunel pa tz’aqb’al: q’eq ub’antajik b’aqilal',
    '👳🏻‍♂' => 'achi ukojom pisb’al jolomaj: saq ub’antajik b’aqilal',
    '👳🏼‍♂' => 'achi ukojom pisb’al jolomaj: retal saq ub’antajik b’aqilal',
    '👳🏽‍♂' => 'achi ukojom pisb’al jolomaj: retal ub’antajik b’aqilal',
    '👳🏾‍♂' => 'achi ukojom pisb’al jolomaj: retal-q’eq ub’antajik b’aqilal',
    '👳🏿‍♂' => 'achi ukojom pisb’al jolomaj: q’eq ub’antajik b’aqilal',
    '👳🏻‍♀' => 'ixoq ukojom pisb’al jolomaj: saq ub’antajik b’aqilal',
    '👳🏼‍♀' => 'ixoq ukojom pisb’al jolomaj: retal saq ub’antajik b’aqilal',
    '👳🏽‍♀' => 'ixoq ukojom pisb’al jolomaj: retal ub’antajik b’aqilal',
    '👳🏾‍♀' => 'ixoq ukojom pisb’al jolomaj: retal-q’eq ub’antajik b’aqilal',
    '👳🏿‍♀' => 'ixoq ukojom pisb’al jolomaj: q’eq ub’antajik b’aqilal',
    '🧙🏻‍♂' => 'achi mayib’al: saq ub’antajik b’aqilal',
    '🧙🏼‍♂' => 'achi mayib’al: retal saq ub’antajik b’aqilal',
    '🧙🏽‍♂' => 'achi mayib’al: retal ub’antajik b’aqilal',
    '🧙🏾‍♂' => 'achi mayib’al: retal-q’eq ub’antajik b’aqilal',
    '🧙🏿‍♂' => 'achi mayib’al: q’eq ub’antajik b’aqilal',
    '🧙🏻‍♀' => 'ixoq mayinel: saq ub’antajik b’aqilal',
    '🧙🏼‍♀' => 'ixoq mayinel: retal saq ub’antajik b’aqilal',
    '🧙🏽‍♀' => 'ixoq mayinel: retal ub’antajik b’aqilal',
    '🧙🏾‍♀' => 'ixoq mayinel: retal-q’eq ub’antajik b’aqilal',
    '🧙🏿‍♀' => 'ixoq mayinel: q’eq ub’antajik b’aqilal',
    '🧚🏻‍♂' => 'achi hada: saq ub’antajik b’aqilal',
    '🧚🏼‍♂' => 'achi hada: retal saq ub’antajik b’aqilal',
    '🧚🏽‍♂' => 'achi hada: retal ub’antajik b’aqilal',
    '🧚🏾‍♂' => 'achi hada: retal-q’eq ub’antajik b’aqilal',
    '🧚🏿‍♂' => 'achi hada: q’eq ub’antajik b’aqilal',
    '🧚🏻‍♀' => 'ixoq hada: saq ub’antajik b’aqilal',
    '🧚🏼‍♀' => 'ixoq hada: retal saq ub’antajik b’aqilal',
    '🧚🏽‍♀' => 'ixoq hada: retal ub’antajik b’aqilal',
    '🧚🏾‍♀' => 'ixoq hada: retal-q’eq ub’antajik b’aqilal',
    '🧚🏿‍♀' => 'ixoq hada: q’eq ub’antajik b’aqilal',
    '🧛🏻‍♂' => 'achi b’tijol kik’: saq ub’antajik b’aqilal',
    '🧛🏼‍♂' => 'achi b’tijol kik’: retal saq ub’antajik b’aqilal',
    '🧛🏽‍♂' => 'achi b’tijol kik’: retal ub’antajik b’aqilal',
    '🧛🏾‍♂' => 'achi b’tijol kik’: retal-q’eq ub’antajik b’aqilal',
    '🧛🏿‍♂' => 'achi b’tijol kik’: q’eq ub’antajik b’aqilal',
    '🧛🏻‍♀' => 'ixoq b’atijol kik’: saq ub’antajik b’aqilal',
    '🧛🏼‍♀' => 'ixoq b’atijol kik’: retal saq ub’antajik b’aqilal',
    '🧛🏽‍♀' => 'ixoq b’atijol kik’: retal ub’antajik b’aqilal',
    '🧛🏾‍♀' => 'ixoq b’atijol kik’: retal-q’eq ub’antajik b’aqilal',
    '🧛🏿‍♀' => 'ixoq b’atijol kik’: q’eq ub’antajik b’aqilal',
    '🧜🏻‍♂' => 'karixoq: saq ub’antajik b’aqilal',
    '🧜🏼‍♂' => 'karixoq: retal saq ub’antajik b’aqilal',
    '🧜🏽‍♂' => 'karixoq: retal ub’antajik b’aqilal',
    '🧜🏾‍♂' => 'karixoq: retal-q’eq ub’antajik b’aqilal',
    '🧜🏿‍♂' => 'karixoq: q’eq ub’antajik b’aqilal',
    '🧜🏻‍♀' => 'mekar: saq ub’antajik b’aqilal',
    '🧜🏼‍♀' => 'mekar: retal saq ub’antajik b’aqilal',
    '🧜🏽‍♀' => 'mekar: retal ub’antajik b’aqilal',
    '🧜🏾‍♀' => 'mekar: retal-q’eq ub’antajik b’aqilal',
    '🧜🏿‍♀' => 'mekar: q’eq ub’antajik b’aqilal',
    '🧝🏻‍♂' => 'achi jalwach: saq ub’antajik b’aqilal',
    '🧝🏼‍♂' => 'achi jalwach: retal saq ub’antajik b’aqilal',
    '🧝🏽‍♂' => 'achi jalwach: retal ub’antajik b’aqilal',
    '🧝🏾‍♂' => 'achi jalwach: retal-q’eq ub’antajik b’aqilal',
    '🧝🏿‍♂' => 'achi jalwach: q’eq ub’antajik b’aqilal',
    '🧝🏻‍♀' => 'ixoq jalwach: saq ub’antajik b’aqilal',
    '🧝🏼‍♀' => 'ixoq jalwach: retal saq ub’antajik b’aqilal',
    '🧝🏽‍♀' => 'ixoq jalwach: retal ub’antajik b’aqilal',
    '🧝🏾‍♀' => 'ixoq jalwach: retal-q’eq ub’antajik b’aqilal',
    '🧝🏿‍♀' => 'ixoq jalwach: q’eq ub’antajik b’aqilal',
    '💆🏻‍♂' => 'achi ktajin kji’ik: saq ub’antajik b’aqilal',
    '💆🏼‍♂' => 'achi ktajin kji’ik: retal saq ub’antajik b’aqilal',
    '💆🏽‍♂' => 'achi ktajin kji’ik: retal ub’antajik b’aqilal',
    '💆🏾‍♂' => 'achi ktajin kji’ik: retal-q’eq ub’antajik b’aqilal',
    '💆🏿‍♂' => 'achi ktajin kji’ik: q’eq ub’antajik b’aqilal',
    '💆🏻‍♀' => 'ixoq ktajin kji’ik: saq ub’antajik b’aqilal',
    '💆🏼‍♀' => 'ixoq ktajin kji’ik: retal saq ub’antajik b’aqilal',
    '💆🏽‍♀' => 'ixoq ktajin kji’ik: retal ub’antajik b’aqilal',
    '💆🏾‍♀' => 'ixoq ktajin kji’ik: retal-q’eq ub’antajik b’aqilal',
    '💆🏿‍♀' => 'ixoq ktajin kji’ik: q’eq ub’antajik b’aqilal',
    '💇🏻‍♂' => 'achi ktajin kramix uwi’: saq ub’antajik b’aqilal',
    '💇🏼‍♂' => 'achi ktajin kramix uwi’: retal saq ub’antajik b’aqilal',
    '💇🏽‍♂' => 'achi ktajin kramix uwi’: retal ub’antajik b’aqilal',
    '💇🏾‍♂' => 'achi ktajin kramix uwi’: retal-q’eq ub’antajik b’aqilal',
    '💇🏿‍♂' => 'achi ktajin kramix uwi’: q’eq ub’antajik b’aqilal',
    '💇🏻‍♀' => 'ixoq ktajin kramix uwi’: saq ub’antajik b’aqilal',
    '💇🏼‍♀' => 'ixoq ktajin kramix uwi’: retal saq ub’antajik b’aqilal',
    '💇🏽‍♀' => 'ixoq ktajin kramix uwi’: retal ub’antajik b’aqilal',
    '💇🏾‍♀' => 'ixoq ktajin kramix uwi’: retal-q’eq ub’antajik b’aqilal',
    '💇🏿‍♀' => 'ixoq ktajin kramix uwi’: q’eq ub’antajik b’aqilal',
    '🚶🏻‍♂' => 'achi ktajin kb’inik: saq ub’antajik b’aqilal',
    '🚶🏼‍♂' => 'achi ktajin kb’inik: retal saq ub’antajik b’aqilal',
    '🚶🏽‍♂' => 'achi ktajin kb’inik: retal ub’antajik b’aqilal',
    '🚶🏾‍♂' => 'achi ktajin kb’inik: retal-q’eq ub’antajik b’aqilal',
    '🚶🏿‍♂' => 'achi ktajin kb’inik: q’eq ub’antajik b’aqilal',
    '🚶🏻‍♀' => 'ixoq ktajin kb’inik: saq ub’antajik b’aqilal',
    '🚶🏼‍♀' => 'ixoq ktajin kb’inik: retal saq ub’antajik b’aqilal',
    '🚶🏽‍♀' => 'ixoq ktajin kb’inik: retal ub’antajik b’aqilal',
    '🚶🏾‍♀' => 'ixoq ktajin kb’inik: retal-q’eq ub’antajik b’aqilal',
    '🚶🏿‍♀' => 'ixoq ktajin kb’inik: q’eq ub’antajik b’aqilal',
    '🏃🏻‍♂' => 'achi ktajin kutij anim: saq ub’antajik b’aqilal',
    '🏃🏼‍♂' => 'achi ktajin kutij anim: retal saq ub’antajik b’aqilal',
    '🏃🏽‍♂' => 'achi ktajin kutij anim: retal ub’antajik b’aqilal',
    '🏃🏾‍♂' => 'achi ktajin kutij anim: retal-q’eq ub’antajik b’aqilal',
    '🏃🏿‍♂' => 'achi ktajin kutij anim: q’eq ub’antajik b’aqilal',
    '🏃🏻‍♀' => 'ixoq ktajin kutij anin: saq ub’antajik b’aqilal',
    '🏃🏼‍♀' => 'ixoq ktajin kutij anin: retal saq ub’antajik b’aqilal',
    '🏃🏽‍♀' => 'ixoq ktajin kutij anin: retal ub’antajik b’aqilal',
    '🏃🏾‍♀' => 'ixoq ktajin kutij anin: retal-q’eq ub’antajik b’aqilal',
    '🏃🏿‍♀' => 'ixoq ktajin kutij anin: q’eq ub’antajik b’aqilal',
    '👯🏻‍♀' => 'ixoq ruk’ uxikin imul pa nimaq’ij: saq ub’antajik b’aqilal',
    '👯🏼‍♀' => 'ixoq ruk’ uxikin imul pa nimaq’ij: retal saq ub’antajik b’aqilal',
    '👯🏽‍♀' => 'ixoq ruk’ uxikin imul pa nimaq’ij: retal ub’antajik b’aqilal',
    '👯🏾‍♀' => 'ixoq ruk’ uxikin imul pa nimaq’ij: retal-q’eq ub’antajik b’aqilal',
    '👯🏿‍♀' => 'ixoq ruk’ uxikin imul pa nimaq’ij: q’eq ub’antajik b’aqilal',
    '👯🏻‍♂' => 'achi ruk’ uxikin imul pa nimaq’ij: saq ub’antajik b’aqilal',
    '👯🏼‍♂' => 'achi ruk’ uxikin imul pa nimaq’ij: retal saq ub’antajik b’aqilal',
    '👯🏽‍♂' => 'achi ruk’ uxikin imul pa nimaq’ij: retal ub’antajik b’aqilal',
    '👯🏾‍♂' => 'achi ruk’ uxikin imul pa nimaq’ij: retal-q’eq ub’antajik b’aqilal',
    '👯🏿‍♂' => 'achi ruk’ uxikin imul pa nimaq’ij: q’eq ub’antajik b’aqilal',
    '🧖🏻‍♂' => 'achi pa uxlab’ upaja: saq ub’antajik b’aqilal',
    '🧖🏼‍♂' => 'achi pa uxlab’ upaja: retal saq ub’antajik b’aqilal',
    '🧖🏽‍♂' => 'achi pa uxlab’ upaja: retal ub’antajik b’aqilal',
    '🧖🏾‍♂' => 'achi pa uxlab’ upaja: retal-q’eq ub’antajik b’aqilal',
    '🧖🏿‍♂' => 'achi pa uxlab’ upaja: q’eq ub’antajik b’aqilal',
    '🧖🏻‍♀' => 'ixoq pa uxlab’ upaja: saq ub’antajik b’aqilal',
    '🧖🏼‍♀' => 'ixoq pa uxlab’ upaja: retal saq ub’antajik b’aqilal',
    '🧖🏽‍♀' => 'ixoq pa uxlab’ upaja: retal ub’antajik b’aqilal',
    '🧖🏾‍♀' => 'ixoq pa uxlab’ upaja: retal-q’eq ub’antajik b’aqilal',
    '🧖🏿‍♀' => 'ixoq pa uxlab’ upaja: q’eq ub’antajik b’aqilal',
    '🧗🏻‍♂' => 'achi ktajin kpaqi’k: saq ub’antajik b’aqilal',
    '🧗🏼‍♂' => 'achi ktajin kpaqi’k: retal saq ub’antajik b’aqilal',
    '🧗🏽‍♂' => 'achi ktajin kpaqi’k: retal ub’antajik b’aqilal',
    '🧗🏾‍♂' => 'achi ktajin kpaqi’k: retal-q’eq ub’antajik b’aqilal',
    '🧗🏿‍♂' => 'achi ktajin kpaqi’k: q’eq ub’antajik b’aqilal',
    '🧗🏻‍♀' => 'ixoq ktajin kpaqi’k: saq ub’antajik b’aqilal',
    '🧗🏼‍♀' => 'ixoq ktajin kpaqi’k: retal saq ub’antajik b’aqilal',
    '🧗🏽‍♀' => 'ixoq ktajin kpaqi’k: retal ub’antajik b’aqilal',
    '🧗🏾‍♀' => 'ixoq ktajin kpaqi’k: retal-q’eq ub’antajik b’aqilal',
    '🧗🏿‍♀' => 'ixoq ktajin kpaqi’k: q’eq ub’antajik b’aqilal',
    '🏌🏻‍♂' => 'achi ktajin kretz’ab’ej yopotz’: saq ub’antajik b’aqilal',
    '🏌🏼‍♂' => 'achi ktajin kretz’ab’ej yopotz’: retal saq ub’antajik b’aqilal',
    '🏌🏽‍♂' => 'achi ktajin kretz’ab’ej yopotz’: retal ub’antajik b’aqilal',
    '🏌🏾‍♂' => 'achi ktajin kretz’ab’ej yopotz’: retal-q’eq ub’antajik b’aqilal',
    '🏌🏿‍♂' => 'achi ktajin kretz’ab’ej yopotz’: q’eq ub’antajik b’aqilal',
    '🏌🏻‍♀' => 'ixoq ktajin kretz’ab’ej yopotz’: saq ub’antajik b’aqilal',
    '🏌🏼‍♀' => 'ixoq ktajin kretz’ab’ej yopotz’: retal saq ub’antajik b’aqilal',
    '🏌🏽‍♀' => 'ixoq ktajin kretz’ab’ej yopotz’: retal ub’antajik b’aqilal',
    '🏌🏾‍♀' => 'ixoq ktajin kretz’ab’ej yopotz’: retal-q’eq ub’antajik b’aqilal',
    '🏌🏿‍♀' => 'ixoq ktajin kretz’ab’ej yopotz’: q’eq ub’antajik b’aqilal',
    '🏄🏻‍♂' => 'achi ktanin ketz’an pa ja’: saq ub’antajik b’aqilal',
    '🏄🏼‍♂' => 'achi ktanin ketz’an pa ja’: retal saq ub’antajik b’aqilal',
    '🏄🏽‍♂' => 'achi ktanin ketz’an pa ja’: retal ub’antajik b’aqilal',
    '🏄🏾‍♂' => 'achi ktanin ketz’an pa ja’: retal-q’eq ub’antajik b’aqilal',
    '🏄🏿‍♂' => 'achi ktanin ketz’an pa ja’: q’eq ub’antajik b’aqilal',
    '🏄🏻‍♀' => 'ixoq ktanin ketz’an pa ja’: saq ub’antajik b’aqilal',
    '🏄🏼‍♀' => 'ixoq ktanin ketz’an pa ja’: retal saq ub’antajik b’aqilal',
    '🏄🏽‍♀' => 'ixoq ktanin ketz’an pa ja’: retal ub’antajik b’aqilal',
    '🏄🏾‍♀' => 'ixoq ktanin ketz’an pa ja’: retal-q’eq ub’antajik b’aqilal',
    '🏄🏿‍♀' => 'ixoq ktanin ketz’an pa ja’: q’eq ub’antajik b’aqilal',
    '🚣🏻‍♂' => 'achi ktajin kub’inisaj jukub’: saq ub’antajik b’aqilal',
    '🚣🏼‍♂' => 'achi ktajin kub’inisaj jukub’: retal saq ub’antajik b’aqilal',
    '🚣🏽‍♂' => 'achi ktajin kub’inisaj jukub’: retal ub’antajik b’aqilal',
    '🚣🏾‍♂' => 'achi ktajin kub’inisaj jukub’: retal-q’eq ub’antajik b’aqilal',
    '🚣🏿‍♂' => 'achi ktajin kub’inisaj jukub’: q’eq ub’antajik b’aqilal',
    '🚣🏻‍♀' => 'ixoq ktajin kub’inisaj jukub’: saq ub’antajik b’aqilal',
    '🚣🏼‍♀' => 'ixoq ktajin kub’inisaj jukub’: retal saq ub’antajik b’aqilal',
    '🚣🏽‍♀' => 'ixoq ktajin kub’inisaj jukub’: retal ub’antajik b’aqilal',
    '🚣🏾‍♀' => 'ixoq ktajin kub’inisaj jukub’: retal-q’eq ub’antajik b’aqilal',
    '🚣🏿‍♀' => 'ixoq ktajin kub’inisaj jukub’: q’eq ub’antajik b’aqilal',
    '🏊🏻‍♂' => 'achi katajin kmuxanik: saq ub’antajik b’aqilal',
    '🏊🏼‍♂' => 'achi katajin kmuxanik: retal saq ub’antajik b’aqilal',
    '🏊🏽‍♂' => 'achi katajin kmuxanik: retal ub’antajik b’aqilal',
    '🏊🏾‍♂' => 'achi katajin kmuxanik: retal-q’eq ub’antajik b’aqilal',
    '🏊🏿‍♂' => 'achi katajin kmuxanik: q’eq ub’antajik b’aqilal',
    '🏊🏻‍♀' => 'ixoq katajin kmuxanik: saq ub’antajik b’aqilal',
    '🏊🏼‍♀' => 'ixoq katajin kmuxanik: retal saq ub’antajik b’aqilal',
    '🏊🏽‍♀' => 'ixoq katajin kmuxanik: retal ub’antajik b’aqilal',
    '🏊🏾‍♀' => 'ixoq katajin kmuxanik: retal-q’eq ub’antajik b’aqilal',
    '🏊🏿‍♀' => 'ixoq katajin kmuxanik: q’eq ub’antajik b’aqilal',
    '⛹🏻‍♂' => 'achi ktajin kupixkansaj potz’: saq ub’antajik b’aqilal',
    '⛹🏼‍♂' => 'achi ktajin kupixkansaj potz’: retal saq ub’antajik b’aqilal',
    '⛹🏽‍♂' => 'achi ktajin kupixkansaj potz’: retal ub’antajik b’aqilal',
    '⛹🏾‍♂' => 'achi ktajin kupixkansaj potz’: retal-q’eq ub’antajik b’aqilal',
    '⛹🏿‍♂' => 'achi ktajin kupixkansaj potz’: q’eq ub’antajik b’aqilal',
    '⛹🏻‍♀' => 'ixoq ktajin kupixkansaj potz’: saq ub’antajik b’aqilal',
    '⛹🏼‍♀' => 'ixoq ktajin kupixkansaj potz’: retal saq ub’antajik b’aqilal',
    '⛹🏽‍♀' => 'ixoq ktajin kupixkansaj potz’: retal ub’antajik b’aqilal',
    '⛹🏾‍♀' => 'ixoq ktajin kupixkansaj potz’: retal-q’eq ub’antajik b’aqilal',
    '⛹🏿‍♀' => 'ixoq ktajin kupixkansaj potz’: q’eq ub’antajik b’aqilal',
    '🏋🏻‍♂' => 'achi kupaqab’isaj taq a’lal: saq ub’antajik b’aqilal',
    '🏋🏼‍♂' => 'achi kupaqab’isaj taq a’lal: retal saq ub’antajik b’aqilal',
    '🏋🏽‍♂' => 'achi kupaqab’isaj taq a’lal: retal ub’antajik b’aqilal',
    '🏋🏾‍♂' => 'achi kupaqab’isaj taq a’lal: retal-q’eq ub’antajik b’aqilal',
    '🏋🏿‍♂' => 'achi kupaqab’isaj taq a’lal: q’eq ub’antajik b’aqilal',
    '🏋🏻‍♀' => 'ixoq kupaqab’isaj taq a’lal: saq ub’antajik b’aqilal',
    '🏋🏼‍♀' => 'ixoq kupaqab’isaj taq a’lal: retal saq ub’antajik b’aqilal',
    '🏋🏽‍♀' => 'ixoq kupaqab’isaj taq a’lal: retal ub’antajik b’aqilal',
    '🏋🏾‍♀' => 'ixoq kupaqab’isaj taq a’lal: retal-q’eq ub’antajik b’aqilal',
    '🏋🏿‍♀' => 'ixoq kupaqab’isaj taq a’lal: q’eq ub’antajik b’aqilal',
    '🚴🏻‍♂' => 'achi b’enaq chi rij kej key ch’ich’: saq ub’antajik b’aqilal',
    '🚴🏼‍♂' => 'achi b’enaq chi rij kej key ch’ich’: retal saq ub’antajik b’aqilal',
    '🚴🏽‍♂' => 'achi b’enaq chi rij kej key ch’ich’: retal ub’antajik b’aqilal',
    '🚴🏾‍♂' => 'achi b’enaq chi rij kej key ch’ich’: retal-q’eq ub’antajik b’aqilal',
    '🚴🏿‍♂' => 'achi b’enaq chi rij kej key ch’ich’: q’eq ub’antajik b’aqilal',
    '🚴🏻‍♀' => 'ixoq b’enaq chi rij kej key ch’ich’: saq ub’antajik b’aqilal',
    '🚴🏼‍♀' => 'ixoq b’enaq chi rij kej key ch’ich’: retal saq ub’antajik b’aqilal',
    '🚴🏽‍♀' => 'ixoq b’enaq chi rij kej key ch’ich’: retal ub’antajik b’aqilal',
    '🚴🏾‍♀' => 'ixoq b’enaq chi rij kej key ch’ich’: retal-q’eq ub’antajik b’aqilal',
    '🚴🏿‍♀' => 'ixoq b’enaq chi rij kej key ch’ich’: q’eq ub’antajik b’aqilal',
    '🚵🏻‍♂' => 'achi b’enaq chi rij key ch’ich’ pa juyub’: saq ub’antajik b’aqilal',
    '🚵🏼‍♂' => 'achi b’enaq chi rij key ch’ich’ pa juyub’: retal saq ub’antajik b’aqilal',
    '🚵🏽‍♂' => 'achi b’enaq chi rij key ch’ich’ pa juyub’: retal ub’antajik b’aqilal',
    '🚵🏾‍♂' => 'achi b’enaq chi rij key ch’ich’ pa juyub’: retal-q’eq ub’antajik b’aqilal',
    '🚵🏿‍♂' => 'achi b’enaq chi rij key ch’ich’ pa juyub’: q’eq ub’antajik b’aqilal',
    '🚵🏻‍♀' => 'ixoq b’enaq chi rij key ch’ich’ pa juyub’: saq ub’antajik b’aqilal',
    '🚵🏼‍♀' => 'ixoq b’enaq chi rij key ch’ich’ pa juyub’: retal saq ub’antajik b’aqilal',
    '🚵🏽‍♀' => 'ixoq b’enaq chi rij key ch’ich’ pa juyub’: retal ub’antajik b’aqilal',
    '🚵🏾‍♀' => 'ixoq b’enaq chi rij key ch’ich’ pa juyub’: retal-q’eq ub’antajik b’aqilal',
    '🚵🏿‍♀' => 'ixoq b’enaq chi rij key ch’ich’ pa juyub’: q’eq ub’antajik b’aqilal',
    '🤸🏻‍♂' => 'achi pa setch’ich’: saq ub’antajik b’aqilal',
    '🤸🏼‍♂' => 'achi pa setch’ich’: retal saq ub’antajik b’aqilal',
    '🤸🏽‍♂' => 'achi pa setch’ich’: retal ub’antajik b’aqilal',
    '🤸🏾‍♂' => 'achi pa setch’ich’: retal-q’eq ub’antajik b’aqilal',
    '🤸🏿‍♂' => 'achi pa setch’ich’: q’eq ub’antajik b’aqilal',
    '🤸🏻‍♀' => 'ixoq pa setch’ich’: saq ub’antajik b’aqilal',
    '🤸🏼‍♀' => 'ixoq pa setch’ich’: retal saq ub’antajik b’aqilal',
    '🤸🏽‍♀' => 'ixoq pa setch’ich’: retal ub’antajik b’aqilal',
    '🤸🏾‍♀' => 'ixoq pa setch’ich’: retal-q’eq ub’antajik b’aqilal',
    '🤸🏿‍♀' => 'ixoq pa setch’ich’: q’eq ub’antajik b’aqilal',
    '🤼🏻‍♀' => 'ixoq ktajin kch’ojinik: saq ub’antajik b’aqilal',
    '🤼🏼‍♀' => 'ixoq ktajin kch’ojinik: retal saq ub’antajik b’aqilal',
    '🤼🏽‍♀' => 'ixoq ktajin kch’ojinik: retal ub’antajik b’aqilal',
    '🤼🏾‍♀' => 'ixoq ktajin kch’ojinik: retal-q’eq ub’antajik b’aqilal',
    '🤼🏿‍♀' => 'ixoq ktajin kch’ojinik: q’eq ub’antajik b’aqilal',
    '🤼🏻‍♂' => 'achi ktajin kch’ojinik: saq ub’antajik b’aqilal',
    '🤼🏼‍♂' => 'achi ktajin kch’ojinik: retal saq ub’antajik b’aqilal',
    '🤼🏽‍♂' => 'achi ktajin kch’ojinik: retal ub’antajik b’aqilal',
    '🤼🏾‍♂' => 'achi ktajin kch’ojinik: retal-q’eq ub’antajik b’aqilal',
    '🤼🏿‍♂' => 'achi ktajin kch’ojinik: q’eq ub’antajik b’aqilal',
    '🤽🏻‍♂' => 'achi ktajin kretz’ab’el potz’ pa ja’: saq ub’antajik b’aqilal',
    '🤽🏼‍♂' => 'achi ktajin kretz’ab’el potz’ pa ja’: retal saq ub’antajik b’aqilal',
    '🤽🏽‍♂' => 'achi ktajin kretz’ab’el potz’ pa ja’: retal ub’antajik b’aqilal',
    '🤽🏾‍♂' => 'achi ktajin kretz’ab’el potz’ pa ja’: retal-q’eq ub’antajik b’aqilal',
    '🤽🏿‍♂' => 'achi ktajin kretz’ab’el potz’ pa ja’: q’eq ub’antajik b’aqilal',
    '🤽🏻‍♀' => 'ixoq ktajin kretz’ab’ej potz’ pa ja’: saq ub’antajik b’aqilal',
    '🤽🏼‍♀' => 'ixoq ktajin kretz’ab’ej potz’ pa ja’: retal saq ub’antajik b’aqilal',
    '🤽🏽‍♀' => 'ixoq ktajin kretz’ab’ej potz’ pa ja’: retal ub’antajik b’aqilal',
    '🤽🏾‍♀' => 'ixoq ktajin kretz’ab’ej potz’ pa ja’: retal-q’eq ub’antajik b’aqilal',
    '🤽🏿‍♀' => 'ixoq ktajin kretz’ab’ej potz’ pa ja’: q’eq ub’antajik b’aqilal',
    '🤾🏻‍♂' => 'achi ktajin kretz’ab’ej potz’ chi q’ab’aj: saq ub’antajik b’aqilal',
    '🤾🏼‍♂' => 'achi ktajin kretz’ab’ej potz’ chi q’ab’aj: retal saq ub’antajik b’aqilal',
    '🤾🏽‍♂' => 'achi ktajin kretz’ab’ej potz’ chi q’ab’aj: retal ub’antajik b’aqilal',
    '🤾🏾‍♂' => 'achi ktajin kretz’ab’ej potz’ chi q’ab’aj: retal-q’eq ub’antajik b’aqilal',
    '🤾🏿‍♂' => 'achi ktajin kretz’ab’ej potz’ chi q’ab’aj: q’eq ub’antajik b’aqilal',
    '🤾🏻‍♀' => 'ixoq ktajin kretz’ab’ej potz’ chi q’ab’aj: saq ub’antajik b’aqilal',
    '🤾🏼‍♀' => 'ixoq ktajin kretz’ab’ej potz’ chi q’ab’aj: retal saq ub’antajik b’aqilal',
    '🤾🏽‍♀' => 'ixoq ktajin kretz’ab’ej potz’ chi q’ab’aj: retal ub’antajik b’aqilal',
    '🤾🏾‍♀' => 'ixoq ktajin kretz’ab’ej potz’ chi q’ab’aj: retal-q’eq ub’antajik b’aqilal',
    '🤾🏿‍♀' => 'ixoq ktajin kretz’ab’ej potz’ chi q’ab’aj: q’eq ub’antajik b’aqilal',
    '🤹🏻‍♂' => 'achi kub’an tzaqb’al k’u’x: saq ub’antajik b’aqilal',
    '🤹🏼‍♂' => 'achi kub’an tzaqb’al k’u’x: retal saq ub’antajik b’aqilal',
    '🤹🏽‍♂' => 'achi kub’an tzaqb’al k’u’x: retal ub’antajik b’aqilal',
    '🤹🏾‍♂' => 'achi kub’an tzaqb’al k’u’x: retal-q’eq ub’antajik b’aqilal',
    '🤹🏿‍♂' => 'achi kub’an tzaqb’al k’u’x: q’eq ub’antajik b’aqilal',
    '🤹🏻‍♀' => 'ixoq kub’an tzaqb’al k’u’x: saq ub’antajik b’aqilal',
    '🤹🏼‍♀' => 'ixoq kub’an tzaqb’al k’u’x: retal saq ub’antajik b’aqilal',
    '🤹🏽‍♀' => 'ixoq kub’an tzaqb’al k’u’x: retal ub’antajik b’aqilal',
    '🤹🏾‍♀' => 'ixoq kub’an tzaqb’al k’u’x: retal-q’eq ub’antajik b’aqilal',
    '🤹🏿‍♀' => 'ixoq kub’an tzaqb’al k’u’x: q’eq ub’antajik b’aqilal',
    '🧘🏻‍♂' => 'achi ukrusim raqan: saq ub’antajik b’aqilal',
    '🧘🏼‍♂' => 'achi ukrusim raqan: retal saq ub’antajik b’aqilal',
    '🧘🏽‍♂' => 'achi ukrusim raqan: retal ub’antajik b’aqilal',
    '🧘🏾‍♂' => 'achi ukrusim raqan: retal-q’eq ub’antajik b’aqilal',
    '🧘🏿‍♂' => 'achi ukrusim raqan: q’eq ub’antajik b’aqilal',
    '🧘🏻‍♀' => 'ixoq ukrusim raqan: saq ub’antajik b’aqilal',
    '🧘🏼‍♀' => 'ixoq ukrusim raqan: retal saq ub’antajik b’aqilal',
    '🧘🏽‍♀' => 'ixoq ukrusim raqan: retal ub’antajik b’aqilal',
    '🧘🏾‍♀' => 'ixoq ukrusim raqan: retal-q’eq ub’antajik b’aqilal',
    '🧘🏿‍♀' => 'ixoq ukrusim raqan: q’eq ub’antajik b’aqilal',
    '👨‍👦' => 'Ajupaja: Achi, Ala',
    '👨‍👧' => 'Ajupaja: Achi, Ali',
    '👩‍👦' => 'Ajupaja: Ixoq, Ala',
    '👩‍👧' => 'Ajupaja: Ixoq, Ali',
    '👁‍🗨' => 'b’aq’wachaj pa pupu tzijonem',
    '👱‍♂' => 'aci q’an uwi’',
    '👱‍♀' => 'ixoq q’an uwi’',
    '🙍‍♂' => 'achi b’isorinaq',
    '🙍‍♀' => 'ixoq b’isorinaq',
    '🙎‍♂' => 'achi xuq’ulik',
    '🙎‍♀' => 'ixoq xuq’ulik',
    '🙅‍♂' => 'achi ktajin kuk’ut JA’I’',
    '🙅‍♀' => 'ixoq uk’utum JA’I’',
    '🙆‍♂' => 'achi ktajin kuk’ut JE’',
    '🙆‍♀' => 'ixoq ktajin kuk’ut JE’',
    '💁‍♂' => 'achi upaqab’isam uq’ab’',
    '💁‍♀' => 'ixoq upaqab’isam uq’ab’',
    '🙋‍♂' => 'achi uyakom uq’ab’',
    '🙋‍♀' => 'ixoq uyakom uq’ab’',
    '🙇‍♂' => 'achi ktajin kuk’ut k’ixb’alil',
    '🙇‍♀' => 'Ixoq ktajin kuk’ut k’ixb’alil',
    '🤦‍♂' => 'achi ktajin kuya’ uq’ab’ chi upalaj',
    '🤦‍♀' => 'ixoq ktajin kuya’ uq’ab’ chi upalaj',
    '🤷‍♂' => 'achi man q’alaj ta chi uwach',
    '🤷‍♀' => 'ixoq man q’alaj ta chi uwach',
    '👨‍⚕' => 'achi ajchaj chi rij utzwachil',
    '👩‍⚕' => 'ixoq chakunel rech utzwachil',
    '👨‍🎓' => 'achi tijoxel',
    '👩‍🎓' => 'ixoq tijoxel',
    '👨‍🏫' => 'achi ajtij',
    '👩‍🏫' => 'ixoq ajtij',
    '👨‍⚖' => 'achi q’atol tzij',
    '👩‍⚖' => 'ixoq k’atb’al tzij',
    '👨‍🌾' => 'achi ajtikon',
    '👩‍🌾' => 'ixoq tikonel',
    '👨‍🍳' => 'achi b’anal wa',
    '👩‍🍳' => 'ixoq b’anal wa',
    '👨‍🔧' => 'aj jaqoj ch’ich’',
    '👩‍🔧' => 'ixoq jaqol ch’ich’',
    '👨‍🏭' => 'achi ajachak pa ja b’anb’al',
    '👩‍🏭' => 'ixoq ajchak pa ja b’anb’al',
    '👨‍💼' => 'achi ajchak pa ja chakub’al',
    '👩‍💼' => 'ixoq chakunel pa ja chak’ub’al',
    '👨‍🔬' => 'ach aj q’inom eta’mab’al',
    '👩‍🔬' => 'ixoq q’inom reta’mab’al',
    '👨‍💻' => 'achi aj k’ak’ eta’mab’al',
    '👩‍💻' => 'ixoq aj k’ak’ eta’mab’al',
    '👨‍🎤' => 'achi b’ixanel',
    '👩‍🎤' => 'ixoq b’ixanel',
    '👨‍🎨' => 'achi ajje’lal chak',
    '👩‍🎨' => 'ixoq ajje’lal chak',
    '👨‍✈' => 'achi binsaj ch’ich’',
    '👩‍✈' => 'ixoq b’inxik’ich’ich’',
    '👨‍🚀' => 'achi nik’ol kaj',
    '👩‍🚀' => 'ixoq nik’ol kaj',
    '👨‍🚒' => 'achi chupul q’aq’',
    '👩‍🚒' => 'ixoq chupul q’a’q',
    '👮‍♂' => 'achi q’atb’altzij chajinel',
    '👮‍♀' => 'ixoq q’atb’al tzij chajinel',
    '🕵‍♂' => 'achi solonel uxe’',
    '🕵‍♀' => 'ixoq solonel uxe’',
    '💂‍♂' => 'achi chajinel',
    '💂‍♀' => 'ixoq chajinel',
    '👷‍♂' => 'achi chakunel pa tz’aqb’al',
    '👷‍♀' => 'ixoq chakunel pa tz’aqb’al',
    '👳‍♂' => 'achi ukojom pisb’al jolomaj',
    '👳‍♀' => 'ixoq ukojom pisb’al jolomaj',
    '🧙‍♂' => 'achi mayib’al',
    '🧙‍♀' => 'ixoq mayinel',
    '🧚‍♂' => 'achi hada',
    '🧚‍♀' => 'ixoq hada',
    '🧛‍♂' => 'achi b’tijol kik’',
    '🧛‍♀' => 'ixoq b’atijol kik’',
    '🧜‍♂' => 'karixoq',
    '🧜‍♀' => 'mekar',
    '🧝‍♂' => 'achi jalwach',
    '🧝‍♀' => 'ixoq jalwach',
    '🧞‍♂' => 'achi nireta’mab’al',
    '🧞‍♀' => 'ixoq nireta’mab’al',
    '🧟‍♂' => 'achi k’askaminaq',
    '🧟‍♀' => 'ixoq b’inel kaminaq',
    '💆‍♂' => 'achi ktajin kji’ik',
    '💆‍♀' => 'ixoq ktajin kji’ik',
    '💇‍♂' => 'achi ktajin kramix uwi’',
    '💇‍♀' => 'ixoq ktajin kramix uwi’',
    '🚶‍♂' => 'achi ktajin kb’inik',
    '🚶‍♀' => 'ixoq ktajin kb’inik',
    '🏃‍♂' => 'achi ktajin kutij anim',
    '🏃‍♀' => 'ixoq ktajin kutij anin',
    '👯‍♂' => 'achi ruk’ uxikin imul pa nimaq’ij',
    '👯‍♀' => 'ixoq ruk’ uxikin imul pa nimaq’ij',
    '🧖‍♂' => 'achi pa uxlab’ upaja',
    '🧖‍♀' => 'ixoq pa uxlab’ upaja',
    '🧗‍♂' => 'achi ktajin kpaqi’k',
    '🧗‍♀' => 'ixoq ktajin kpaqi’k',
    '🏌‍♂' => 'achi ktajin kretz’ab’ej yopotz’',
    '🏌‍♀' => 'ixoq ktajin kretz’ab’ej yopotz’',
    '🏄‍♂' => 'achi ktanin ketz’an pa ja’',
    '🏄‍♀' => 'ixoq ktanin ketz’an pa ja’',
    '🚣‍♂' => 'achi ktajin kub’inisaj jukub’',
    '🚣‍♀' => 'ixoq ktajin kub’inisaj jukub’',
    '🏊‍♂' => 'achi katajin kmuxanik',
    '🏊‍♀' => 'ixoq katajin kmuxanik',
    '⛹‍♂' => 'achi ktajin kupixkansaj potz’',
    '⛹‍♀' => 'ixoq ktajin kupixkansaj potz’',
    '🏋‍♂' => 'achi kupaqab’isaj taq a’lal',
    '🏋‍♀' => 'ixoq kupaqab’isaj taq a’lal',
    '🚴‍♂' => 'achi b’enaq chi rij kej key ch’ich’',
    '🚴‍♀' => 'ixoq b’enaq chi rij kej key ch’ich’',
    '🚵‍♂' => 'achi b’enaq chi rij key ch’ich’ pa juyub’',
    '🚵‍♀' => 'ixoq b’enaq chi rij key ch’ich’ pa juyub’',
    '🤸‍♂' => 'achi pa setch’ich’',
    '🤸‍♀' => 'ixoq pa setch’ich’',
    '🤼‍♂' => 'achi ktajin kch’ojinik',
    '🤼‍♀' => 'ixoq ktajin kch’ojinik',
    '🤽‍♂' => 'achi ktajin kretz’ab’el potz’ pa ja’',
    '🤽‍♀' => 'ixoq ktajin kretz’ab’ej potz’ pa ja’',
    '🤾‍♂' => 'achi ktajin kretz’ab’ej potz’ chi q’ab’aj',
    '🤾‍♀' => 'ixoq ktajin kretz’ab’ej potz’ chi q’ab’aj',
    '🤹‍♂' => 'achi kub’an tzaqb’al k’u’x',
    '🤹‍♀' => 'ixoq kub’an tzaqb’al k’u’x',
    '🧘‍♂' => 'achi ukrusim raqan',
    '🧘‍♀' => 'ixoq ukrusim raqan',
    '🏳‍🌈' => 'retamaq’ xukuq’ab’',
    '👋🏻' => 'Upam q’ab’aj: saq ub’antajik b’aqilal',
    '👋🏼' => 'Upam q’ab’aj: retal saq ub’antajik b’aqilal',
    '👋🏽' => 'Upam q’ab’aj: retal ub’antajik b’aqilal',
    '👋🏾' => 'Upam q’ab’aj: retal-q’eq ub’antajik b’aqilal',
    '👋🏿' => 'Upam q’ab’aj: q’eq ub’antajik b’aqilal',
    '🤚🏻' => 'Yakom upam q’ab’aj: saq ub’antajik b’aqilal',
    '🤚🏼' => 'Yakom upam q’ab’aj: retal saq ub’antajik b’aqilal',
    '🤚🏽' => 'Yakom upam q’ab’aj: retal ub’antajik b’aqilal',
    '🤚🏾' => 'Yakom upam q’ab’aj: retal-q’eq ub’antajik b’aqilal',
    '🤚🏿' => 'Yakom upam q’ab’aj: q’eq ub’antajik b’aqilal',
    '🖐🏻' => 'yakom q’ab’aj ruk’ lik’ital taq uwi’ q’ab’al: saq ub’antajik b’aqilal',
    '🖐🏼' => 'yakom q’ab’aj ruk’ lik’ital taq uwi’ q’ab’al: retal saq ub’antajik b’aqilal',
    '🖐🏽' => 'yakom q’ab’aj ruk’ lik’ital taq uwi’ q’ab’al: retal ub’antajik b’aqilal',
    '🖐🏾' => 'yakom q’ab’aj ruk’ lik’ital taq uwi’ q’ab’al: retal-q’eq ub’antajik b’aqilal',
    '🖐🏿' => 'yakom q’ab’aj ruk’ lik’ital taq uwi’ q’ab’al: q’eq ub’antajik b’aqilal',
    '✋🏻' => 'Yakom q’ab’aj: saq ub’antajik b’aqilal',
    '✋🏼' => 'Yakom q’ab’aj: retal saq ub’antajik b’aqilal',
    '✋🏽' => 'Yakom q’ab’aj: retal ub’antajik b’aqilal',
    '✋🏾' => 'Yakom q’ab’aj: retal-q’eq ub’antajik b’aqilal',
    '✋🏿' => 'Yakom q’ab’aj: q’eq ub’antajik b’aqilal',
    '🖖🏻' => 'Rutzil wachaj: saq ub’antajik b’aqilal',
    '🖖🏼' => 'Rutzil wachaj: retal saq ub’antajik b’aqilal',
    '🖖🏽' => 'Rutzil wachaj: retal ub’antajik b’aqilal',
    '🖖🏾' => 'Rutzil wachaj: retal-q’eq ub’antajik b’aqilal',
    '🖖🏿' => 'Rutzil wachaj: q’eq ub’antajik b’aqilal',
    '👌🏻' => 'Uk’amik q’ab’al: saq ub’antajik b’aqilal',
    '👌🏼' => 'Uk’amik q’ab’al: retal saq ub’antajik b’aqilal',
    '👌🏽' => 'Uk’amik q’ab’al: retal ub’antajik b’aqilal',
    '👌🏾' => 'Uk’amik q’ab’al: retal-q’eq ub’antajik b’aqilal',
    '👌🏿' => 'Uk’amik q’ab’al: q’eq ub’antajik b’aqilal',
    '✌🏻' => 'q’ab’aj rech ch’akanem: saq ub’antajik b’aqilal',
    '✌🏼' => 'q’ab’aj rech ch’akanem: retal saq ub’antajik b’aqilal',
    '✌🏽' => 'q’ab’aj rech ch’akanem: retal ub’antajik b’aqilal',
    '✌🏾' => 'q’ab’aj rech ch’akanem: retal-q’eq ub’antajik b’aqilal',
    '✌🏿' => 'q’ab’aj rech ch’akanem: q’eq ub’antajik b’aqilal',
    '🤞🏻' => 'Uwi’ q’ab’aj ukrusim rib’: saq ub’antajik b’aqilal',
    '🤞🏼' => 'Uwi’ q’ab’aj ukrusim rib’: retal saq ub’antajik b’aqilal',
    '🤞🏽' => 'Uwi’ q’ab’aj ukrusim rib’: retal ub’antajik b’aqilal',
    '🤞🏾' => 'Uwi’ q’ab’aj ukrusim rib’: retal-q’eq ub’antajik b’aqilal',
    '🤞🏿' => 'Uwi’ q’ab’aj ukrusim rib’: q’eq ub’antajik b’aqilal',
    '🤟🏻' => 'uk’utik katwaj: saq ub’antajik b’aqilal',
    '🤟🏼' => 'uk’utik katwaj: retal saq ub’antajik b’aqilal',
    '🤟🏽' => 'uk’utik katwaj: retal ub’antajik b’aqilal',
    '🤟🏾' => 'uk’utik katwaj: retal-q’eq ub’antajik b’aqilal',
    '🤟🏿' => 'uk’utik katwaj: q’eq ub’antajik b’aqilal',
    '🤘🏻' => 'Retal uk’a’: saq ub’antajik b’aqilal',
    '🤘🏼' => 'Retal uk’a’: retal saq ub’antajik b’aqilal',
    '🤘🏽' => 'Retal uk’a’: retal ub’antajik b’aqilal',
    '🤘🏾' => 'Retal uk’a’: retal-q’eq ub’antajik b’aqilal',
    '🤘🏿' => 'Retal uk’a’: q’eq ub’antajik b’aqilal',
    '🤙🏻' => 'k’utq’ab’aj Chinasik’ij: saq ub’antajik b’aqilal',
    '🤙🏼' => 'k’utq’ab’aj Chinasik’ij: retal saq ub’antajik b’aqilal',
    '🤙🏽' => 'k’utq’ab’aj Chinasik’ij: retal ub’antajik b’aqilal',
    '🤙🏾' => 'k’utq’ab’aj Chinasik’ij: retal-q’eq ub’antajik b’aqilal',
    '🤙🏿' => 'k’utq’ab’aj Chinasik’ij: q’eq ub’antajik b’aqilal',
    '👈🏻' => 'k’utwiq’ab’ Kuk’ut pa Moxq’ab’: saq ub’antajik b’aqilal',
    '👈🏼' => 'k’utwiq’ab’ Kuk’ut pa Moxq’ab’: retal saq ub’antajik b’aqilal',
    '👈🏽' => 'k’utwiq’ab’ Kuk’ut pa Moxq’ab’: retal ub’antajik b’aqilal',
    '👈🏾' => 'k’utwiq’ab’ Kuk’ut pa Moxq’ab’: retal-q’eq ub’antajik b’aqilal',
    '👈🏿' => 'k’utwiq’ab’ Kuk’ut pa Moxq’ab’: q’eq ub’antajik b’aqilal',
    '👉🏻' => 'k’utwiq’ab’ Kuk’ut pa Wikiq’ab’: saq ub’antajik b’aqilal',
    '👉🏼' => 'k’utwiq’ab’ Kuk’ut pa Wikiq’ab’: retal saq ub’antajik b’aqilal',
    '👉🏽' => 'k’utwiq’ab’ Kuk’ut pa Wikiq’ab’: retal ub’antajik b’aqilal',
    '👉🏾' => 'k’utwiq’ab’ Kuk’ut pa Wikiq’ab’: retal-q’eq ub’antajik b’aqilal',
    '👉🏿' => 'k’utwiq’ab’ Kuk’ut pa Wikiq’ab’: q’eq ub’antajik b’aqilal',
    '👆🏻' => 'k’utwiq’ab’ Kuk’ut pa Uwi’: saq ub’antajik b’aqilal',
    '👆🏼' => 'k’utwiq’ab’ Kuk’ut pa Uwi’: retal saq ub’antajik b’aqilal',
    '👆🏽' => 'k’utwiq’ab’ Kuk’ut pa Uwi’: retal ub’antajik b’aqilal',
    '👆🏾' => 'k’utwiq’ab’ Kuk’ut pa Uwi’: retal-q’eq ub’antajik b’aqilal',
    '👆🏿' => 'k’utwiq’ab’ Kuk’ut pa Uwi’: q’eq ub’antajik b’aqilal',
    '🖕🏻' => 'nik’ajal uwi’ q’ab’al: saq ub’antajik b’aqilal',
    '🖕🏼' => 'nik’ajal uwi’ q’ab’al: retal saq ub’antajik b’aqilal',
    '🖕🏽' => 'nik’ajal uwi’ q’ab’al: retal ub’antajik b’aqilal',
    '🖕🏾' => 'nik’ajal uwi’ q’ab’al: retal-q’eq ub’antajik b’aqilal',
    '🖕🏿' => 'nik’ajal uwi’ q’ab’al: q’eq ub’antajik b’aqilal',
    '👇🏻' => 'k’utwiq’ab’ Kuk’ut chi Uxe’: saq ub’antajik b’aqilal',
    '👇🏼' => 'k’utwiq’ab’ Kuk’ut chi Uxe’: retal saq ub’antajik b’aqilal',
    '👇🏽' => 'k’utwiq’ab’ Kuk’ut chi Uxe’: retal ub’antajik b’aqilal',
    '👇🏾' => 'k’utwiq’ab’ Kuk’ut chi Uxe’: retal-q’eq ub’antajik b’aqilal',
    '👇🏿' => 'k’utwiq’ab’ Kuk’ut chi Uxe’: q’eq ub’antajik b’aqilal',
    '☝🏻' => 'ch’ipel kuk’ut uwi’: saq ub’antajik b’aqilal',
    '☝🏼' => 'ch’ipel kuk’ut uwi’: retal saq ub’antajik b’aqilal',
    '☝🏽' => 'ch’ipel kuk’ut uwi’: retal ub’antajik b’aqilal',
    '☝🏾' => 'ch’ipel kuk’ut uwi’: retal-q’eq ub’antajik b’aqilal',
    '☝🏿' => 'ch’ipel kuk’ut uwi’: q’eq ub’antajik b’aqilal',
    '👍🏻' => 'Uwi q’ab’aj pa uwi’: saq ub’antajik b’aqilal',
    '👍🏼' => 'Uwi q’ab’aj pa uwi’: retal saq ub’antajik b’aqilal',
    '👍🏽' => 'Uwi q’ab’aj pa uwi’: retal ub’antajik b’aqilal',
    '👍🏾' => 'Uwi q’ab’aj pa uwi’: retal-q’eq ub’antajik b’aqilal',
    '👍🏿' => 'Uwi q’ab’aj pa uwi’: q’eq ub’antajik b’aqilal',
    '👎🏻' => 'Uwi q’ab’aj chi uxe’: saq ub’antajik b’aqilal',
    '👎🏼' => 'Uwi q’ab’aj chi uxe’: retal saq ub’antajik b’aqilal',
    '👎🏽' => 'Uwi q’ab’aj chi uxe’: retal ub’antajik b’aqilal',
    '👎🏾' => 'Uwi q’ab’aj chi uxe’: retal-q’eq ub’antajik b’aqilal',
    '👎🏿' => 'Uwi q’ab’aj chi uxe’: q’eq ub’antajik b’aqilal',
    '✊🏻' => 'K’olom q’ab’aj: saq ub’antajik b’aqilal',
    '✊🏼' => 'K’olom q’ab’aj: retal saq ub’antajik b’aqilal',
    '✊🏽' => 'K’olom q’ab’aj: retal ub’antajik b’aqilal',
    '✊🏾' => 'K’olom q’ab’aj: retal-q’eq ub’antajik b’aqilal',
    '✊🏿' => 'K’olom q’ab’aj: q’eq ub’antajik b’aqilal',
    '👊🏻' => 'K’olon q’ab’aj petinaq: saq ub’antajik b’aqilal',
    '👊🏼' => 'K’olon q’ab’aj petinaq: retal saq ub’antajik b’aqilal',
    '👊🏽' => 'K’olon q’ab’aj petinaq: retal ub’antajik b’aqilal',
    '👊🏾' => 'K’olon q’ab’aj petinaq: retal-q’eq ub’antajik b’aqilal',
    '👊🏿' => 'K’olon q’ab’aj petinaq: q’eq ub’antajik b’aqilal',
    '🤛🏻' => 'K’olon q’ab’aj: saq ub’antajik b’aqilal',
    '🤛🏼' => 'K’olon q’ab’aj: retal saq ub’antajik b’aqilal',
    '🤛🏽' => 'K’olon q’ab’aj: retal ub’antajik b’aqilal',
    '🤛🏾' => 'K’olon q’ab’aj: retal-q’eq ub’antajik b’aqilal',
    '🤛🏿' => 'K’olon q’ab’aj: q’eq ub’antajik b’aqilal',
    '🤜🏻' => 'K’olon q’ab’aj rech utzil: saq ub’antajik b’aqilal',
    '🤜🏼' => 'K’olon q’ab’aj rech utzil: retal saq ub’antajik b’aqilal',
    '🤜🏽' => 'K’olon q’ab’aj rech utzil: retal ub’antajik b’aqilal',
    '🤜🏾' => 'K’olon q’ab’aj rech utzil: retal-q’eq ub’antajik b’aqilal',
    '🤜🏿' => 'K’olon q’ab’aj rech utzil: q’eq ub’antajik b’aqilal',
    '👏🏻' => 'Upaq’apaxik upaq’ab’aj: saq ub’antajik b’aqilal',
    '👏🏼' => 'Upaq’apaxik upaq’ab’aj: retal saq ub’antajik b’aqilal',
    '👏🏽' => 'Upaq’apaxik upaq’ab’aj: retal ub’antajik b’aqilal',
    '👏🏾' => 'Upaq’apaxik upaq’ab’aj: retal-q’eq ub’antajik b’aqilal',
    '👏🏿' => 'Upaq’apaxik upaq’ab’aj: q’eq ub’antajik b’aqilal',
    '🙌🏻' => 'Yakom keb’ q’ab’aj: saq ub’antajik b’aqilal',
    '🙌🏼' => 'Yakom keb’ q’ab’aj: retal saq ub’antajik b’aqilal',
    '🙌🏽' => 'Yakom keb’ q’ab’aj: retal ub’antajik b’aqilal',
    '🙌🏾' => 'Yakom keb’ q’ab’aj: retal-q’eq ub’antajik b’aqilal',
    '🙌🏿' => 'Yakom keb’ q’ab’aj: q’eq ub’antajik b’aqilal',
    '👐🏻' => 'Jaqom q’ab’aj: saq ub’antajik b’aqilal',
    '👐🏼' => 'Jaqom q’ab’aj: retal saq ub’antajik b’aqilal',
    '👐🏽' => 'Jaqom q’ab’aj: retal ub’antajik b’aqilal',
    '👐🏾' => 'Jaqom q’ab’aj: retal-q’eq ub’antajik b’aqilal',
    '👐🏿' => 'Jaqom q’ab’aj: q’eq ub’antajik b’aqilal',
    '🤲🏻' => 'utunik q’ab’aj: saq ub’antajik b’aqilal',
    '🤲🏼' => 'utunik q’ab’aj: retal saq ub’antajik b’aqilal',
    '🤲🏽' => 'utunik q’ab’aj: retal ub’antajik b’aqilal',
    '🤲🏾' => 'utunik q’ab’aj: retal-q’eq ub’antajik b’aqilal',
    '🤲🏿' => 'utunik q’ab’aj: q’eq ub’antajik b’aqilal',
    '🤝🏻' => 'Uk’ulaxik Q’ab’aj: saq ub’antajik b’aqilal',
    '🤝🏼' => 'Uk’ulaxik Q’ab’aj: retal saq ub’antajik b’aqilal',
    '🤝🏽' => 'Uk’ulaxik Q’ab’aj: retal ub’antajik b’aqilal',
    '🤝🏾' => 'Uk’ulaxik Q’ab’aj: retal-q’eq ub’antajik b’aqilal',
    '🤝🏿' => 'Uk’ulaxik Q’ab’aj: q’eq ub’antajik b’aqilal',
    '🙏🏻' => 'Mejtal Q’ab’aj: saq ub’antajik b’aqilal',
    '🙏🏼' => 'Mejtal Q’ab’aj: retal saq ub’antajik b’aqilal',
    '🙏🏽' => 'Mejtal Q’ab’aj: retal ub’antajik b’aqilal',
    '🙏🏾' => 'Mejtal Q’ab’aj: retal-q’eq ub’antajik b’aqilal',
    '🙏🏿' => 'Mejtal Q’ab’aj: q’eq ub’antajik b’aqilal',
    '✍🏻' => 'Tz’ib’anem chi q’ab’aj: saq ub’antajik b’aqilal',
    '✍🏼' => 'Tz’ib’anem chi q’ab’aj: retal saq ub’antajik b’aqilal',
    '✍🏽' => 'Tz’ib’anem chi q’ab’aj: retal ub’antajik b’aqilal',
    '✍🏾' => 'Tz’ib’anem chi q’ab’aj: retal-q’eq ub’antajik b’aqilal',
    '✍🏿' => 'Tz’ib’anem chi q’ab’aj: q’eq ub’antajik b’aqilal',
    '💅🏻' => 'Tz’ajb’al ixk’aq: saq ub’antajik b’aqilal',
    '💅🏼' => 'Tz’ajb’al ixk’aq: retal saq ub’antajik b’aqilal',
    '💅🏽' => 'Tz’ajb’al ixk’aq: retal ub’antajik b’aqilal',
    '💅🏾' => 'Tz’ajb’al ixk’aq: retal-q’eq ub’antajik b’aqilal',
    '💅🏿' => 'Tz’ajb’al ixk’aq: q’eq ub’antajik b’aqilal',
    '🤳🏻' => 'Relesaxik uwachib’al: saq ub’antajik b’aqilal',
    '🤳🏼' => 'Relesaxik uwachib’al: retal saq ub’antajik b’aqilal',
    '🤳🏽' => 'Relesaxik uwachib’al: retal ub’antajik b’aqilal',
    '🤳🏾' => 'Relesaxik uwachib’al: retal-q’eq ub’antajik b’aqilal',
    '🤳🏿' => 'Relesaxik uwachib’al: q’eq ub’antajik b’aqilal',
    '💪🏻' => 'K’utchuq’ab’: saq ub’antajik b’aqilal',
    '💪🏼' => 'K’utchuq’ab’: retal saq ub’antajik b’aqilal',
    '💪🏽' => 'K’utchuq’ab’: retal ub’antajik b’aqilal',
    '💪🏾' => 'K’utchuq’ab’: retal-q’eq ub’antajik b’aqilal',
    '💪🏿' => 'K’utchuq’ab’: q’eq ub’antajik b’aqilal',
    '👂🏻' => 'Xikinaj: saq ub’antajik b’aqilal',
    '👂🏼' => 'Xikinaj: retal saq ub’antajik b’aqilal',
    '👂🏽' => 'Xikinaj: retal ub’antajik b’aqilal',
    '👂🏾' => 'Xikinaj: retal-q’eq ub’antajik b’aqilal',
    '👂🏿' => 'Xikinaj: q’eq ub’antajik b’aqilal',
    '👃🏻' => 'Tza’maj: saq ub’antajik b’aqilal',
    '👃🏼' => 'Tza’maj: retal saq ub’antajik b’aqilal',
    '👃🏽' => 'Tza’maj: retal ub’antajik b’aqilal',
    '👃🏾' => 'Tza’maj: retal-q’eq ub’antajik b’aqilal',
    '👃🏿' => 'Tza’maj: q’eq ub’antajik b’aqilal',
    '👶🏻' => 'Ne’: saq ub’antajik b’aqilal',
    '👶🏼' => 'Ne’: retal saq ub’antajik b’aqilal',
    '👶🏽' => 'Ne’: retal ub’antajik b’aqilal',
    '👶🏾' => 'Ne’: retal-q’eq ub’antajik b’aqilal',
    '👶🏿' => 'Ne’: q’eq ub’antajik b’aqilal',
    '🧒🏻' => 'ak’al: saq ub’antajik b’aqilal',
    '🧒🏼' => 'ak’al: retal saq ub’antajik b’aqilal',
    '🧒🏽' => 'ak’al: retal ub’antajik b’aqilal',
    '🧒🏾' => 'ak’al: retal-q’eq ub’antajik b’aqilal',
    '🧒🏿' => 'ak’al: q’eq ub’antajik b’aqilal',
    '👦🏻' => 'Ala: saq ub’antajik b’aqilal',
    '👦🏼' => 'Ala: retal saq ub’antajik b’aqilal',
    '👦🏽' => 'Ala: retal ub’antajik b’aqilal',
    '👦🏾' => 'Ala: retal-q’eq ub’antajik b’aqilal',
    '👦🏿' => 'Ala: q’eq ub’antajik b’aqilal',
    '👧🏻' => 'Ali: saq ub’antajik b’aqilal',
    '👧🏼' => 'Ali: retal saq ub’antajik b’aqilal',
    '👧🏽' => 'Ali: retal ub’antajik b’aqilal',
    '👧🏾' => 'Ali: retal-q’eq ub’antajik b’aqilal',
    '👧🏿' => 'Ali: q’eq ub’antajik b’aqilal',
    '🧑🏻' => 'nim: saq ub’antajik b’aqilal',
    '🧑🏼' => 'nim: retal saq ub’antajik b’aqilal',
    '🧑🏽' => 'nim: retal ub’antajik b’aqilal',
    '🧑🏾' => 'nim: retal-q’eq ub’antajik b’aqilal',
    '🧑🏿' => 'nim: q’eq ub’antajik b’aqilal',
    '👱🏻' => 'Q’an uwi’ winaq: saq ub’antajik b’aqilal',
    '👱🏼' => 'Q’an uwi’ winaq: retal saq ub’antajik b’aqilal',
    '👱🏽' => 'Q’an uwi’ winaq: retal ub’antajik b’aqilal',
    '👱🏾' => 'Q’an uwi’ winaq: retal-q’eq ub’antajik b’aqilal',
    '👱🏿' => 'Q’an uwi’ winaq: q’eq ub’antajik b’aqilal',
    '👨🏻' => 'Achi: saq ub’antajik b’aqilal',
    '👨🏼' => 'Achi: retal saq ub’antajik b’aqilal',
    '👨🏽' => 'Achi: retal ub’antajik b’aqilal',
    '👨🏾' => 'Achi: retal-q’eq ub’antajik b’aqilal',
    '👨🏿' => 'Achi: q’eq ub’antajik b’aqilal',
    '🧔🏻' => 'winaq k’o risma’ch: saq ub’antajik b’aqilal',
    '🧔🏼' => 'winaq k’o risma’ch: retal saq ub’antajik b’aqilal',
    '🧔🏽' => 'winaq k’o risma’ch: retal ub’antajik b’aqilal',
    '🧔🏾' => 'winaq k’o risma’ch: retal-q’eq ub’antajik b’aqilal',
    '🧔🏿' => 'winaq k’o risma’ch: q’eq ub’antajik b’aqilal',
    '👩🏻' => 'Ixoq: saq ub’antajik b’aqilal',
    '👩🏼' => 'Ixoq: retal saq ub’antajik b’aqilal',
    '👩🏽' => 'Ixoq: retal ub’antajik b’aqilal',
    '👩🏾' => 'Ixoq: retal-q’eq ub’antajik b’aqilal',
    '👩🏿' => 'Ixoq: q’eq ub’antajik b’aqilal',
    '🧓🏻' => 'ri’j: saq ub’antajik b’aqilal',
    '🧓🏼' => 'ri’j: retal saq ub’antajik b’aqilal',
    '🧓🏽' => 'ri’j: retal ub’antajik b’aqilal',
    '🧓🏾' => 'ri’j: retal-q’eq ub’antajik b’aqilal',
    '🧓🏿' => 'ri’j: q’eq ub’antajik b’aqilal',
    '👴🏻' => 'Ri’j achi: saq ub’antajik b’aqilal',
    '👴🏼' => 'Ri’j achi: retal saq ub’antajik b’aqilal',
    '👴🏽' => 'Ri’j achi: retal ub’antajik b’aqilal',
    '👴🏾' => 'Ri’j achi: retal-q’eq ub’antajik b’aqilal',
    '👴🏿' => 'Ri’j achi: q’eq ub’antajik b’aqilal',
    '👵🏻' => 'Ri’j ixoq: saq ub’antajik b’aqilal',
    '👵🏼' => 'Ri’j ixoq: retal saq ub’antajik b’aqilal',
    '👵🏽' => 'Ri’j ixoq: retal ub’antajik b’aqilal',
    '👵🏾' => 'Ri’j ixoq: retal-q’eq ub’antajik b’aqilal',
    '👵🏿' => 'Ri’j ixoq: q’eq ub’antajik b’aqilal',
    '🙍🏻' => 'Winaq b’isornaq: saq ub’antajik b’aqilal',
    '🙍🏼' => 'Winaq b’isornaq: retal saq ub’antajik b’aqilal',
    '🙍🏽' => 'Winaq b’isornaq: retal ub’antajik b’aqilal',
    '🙍🏾' => 'Winaq b’isornaq: retal-q’eq ub’antajik b’aqilal',
    '🙍🏿' => 'Winaq b’isornaq: q’eq ub’antajik b’aqilal',
    '🙎🏻' => 'Winaq schnaq uk’u’x: saq ub’antajik b’aqilal',
    '🙎🏼' => 'Winaq schnaq uk’u’x: retal saq ub’antajik b’aqilal',
    '🙎🏽' => 'Winaq schnaq uk’u’x: retal ub’antajik b’aqilal',
    '🙎🏾' => 'Winaq schnaq uk’u’x: retal-q’eq ub’antajik b’aqilal',
    '🙎🏿' => 'Winaq schnaq uk’u’x: q’eq ub’antajik b’aqilal',
    '🙅🏻' => 'Winaq uk’utum JA’I’: saq ub’antajik b’aqilal',
    '🙅🏼' => 'Winaq uk’utum JA’I’: retal saq ub’antajik b’aqilal',
    '🙅🏽' => 'Winaq uk’utum JA’I’: retal ub’antajik b’aqilal',
    '🙅🏾' => 'Winaq uk’utum JA’I’: retal-q’eq ub’antajik b’aqilal',
    '🙅🏿' => 'Winaq uk’utum JA’I’: q’eq ub’antajik b’aqilal',
    '🙆🏻' => 'Winaq uk’utum JE’: saq ub’antajik b’aqilal',
    '🙆🏼' => 'Winaq uk’utum JE’: retal saq ub’antajik b’aqilal',
    '🙆🏽' => 'Winaq uk’utum JE’: retal ub’antajik b’aqilal',
    '🙆🏾' => 'Winaq uk’utum JE’: retal-q’eq ub’antajik b’aqilal',
    '🙆🏿' => 'Winaq uk’utum JE’: q’eq ub’antajik b’aqilal',
    '💁🏻' => 'Winaq upaqab’sam jun uq’ab’: saq ub’antajik b’aqilal',
    '💁🏼' => 'Winaq upaqab’sam jun uq’ab’: retal saq ub’antajik b’aqilal',
    '💁🏽' => 'Winaq upaqab’sam jun uq’ab’: retal ub’antajik b’aqilal',
    '💁🏾' => 'Winaq upaqab’sam jun uq’ab’: retal-q’eq ub’antajik b’aqilal',
    '💁🏿' => 'Winaq upaqab’sam jun uq’ab’: q’eq ub’antajik b’aqilal',
    '🙋🏻' => 'Winaq upaqab’am uq’ab’: saq ub’antajik b’aqilal',
    '🙋🏼' => 'Winaq upaqab’am uq’ab’: retal saq ub’antajik b’aqilal',
    '🙋🏽' => 'Winaq upaqab’am uq’ab’: retal ub’antajik b’aqilal',
    '🙋🏾' => 'Winaq upaqab’am uq’ab’: retal-q’eq ub’antajik b’aqilal',
    '🙋🏿' => 'Winaq upaqab’am uq’ab’: q’eq ub’antajik b’aqilal',
    '🙇🏻' => 'Winaq k’o uk’ixb’alil: saq ub’antajik b’aqilal',
    '🙇🏼' => 'Winaq k’o uk’ixb’alil: retal saq ub’antajik b’aqilal',
    '🙇🏽' => 'Winaq k’o uk’ixb’alil: retal ub’antajik b’aqilal',
    '🙇🏾' => 'Winaq k’o uk’ixb’alil: retal-q’eq ub’antajik b’aqilal',
    '🙇🏿' => 'Winaq k’o uk’ixb’alil: q’eq ub’antajik b’aqilal',
    '🤦🏻' => 'Winaq k’o uq’ab’ chi upalaj: saq ub’antajik b’aqilal',
    '🤦🏼' => 'Winaq k’o uq’ab’ chi upalaj: retal saq ub’antajik b’aqilal',
    '🤦🏽' => 'Winaq k’o uq’ab’ chi upalaj: retal ub’antajik b’aqilal',
    '🤦🏾' => 'Winaq k’o uq’ab’ chi upalaj: retal-q’eq ub’antajik b’aqilal',
    '🤦🏿' => 'Winaq k’o uq’ab’ chi upalaj: q’eq ub’antajik b’aqilal',
    '🤷🏻' => 'Winaq man reta’m taj: saq ub’antajik b’aqilal',
    '🤷🏼' => 'Winaq man reta’m taj: retal saq ub’antajik b’aqilal',
    '🤷🏽' => 'Winaq man reta’m taj: retal ub’antajik b’aqilal',
    '🤷🏾' => 'Winaq man reta’m taj: retal-q’eq ub’antajik b’aqilal',
    '🤷🏿' => 'Winaq man reta’m taj: q’eq ub’antajik b’aqilal',
    '👮🏻' => 'Achi q’atb’altzij: saq ub’antajik b’aqilal',
    '👮🏼' => 'Achi q’atb’altzij: retal saq ub’antajik b’aqilal',
    '👮🏽' => 'Achi q’atb’altzij: retal ub’antajik b’aqilal',
    '👮🏾' => 'Achi q’atb’altzij: retal-q’eq ub’antajik b’aqilal',
    '👮🏿' => 'Achi q’atb’altzij: q’eq ub’antajik b’aqilal',
    '🕵🏻' => 'solonel uxe’: saq ub’antajik b’aqilal',
    '🕵🏼' => 'solonel uxe’: retal saq ub’antajik b’aqilal',
    '🕵🏽' => 'solonel uxe’: retal ub’antajik b’aqilal',
    '🕵🏾' => 'solonel uxe’: retal-q’eq ub’antajik b’aqilal',
    '🕵🏿' => 'solonel uxe’: q’eq ub’antajik b’aqilal',
    '💂🏻' => 'Chajinel: saq ub’antajik b’aqilal',
    '💂🏼' => 'Chajinel: retal saq ub’antajik b’aqilal',
    '💂🏽' => 'Chajinel: retal ub’antajik b’aqilal',
    '💂🏾' => 'Chajinel: retal-q’eq ub’antajik b’aqilal',
    '💂🏿' => 'Chajinel: q’eq ub’antajik b’aqilal',
    '👷🏻' => 'Ajchak rech Tzaqb’al: saq ub’antajik b’aqilal',
    '👷🏼' => 'Ajchak rech Tzaqb’al: retal saq ub’antajik b’aqilal',
    '👷🏽' => 'Ajchak rech Tzaqb’al: retal ub’antajik b’aqilal',
    '👷🏾' => 'Ajchak rech Tzaqb’al: retal-q’eq ub’antajik b’aqilal',
    '👷🏿' => 'Ajchak rech Tzaqb’al: q’eq ub’antajik b’aqilal',
    '🤴🏻' => 'Uk’ajol rey: saq ub’antajik b’aqilal',
    '🤴🏼' => 'Uk’ajol rey: retal saq ub’antajik b’aqilal',
    '🤴🏽' => 'Uk’ajol rey: retal ub’antajik b’aqilal',
    '🤴🏾' => 'Uk’ajol rey: retal-q’eq ub’antajik b’aqilal',
    '🤴🏿' => 'Uk’ajol rey: q’eq ub’antajik b’aqilal',
    '👸🏻' => 'Umi’al rey: saq ub’antajik b’aqilal',
    '👸🏼' => 'Umi’al rey: retal saq ub’antajik b’aqilal',
    '👸🏽' => 'Umi’al rey: retal ub’antajik b’aqilal',
    '👸🏾' => 'Umi’al rey: retal-q’eq ub’antajik b’aqilal',
    '👸🏿' => 'Umi’al rey: q’eq ub’antajik b’aqilal',
    '👳🏻' => 'Winaq upisom ujolom: saq ub’antajik b’aqilal',
    '👳🏼' => 'Winaq upisom ujolom: retal saq ub’antajik b’aqilal',
    '👳🏽' => 'Winaq upisom ujolom: retal ub’antajik b’aqilal',
    '👳🏾' => 'Winaq upisom ujolom: retal-q’eq ub’antajik b’aqilal',
    '👳🏿' => 'Winaq upisom ujolom: q’eq ub’antajik b’aqilal',
    '👲🏻' => 'Achi ruk’ ko powi’ rech china: saq ub’antajik b’aqilal',
    '👲🏼' => 'Achi ruk’ ko powi’ rech china: retal saq ub’antajik b’aqilal',
    '👲🏽' => 'Achi ruk’ ko powi’ rech china: retal ub’antajik b’aqilal',
    '👲🏾' => 'Achi ruk’ ko powi’ rech china: retal-q’eq ub’antajik b’aqilal',
    '👲🏿' => 'Achi ruk’ ko powi’ rech china: q’eq ub’antajik b’aqilal',
    '🧕🏻' => 'ixoq ruk’ payujolomaj: saq ub’antajik b’aqilal',
    '🧕🏼' => 'ixoq ruk’ payujolomaj: retal saq ub’antajik b’aqilal',
    '🧕🏽' => 'ixoq ruk’ payujolomaj: retal ub’antajik b’aqilal',
    '🧕🏾' => 'ixoq ruk’ payujolomaj: retal-q’eq ub’antajik b’aqilal',
    '🧕🏿' => 'ixoq ruk’ payujolomaj: q’eq ub’antajik b’aqilal',
    '🤵🏻' => 'Achi pa esmoquin: saq ub’antajik b’aqilal',
    '🤵🏼' => 'Achi pa esmoquin: retal saq ub’antajik b’aqilal',
    '🤵🏽' => 'Achi pa esmoquin: retal ub’antajik b’aqilal',
    '🤵🏾' => 'Achi pa esmoquin: retal-q’eq ub’antajik b’aqilal',
    '🤵🏿' => 'Achi pa esmoquin: q’eq ub’antajik b’aqilal',
    '👰🏻' => 'K’ulanali ruk’ Tasjolom: saq ub’antajik b’aqilal',
    '👰🏼' => 'K’ulanali ruk’ Tasjolom: retal saq ub’antajik b’aqilal',
    '👰🏽' => 'K’ulanali ruk’ Tasjolom: retal ub’antajik b’aqilal',
    '👰🏾' => 'K’ulanali ruk’ Tasjolom: retal-q’eq ub’antajik b’aqilal',
    '👰🏿' => 'K’ulanali ruk’ Tasjolom: q’eq ub’antajik b’aqilal',
    '🤰🏻' => 'Yowab’ ixoq: saq ub’antajik b’aqilal',
    '🤰🏼' => 'Yowab’ ixoq: retal saq ub’antajik b’aqilal',
    '🤰🏽' => 'Yowab’ ixoq: retal ub’antajik b’aqilal',
    '🤰🏾' => 'Yowab’ ixoq: retal-q’eq ub’antajik b’aqilal',
    '🤰🏿' => 'Yowab’ ixoq: q’eq ub’antajik b’aqilal',
    '🤱🏻' => 'uya’ik tz’um: saq ub’antajik b’aqilal',
    '🤱🏼' => 'uya’ik tz’um: retal saq ub’antajik b’aqilal',
    '🤱🏽' => 'uya’ik tz’um: retal ub’antajik b’aqilal',
    '🤱🏾' => 'uya’ik tz’um: retal-q’eq ub’antajik b’aqilal',
    '🤱🏿' => 'uya’ik tz’um: q’eq ub’antajik b’aqilal',
    '👼🏻' => 'Tyox Ne’: saq ub’antajik b’aqilal',
    '👼🏼' => 'Tyox Ne’: retal saq ub’antajik b’aqilal',
    '👼🏽' => 'Tyox Ne’: retal ub’antajik b’aqilal',
    '👼🏾' => 'Tyox Ne’: retal-q’eq ub’antajik b’aqilal',
    '👼🏿' => 'Tyox Ne’: q’eq ub’antajik b’aqilal',
    '🎅🏻' => 'Jachal Sipanik: saq ub’antajik b’aqilal',
    '🎅🏼' => 'Jachal Sipanik: retal saq ub’antajik b’aqilal',
    '🎅🏽' => 'Jachal Sipanik: retal ub’antajik b’aqilal',
    '🎅🏾' => 'Jachal Sipanik: retal-q’eq ub’antajik b’aqilal',
    '🎅🏿' => 'Jachal Sipanik: q’eq ub’antajik b’aqilal',
    '🤶🏻' => 'Ixoq Claus: saq ub’antajik b’aqilal',
    '🤶🏼' => 'Ixoq Claus: retal saq ub’antajik b’aqilal',
    '🤶🏽' => 'Ixoq Claus: retal ub’antajik b’aqilal',
    '🤶🏾' => 'Ixoq Claus: retal-q’eq ub’antajik b’aqilal',
    '🤶🏿' => 'Ixoq Claus: q’eq ub’antajik b’aqilal',
    '🧙🏻' => 'mayinel: saq ub’antajik b’aqilal',
    '🧙🏼' => 'mayinel: retal saq ub’antajik b’aqilal',
    '🧙🏽' => 'mayinel: retal ub’antajik b’aqilal',
    '🧙🏾' => 'mayinel: retal-q’eq ub’antajik b’aqilal',
    '🧙🏿' => 'mayinel: q’eq ub’antajik b’aqilal',
    '🧚🏻' => 'hada: saq ub’antajik b’aqilal',
    '🧚🏼' => 'hada: retal saq ub’antajik b’aqilal',
    '🧚🏽' => 'hada: retal ub’antajik b’aqilal',
    '🧚🏾' => 'hada: retal-q’eq ub’antajik b’aqilal',
    '🧚🏿' => 'hada: q’eq ub’antajik b’aqilal',
    '🧛🏻' => 'b’atijol kik’: saq ub’antajik b’aqilal',
    '🧛🏼' => 'b’atijol kik’: retal saq ub’antajik b’aqilal',
    '🧛🏽' => 'b’atijol kik’: retal ub’antajik b’aqilal',
    '🧛🏾' => 'b’atijol kik’: retal-q’eq ub’antajik b’aqilal',
    '🧛🏿' => 'b’atijol kik’: q’eq ub’antajik b’aqilal',
    '🧜🏻' => 'karwinaq: saq ub’antajik b’aqilal',
    '🧜🏼' => 'karwinaq: retal saq ub’antajik b’aqilal',
    '🧜🏽' => 'karwinaq: retal ub’antajik b’aqilal',
    '🧜🏾' => 'karwinaq: retal-q’eq ub’antajik b’aqilal',
    '🧜🏿' => 'karwinaq: q’eq ub’antajik b’aqilal',
    '🧝🏻' => 'jalwach: saq ub’antajik b’aqilal',
    '🧝🏼' => 'jalwach: retal saq ub’antajik b’aqilal',
    '🧝🏽' => 'jalwach: retal ub’antajik b’aqilal',
    '🧝🏾' => 'jalwach: retal-q’eq ub’antajik b’aqilal',
    '🧝🏿' => 'jalwach: q’eq ub’antajik b’aqilal',
    '💆🏻' => 'Winaq tajin uji’ik: saq ub’antajik b’aqilal',
    '💆🏼' => 'Winaq tajin uji’ik: retal saq ub’antajik b’aqilal',
    '💆🏽' => 'Winaq tajin uji’ik: retal ub’antajik b’aqilal',
    '💆🏾' => 'Winaq tajin uji’ik: retal-q’eq ub’antajik b’aqilal',
    '💆🏿' => 'Winaq tajin uji’ik: q’eq ub’antajik b’aqilal',
    '💇🏻' => 'Winaq tajin uramixik uwi’: saq ub’antajik b’aqilal',
    '💇🏼' => 'Winaq tajin uramixik uwi’: retal saq ub’antajik b’aqilal',
    '💇🏽' => 'Winaq tajin uramixik uwi’: retal ub’antajik b’aqilal',
    '💇🏾' => 'Winaq tajin uramixik uwi’: retal-q’eq ub’antajik b’aqilal',
    '💇🏿' => 'Winaq tajin uramixik uwi’: q’eq ub’antajik b’aqilal',
    '🚶🏻' => 'Winaq kab’inik: saq ub’antajik b’aqilal',
    '🚶🏼' => 'Winaq kab’inik: retal saq ub’antajik b’aqilal',
    '🚶🏽' => 'Winaq kab’inik: retal ub’antajik b’aqilal',
    '🚶🏾' => 'Winaq kab’inik: retal-q’eq ub’antajik b’aqilal',
    '🚶🏿' => 'Winaq kab’inik: q’eq ub’antajik b’aqilal',
    '🏃🏻' => 'Winaq kutij anim: saq ub’antajik b’aqilal',
    '🏃🏼' => 'Winaq kutij anim: retal saq ub’antajik b’aqilal',
    '🏃🏽' => 'Winaq kutij anim: retal ub’antajik b’aqilal',
    '🏃🏾' => 'Winaq kutij anim: retal-q’eq ub’antajik b’aqilal',
    '🏃🏿' => 'Winaq kutij anim: q’eq ub’antajik b’aqilal',
    '💃🏻' => 'Ixoq kaxojowik: saq ub’antajik b’aqilal',
    '💃🏼' => 'Ixoq kaxojowik: retal saq ub’antajik b’aqilal',
    '💃🏽' => 'Ixoq kaxojowik: retal ub’antajik b’aqilal',
    '💃🏾' => 'Ixoq kaxojowik: retal-q’eq ub’antajik b’aqilal',
    '💃🏿' => 'Ixoq kaxojowik: q’eq ub’antajik b’aqilal',
    '🕺🏻' => 'Achi kaxojowik: saq ub’antajik b’aqilal',
    '🕺🏼' => 'Achi kaxojowik: retal saq ub’antajik b’aqilal',
    '🕺🏽' => 'Achi kaxojowik: retal ub’antajik b’aqilal',
    '🕺🏾' => 'Achi kaxojowik: retal-q’eq ub’antajik b’aqilal',
    '🕺🏿' => 'Achi kaxojowik: q’eq ub’antajik b’aqilal',
    '🕴🏻' => 'achi ukojon nim atz’i’aq rech k’ayinem: saq ub’antajik b’aqilal',
    '🕴🏼' => 'achi ukojon nim atz’i’aq rech k’ayinem: retal saq ub’antajik b’aqilal',
    '🕴🏽' => 'achi ukojon nim atz’i’aq rech k’ayinem: retal ub’antajik b’aqilal',
    '🕴🏾' => 'achi ukojon nim atz’i’aq rech k’ayinem: retal-q’eq ub’antajik b’aqilal',
    '🕴🏿' => 'achi ukojon nim atz’i’aq rech k’ayinem: q’eq ub’antajik b’aqilal',
    '👯🏻' => 'E winaq ruk’ uxikin imul: saq ub’antajik b’aqilal',
    '👯🏼' => 'E winaq ruk’ uxikin imul: retal saq ub’antajik b’aqilal',
    '👯🏽' => 'E winaq ruk’ uxikin imul: retal ub’antajik b’aqilal',
    '👯🏾' => 'E winaq ruk’ uxikin imul: retal-q’eq ub’antajik b’aqilal',
    '👯🏿' => 'E winaq ruk’ uxikin imul: q’eq ub’antajik b’aqilal',
    '🧖🏻' => 'winaq pa uxlab’ upaja: saq ub’antajik b’aqilal',
    '🧖🏼' => 'winaq pa uxlab’ upaja: retal saq ub’antajik b’aqilal',
    '🧖🏽' => 'winaq pa uxlab’ upaja: retal ub’antajik b’aqilal',
    '🧖🏾' => 'winaq pa uxlab’ upaja: retal-q’eq ub’antajik b’aqilal',
    '🧖🏿' => 'winaq pa uxlab’ upaja: q’eq ub’antajik b’aqilal',
    '🧗🏻' => 'winaq ktajin kpaqi’k: saq ub’antajik b’aqilal',
    '🧗🏼' => 'winaq ktajin kpaqi’k: retal saq ub’antajik b’aqilal',
    '🧗🏽' => 'winaq ktajin kpaqi’k: retal ub’antajik b’aqilal',
    '🧗🏾' => 'winaq ktajin kpaqi’k: retal-q’eq ub’antajik b’aqilal',
    '🧗🏿' => 'winaq ktajin kpaqi’k: q’eq ub’antajik b’aqilal',
    '🏇🏻' => 'Anim chi rij kej: saq ub’antajik b’aqilal',
    '🏇🏼' => 'Anim chi rij kej: retal saq ub’antajik b’aqilal',
    '🏇🏽' => 'Anim chi rij kej: retal ub’antajik b’aqilal',
    '🏇🏾' => 'Anim chi rij kej: retal-q’eq ub’antajik b’aqilal',
    '🏇🏿' => 'Anim chi rij kej: q’eq ub’antajik b’aqilal',
    '🏂🏻' => 'Charar pa t’aja’j: saq ub’antajik b’aqilal',
    '🏂🏼' => 'Charar pa t’aja’j: retal saq ub’antajik b’aqilal',
    '🏂🏽' => 'Charar pa t’aja’j: retal ub’antajik b’aqilal',
    '🏂🏾' => 'Charar pa t’aja’j: retal-q’eq ub’antajik b’aqilal',
    '🏂🏿' => 'Charar pa t’aja’j: q’eq ub’antajik b’aqilal',
    '🏌🏻' => 'winaq ktajin kretz’ab’ej yopotz’: saq ub’antajik b’aqilal',
    '🏌🏼' => 'winaq ktajin kretz’ab’ej yopotz’: retal saq ub’antajik b’aqilal',
    '🏌🏽' => 'winaq ktajin kretz’ab’ej yopotz’: retal ub’antajik b’aqilal',
    '🏌🏾' => 'winaq ktajin kretz’ab’ej yopotz’: retal-q’eq ub’antajik b’aqilal',
    '🏌🏿' => 'winaq ktajin kretz’ab’ej yopotz’: q’eq ub’antajik b’aqilal',
    '🏄🏻' => 'Winaq aj etz’anel pa ja’: saq ub’antajik b’aqilal',
    '🏄🏼' => 'Winaq aj etz’anel pa ja’: retal saq ub’antajik b’aqilal',
    '🏄🏽' => 'Winaq aj etz’anel pa ja’: retal ub’antajik b’aqilal',
    '🏄🏾' => 'Winaq aj etz’anel pa ja’: retal-q’eq ub’antajik b’aqilal',
    '🏄🏿' => 'Winaq aj etz’anel pa ja’: q’eq ub’antajik b’aqilal',
    '🚣🏻' => 'Winaq kub’inisaj jukub’: saq ub’antajik b’aqilal',
    '🚣🏼' => 'Winaq kub’inisaj jukub’: retal saq ub’antajik b’aqilal',
    '🚣🏽' => 'Winaq kub’inisaj jukub’: retal ub’antajik b’aqilal',
    '🚣🏾' => 'Winaq kub’inisaj jukub’: retal-q’eq ub’antajik b’aqilal',
    '🚣🏿' => 'Winaq kub’inisaj jukub’: q’eq ub’antajik b’aqilal',
    '🏊🏻' => 'Winaq aj muxanel: saq ub’antajik b’aqilal',
    '🏊🏼' => 'Winaq aj muxanel: retal saq ub’antajik b’aqilal',
    '🏊🏽' => 'Winaq aj muxanel: retal ub’antajik b’aqilal',
    '🏊🏾' => 'Winaq aj muxanel: retal-q’eq ub’antajik b’aqilal',
    '🏊🏿' => 'Winaq aj muxanel: q’eq ub’antajik b’aqilal',
    '⛹🏻' => 'winaq ktajin kupixkansaj potz’: saq ub’antajik b’aqilal',
    '⛹🏼' => 'winaq ktajin kupixkansaj potz’: retal saq ub’antajik b’aqilal',
    '⛹🏽' => 'winaq ktajin kupixkansaj potz’: retal ub’antajik b’aqilal',
    '⛹🏾' => 'winaq ktajin kupixkansaj potz’: retal-q’eq ub’antajik b’aqilal',
    '⛹🏿' => 'winaq ktajin kupixkansaj potz’: q’eq ub’antajik b’aqilal',
    '🏋🏻' => 'winaq kupaqab’isaj taq a’lal: saq ub’antajik b’aqilal',
    '🏋🏼' => 'winaq kupaqab’isaj taq a’lal: retal saq ub’antajik b’aqilal',
    '🏋🏽' => 'winaq kupaqab’isaj taq a’lal: retal ub’antajik b’aqilal',
    '🏋🏾' => 'winaq kupaqab’isaj taq a’lal: retal-q’eq ub’antajik b’aqilal',
    '🏋🏿' => 'winaq kupaqab’isaj taq a’lal: q’eq ub’antajik b’aqilal',
    '🚴🏻' => 'Winaq aj kej ch’ich’: saq ub’antajik b’aqilal',
    '🚴🏼' => 'Winaq aj kej ch’ich’: retal saq ub’antajik b’aqilal',
    '🚴🏽' => 'Winaq aj kej ch’ich’: retal ub’antajik b’aqilal',
    '🚴🏾' => 'Winaq aj kej ch’ich’: retal-q’eq ub’antajik b’aqilal',
    '🚴🏿' => 'Winaq aj kej ch’ich’: q’eq ub’antajik b’aqilal',
    '🚵🏻' => 'Winaq aj kej ch’ich’ pa juyub’: saq ub’antajik b’aqilal',
    '🚵🏼' => 'Winaq aj kej ch’ich’ pa juyub’: retal saq ub’antajik b’aqilal',
    '🚵🏽' => 'Winaq aj kej ch’ich’ pa juyub’: retal ub’antajik b’aqilal',
    '🚵🏾' => 'Winaq aj kej ch’ich’ pa juyub’: retal-q’eq ub’antajik b’aqilal',
    '🚵🏿' => 'Winaq aj kej ch’ich’ pa juyub’: q’eq ub’antajik b’aqilal',
    '🤸🏻' => 'Winaq xulan uwi’: saq ub’antajik b’aqilal',
    '🤸🏼' => 'Winaq xulan uwi’: retal saq ub’antajik b’aqilal',
    '🤸🏽' => 'Winaq xulan uwi’: retal ub’antajik b’aqilal',
    '🤸🏾' => 'Winaq xulan uwi’: retal-q’eq ub’antajik b’aqilal',
    '🤸🏿' => 'Winaq xulan uwi’: q’eq ub’antajik b’aqilal',
    '🤼🏻' => 'E winaq kech’o’jinik: saq ub’antajik b’aqilal',
    '🤼🏼' => 'E winaq kech’o’jinik: retal saq ub’antajik b’aqilal',
    '🤼🏽' => 'E winaq kech’o’jinik: retal ub’antajik b’aqilal',
    '🤼🏾' => 'E winaq kech’o’jinik: retal-q’eq ub’antajik b’aqilal',
    '🤼🏿' => 'E winaq kech’o’jinik: q’eq ub’antajik b’aqilal',
    '🤽🏻' => 'Winaq aj etz’anel potz’ pa ja’: saq ub’antajik b’aqilal',
    '🤽🏼' => 'Winaq aj etz’anel potz’ pa ja’: retal saq ub’antajik b’aqilal',
    '🤽🏽' => 'Winaq aj etz’anel potz’ pa ja’: retal ub’antajik b’aqilal',
    '🤽🏾' => 'Winaq aj etz’anel potz’ pa ja’: retal-q’eq ub’antajik b’aqilal',
    '🤽🏿' => 'Winaq aj etz’anel potz’ pa ja’: q’eq ub’antajik b’aqilal',
    '🤾🏻' => 'Winaq aj etz’anel potz’ chi q’ab’aj: saq ub’antajik b’aqilal',
    '🤾🏼' => 'Winaq aj etz’anel potz’ chi q’ab’aj: retal saq ub’antajik b’aqilal',
    '🤾🏽' => 'Winaq aj etz’anel potz’ chi q’ab’aj: retal ub’antajik b’aqilal',
    '🤾🏾' => 'Winaq aj etz’anel potz’ chi q’ab’aj: retal-q’eq ub’antajik b’aqilal',
    '🤾🏿' => 'Winaq aj etz’anel potz’ chi q’ab’aj: q’eq ub’antajik b’aqilal',
    '🤹🏻' => 'Winaq aj mayib’al: saq ub’antajik b’aqilal',
    '🤹🏼' => 'Winaq aj mayib’al: retal saq ub’antajik b’aqilal',
    '🤹🏽' => 'Winaq aj mayib’al: retal ub’antajik b’aqilal',
    '🤹🏾' => 'Winaq aj mayib’al: retal-q’eq ub’antajik b’aqilal',
    '🤹🏿' => 'Winaq aj mayib’al: q’eq ub’antajik b’aqilal',
    '🧘🏻' => 'winaq ukrusim raqan: saq ub’antajik b’aqilal',
    '🧘🏼' => 'winaq ukrusim raqan: retal saq ub’antajik b’aqilal',
    '🧘🏽' => 'winaq ukrusim raqan: retal ub’antajik b’aqilal',
    '🧘🏾' => 'winaq ukrusim raqan: retal-q’eq ub’antajik b’aqilal',
    '🧘🏿' => 'winaq ukrusim raqan: q’eq ub’antajik b’aqilal',
    '🛀🏻' => 'Winaq tajin katinik: saq ub’antajik b’aqilal',
    '🛀🏼' => 'Winaq tajin katinik: retal saq ub’antajik b’aqilal',
    '🛀🏽' => 'Winaq tajin katinik: retal ub’antajik b’aqilal',
    '🛀🏾' => 'Winaq tajin katinik: retal-q’eq ub’antajik b’aqilal',
    '🛀🏿' => 'Winaq tajin katinik: q’eq ub’antajik b’aqilal',
    '🛌🏻' => 'Winaq pa ch’at: saq ub’antajik b’aqilal',
    '🛌🏼' => 'Winaq pa ch’at: retal saq ub’antajik b’aqilal',
    '🛌🏽' => 'Winaq pa ch’at: retal ub’antajik b’aqilal',
    '🛌🏾' => 'Winaq pa ch’at: retal-q’eq ub’antajik b’aqilal',
    '🛌🏿' => 'Winaq pa ch’at: q’eq ub’antajik b’aqilal',
    '👭🏻' => 'Keb’ ixoqib’ kichapom kiq’ab’: saq ub’antajik b’aqilal',
    '👭🏼' => 'Keb’ ixoqib’ kichapom kiq’ab’: retal saq ub’antajik b’aqilal',
    '👭🏽' => 'Keb’ ixoqib’ kichapom kiq’ab’: retal ub’antajik b’aqilal',
    '👭🏾' => 'Keb’ ixoqib’ kichapom kiq’ab’: retal-q’eq ub’antajik b’aqilal',
    '👭🏿' => 'Keb’ ixoqib’ kichapom kiq’ab’: q’eq ub’antajik b’aqilal',
    '👫🏻' => 'Achi chi’l ixoq kichapom kiq’ab’: saq ub’antajik b’aqilal',
    '👫🏼' => 'Achi chi’l ixoq kichapom kiq’ab’: retal saq ub’antajik b’aqilal',
    '👫🏽' => 'Achi chi’l ixoq kichapom kiq’ab’: retal ub’antajik b’aqilal',
    '👫🏾' => 'Achi chi’l ixoq kichapom kiq’ab’: retal-q’eq ub’antajik b’aqilal',
    '👫🏿' => 'Achi chi’l ixoq kichapom kiq’ab’: q’eq ub’antajik b’aqilal',
    '👬🏻' => 'Keb’ achijab’ kichapom kiq’ab’: saq ub’antajik b’aqilal',
    '👬🏼' => 'Keb’ achijab’ kichapom kiq’ab’: retal saq ub’antajik b’aqilal',
    '👬🏽' => 'Keb’ achijab’ kichapom kiq’ab’: retal ub’antajik b’aqilal',
    '👬🏾' => 'Keb’ achijab’ kichapom kiq’ab’: retal-q’eq ub’antajik b’aqilal',
    '👬🏿' => 'Keb’ achijab’ kichapom kiq’ab’: q’eq ub’antajik b’aqilal',
    '💏🏻' => 'Tz’umanik: saq ub’antajik b’aqilal',
    '💏🏼' => 'Tz’umanik: retal saq ub’antajik b’aqilal',
    '💏🏽' => 'Tz’umanik: retal ub’antajik b’aqilal',
    '💏🏾' => 'Tz’umanik: retal-q’eq ub’antajik b’aqilal',
    '💏🏿' => 'Tz’umanik: q’eq ub’antajik b’aqilal',
    '💑🏻' => 'Kab’ichal ruk’ anima: saq ub’antajik b’aqilal',
    '💑🏼' => 'Kab’ichal ruk’ anima: retal saq ub’antajik b’aqilal',
    '💑🏽' => 'Kab’ichal ruk’ anima: retal ub’antajik b’aqilal',
    '💑🏾' => 'Kab’ichal ruk’ anima: retal-q’eq ub’antajik b’aqilal',
    '💑🏿' => 'Kab’ichal ruk’ anima: q’eq ub’antajik b’aqilal',
    '🏻' => 'saq ub’antajik b’aqilal',
    '🏼' => 'retal saq ub’antajik b’aqilal',
    '🏽' => 'retal ub’antajik b’aqilal',
    '🏾' => 'retal-q’eq ub’antajik b’aqilal',
    '🏿' => 'q’eq ub’antajik b’aqilal',
    '😀' => 'Ktze’n Palajaj',
    '😃' => 'Tze’naq palajaj uk’ab’om uchi’',
    '😄' => 'Ktze’n palajaj uk’ab’om uchi’ chi’l ktze’n b’aq’wachaj',
    '😁' => 'Ktze’n palajaj ruk’ ktze’n b’aq’wachaj',
    '😆' => 'Ktze’n palajaj uk’ab’om uchi’ chi’l utzapim b’aq’wachaj',
    '😅' => 'Ktze’n palajaj uk’ab’om uchi’ chi’l joron uwa’l wachaj',
    '🤣' => 'Sib’alaj tze’naq',
    '😂' => 'Palajaj Ruk’ Uwal Wachaj rech Ki’kotemal',
    '🙂' => 'Tze’naq palajaj',
    '🙃' => 'Xulan uwi’ palajaj',
    '😉' => 'Utz’apim ub’aqwach palajaj',
    '😊' => 'Tze’naq palajaj porotz’ ub’aqwach',
    '😇' => 'Tze’naq me’s ruk’ setesik pa ujolom',
    '😍' => 'Tze’naq palajaj ruk’ anima’ chi ub’aqwach',
    '🤩' => 'uriqom k’ax',
    '😘' => 'Palajaj kuwupuj jun Chi’aj',
    '😗' => 'Palajaj ruk’ tz’umanik',
    '☺' => 'tze’nem',
    '😚' => 'Palajaj ruk’ tz’umanik Utz’apim uwach',
    '😙' => 'Palajaj ruk’ Tz’umanik Tz’enaq ub’aqwach',
    '😋' => 'Palajaj ktajin Kuki’risaj Je’l riki’l',
    '😛' => 'Palajaj ruk’ Relesam Raq',
    '😜' => 'palajaj ruk’ relesam raq’ chi’l uyupwachim uwach',
    '🤪' => 'pay palajaj',
    '😝' => 'palajaj ruk’ relesam raq’ chi’l utz’apim uwach',
    '🤑' => 'Palajaj ruk’ pwaq',
    '🤗' => 'Umatzexik Palajaj',
    '🤭' => 'palajaj uch’uqum uchi’',
    '🤫' => 'matzalem palajaj',
    '🤔' => 'Chomanik palajaj',
    '🤐' => 'Palajaj sierayim uchi’',
    '🤨' => 'palajaj ruk’ paqab’isam rij uwach',
    '😐' => 'Suk’ul palajaj',
    '😑' => 'Palajaj man k’o ta Kub’ij',
    '😶' => 'Palajaj Man k’o ta Uchi’',
    '😏' => 'Jech’el uchi’ palajaj',
    '😒' => 'Man kaki’kot ta palajaj',
    '🙄' => 'Palajaj ruk’ ksilkop b’aqwachaj',
    '😬' => 'Ub’anom Palajaj',
    '🤥' => 'Nim utza’m',
    '😌' => 'Qajinaq uwach palajaj',
    '😔' => 'Qajnaq uwach palajaj',
    '😪' => 'Karaj uwaram palajaj',
    '🤤' => 'Palajaj ruk’ K’axaj',
    '😴' => 'Warnaq palajaj',
    '😷' => 'Palajaj ruk’ k’oj rech Kunanem',
    '🤒' => 'Palajaj Ruk’ Ucholajil tewq’aq’al',
    '🤕' => 'Palajaj ruk’ Pistal Jolomaj',
    '🤢' => 'Ulemlotem anima’ palajaj',
    '🤮' => 'palajaj ktajin kxab’ik',
    '🤧' => 'At’ujnab’em palajaj',
    '😵' => 'Ksutin ujolom Palajaj',
    '🤯' => 'ktukin jolomaj',
    '🤠' => 'Upalaj Upowi’ Bake’r',
    '😎' => 'Tze’naq palajaj ruk’ anti’oj rech uwaq’ij',
    '🤓' => 'Jalajoj Palajaj',
    '🧐' => 'palajaj ruk’ jun ch’uqwachaj',
    '😕' => 'Sachinaq uk’u’x Palajaj',
    '😟' => 'Uxe’m rib’ palajaj',
    '🙁' => 'B’isornaq palajaj',
    '☹' => 'ukichi’chem upalaj',
    '😮' => 'Palajaj ruk’ Jaqatal Chi’aj',
    '😯' => 'memarinaq Palajaj',
    '😲' => 'Palaj rech mayib’al',
    '😳' => 'Kaq palajaj',
    '😦' => 'B’isorinaq Palajaj ruk’ Ujaqom Uchu’',
    '😧' => 'Palajaj B’isorinaq',
    '😨' => 'Ixib’im rib’ Palaljaj',
    '😰' => 'Palajaj ruk’ jaqatal chi’aj chi’l joron k’atanal',
    '😥' => 'B’isorinaq Palajaj xa k’ut ruk’ Q’alb’al k’u’x',
    '😢' => 'Koq’ Upalaj',
    '😭' => 'Oq’inaq palajaj',
    '😱' => 'Palajaj Kuraq uchi’ chech Xb’in ib’',
    '😖' => 'Palajaj Sachinaq Uk’u’x',
    '😣' => 'Ch’iqiqem palajaj',
    '😞' => 'B’isorinaq Palajaj',
    '😓' => 'Palajaj ruk’ Joron K’atanal',
    '😩' => 'Koq’ palajaj',
    '😫' => 'Kosnaq palajaj',
    '😤' => 'Palajaj ruk’ k’atanal rech Tza’maj',
    '😡' => 'K’a’n palajaj',
    '😠' => 'K’anarinaq Palajaj',
    '🤬' => 'taq palajaj ruk’ taq etal chi uchi’',
    '😈' => 'Tze’naq palajaj ruk’ setesik pa ujolom',
    '👿' => 'K’anarinaq Palajaj ruk’ Uk’a’',
    '💀' => 'Ujolom kamnaq',
    '☠' => 'b’aq ukrusim rib’ rech jolomaj chi’l taq b’aq',
    '💩' => 'Tz’uqutz’ik retzelal',
    '🤡' => 'Palajaj rech Paya’s',
    '👹' => 'Ogro',
    '👺' => 'Alaj Nitz’',
    '👻' => 'Xib’inel',
    '👽' => 'Ajkaj jalwach',
    '👾' => 'Xib’inel jalwach',
    '🤖' => 'Ch’ich’ upalaj',
    '😺' => 'Tze’naq me’s uk’ab’om uchi’',
    '😸' => 'Ktze’n Palajaj rech Me’s Ruk’ Ktze’n Ub’aqwach',
    '😹' => 'Upalaj me’s ruk’ uwal Wachaj rech Ki’kotemal',
    '😻' => 'Tze’naq me’s ruk’ anima’ chi ub’aqwach',
    '😼' => 'Upalaj me’s ruk’ Jech’el Tze’nem',
    '😽' => 'Upalaj Me’s ruk’ Tzumanik utz’apim uwach',
    '🙀' => 'Kosnaq upalaj me’s',
    '😿' => 'Koq’ Upalaj Me’s',
    '😾' => 'K’a’n upalaj me’s',
    '🙈' => 'K’oy uch’uqum ub’aq’wach',
    '🙉' => 'Mata jun K’oy le man Utz taj',
    '🙊' => 'K’oy uch’uqum uchi’',
    '💌' => 'Wuj rech loq’ob’al',
    '💘' => 'Anima ruk’ Ch’ab’',
    '💝' => 'Anima ruk’ Kemutasil',
    '💖' => 'Anima’ kachupchutik',
    '💗' => 'Uk’iyem Anima',
    '💓' => 'Ub’irb’otem Anima',
    '💞' => 'Rutzirisaxik anima’',
    '💕' => 'Keb’ anima’',
    '💟' => 'Uwiqik Anima',
    '❣' => 'al anima rech mayb’al',
    '💔' => 'Paxinaq Anima',
    '❤' => 'kaq anima',
    '🧡' => 'uwaxub’ anima',
    '💛' => 'Q’an anima’',
    '💚' => 'Rax Anima',
    '💙' => 'Raxkaj Anima',
    '💜' => 'Kaqxuk’uxuj anima’',
    '🖤' => 'Q’eq anima',
    '💋' => 'Etal rech Tz’umanik',
    '💯' => 'Cien Puntos',
    '💢' => 'Retal Eyowal',
    '💥' => 'Paq’inem',
    '💫' => 'Ksutin Ujolom',
    '💦' => 'Alaj taq tz’uj',
    '💨' => 'Naj Tijoj Anim',
    '🕳' => 'jul',
    '💬' => 'Pupu ruk’ q’atnak’',
    '🗨' => 'moxq’ab’ tzijonem pa jopob’al',
    '🗯' => 'wikiq’ab’ eyowarinaq jopob’al',
    '💭' => 'Sutz’ rech chomanik',
    '💤' => 'Zzz',
    '👋' => 'Upam q’ab’aj',
    '🤚' => 'Yakom upam q’ab’aj',
    '🖐' => 'yakom q’ab’aj ruk’ lik’ital taq uwi’ q’ab’al',
    '✋' => 'Yakom q’ab’aj',
    '🖖' => 'Rutzil wachaj',
    '👌' => 'Uk’amik q’ab’al',
    '✌' => 'q’ab’aj rech ch’akanem',
    '🤞' => 'Uwi’ q’ab’aj ukrusim rib’',
    '🤟' => 'uk’utik katwaj',
    '🤘' => 'Retal uk’a’',
    '🤙' => 'k’utq’ab’aj Chinasik’ij',
    '👈' => 'k’utwiq’ab’ Kuk’ut pa Moxq’ab’',
    '👉' => 'k’utwiq’ab’ Kuk’ut pa Wikiq’ab’',
    '👆' => 'k’utwiq’ab’ Kuk’ut pa Uwi’',
    '🖕' => 'nik’ajal uwi’ q’ab’al',
    '👇' => 'k’utwiq’ab’ Kuk’ut chi Uxe’',
    '☝' => 'ch’ipel kuk’ut uwi’',
    '👍' => 'Uwi q’ab’aj pa uwi’',
    '👎' => 'Uwi q’ab’aj chi uxe’',
    '✊' => 'K’olom q’ab’aj',
    '👊' => 'K’olon q’ab’aj petinaq',
    '🤛' => 'K’olon q’ab’aj',
    '🤜' => 'K’olon q’ab’aj rech utzil',
    '👏' => 'Upaq’apaxik upaq’ab’aj',
    '🙌' => 'Yakom keb’ q’ab’aj',
    '👐' => 'Jaqom q’ab’aj',
    '🤲' => 'utunik q’ab’aj',
    '🤝' => 'Uk’ulaxik Q’ab’aj',
    '🙏' => 'Mejtal Q’ab’aj',
    '✍' => 'Tz’ib’anem chi q’ab’aj',
    '💅' => 'Tz’ajb’al ixk’aq',
    '🤳' => 'Relesaxik uwachib’al',
    '💪' => 'K’utchuq’ab’',
    '👂' => 'Xikinaj',
    '👃' => 'Tza’maj',
    '🧠' => 'tzantzaq’or',
    '👀' => 'B’aq’wachaj',
    '👁' => 'b’aqwach',
    '👅' => 'Raq’',
    '👄' => 'Chi’aj',
    '👶' => 'Ne’',
    '🧒' => 'ak’al',
    '👦' => 'Ala',
    '👧' => 'Ali',
    '🧑' => 'nim',
    '👱' => 'Q’an uwi’ winaq',
    '👨' => 'Achi',
    '🧔' => 'winaq k’o risma’ch',
    '👩' => 'Ixoq',
    '🧓' => 'ri’j',
    '👴' => 'Ri’j achi',
    '👵' => 'Ri’j ixoq',
    '🙍' => 'Winaq b’isornaq',
    '🙎' => 'Winaq schnaq uk’u’x',
    '🙅' => 'Winaq uk’utum JA’I’',
    '🙆' => 'Winaq uk’utum JE’',
    '💁' => 'Winaq upaqab’sam jun uq’ab’',
    '🙋' => 'Winaq upaqab’am uq’ab’',
    '🙇' => 'Winaq k’o uk’ixb’alil',
    '🤦' => 'Winaq k’o uq’ab’ chi upalaj',
    '🤷' => 'Winaq man reta’m taj',
    '👮' => 'Achi q’atb’altzij',
    '🕵' => 'solonel uxe’',
    '💂' => 'Chajinel',
    '👷' => 'Ajchak rech Tzaqb’al',
    '🤴' => 'Uk’ajol rey',
    '👸' => 'Umi’al rey',
    '👳' => 'Winaq upisom ujolom',
    '👲' => 'Achi ruk’ ko powi’ rech china',
    '🧕' => 'ixoq ruk’ payujolomaj',
    '🤵' => 'Achi pa esmoquin',
    '👰' => 'K’ulanali ruk’ Tasjolom',
    '🤰' => 'Yowab’ ixoq',
    '🤱' => 'uya’ik tz’um',
    '👼' => 'Tyox Ne’',
    '🎅' => 'Jachal Sipanik',
    '🤶' => 'Ixoq Claus',
    '🧙' => 'mayinel',
    '🧚' => 'hada',
    '🧛' => 'b’atijol kik’',
    '🧜' => 'karwinaq',
    '🧝' => 'jalwach',
    '🧞' => 'nireta’mab’al',
    '🧟' => 'k’askaminaq',
    '💆' => 'Winaq tajin uji’ik',
    '💇' => 'Winaq tajin uramixik uwi’',
    '🚶' => 'Winaq kab’inik',
    '🏃' => 'Winaq kutij anim',
    '💃' => 'Ixoq kaxojowik',
    '🕺' => 'Achi kaxojowik',
    '🕴' => 'achi ukojon nim atz’i’aq rech k’ayinem',
    '👯' => 'E winaq ruk’ uxikin imul',
    '🧖' => 'winaq pa uxlab’ upaja',
    '🧗' => 'winaq ktajin kpaqi’k',
    '🤺' => 'ch’ojinel',
    '🏇' => 'Anim chi rij kej',
    '⛷' => 'charanel',
    '🏂' => 'Charar pa t’aja’j',
    '🏌' => 'winaq ktajin kretz’ab’ej yopotz’',
    '🏄' => 'Winaq aj etz’anel pa ja’',
    '🚣' => 'Winaq kub’inisaj jukub’',
    '🏊' => 'Winaq aj muxanel',
    '⛹' => 'winaq ktajin kupixkansaj potz’',
    '🏋' => 'winaq kupaqab’isaj taq a’lal',
    '🚴' => 'Winaq aj kej ch’ich’',
    '🚵' => 'Winaq aj kej ch’ich’ pa juyub’',
    '🤸' => 'Winaq xulan uwi’',
    '🤼' => 'E winaq kech’o’jinik',
    '🤽' => 'Winaq aj etz’anel potz’ pa ja’',
    '🤾' => 'Winaq aj etz’anel potz’ chi q’ab’aj',
    '🤹' => 'Winaq aj mayib’al',
    '🧘' => 'winaq ukrusim raqan',
    '🛀' => 'Winaq tajin katinik',
    '🛌' => 'Winaq pa ch’at',
    '👭' => 'Keb’ ixoqib’ kichapom kiq’ab’',
    '👫' => 'Achi chi’l ixoq kichapom kiq’ab’',
    '👬' => 'Keb’ achijab’ kichapom kiq’ab’',
    '💏' => 'Tz’umanik',
    '💑' => 'Kab’ichal ruk’ anima',
    '🗣' => 'winaq ktzijonik',
    '👤' => 'Rinoch Uwak’u’xaj',
    '👥' => 'Rinoch’ taq Uwak’u’xaj',
    '👪' => 'Ajupaja',
    '👣' => 'Retal Aqanaj',
    '🐵' => 'Upalaj k’oy',
    '🐒' => 'K’oy',
    '🦍' => 'Nim K’oy',
    '🐶' => 'Upalaj tz’i’',
    '🐕' => 'Tz’i’',
    '🐩' => 'Caniche',
    '🐺' => 'Upalaj koyo’t',
    '🦊' => 'Upalaj sokoyo’t',
    '🐱' => 'Upalaj me’s',
    '🐈' => 'Me’s',
    '🦁' => 'Upalaj koj',
    '🐯' => 'Upalaj b’alam',
    '🐅' => 'B’alam',
    '🐆' => 'B’alame’s',
    '🐴' => 'Palajaj rech Kej',
    '🐎' => 'Kej',
    '🦄' => 'Upalaj unicornio',
    '🦓' => 'me’skej',
    '🦌' => 'Masat',
    '🐮' => 'Upalaj Wakax',
    '🐂' => 'Buwakax',
    '🐃' => 'Wakax rech ja’',
    '🐄' => 'Wakax',
    '🐷' => 'Upalaj aq',
    '🐖' => 'Aq',
    '🐗' => 'K’ache’laq',
    '🐽' => 'Utza’m aq',
    '🐏' => 'Karne’l',
    '🐑' => 'chij',
    '🐐' => 'K’isik’',
    '🐪' => 'Kamey',
    '🐫' => 'Keb’ q’u’s kamey',
    '🦒' => 'yuqchikop',
    '🐘' => 'Tix',
    '🦏' => 'Rinoceronte',
    '🐭' => 'Upalaj ch’o',
    '🐁' => 'Ch’o',
    '🐀' => 'B’ayi’s',
    '🐹' => 'Upalaj jamch’o',
    '🐰' => 'Upalaj imul',
    '🐇' => 'Imul',
    '🐿' => 'chikuk',
    '🦔' => 'puk’cho',
    '🦇' => 'Sotz’',
    '🐻' => 'Upalaj Oso',
    '🐨' => 'Coala',
    '🐼' => 'Upalaj panda',
    '🐾' => 'Uparaqan awaj',
    '🦃' => 'No’s',
    '🐔' => 'Ak’',
    '🐓' => 'Ama’',
    '🐣' => 'Uk’iyib’al Wich’',
    '🐤' => 'Alaj Wich’',
    '🐥' => 'Alaj Wich chi uwach',
    '🐦' => 'Tz’ikin',
    '🐧' => 'Pingüino',
    '🕊' => 'b’otz’iki’n',
    '🦅' => 'Xik',
    '🦆' => 'Patax',
    '🦉' => 'Tukur',
    '🐸' => 'Upalaj Xpeq',
    '🐊' => 'Kokodril',
    '🐢' => 'Kok',
    '🦎' => 'Xpa’ch',
    '🐍' => 'Kumatz',
    '🐲' => 'Chak’achik Awaj Upalaj',
    '🐉' => 'Chak’achik awaj',
    '🦕' => 'sanimayin',
    '🦖' => 'tenimayin',
    '🐳' => 'Nim kar karesaj la ja’',
    '🐋' => 'Mataq’tami’',
    '🐬' => 'Aqk’ar',
    '🐟' => 'Kar',
    '🐠' => 'Kar rech saq’ij',
    '🐡' => 'K’ixkar',
    '🦈' => 'Tib’kar',
    '🐙' => 'Yatz chikop',
    '🐚' => 'Ub’olq’otim rib’ concha',
    '🦀' => 'Tap',
    '🦐' => 'kamaron',
    '🦑' => 'kalamar',
    '🐌' => 'T’ot’',
    '🦋' => 'Pepe',
    '🐛' => 'k’axk’olil',
    '🐜' => 'Sanik',
    '🐝' => 'Raxkab’ rech Awonon',
    '🐞' => 'K’o’x',
    '🦗' => 'Lol',
    '🕷' => 'uparaqan key',
    '🕸' => 'k’at rech uparaqan kej',
    '🦂' => 'Escorpión',
    '💐' => 'Juyetaj',
    '🌸' => 'Ukotz’ijal k’uxk’ab’el',
    '💮' => 'Saq kotz’i’j',
    '🏵' => 'kemk’otz’ij',
    '🌹' => 'Kaqkoj',
    '🥀' => 'Chaqi’j kotz’i’j',
    '🌺' => 'Taq kotzi’j',
    '🌻' => 'Q’an kotz’i’j',
    '🌼' => 'Kotz’ij',
    '🌷' => 'Tulipan',
    '🌱' => 'Q’ayes',
    '🌲' => 'Tz’inchaj',
    '🌳' => 'Ponopik Che’',
    '🌴' => 'Palmche’',
    '🌵' => 'Nochti’',
    '🌾' => 'Q’ayes rech aros',
    '🌿' => 'Ichaj',
    '☘' => 'xakotzi’j',
    '🍀' => 'Kotz’ij Kajib’ Uxaq',
    '🍁' => 'Uxaq maple',
    '🍂' => 'Tzaqinaq uxaq che’',
    '🍃' => 'Uxaq che’ silob’sam rumal kaqiq’',
    '🍄' => 'Uxe che’',
    '🍇' => 'Taq raxpopoj',
    '🍈' => 'Uwaxub’awache’',
    '🍉' => 'Kaqaq’oq’',
    '🍊' => 'Tamarindo',
    '🍋' => 'Alamnax',
    '🍌' => 'Ankine’y',
    '🍍' => 'Ch’op',
    '🍎' => 'Kaq mansa’n',
    '🍏' => 'Rax Mansa’n',
    '🍐' => 'Pera',
    '🍑' => 'Tara’s',
    '🍒' => 'Taq kaqk’uxk’ab’el',
    '🍓' => 'Kaqumache’',
    '🥝' => 'Uwach che’ kiwi',
    '🍅' => 'Pix',
    '🥥' => 'koko',
    '🥑' => 'Oj',
    '🍆' => 'Raxpopoj Q’ax',
    '🥔' => 'Saqwach',
    '🥕' => 'Sanaor',
    '🌽' => 'Jal rech Ixim',
    '🌶' => 'poqon q’ax',
    '🥒' => 'k’olotal raxuwache’',
    '🥦' => 'raxichaj',
    '🥜' => 'Mani’y',
    '🌰' => 'Kaxlanmani’y',
    '🍞' => 'lokaxlanwa',
    '🥐' => 'Krosant',
    '🥖' => 'Jurujik kaxlanwa',
    '🥨' => 'tzayayet',
    '🥞' => 'ktan setkaxlanwa',
    '🧀' => 'Jub’a’ Kexu',
    '🍖' => 'Ti’ij ruk’ baq',
    '🍗' => 'Ra’ ak’',
    '🥩' => 'uramik ti’j',
    '🥓' => 'B’olom ti’ij',
    '🍔' => 'Ti’jkaxlanwa',
    '🍟' => 'B’olom saqwach',
    '🍕' => 'Pizza',
    '🌭' => 'Rab’kaxlanwa',
    '🥪' => 'sati’jkaxlanwa',
    '🌮' => 'Wotz’otz’',
    '🌯' => 'Lajbur',
    '🥙' => 'Riki’l pa kaxlanwa',
    '🥚' => 'Saqmo’l',
    '🍳' => 'Tzakoj riki’l',
    '🥘' => 'Riki’l pa xarten',
    '🍲' => 'Laq rech riki’l',
    '🥣' => 'b’olaq ruk’ pak’ab’al',
    '🥗' => 'Rax Uwache’',
    '🍿' => 'Paq’im ixim',
    '🥫' => 'wa pa b’ot',
    '🍱' => 'Kajxukut rech Riki’l',
    '🍘' => 'Kaxlanwa aros',
    '🍙' => 'Tz’uqutz’ik aros',
    '🍚' => 'Tzakom Aros',
    '🍛' => 'Aros pa Jok’om',
    '🍜' => 'K’atan laq riki’l',
    '🍝' => 'Jurujaq',
    '🍠' => 'B’olom Kamo’t',
    '🍢' => 'Oden',
    '🍣' => 'Sushi',
    '🍤' => 'B’olom Kamaron',
    '🍥' => 'Setesik Kar ruk’ sutib’al',
    '🍡' => 'Dango',
    '🥟' => 't’oqto’y',
    '🥠' => 'q’ochom kab’',
    '🥡' => 'k’olwa',
    '🍦' => 'Tz’uqutz’ik t’aja’j',
    '🍧' => 'T’aja’j pa k’olib’al',
    '🍨' => 'Joromsab’al',
    '🍩' => 'Taq mulq’ab’',
    '🍪' => 'Yayet',
    '🎂' => 'Kaxlanwa rech alaxib’al',
    '🍰' => 'Jub’a kaxlanwa',
    '🥧' => 'pisetkaxlanwa',
    '🍫' => 'Uq’e’tb’al chokolat',
    '🍬' => 'Kab’',
    '🍭' => 'Setkab’',
    '🍮' => 'Ruk’ Uwaltu’',
    '🍯' => 'Xa’r rech Raxkab’',
    '🍼' => 'Mamon',
    '🥛' => 'Kop rech uwaltu’',
    '☕' => 'K’atam Kaqumuxik',
    '🍵' => 'Jun b’as meq’in te',
    '🍶' => 'Qumulb’al',
    '🍾' => 'B’ot ruk’ tz’apib’al le kpolajik',
    '🍷' => 'Pajb’al rech tzam',
    '🍸' => 'Kop rech Uwalche’',
    '🍹' => 'Ja’ rech saq’ij',
    '🍺' => 'Jun xa’r Tzam',
    '🍻' => 'Upaq’ixik Xa’r rech Tzam',
    '🥂' => 'Upaq’ixik taq kop',
    '🥃' => 'Alaj b’as',
    '🥤' => 'kop ruk’ jek’b’al',
    '🥢' => 'che’teleb’al',
    '🍽' => 'xk’aq chi’l kuchi’l ruk’ web’al',
    '🍴' => 'Leleb’al chi’l ch’ikb’al',
    '🥄' => 'Pak’ab’al',
    '🔪' => 'Kuchi’l rech Nuk’b’al q’aq’',
    '🏺' => 'Ánfora',
    '🌍' => 'K’olok’ik Kuk’ut Europa chi’l Africa',
    '🌎' => 'K’olok’ik Kuk’ut taq América',
    '🌏' => 'K’olok’ik Kuk’ut Asia chi’l Australia',
    '🌐' => 'K’olok’ik Kuk’ut taq Meriadianos',
    '🗺' => 'uwachib’al uwachulew',
    '🗾' => 'Uwachib’al uwachulew rech Japón',
    '🏔' => 'juyub’ ruk’ saq tew',
    '⛰' => 'juyub’',
    '🌋' => 'Xkanul',
    '🗻' => 'Uwachi’b’al juyub’',
    '🏕' => 'uxjuyub’',
    '🏖' => 'palow ruk’ q’ateb’al jab’',
    '🏜' => 'tz’inilik ulew',
    '🏝' => 'tz’inilik ulew sutja’',
    '🏞' => 'uxlamb’al rech amaq’',
    '🏟' => 'nim etz’amb’al',
    '🏛' => 'ojer ja',
    '🏗' => 'tz’qb’al ja',
    '🏘' => 'taq ja',
    '🏚' => 'meb’a’ ja',
    '🏠' => 'Ja',
    '🏡' => 'Ja ruk’ kotz’ij',
    '🏢' => 'Nim ja chakub’al',
    '🏣' => 'Taqb’al Oqa’n rech Japon',
    '🏤' => 'Wachib’al ja chakub’al',
    '🏥' => 'Nim Ja k’unab’al',
    '🏦' => 'K’olpwaq',
    '🏨' => 'Ja warab’al',
    '🏩' => 'Warab’al rech loq’ob’al',
    '🏪' => 'K’ayib’al rech Ajawatajem',
    '🏫' => 'Tijob’al',
    '🏬' => 'Nimaq k’olib’al',
    '🏭' => 'Ja wokob’al',
    '🏯' => 'Je’l ja rech Japo’n',
    '🏰' => 'kasti’y',
    '💒' => 'K’ulanem',
    '🗼' => 'Torre Tokio',
    '🗽' => 'Estatua de la libertad',
    '⛪' => 'Tyox',
    '🕌' => 'Mezquita',
    '🕍' => 'tyoxja',
    '⛩' => 'sinto',
    '🕋' => 'Kaaba',
    '⛲' => 'Uxe’al',
    '⛺' => 'Xax Wara’b’al',
    '🌁' => 'Q’eq sutz’',
    '🌃' => 'Chaq’ab’ ruk’ ch’umil',
    '🏙' => 'uwachib’al nim tinamit',
    '🌄' => 'Q’ij chi rij juyub’',
    '🌅' => 'Usaqarib’al',
    '🌆' => 'Wachib’al rech Tinamit rech B’enaq q’ij',
    '🌇' => 'Uqajik b’i q’ij',
    '🌉' => 'Q’axeb’al Chaq’ab’',
    '♨' => 'k’atanja’',
    '🎠' => 'Setkej',
    '🎡' => 'Setesik Mayb’al',
    '🎢' => 'Montaña rusa',
    '💈' => 'B’olob’ik ub’antajik',
    '🎪' => 'Uk’olib’al Et’zamb’al',
    '🚂' => 'Jurujik ch’ich’',
    '🚃' => 'Laj jurujik ch’ich’',
    '🚄' => 'Nim ukanil Jurujik ch’ich’',
    '🚅' => 'Nim ukanil Jurujik ch’ich’ ruk’ Utz’am',
    '🚆' => 'Nim jurujik ch’ich’',
    '🚇' => 'Etab’al',
    '🚈' => 'Uwach jurujik ch’ich’',
    '🚉' => 'Opanib’al',
    '🚊' => 'Ub’e jurujik ch’ich’',
    '🚝' => 'Jeb’el jurujik ch’ich’',
    '🚞' => 'Jurujik ch’ich’ pa juyub’',
    '🚋' => 'Ub’e ch’ich’ b’inib’al',
    '🚌' => 'Retal Ch’ich’',
    '🚍' => 'Nim ch’ich’ kanaqajob’ loq',
    '🚎' => 'Trolebús',
    '🚐' => 'Alaj b’inib’al',
    '🚑' => 'K’amb’al yowab’',
    '🚒' => 'Ko’kach’ch’ rech Chupq’aq’',
    '🚓' => 'B’inib’al ch’ich’ rech q’atb’altzij',
    '🚔' => 'Chajib’alch’ich’ Petinaq',
    '🚕' => 'Alaj chh’ich’',
    '🚖' => 'Alaj Ch’ich’ petinaq',
    '🚗' => 'Ch’ich’',
    '🚘' => 'Ch’ich’ b’inib’al kanaqajob’ loq',
    '🚙' => 'Etz’anem kakoj wi b’inib’al ch’ich’',
    '🚚' => 'Ko’kach’ich’ rech jachb’al',
    '🚛' => 'Alaj ko’k Ch’ich’',
    '🚜' => 'Tractor',
    '🏎' => 'anim rech ch’ich’',
    '🏍' => 'ret’et’',
    '🛵' => 'Alaj kej ch’ich’',
    '🚲' => 'Kej ch’ich’',
    '🛴' => 'Jilinel',
    '🚏' => 'Q’ateb’al Retal ch’ich’',
    '🛣' => 'nimq’eq b’e',
    '🛤' => 'jurujik ch’ich’ ko’k',
    '🛢' => 'b’olk’olib’al rech q’anal',
    '⛽' => 'Polajem rech Q’aq’ib’al',
    '🚨' => 'Kaxlan q’aq’ rech q’atb’altzij',
    '🚥' => 'Qe’l Ucholajil Ch’ich’',
    '🚦' => 'Tak’al kaxlan q’aq’ rech b’inib’al',
    '🛑' => 'Retal qatalem',
    '🚧' => 'Tz’aqb’al',
    '⚓' => 'Jachal uwach',
    '⛵' => 'Tok’jukub’',
    '🛶' => 'Jukub’',
    '🚤' => 'Ananinaq jukub’',
    '🛳' => 'aj b’yaj',
    '⛴' => 'erenik',
    '🛥' => 'anch’ich’ jukub’',
    '🚢' => 'Nim jukub’',
    '✈' => 'xik’ich’ich’',
    '🛩' => 'nitz’ xik’ich’ich’',
    '🛫' => 'Releb’al xik’ichi’ch’',
    '🛬' => 'Ropanib’al xik’ik’el ch’ich’',
    '💺' => 'T’uyulb’al',
    '🚁' => 'Rapch’ich’',
    '🚟' => 'Q’axeb’al',
    '🚠' => 'Teleférico',
    '🚡' => 'Chikajij xekekb’al',
    '🛰' => 'sutinel',
    '🛸' => 'chikajilset',
    '🛎' => 'telenel',
    '⌛' => 'Jalajoj lame’t',
    '⏳' => 'Taq lame’t ruk’ seneyeb’',
    '⌚' => 'Retab’al q’ij',
    '⏰' => 'Wane’jb’al rech retalq’ij',
    '⏱' => 'q’ateb’al retab’alil q’ij',
    '⏲' => 'retab’alil q’ij rech kloretab’al q’ij',
    '🕰' => 'maretab’al q’ij',
    '🕛' => 'Kab’lajuj ramaj',
    '🕧' => 'Kab’lajuj-juwinaq lajuj',
    '🕐' => 'Jun ramaj',
    '🕜' => 'Jun-juwinaq lajuj',
    '🕑' => 'Keb’ ramaj',
    '🕝' => 'Keb’-juwinaq lajuj',
    '🕒' => 'Oxib’ ramaj',
    '🕞' => 'Oxib’-juwinaq lajuj',
    '🕓' => 'Kajib’ Ramaj',
    '🕟' => 'Kajib’ ruk’ Juwinaq lajuj',
    '🕔' => 'Job’ Ramaj',
    '🕠' => 'Job’ ruk’ Juwinaq Lajuj',
    '🕕' => 'Waqib’ ramaj',
    '🕡' => 'Waqb’-juwinaq lajuj',
    '🕖' => 'Wuqub’ ramaj',
    '🕢' => 'Wuqub’-juwinaq lajuj',
    '🕗' => 'Wajxaqib’ Ramaj',
    '🕣' => 'Wajxaqib’ ruk’ Juwinaq Lajuj',
    '🕘' => 'B’elejeb’ ramaj',
    '🕤' => 'B’elejeb’-juwinaq lajuj',
    '🕙' => 'Lajuj ramaj',
    '🕥' => 'Lajuj-juwinaq lajuj',
    '🕚' => 'Ju’lajuj Ramaj',
    '🕦' => 'Ju’lajuj ruk’ Juwinaq lajuj',
    '🌑' => 'K’ak’ ik’',
    '🌒' => 'Uk’iyem jub’a ik’',
    '🌓' => 'Nik’aj ik’',
    '🌔' => 'Ub’antajik kotokik ik’',
    '🌕' => 'Tzaqat Ik’',
    '🌖' => 'Q’ilb’al rech xotol ik’',
    '🌗' => 'Jub’a ik’',
    '🌘' => 'Q’ilb’al rech uk’iyem ik’',
    '🌙' => 'Uk’iyik ik’',
    '🌚' => 'K’ak’ ik’ palajaj',
    '🌛' => 'Nik’aj Ik’ ruk’ Palajaj',
    '🌜' => 'Jub’a ik’ k’o upalaj',
    '🌡' => 'q’aq’tewal',
    '☀' => 'q’ij',
    '🌝' => 'Tzaqat Ik’ ruk’ Palajaj',
    '🌞' => 'Q’ij k’o upalaj',
    '⭐' => 'Saq retal ch’umil',
    '🌟' => 'Uchupchutem Ch’umil',
    '🌠' => 'Uxu’m ch’umil',
    '🌌' => 'Chikajil',
    '☁' => 'sutz’',
    '⛅' => 'Q’ij chi rij sutz’',
    '⛈' => 'sutz’ ruk’ tzuk’linem chi’l jab’',
    '🌤' => 'q’ij chi rij nitz’ sutz',
    '🌥' => 'q’ij chi rij nim sutz',
    '🌦' => 'q’ij chi rij sutz’ rech jab’',
    '🌧' => 'sutz’ ruk’ jab’',
    '🌨' => 'sutz’ ruk’ saq tew',
    '🌩' => 'sutz’ ruk’ tzuklinem',
    '🌪' => 'nim salk’um',
    '🌫' => 'sutz’ u-wächulew',
    '🌬' => 'kaqiq’ palajaj',
    '🌀' => 'Ciclón',
    '🌈' => 'Xk’uq’ab’',
    '🌂' => 'Tz’apital Q’atjab’',
    '☂' => 'q’ateb’al jab’',
    '☔' => 'Panab’al ruk’ jab’',
    '⛱' => 'q’atjab’ pa uwach ulew',
    '⚡' => 'Nim uchuq’ab’',
    '❄' => 'krissaq tew',
    '☃' => 'achi rech saq tew',
    '⛄' => 'Achi rech t’aja’j maj utza’m',
    '☄' => 'juch’ch’umil',
    '🔥' => 'Q’aq’',
    '💧' => 'Tz’uj',
    '🌊' => 'Uyi’kopem ja’',
    '🎃' => 'Tzijil Mukun',
    '🎄' => 'Che’ rech Alaxib’al',
    '🎆' => 'Kaxlan taq Q’aq’',
    '🎇' => 'Kareprotik',
    '✨' => 'Kachupchutik',
    '🎈' => 'Pupu',
    '🎉' => 'Wiqob’al rech nimaq’ij',
    '🎊' => 'Setesik rech Kab’',
    '🎋' => 'Che’ rech Tanabata',
    '🎍' => 'Wiqob’al xaqchaj',
    '🎎' => 'Taq Ala’s rech Japon',
    '🎏' => 'Jalajoj kar',
    '🎐' => 'Kampani’l rech kaqiq’',
    '🎑' => 'Ik’ ch’il nimaq’ij',
    '🎀' => 'kemutasil',
    '🎁' => 'Pisom kochij',
    '🎗' => 'na’tajisab’al kemutasil',
    '🎟' => 'rajilab’alil',
    '🎫' => 'Uwujil',
    '🎖' => 'chachal rech militar',
    '🏆' => 'Trofeo',
    '🏅' => 'Chachal rech etz’anem',
    '🥇' => '1st Ucholaj chachal',
    '🥈' => '2nd Ucholajil Chachal',
    '🥉' => '3rd ucholajil Chachal',
    '⚽' => 'Potz’ rech aqanaj',
    '⚾' => 'Potz’pale’t',
    '🏀' => 'Q’ab’potz’',
    '🏐' => 'Voleibol',
    '🏈' => 'Aqananik rech América',
    '🏉' => 'Tutz’utik potz’',
    '🎾' => 'Potz’ chi pale’t',
    '🎳' => 'K’aqoj',
    '🏏' => 'potz’ che’ etz’anem',
    '🏑' => 'Hockey chi uwach Q’ayes',
    '🏒' => 'Hockey pa Saq Tew',
    '🏓' => 'Ping Pong',
    '🏸' => 'Setesik pale’t',
    '🥊' => 'Tasq’ab’ rech Ch’ayk’olq’ab’',
    '🥋' => 'Atz’i’aq rech ajch’a’oj',
    '🥅' => 'Kemk’at Ub’antajik',
    '⛳' => 'Retwokaj pa Ju’l',
    '⛸' => 'texajab’ rech t’ajaj',
    '🎣' => 'Chapb’al kar',
    '🎽' => 'Jastaq tijb’al anim',
    '🎿' => 'Chararb’al',
    '🛷' => 'b’enam pa teleb’al',
    '🥌' => 'setab’aj',
    '🎯' => 'Suk’um Nim ucholajil',
    '🔫' => 'K’qb’al q’aq’',
    '🎱' => 'K’olok’ik wajxaqib’',
    '🔮' => 'Setesik Kristal',
    '🎮' => 'Silob’wachib’al rech etz’anem',
    '🕹' => 'etz’piz’b’al',
    '🎰' => 'Ch’ich’ etz’anb’al',
    '🎲' => 'Ukamikal etz’anem',
    '♠' => 'nimatz’i’aqb’al',
    '♥' => 'anima',
    '♦' => 'jeb’el ab’aj nimatz’i’aqb’al',
    '♣' => 'luwokajil',
    '🃏' => 'Etz’anel',
    '🀄' => 'Mahjong kaq Dragon',
    '🎴' => 'Taq kotz’ij uwujil etz’anem',
    '🎭' => 'Palajaj rech je’l k’utunsanem',
    '🖼' => 'wachib’al kojom uchi’',
    '🎨' => 'Palet rech Aje’lal chak',
    '👓' => 'Taq kop',
    '🕶' => 'q’ijilb’al',
    '👔' => 'Rab’kulaj',
    '👕' => 'Ku’t atz’i’aq',
    '👖' => 'Taq Rab’koxtar',
    '🧣' => 'ku’t uq',
    '🧤' => 'ch’uq’ab’',
    '🧥' => 'koq’uaj',
    '🧦' => 'tasaqanaj',
    '👗' => 'Roqorik Atz’i’aq',
    '👘' => 'Kimono',
    '👙' => 'Muxja’',
    '👚' => 'Ujastaq ixoq',
    '👛' => 'Karte’r',
    '👜' => 'Chim',
    '👝' => 'Je’l B’olxa',
    '🛍' => 'chim rech loq’oj',
    '🎒' => 'Chim rech tijob’al',
    '👞' => 'Uxajab’ achi',
    '👟' => 'Xajab’ tijb’al anim',
    '👠' => 'Nim Uparaqan Xajab’',
    '👡' => 'Uxo’l aqanaj rech ixoq',
    '👢' => 'Ub’otax ixoq',
    '👑' => 'Setjolomaj',
    '👒' => 'Upowi’ ixoq',
    '🎩' => 'Jurujik powi’',
    '🎓' => 'Powi’ rech Ch’akanem',
    '🧢' => 'b’ito’y',
    '⛑' => 'chi’ch’ powi’ rech tob’anem',
    '📿' => 'Retz’ab’a’lil uqul q’ab’aj',
    '💄' => 'Tz’ajb’al chi’aj',
    '💍' => 'Mulq’ab’',
    '💎' => 'Ab’aj rech Gema',
    '🔇' => 'Q’atab’am ch’ab’alil',
    '🔈' => 'Ta’ob’al tzij nitz’ uchuq’ab’',
    '🔉' => 'Ta’ob’al tzij retal uchuq’ab’',
    '🔊' => 'Ta’ob’al tzij nim uchuq’ab’',
    '📢' => 'Ko jek’b’al ch’aweb’al',
    '📣' => 'Ch’ich’ ch’aweb’al',
    '📯' => 'Kotokik trompet',
    '🔔' => 'Kampan',
    '🔕' => 'Kampan ruk’ Juch’',
    '🎼' => 'Wuj rech utz’ib’ q’ojom',
    '🎵' => 'Utz’ib’ q’ojom',
    '🎶' => 'Taq utz’ib’ q’ojom',
    '🎙' => 'k’oq’ojomal rech jek’b’al ch’aweb’al',
    '🎚' => 'jililb’al cholajil',
    '🎛' => 'rilawachixik taq pitz’b’al',
    '🎤' => 'Jeqb’al ch’ab’al',
    '🎧' => 'Uk’amal ch’aweb’al',
    '📻' => 'Q’axeb’al tzij',
    '🎷' => 'Saxopon',
    '🎺' => 'Trompet',
    '🎸' => 'Kita’r',
    '🎹' => 'Q’ojomb’al tz’emb’al',
    '🎻' => 'Violin',
    '🥁' => 'Tamb’or',
    '📱' => 'B’inib’al ch’aweb’al',
    '📲' => 'B’inib’al ch’aweb’al ruk’ ch’ab’',
    '☎' => 'ch’aweb’al',
    '📞' => 'Ch’aweb’al pa eye’nik',
    '📟' => 'Tzukub’alwinaq',
    '📠' => 'Q’axeb’al Wuj',
    '🔋' => 'K’olq’aq’al',
    '🔌' => 'T’iqb’al Kaxlan Q’aq’',
    '💻' => 'Achib’il t’inwach',
    '🖥' => 'kematz’ib’ rech mexatz’ib’',
    '🖨' => 'tz’ajtz’ib’anel',
    '⌨' => 'pitz’b’al',
    '🖱' => 'ch’o rech kematz’ib’',
    '🖲' => 'tach’o',
    '💽' => 'Ko K’olib’al',
    '💾' => 'Kajxukut K’olib’al',
    '💿' => 'Set k’olib’al',
    '📀' => 'Dvd',
    '🎥' => 'Eelesab’al wachib’al',
    '🎞' => 'taq uchi’ silob’k’utwachib’al',
    '📽' => 'k’utb’al silob’k’utwachinem',
    '📺' => 'Q’axwachirisab’al',
    '📷' => 'Elesab’al wachib’al',
    '📸' => 'Elesab’al wachib’al ruk’ tzuk’linem',
    '📹' => 'Elesab’al silob’wachib’al',
    '📼' => 'Silob’sab’al',
    '🔍' => 'Setesik lame’t nimarisab’al',
    '🔎' => 'Qetsab’al',
    '🕯' => 'kantela',
    '💡' => 'Tzijil kaxlan q’aq’',
    '🔦' => 'Tzuk’b’al',
    '🏮' => 'Kaq tzuk’ulb’al',
    '📔' => 'Wokub’ixikil q’oq’otem rij',
    '📕' => 'Tz’apital wuj',
    '📖' => 'Jaqom wuj',
    '📗' => 'Rax Wuj',
    '📘' => 'Raxkaj Wuj',
    '📙' => 'Uje’ koj wuj',
    '📚' => 'Taq wuj',
    '📓' => 'Wokub’ixikil',
    '📒' => 'Kab’ichal retal wuj',
    '📃' => 'Uxaq wuj mejom la chi uxe’',
    '📜' => 'Ojer wujilal',
    '📄' => 'Uxaq wuj mejom uchi’',
    '📰' => 'Wuj tzijonb’al',
    '🗞' => 'b’olq’otim',
    '📑' => 'Taq k’utjaqb’al rech kojb’al retal',
    '🔖' => 'Kojb’al retal',
    '🏷' => 'retwokaj',
    '💰' => 'Chim rech pwaq',
    '💴' => 'Pwaq yen',
    '💵' => 'Uxaq Dolar',
    '💶' => 'Uxaq Euro',
    '💷' => 'Ub’ixikil ja k’olpwaq libra',
    '💸' => 'Pwaq ruk’ uxik’',
    '💳' => 'Uwujil K’asaj',
    '💹' => 'Ktajin Kpaqi’ Wokk’utunsab’al ruk’ Yen',
    '✉' => 'k’oltz’ib’wuj',
    '📧' => 'Taqoqxa’nib’al',
    '📨' => 'Rokik k’oltz’ib’wuj',
    '📩' => 'K’olwuj ruk’ ch’ab’',
    '📤' => 'K’olib’al chi kaj',
    '📥' => 'K’oltaqoqxa’nib’al',
    '📦' => 'Tanaj oqxa’n',
    '📫' => 'Tz’apital Opanib’al taqoqxa’n ruk’ Paqab’isam Retwokaj',
    '📪' => 'Tz’apital Opanib’al taqoqxa’n ruk’ xulan Retwokaj',
    '📬' => 'Jaqom k’olib’al taqoqxa’n ruk’ bandera',
    '📭' => 'Jaqom k’olib’al taqoqxa’n',
    '📮' => 'K’olib’al taqoqxa’n',
    '🗳' => 'kajxukut rech b’owuj ruk’ b’owuj',
    '✏' => 'che’ tz’ib’ab’al',
    '✒' => 'q’eq uwi’',
    '🖋' => 'uxe’l che’ tz’ib’ab’al',
    '🖊' => 'tz’ib’ab’al',
    '🖌' => 'mestz’ajb’al',
    '🖍' => 'tz’ajb’al',
    '📝' => 'Tz’i’b’ab’al ruk’ wuj',
    '💼' => 'Jeb’el k’olib’al',
    '📁' => 'K’olkemchak rech Kemk’olib’al',
    '📂' => 'Jaqom k’olkemchak',
    '🗂' => 'jachb’al taq ucholajil wuj',
    '📅' => 'Cholq’ij',
    '📆' => 'Aninaq uretzixik cholq’ij',
    '🗒' => 'b’olq’ot t’in pitz’b’al',
    '🗓' => 'b’olq’ot cholq’ij',
    '📇' => 'Kemch’aqata’q',
    '📈' => 'Ktajin Kpaqi’ Wokk’utunsab’al',
    '📉' => 'Ktajin Kxuli’ Wokk’utunsab’al',
    '📊' => 'K’utwachib’al rech q’e’tb’al',
    '📋' => 'K’olk’iwuj',
    '📌' => 'Nitz’ lawux',
    '📍' => 'K’olok’ik nitz’ lawux',
    '📎' => 'Chapab’al wuj',
    '🖇' => 'tiqital',
    '📏' => 'Suk’ etab’al',
    '📐' => 'Oxxukut etab’al',
    '✂' => 'taq qupib’al',
    '🗃' => 'kajxukut rech ukemk’olib’al uwujil',
    '🗄' => 'k’olwuj',
    '🗑' => 'meschakach',
    '🔒' => 'Tz’apitalik',
    '🔓' => 'Tz’apital taj',
    '🔏' => 'Tz’apital ruk’ tz’ib’ab’al',
    '🔐' => 'Tz’apital ruk’ lawe',
    '🔑' => 'Lawe',
    '🗝' => 'ojer retokib’al',
    '🔨' => 'B’ajib’al',
    '⛏' => 'usik’ik’',
    '⚒' => 'b’ajib’al chi’l usik’ik',
    '🛠' => 'B’ajib’al chi’l nim lawe',
    '🗡' => 'kuchi’l',
    '⚔' => 'ukrusim rib’ taq spad',
    '💣' => 'Polajem',
    '🏹' => 'Arku’ rech Ch’ab’',
    '🛡' => 'q’ateb’al',
    '🔧' => 'Llave inglesa',
    '🔩' => 'Chapb’al ruk’ tz’apib’al',
    '⚙' => 'mulaj ch’ich’',
    '🗜' => 'laq’apub’al',
    '⚖' => 'Upajik ucholajil',
    '🔗' => 'Kemwiqb’al',
    '⛓' => 'taq ch’ich’',
    '⚗' => 'k’amil',
    '🔬' => 'Nitz’arib’al',
    '🔭' => 'Ilb’al uwach kaj',
    '📡' => 'Jek’b’al chuq’ab’il pa kaqiq’',
    '💉' => 'B’aq kunab’al',
    '💊' => 'Kunab’al',
    '🚪' => 'Uchi ja',
    '🛏' => 'ch’at',
    '🛋' => 'nim tem chi’l chaq’aq’',
    '🚽' => 'Seteleb’al',
    '🚿' => 'Atinib’al',
    '🛁' => 'Ch’ajb’al',
    '🛒' => 'Kare’t rech loq’oj',
    '🚬' => 'Sik’',
    '⚰' => 'kaxa',
    '⚱' => 'muqunem k’olchaj',
    '🗿' => 'Ab’aj palajaj',
    '🏧' => 'Retal ATM',
    '🚮' => 'Uk’aqik mes pa uk’olib’al',
    '🚰' => 'Ch’ajch’oj ja’',
    '♿' => 'Retal tem kasutin raqan',
    '🚹' => 'Kik’olib’al achijab’',
    '🚺' => 'Upaja kech ixoqib’',
    '🚻' => 'Eleb’al',
    '🚼' => 'Retal Ne’',
    '🚾' => 'Eleb’al rech ja’',
    '🛂' => 'Q’atul wujilal',
    '🛃' => 'Ja tojb’al okem',
    '🛄' => 'Uk’amik Jastaq',
    '🛅' => 'K’olib’al wuj ruk’ lawe',
    '⚠' => 'q’ilb’al',
    '🚸' => 'Ktajin ke’eq’ax ak’alab’',
    '⛔' => 'Maj okib’al',
    '🚫' => 'Q’atetalik',
    '🚳' => 'Man rech ta kej ch’ich’',
    '🚭' => 'Man rech ta tub’anem',
    '🚯' => 'Kak’aq ta mes',
    '🚱' => 'Ja’ maj ch’ajch’oj taj',
    '🚷' => 'Man rech b’inem',
    '📵' => 'Man rech ta b’inib’al ch’aweb’al',
    '🔞' => 'Man kech ta ak’alab’',
    '☢' => 'k’atmiq’anem',
    '☣' => 'uk’axk’olil k’aslemal',
    '⬆' => 'ch’ab’ pa uwi’',
    '↗' => 'ch’ab’ pa uwi’ chi’l pa wikiq’ab’',
    '➡' => 'wikiq’ab’ ch’ab’',
    '↘' => 'wikiq’ab’ cha’b’ chi uxe’',
    '⬇' => 'cha’b’ chi uxe’',
    '↙' => 'moxq’ab’ ch’ab’ chi uxe’',
    '⬅' => 'moxq’ab’ chab’',
    '↖' => 'moxq’ab’ ch’ab’ pa uwi’',
    '↕' => 'ch’ab’ pa uwi’-chi uxe’',
    '↔' => 'ch’ab’ moxq’ab’-wikiq’ab’',
    '↩' => 'wikiq’ab’ ch’ab’ kotol b’i pa moxq’ab’',
    '↪' => 'moxq’ab’ q’ab’ ch’ab’ kotol b’i pa wikiq’ab’',
    '⤴' => 'wikiq’ab’ ch’ab’ kotol b’i pa uwi’',
    '⤵' => 'wikiq’ab’ ch’ab’ kotol b’i chi uxe’',
    '🔃' => 'Tak’al taq ch’ab’ pa Wikiq’ab’',
    '🔄' => 'Pitz’b’al rech Moxq’ab’ taq Ch’ab’',
    '🔙' => 'Ch’ab’ rech Tzalijisab’al',
    '🔚' => 'UKISB’AL Ch’ab’',
    '🔛' => 'Ch’ab’ chi kaj',
    '🔜' => 'Aninaq Ch’ab’',
    '🔝' => 'Ch’ab’ TOP',
    '🛐' => 'K’olib’al b’anb’al ch’ab’al',
    '⚛' => 'etal atom',
    '🕉' => 'om',
    '✡' => 'ch’umil rech David',
    '☸' => 'b’inisab’al rech dharma',
    '☯' => 'kojb’al yin kojb’al yang',
    '✝' => 'krus latino',
    '☦' => 'krus ortodoxio',
    '☪' => 'ch’umil chi’l uk’iyem',
    '☮' => 'retal utzil',
    '🕎' => 'Tzuk’ulb’al kotz’i’j',
    '🔯' => 'Waqib’ uwi’ Jisik’ uwi’ ch’umil',
    '♈' => 'Aries',
    '♉' => 'Taurus',
    '♊' => 'Geminis',
    '♋' => 'Q’ayik',
    '♌' => 'Leo',
    '♍' => 'Virgo',
    '♎' => 'Libra',
    '♏' => 'Escorpio',
    '♐' => 'Sagitario',
    '♑' => 'Capricornio',
    '♒' => 'K’arb’al',
    '♓' => 'Piscis',
    '⛎' => 'Ofiuco',
    '🔀' => 'Ch’ab’ upach’um rib’',
    '🔁' => 'Pitz’b’al ukamulixik',
    '🔂' => 'Pitz’b’al ukamulixik q’ojom',
    '▶' => 'pitz’b’al rech utzijil',
    '⏩' => 'Aninaq Pitz’b’al chi Uwach',
    '⏭' => 'pitz’b’al teren chi uloq',
    '⏯' => 'pitz’b’al rech utzijik on ruxlanisaxik',
    '◀' => 'pitz’b’al rech tzalijisab’al',
    '⏪' => 'Aninaq Tzalijisab’al Pitz’b’al',
    '⏮' => 'pitz’b’al rech uk’isb’al b’ix',
    '🔼' => 'Pitz’b’al pa uwi’',
    '⏫' => 'Aninaq Pitz’b’al pa uwi’',
    '🔽' => 'Pitz’b’al chi uxe’',
    '⏬' => 'Aninaq Pitz’b’al chi Uxe’',
    '⏸' => 'pitz’b’al rech uxlanem',
    '⏹' => 'pitz’b’al rech uq’atexik',
    '⏺' => 'pitz’b’al rech uk’olik ch’ab’alil',
    '⏏' => 'pitz’b’al rech relesaxik',
    '🎦' => 'Silob’k’utwachib’al',
    '🔅' => 'Ub’antajik Pitz’b’al',
    '🔆' => 'Reprot B’oton',
    '📶' => 'Taq uq’e’tb’al Jeqk’utb’alil',
    '📳' => 'Kab’irb’ot ub’antajik',
    '📴' => 'Chupum b’inib’al ch’aweb’al',
    '♀' => 'Juch’b’i’aj rech ixoq',
    '♂' => 'juch’b’i’aj rech achi',
    '✖' => 'nim k’iyarisanem x',
    '➕' => 'Al Etal rech Mulinem',
    '➖' => 'Al Etal rech Elesanem',
    '➗' => 'Al Etal rech Elesab’al',
    '‼' => 'keb’ichal etal rech mayib’al',
    '⁉' => 'etal rech k’otb’al chi’aj',
    '❓' => 'Retal k’otoj chi’aj',
    '❔' => 'Saq retal k’otoj chi’aj',
    '❕' => 'Retal saq mayb’al',
    '❗' => 'Retal Tzaqb’al k’u’x',
    '〰' => 'kotokik nimajuch’',
    '💱' => 'Uk’exik Pwaq',
    '💲' => 'Al Etal rech Dólar',
    '⚕' => 'etal rech kunanem',
    '♻' => 'retal k’olmes',
    '⚜' => 'pek’otzi’j',
    '🔱' => 'Retal oxib’ uwi’',
    '📛' => 'Uk’olib’al b’i’aj',
    '🔰' => 'Etal rech Japon rech taq majib’al',
    '⭕' => 'Al Nim Setesik',
    '✅' => 'Saq retal juch’',
    '☑' => 'kajxukut rech juch’b’al ruk’ q’atub’al',
    '✔' => 'nim uq’atub’al etal',
    '❌' => 'Retal Krus',
    '❎' => 'Pitz’b’al rech retal Krus',
    '➰' => 'Kotokik k’a’am',
    '➿' => 'Kab’ichal kotokik b’atz’',
    '〽' => 'k’exb’alil rech utz’aqatil etal',
    '✳' => 'wajxaqib’ ra’l uwi’ ch’umul',
    '✴' => 'wajxaqib’ uwi’ ch’umul',
    '❇' => 'chupchutem',
    '™' => 'k’ay etal',
    '🔠' => 'Rokib’al Nim tz’ib’ rech Latino',
    '🔡' => 'Rokib’al Nitz’ tz’ib’ rech Latino',
    '🔢' => 'Rokib’al taq Ajilab’al',
    '🔣' => 'Rokib’al taq Etal',
    '🔤' => 'Rokib’al taq Tz’ib’wuj rech Latino',
    '🅰' => 'pitz’b’al A (kik’ uwach)',
    '🆎' => 'Pitz’b’al AB (kik’ uwach)',
    '🅱' => 'pitz’b’al B (kik’ uwach)',
    '🆑' => 'B’oton CL',
    '🆒' => 'JE’L B’oton',
    '🆓' => 'Pitz’b’al rech Tzoqopib’al',
    'ℹ' => 'q’alajisanem',
    '🆔' => 'Pitz’b’al rech ID',
    'Ⓜ' => 'sutim M',
    '🆕' => 'K’AK’ pitz’b’al',
    '🆖' => 'NG pitz’b’al',
    '🅾' => 'O pitz’b’al (uwach kik’)',
    '🆗' => 'Pitz’b’al rech Uk’amik',
    '🅿' => 'pitz’b’al P',
    '🆘' => 'Pitz’b’al SOS',
    '🆚' => 'Pitz’b’al VS',
    '🈁' => 'Pitz’b’al rech ’waral’ rech Japon',
    '🈂' => 'rech Japón "tojtal patanib’al" pitz’b’al',
    '🈷' => 'rech Japón pitz’b’al rech "rajilab’alil chi ik’"',
    '🈶' => 'Pitz’b’al rech ’man xaq ta Sipalatik’ rech Japon',
    '🈯' => 'Pitz’b’al rech ’tastalik’ rech Japon',
    '🉐' => 'Pitz’b’al rech ’rajilal’ rech Jap’on',
    '🈹' => 'Pitz’b’al rech ’qajrajilal’ rech Japon',
    '🈚' => 'Pitz’b’al rech ’man Ktoj taj’ rech Japon',
    '🈲' => 'Pitz’b’al rech "man ya’tal taj" rech Japon',
    '🉑' => 'Pitz’b’al rech ’uk’amik’ rech Japo’n',
    '🈸' => 'Pitz’b’al rech ’kojkemchak’ rech Japo’n',
    '🈴' => 'Pitz’b’al rech "uq’axexik ucholajil" rech Japon',
    '🈳' => 'Pitz’b’al rech ’tolonik’ rech Japon',
    '㊗' => 'Pitz’b’al rech "ki’kotemal chi awech" rech Japon',
    '㊙' => 'Pitz’b’al rech "echeb’alil" rech Japon',
    '🈺' => 'Japanese ’jaqatal chech taq K’ayinem’ rech Japon',
    '🈵' => 'Pitz’b’al rech ’man k’o ta Tolonik’ rech Japon',
    '🔴' => 'Setesik kaq',
    '🔵' => 'Setesik Raxkaj',
    '⚫' => 'Q’eq Setesik',
    '⚪' => 'Setesik saq',
    '⬛' => 'Nim q’eq kajxukut',
    '⬜' => 'Nim saq kajxukut',
    '◼' => 'retal q’eq’ kajxukut',
    '◻' => 'retal saq kajxukut',
    '◾' => 'Retal-Nitz’ Q’eq Kajxukut',
    '◽' => 'Saq nik’aj nitz’ kajxukut',
    '▪' => 'q’eq’ nitz’ kajxukut',
    '▫' => 'saq nitz’ kajxukut',
    '🔶' => 'Nim uje’ koj ab’aj',
    '🔷' => 'Nim raxkaj ab’aj',
    '🔸' => 'Nitz’ uje’ koj ab’aj',
    '🔹' => 'Nitz’ raxkaj ab’aj',
    '🔺' => 'Kaq oxxukut paqal uwi’',
    '🔻' => 'Kaq oxxukut xulan uwi’',
    '💠' => 'Je’lalaj ab’aj ruk’ Nak’',
    '🔘' => 'Pitz’b’al q’axeb’al tzij',
    '🔳' => 'Saq kajxukut pitz’b’al',
    '🔲' => 'Q’eq kajxukut b’oton',
    '🏁' => 'Kajxukut Retwokaj',
    '🚩' => 'Oxxukut retwokaj',
    '🎌' => 'Taq retal wokaj Ukrusim rib’',
    '🏴' => 'Q’eq Retwokaj',
    '🏳' => 'saq retamaq’',
];
